(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  13563674,     281438]*)
(*NotebookOutlinePosition[  13636405,     284010]*)
(*  CellTagsIndexPosition[  13636361,     284006]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["A Catalog of Cellular Automata", "Title",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  StyleBox["By\n\n", "Author"],
  StyleBox["Jaime Rangel-Mondrag\[OAcute]n", "Author",
    FontSize->18,
    FontWeight->"Bold"],
  StyleBox["\n", "Author"],
  StyleBox["jrangel@sunserver.uaq.mx", "Reference",
    FontSize->16]
}], "Author",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  StyleBox["\nFACULTAD DE INFORM\[CapitalAAcute]TICA\nUNIVERSIDAD AUT\
\[CapitalOAcute]NOMA DE QUER\[CapitalEAcute]TARO\nDIVISI\[CapitalOAcute]N DE \
ESTUDIOS DE POSGRADO", "Reference",
    FontSize->16,
    FontWeight->"Bold"],
  StyleBox["\nCentro Universitario\nCerro de las Campanas s/n\nC.P.76010 Quer\
\[EAcute]taro, Qro.\nMexico", "Reference",
    FontSize->16]
}], "Address"],

Cell[TextData[{
  StyleBox["\nCopyright \[Copyright] December 2000, UAQ, Facultad de Inform\
\[AAcute]tica\n\n", "Commentary"],
  StyleBox["Permission is hereby granted to reproduce part or all of this \
file for any purpose other than direct profit providing that the source is \
acknowledged.",
    FontColor->RGBColor[0, 0, 1]]
}], "Reference"],

Cell["\<\
Acknowledgements

This work was initiated at Wolfram Research Inc., in Champaign IL, USA, while \
the author was spending two months as a Visiting Scholar. Their assistance \
and enthusiastic support is gratefully acknowledged. My thanks are also given \
for the continuous support received from the University of Queretaro in \
Mexico, where this work found completion.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell["", "SectionFirst"],

Cell[TextData[{
  "\"What a ",
  StyleBox["relief",
    FontSlant->"Italic"],
  ", to be away from straight lines,\" a thin man said.\n\n\"Um, how so?\" \
Hari said, trying to seem interested.\n\n\"Well, of course straight lines don\
\.b4t exist in nature. They have to be \nput there by humans.\" He sighed, \
\"I love to be free of straightness!\"\n\nHari instantly thought of pine \
needles; strata of metamorphic rock; \nthe inside edge of a half-moon; \
spider-woven silk strands; \nthe line along the top of a breaking ocean wave; \
crystal patterns; \nwhite quartz lines on granite slabs; the far horizon of a \
vast calm lake; \nthe legs of birds; spikes of cactus; the arrow dive of a \
raptor; \ntrunks of young, fast-growing trees; \nwisps of high windblown \
clouds; ice cracks; \nthe two sides of the V of migrating birds; icicles.\n\
\"Not so,\" he said, but no more.\n\nFoundation\.b4s Fear\nG. Benford"
}], "Text",
  TextAlignment->Right,
  TextJustification->0],

Cell[TextData[{
  "Cellular automata (CA) comprise rules encapsulating mechanisms of \
evolution that model highly complex behavior.  Systematic interest in CA has \
received considerable impetus from the continuous",
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12],
  "work of Stephen Wolfram since 1983 (who undertook a computer-based search \
on the properties of one-dimensional CA) up to the worldwide interest on his \
upcoming book \"A New Kind of  Science\" [1].\n\nA one-dimensional CA \
processes in parallel the simultaneous change of state of each individual \
cell forming a collection arranged in a line. These individual changes are \
performed in accordance to the states of each one of their neighbors \
including itself through the application of a local transition rule. It is \
remarkable the fact that from such a simple mechanism we are able to generate \
a behavior of profoundly intrincate complexity, all this in contrast to the \
general impression that effects are always preceded by causes of at least \
comparable complexity.\n\nIn this work we assume only two possible states and \
the allotted set of states to be ",
  StyleBox["Range[0, b-1]", "InlineInput"],
  ", where b varies from 2 to 4 calling such CA dyadic, triadic and tetradic \
respectively. This work comprises the  generation and display of catalogs of \
families of these CA covering irreducible, totalistic and reversible ones. \
The following results were obtained after several weeks of \
computationally-intensive sessions."
}], "Abstract",
  TextAlignment->Left,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["DYADIC CA", "SectionFirst"],

Cell["CA rules are described by lists:", "Text"],

Cell[BoxData[
    \(\(rule1 = {0, 1, 0, 1, 1, 1, 1, 1};\)\)], "Input"],

Cell[TextData[{
  "We interpret this rule as describing a transformation from the set ",
  Cell[BoxData[
      \(TraditionalForm\`\(\({0, \ 1}\)\(\ \)\)\^\(\(3\)\(\ \)\)\)]],
  "to the set {0,1}"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Thread[
      Map[StringJoin[ToString\ \  /@ \ IntegerDigits[#, 2, 3]] &, 
          Range[0, 7]] \[Rule] rule1]\)], "Input"],

Cell[BoxData[
    \({"000" \[Rule] 0, "001" \[Rule] 1, "010" \[Rule] 0, "011" \[Rule] 1, 
      "100" \[Rule] 1, "101" \[Rule] 1, "110" \[Rule] 1, 
      "111" \[Rule] 1}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "That is, a rule of the form axb \[Rule] y describes the new value y of a \
given cell, given its present value x and those of its two neighbors a and b. \
In the case of dyadic CA, there are ",
  Cell[BoxData[
      \(TraditionalForm\`2\^\(2\^3\)\)]],
  "=256 possible rules. It is possible to prove that linear CA do not need to \
have large neighborhoods; in fact, as Albert and Culick showed [2], it is \
sufficient to have just two cells in a neighborhood.\n\nIn drawing the \
evolution of  CA we indicate state 0 as a white square and a 1 as a black one \
appearing in a two-dimensional evolution  diagram. Function ",
  StyleBox["evolve", "InlineInput"],
  " takes the initial global state of the cellular space ",
  StyleBox["cS", "InlineInput"],
  ", along with a ",
  StyleBox["rule", "InlineInput"],
  " and the number of steps ",
  StyleBox["n", "InlineInput"],
  " of evolution and produces the matrix corresponding to the time diagram of \
the evolution of the corresponding CA. Note that we keep the end sites of cS \
quiescent, which might otherwise produce boundary distortions if a rule \
attempts to activate them; further, function ",
  StyleBox["showCA", "InlineInput"],
  "  generates a graphic object corresponding to a selected portion of this \
matrix to be displayed afterwards."
}], "Text"],

Cell[BoxData[{
    \(cellularSpace[n_] := 
      ReplacePart[Table[0, {n}], 
        1, \[LeftCeiling]n/
            2\[RightCeiling]]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(evolve[b_, cS_, rule_, gen_] := 
      Module[{t}, \[IndentingNewLine]t = 
          Thread[IntegerDigits[Range[0, b\^3 - 1], b, 3] \[Rule] rule]; \ 
        NestList[Join[{0}, Partition[#, 3, 1]\ \  /. t, {0}] &, cS, 
          gen]]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(showCA[b_, cS_, rule_, gen_, fromRow_, fromCol_, toCol_, label_:  1] := 
      Module[{e, index}, \[IndentingNewLine]e = 
          Take[evolve[b, cS, rule, gen], {fromRow, 
              gen}]; \ \[IndentingNewLine]e = \(Take[#, {fromCol, 
                  toCol}] &\)\ \  /@ \ e; \ \[IndentingNewLine]index = 
          StringJoin[
            Which[label \[Equal] 0, "\<\>", label \[Equal] 1, \ 
              ToString\ \  /@ \ rule, label \[Equal] 2, 
              ToString[
                FromDigits[rule, b]]]]; \[IndentingNewLine]ListDensityPlot[
          Reverse[\(-e\)]\ , FrameTicks \[Rule] None, Frame \[Rule] False, 
          Mesh \[Rule] False, AspectRatio \[Rule] Automatic, 
          DisplayFunction \[Rule] Identity, 
          PlotLabel \[Rule] index]]\)}], "Input",
  InitializationCell->True],

Cell["\<\
Note that the length of the cellular space is chosen to be an odd number so \
that the final pattern has central symmetry. Wolfram rule number set out the \
possible sequences of cells in reverse lexicographic order. So our rule \
01101000=104 corresponds to Wolfram\.b4s rule 00010110=22.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n = 31;\)\), "\[IndentingNewLine]", 
    \(\(Show[
        showCA[2, cellularSpace[n], rule1, \[LeftFloor]n/2\[RightFloor], 1, 
          1, n], DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .48387 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0310174 0.00930521 0.0310174 [
[.5 .49637 -26 0 ]
[.5 .49637 26 12.875 ]
[ 0 0 0 0 ]
[ 1 .48387 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .49637 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(01011111) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .48387 L
0 .48387 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00931 translate
.96154 .46526 scale
31 string
31 15 8 [31 0 0 15 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFF
FFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 139.313},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Rb000`400?l00000o`00003oo`3AcJTQ
0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@005P3AcJT7ooooo`P000002?oo
ool8000000Sooooo20000008ooooo`L000002?ooool8000000Sooooo20000008ooooo`P000002?oo
ool7000000Sooooo20000008ooooo`P000002?ooool8000000Oooooo20000008ooooo`P000002?oo
ool8000000Sooooo20000007oooooaL0dLfY000F0=7=Z@Oooooo20000008ooooo`P000002?ooool8
000000Sooooo1`000008ooooo`P000002?ooool8000000Sooooo20000008ooooo`L000002?ooool8
000000Sooooo20000008ooooo`P000001oooool8000000Sooooo20000008ooooo`P000002?ooool8
000000Oooooo5`3AcJT001H0dLfY1oooool8000000Sooooo20000008ooooo`P000002?ooool70000
00Sooooo20000008ooooo`P000002?ooool8000000Sooooo1`000008ooooo`P000002?ooool80000
00Sooooo20000007ooooo`P000002?ooool8000000Sooooo20000008ooooo`P000001ooooolG0=7=
Z@005P3AcJT7ooooo`P000002?ooool8000000Sooooo20000008ooooo`L000002?ooool8000000So
oooo20000008ooooo`P000002?ooool7000000Sooooo20000008ooooo`P000002?ooool8000000Oo
oooo20000008ooooo`P000002?ooool8000000Sooooo20000007oooooaL0dLfY000F0=7=Z@Oooooo
20000008ooooo`P000002?ooool8000000Sooooo1`000008ooooo`P000002?ooool8000000Sooooo
20000008ooooo`L000002?ooool8000000Sooooo20000008ooooo`P000001oooool8000000Sooooo
20000008ooooo`P000002?ooool8000000Oooooo5`3AcJT001H0dLfY1oooool8000000Sooooo2000
0008ooooo`P000002?ooool7000000Sooooo20000008ooooo`P000002?ooool8000000Sooooo1`00
0008ooooo`P000002?ooool8000000Sooooo20000007ooooo`P000002?ooool8000000Sooooo2000
0008ooooo`P000001ooooolG0=7=Z@005P3AcJT7ooooo`P000002?ooool8000000Sooooo20000008
ooooo`L000002?ooool8000000Sooooo20000008ooooo`P000002?ooool7000000Sooooo20000008
ooooo`P000002?ooool8000000Oooooo20000008ooooo`P000002?ooool8000000Sooooo20000007
oooooaL0dLfY000F0=7=Z@oooooo20000008ooooo`P000002?ooool8000000Oooooo20000008oooo
o`P000002?ooool8000000Sooooo20000007ooooo`P000002?ooool8000000Sooooo20000008oooo
o`L000002?ooool8000000Sooooo20000008ooooo`P000003ooooolG0=7=Z@005P3AcJT?ooooo`P0
00002?ooool8000000Sooooo20000007ooooo`P000002?ooool8000000Sooooo20000008ooooo`P0
00001oooool8000000Sooooo20000008ooooo`P000002?ooool7000000Sooooo20000008ooooo`P0
00002?ooool8000000oooooo5`3AcJT001H0dLfY3oooool8000000Sooooo20000008ooooo`P00000
1oooool8000000Sooooo20000008ooooo`P000002?ooool8000000Oooooo20000008ooooo`P00000
2?ooool8000000Sooooo1`000008ooooo`P000002?ooool8000000Sooooo2000000?oooooaL0dLfY
000F0=7=Z@oooooo20000008ooooo`P000002?ooool8000000Oooooo20000008ooooo`P000002?oo
ool8000000Sooooo20000007ooooo`P000002?ooool8000000Sooooo20000008ooooo`L000002?oo
ool8000000Sooooo20000008ooooo`P000003ooooolG0=7=Z@005P3AcJT?ooooo`P000002?ooool8
000000Sooooo20000007ooooo`P000002?ooool8000000Sooooo20000008ooooo`P000001oooool8
000000Sooooo20000008ooooo`P000002?ooool7000000Sooooo20000008ooooo`P000002?ooool8
000000oooooo5`3AcJT001H0dLfY3oooool8000000Sooooo20000008ooooo`P000001oooool80000
00Sooooo20000008ooooo`P000002?ooool8000000Oooooo20000008ooooo`P000002?ooool80000
00Sooooo1`000008ooooo`P000002?ooool8000000Sooooo2000000?oooooaL0dLfY000F0=7=Z@oo
oooo20000008ooooo`P000002?ooool8000000Oooooo20000008ooooo`P000002?ooool8000000So
oooo20000007ooooo`P000002?ooool8000000Sooooo20000008ooooo`L000002?ooool8000000So
oooo20000008ooooo`P000003ooooolG0=7=Z@005P3AcJT?ooooo`P000002?ooool8000000Sooooo
20000007ooooo`P000002?ooool8000000Sooooo20000008ooooo`P000001oooool8000000Sooooo
20000008ooooo`P000002?ooool7000000Sooooo20000008ooooo`P000002?ooool8000000oooooo
5`3AcJT001H0dLfY5oooool8000000Sooooo20000008ooooo`L000002?ooool8000000Sooooo2000
0008ooooo`P000002?ooool7000000Sooooo20000008ooooo`P000002?ooool8000000Oooooo2000
0008ooooo`P000002?ooool8000001Oooooo5`3AcJT001H0dLfY5oooool8000000Sooooo20000008
ooooo`L000002?ooool8000000Sooooo20000008ooooo`P000002?ooool7000000Sooooo20000008
ooooo`P000002?ooool8000000Oooooo20000008ooooo`P000002?ooool8000001Oooooo5`3AcJT0
01H0dLfY5oooool8000000Sooooo20000008ooooo`L000002?ooool8000000Sooooo20000008oooo
o`P000002?ooool7000000Sooooo20000008ooooo`P000002?ooool8000000Oooooo20000008oooo
o`P000002?ooool8000001Oooooo5`3AcJT001H0dLfY5oooool8000000Sooooo20000008ooooo`L0
00002?ooool8000000Sooooo20000008ooooo`P000002?ooool7000000Sooooo20000008ooooo`P0
00002?ooool8000000Oooooo20000008ooooo`P000002?ooool8000001Oooooo5`3AcJT001H0dLfY
5oooool8000000Sooooo20000008ooooo`L000002?ooool8000000Sooooo20000008ooooo`P00000
2?ooool7000000Sooooo20000008ooooo`P000002?ooool8000000Oooooo20000008ooooo`P00000
2?ooool8000001Oooooo5`3AcJT001H0dLfY5oooool8000000Sooooo20000008ooooo`L000002?oo
ool8000000Sooooo20000008ooooo`P000002?ooool7000000Sooooo20000008ooooo`P000002?oo
ool8000000Oooooo20000008ooooo`P000002?ooool8000001Oooooo5`3AcJT001H0dLfY5oooool8
000000Sooooo20000008ooooo`L000002?ooool8000000Sooooo20000008ooooo`P000002?ooool7
000000Sooooo20000008ooooo`P000002?ooool8000000Oooooo20000008ooooo`P000002?ooool8
000001Oooooo5`3AcJT001H0dLfY5oooool8000000Sooooo20000008ooooo`L000002?ooool80000
00Sooooo20000008ooooo`P000002?ooool7000000Sooooo20000008ooooo`P000002?ooool80000
00Oooooo20000008ooooo`P000002?ooool8000001Oooooo5`3AcJT001H0dLfY7oooool8000000So
oooo20000007ooooo`P000002?ooool8000000Sooooo20000008ooooo`P000001oooool8000000So
oooo20000008ooooo`P000002?ooool7000000Sooooo20000008ooooo`P000007ooooolG0=7=Z@00
5P3AcJTOooooo`P000002?ooool8000000Oooooo20000008ooooo`P000002?ooool8000000Sooooo
20000007ooooo`P000002?ooool8000000Sooooo20000008ooooo`L000002?ooool8000000Sooooo
2000000OoooooaL0dLfY000F0=7=ZAoooooo20000008ooooo`P000001oooool8000000Sooooo2000
0008ooooo`P000002?ooool8000000Oooooo20000008ooooo`P000002?ooool8000000Sooooo1`00
0008ooooo`P000002?ooool8000001oooooo5`3AcJT001H0dLfY7oooool8000000Sooooo20000007
ooooo`P000002?ooool8000000Sooooo20000008ooooo`P000001oooool8000000Sooooo20000008
ooooo`P000002?ooool7000000Sooooo20000008ooooo`P000007ooooolG0=7=Z@005P3AcJTOoooo
o`P000002?ooool8000000Oooooo20000008ooooo`P000002?ooool8000000Sooooo20000007oooo
o`P000002?ooool8000000Sooooo20000008ooooo`L000002?ooool8000000Sooooo2000000Ooooo
oaL0dLfY000F0=7=ZAoooooo20000008ooooo`P000001oooool8000000Sooooo20000008ooooo`P0
00002?ooool8000000Oooooo20000008ooooo`P000002?ooool8000000Sooooo1`000008ooooo`P0
00002?ooool8000001oooooo5`3AcJT001H0dLfY7oooool8000000Sooooo20000007ooooo`P00000
2?ooool8000000Sooooo20000008ooooo`P000001oooool8000000Sooooo20000008ooooo`P00000
2?ooool7000000Sooooo20000008ooooo`P000007ooooolG0=7=Z@005P3AcJTOooooo`P000002?oo
ool8000000Oooooo20000008ooooo`P000002?ooool8000000Sooooo20000007ooooo`P000002?oo
ool8000000Sooooo20000008ooooo`L000002?ooool8000000Sooooo2000000OoooooaL0dLfY000F
0=7=ZBOooooo20000008ooooo`L000002?ooool8000000Sooooo20000008ooooo`P000002?ooool7
000000Sooooo20000008ooooo`P000002?ooool8000000Oooooo20000008ooooo`P000009ooooolG
0=7=Z@005P3AcJTWooooo`P000002?ooool7000000Sooooo20000008ooooo`P000002?ooool80000
00Sooooo1`000008ooooo`P000002?ooool8000000Sooooo20000007ooooo`P000002?ooool80000
02Oooooo5`3AcJT001H0dLfY9oooool8000000Sooooo1`000008ooooo`P000002?ooool8000000So
oooo20000008ooooo`L000002?ooool8000000Sooooo20000008ooooo`P000001oooool8000000So
oooo2000000WoooooaL0dLfY000F0=7=ZBOooooo20000008ooooo`L000002?ooool8000000Sooooo
20000008ooooo`P000002?ooool7000000Sooooo20000008ooooo`P000002?ooool8000000Oooooo
20000008ooooo`P000009ooooolG0=7=Z@005P3AcJTWooooo`P000002?ooool7000000Sooooo2000
0008ooooo`P000002?ooool8000000Sooooo1`000008ooooo`P000002?ooool8000000Sooooo2000
0007ooooo`P000002?ooool8000002Oooooo5`3AcJT001H0dLfY9oooool8000000Sooooo1`000008
ooooo`P000002?ooool8000000Sooooo20000008ooooo`L000002?ooool8000000Sooooo20000008
ooooo`P000001oooool8000000Sooooo2000000WoooooaL0dLfY000F0=7=ZBOooooo20000008oooo
o`L000002?ooool8000000Sooooo20000008ooooo`P000002?ooool7000000Sooooo20000008oooo
o`P000002?ooool8000000Oooooo20000008ooooo`P000009ooooolG0=7=Z@005P3AcJT_ooooo`P0
00001oooool8000000Sooooo20000008ooooo`P000002?ooool8000000Oooooo20000008ooooo`P0
00002?ooool8000000Sooooo1`000008ooooo`P00000;ooooolG0=7=Z@005P3AcJT_ooooo`P00000
1oooool8000000Sooooo20000008ooooo`P000002?ooool8000000Oooooo20000008ooooo`P00000
2?ooool8000000Sooooo1`000008ooooo`P00000;ooooolG0=7=Z@005P3AcJT_ooooo`P000001ooo
ool8000000Sooooo20000008ooooo`P000002?ooool8000000Oooooo20000008ooooo`P000002?oo
ool8000000Sooooo1`000008ooooo`P00000;ooooolG0=7=Z@005P3AcJT_ooooo`P000001oooool8
000000Sooooo20000008ooooo`P000002?ooool8000000Oooooo20000008ooooo`P000002?ooool8
000000Sooooo1`000008ooooo`P00000;ooooolG0=7=Z@005P3AcJT_ooooo`P000001oooool80000
00Sooooo20000008ooooo`P000002?ooool8000000Oooooo20000008ooooo`P000002?ooool80000
00Sooooo1`000008ooooo`P00000;ooooolG0=7=Z@005P3AcJT_ooooo`P000001oooool8000000So
oooo20000008ooooo`P000002?ooool8000000Oooooo20000008ooooo`P000002?ooool8000000So
oooo1`000008ooooo`P00000;ooooolG0=7=Z@005P3AcJT_ooooo`P000001oooool8000000Sooooo
20000008ooooo`P000002?ooool8000000Oooooo20000008ooooo`P000002?ooool8000000Sooooo
1`000008ooooo`P00000;ooooolG0=7=Z@005P3AcJT_ooooo`P000001oooool8000000Sooooo2000
0008ooooo`P000002?ooool8000000Oooooo20000008ooooo`P000002?ooool8000000Sooooo1`00
0008ooooo`P00000;ooooolG0=7=Z@005P3AcJTgooooo`L000002?ooool8000000Sooooo20000008
ooooo`P000002?ooool7000000Sooooo20000008ooooo`P000002?ooool8000000Oooooo2000000g
oooooaL0dLfY000F0=7=ZCOooooo1`000008ooooo`P000002?ooool8000000Sooooo20000008oooo
o`L000002?ooool8000000Sooooo20000008ooooo`P000001oooool8000003Oooooo5`3AcJT001H0
dLfY=oooool7000000Sooooo20000008ooooo`P000002?ooool8000000Sooooo1`000008ooooo`P0
00002?ooool8000000Sooooo20000007ooooo`P00000=ooooolG0=7=Z@005P3AcJTgooooo`L00000
2?ooool8000000Sooooo20000008ooooo`P000002?ooool7000000Sooooo20000008ooooo`P00000
2?ooool8000000Oooooo2000000goooooaL0dLfY000F0=7=ZCOooooo1`000008ooooo`P000002?oo
ool8000000Sooooo20000008ooooo`L000002?ooool8000000Sooooo20000008ooooo`P000001ooo
ool8000003Oooooo5`3AcJT001H0dLfY=oooool7000000Sooooo20000008ooooo`P000002?ooool8
000000Sooooo1`000008ooooo`P000002?ooool8000000Sooooo20000007ooooo`P00000=ooooolG
0=7=Z@005P3AcJTgooooo`L000002?ooool8000000Sooooo20000008ooooo`P000002?ooool70000
00Sooooo20000008ooooo`P000002?ooool8000000Oooooo2000000goooooaL0dLfY000F0=7=ZCOo
oooo1`000008ooooo`P000002?ooool8000000Sooooo20000008ooooo`L000002?ooool8000000So
oooo20000008ooooo`P000001oooool8000003Oooooo5`3AcJT001H0dLfY?_ooool8000000Sooooo
20000008ooooo`P000002?ooool8000000Oooooo20000008ooooo`P000002?ooool8000000Sooooo
1`00000ooooooaL0dLfY000F0=7=ZCkooooo20000008ooooo`P000002?ooool8000000Sooooo2000
0007ooooo`P000002?ooool8000000Sooooo20000008ooooo`L00000?ooooolG0=7=Z@005P3AcJTn
ooooo`P000002?ooool8000000Sooooo20000008ooooo`P000001oooool8000000Sooooo20000008
ooooo`P000002?ooool7000003oooooo5`3AcJT001H0dLfY?_ooool8000000Sooooo20000008oooo
o`P000002?ooool8000000Oooooo20000008ooooo`P000002?ooool8000000Sooooo1`00000ooooo
oaL0dLfY000F0=7=ZCkooooo20000008ooooo`P000002?ooool8000000Sooooo20000007ooooo`P0
00002?ooool8000000Sooooo20000008ooooo`L00000?ooooolG0=7=Z@005P3AcJTnooooo`P00000
2?ooool8000000Sooooo20000008ooooo`P000001oooool8000000Sooooo20000008ooooo`P00000
2?ooool7000003oooooo5`3AcJT001H0dLfY?_ooool8000000Sooooo20000008ooooo`P000002?oo
ool8000000Oooooo20000008ooooo`P000002?ooool8000000Sooooo1`00000ooooooaL0dLfY000F
0=7=ZCkooooo20000008ooooo`P000002?ooool8000000Sooooo20000007ooooo`P000002?ooool8
000000Sooooo20000008ooooo`L00000?ooooolG0=7=Z@005P3AcJU6ooooo`P000002?ooool80000
00Sooooo20000008ooooo`L000002?ooool8000000Sooooo20000008ooooo`P00000A_oooolG0=7=
Z@005P3AcJU6ooooo`P000002?ooool8000000Sooooo20000008ooooo`L000002?ooool8000000So
oooo20000008ooooo`P00000A_oooolG0=7=Z@005P3AcJU6ooooo`P000002?ooool8000000Sooooo
20000008ooooo`L000002?ooool8000000Sooooo20000008ooooo`P00000A_oooolG0=7=Z@005P3A
cJU6ooooo`P000002?ooool8000000Sooooo20000008ooooo`L000002?ooool8000000Sooooo2000
0008ooooo`P00000A_oooolG0=7=Z@005P3AcJU6ooooo`P000002?ooool8000000Sooooo20000008
ooooo`L000002?ooool8000000Sooooo20000008ooooo`P00000A_oooolG0=7=Z@005P3AcJU6oooo
o`P000002?ooool8000000Sooooo20000008ooooo`L000002?ooool8000000Sooooo20000008oooo
o`P00000A_oooolG0=7=Z@005P3AcJU6ooooo`P000002?ooool8000000Sooooo20000008ooooo`L0
00002?ooool8000000Sooooo20000008ooooo`P00000A_oooolG0=7=Z@005P3AcJU>ooooo`P00000
2?ooool8000000Sooooo20000007ooooo`P000002?ooool8000000Sooooo2000001>oooooaL0dLfY
000F0=7=ZDkooooo20000008ooooo`P000002?ooool8000000Oooooo20000008ooooo`P000002?oo
ool8000004kooooo5`3AcJT001H0dLfYC_ooool8000000Sooooo20000008ooooo`P000001oooool8
000000Sooooo20000008ooooo`P00000C_oooolG0=7=Z@005P3AcJU>ooooo`P000002?ooool80000
00Sooooo20000007ooooo`P000002?ooool8000000Sooooo2000001>oooooaL0dLfY000F0=7=ZDko
oooo20000008ooooo`P000002?ooool8000000Oooooo20000008ooooo`P000002?ooool8000004ko
oooo5`3AcJT001H0dLfYC_ooool8000000Sooooo20000008ooooo`P000001oooool8000000Sooooo
20000008ooooo`P00000C_oooolG0=7=Z@005P3AcJU>ooooo`P000002?ooool8000000Sooooo2000
0007ooooo`P000002?ooool8000000Sooooo2000001>oooooaL0dLfY000F0=7=ZDkooooo20000008
ooooo`P000002?ooool8000000Oooooo20000008ooooo`P000002?ooool8000004kooooo5`3AcJT0
01H0dLfYE_ooool8000000Sooooo20000008ooooo`L000002?ooool8000000Sooooo2000001Foooo
oaL0dLfY000F0=7=ZEKooooo20000008ooooo`P000002?ooool7000000Sooooo20000008ooooo`P0
0000E_oooolG0=7=Z@005P3AcJUFooooo`P000002?ooool8000000Sooooo1`000008ooooo`P00000
2?ooool8000005Kooooo5`3AcJT001H0dLfYE_ooool8000000Sooooo20000008ooooo`L000002?oo
ool8000000Sooooo2000001FoooooaL0dLfY000F0=7=ZEKooooo20000008ooooo`P000002?ooool7
000000Sooooo20000008ooooo`P00000E_oooolG0=7=Z@005P3AcJUFooooo`P000002?ooool80000
00Sooooo1`000008ooooo`P000002?ooool8000005Kooooo5`3AcJT001H0dLfYE_ooool8000000So
oooo20000008ooooo`L000002?ooool8000000Sooooo2000001FoooooaL0dLfY000F0=7=ZEKooooo
20000008ooooo`P000002?ooool7000000Sooooo20000008ooooo`P00000E_oooolG0=7=Z@005P3A
cJUNooooo`P000002?ooool8000000Oooooo20000008ooooo`P00000G_oooolG0=7=Z@005P3AcJUN
ooooo`P000002?ooool8000000Oooooo20000008ooooo`P00000G_oooolG0=7=Z@005P3AcJUNoooo
o`P000002?ooool8000000Oooooo20000008ooooo`P00000G_oooolG0=7=Z@005P3AcJUNooooo`P0
00002?ooool8000000Oooooo20000008ooooo`P00000G_oooolG0=7=Z@005P3AcJUNooooo`P00000
2?ooool8000000Oooooo20000008ooooo`P00000G_oooolG0=7=Z@005P3AcJUNooooo`P000002?oo
ool8000000Oooooo20000008ooooo`P00000G_oooolG0=7=Z@005P3AcJUNooooo`P000002?ooool8
000000Oooooo20000008ooooo`P00000G_oooolG0=7=Z@005P3AcJUNooooo`P000002?ooool80000
00Oooooo20000008ooooo`P00000G_oooolG0=7=Z@005P3AcJUVooooo`P000002?ooool7000000So
oooo2000001VoooooaL0dLfY000F0=7=ZFKooooo20000008ooooo`L000002?ooool8000006Kooooo
5`3AcJT001H0dLfYI_ooool8000000Sooooo1`000008ooooo`P00000I_oooolG0=7=Z@005P3AcJUV
ooooo`P000002?ooool7000000Sooooo2000001VoooooaL0dLfY000F0=7=ZFKooooo20000008oooo
o`L000002?ooool8000006Kooooo5`3AcJT001H0dLfYI_ooool8000000Sooooo1`000008ooooo`P0
0000I_oooolG0=7=Z@005P3AcJUVooooo`P000002?ooool7000000Sooooo2000001VoooooaL0dLfY
000F0=7=ZFKooooo20000008ooooo`L000002?ooool8000006Kooooo5`3AcJT001H0dLfYK_ooool8
000000Oooooo2000001^oooooaL0dLfY000F0=7=ZFkooooo20000007ooooo`P00000K_oooolG0=7=
Z@005P3AcJU^ooooo`P000001oooool8000006kooooo5`3AcJT001H0dLfYK_ooool8000000Oooooo
2000001^oooooaL0dLfY000F0=7=ZFkooooo20000007ooooo`P00000K_oooolG0=7=Z@005P3AcJU^
ooooo`P000001oooool8000006kooooo5`3AcJT001H0dLfYK_ooool8000000Oooooo2000001^oooo
oaL0dLfY000F0=7=ZGKooooo1`00001foooooaL0dLfY000F0=7=ZGKooooo1`00001foooooaL0dLfY
000F0=7=ZGKooooo1`00001foooooaL0dLfY000F0=7=ZGKooooo1`00001foooooaL0dLfY000F0=7=
ZGKooooo1`00001foooooaL0dLfY000F0=7=ZGKooooo1`00001foooooaL0dLfY000F0=7=ZGKooooo
1`00001foooooaL0dLfY000F0=7=ZGKooooo1`00001foooooaL0dLfY003o0=7=ZB40dLfY003o0=7=
ZB40dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o0=7=
ZB40dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY001i0=7=Z@9000000`3AcJT5
@0000080dLfY0T0000030=7=Z@E0000000<0dLfY@000040000000d0000000`3AcJU00000@0000003
@00000030=7=ZD000010000000=0000000<0dLfY@000040000000d00001i0=7=Z@00N03AcJT01400
0000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=
Z@020=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=
Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0N@3AcJT007P0dLfY00A00000
0=7=Z@3AcJU00000103AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0
0P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0
0`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY07T0dLfY001h0=7=Z@04@000003A
cJT0dLfY@00000@0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080
dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0
dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@1i0=7=Z@00N03AcJT014000000dLfY
0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=
Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=
Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0N@3AcJT007T0dLfY0T0000040=7=Z@90
0000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@90
0000N`3AcJT00?l0dLfY8@3AcJT00?l0dLfY8@3AcJT00?l0dLfY8@3AcJT00001\
\>"],
  ImageRangeCache->{{{0, 287}, {138.313, 0}} -> {-2.80751, -0.30008, \
0.127578, 0.127578}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(rule2 = {0, 1, 0, 1, 1, 0, 1, 0};\)\), "\[IndentingNewLine]", 
    \(\(n = 61;\)\), "\[IndentingNewLine]", 
    \(\(Show[
        showCA[2, cellularSpace[n], rule2, \[LeftFloor]n/2\[RightFloor], 1, 
          1, n], DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4918 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0157629 0.00945776 0.0157629 [
[.5 .5043 -26 0 ]
[.5 .5043 26 12.875 ]
[ 0 0 0 0 ]
[ 1 .4918 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5043 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(01011010) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .4918 L
0 .4918 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00946 translate
.96154 .47289 scale
61 string
61 30 8 [61 0 0 30 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00
FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FF
FFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF
FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF
FFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00
FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFF
FFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF
00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 141.625},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000SB000`400?l00000o`00003oo`3AcJTQ
0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@005@3AcJT4ooooo`@000001?ooool4000001Cooooo
10000004ooooo`@000005?ooool4000000Cooooo1000000Dooooo`@000001?ooool4000001Cooooo
1@000004ooooo`@000005?ooool4000000Cooooo1000000Dooooo`@000001?ooool4000001Cooooo
10000004ooooo`@000001?oooolF0=7=Z@005@3AcJT4ooooo`@000001?ooool4000001Cooooo1000
0004ooooo`@000005?ooool4000000Cooooo1000000Dooooo`@000001?ooool4000001Cooooo1@00
0004ooooo`@000005?ooool4000000Cooooo1000000Dooooo`@000001?ooool4000001Cooooo1000
0004ooooo`@000001?oooolF0=7=Z@005@3AcJT4ooooo`@000001?ooool4000001Cooooo10000004
ooooo`@000005?ooool4000000Cooooo1000000Dooooo`@000001?ooool4000001Cooooo1@000004
ooooo`@000005?ooool4000000Cooooo1000000Dooooo`@000001?ooool4000001Cooooo10000004
ooooo`@000001?oooolF0=7=Z@005@3AcJT4ooooo`@000001?ooool4000001Cooooo10000004oooo
o`@000005?ooool4000000Cooooo1000000Dooooo`@000001?ooool4000001Cooooo1@000004oooo
o`@000005?ooool4000000Cooooo1000000Dooooo`@000001?ooool4000001Cooooo10000004oooo
o`@000001?oooolF0=7=Z@005@3AcJT8ooooo`@000007?ooool4000001cooooo1000000Looooo`@0
00007Oooool4000001cooooo1000000Looooo`@000007?ooool4000000Sooooo5P3AcJT001D0dLfY
2?ooool4000001cooooo1000000Looooo`@000007?ooool4000001gooooo1000000Looooo`@00000
7?ooool4000001cooooo10000008oooooaH0dLfY000E0=7=Z@Sooooo1000000Looooo`@000007?oo
ool4000001cooooo1000000Mooooo`@000007?ooool4000001cooooo1000000Looooo`@000002?oo
oolF0=7=Z@005@3AcJT8ooooo`@000007?ooool4000001cooooo1000000Looooo`@000007Oooool4
000001cooooo1000000Looooo`@000007?ooool4000000Sooooo5P3AcJT001D0dLfY3?ooool40000
00Cooooo10000004ooooo`@000001?ooool4000002Cooooo10000004ooooo`@000001?ooool40000
00Cooooo1000000Uooooo`@000001?ooool4000000Cooooo10000004ooooo`@000009?ooool40000
00Cooooo10000004ooooo`@000001?ooool4000000cooooo5P3AcJT001D0dLfY3?ooool4000000Co
oooo10000004ooooo`@000001?ooool4000002Cooooo10000004ooooo`@000001?ooool4000000Co
oooo1000000Uooooo`@000001?ooool4000000Cooooo10000004ooooo`@000009?ooool4000000Co
oooo10000004ooooo`@000001?ooool4000000cooooo5P3AcJT001D0dLfY3?ooool4000000Cooooo
10000004ooooo`@000001?ooool4000002Cooooo10000004ooooo`@000001?ooool4000000Cooooo
1000000Uooooo`@000001?ooool4000000Cooooo10000004ooooo`@000009?ooool4000000Cooooo
10000004ooooo`@000001?ooool4000000cooooo5P3AcJT001D0dLfY3?ooool4000000Cooooo1000
0004ooooo`@000001?ooool4000002Cooooo10000004ooooo`@000001?ooool4000000Cooooo1000
000Uooooo`@000001?ooool4000000Cooooo10000004ooooo`@000009?ooool4000000Cooooo1000
0004ooooo`@000001?ooool4000000cooooo5P3AcJT001D0dLfY4?ooool4000000cooooo1000000/
ooooo`@000003?ooool4000002gooooo1000000<ooooo`@00000;?ooool4000000cooooo1000000@
oooooaH0dLfY000E0=7=ZA3ooooo1000000<ooooo`@00000;?ooool4000000cooooo1000000]oooo
o`@000003?ooool4000002cooooo1000000<ooooo`@000004?oooolF0=7=Z@005@3AcJT@ooooo`@0
00003?ooool4000002cooooo1000000<ooooo`@00000;Oooool4000000cooooo1000000/ooooo`@0
00003?ooool40000013ooooo5P3AcJT001D0dLfY4?ooool4000000cooooo1000000/ooooo`@00000
3?ooool4000002gooooo1000000<ooooo`@00000;?ooool4000000cooooo1000000@oooooaH0dLfY
000E0=7=ZACooooo10000004ooooo`@00000=?ooool4000000Cooooo1000000eooooo`@000001?oo
ool4000003Cooooo10000004ooooo`@000005?oooolF0=7=Z@005@3AcJTDooooo`@000001?ooool4
000003Cooooo10000004ooooo`@00000=Oooool4000000Cooooo1000000dooooo`@000001?ooool4
000001Cooooo5P3AcJT001D0dLfY5?ooool4000000Cooooo1000000dooooo`@000001?ooool40000
03Gooooo10000004ooooo`@00000=?ooool4000000Cooooo1000000DoooooaH0dLfY000E0=7=ZACo
oooo10000004ooooo`@00000=?ooool4000000Cooooo1000000eooooo`@000001?ooool4000003Co
oooo10000004ooooo`@000005?oooolF0=7=Z@005@3AcJTHooooo`@00000??ooool4000003gooooo
1000000looooo`@000006?oooolF0=7=Z@005@3AcJTHooooo`@00000??ooool4000003gooooo1000
000looooo`@000006?oooolF0=7=Z@005@3AcJTHooooo`@00000??ooool4000003gooooo1000000l
ooooo`@000006?oooolF0=7=Z@005@3AcJTHooooo`@00000??ooool4000003gooooo1000000loooo
o`@000006?oooolF0=7=Z@005@3AcJTLooooo`@000001?ooool4000000Cooooo10000004ooooo`@0
00001?ooool4000000Cooooo10000004ooooo`@000001?ooool4000004Gooooo10000004ooooo`@0
00001?ooool4000000Cooooo10000004ooooo`@000001?ooool4000000Cooooo10000004ooooo`@0
00007?oooolF0=7=Z@005@3AcJTLooooo`@000001?ooool4000000Cooooo10000004ooooo`@00000
1?ooool4000000Cooooo10000004ooooo`@000001?ooool4000004Gooooo10000004ooooo`@00000
1?ooool4000000Cooooo10000004ooooo`@000001?ooool4000000Cooooo10000004ooooo`@00000
7?oooolF0=7=Z@005@3AcJTLooooo`@000001?ooool4000000Cooooo10000004ooooo`@000001?oo
ool4000000Cooooo10000004ooooo`@000001?ooool4000004Gooooo10000004ooooo`@000001?oo
ool4000000Cooooo10000004ooooo`@000001?ooool4000000Cooooo10000004ooooo`@000007?oo
oolF0=7=Z@005@3AcJTLooooo`@000001?ooool4000000Cooooo10000004ooooo`@000001?ooool4
000000Cooooo10000004ooooo`@000001?ooool4000004Gooooo10000004ooooo`@000001?ooool4
000000Cooooo10000004ooooo`@000001?ooool4000000Cooooo10000004ooooo`@000007?oooolF
0=7=Z@005@3AcJTPooooo`@000003?ooool4000000cooooo1000000<ooooo`@00000COooool40000
00cooooo1000000<ooooo`@000003?ooool40000023ooooo5P3AcJT001D0dLfY8?ooool4000000co
oooo1000000<ooooo`@000003?ooool4000004gooooo1000000<ooooo`@000003?ooool4000000co
oooo1000000PoooooaH0dLfY000E0=7=ZB3ooooo1000000<ooooo`@000003?ooool4000000cooooo
1000001=ooooo`@000003?ooool4000000cooooo1000000<ooooo`@000008?oooolF0=7=Z@005@3A
cJTPooooo`@000003?ooool4000000cooooo1000000<ooooo`@00000COooool4000000cooooo1000
000<ooooo`@000003?ooool40000023ooooo5P3AcJT001D0dLfY9?ooool4000000Cooooo1000000D
ooooo`@000001?ooool4000005Gooooo10000004ooooo`@000005?ooool4000000Cooooo1000000T
oooooaH0dLfY000E0=7=ZBCooooo10000004ooooo`@000005?ooool4000000Cooooo1000001Eoooo
o`@000001?ooool4000001Cooooo10000004ooooo`@000009?oooolF0=7=Z@005@3AcJTTooooo`@0
00001?ooool4000001Cooooo10000004ooooo`@00000EOooool4000000Cooooo1000000Dooooo`@0
00001?ooool4000002Cooooo5P3AcJT001D0dLfY9?ooool4000000Cooooo1000000Dooooo`@00000
1?ooool4000005Gooooo10000004ooooo`@000005?ooool4000000Cooooo1000000ToooooaH0dLfY
000E0=7=ZBSooooo1000000Looooo`@00000GOooool4000001cooooo1000000XoooooaH0dLfY000E
0=7=ZBSooooo1000000Looooo`@00000GOooool4000001cooooo1000000XoooooaH0dLfY000E0=7=
ZBSooooo1000000Looooo`@00000GOooool4000001cooooo1000000XoooooaH0dLfY000E0=7=ZBSo
oooo1000000Looooo`@00000GOooool4000001cooooo1000000XoooooaH0dLfY000E0=7=ZBcooooo
10000004ooooo`@000001?ooool4000000Cooooo1000001Uooooo`@000001?ooool4000000Cooooo
10000004ooooo`@00000;?oooolF0=7=Z@005@3AcJT/ooooo`@000001?ooool4000000Cooooo1000
0004ooooo`@00000IOooool4000000Cooooo10000004ooooo`@000001?ooool4000002cooooo5P3A
cJT001D0dLfY;?ooool4000000Cooooo10000004ooooo`@000001?ooool4000006Gooooo10000004
ooooo`@000001?ooool4000000Cooooo1000000/oooooaH0dLfY000E0=7=ZBcooooo10000004oooo
o`@000001?ooool4000000Cooooo1000001Uooooo`@000001?ooool4000000Cooooo10000004oooo
o`@00000;?oooolF0=7=Z@005@3AcJT`ooooo`@000003?ooool4000006gooooo1000000<ooooo`@0
0000<?oooolF0=7=Z@005@3AcJT`ooooo`@000003?ooool4000006gooooo1000000<ooooo`@00000
<?oooolF0=7=Z@005@3AcJT`ooooo`@000003?ooool4000006gooooo1000000<ooooo`@00000<?oo
oolF0=7=Z@005@3AcJT`ooooo`@000003?ooool4000006gooooo1000000<ooooo`@00000<?oooolF
0=7=Z@005@3AcJTdooooo`@000001?ooool4000007Gooooo10000004ooooo`@00000=?oooolF0=7=
Z@005@3AcJTdooooo`@000001?ooool4000007Gooooo10000004ooooo`@00000=?oooolF0=7=Z@00
5@3AcJTdooooo`@000001?ooool4000007Gooooo10000004ooooo`@00000=?oooolF0=7=Z@005@3A
cJTdooooo`@000001?ooool4000007Gooooo10000004ooooo`@00000=?oooolF0=7=Z@005@3AcJTh
ooooo`@00000OOooool4000003Sooooo5P3AcJT001D0dLfY>?ooool4000007gooooo1000000hoooo
oaH0dLfY000E0=7=ZCSooooo1000001mooooo`@00000>?oooolF0=7=Z@005@3AcJThooooo`@00000
OOooool4000003Sooooo5P3AcJT001D0dLfY??ooool4000000Cooooo10000004ooooo`@000001?oo
ool4000000Cooooo10000004ooooo`@000001?ooool4000000Cooooo10000004ooooo`@000001?oo
ool5000000Cooooo10000004ooooo`@000001?ooool4000000Cooooo10000004ooooo`@000001?oo
ool4000003cooooo5P3AcJT001D0dLfY??ooool4000000Cooooo10000004ooooo`@000001?ooool4
000000Cooooo10000004ooooo`@000001?ooool4000000Cooooo10000004ooooo`@000001?ooool5
000000Cooooo10000004ooooo`@000001?ooool4000000Cooooo10000004ooooo`@000001?ooool4
000003cooooo5P3AcJT001D0dLfY??ooool4000000Cooooo10000004ooooo`@000001?ooool40000
00Cooooo10000004ooooo`@000001?ooool4000000Cooooo10000004ooooo`@000001?ooool50000
00Cooooo10000004ooooo`@000001?ooool4000000Cooooo10000004ooooo`@000001?ooool40000
03cooooo5P3AcJT001D0dLfY??ooool4000000Cooooo10000004ooooo`@000001?ooool4000000Co
oooo10000004ooooo`@000001?ooool4000000Cooooo10000004ooooo`@000001?ooool5000000Co
oooo10000004ooooo`@000001?ooool4000000Cooooo10000004ooooo`@000001?ooool4000003co
oooo5P3AcJT001D0dLfY@?ooool4000000cooooo1000000<ooooo`@000003?ooool4000000cooooo
1000000=ooooo`@000003?ooool4000000cooooo10000010oooooaH0dLfY000E0=7=ZD3ooooo1000
000<ooooo`@000003?ooool4000000cooooo1000000<ooooo`@000003Oooool4000000cooooo1000
000<ooooo`@00000@?oooolF0=7=Z@005@3AcJU0ooooo`@000003?ooool4000000cooooo1000000<
ooooo`@000003?ooool4000000gooooo1000000<ooooo`@000003?ooool40000043ooooo5P3AcJT0
01D0dLfY@?ooool4000000cooooo1000000<ooooo`@000003?ooool4000000cooooo1000000=oooo
o`@000003?ooool4000000cooooo10000010oooooaH0dLfY000E0=7=ZDCooooo10000004ooooo`@0
00005?ooool4000000Cooooo1000000Dooooo`D000001?ooool4000001Cooooo10000004ooooo`@0
0000A?oooolF0=7=Z@005@3AcJU4ooooo`@000001?ooool4000001Cooooo10000004ooooo`@00000
5?ooool5000000Cooooo1000000Dooooo`@000001?ooool4000004Cooooo5P3AcJT001D0dLfYA?oo
ool4000000Cooooo1000000Dooooo`@000001?ooool4000001Cooooo1@000004ooooo`@000005?oo
ool4000000Cooooo10000014oooooaH0dLfY000E0=7=ZDCooooo10000004ooooo`@000005?ooool4
000000Cooooo1000000Dooooo`D000001?ooool4000001Cooooo10000004ooooo`@00000A?oooolF
0=7=Z@005@3AcJU8ooooo`@000007?ooool4000001gooooo1000000Looooo`@00000B?oooolF0=7=
Z@005@3AcJU8ooooo`@000007?ooool4000001gooooo1000000Looooo`@00000B?oooolF0=7=Z@00
5@3AcJU8ooooo`@000007?ooool4000001gooooo1000000Looooo`@00000B?oooolF0=7=Z@005@3A
cJU8ooooo`@000007?ooool4000001gooooo1000000Looooo`@00000B?oooolF0=7=Z@005@3AcJU<
ooooo`@000001?ooool4000000Cooooo10000004ooooo`@000009Oooool4000000Cooooo10000004
ooooo`@000001?ooool4000004cooooo5P3AcJT001D0dLfYC?ooool4000000Cooooo10000004oooo
o`@000001?ooool4000002Gooooo10000004ooooo`@000001?ooool4000000Cooooo1000001<oooo
oaH0dLfY000E0=7=ZDcooooo10000004ooooo`@000001?ooool4000000Cooooo1000000Uooooo`@0
00001?ooool4000000Cooooo10000004ooooo`@00000C?oooolF0=7=Z@005@3AcJU<ooooo`@00000
1?ooool4000000Cooooo10000004ooooo`@000009Oooool4000000Cooooo10000004ooooo`@00000
1?ooool4000004cooooo5P3AcJT001D0dLfYD?ooool4000000cooooo1000000]ooooo`@000003?oo
ool40000053ooooo5P3AcJT001D0dLfYD?ooool4000000cooooo1000000]ooooo`@000003?ooool4
0000053ooooo5P3AcJT001D0dLfYD?ooool4000000cooooo1000000]ooooo`@000003?ooool40000
053ooooo5P3AcJT001D0dLfYE?ooool4000000Cooooo1000000eooooo`@000001?ooool4000005Co
oooo5P3AcJT001D0dLfYE?ooool4000000Cooooo1000000eooooo`@000001?ooool4000005Cooooo
5P3AcJT001D0dLfYE?ooool4000000Cooooo1000000eooooo`@000001?ooool4000005Cooooo5P3A
cJT001D0dLfYE?ooool4000000Cooooo1000000eooooo`@000001?ooool4000005Cooooo5P3AcJT0
01D0dLfYF?ooool4000003gooooo1000001HoooooaH0dLfY000E0=7=ZESooooo1000000mooooo`@0
0000F?oooolF0=7=Z@005@3AcJUHooooo`@00000?Oooool4000005Sooooo5P3AcJT001D0dLfYF?oo
ool4000003gooooo1000001HoooooaH0dLfY000E0=7=ZEcooooo10000004ooooo`@000001?ooool4
000000Cooooo10000004ooooo`@000001?ooool5000000Cooooo10000004ooooo`@00000G?oooolF
0=7=Z@005@3AcJULooooo`@000001?ooool4000000Cooooo10000004ooooo`@000001?ooool40000
00Cooooo1@000004ooooo`@000001?ooool4000005cooooo5P3AcJT001D0dLfYG?ooool4000000Co
oooo10000004ooooo`@000001?ooool4000000Cooooo10000004ooooo`D000001?ooool4000000Co
oooo1000001LoooooaH0dLfY000E0=7=ZEcooooo10000004ooooo`@000001?ooool4000000Cooooo
10000004ooooo`@000001?ooool5000000Cooooo10000004ooooo`@00000G?oooolF0=7=Z@005@3A
cJUPooooo`@000003?ooool4000000cooooo1000000=ooooo`@00000H?oooolF0=7=Z@005@3AcJUP
ooooo`@000003?ooool4000000cooooo1000000=ooooo`@00000H?oooolF0=7=Z@005@3AcJUPoooo
o`@000003?ooool4000000cooooo1000000=ooooo`@00000H?oooolF0=7=Z@005@3AcJUPooooo`@0
00003?ooool4000000cooooo1000000=ooooo`@00000H?oooolF0=7=Z@005@3AcJUTooooo`@00000
1?ooool4000001Cooooo1@000004ooooo`@00000I?oooolF0=7=Z@005@3AcJUTooooo`@000001?oo
ool4000001Cooooo1@000004ooooo`@00000I?oooolF0=7=Z@005@3AcJUTooooo`@000001?ooool4
000001Cooooo1@000004ooooo`@00000I?oooolF0=7=Z@005@3AcJUTooooo`@000001?ooool40000
01Cooooo1@000004ooooo`@00000I?oooolF0=7=Z@005@3AcJUXooooo`@000007Oooool4000006So
oooo5P3AcJT001D0dLfYJ?ooool4000001gooooo1000001XoooooaH0dLfY000E0=7=ZFSooooo1000
000Mooooo`@00000J?oooolF0=7=Z@005@3AcJUXooooo`@000007Oooool4000006Sooooo5P3AcJT0
01D0dLfYK?ooool4000000Cooooo10000004ooooo`@000001?ooool5000006cooooo5P3AcJT001D0
dLfYK?ooool4000000Cooooo10000004ooooo`@000001?ooool5000006cooooo5P3AcJT001D0dLfY
K?ooool4000000Cooooo10000004ooooo`@000001?ooool5000006cooooo5P3AcJT001D0dLfYK?oo
ool4000000Cooooo10000004ooooo`@000001?ooool5000006cooooo5P3AcJT001D0dLfYL?ooool4
000000cooooo1000001aoooooaH0dLfY000E0=7=ZG3ooooo1000000<ooooo`@00000LOoooolF0=7=
Z@005@3AcJU`ooooo`@000003?ooool40000077ooooo5P3AcJT001D0dLfYL?ooool4000000cooooo
1000001aoooooaH0dLfY000E0=7=ZGCooooo10000004ooooo`@00000MOoooolF0=7=Z@005@3AcJUd
ooooo`@000001?ooool4000007Gooooo5P3AcJT001D0dLfYM?ooool4000000Cooooo1000001eoooo
oaH0dLfY000E0=7=ZGCooooo10000004ooooo`@00000MOoooolF0=7=Z@005@3AcJUhooooo`@00000
NOoooolF0=7=Z@005@3AcJUhooooo`@00000NOoooolF0=7=Z@005@3AcJUhooooo`@00000NOoooolF
0=7=Z@005@3AcJUhooooo`@00000NOoooolF0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3A
cJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3A
cJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00N@3AcJT2@00000<0dLfY1D0000020=7=Z@90
00000`3AcJT5@00000030=7=ZD000010000000=000000P3AcJT2@00000<0dLfY1D0000020=7=Z@90
0000N`3AcJT007P0dLfY00A000000=7=Z@3AcJU00000103AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY
0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3A
cJT00d000000dLfY0=7=Z@1h0=7=Z@00N03AcJT014000000dLfY0=7=ZD0000040=7=Z@05@000003A
cJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00<0dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY07P0dLfY001h0=7=Z@04@000003AcJT0dLfY@000
00@0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00=00000
0=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3A
cJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0N03AcJT007P0dLfY00A0
00000=7=Z@3AcJU00000103AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3A
cJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d00
0000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@1h
0=7=Z@00N@3AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=
Z@900000103AcJT2@00000@0dLfY0T00001k0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3A
cJTQ0=7=Z@00\
\>"],
  ImageRangeCache->{{{0, 287}, {140.625, 0}} -> {-5.43748, -0.600161, \
0.250436, 0.250436}}]
}, Open  ]],

Cell["\<\
The following one is, in Wolfram\.b4s classification, rule number 105. Note \
we have to extend the cellular space so that the spurious behavior at the \
ends does not reach the one produced by the  initial seed.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(rule3 = 
        Reverse[IntegerDigits[105, 2, 8]];\)\), "\[IndentingNewLine]", 
    \(\(n = 201;\)\), "\[IndentingNewLine]", 
    \(\(Show[
        showCA[2, cellularSpace[n], rule3, \[LeftFloor]n/4\[RightFloor], 
          1, \[LeftFloor]n/4\[RightFloor], n - \[LeftFloor]n/4\[RightFloor]], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4902 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00942685 0.00942685 0.00942685 [
[.5 .5027 -26 0 ]
[.5 .5027 26 12.875 ]
[ 0 0 0 0 ]
[ 1 .4902 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5027 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10010110) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .4902 L
0 .4902 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00943 translate
.96154 .47134 scale
102 string
102 50 8 [102 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 141.125},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000SB000`400?l00000o`00003oo`3AcJTQ
0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@005@3AcJT5000000L0oooo7`00
00070?ooodH000001`3ooom5000000L0oooo7`0000080?ooo`8000005`3AcJT001D0dLfY1@000007
0?oooal000001`3ooom6000000L0ooooA@0000070?oooal00000203oool2000001L0dLfY000E0=7=
Z@L0oooo0`00000S0?ooo`<00000BP3oool2000004/0oooo0P00000T0?ooo`8000001@3ooolG0=7=
Z@005@3AcJT70?ooo`<000008`3oool3000004X0oooo0P00001;0?ooo`800000903oool2000000D0
oooo5`3AcJT001D0dLfY1`3oool3000002<0oooo0`00001:0?ooo`800000B`3oool2000002@0oooo
0P0000050?oooaL0dLfY000E0=7=Z@X00000103oool3000000D0oooo0P0000050?ooo`8000001@3o
ool2000000D0oooo0P0000030?ooo`8000001@3oool2000000D0oooo0`0000040?ooo`<000001@3o
ool2000000D0oooo0P0000050?ooo`8000001@3oool2000000D0oooo0`0000040?ooo`<000001@3o
ool200000080oooo0`0000050?ooo`8000001@3oool2000000D0oooo0P0000050?ooo`8000001@3o
ool3000000@0oooo0`0000050?ooo`8000001@3oool2000000D0oooo0P0000050?ooo`<000000P3o
ool2000000D0oooo0`0000040?ooo`<00000103oool3000000D0oooo0P0000050?ooo`L000005`3A
cJT001D0dLfY2P0000040?ooo`<000001@3oool2000000D0oooo0P0000050?ooo`8000001@3oool2
000000<0oooo0P0000050?ooo`8000001@3oool3000000@0oooo0`0000050?ooo`8000001@3oool2
000000D0oooo0P0000050?ooo`8000001@3oool3000000@0oooo0`0000050?ooo`8000000P3oool3
000000D0oooo0P0000050?ooo`8000001@3oool2000000D0oooo0P0000050?ooo`<00000103oool3
000000D0oooo0P0000050?ooo`8000001@3oool2000000D0oooo0`0000020?ooo`8000001@3oool3
000000@0oooo0`0000040?ooo`<000001@3oool2000000D0oooo1`00000G0=7=Z@005@3AcJT<0?oo
o`8000000`3oool2000000L0oooo0`0000020?ooo`800000203oool200000080oooo0`0000020?oo
o`<000001`3oool2000000<0oooo0P0000070?ooo`<000000P3oool2000000P0oooo0P0000020?oo
o`<000001`3oool2000000<0oooo0P0000070?ooo`<000000P3oool2000000<0oooo0P0000070?oo
o`<000000P3oool3000000L0oooo0P0000020?ooo`<000001`3oool2000000<0oooo0P0000070?oo
o`<000000P3oool3000000L0oooo0P0000030?ooo`8000000P3oool3000000L0oooo0P0000030?oo
o`8000001`3oool300000080oooo0P00000:0?oooaL0dLfY000E0=7=Z@`0oooo0P0000030?ooo`80
00001`3oool300000080oooo0P0000080?ooo`8000000P3oool300000080oooo0`0000070?ooo`80
00000`3oool2000000L0oooo0`0000020?ooo`800000203oool200000080oooo0`0000070?ooo`80
00000`3oool2000000L0oooo0`0000020?ooo`8000000`3oool2000000L0oooo0`0000020?ooo`<0
00001`3oool200000080oooo0`0000070?ooo`8000000`3oool2000000L0oooo0`0000020?ooo`<0
00001`3oool2000000<0oooo0P0000020?ooo`<000001`3oool2000000<0oooo0P0000070?ooo`<0
00000P3oool2000000X0oooo5`3AcJT001D0dLfY303oool2000000<0oooo0P0000070?ooo`<00000
0P3oool2000000P0oooo0P0000020?ooo`<000000P3oool3000000L0oooo0P0000030?ooo`800000
1`3oool300000080oooo0P0000080?ooo`8000000P3oool3000000L0oooo0P0000030?ooo`800000
1`3oool300000080oooo0P0000030?ooo`8000001`3oool300000080oooo0`0000070?ooo`800000
0P3oool3000000L0oooo0P0000030?ooo`8000001`3oool300000080oooo0`0000070?ooo`800000
0`3oool200000080oooo0`0000070?ooo`8000000`3oool2000000L0oooo0`0000020?ooo`800000
2P3ooolG0=7=Z@005@3AcJT>000000P0oooo0P0000070?ooo``000001`3oool<000000L0oooo0`00
00070?ooo``000001`3oool2000000P0oooo300000070?ooo``000001`3oool2000000L0oooo3000
00080?ooo`8000001`3oool<000000L0oooo300000070?ooo`<000001`3oool<000001L0dLfY000E
0=7=Z@h00000203oool2000000L0oooo300000070?ooo``000001`3oool3000000L0oooo30000007
0?ooo`800000203oool<000000L0oooo300000070?ooo`8000001`3oool<000000P0oooo0P000007
0?ooo``000001`3oool<000000L0oooo0`0000070?ooo``000005`3AcJT001D0dLfY4@3oool20000
00L0oooo0`00000@0?ooo`<000004@3oool2000000L0oooo0`00000@0?ooo`<000001`3oool20000
0140oooo0P00000A0?ooo`<000001`3oool200000140oooo0P0000070?ooo`<000004@3oool20000
0140oooo0P0000070?ooo`<000003P3ooolG0=7=Z@005@3AcJTA0?ooo`8000001`3oool300000100
oooo0`00000A0?ooo`8000001`3oool300000100oooo0`0000070?ooo`8000004@3oool200000140
oooo0`0000070?ooo`8000004@3oool2000000L0oooo0`00000A0?ooo`8000004@3oool2000000L0
oooo0`00000>0?oooaL0dLfY000E0=7=ZA<000001@3oool2000000<0oooo0P0000050?ooo`800000
1@3oool2000000<0oooo0P0000050?ooo`8000001@3oool300000080oooo0P0000050?oooaH00000
103oool300000080oooo0`0000040?ooo`<000001@3oool200000080oooo0`0000050?ooo`800000
1@3oool2000000<0oooo0P0000050?oooaD000001@3oool2000000<0oooo0P0000050?ooo`800000
1@3oool300000080oooo0P0000050?ooo`<00000103oool300000080oooo0P0000050?oooa400000
5`3AcJT001D0dLfY4`0000050?ooo`8000000`3oool2000000D0oooo0P0000050?ooo`8000000`3o
ool2000000D0oooo0P0000050?ooo`<000000P3oool2000000D0oooo5P0000040?ooo`<000000P3o
ool3000000@0oooo0`0000050?ooo`8000000P3oool3000000D0oooo0P0000050?ooo`8000000`3o
ool2000000D0oooo5@0000050?ooo`8000000`3oool2000000D0oooo0P0000050?ooo`<000000P3o
ool2000000D0oooo0`0000040?ooo`<000000P3oool2000000D0oooo4@00000G0=7=Z@005@3AcJTC
000000D0oooo0P0000030?ooo`8000001@3oool2000000D0oooo0P0000030?ooo`8000001@3oool2
000000D0oooo0`0000020?ooo`8000001@3ooolF000000@0oooo0`0000020?ooo`<00000103oool3
000000D0oooo0P0000020?ooo`<000001@3oool2000000D0oooo0P0000030?ooo`8000001@3ooolE
000000D0oooo0P0000030?ooo`8000001@3oool2000000D0oooo0`0000020?ooo`8000001@3oool3
000000@0oooo0`0000020?ooo`8000001@3ooolA000001L0dLfY000E0=7=ZAH0oooo0P0000020?oo
o`<000000P3oool2000000P0oooo0P0000020?ooo`<000000P3oool3000000L0oooo0P0000030?oo
o`8000000P3oool3000001X0oooo0P0000030?ooo`8000000`3oool2000000L0oooo0`0000020?oo
o`8000000`3oool2000000L0oooo0`0000020?ooo`<000000P3oool2000001/0oooo0P0000020?oo
o`<000000P3oool3000000L0oooo0P0000030?ooo`8000000P3oool3000000L0oooo0P0000030?oo
o`8000000P3oool3000001<0oooo5`3AcJT001D0dLfY5P3oool200000080oooo0`0000020?ooo`80
0000203oool200000080oooo0`0000020?ooo`<000001`3oool2000000<0oooo0P0000020?ooo`<0
00006P3oool2000000<0oooo0P0000030?ooo`8000001`3oool300000080oooo0P0000030?ooo`80
00001`3oool300000080oooo0`0000020?ooo`8000006`3oool200000080oooo0`0000020?ooo`<0
00001`3oool2000000<0oooo0P0000020?ooo`<000001`3oool2000000<0oooo0P0000020?ooo`<0
00004`3ooolG0=7=Z@005@3AcJTH000000L0oooo300000070?ooo``000001`3ooolO000000P0oooo
300000070?ooo``000001`3ooolO000000L0oooo300000070?ooo``000001`3ooolF000001L0dLfY
000E0=7=ZAP000001`3oool<000000L0oooo300000070?oooal00000203oool<000000L0oooo3000
00070?oooal000001`3oool<000000L0oooo300000070?oooaH000005`3AcJT001D0dLfY6P3oool3
00000100oooo0`00000A0?ooo`800000903oool200000140oooo0P00000A0?ooo`<000008`3oool3
00000140oooo0P00000A0?ooo`800000603ooolG0=7=Z@005@3AcJTJ0?ooo`<00000403oool30000
0140oooo0P00000T0?ooo`8000004@3oool200000140oooo0`00000S0?ooo`<000004@3oool20000
0140oooo0P00000H0?oooaL0dLfY000E0=7=ZAX0oooo0`00000@0?ooo`<000004@3oool2000002@0
oooo0P00000A0?ooo`8000004@3oool3000002<0oooo0`00000A0?ooo`8000004@3oool2000001P0
oooo5`3AcJT001D0dLfY7@0000040?ooo`<000001@3oool2000000L0oooo0`0000040?ooo`<00000
1@3ooolX000000D0oooo0P0000050?ooo`<000001`3oool2000000D0oooo0P0000050?ooobT00000
1@3oool2000000D0oooo0P0000070?ooo`<000001@3oool2000000D0oooo6P00000G0=7=Z@005@3A
cJTM000000@0oooo0`0000050?ooo`8000001`3oool3000000@0oooo0`0000050?ooobP000001@3o
ool2000000D0oooo0`0000070?ooo`8000001@3oool2000000D0oooo:@0000050?ooo`8000001@3o
ool2000000L0oooo0`0000050?ooo`8000001@3ooolJ000001L0dLfY000E0=7=ZAl0oooo0P000003
0?ooo`8000001`3oool3000000L0oooo0P0000030?ooo`800000;P3oool200000080oooo0`000007
0?ooo`800000203oool200000080oooo0`00000]0?ooo`<000000P3oool2000000P0oooo0P000007
0?ooo`<000000P3oool2000001d0oooo5`3AcJT001D0dLfY7`3oool2000000<0oooo0P0000070?oo
o`<000001`3oool2000000<0oooo0P00000^0?ooo`8000000P3oool3000000L0oooo0P0000080?oo
o`8000000P3oool3000002d0oooo0`0000020?ooo`800000203oool2000000L0oooo0`0000020?oo
o`8000007@3ooolG0=7=Z@005@3AcJTO0?ooo`8000000`3oool2000000L0oooo0`0000070?ooo`80
00000`3oool2000002h0oooo0P0000020?ooo`<000001`3oool2000000P0oooo0P0000020?ooo`<0
0000;@3oool300000080oooo0P0000080?ooo`8000001`3oool300000080oooo0P00000M0?oooaL0
dLfY000E0=7=ZB400000203oool2000000L0oooo0`0000070?oooc8000001`3oool3000000L0oooo
0P0000070?oooc<000001`3oool2000000L0oooo0`0000070?oooal000005`3AcJT001D0dLfY8@00
00080?ooo`8000001`3oool3000000L0oooo<P0000070?ooo`<000001`3oool2000000L0oooo<`00
00070?ooo`8000001`3oool3000000L0oooo7`00000G0=7=Z@005@3AcJTT0?ooo`8000001`3oool3
000000L0oooo0P00000g0?ooo`<000001`3oool2000000P0oooo0P00000g0?ooo`800000203oool2
000000L0oooo0`00000Q0?oooaL0dLfY000E0=7=ZB@0oooo0P0000070?ooo`<000001`3oool20000
03L0oooo0`0000070?ooo`800000203oool2000003L0oooo0P0000080?ooo`8000001`3oool30000
0240oooo5`3AcJT001D0dLfY9P0000050?ooo`8000000`3oool2000000D0oooo?00000050?ooo`80
00000P3oool3000000D0oooo>`0000050?ooo`<000000P3oool2000000D0oooo9000000G0=7=Z@00
5@3AcJTV000000D0oooo0P0000030?ooo`8000001@3oooll000000D0oooo0P0000020?ooo`<00000
1@3ooolk000000D0oooo0`0000020?ooo`8000001@3ooolT000001L0dLfY000E0=7=ZBH000001@3o
ool2000000<0oooo0P0000050?oooc`000001@3oool200000080oooo0`0000050?oooc/000001@3o
ool300000080oooo0P0000050?ooob@000005`3AcJT001D0dLfY:@3oool200000080oooo0`000002
0?ooo`<00000@03oool300000080oooo0P0000030?ooo`800000@@3oool2000000<0oooo0P000002
0?ooo`<000009P3ooolG0=7=Z@005@3AcJTY0?ooo`8000000P3oool300000080oooo0`0000100?oo
o`<000000P3oool2000000<0oooo0P0000110?ooo`8000000`3oool200000080oooo0`00000V0?oo
oaL0dLfY000E0=7=ZB/000001`3ooom6000000L0ooooA@0000070?ooobT000005`3AcJT001D0dLfY
:`0000070?ooodH000001`3ooom5000000L0oooo:@00000G0=7=Z@005@3AcJT]0?ooo`<00000BP3o
ool2000004/0oooo0P00000[0?oooaL0dLfY000E0=7=ZBd0oooo0`00001:0?ooo`800000B`3oool2
000002/0oooo5`3AcJT001D0dLfY;@3oool3000004X0oooo0P00001;0?ooo`800000:`3ooolG0=7=
Z@005@3AcJT`000000D0oooo0P0000050?ooo`8000001@3oool2000000D0oooo0`0000040?ooo`<0
00001@3oool2000000D0oooo0P0000050?ooo`8000001@3oool2000000D0oooo0`0000070?ooo`80
00001@3oool2000000D0oooo0`0000040?ooo`<00000103oool3000000D0oooo0P0000050?ooo`80
00001@3oool2000000D0oooo0`0000040?ooo`<000001@3oool]000001L0dLfY000E0=7=ZC000000
1@3oool2000000D0oooo0P0000050?ooo`8000001@3oool3000000@0oooo0`0000050?ooo`800000
1@3oool2000000D0oooo0P0000050?ooo`8000001@3oool3000000L0oooo0P0000050?ooo`800000
1@3oool3000000@0oooo0`0000040?ooo`<000001@3oool2000000D0oooo0P0000050?ooo`800000
1@3oool3000000@0oooo0`0000050?ooobd000005`3AcJT001D0dLfY<P3oool300000080oooo0P00
00080?ooo`8000000P3oool3000000L0oooo0P0000030?ooo`8000001`3oool300000080oooo0P00
00080?ooo`8000000P3oool3000000L0oooo0P0000080?ooo`8000000P3oool3000000L0oooo0P00
00030?ooo`8000001`3oool300000080oooo0P0000080?ooo`8000000P3oool3000000L0oooo0P00
00030?ooo`800000<03ooolG0=7=Z@005@3AcJTb0?ooo`<000000P3oool2000000P0oooo0P000002
0?ooo`<000001`3oool2000000<0oooo0P0000070?ooo`<000000P3oool2000000P0oooo0P000002
0?ooo`<000001`3oool2000000P0oooo0P0000020?ooo`<000001`3oool2000000<0oooo0P000007
0?ooo`<000000P3oool2000000P0oooo0P0000020?ooo`<000001`3oool2000000<0oooo0P00000`
0?oooaL0dLfY000E0=7=ZC80oooo0`0000020?ooo`800000203oool200000080oooo0`0000070?oo
o`8000000`3oool2000000L0oooo0`0000020?ooo`800000203oool200000080oooo0`0000070?oo
o`800000203oool200000080oooo0`0000070?ooo`8000000`3oool2000000L0oooo0`0000020?oo
o`800000203oool200000080oooo0`0000070?ooo`8000000`3oool200000300oooo5`3AcJT001D0
dLfY=@0000070?ooo`8000001`3oool<000000P0oooo0P0000070?ooo``000001`3oool3000000L0
oooo0P0000070?ooo``000001`3oool3000000L0oooo300000070?ooo`<000001`3ooolb000001L0
dLfY000E0=7=ZCD000001`3oool2000000L0oooo300000080?ooo`8000001`3oool<000000L0oooo
0`0000070?ooo`8000001`3oool<000000L0oooo0`0000070?ooo``000001`3oool3000000L0oooo
<P00000G0=7=Z@005@3AcJTg0?ooo`800000203oool200000140oooo0P0000070?ooo`<00000403o
ool3000000L0oooo0P0000080?ooo`8000004@3oool2000000L0oooo0`00000@0?ooo`<000001`3o
ool2000003D0oooo5`3AcJT001D0dLfY=`3oool2000000P0oooo0P00000A0?ooo`8000001`3oool3
00000100oooo0`0000070?ooo`800000203oool200000140oooo0P0000070?ooo`<00000403oool3
000000L0oooo0P00000e0?oooaL0dLfY000E0=7=ZCT000001@3oool300000080oooo0P0000050?oo
o`<00000103oool300000080oooo0`0000040?oooaH000001@3oool200000080oooo0`0000050?oo
oaD000001@3oool2000000<0oooo0P0000050?ooo`8000001@3oool2000000<0oooo0P0000050?oo
ocL000005`3AcJT001D0dLfY>@0000050?ooo`<000000P3oool2000000D0oooo0`0000040?ooo`<0
00000P3oool3000000@0oooo5P0000050?ooo`8000000P3oool3000000D0oooo5@0000050?ooo`80
00000`3oool2000000D0oooo0P0000050?ooo`8000000`3oool2000000D0oooo=`00000G0=7=Z@00
5@3AcJTi000000D0oooo0`0000020?ooo`8000001@3oool3000000@0oooo0`0000020?ooo`<00000
103ooolF000000D0oooo0P0000020?ooo`<000001@3ooolE000000D0oooo0P0000030?ooo`800000
1@3oool2000000D0oooo0P0000030?ooo`8000001@3ooolg000001L0dLfY000E0=7=ZC`0oooo0P00
00030?ooo`8000000P3oool3000000L0oooo0P0000030?ooo`8000000`3oool2000001X0oooo0`00
00020?ooo`8000000`3oool2000001X0oooo0`0000020?ooo`<000000P3oool2000000P0oooo0P00
00020?ooo`<000000P3oool3000003T0oooo5`3AcJT001D0dLfY?03oool2000000<0oooo0P000002
0?ooo`<000001`3oool2000000<0oooo0P0000030?ooo`8000006P3oool300000080oooo0P000003
0?ooo`8000006P3oool300000080oooo0`0000020?ooo`800000203oool200000080oooo0`000002
0?ooo`<00000>@3ooolG0=7=Z@005@3AcJTn000000L0oooo300000080?oooal000001`3ooolO0000
00L0oooo300000070?oooc`000005`3AcJT001D0dLfY?P0000070?ooo``00000203ooolO000000L0
oooo7`0000070?ooo``000001`3oooll000001L0dLfY000E0=7=ZCh000001`3oool<000000P0oooo
7`0000070?oooal000001`3oool<000000L0oooo?000000G0=7=Z@005@3AcJU10?ooo`8000004@3o
ool2000002@0oooo0P00000T0?ooo`<00000403oool3000003h0oooo5`3AcJT001D0dLfY@@3oool2
00000140oooo0P00000T0?ooo`800000903oool300000100oooo0`00000n0?oooaL0dLfY000E0=7=
ZD<000001@3oool2000000D0oooo0P0000080?ooo`8000001@3oool2000000D0oooo0P0000050?oo
o`8000001@3oool3000000L0oooo0P0000050?ooo`8000001@3oool3000000@0oooo0`0000040?oo
o`<000001`3oool2000000D0oooo0`0000040?oood4000005`3AcJT001D0dLfY@`0000050?ooo`80
00001@3oool2000000P0oooo0P0000050?ooo`8000001@3oool2000000D0oooo0P0000050?ooo`<0
00001`3oool2000000D0oooo0P0000050?ooo`<00000103oool3000000@0oooo0`0000070?ooo`80
00001@3oool3000000@0oooo@@00000G0=7=Z@005@3AcJU50?ooo`<000000P3oool3000000L0oooo
0P0000070?ooo`<000000P3oool2000000P0oooo0P0000020?ooo`<000001`3oool2000000P0oooo
0P0000020?ooo`<000001`3oool2000000<0oooo0P0000070?ooo`<000001`3oool2000000<0oooo
0P0000130?oooaL0dLfY000E0=7=ZDD0oooo0`0000020?ooo`<000001`3oool2000000L0oooo0`00
00020?ooo`800000203oool200000080oooo0`0000070?ooo`800000203oool200000080oooo0`00
00070?ooo`8000000`3oool2000000L0oooo0`0000070?ooo`8000000`3oool2000004<0oooo5`3A
cJT001D0dLfYA@3oool300000080oooo0`0000070?ooo`8000001`3oool300000080oooo0P000008
0?ooo`8000000P3oool3000000L0oooo0P0000080?ooo`8000000P3oool3000000L0oooo0P000003
0?ooo`8000001`3oool3000000L0oooo0P0000030?ooo`800000@`3ooolG0=7=Z@005@3AcJU80000
00L0oooo0P0000080?ooo`8000001`3oool<000000L0oooo0`0000070?ooo`8000001`3oool<0000
00L0oooo0`0000070?ooo`800000203ooom5000001L0dLfY000E0=7=ZDP000001`3oool2000000P0
oooo0P0000070?ooo``000001`3oool3000000L0oooo0P0000070?ooo``000001`3oool3000000L0
oooo0P0000080?ooodD000005`3AcJT001D0dLfYBP3oool3000000L0oooo0P0000070?ooo`<00000
403oool3000000L0oooo0P0000080?ooo`8000004@3oool2000000L0oooo0`0000070?ooo`800000
B03ooolG0=7=Z@005@3AcJU:0?ooo`<000001`3oool2000000L0oooo0`00000@0?ooo`<000001`3o
ool2000000P0oooo0P00000A0?ooo`8000001`3oool3000000L0oooo0P0000180?oooaL0dLfY000E
0=7=ZDd00000103oool300000080oooo0`0000040?oooaH000001@3oool200000080oooo0`000005
0?oooaD000001@3oool2000000<0oooo0P0000050?ooodX000005`3AcJT001D0dLfYC@0000040?oo
o`<000000P3oool3000000@0oooo5P0000050?ooo`8000000P3oool3000000D0oooo5@0000050?oo
o`8000000`3oool2000000D0ooooBP00000G0=7=Z@005@3AcJU=000000@0oooo0`0000020?ooo`<0
0000103ooolF000000D0oooo0P0000020?ooo`<000001@3ooolE000000D0oooo0P0000030?ooo`80
00001@3ooom:000001L0dLfY000E0=7=ZDl0oooo0P0000030?ooo`8000000`3oool2000001X0oooo
0`0000020?ooo`8000000`3oool2000001X0oooo0`0000020?ooo`<000000P3oool2000004d0oooo
5`3AcJT001D0dLfYC`3oool2000000<0oooo0P0000030?ooo`8000006P3oool300000080oooo0P00
00030?ooo`8000006P3oool300000080oooo0`0000020?ooo`800000C@3ooolG0=7=Z@005@3AcJUA
000000P0oooo7`0000070?oooal000001`3ooom?000001L0dLfY000E0=7=ZE400000203ooolO0000
00L0oooo7`0000070?ooodl000005`3AcJT001D0dLfYD@0000080?oooal000001`3ooolO000000L0
ooooC`00000G0=7=Z@005@3AcJUD0?ooo`800000903oool2000002@0oooo0`00001A0?oooaL0dLfY
000E0=7=ZE@0oooo0P00000T0?ooo`800000903oool300000540oooo5`3AcJT001D0dLfYEP000005
0?ooo`8000001@3oool2000000D0oooo0`0000040?ooo`<000001@3oool200000080oooo0`000005
0?ooo`8000001@3oool2000000D0oooo0P0000050?ooo`8000001@3ooomD000001L0dLfY000E0=7=
ZEH000001@3oool2000000D0oooo0P0000050?ooo`<00000103oool3000000D0oooo0P0000020?oo
o`<000001@3oool2000000D0oooo0P0000050?ooo`8000001@3oool2000000D0ooooE000000G0=7=
Z@005@3AcJUI0?ooo`8000000P3oool3000000L0oooo0P0000030?ooo`8000001`3oool300000080
oooo0P0000030?ooo`8000001`3oool300000080oooo0`0000070?ooo`8000000P3oool3000005H0
oooo5`3AcJT001D0dLfYF@3oool200000080oooo0`0000070?ooo`8000000`3oool2000000L0oooo
0`0000020?ooo`8000000`3oool2000000L0oooo0`0000020?ooo`<000001`3oool200000080oooo
0`00001F0?oooaL0dLfY000E0=7=ZET0oooo0P0000020?ooo`<000001`3oool2000000<0oooo0P00
00070?ooo`<000000P3oool2000000<0oooo0P0000070?ooo`<000000P3oool3000000L0oooo0P00
00020?ooo`<00000EP3ooolG0=7=Z@005@3AcJUK000000L0oooo0P0000080?ooo``000001`3oool<
000000L0oooo0P0000070?oooeT000005`3AcJT001D0dLfYF`0000070?ooo`800000203oool<0000
00L0oooo300000070?ooo`8000001`3ooomI000001L0dLfY000E0=7=ZEd0oooo0`0000070?ooo`80
00004@3oool200000140oooo0`0000070?ooo`800000F`3ooolG0=7=Z@005@3AcJUM0?ooo`<00000
1`3oool200000140oooo0P00000A0?ooo`<000001`3oool2000005/0oooo5`3AcJT001D0dLfYH000
00040?ooo`<000000P3oool3000000@0oooo0`0000050?ooo`8000000P3oool3000000D0oooo0P00
00050?ooo`8000000`3oool2000000D0ooooG@00000G0=7=Z@005@3AcJUP000000@0oooo0`000002
0?ooo`<00000103oool3000000D0oooo0P0000020?ooo`<000001@3oool2000000D0oooo0P000003
0?ooo`8000001@3ooomM000001L0dLfY000E0=7=ZF000000103oool300000080oooo0`0000040?oo
o`<000001@3oool200000080oooo0`0000050?ooo`8000001@3oool2000000<0oooo0P0000050?oo
oed000005`3AcJT001D0dLfYHP3oool2000000<0oooo0P0000030?ooo`8000001`3oool300000080
oooo0P0000030?ooo`8000001`3oool300000080oooo0`0000020?ooo`800000H03ooolG0=7=Z@00
5@3AcJUR0?ooo`8000000`3oool2000000<0oooo0P0000070?ooo`<000000P3oool2000000<0oooo
0P0000070?ooo`<000000P3oool300000080oooo0P00001P0?oooaL0dLfY000E0=7=ZF@00000203o
ool<000000L0oooo300000070?ooof8000005`3AcJT001D0dLfYI00000080?ooo``000001`3oool<
000000L0ooooHP00000G0=7=Z@005@3AcJUT000000P0oooo300000070?ooo``000001`3ooomR0000
01L0dLfY000E0=7=ZFL0oooo0P00000A0?ooo`8000004@3oool3000006@0oooo5`3AcJT001D0dLfY
I`3oool200000140oooo0P00000A0?ooo`<00000I03ooolG0=7=Z@005@3AcJUY000000D0oooo0P00
00050?ooo`<000001`3oool2000000D0oooo0P0000050?ooofL000005`3AcJT001D0dLfYJ@000005
0?ooo`8000001@3oool3000000L0oooo0P0000050?ooo`8000001@3ooomW000001L0dLfY000E0=7=
ZF`0oooo0P0000020?ooo`<000001`3oool2000000P0oooo0P0000020?ooo`<00000J@3ooolG0=7=
Z@005@3AcJU/0?ooo`8000000P3oool3000000L0oooo0P0000080?ooo`8000000P3oool3000006T0
oooo5`3AcJT001D0dLfYK03oool200000080oooo0`0000070?ooo`800000203oool200000080oooo
0`00001Y0?oooaL0dLfY000E0=7=ZFh000001`3oool3000000L0oooo0P0000070?ooof`000005`3A
cJT001D0dLfYKP0000070?ooo`<000001`3oool2000000L0ooooK000000G0=7=Z@005@3AcJU`0?oo
o`<000001`3oool2000000P0oooo0P00001^0?oooaL0dLfY000E0=7=ZG00oooo0`0000070?ooo`80
0000203oool2000006h0oooo5`3AcJT001D0dLfYL`0000050?ooo`8000000P3oool3000000D0oooo
L000000G0=7=Z@005@3AcJUc000000D0oooo0P0000020?ooo`<000001@3ooom`000001L0dLfY000E
0=7=ZG<000001@3oool200000080oooo0`0000050?ooog0000005`3AcJT001D0dLfYM@3oool30000
0080oooo0P0000030?ooo`800000L`3ooolG0=7=Z@005@3AcJUe0?ooo`<000000P3oool2000000<0
oooo0P00001c0?oooaL0dLfY000E0=7=ZGP000001`3ooome000001L0dLfY000E0=7=ZGP000001`3o
oome000001L0dLfY000E0=7=ZGP000001`3ooome000001L0dLfY000E0=7=ZGX0oooo0P00001h0?oo
oaL0dLfY000E0=7=ZGX0oooo0P00001h0?oooaL0dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o
0=7=ZB40dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o
0=7=ZB40dLfY003o0=7=ZB40dLfY001h0=7=Z@E000000P3AcJT2@00000@0dLfY0T0000030=7=Z@E0
00000P3AcJT2@00000<0dLfY1D0000000`3AcJU00000@0000003@0000080dLfY0T00001k0=7=Z@00
NP3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d00
0000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@02
0=7=Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003A
cJT0dLfY07P0dLfY001j0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=
ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03
@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00=000000=7=Z@3AcJT0N03AcJT007X0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=
Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3A
cJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003A
cJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@1h0=7=Z@00NP3AcJT01D000000dLfY0=7=
Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY
00<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY07P0dLfY001i0=7=
Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=
Z@900000103AcJT2@00007/0dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {140.125, 0}} -> {-9.13688, -1.00027, \
0.419072, 0.419072}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(rule4 = {0, 1, 1, 0, 1, 0, 1, 0};\)\), "\[IndentingNewLine]", 
    \(\(Show[
        showCA[2, cellularSpace[n], rule4, \[LeftFloor]n/4\[RightFloor], 
          1, \[LeftFloor]n/4\[RightFloor], n - \[LeftFloor]n/4\[RightFloor]], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4902 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00942685 0.00942685 0.00942685 [
[.5 .5027 -26 0 ]
[.5 .5027 26 12.875 ]
[ 0 0 0 0 ]
[ 1 .4902 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5027 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(01101010) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .4902 L
0 .4902 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00943 translate
.96154 .47134 scale
102 string
102 50 8 [102 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 141.125},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000SB000`400?l00000o`00003oo`3AcJTQ
0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@005@3AcJT50?ooo`L000002P3o
ool200000080oooo0`0000020?ooo`8000000`3oool9000000D0oooo1@0000050?ooo`D00000303o
ool200000080oooo4`0000080?ooo`@000000`3oool700000080oooo1@00000<0?ooo``000003P3o
ool5000000<0oooo1000000:0?ooo`D000000P3oool3000000L0oooo1`0000050?ooo`@000000`3o
ool9000000<0oooo1@0000020?oooaL0dLfY000E0=7=Z@D0oooo1`00000:0?ooo`8000000P3oool3
00000080oooo0P0000030?ooo`T000001@3oool5000000D0oooo1@00000<0?ooo`8000000P3ooolC
000000P0oooo100000030?ooo`L000000P3oool5000000`0oooo3000000>0?ooo`D000000`3oool4
000000X0oooo1@0000020?ooo`<000001`3oool7000000D0oooo100000030?ooo`T000000`3oool5
00000080oooo5`3AcJT001D0dLfY1`3oool3000000h0oooo1@0000020?ooo`8000000`3oool20000
00D0oooo0P0000030?ooo`D000002@3oool300000080oooo300000020?ooo`<000001@3oool20000
00D0oooo0P00000<0?ooo`8000000`3oool2000000D0oooo1@00000A0?ooo`8000001@3oool20000
0080oooo3`0000070?ooo`8000000`3oool9000000P0oooo2@0000050?ooo`L000001`3oool30000
00@0oooo1@0000050?oooaL0dLfY000E0=7=Z@L0oooo0`00000>0?ooo`D000000P3oool2000000<0
oooo0P0000050?ooo`8000000`3oool5000000T0oooo0`0000020?ooo``000000P3oool3000000D0
oooo0P0000050?ooo`800000303oool2000000<0oooo0P0000050?ooo`D000004@3oool2000000D0
oooo0P0000020?ooo`l000001`3oool2000000<0oooo2@0000080?ooo`T000001@3oool7000000L0
oooo0`0000040?ooo`D000001@3ooolG0=7=Z@005@3AcJT70?ooo`<000003P3oool500000080oooo
0P0000030?ooo`8000001@3oool2000000<0oooo1@0000090?ooo`<000000P3oool<00000080oooo
0`0000050?ooo`8000001@3oool2000000`0oooo0P0000030?ooo`8000001@3oool500000140oooo
0P0000050?ooo`8000000P3oool?000000L0oooo0P0000030?ooo`T00000203oool9000000D0oooo
1`0000070?ooo`<00000103oool5000000D0oooo5`3AcJT001D0dLfY2P3oool@000000L0oooo1@00
00030?ooo`@000000`3oool2000000l0oooo100000050?ooo`<000001`3oool700000080oooo1@00
00020?ooo``000000`3oool2000000<0oooo1000000F0?ooo`L000000P3oool3000000D0oooo0P00
00050?ooo`T000000`3oool2000000D0oooo0P0000030?ooo`L000001@3oool2000000<0oooo1000
00050?ooo`X000000P3oool5000000L0oooo5`3AcJT001D0dLfY2P3oool@000000L0oooo1@000003
0?ooo`@000000`3oool2000000l0oooo100000050?ooo`<000001`3oool700000080oooo1@000002
0?ooo``000000`3oool2000000<0oooo1000000F0?ooo`L000000P3oool3000000D0oooo0P000005
0?ooo`T000000`3oool2000000D0oooo0P0000030?ooo`L000001@3oool2000000<0oooo10000005
0?ooo`X000000P3oool5000000L0oooo5`3AcJT001D0dLfY303oool2000000D0oooo0`0000040?oo
o`X000001`3oool2000000<0oooo0P0000030?ooo`h000002P3oool9000000D0oooo1@0000070?oo
o`8000001@3oool2000000<0oooo0P0000030?ooo`8000006P3oool3000000L0oooo1`0000020?oo
o`D000001@3oool2000000<0oooo0P0000030?ooo`@000000`3oool2000000D0oooo1`0000030?oo
o`8000002@3oool3000000D0oooo1000000:0?oooaL0dLfY000E0=7=Z@`0oooo0P0000050?ooo`<0
0000103oool:000000L0oooo0P0000030?ooo`8000000`3oool>000000X0oooo2@0000050?ooo`D0
00001`3oool2000000D0oooo0P0000030?ooo`8000000`3oool2000001X0oooo0`0000070?ooo`L0
00000P3oool5000000D0oooo0P0000030?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`L0
00000`3oool2000000T0oooo0`0000050?ooo`@000002P3ooolG0=7=Z@005@3AcJT<0?ooo`800000
1@3oool3000000@0oooo2P0000070?ooo`8000000`3oool2000000<0oooo3P00000:0?ooo`T00000
1@3oool5000000L0oooo0P0000050?ooo`8000000`3oool2000000<0oooo0P00000J0?ooo`<00000
1`3oool700000080oooo1@0000050?ooo`8000000`3oool2000000<0oooo100000030?ooo`800000
1@3oool7000000<0oooo0P0000090?ooo`<000001@3oool4000000X0oooo5`3AcJT001D0dLfY3P3o
ool800000080oooo1@0000040?ooo`<000000P3oool7000000<0oooo0P0000030?ooo`8000001@3o
ool2000000D0oooo300000050?ooo`8000000`3oool4000000`0oooo1`0000030?ooo`8000000`3o
ool200000080oooo6`0000020?ooo`L000001@3oool5000000T0oooo1@0000030?ooo`8000001`3o
ool7000000D0oooo1@0000020?ooo`X000000P3oool5000000`0oooo5`3AcJT001D0dLfY3P3oool8
00000080oooo1@0000040?ooo`<000000P3oool7000000<0oooo0P0000030?ooo`8000001@3oool2
000000D0oooo300000050?ooo`8000000`3oool4000000`0oooo1`0000030?ooo`8000000`3oool2
00000080oooo6`0000020?ooo`L000001@3oool5000000T0oooo1@0000030?ooo`8000001`3oool7
000000D0oooo1@0000020?ooo`X000000P3oool5000000`0oooo5`3AcJT001D0dLfY4@3oool20000
00L0oooo0`0000020?ooo`D000000P3oool3000000@0oooo1@0000030?ooo`8000000P3oool50000
00<0oooo100000050?ooo`<000002@3oool500000140oooo0P0000070?ooo`D000000P3oool30000
00D0oooo0P0000050?ooo`8000001@3oool2000000L0oooo0`0000090?ooo`<000000P3oool:0000
00L0oooo2P0000040?ooo`P000001`3oool2000000D0oooo1@00000>0?oooaL0dLfY000E0=7=ZA40
oooo0P0000070?ooo`<000000P3oool500000080oooo0`0000040?ooo`D000000`3oool200000080
oooo1@0000030?ooo`@000001@3oool3000000T0oooo1@00000A0?ooo`8000001`3oool500000080
oooo0`0000050?ooo`8000001@3oool2000000D0oooo0P0000070?ooo`<000002@3oool300000080
oooo2P0000070?ooo`X00000103oool8000000L0oooo0P0000050?ooo`D000003P3ooolG0=7=Z@00
5@3AcJTC0?ooo`X000000P3oool2000000P0oooo1`0000070?ooo`D000001`3oool2000000<0oooo
1@0000020?ooo`X000005@3oool:000000L0oooo1`0000020?ooo`D000000`3oool4000000<0oooo
1`0000020?ooo`X000000P3oool3000000@0oooo0`0000020?ooo`L000001@3oool300000080oooo
1@0000050?ooo`T000000P3oool500000140oooo5`3AcJT001D0dLfY4`3oool:00000080oooo0P00
00080?ooo`L000001`3oool5000000L0oooo0P0000030?ooo`D000000P3oool:000001D0oooo2P00
00070?ooo`L000000P3oool5000000<0oooo100000030?ooo`L000000P3oool:00000080oooo0`00
00040?ooo`<000000P3oool7000000D0oooo0`0000020?ooo`D000001@3oool900000080oooo1@00
000A0?oooaL0dLfY000E0=7=ZA<0oooo2P0000020?ooo`800000203oool7000000L0oooo1@000007
0?ooo`8000000`3oool500000080oooo2P00000E0?ooo`X000001`3oool700000080oooo1@000003
0?ooo`@000000`3oool700000080oooo2P0000020?ooo`<00000103oool300000080oooo1`000005
0?ooo`<000000P3oool5000000D0oooo2@0000020?ooo`D000004@3ooolG0=7=Z@005@3AcJTF0?oo
o`8000001@3oool4000000<0oooo1`0000050?ooo`T00000303oool5000000L0oooo0`0000050?oo
oaL000001@3oool300000080oooo1`0000050?ooo`D000001`3oool2000000<0oooo0P0000050?oo
o`D00000103oool300000080oooo0`0000020?ooo`D000000P3oool3000000@0oooo200000020?oo
o`8000002P3oool2000000D0oooo1@00000C0?oooaL0dLfY000E0=7=ZAH0oooo0P0000050?ooo`@0
00000`3oool7000000D0oooo2@00000<0?ooo`D000001`3oool3000000D0oooo5`0000050?ooo`<0
00000P3oool7000000D0oooo1@0000070?ooo`8000000`3oool2000000D0oooo1@0000040?ooo`<0
00000P3oool300000080oooo1@0000020?ooo`<00000103oool800000080oooo0P00000:0?ooo`80
00001@3oool5000001<0oooo5`3AcJT001D0dLfY603oool7000000L0oooo0`0000090?ooo`<00000
103oool?000000`0oooo1`0000050?ooo`8000001@3oool2000000D0oooo0P0000030?ooo`D00000
0P3oool2000000D0oooo1`00000<0?ooo`D000000P3oool5000000X0oooo1@0000020?ooo`800000
203oool7000000D0oooo100000030?ooo`T000000`3oool4000001H0oooo5`3AcJT001D0dLfY603o
ool7000000L0oooo0`0000090?ooo`<00000103oool?000000`0oooo1`0000050?ooo`8000001@3o
ool2000000D0oooo0P0000030?ooo`D000000P3oool2000000D0oooo1`00000<0?ooo`D000000P3o
ool5000000X0oooo1@0000020?ooo`800000203oool7000000D0oooo100000030?ooo`T000000`3o
ool4000001H0oooo5`3AcJT001D0dLfY6P3oool3000000`0oooo300000020?ooo`D000001@3oool2
000000D0oooo3P0000050?ooo`L000000P3oool5000000<0oooo100000030?ooo`8000001`3oool8
000000@0oooo3`0000070?ooo`8000000`3oool9000000L0oooo2P0000050?ooo`L000001`3oool3
000000@0oooo1@00000H0?oooaL0dLfY000E0=7=ZAX0oooo0`00000<0?ooo``000000P3oool50000
00D0oooo0P0000050?ooo`h000001@3oool700000080oooo1@0000030?ooo`@000000`3oool20000
00L0oooo200000040?ooo`l000001`3oool2000000<0oooo2@0000070?ooo`X000001@3oool70000
00L0oooo0`0000040?ooo`D00000603ooolG0=7=Z@005@3AcJTJ0?ooo`<00000303oool<00000080
oooo1@0000050?ooo`8000001@3oool>000000D0oooo1`0000020?ooo`D000000`3oool4000000<0
oooo0P0000070?ooo`P00000103oool?000000L0oooo0P0000030?ooo`T000001`3oool:000000D0
oooo1`0000070?ooo`<00000103oool5000001P0oooo5`3AcJT001D0dLfY7@3oool>000000D0oooo
0P0000070?ooo`<000000P3oool500000080oooo1@0000050?ooo`8000001@3oool7000000D0oooo
1@0000070?ooo`8000000`3oool2000000<0oooo1`0000050?ooo`L000001@3oool2000000D0oooo
2@0000030?ooo`8000001@3oool2000000<0oooo1`0000050?ooo`8000000P3oool5000000D0oooo
2P0000020?ooo`D000006P3ooolG0=7=Z@005@3AcJTM0?ooo`h000001@3oool2000000L0oooo0`00
00020?ooo`D000000P3oool5000000D0oooo0P0000050?ooo`L000001@3oool5000000L0oooo0P00
00030?ooo`8000000`3oool7000000D0oooo1`0000050?ooo`8000001@3oool9000000<0oooo0P00
00050?ooo`8000000`3oool7000000D0oooo0P0000020?ooo`D000001@3oool:00000080oooo1@00
000J0?oooaL0dLfY000E0=7=ZAl0oooo0P0000050?ooo`<000002@3oool:00000080oooo0`000007
0?ooo`8000000`3oool4000000<0oooo1@0000040?ooo`L00000303oool5000000<0oooo0P000005
0?ooo`L000001@3oool700000080oooo1@0000050?ooo`8000000`3oool200000080oooo1@000003
0?ooo`8000001@3oool700000080oooo0`0000090?ooo`<000001@3oool4000001d0oooo5`3AcJT0
01D0dLfY7`3oool2000000D0oooo0`0000090?ooo`X000000P3oool3000000L0oooo0P0000030?oo
o`@000000`3oool5000000@0oooo1`00000<0?ooo`D000000`3oool2000000D0oooo1`0000050?oo
o`L000000P3oool5000000D0oooo0P0000030?ooo`8000000P3oool5000000<0oooo0P0000050?oo
o`L000000P3oool3000000T0oooo0`0000050?ooo`@000007@3ooolG0=7=Z@005@3AcJTO0?ooo`80
00001@3oool3000000T0oooo2P0000020?ooo`<000001`3oool2000000<0oooo100000030?ooo`D0
0000103oool7000000`0oooo1@0000030?ooo`8000001@3oool7000000D0oooo1`0000020?ooo`D0
00001@3oool2000000<0oooo0P0000020?ooo`D000000`3oool2000000D0oooo1`0000020?ooo`<0
00002@3oool3000000D0oooo1000000M0?oooaL0dLfY000E0=7=ZB40oooo200000020?ooo`X00000
103oool300000080oooo0`0000020?ooo`L000000`3oool2000000L0oooo0`0000020?ooo`D00000
103oool?000000L0oooo1`0000050?ooo`L000001@3oool5000000T0oooo1@0000020?ooo`<00000
1`3oool7000000D0oooo1@0000020?ooo`X000000P3oool5000001l0oooo5`3AcJT001D0dLfY8@3o
ool800000080oooo2P0000040?ooo`<000000P3oool300000080oooo1`0000030?ooo`8000001`3o
ool300000080oooo1@0000040?ooo`l000001`3oool7000000D0oooo1`0000050?ooo`D000002@3o
ool500000080oooo0`0000070?ooo`L000001@3oool500000080oooo2P0000020?ooo`D000007`3o
oolG0=7=Z@005@3AcJTT0?ooo`8000001`3oool3000000D0oooo1`0000020?ooo`<000000P3oool2
000000D0oooo1@0000020?ooo`P000000P3oool2000000X0oooo0P0000050?ooo`800000303oool3
000000T0oooo0`0000090?ooo`<000000P3oool:000000L0oooo2@0000050?ooo`L00000203oool2
000000D0oooo1@00000Q0?oooaL0dLfY000E0=7=ZB@0oooo0P0000070?ooo`<000001@3oool70000
0080oooo0`0000020?ooo`8000001@3oool500000080oooo200000020?ooo`8000002P3oool20000
00D0oooo0P00000<0?ooo`<000002@3oool3000000T0oooo0`0000020?ooo`X000001`3oool90000
00D0oooo1`0000080?ooo`8000001@3oool500000240oooo5`3AcJT001D0dLfY9P3oool:00000080
oooo1@0000050?ooo`D000000P3oool2000000<0oooo1@0000070?ooo`8000001`3oool<000000<0
oooo100000030?ooo``000000P3oool:00000080oooo2P0000020?ooo`8000001@3oool300000080
oooo1`0000050?ooo`8000000`3oool5000000@0oooo2P0000020?ooo`D00000903ooolG0=7=Z@00
5@3AcJTV0?ooo`X000000P3oool5000000D0oooo1@0000020?ooo`8000000`3oool5000000L0oooo
0P0000070?ooo``000000`3oool4000000<0oooo300000020?ooo`X000000P3oool:00000080oooo
0P0000050?ooo`<000000P3oool7000000D0oooo0P0000030?ooo`D00000103oool:00000080oooo
1@00000T0?oooaL0dLfY000E0=7=ZBH0oooo2P0000020?ooo`D000001@3oool500000080oooo0P00
00030?ooo`D000001`3oool2000000L0oooo300000030?ooo`@000000`3oool<00000080oooo2P00
00020?ooo`X000000P3oool2000000D0oooo0`0000020?ooo`L000001@3oool2000000<0oooo1@00
00040?ooo`X000000P3oool5000002@0oooo5`3AcJT001D0dLfY:@3oool2000000D0oooo1@000009
0?ooo`<000000P3oool2000000<0oooo0P00000<0?ooo`X00000103oool3000000L0oooo0P000003
0?ooo`8000001@3oool2000000P0oooo0P0000050?ooo`D00000103oool300000080oooo0P000003
0?ooo`D000000P3oool2000000D0oooo1`0000030?ooo`8000002P3oool2000000D0oooo1@00000V
0?oooaL0dLfY000E0=7=ZBT0oooo0P0000050?ooo`D000002@3oool300000080oooo0P0000030?oo
o`800000303oool:000000@0oooo0`0000070?ooo`8000000`3oool2000000D0oooo0P0000080?oo
o`8000001@3oool5000000@0oooo0`0000020?ooo`8000000`3oool500000080oooo0P0000050?oo
o`L000000`3oool2000000X0oooo0P0000050?ooo`D000009P3ooolG0=7=Z@005@3AcJT[0?ooo`L0
00003`3oool4000000<0oooo0P0000030?ooo``00000103oool300000080oooo1@0000020?ooo`L0
00000`3oool2000000<0oooo100000030?ooo`L000000P3oool5000000X0oooo100000030?ooo`80
00001`3oool8000000@0oooo1@0000030?ooo`T000000`3oool4000002T0oooo5`3AcJT001D0dLfY
:`3oool7000000l0oooo100000030?ooo`8000000`3oool<000000@0oooo0`0000020?ooo`D00000
0P3oool7000000<0oooo0P0000030?ooo`@000000`3oool700000080oooo1@00000:0?ooo`@00000
0`3oool2000000L0oooo200000040?ooo`D000000`3oool9000000<0oooo1000000Y0?oooaL0dLfY
000E0=7=ZBd0oooo0`00000C0?ooo`8000000`3oool2000000<0oooo0P0000050?ooo`8000002P3o
ool4000000P0oooo0P0000070?ooo`D000001`3oool3000000L0oooo0P0000030?ooo`T000001`3o
ool:000000D0oooo1`0000070?ooo`8000001@3oool5000002/0oooo5`3AcJT001D0dLfY;@3oool3
000001<0oooo0P0000030?ooo`8000000`3oool2000000D0oooo0P00000:0?ooo`@00000203oool2
000000L0oooo1@0000070?ooo`<000001`3oool2000000<0oooo2@0000070?ooo`X000001@3oool7
000000L0oooo0P0000050?ooo`D00000:`3ooolG0=7=Z@005@3AcJT]0?ooo`<000004`3oool20000
00<0oooo0P0000030?ooo`8000001@3oool2000000X0oooo100000080?ooo`8000001`3oool50000
00L0oooo0`0000070?ooo`8000000`3oool9000000L0oooo2P0000050?ooo`L000001`3oool20000
00D0oooo1@00000[0?oooaL0dLfY000E0=7=ZC00oooo5@0000030?ooo`8000000`3oool200000080
oooo1@0000030?ooo`T00000303oool:000000`0oooo2@0000030?ooo`8000001@3oool200000080
oooo200000040?ooo`<000000P3oool5000000D0oooo2@0000030?ooo`D00000;@3ooolG0=7=Z@00
5@3AcJT`0?oooaD000000`3oool2000000<0oooo0P0000020?ooo`D000000`3oool9000000`0oooo
2P00000<0?ooo`T000000`3oool2000000D0oooo0P0000020?ooo`P00000103oool300000080oooo
1@0000050?ooo`T000000`3oool5000002d0oooo5`3AcJT001D0dLfY<P3oool3000000@0oooo0`00
00050?ooo`8000001`3oool500000080oooo0`0000070?ooo`8000001@3oool>000000D0oooo0`00
00020?ooo``000001@3oool2000000<0oooo0P0000020?ooo`D000000P3oool3000000D0oooo1`00
00020?ooo`<000002@3oool3000000@0oooo1@00000`0?oooaL0dLfY000E0=7=ZC80oooo0`000004
0?ooo`<000001@3oool2000000L0oooo1@0000020?ooo`<000001`3oool2000000D0oooo3P000005
0?ooo`<000000P3oool<000000D0oooo0P0000030?ooo`8000000P3oool500000080oooo0`000005
0?ooo`L000000P3oool3000000T0oooo0`0000040?ooo`D00000<03ooolG0=7=Z@005@3AcJTb0?oo
o`<00000103oool3000000D0oooo0P0000070?ooo`D000000P3oool3000000L0oooo0P0000050?oo
o`h000001@3oool300000080oooo300000050?ooo`8000000`3oool200000080oooo1@0000020?oo
o`<000001@3oool700000080oooo0`0000090?ooo`<00000103oool500000300oooo5`3AcJT001D0
dLfY=@3oool700000080oooo1@0000020?ooo`P000001`3oool9000000<0oooo100000050?ooo`<0
0000103oool800000080oooo0P0000050?ooo`<000002@3oool500000080oooo0`0000070?ooo`L0
00001@3oool500000080oooo2P0000020?ooo`D00000<P3ooolG0=7=Z@005@3AcJTe0?ooo`L00000
0P3oool500000080oooo200000070?ooo`T000000`3oool4000000D0oooo0`0000040?ooo`P00000
0P3oool2000000D0oooo0`0000090?ooo`D000000P3oool3000000L0oooo1`0000050?ooo`D00000
0P3oool:00000080oooo1@00000b0?oooaL0dLfY000E0=7=ZCL0oooo0P0000080?ooo`8000000P3o
ool3000000D0oooo2@0000050?ooo`8000000`3oool2000000X0oooo1`0000050?ooo`@000000`3o
ool500000080oooo2P0000070?ooo`T000001@3oool7000000L0oooo0`0000050?ooo`@00000=@3o
oolG0=7=Z@005@3AcJTg0?ooo`800000203oool200000080oooo0`0000050?ooo`T000001@3oool2
000000<0oooo0P00000:0?ooo`L000001@3oool4000000<0oooo1@0000020?ooo`X000001`3oool9
000000D0oooo1`0000070?ooo`<000001@3oool4000003D0oooo5`3AcJT001D0dLfY>@3oool:0000
0080oooo0`0000020?ooo`D000001@3oool2000000<0oooo100000030?ooo`8000000P3oool:0000
00D0oooo1`0000070?ooo`<000000P3oool2000000D0oooo0`0000020?ooo`L000001@3oool20000
00<0oooo100000050?ooo`X000000P3oool5000003L0oooo5`3AcJT001D0dLfY>@3oool:00000080
oooo0`0000020?ooo`D000001@3oool2000000<0oooo100000030?ooo`8000000P3oool:000000D0
oooo1`0000070?ooo`<000000P3oool2000000D0oooo0`0000020?ooo`L000001@3oool2000000<0
oooo100000050?ooo`X000000P3oool5000003L0oooo5`3AcJT001D0dLfY>@3oool:00000080oooo
0`0000020?ooo`D000001@3oool2000000<0oooo100000030?ooo`8000000P3oool:000000D0oooo
1`0000070?ooo`<000000P3oool2000000D0oooo0`0000020?ooo`L000001@3oool2000000<0oooo
100000050?ooo`X000000P3oool5000003L0oooo5`3AcJT001D0dLfY?03oool2000000D0oooo1@00
00020?ooo`<000002@3oool5000000L0oooo1@0000050?ooo`8000000P3oool5000000D0oooo2P00
00020?ooo`8000000`3oool500000080oooo0P0000050?ooo`L000000`3oool2000000X0oooo0P00
00050?ooo`D00000>@3ooolG0=7=Z@005@3AcJTl0?ooo`8000001@3oool500000080oooo0`000009
0?ooo`D000001`3oool5000000D0oooo0P0000020?ooo`D000001@3oool:00000080oooo0P000003
0?ooo`D000000P3oool2000000D0oooo1`0000030?ooo`8000002P3oool2000000D0oooo1@00000i
0?oooaL0dLfY000E0=7=ZCh0oooo1`0000080?ooo``000002`3oool300000080oooo1@0000020?oo
o`<000002@3oool3000000D0oooo100000030?ooo`8000001`3oool7000000D0oooo1@0000020?oo
o`X000000P3oool5000003`0oooo5`3AcJT001D0dLfY?P3oool7000000P0oooo3000000;0?ooo`<0
00000P3oool500000080oooo0`0000090?ooo`<000001@3oool4000000<0oooo0P0000070?ooo`L0
00001@3oool500000080oooo2P0000020?ooo`D00000?03ooolG0=7=Z@005@3AcJTn0?ooo`L00000
203oool<000000/0oooo0`0000020?ooo`D000000P3oool3000000T0oooo0`0000050?ooo`@00000
0`3oool2000000L0oooo1`0000050?ooo`D000000P3oool:00000080oooo1@00000l0?oooaL0dLfY
000E0=7=ZD40oooo0P00000<0?ooo`8000001@3oool300000080oooo300000020?ooo`<000001`3o
ool<00000080oooo1@0000070?ooo`X00000103oool8000000L0oooo0P0000050?ooo`D00000?P3o
oolG0=7=Z@005@3AcJU10?ooo`800000303oool2000000D0oooo0`0000020?ooo``000000P3oool3
000000L0oooo300000020?ooo`D000001`3oool:000000@0oooo200000070?ooo`8000001@3oool5
000003h0oooo5`3AcJT001D0dLfY@`3oool>000000<0oooo1@0000020?ooo`8000001@3oool20000
00P0oooo2@0000050?ooo`800000203oool200000080oooo200000040?ooo`<000000P3oool50000
00D0oooo2@0000030?ooo`@00000@@3ooolG0=7=Z@005@3AcJU30?ooo`h000000`3oool500000080
oooo0P0000050?ooo`800000203oool9000000D0oooo0P0000080?ooo`8000000P3oool8000000@0
oooo0`0000020?ooo`D000001@3oool9000000<0oooo100000110?oooaL0dLfY000E0=7=ZDD0oooo
0`0000050?ooo`8000001`3oool300000080oooo0P0000030?ooo`@000000`3oool7000000D0oooo
0P0000030?ooo`@000000`3oool700000080oooo0`0000050?ooo`L000000P3oool2000000X0oooo
0P0000050?ooo`D00000@`3ooolG0=7=Z@005@3AcJU50?ooo`<000001@3oool2000000L0oooo0`00
00020?ooo`8000000`3oool4000000<0oooo1`0000050?ooo`8000000`3oool4000000<0oooo1`00
00020?ooo`<000001@3oool700000080oooo0P00000:0?ooo`8000001@3oool5000004<0oooo5`3A
cJT001D0dLfYA@3oool3000000D0oooo0P0000070?ooo`<000000P3oool2000000<0oooo10000003
0?ooo`L000001@3oool2000000<0oooo100000030?ooo`L000000P3oool3000000D0oooo1`000002
0?ooo`8000002P3oool2000000D0oooo1@0000130?oooaL0dLfY000E0=7=ZDP0oooo1`0000020?oo
o`P000000P3oool2000000<0oooo0P0000070?ooo`<000002@3oool5000000L0oooo0`0000070?oo
o`L000001@3oool4000000<0oooo2@0000030?ooo`D00000A@3ooolG0=7=Z@005@3AcJU80?ooo`L0
00000P3oool800000080oooo0P0000030?ooo`8000001`3oool3000000T0oooo1@0000070?ooo`<0
00001`3oool7000000D0oooo100000030?ooo`T000000`3oool5000004D0oooo5`3AcJT001D0dLfY
BP3oool3000000L0oooo0P0000070?ooo`D000000P3oool800000080oooo2P00000<0?ooo`T00000
1@3oool7000000L0oooo0`0000040?ooo`D00000B03ooolG0=7=Z@005@3AcJU:0?ooo`<000001`3o
ool2000000L0oooo1@0000020?ooo`P000000P3oool:000000`0oooo2@0000050?ooo`L000001`3o
ool3000000@0oooo1@0000180?oooaL0dLfY000E0=7=ZDd0oooo2@0000030?ooo`L000001`3oool2
000000L0oooo0`0000050?ooo`h000001@3oool2000000<0oooo100000050?ooo`X000000P3oool5
000004X0oooo5`3AcJT001D0dLfYC@3oool9000000<0oooo1`0000070?ooo`8000001`3oool30000
00D0oooo3P0000050?ooo`8000000`3oool4000000D0oooo2P0000020?ooo`D00000BP3ooolG0=7=
Z@005@3AcJU=0?ooo`T000000`3oool7000000L0oooo0P0000070?ooo`<000001@3oool>000000D0
oooo0P0000030?ooo`@000001@3oool:00000080oooo1@00001:0?oooaL0dLfY000E0=7=ZDl0oooo
0P0000050?ooo`D000001@3oool9000000<0oooo1`0000020?ooo`D000001@3oool2000000D0oooo
1`0000030?ooo`8000002@3oool3000000D0oooo1000001=0?oooaL0dLfY000E0=7=ZDl0oooo0P00
00050?ooo`D000001@3oool9000000<0oooo1`0000020?ooo`D000001@3oool2000000D0oooo1`00
00030?ooo`8000002@3oool3000000D0oooo1000001=0?oooaL0dLfY000E0=7=ZE40oooo20000009
0?ooo`8000001@3oool5000000D0oooo1@0000090?ooo`L000001@3oool500000080oooo2P000002
0?ooo`D00000C`3ooolG0=7=Z@005@3AcJUA0?ooo`P000002@3oool2000000D0oooo1@0000050?oo
o`D000002@3oool7000000D0oooo1@0000020?ooo`X000000P3oool5000004l0oooo5`3AcJT001D0
dLfYD@3oool8000000T0oooo0P0000050?ooo`D000001@3oool5000000T0oooo1`0000050?ooo`D0
00000P3oool:00000080oooo1@00001?0?oooaL0dLfY000E0=7=ZE@0oooo0P00000>0?ooo`P00000
2@3oool300000080oooo2P0000040?ooo`P000001`3oool2000000D0oooo1@00001A0?oooaL0dLfY
000E0=7=ZE@0oooo0P00000>0?ooo`P000002@3oool300000080oooo2P0000040?ooo`P000001`3o
ool2000000D0oooo1@00001A0?oooaL0dLfY000E0=7=ZEH0oooo4@0000050?ooo``000000P3oool2
000000D0oooo0`0000020?ooo`D000001@3oool900000080oooo1@00001D0?oooaL0dLfY000E0=7=
ZEH0oooo4@0000050?ooo``000000P3oool2000000D0oooo0`0000020?ooo`D000001@3oool90000
0080oooo1@00001D0?oooaL0dLfY000E0=7=ZET0oooo0P0000050?ooo`8000001@3oool7000000D0
oooo0P0000070?ooo`P000000P3oool2000000X0oooo0P0000050?ooo`D00000EP3ooolG0=7=Z@00
5@3AcJUI0?ooo`8000001@3oool2000000D0oooo1`0000050?ooo`8000001`3oool800000080oooo
0P00000:0?ooo`8000001@3oool5000005H0oooo5`3AcJT001D0dLfYF@3oool2000000D0oooo0P00
00050?ooo`L000001@3oool2000000L0oooo200000020?ooo`8000002P3oool2000000D0oooo1@00
001F0?oooaL0dLfY000E0=7=ZE/0oooo1`0000020?ooo`D000001@3oool7000000<0oooo1`000005
0?ooo`@000000`3oool9000000<0oooo1000001I0?oooaL0dLfY000E0=7=ZE/0oooo1`0000020?oo
o`D000001@3oool7000000<0oooo1`0000050?ooo`@000000`3oool9000000<0oooo1000001I0?oo
oaL0dLfY000E0=7=ZEd0oooo0`0000070?ooo`8000000`3oool4000000D0oooo1@0000050?ooo`L0
00001`3oool3000000@0oooo1@00001K0?oooaL0dLfY000E0=7=ZEd0oooo0`0000070?ooo`800000
0`3oool4000000D0oooo1@0000050?ooo`L000001`3oool3000000@0oooo1@00001K0?oooaL0dLfY
000E0=7=ZF00oooo2@0000030?ooo`8000002P3oool200000080oooo1@0000050?ooo`X000000P3o
ool5000005d0oooo5`3AcJT001D0dLfYH03oool9000000<0oooo0P00000:0?ooo`8000000P3oool5
000000D0oooo2P0000020?ooo`D00000G@3ooolG0=7=Z@005@3AcJUP0?ooo`T000000`3oool20000
00X0oooo0P0000020?ooo`D000001@3oool:00000080oooo1@00001M0?oooaL0dLfY000E0=7=ZF80
oooo0P0000050?ooo`D000000P3oool:00000080oooo0`0000090?ooo`<000001@3oool400000600
oooo5`3AcJT001D0dLfYHP3oool2000000D0oooo1@0000020?ooo`X000000P3oool3000000T0oooo
0`0000050?ooo`@00000H03ooolG0=7=Z@005@3AcJUT0?ooo`P000001`3oool2000000D0oooo1@00
00020?ooo`X000000P3oool500000680oooo5`3AcJT001D0dLfYI03oool8000000L0oooo0P000005
0?ooo`D000000P3oool:00000080oooo1@00001R0?oooaL0dLfY000E0=7=ZF@0oooo200000070?oo
o`8000001@3oool500000080oooo2P0000020?ooo`D00000HP3ooolG0=7=Z@005@3AcJUW0?ooo`80
0000303oool7000000P0oooo0P0000050?ooo`D00000I03ooolG0=7=Z@005@3AcJUW0?ooo`800000
303oool7000000P0oooo0P0000050?ooo`D00000I03ooolG0=7=Z@005@3AcJUY0?ooo`l00000103o
ool:00000080oooo1@00001W0?oooaL0dLfY000E0=7=ZFT0oooo3`0000040?ooo`X000000P3oool5
000006L0oooo5`3AcJT001D0dLfYK03oool2000000D0oooo0P00000:0?ooo`8000001@3oool50000
06T0oooo5`3AcJT001D0dLfYK03oool2000000D0oooo0P00000:0?ooo`8000001@3oool5000006T0
oooo5`3AcJT001D0dLfYK03oool2000000D0oooo0P00000:0?ooo`8000001@3oool5000006T0oooo
5`3AcJT001D0dLfYKP3oool7000000<0oooo2@0000030?ooo`@00000K03ooolG0=7=Z@005@3AcJU^
0?ooo`L000000`3oool9000000<0oooo1000001/0?oooaL0dLfY000E0=7=ZG00oooo0`0000070?oo
o`8000001@3oool5000006h0oooo5`3AcJT001D0dLfYL03oool3000000L0oooo0P0000050?ooo`D0
0000KP3ooolG0=7=Z@005@3AcJUc0?ooo`T000000`3oool500000700oooo5`3AcJT001D0dLfYL`3o
ool9000000<0oooo1@00001`0?oooaL0dLfY000E0=7=ZG<0oooo2@0000030?ooo`D00000L03ooolG
0=7=Z@005@3AcJUe0?ooo`<00000103oool5000007<0oooo5`3AcJT001D0dLfYM@3oool3000000@0
oooo1@00001c0?oooaL0dLfY000E0=7=ZGP0oooo1`00001e0?oooaL0dLfY000E0=7=ZGP0oooo1`00
001e0?oooaL0dLfY000E0=7=ZGP0oooo1`00001e0?oooaL0dLfY000E0=7=ZGX0oooo0P00001h0?oo
oaL0dLfY000E0=7=ZGX0oooo0P00001h0?oooaL0dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o
0=7=ZB40dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o
0=7=ZB40dLfY003o0=7=ZB40dLfY001i0=7=Z@9000000`3AcJT5@00000030=7=ZD000010000000=0
00000P3AcJT2@00000<0dLfY1D0000020=7=Z@9000000`3AcJT5@0000080dLfY0T00001k0=7=Z@00
N03AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@0000002
0=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003A
cJT0dLfY07P0dLfY001h0=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT00`3A
cJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY
0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00=000000=7=Z@3AcJT0N03AcJT007P0dLfY00A000000=7=Z@3AcJU00000103AcJT00d00
0000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@02
0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003A
cJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@1h0=7=Z@00N03AcJT014000000dLfY0=7=
ZD0000040=7=Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03
@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY
0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY07P0dLfY001i0=7=
Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=
Z@900000103AcJT2@00007/0dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {140.125, 0}} -> {-9.13688, -1.00027, \
0.419072, 0.419072}}]
}, Open  ]],

Cell["\<\
A close up on the previous CA displays a remarkable degree of complexity.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[showCA[2, cellularSpace[1001], rule4, 400, 100, 400, 600], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.49751 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00478377 0.0287983 0.00478377 [
[.5 1.51001 -26 0 ]
[.5 1.51001 26 12.875 ]
[ 0 0 0 0 ]
[ 1 1.49751 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.51001 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(01101010) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.49751 L
0 1.49751 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0288 translate
.96154 1.43991 scale
201 string
201 301 8 [201 0 0 301 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000000000FFFFFFFF000000000000FFFF0000FFFFFFFFFFFF0000FF0000FFFFFF0000
FF00FF000000FF0000FFFFFFFFFF0000FF0000FF000000FF00FFFF000000FF00000000FF
FFFF00000000FFFFFFFFFF00000000FFFF0000FFFFFFFF00FFFF000000FFFFFFFF00FFFF
00FFFFFF0000FFFF00FFFF000000FF000000FF000000FF00FF00FFFFFFFF000000FF00FF
00000000FF0000FFFF0000FF00FFFF00FF00000000FFFF00FF0000FF00FFFFFF00000000
00FF00FFFF00FF000000FFFFFF00FFFFFFFF000000
0000FFFF00FFFFFFFFFFFF00FFFF00FFFFFFFF00FF000000000000FFFFFF00FF000000FF
FFFF0000FFFF0000FFFFFFFFFFFFFF00FF00FFFFFF00FFFFFF000000FFFF0000FFFF00FF
000000FFFF00FF0000000000FFFF00FF0000FFFFFFFFFFFF000000FFFF0000000000FF00
00FF000000FFFFFFFF000000FFFF0000FFFF0000FFFF0000FF00FF00000000FFFF0000FF
00FFFF00FF00FFFFFFFF00FF00FF0000FF00FFFF00FF0000FF00FFFFFF00000000FFFF00
FFFFFF000000FF00FFFF00000000FF00000000FFFF
FF00FF0000FF000000000000FF0000FF00000000FF00FFFF00FFFF00000000FF00FFFF00
000000FFFFFFFF00FF00000000000000FF00FF000000FF000000FFFF000000FFFFFFFF00
00FFFF000000FF00FFFF00FFFFFFFF0000FFFFFFFFFFFFFFFF00FFFFFFFF00FFFF00FF00
FFFFFF00FFFFFFFFFFFF00FFFFFFFF00FF0000FFFFFFFF00FF00FF00FFFF00FF0000FFFF
FF000000FF00FF00000000FF00FF00FFFFFF000000FF00FFFFFF00000000FFFF00FF0000
FF000000FFFF0000FF0000FFFF00FF00FFFF00FF00
0000FF00FFFFFF00FFFF00FFFFFF00FF00FFFF00FF00FF0000FF0000FFFF00FF00FF0000
FFFF00FF00000000FF00FFFF00FFFF00FF00FF00FFFF0000FFFF000000FFFF0000000000
FFFFFFFF00FFFFFF000000FF00000000FFFFFFFFFFFFFFFFFFFF0000000000FF0000FF00
FF000000FF000000000000FF00000000FF00FFFFFFFFFFFF0000FF00FF0000FF00FFFFFF
FFFF00FFFFFF0000FFFF00FF00FF00FF000000FFFF0000FF000000FFFF00FF0000FF00FF
FFFF00FFFFFFFF00FF00FFFFFFFF0000FF0000FF00
FF00FF00FF000000FF0000FF000000FF00FF0000FF00FF00FFFFFF00FF0000FF00FF00FF
FFFFFF0000FFFF00FF00FF0000FF0000FF00FF00FF0000FFFFFFFF00FFFFFFFF00FFFF00
FF00000000FF000000FFFF0000FFFF00FF00000000000000000000FFFF00FFFFFF00FF00
FF00FFFF0000FFFF00FFFF0000FFFF00FF00FF000000000000FFFFFF0000FFFFFF000000
000000FF000000FFFFFFFF0000FF00FF00FFFF000000FFFFFF00FFFFFFFF0000FFFFFF00
000000FF00000000FF00FF00000000FFFFFF00FF00
0000FF00FF00FFFF0000FFFFFF00FFFFFF0000FFFFFF0000FF000000FF00FFFFFF0000FF
00000000FFFFFFFF0000FF00FFFFFF00FF00FF00FF00FFFFFFFFFFFF0000000000FF0000
FF00FFFF00FF00FFFF000000FFFFFFFF0000FFFF00FFFF00FFFF00FF0000FF000000FF00
FF00FF0000FFFFFFFF000000FFFFFFFF0000FF00FFFF00FFFF00000000FFFFFFFFFF00FF
FF00FFFFFF00FFFFFFFFFFFF00FF00FF00FF0000FFFF00000000FF00000000FFFFFFFFFF
00FFFF0000FFFF00FF00FF00FFFF00FF000000FF00
FFFF0000FF00FF0000FFFFFFFFFF00000000FFFFFFFFFF00FF00FFFF0000FF000000FFFF
FF00FFFF0000000000FFFFFF00000000FF00FF00FF00FF000000000000FFFF00FFFFFF00
FF00FF0000FF00FF0000FFFF0000000000FFFFFFFF000000FF0000FF00FFFFFF00FFFFFF
0000FF00FFFFFFFFFFFF00FFFFFFFFFFFF00FF00FF0000FF0000FFFF00FF0000000000FF
0000FF000000FF000000000000FF00FF00FF00FFFFFFFF00FFFF0000FFFF00FF00000000
00FF0000FFFFFFFF0000FF00FF0000FF00FFFF0000
FFFFFF00FF00FF00FFFFFFFFFFFFFF00FFFF000000000000FF00FF0000FFFFFF00FFFFFF
FFFF000000FFFF00FFFFFFFFFF00FFFF0000FF00FF00FF00FFFF00FFFF000000FF000000
FF00FF00FFFFFF0000FFFFFFFF00FFFF00FF00000000FFFF0000FFFFFF00000000FF0000
00FFFFFF00000000000000FF000000000000FF00FF00FFFFFF00FF0000FF00FFFF00FFFF
FF00FF00FFFF0000FFFF00FFFF0000FF00FF00FF00000000FF0000FFFFFFFF0000FFFF00
FFFFFF00FF00000000FFFFFF0000FFFFFF000000FF
FFFFFFFF0000FF00FF00000000000000FF0000FFFF00FFFF0000FF00FFFFFFFFFF000000
000000FFFF000000FF0000000000FF0000FFFFFF0000FF00FF0000FF0000FFFF0000FFFF
0000FF00FF000000FFFFFFFFFFFF000000FF00FFFF00FF0000FFFFFFFFFF00FFFF0000FF
FF00000000FFFF00FFFF00FF00FFFF00FFFF0000FF00FF000000FF00FFFFFF000000FF00
0000FF00FF0000FFFFFFFF000000FFFFFF0000FF00FFFF00FF00FFFFFFFFFFFF00FF0000
FF000000FF00FFFF00FF000000FFFFFFFFFF00FFFF
0000000000FFFFFF0000FFFF00FFFF00FF00FFFFFFFF000000FFFFFF000000000000FFFF
00FFFF000000FFFF0000FFFF00FFFFFF00FF000000FFFFFF0000FFFFFF00FF0000FFFFFF
FF00FF00FF00FFFF00000000000000FFFF0000FF0000FF00FFFFFFFFFFFFFF000000FFFF
FFFF00FFFF000000FF0000FF00FF0000FF0000FFFFFF0000FFFF0000FF000000FFFF0000
FFFF0000FF00FFFFFFFFFFFF00FFFFFFFFFF00FF00FF0000FF00FF000000000000FF00FF
FFFF00FFFFFF000000FF00FFFF000000000000FF00
FFFF00FFFF00000000FFFFFFFF000000FF00FF00000000FFFF00000000FFFF00FFFF0000
00FF0000FFFF000000FFFFFFFF00000000FF00FFFF00000000FFFFFFFFFF0000FFFFFFFF
FFFF0000FF00FF0000FFFF00FFFF00FF0000FFFFFF00FF00FF00000000000000FFFF0000
000000FF0000FFFF0000FFFFFF0000FFFFFF00FF000000FFFFFFFF00FF00FFFF000000FF
FFFFFF00FF00FF000000000000FF0000000000FF00FF00FFFFFF0000FFFF00FFFF0000FF
000000FF000000FFFF0000FF0000FFFF00FFFF0000
FF0000FF0000FFFF00FF00000000FFFF0000FF00FFFF00FF0000FFFF00FF0000FF0000FF
FF0000FFFFFFFF00FFFFFFFFFFFF00FFFF0000FF0000FFFF00FF0000000000FFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFF000000FF00FFFFFFFFFF0000FF00FFFF00FFFF00FF0000FF
FF00FFFFFF00FF0000FFFFFFFFFF00FF000000FF00FFFF0000000000FF00FF0000FFFF00
00000000FF00FF00FFFF00FFFF0000FFFF00FFFFFF0000FF000000FFFFFFFF000000FFFF
FF00FFFFFF00FFFFFFFF00FF00FFFFFFFF000000FF
FF00FFFFFF00FF0000FF00FFFF00FF0000FFFFFF000000FF00FFFFFFFF0000FFFFFF00FF
0000FFFFFFFFFFFF00000000000000FF0000FFFFFF00FF0000FF00FFFF00FFFFFFFFFFFF
FFFFFFFF0000FF00FF00000000FFFF0000FF0000000000FFFFFF000000FF0000FF00FFFF
FFFF00000000FF00FFFFFFFFFFFFFF0000FFFF0000FF0000FFFF00FFFFFF0000FFFFFFFF
00FFFF00FF00FF00FF0000FF0000FFFFFFFF00000000FFFFFF00FFFFFFFFFFFF00FFFFFF
FFFF00000000FF00000000FF00FF00000000FFFF00
FF00FF000000FF00FFFFFF000000FF00FFFFFFFFFF00FFFFFF0000000000FFFFFFFFFF00
00FFFFFFFFFFFFFFFF00FFFF00FFFF0000FFFFFFFFFF0000FFFFFF000000FF0000000000
0000000000FFFFFF0000FFFF00FF0000FFFFFF00FFFF00FF000000FFFF0000FFFFFF0000
000000FFFF00FF00FF00000000000000FFFFFFFF00FF00FFFFFFFF00000000FFFFFFFFFF
FF000000FF00FF00FF00FFFFFF00FF00000000FFFF00FF000000FF000000000000FF0000
000000FFFF00FF00FFFF00FF00FF00FFFF00FF0000
0000FF00FFFF0000FF000000FFFF0000FF0000000000FF000000FFFF00FFFFFFFFFFFFFF
00FF0000000000000000FF0000FF0000FFFFFFFFFFFFFF00FF000000FFFF0000FFFF00FF
FF00FFFF00FF000000FFFFFFFF0000FFFFFFFFFF000000FF00FFFF000000FFFFFFFFFF00
FFFF00FF0000FF00FF00FFFF00FFFF00FF00000000FF00FF00000000FFFF00FF00000000
0000FFFF0000FF00FF00FF000000FF00FFFF00FF0000FF00FFFF0000FFFF00FFFF0000FF
FF00FFFFFFFF0000FF0000FF00FF00FF0000FF00FF
00FFFFFF000000FFFFFF00FFFFFFFF00FF00FFFF00FFFFFF00FFFFFFFF00000000000000
00FF00FFFF00FFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFF0000FFFF000000FFFFFFFF00
0000FF0000FF00FFFF0000000000FFFFFFFFFFFFFF00FFFFFF000000FFFF000000000000
FF0000FF00FFFFFF0000FF0000FF0000FF00FFFF00FF00FF00FFFF00FF0000FF00FFFF00
FFFF000000FFFFFF0000FF00FFFF0000FF0000FF00FFFFFF000000FFFFFFFF000000FFFF
FFFF0000000000FFFFFF00FF00FF00FF00FFFFFF00
00FF000000FFFF00000000FF00000000FF00FF0000FF000000FF00000000FFFF00FFFF00
FFFFFF000000FF0000FF000000FF00FF000000000000000000FFFFFFFF00FFFFFFFFFFFF
00FFFFFF00FF00FF0000FFFF00FFFFFFFFFFFFFFFFFF00000000FFFF000000FFFF00FFFF
0000FFFFFF00000000FFFFFF00FF00FFFFFF000000FF00FF00FF0000FF00FFFFFF000000
FF0000FFFF00000000FFFFFF000000FFFFFF00FF00FF000000FFFF0000000000FFFF0000
000000FFFF00FFFFFFFFFF0000FF00FF00FF000000
00FF00FFFF000000FFFF00FF00FFFF00FF00FF00FFFFFF00FFFFFF00FFFF000000FF0000
FF000000FFFF0000FFFFFF00FFFFFF0000FFFF00FFFF00FFFF0000000000FF0000000000
00FF000000FF00FF00FFFFFFFF00000000000000000000FFFF00FF0000FFFF000000FF00
00FFFFFFFFFF00FFFF00000000FF00FF000000FFFF0000FF00FF00FFFFFF00000000FFFF
0000FFFFFFFF00FFFF00000000FFFF00000000FF00FF00FFFF000000FFFF00FFFFFFFF00
FFFF00FF0000FF0000000000FFFFFF0000FF00FFFF
FFFFFF000000FFFF000000FF00FF0000FF00FF00FF000000FF000000FF0000FFFF0000FF
FFFF00FFFFFFFF00FF000000FF000000FFFFFFFF000000FF0000FFFF00FFFFFF00FFFF00
FFFFFF00FFFFFF0000FF00000000FFFF00FFFF00FFFF00FF0000FF00FFFFFFFF00FFFFFF
00FF0000000000FF0000FFFF00FF00FF00FFFF000000FFFFFF0000FF000000FFFF00FF00
00FFFFFFFFFFFF000000FFFF00FF0000FFFF00FF00FF00FF0000FFFF000000FF00000000
FF0000FF00FFFFFF00FFFF00FF000000FFFFFF0000
00000000FFFF000000FFFF0000FF00FFFFFF0000FF00FFFF0000FFFF0000FFFFFFFF00FF
000000FF00000000FF00FFFF0000FFFF0000000000FFFF0000FFFFFFFF00000000FF0000
FF000000FF000000FFFFFF00FFFF000000FF0000FF0000FF00FFFFFF0000000000FF0000
00FF00FFFF00FFFFFF00FF0000FF00FF00FF0000FFFF00000000FFFFFF00FFFFFFFF0000
FFFFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFF0000FF00FF00FFFFFFFF00FFFFFF00FFFF
0000FFFFFF00000000FF0000FF00FFFF00000000FF
00FFFF00FF0000FFFF000000FFFFFF00000000FFFFFF000000FFFFFFFF00FF00000000FF
00FFFF0000FFFF00FF00FF0000FFFFFFFF00FFFF00FF0000FFFFFFFFFFFF00FFFF0000FF
FFFF00FFFFFF00FFFFFFFFFF000000FFFF0000FFFFFF00FF00FF000000FFFF00FFFFFF00
FFFFFF000000FF000000FF00FFFFFF0000FF00FFFFFFFF00FFFF00000000FF00000000FF
FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF00FF00FF00FF00000000FF000000FF00
00FFFFFFFFFF00FFFF0000FFFFFF000000FFFF00FF
FFFFFFFF0000FFFFFFFF00FFFFFFFFFF00FFFF00000000FFFF0000000000FF00FFFF00FF
00FF0000FFFFFFFF0000FF00FFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFF000000FFFF
FFFFFF00000000FF0000000000FFFF000000FFFFFFFFFF0000FF00FFFF000000FF000000
FF000000FFFF0000FFFF0000FF000000FFFFFF0000000000FF0000FFFF00FF00FFFF00FF
00000000000000000000FFFF00FFFFFFFFFFFFFFFF0000FF00FF00FFFF00FF00FFFF0000
FFFFFFFFFFFFFF000000FFFFFFFFFF00FFFFFFFF00
0000000000FFFFFFFFFFFF000000000000FF0000FFFF00FF0000FFFF00FFFFFF000000FF
00FF00FFFFFFFFFFFF00FF00FF000000000000FFFF0000FF0000000000000000FFFF0000
00000000FFFF00FF00FFFF00FFFFFFFF00FFFFFFFFFFFFFF00FF00FF0000FFFF0000FFFF
0000FFFF000000FFFFFFFF00FF00FFFF00000000FFFF00FFFFFF00FF0000FF00FF0000FF
00FFFF00FFFF00FFFF00FF0000FF0000000000000000FFFFFF0000FF0000FF00FF0000FF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000000000
FF00FFFF00FF000000000000FFFF00FFFF0000FFFFFFFF0000FFFFFFFF00000000FFFF00
00FF00FF000000000000FF00FF00FFFF00FFFF000000FFFFFF00FFFF00FFFF00FF0000FF
FF00FFFF000000FF00FF0000FF00000000FF00000000000000FF00FF00FFFFFFFF00FF00
00FFFFFFFF00FFFFFFFFFFFF0000FF0000FFFF00FF0000FF000000FF00FFFFFF0000FFFF
FF000000FF0000FF0000FF00FFFFFF00FFFF00FFFF00FF000000FFFFFF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFF00FF
FFFF000000FF00FFFF00FFFF000000FF0000FFFFFFFFFFFF00FF00000000FFFF00FF0000
FFFFFF0000FFFF00FFFF0000FF00FF0000FF0000FFFF00000000FF0000FF0000FF00FFFF
FFFF000000FFFF0000FF00FFFFFF00FFFF0000FFFF00FFFF00FF00FF00FF00000000FF00
FFFFFFFFFFFF00000000000000FFFFFF00FF0000FF00FFFFFF00FFFFFF00000000FFFFFF
FFFF00FFFFFF00FF00FFFFFF00000000FF0000FF0000FF00FFFF00000000FF00FF00FF00
00000000000000000000FFFF00FFFF00FFFFFFFF00
FFFFFF00FFFFFF000000FF0000FFFF0000FFFFFFFFFFFFFFFF0000FFFF00FF0000FF00FF
FFFFFFFF00FF0000FF0000FFFFFF0000FFFFFF00FF0000FFFF00FF00FFFFFF00FF00FF00
000000FFFF000000FFFFFF00000000FF0000FFFFFFFF000000FF00FF00FF00FFFF00FF00
FF000000000000FFFF00FFFF00FF000000FF00FFFFFF00000000FF000000FFFF00FF0000
000000FF000000FF00FF000000FFFF00FF00FFFFFF00FF00FF0000FFFF00FF00FF00FF00
FFFF00FFFF00FFFF00FFFFFFFF000000FF00000000
00000000FF000000FFFF0000FFFFFFFF00FF0000000000000000FFFFFFFF0000FFFFFF00
0000000000FF00FFFFFF00FF000000FFFFFFFFFF0000FFFFFFFF0000FF000000FF00FF00
FFFF00FF0000FFFF00000000FFFF00FF00FFFFFFFFFFFF00FFFFFF0000FF00FF0000FF00
FF00FFFF00FFFF000000FF0000FF00FFFF0000FF000000FFFF00FF00FFFF000000FF00FF
FF00FFFFFF00FFFFFF0000FFFF000000FF00FF000000FF00FF00FFFFFFFF0000FF00FF00
FF0000FF0000FF0000FF00000000FFFF0000FFFF00
FFFF00FFFFFF00FFFFFFFF00FF00000000FF00FFFF00FFFF00FFFFFFFFFFFF00FF000000
FFFF00FFFF0000FF000000FF00FFFF000000000000FFFFFFFFFFFF00FF00FFFF0000FF00
FF0000FF00FFFFFFFF00FFFF000000FF00FF000000000000FF000000FFFFFF0000FFFFFF
0000FF0000FF0000FFFF0000FFFFFF000000FFFFFF00FFFFFFFF0000FF0000FFFF0000FF
0000FF000000FF000000FFFFFFFF00FFFFFF0000FFFF0000FF00FF00000000FFFFFF0000
FF00FFFFFF00FF00FFFFFF00FFFF000000FFFFFFFF
FF0000FF000000FF00000000FF00FFFF00FF00FF0000FF0000FF000000000000FF00FFFF
000000FF0000FFFFFF00FFFFFF000000FFFF00FFFF00000000000000FF00FF0000FFFFFF
0000FFFFFF0000000000FF0000FFFF0000FF00FFFF00FFFF0000FFFF00000000FFFFFFFF
FF00FF00FFFFFF00FF0000FFFFFFFFFF00FFFFFFFFFF0000000000FFFFFF00FF0000FFFF
FF00FF00FFFF0000FFFF0000000000FF000000FFFFFFFF00FF00FF00FFFF00FF000000FF
FFFF00000000FF00FF000000FF0000FFFF00000000
FF00FFFFFF00FFFFFF00FFFF0000FF0000FF00FF00FFFFFF00FF00FFFF00FFFF0000FF00
00FFFF0000FFFFFFFFFF00000000FFFF000000FF0000FFFF00FFFF00FF00FF00FFFFFFFF
FF00FF000000FFFF00FFFFFF00FF0000FFFFFF000000FF0000FFFFFFFF00FFFF00000000
0000FF00FF000000FF00FFFFFFFFFFFFFF000000000000FFFF00FFFFFFFFFF0000FFFFFF
FFFF0000FF0000FFFFFFFF00FFFF00FF00FFFF0000000000FF00FF00FF0000FF00FFFF00
000000FFFF00FF00FF00FFFF0000FFFFFFFF00FFFF
FF00FF000000FF000000FF0000FFFFFF00FF00FF00FF000000FF00FF0000FF0000FFFFFF
00FF0000FFFFFFFFFFFFFF00FFFF000000FFFF0000FFFFFFFF000000FF00FF00FF000000
0000FF00FFFF000000FF000000FF00FFFFFFFFFF00FFFFFF00FF00000000FF0000FFFF00
FFFF0000FF00FFFF0000FF00000000000000FFFF00FFFF000000FF0000000000FFFFFFFF
FFFFFF00FF00FFFFFFFFFFFF000000FF00FF0000FFFF00FFFFFF0000FF00FFFFFF000000
FFFF00FF0000FF00FF00FF0000FFFFFFFFFFFF0000
FF00FF00FFFF0000FFFF0000FFFFFFFFFF0000FF00FF00FFFF0000FF00FFFFFF00FF0000
00FF00FFFFFFFFFFFFFFFFFF000000FFFF000000FFFFFFFFFFFF00FFFFFF0000FF00FFFF
00FFFFFF000000FFFF0000FFFF0000FF0000000000FF000000FF00FFFF00FF00FFFFFFFF
000000FFFFFF000000FFFFFF00FFFF00FFFF000000FF0000FFFF0000FFFF00FFFFFFFFFF
FFFFFFFF0000FF000000000000FFFF0000FF00FFFFFFFF00000000FFFFFF00000000FFFF
000000FF00FFFFFF0000FF00FFFFFFFFFFFFFFFF00
FF00FF00FF0000FFFFFFFF00FF0000000000FFFFFF0000FF0000FFFFFF00000000FF00FF
FF0000FF000000000000000000FFFF000000FFFF00000000000000FF000000FFFFFF0000
00FF000000FFFF000000FFFFFFFF00FF00FFFF00FFFFFF00FFFFFF000000FF00FF000000
00FFFF00000000FFFF00000000FF0000FF0000FFFF0000FFFFFFFF00FF0000FF00000000
0000000000FFFFFF00FFFF00FFFFFFFF00FF00FF00000000FFFF00FF000000FFFF00FF00
00FFFF0000FF000000FFFFFF000000000000000000
FFFF0000FF00FFFFFFFFFFFF0000FFFF00FFFFFFFFFF00FF00FFFFFFFFFF00FFFF0000FF
0000FFFFFF00FFFF00FFFF00FFFFFFFF00FFFFFFFF00FFFF00FFFF0000FFFF00000000FF
FF0000FFFF000000FFFF0000000000FF00FF0000FF000000FF000000FFFF0000FF00FFFF
00FF0000FFFF00FF0000FFFF00FF00FFFFFF00FF0000FFFFFFFFFFFF0000FFFFFF00FFFF
00FFFF00FFFFFFFFFF000000FF00000000FF00FF00FFFF00FF0000FF00FFFF000000FF00
FFFFFFFF00FF00FFFF00000000FFFF00FFFF00FFFF
FFFFFF00FF00FF000000000000FFFFFFFF000000000000FF00FF0000000000FF0000FFFF
FF00FF000000FF0000FF0000FF00000000FF00000000FF0000FF0000FFFFFFFF00FFFF00
0000FFFFFFFF00FFFFFFFF00FFFF00FF00FF00FFFFFF00FFFFFF00FFFFFFFF00FF00FF00
00FF00FFFFFFFF0000FFFFFFFF0000FF000000FF00FFFFFFFFFFFFFFFF00FF000000FF00
00FF0000FF0000000000FFFF0000FFFF00FF00FF00FF0000FF00FFFFFF000000FFFF0000
FF00000000FF00FF0000FFFF00FF0000FF0000FF00
FFFFFFFF0000FF00FFFF00FFFF0000000000FFFF00FFFF0000FF00FFFF00FFFFFF00FF00
0000FF00FFFF0000FFFFFF00FF00FFFF00FF00FFFF00FF00FFFFFF00FF00000000FF0000
FFFF0000000000FF00000000FF0000FF00FF00FF000000FF000000FF00000000FF00FF00
FFFFFF0000000000FFFFFFFFFFFF00FF00FFFF0000FF0000000000000000FF00FFFF0000
FFFFFF00FF00FFFF00FFFFFFFF00FF0000FF00FF00FF00FFFFFF00000000FFFF000000FF
FFFF00FFFF0000FF00FFFFFFFF0000FFFFFF00FF00
0000000000FFFFFF000000FF0000FFFF00FFFFFFFF000000FFFFFF000000FF000000FF00
FFFF0000FF0000FFFFFFFFFF0000FF0000FF00FF0000FF00FF000000FF00FFFF00FF00FF
FFFFFF00FFFF00FF00FFFF00FF00FFFFFF0000FF00FFFF0000FFFF0000FFFF00FF00FF00
FF000000FFFF00FFFFFFFFFFFFFFFF0000FF0000FFFFFF00FFFF00FFFF00FF00FF0000FF
FFFFFFFF0000FF0000FF00000000FF00FFFFFF0000FF00FF000000FFFF00FF0000FFFF00
000000FF0000FFFFFF0000000000FFFFFFFFFF0000
00FFFF00FFFFFFFFFF00FFFFFF00FF0000FF00000000FFFF00000000FFFF0000FFFF0000
FF0000FFFFFF00FF0000000000FFFFFF00FF00FF00FFFFFF0000FFFF0000FF0000FF00FF
00000000FF0000FF00FF0000FF00FF000000FFFFFF000000FFFFFFFF00FF0000FF00FF00
FF00FFFF000000FF0000000000000000FFFFFF00FF000000FF0000FF0000FF00FF00FFFF
FFFFFFFFFF00FF00FFFFFF00FFFF0000FF000000FFFFFF0000FFFF000000FF00FFFFFFFF
00FFFF0000FFFFFFFFFF00FFFF00FF0000000000FF
00FF0000FF0000000000FF000000FF00FFFFFF00FFFF000000FFFF00FF0000FFFFFFFF00
FF00FFFFFFFFFF0000FFFF00FFFFFFFFFF0000FF00FF000000FFFFFFFF00FF00FFFFFF00
00FFFF00FF00FFFFFF0000FFFFFF0000FFFF00000000FFFF0000000000FF00FFFFFF0000
FF00FF0000FFFF0000FFFF00FFFF00FFFFFFFFFF0000FFFF0000FFFFFF00FF00FF00FF00
000000000000FF00FF000000FF0000FFFFFF00FFFFFFFFFF00FF0000FFFF0000FF000000
00FF0000FFFFFFFFFFFFFF000000FF00FFFF00FFFF
FFFFFF00FF00FFFF00FFFFFF00FFFFFF00000000FF0000FFFF000000FF00FFFFFFFFFFFF
0000FF0000000000FFFFFFFF000000000000FFFFFF0000FFFF0000000000FF00FF000000
FFFFFFFF0000FF000000FFFFFFFFFF00FF0000FFFF00FF0000FFFF00FFFFFF00000000FF
FFFF0000FFFFFFFF00FF0000FF0000FF0000000000FFFFFFFF00FF000000FF00FF00FF00
FFFF00FFFF00FF00FF00FFFF0000FFFFFFFFFF000000000000FF00FFFFFFFF00FF00FFFF
00FF00FFFFFFFFFFFFFFFFFF00FFFFFF000000FF00
FF000000FF00FF0000FF000000FF000000FFFF00FF00FFFFFFFF00FFFFFF000000000000
00FFFFFF00FFFF00FF00000000FFFF00FFFF00000000FFFFFFFF00FFFF00FF00FF00FFFF
0000000000FFFFFF00FFFFFFFFFFFFFF0000FFFFFFFF0000FFFFFFFF00000000FFFF00FF
000000FFFFFFFFFFFF0000FFFFFF00FF00FFFF00FFFFFFFFFFFF0000FFFF0000FF00FF00
FF0000FF0000FF00FF00FF0000FFFFFFFFFFFFFF00FFFF00FFFFFF0000000000FF00FF00
00FF00FF000000000000000000FF000000FFFF0000
FF00FFFF0000FF00FFFFFF00FFFFFF00FFFFFFFF0000FF00000000FF000000FFFF00FFFF
00FF000000FF0000FF00FFFF00FF0000FF0000FFFF00FF00000000FF0000FF00FF00FF00
00FFFF00FFFFFFFFFF0000000000000000FFFFFFFFFFFF00FF00000000FFFF00FF0000FF
00FFFF00000000000000FFFFFFFFFF0000FF0000FF000000000000FFFFFFFF00FF00FF00
FF00FFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF000000FF000000FFFF00FFFFFF0000
FFFFFF0000FFFF00FFFF00FFFF0000FFFF000000FF
0000FF0000FFFFFF00000000FF000000FF00000000FFFFFF00FFFF0000FFFF000000FF00
00FF00FFFF0000FFFFFF000000FF00FFFFFF00FF0000FF00FFFF00FF00FFFFFF0000FF00
FFFFFFFF000000000000FFFF00FFFF00FFFFFFFFFFFFFFFF0000FFFF00FF0000FF00FFFF
FF000000FFFF00FFFF00FF0000000000FFFFFF00FF00FFFF00FFFF0000000000FF00FF00
FF00FF000000FF00FF00FF00FF000000000000000000FFFF0000FFFF000000FF000000FF
FFFFFFFF00FF0000FF0000FF0000FFFFFFFF00FFFF
00FFFFFF00FF000000FFFF00FF00FFFF0000FFFF00FF000000FF0000FFFFFFFF00FFFFFF
00FF00FF0000FFFFFFFFFF00FFFFFF00000000FF00FFFFFF000000FF00FF000000FFFFFF
0000000000FFFF00FFFF000000FF0000FF0000000000000000FFFFFFFF0000FFFFFF0000
0000FFFF000000FF0000FF00FFFF00FFFFFFFFFF0000FF0000FF0000FFFF00FFFFFF0000
FF00FF00FFFF0000FF00FF00FF00FFFF00FFFF00FFFF000000FFFFFFFF00FFFFFF00FFFF
FFFFFFFFFF0000FFFFFF00FF00FFFFFFFFFFFF0000
00FF000000FF00FFFF000000FF00FF0000FFFFFFFF0000FFFF0000FFFFFFFFFFFF000000
00FF00FF00FFFFFFFFFFFFFF00000000FFFF00FF00FF000000FFFF0000FF00FFFF000000
00FFFF00FFFFFFFF000000FFFF0000FFFFFF00FFFF00FFFF00FF00000000FFFFFFFFFF00
FFFF000000FFFF0000FFFFFF000000FF0000000000FFFFFF00FF00FFFFFFFF00000000FF
FFFF0000FF0000FFFFFF0000FF00FF0000FF0000FF0000FFFF0000000000FF000000FF00
000000000000FFFFFFFFFF0000FF000000000000FF
00FF00FFFF0000FF0000FFFF0000FF00FFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFF00FF
FF0000FF00FF00000000000000FFFF00FF0000FF00FF00FFFF000000FFFFFF000000FFFF
00FF0000FF00000000FFFF000000FFFFFFFFFF000000FF0000FF00FFFF00FF0000000000
FF0000FFFF000000FFFFFFFFFF00FFFFFF00FFFF00FF000000FF00FF00000000FFFF00FF
000000FFFFFF00FF000000FFFFFF0000FFFFFF00FF00FFFFFFFF00FFFF00FF00FFFF0000
FFFF00FFFF00FF0000000000FFFFFF00FFFF00FFFF
FFFFFF000000FFFFFF00FF0000FFFFFF00000000000000FF00FFFFFFFFFFFFFFFFFFFF00
0000FFFFFF0000FFFF00FFFF00FF0000FF00FFFFFF0000FF0000FFFF00000000FFFF0000
00FF00FFFFFF00FFFF000000FFFF000000000000FFFF0000FFFFFF000000FF00FFFF00FF
FFFF00FF0000FFFF000000000000FF000000FF0000FF00FFFF0000FF00FFFF00FF0000FF
00FFFF00000000FF00FFFF00000000FFFFFFFFFF0000FF00000000FF0000FF00FF0000FF
FFFFFF000000FF00FFFF00FFFFFFFFFF000000FF00
FF000000FFFF00000000FF00FFFFFFFFFF00FFFF00FFFF0000FF00000000000000000000
FFFF00000000FFFFFFFF000000FF00FFFFFF00000000FFFFFF00FF0000FFFF00FF0000FF
FF0000FF000000FF0000FFFF000000FFFF00FFFF000000FFFFFFFFFF00FFFFFF000000FF
000000FF00FFFFFFFF00FFFF00FFFFFF00FFFFFF00FF00FF0000FFFFFF000000FF00FFFF
FF000000FFFF00FF00FF0000FFFF00FF0000000000FFFFFF00FFFF0000FFFFFF0000FFFF
FFFFFFFF00FFFFFF000000FF0000000000FFFF0000
0000FFFF000000FFFF00FF00FF0000000000FF0000FF0000FFFFFF00FFFF00FFFF00FFFF
000000FFFF00FF00000000FFFF0000FF000000FFFF00FF000000FF00FFFFFFFF0000FFFF
FFFF00FF00FFFF0000FFFFFFFF00FFFFFFFF000000FFFF000000000000FF000000FFFF00
00FFFF0000FF00000000FF0000FF000000FF000000FF00FF00FFFFFFFFFF00FFFFFF0000
0000FFFF000000FF00FF00FFFFFFFF0000FFFF00FFFFFFFFFF000000FFFFFFFFFF00FF00
0000000000FF000000FFFF0000FFFF00FFFFFFFF00
00FFFFFFFF00FFFFFFFF0000FF00FFFF00FFFFFF00FF00FFFFFFFFFF000000FF0000FF00
00FFFF000000FF00FFFF00FF0000FFFFFF00FFFFFFFF0000FFFF0000FF00000000FFFFFF
FFFFFF0000FF0000FFFFFFFFFFFF0000000000FFFF000000FFFF00FFFF0000FFFF000000
FFFFFFFF00FF00FFFF00FF00FFFFFF00FFFFFF00FFFFFF0000FF0000000000FF000000FF
FF00FF0000FFFF0000FF00FF00000000FFFFFFFF000000000000FFFF000000000000FF00
FFFF00FFFF0000FFFF000000FFFFFFFF0000000000
FF0000000000FF00000000FFFFFF000000FF000000FF00FF0000000000FFFF0000FFFFFF
00FF0000FFFF0000FF0000FF00FFFFFFFFFF0000000000FFFFFFFF00FF00FFFF00FF0000
00000000FFFFFF00FF000000000000FFFF00FFFFFFFF00FFFFFFFF000000FFFFFFFF00FF
FFFFFFFFFF0000FF0000FF00FF000000FF000000FF000000FFFFFF00FFFF00FF00FFFF00
0000FF00FFFFFFFF00FF00FF00FFFF00FF00000000FFFF00FFFF000000FFFF00FFFF0000
FF0000FF0000FFFFFFFF00FFFFFFFFFFFF00FFFF00
0000FFFF00FFFFFF00FFFF00000000FFFF0000FFFF0000FF00FFFF00FFFFFFFF00FF0000
00FF00FFFFFFFF00FF00FFFFFF000000000000FFFF00FFFFFFFFFFFF0000FF0000FF00FF
FF00FFFF00000000FF00FFFF00FFFF000000FF00000000FF00000000FFFF0000000000FF
000000000000FFFFFF00FF00FF00FFFF0000FFFF0000FFFF00000000FF0000FF00FF0000
FFFF0000FF00000000FF00FF00FF0000FF00FFFF00FF0000FF0000FFFF000000FF0000FF
FFFF00FF00FFFFFFFFFFFF00000000000000FF0000
FFFF000000FF000000FF0000FFFF00FF0000FFFFFFFF00FF00FF0000FF00000000FF00FF
FF0000FF00000000FF00FF000000FFFF00FFFF000000FF000000000000FFFFFF00FF00FF
0000FF0000FFFF00FF00FF0000FF0000FFFF0000FFFF00FF00FFFF00FF0000FFFF00FFFF
FF00FFFF00FFFFFFFFFF0000FF00FF0000FFFFFFFF00FF0000FFFF00FF00FFFFFF0000FF
FFFFFF00FF00FFFF00FF00FF00FF00FFFFFF000000FF00FFFFFF00FF0000FFFF0000FFFF
FFFFFF0000FF000000000000FFFF00FFFF00FF00FF
FF0000FFFF0000FFFF0000FFFFFFFF0000FFFFFFFFFFFF0000FF00FFFFFF00FFFF0000FF
0000FFFFFF00FFFF0000FF00FFFF000000FF0000FFFF0000FFFF00FFFF00000000FF00FF
00FFFFFF00FF0000FF00FF00FFFFFF00FF0000FFFFFFFF0000FF0000FF00FFFFFFFF0000
0000FF0000FF0000000000FFFFFF0000FFFFFFFFFFFF0000FFFFFFFF0000FF000000FFFF
FFFFFFFF0000FF0000FF00FF00FF00FF000000FFFF0000FF000000FF00FFFFFFFF00FF00
00000000FFFFFF00FFFF00FFFFFFFF000000FF00FF
FF00FFFFFFFF00FF0000FFFFFFFFFFFF00FF000000000000FFFFFF00000000FF0000FFFF
FF00FF000000FF0000FFFFFF000000FFFF0000FFFFFFFF00FF0000FF0000FFFF00FF00FF
00FF000000FF00FFFFFF0000FF000000FF00FFFFFFFFFFFF00FF00FFFFFF0000000000FF
FF00FF00FFFFFF00FFFF00FF000000FFFFFFFFFFFFFFFF00FF00000000FFFFFF00FFFFFF
FFFFFFFFFF00FF00FFFFFF0000FF00FF00FFFF000000FFFFFF00FFFFFF0000000000FF00
FFFF00FFFFFFFFFF000000FF00000000FFFF0000FF
0000FF00000000FF00FFFFFFFFFFFFFFFF0000FFFF00FFFF00000000FFFF00FF00FFFFFF
FFFF0000FFFF0000FFFFFFFFFF00FFFFFFFF00FF00000000FF00FFFFFF00FF0000FF00FF
00FF00FFFF0000FF000000FFFFFF00FFFFFF00000000000000FF00FF000000FFFF00FFFF
FFFF0000FF000000FF0000FF00FFFF000000000000000000FF00FFFF00FF000000FF0000
000000000000FF00FF000000FFFFFF0000FF0000FFFF00000000FF000000FFFF00FFFFFF
000000FF0000000000FFFF0000FFFF00FF0000FFFF
00FFFFFF00FFFF0000FF0000000000000000FFFFFFFF000000FFFF00FF0000FF00FF0000
000000FFFFFFFF00FF0000000000FF00000000FF00FFFF00FF00FF000000FF00FFFFFF00
00FF00FF0000FFFFFF00FFFFFFFFFF00000000FFFF00FFFF00FF00FF00FFFF000000FF00
000000FFFFFF00FFFFFF00FF00FF0000FFFF00FFFF00FFFF0000FF0000FF00FFFF0000FF
FF00FFFF00FFFFFF0000FFFF00000000FFFFFF00FF0000FFFF00FF00FFFF000000FF0000
00FFFF0000FFFF00FFFFFFFF00FF0000FF00FFFFFF
00FF000000FF0000FFFFFF00FFFF00FFFF00FF00000000FFFF000000FF00FFFFFF0000FF
FF00FFFFFFFFFFFF0000FFFF00FFFFFF00FFFF0000FF0000FF00FF00FFFF0000FF000000
FFFFFF0000FFFFFFFFFF000000000000FFFF00FF0000FF0000FF00FF00FF0000FFFF0000
FFFF00FF000000FF000000FF00FF00FFFFFFFF000000FF0000FFFFFF00FF00FF0000FFFF
FFFF000000FF000000FFFFFFFF00FFFF00000000FF00FFFFFFFF0000FF0000FFFF0000FF
FF000000FFFFFFFF0000000000FF00FFFFFF000000
00FF00FFFF0000FFFFFFFFFF000000FF0000FF00FFFF00FF0000FFFF0000FF000000FFFF
FFFF00000000000000FFFFFFFF00000000FF0000FFFFFF00FF00FF00FF0000FFFFFF00FF
FFFFFFFF00FF0000000000FFFF00FFFF000000FF00FFFFFF00FF00FF00FF00FFFFFFFF00
FF0000FF00FFFF0000FFFF0000FF00FF00000000FFFF0000FFFFFFFFFF0000FF00FFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFF000000FFFF00FF00FF00000000FFFFFF00FF0000FFFF
FFFF00FFFFFFFFFFFF00FFFF00FF00FF000000FFFF
00FF00FF0000FFFFFFFFFFFFFF00FFFFFF00FF00FF0000FF00FFFFFFFF00FF00FFFF0000
000000FFFF00FFFF00FF00000000FFFF00FF00FFFFFFFFFF0000FF00FF00FFFFFFFFFF00
0000000000FF00FFFF00FFFFFFFF000000FFFF0000FF000000FF00FF00FF00FF00000000
FF00FFFFFF000000FFFFFFFF00FF00FF00FFFF00FF0000FFFFFFFFFFFFFF00FF00FF0000
00000000FF000000FF000000000000FFFF000000FF00FF00FFFF00FF000000FF00FFFFFF
FFFFFF00000000000000FF0000FF00FF00FFFF0000
00FF00FF00FFFFFFFFFFFFFFFFFF00000000FF00FF00FFFFFF0000000000FF00FF0000FF
FF00FFFFFFFF000000FF00FFFF00FF0000FF00FF0000000000FFFFFF0000FF0000000000
FFFF00FFFF0000FF0000FF00000000FFFF000000FFFFFF00FFFFFF0000FF00FF00FFFF00
FF00FF000000FFFF0000000000FF00FF00FF0000FF00FFFFFFFFFFFFFFFFFF0000FF00FF
FF00FFFF0000FFFF0000FFFF00FFFF000000FFFF0000FF00FF0000FF00FFFF0000FF0000
00000000FFFF00FFFF00FF00FFFFFF0000FF0000FF
FFFFFF0000FF000000000000000000FFFF00FF00FF00FF000000FFFF00FFFFFF0000FFFF
FFFF0000000000FFFF0000FF0000FF00FFFFFF0000FFFF00FFFFFFFFFF00FF00FFFF00FF
FFFFFF000000FFFFFF00FF00FFFF00FF0000FFFF00000000FF000000FFFFFF0000FF0000
FF00FF00FFFF000000FFFF00FFFFFF0000FF00FFFFFF00000000000000000000FFFFFF00
0000FF0000FFFFFFFF00FF0000FF0000FFFF000000FFFFFF0000FFFFFF000000FFFFFF00
FFFF00FFFFFFFF000000FF00FF000000FFFFFF00FF
00000000FFFFFF00FFFF00FFFF00FFFFFFFF0000FF00FF00FFFF000000FF000000FFFFFF
FFFFFF00FFFF00FF0000FFFFFF00FF00FF000000FFFFFFFF000000000000FF00FF0000FF
00000000FFFF00000000FF00FF0000FF00FFFFFFFF00FFFF0000FFFF00000000FFFFFF00
FF00FF00FF0000FFFF000000FF000000FFFFFF00000000FFFF00FFFF00FFFF00FF000000
FFFF0000FFFFFFFFFFFF0000FFFFFF00FF0000FFFF00000000FFFFFFFFFF00FFFFFFFFFF
000000FF00000000FFFF0000FF00FFFF00000000FF
00FFFF00FF000000FF0000FF0000FF00000000FFFFFF0000FF0000FFFF0000FFFF000000
00000000FF0000FF00FFFFFFFFFF0000FF00FFFF0000000000FFFF00FFFF0000FF00FFFF
FF00FFFF000000FFFF00FF00FF00FFFFFF0000000000FF0000FFFFFFFF00FFFF00000000
FF00FF00FF00FFFFFFFF00FFFFFF00FFFFFFFFFF00FFFF000000FF0000FF0000FF00FFFF
000000FFFFFFFFFFFFFFFF00FF000000FF00FFFFFFFF00FFFF000000000000FF00000000
00FFFF0000FFFF00FF0000FFFFFF000000FFFF00FF
FF000000FF00FFFF0000FFFFFF00FF00FFFF00FF000000FFFFFF00FF0000FFFFFFFF00FF
FF00FFFF0000FFFFFF000000000000FFFFFF000000FFFF00FFFFFFFF000000FFFFFF0000
0000FF0000FFFF000000FF00FF00FF000000FFFF00FFFFFF00FF00000000FF0000FFFF00
FF00FF00FF00FF00000000FF000000FF0000000000FF0000FFFF0000FFFFFF00FF00FF00
00FFFF000000000000000000FF00FFFF0000FF00000000FF0000FFFF00FFFF0000FFFF00
FFFFFFFF00FF0000FF00FFFFFFFFFF00FFFFFFFF00
FFFF00FFFFFF000000FFFFFFFFFF0000FF0000FF00FFFF00000000FF00FFFFFFFFFFFF00
0000FF0000FFFFFFFFFF00FFFF00FFFFFFFFFF00FFFFFFFF0000000000FFFF00000000FF
FF00FF00FFFFFFFF00FFFFFF0000FF00FFFF000000FF000000FF00FFFF00FF00FFFFFFFF
0000FF00FF00FF00FFFF00FF00FFFF0000FFFF00FFFFFF00FF0000FFFFFFFFFF0000FF00
FFFFFFFF00FFFF00FFFF00FFFFFF000000FFFFFF00FFFF0000FFFFFFFF000000FFFFFFFF
0000000000FF00FFFFFF000000000000FF00000000
FFFFFF00000000FFFF000000000000FFFFFF00FF00FF0000FFFF00FF00FF000000000000
FFFF0000FFFFFFFFFFFFFF000000FF0000000000FF00000000FFFF00FFFFFFFF00FFFF00
0000FF00FF00000000FF000000FFFFFF000000FFFF0000FFFF0000FF0000FF00FF000000
00FFFFFF0000FF00FF0000FF00FF0000FFFFFFFF00000000FF00FFFFFFFFFFFFFF00FF00
FF00000000FF0000FF0000FF000000FFFF00000000FF0000FFFFFFFFFFFF00FFFFFFFFFF
FF00FFFF00FF00FF000000FFFF00FFFF0000FFFF00
00000000FFFF00FF0000FFFF00FFFF00000000FF00FF00FFFFFFFF0000FF00FFFF00FFFF
000000FFFFFFFFFFFFFFFFFF00FFFFFF00FFFF00FF00FFFF00FF0000FF00000000FF0000
FFFF0000FF00FFFF00FF00FFFF00000000FFFF000000FFFFFFFF00FF00FFFFFF0000FFFF
00FF000000FFFFFF0000FFFFFF0000FFFFFFFFFFFF00FFFF0000FF00000000000000FF00
FF00FFFF00FF00FFFFFF00FF00FFFF000000FFFF00FF00FFFFFFFFFFFFFFFF0000000000
0000FF0000FF00FF00FFFF000000FF0000FFFFFFFF
FFFF00FFFFFFFF0000FFFFFFFF000000FFFF00FF00FF00FF00000000FFFFFF000000FF00
00FFFF00000000000000000000FF000000FF0000FF00FF0000FF00FFFFFF00FFFF0000FF
FFFFFF00FF00FF0000FF00FF0000FFFF00FF0000FFFF0000000000FF00FF000000FFFFFF
FF0000FFFF00000000FFFFFFFFFF00FF000000000000FF0000FFFFFF00FFFF00FFFF0000
FF00FF0000FF00FF000000FF00FF0000FFFF000000FF00FF0000000000000000FFFF00FF
FF00FF00FFFFFF0000FF0000FFFF0000FFFFFFFFFF
FF0000FF00000000FFFFFFFFFFFF00FFFFFFFF0000FF00FF00FFFF00FF000000FFFF0000
FFFFFFFF00FFFF00FFFF00FFFF0000FFFF0000FFFFFF0000FFFFFF00000000FF0000FFFF
FFFFFFFF0000FF00FFFFFF0000FFFFFFFF0000FFFFFFFF00FFFF00FF00FF00FFFF000000
0000FFFFFFFF00FFFF000000000000FF00FFFF00FFFF0000FFFFFFFFFF000000FF0000FF
FFFF0000FFFFFF0000FFFF0000FF00FFFFFFFF00FFFFFF0000FFFF00FFFF00FFFFFFFF00
0000FF00FF000000FFFFFF00FF0000FFFFFFFFFFFF
0000FFFFFF00FFFF00000000000000FF00000000FFFFFF0000FF0000FF00FFFF000000FF
FFFFFFFFFF000000FF0000FF0000FFFFFFFF00FF000000FFFFFFFFFF00FFFF0000FFFFFF
FFFFFFFFFF00FF00FF000000FFFFFFFFFFFF00FF00000000FF0000FF00FF00FF0000FFFF
00FFFFFFFFFFFF000000FFFF00FFFF0000FF0000FF0000FFFFFFFFFFFFFF00FFFFFF00FF
000000FFFFFFFFFF00FF0000FFFFFF0000000000FF000000FFFFFFFF000000FF00000000
FFFF0000FF00FFFF00000000FF00FFFFFFFFFFFFFF
00FFFFFFFFFF000000FFFF00FFFF00FF00FFFF00FF000000FFFFFF00FF00FF0000FFFF00
000000000000FFFF0000FFFFFF00FF00000000FF00FFFF000000000000FF0000FFFFFFFF
FFFFFFFFFFFF0000FF00FFFF00000000000000FF00FFFF00FF00FFFFFF0000FF00FFFFFF
FF00000000000000FFFF000000FF0000FFFFFF00FF00FFFFFFFFFFFFFFFFFF00000000FF
00FFFF000000000000FF00FFFFFFFFFF00FFFF00FF00FFFF0000000000FFFF0000FFFF00
FF0000FFFFFF000000FFFF00FF00FF000000000000
00FF0000000000FFFF000000FF0000FF00FF0000FF00FFFF00000000FF00FF00FFFFFFFF
00FFFF00FFFF000000FFFFFFFFFF0000FFFF00FF00FF0000FFFF00FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFF00FF00FF0000FFFF00FFFF00FF00FF0000FF00FF000000FFFFFF000000
0000FFFF00FFFF00FF0000FFFF0000FFFFFFFFFF0000FF000000000000000000FFFF00FF
00FF0000FFFF00FFFF0000FF0000000000FF0000FF00FF0000FFFF00FFFFFFFF00FF0000
FF00FFFFFFFFFF00FFFFFFFF0000FF00FFFF00FFFF
FF0000FFFF00FFFFFFFF00FFFFFF00FF00FF00FFFFFF000000FFFF00FF00FF00FF000000
00FF0000FF0000FFFF000000000000FFFFFFFF0000FF00FFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FF00FFFFFFFF000000FF00FF00FFFFFF0000FFFF00000000FFFF
00FFFFFFFF000000FF00FFFFFFFF00FF0000000000FFFFFF00FFFF00FFFF00FFFFFFFF00
00FF00FFFFFFFF000000FFFFFF00FFFF00FF00FFFFFF0000FFFFFFFF0000000000FF00FF
FFFF000000000000FF00000000FFFFFF000000FF00
0000FFFFFFFF0000000000FF000000FF00FF00FF000000FFFF000000FF00FF00FF00FFFF
00FF00FFFFFF00FF0000FFFF00FFFF0000000000FFFFFF0000000000FFFF000000000000
000000000000000000FFFFFF0000000000FFFF0000FF00FF000000FFFFFFFF00FFFF0000
00FF00000000FFFF0000FF00000000FF00FFFF00FFFFFFFFFF000000FF0000FF00000000
FFFFFF0000000000FFFF00000000FF0000FF00FF000000FFFFFFFFFFFF00FFFF00FF00FF
000000FFFF00FFFF0000FFFF00FF000000FFFF0000
00FFFFFFFFFFFF00FFFF00FF00FFFF0000FF00FF00FFFF000000FFFF0000FF00FF00FF00
00FF00FF000000FF00FFFFFFFF000000FFFF00FFFFFFFFFF00FFFF00FF0000FFFF00FFFF
00FFFF00FFFF00FFFF00000000FFFF00FFFFFFFF00FF00FF00FFFF0000000000FF0000FF
FF0000FFFF00FF0000FFFFFF00FFFF0000FF0000FF0000000000FFFF0000FFFFFF00FFFF
00000000FFFF00FFFFFFFF00FFFF0000FFFFFF0000FFFF00000000000000FF0000FF00FF
00FFFF000000FF0000FFFFFFFF0000FFFF000000FF
00FF000000000000FF0000FF00FF0000FFFFFF0000FF0000FFFF000000FFFFFF0000FF00
FFFFFF0000FFFF0000FF00000000FFFF000000FF0000000000FF0000FF00FFFFFFFF0000
00FF0000FF0000FF0000FFFF00FF0000FF00000000FF00FF00FF0000FFFF00FFFFFF00FF
0000FFFFFFFF0000FFFFFFFFFF000000FFFFFF00FF00FFFF00FFFFFFFF00FF000000FF00
00FFFF00FF0000FF00000000FF0000FFFFFFFFFF00FF0000FFFF00FFFF00FF00FFFFFF00
00FF0000FFFF0000FFFFFFFFFFFF00FF0000FFFF00
FFFFFF00FFFF00FFFFFF00FF00FF00FFFFFFFFFF00FF00FFFFFFFF00FFFFFFFFFF00FF00
FF000000FFFFFFFF00FF00FFFF00FF0000FFFF0000FFFF00FFFFFF00FF00FF00000000FF
FF0000FFFFFF00FF00FFFFFFFF0000FFFFFF00FFFF0000FF00FF00FFFFFFFF00000000FF
00FFFFFFFFFFFF00FF0000000000FFFF00000000FF00FF0000FF00000000FF00FFFF0000
FFFFFFFF0000FFFFFF00FFFF0000FFFFFFFFFFFFFF0000FFFFFFFF000000FF00FF000000
FFFFFF00FF0000FFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFF000000FF000000FF00FF00FF0000000000FF00FF00000000FF0000000000FF00
FF00FFFF0000000000FF00FF0000FF00FFFFFFFF00FF0000FF000000FF00FF00FFFF00FF
0000FFFFFFFFFF0000FF00000000FFFFFFFFFF000000FFFFFF0000FF00000000FFFF00FF
00FF000000000000FF00FFFF00FFFFFFFF00FFFF0000FF00FFFFFF00FFFF0000FF0000FF
FFFFFFFFFF00FF000000FF0000FFFFFFFFFFFFFFFFFF00FF00000000FFFF0000FF00FFFF
00000000FF00FFFFFFFFFFFFFFFFFFFF00FF000000
0000000000FFFF0000FFFF0000FF00FF00FFFF00FFFFFF0000FFFF00FF00FFFF00FFFFFF
0000FF0000FFFF00FFFFFF0000FFFFFF0000000000FF00FFFFFF00FFFFFF0000FF0000FF
00FFFFFFFFFFFFFF00FF00FFFF00FF0000000000FFFF00000000FFFFFF00FFFF000000FF
00FF00FFFF00FFFF0000FF0000FF00000000FF0000FFFFFF00000000FF0000FFFFFF00FF
000000000000FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFF00FF0000FFFFFF0000
00FFFF00FF00FF00000000000000000000FF00FFFF
00FFFF00FFFFFFFF00FF0000FFFFFF0000FF0000FF000000FFFFFFFF0000FF0000FF0000
00FFFFFF00FF0000FF000000FFFFFFFFFF00FFFF00FF00FF000000FF000000FFFFFF00FF
00FF00000000000000FF00FF0000FF00FFFF00FFFFFFFF00FFFF00000000FF0000FFFF00
00FF00FF0000FF0000FFFFFF00FF00FFFF00FF00FFFFFFFFFF00FFFF0000FFFFFFFFFF00
00FFFF00FFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF00FFFFFFFFFF00
FFFFFFFF0000FF00FFFF00FFFF00FFFF00FF00FF00
FFFFFFFF0000000000FF00FFFFFFFFFF00FF00FFFFFF00FFFFFFFFFFFF00FF00FFFFFF00
FFFFFFFFFF0000FFFFFF00FFFFFFFFFFFFFF000000FF00FF00FFFF0000FFFF00000000FF
00FF00FFFF00FFFF00FF00FF00FFFFFF000000FF00000000FF0000FFFF00FF00FFFFFFFF
00FF00FF00FFFFFF00FF000000FF00FF0000FF00FF0000000000FF0000FFFFFFFFFFFFFF
00FF0000FF0000FFFFFF00FF00000000000000000000000000FF00FFFFFF000000000000
FF00000000FFFFFF000000FF0000FF0000FF00FF00
0000000000FFFF00FFFFFF000000000000FF00FF000000FF000000000000FF00FF000000
FF0000000000FFFFFFFFFF0000000000000000FFFF0000FF00FF0000FFFFFFFF00FFFF00
00FF00FF0000FF0000FF00FF00FF000000FFFF0000FFFF00FF00FFFFFFFF0000FF000000
00FF00FF00FF000000FF00FFFF0000FF00FFFFFF0000FFFF00FFFFFF00FF000000000000
00FF00FFFFFF00FF000000FF00FFFF00FFFF00FFFF00FFFF00FF00FF000000FFFF00FFFF
0000FFFF00FF000000FFFF0000FFFFFF00FF00FF00
00FFFF00FFFFFFFF00000000FFFF00FFFF0000FF00FFFF0000FFFF00FFFF0000FF00FFFF
0000FFFF00FFFFFFFFFFFFFF00FFFF00FFFF00FF0000FFFFFF0000FFFFFFFFFFFF000000
FFFFFF0000FFFFFF00FF00FF00FF00FFFF000000FFFFFFFF0000FF00000000FFFFFF00FF
FF0000FF00FF00FFFF0000FF0000FFFFFF00000000FFFFFFFF00000000FF00FFFF00FFFF
00FF00FF000000FF00FFFF0000FF0000FF0000FF0000FF0000FF00FF00FFFF000000FF00
00FFFFFFFF0000FFFF000000FFFFFFFFFF0000FF00
FF000000FF00000000FFFF00FF0000FF0000FFFFFF000000FFFFFFFF000000FFFFFF0000
00FFFFFFFF0000000000000000FF0000FF0000FF00FFFFFFFFFF00FF000000000000FFFF
00000000FFFFFFFFFF0000FF00FF00FF0000FFFF0000000000FFFFFF00FFFF00000000FF
0000FFFFFF0000FF0000FFFFFF00FF000000FFFF00FF00000000FFFF00FF00FF0000FF00
00FF00FF00FFFF0000FF0000FFFFFF00FF00FFFFFF00FF00FFFFFF0000FF0000FFFF0000
FFFFFFFFFFFF00FF0000FFFF000000000000FFFFFF
FFFF00FFFFFF00FFFF000000FF00FFFFFF00FF000000FFFF0000000000FFFF00000000FF
FF0000000000FFFF00FFFF00FFFFFF00FF00FFFFFF000000000000FF00FFFF00FFFF0000
00FFFF00FF0000000000FFFFFF0000FF00FFFFFFFF00FFFF00FF000000FF0000FFFF00FF
00FFFFFFFFFF00FF00FFFFFFFFFF0000FFFF000000FF00FFFF00FF0000FF00FF00FFFFFF
00FF00FF00FF0000FFFFFF00FF000000FF00FF000000FF00FF000000FFFFFF00FF0000FF
FFFFFFFFFFFFFF0000FFFFFFFF00FFFF00FFFFFFFF
000000FF000000FF0000FFFF0000FF000000FF00FFFF000000FFFF00FFFFFFFF00FFFF00
0000FFFF00FFFFFFFF000000FF000000FF00FF000000FFFF00FFFF0000FF0000FF0000FF
FF000000FF00FFFF00FFFFFFFFFF00FF00FF00000000FF0000FF00FFFF0000FFFFFFFF00
00FF0000000000FF00FF0000000000FFFFFFFF00FFFFFF000000FF00FFFFFF0000FF0000
00FF00FF00FF00FFFFFFFFFF0000FFFF0000FF00FFFF0000FF00FFFF00000000FF00FFFF
FFFFFFFFFFFFFFFF00FF00000000FF0000FF000000
FFFF00FF00FFFF0000FFFFFFFF00FF00FFFF0000FF0000FFFF000000FF00000000FF0000
FFFF000000FF00000000FFFF0000FFFF0000FF00FFFF000000FF0000FFFFFF00FF00FFFF
FFFF00FFFFFF000000FF0000000000FF00FF00FFFF00FF00FFFFFF000000FFFFFFFFFFFF
00FF00FFFF00FFFFFF0000FFFF00FFFFFFFFFFFF00000000FFFF0000FF000000FFFFFF00
FFFFFF0000FF00FF0000000000FFFFFFFF00FF00FF0000FFFFFF000000FFFF00FF00FF00
000000000000000000FF00FFFF00FF00FFFFFF00FF
FF0000FF00FF0000FFFFFFFFFFFF0000FF0000FFFFFF00FF0000FFFF0000FFFF00FF00FF
FFFFFF00FFFFFF00FFFF000000FFFFFFFF00FF00FF0000FFFF0000FFFFFFFFFF0000FF00
000000FF000000FFFF0000FFFF00FFFFFF0000FF0000FF00FF000000FFFF000000000000
00FF00FF0000FF000000FFFFFFFF00000000000000FFFF00FF0000FFFFFF00FFFFFFFFFF
00000000FFFFFF0000FFFF00FFFFFFFFFFFF0000FF00FFFFFFFFFF00FFFFFFFF0000FF00
FFFF00FFFF00FFFF00FF00FF0000FF00FF000000FF
FFFF00FF00FF00FFFFFFFFFFFFFFFF00FF00FFFFFFFFFF0000FFFFFFFF00FF0000FF00FF
00000000FF000000FF0000FFFF0000000000FF00FF00FFFFFFFF00FF0000000000FFFFFF
00FFFF0000FFFF000000FFFFFFFF00000000FFFFFF00FF00FF00FFFF000000FFFF00FFFF
00FF00FF00FFFFFF00FFFFFFFFFFFF00FFFF00FFFF000000FF00FFFFFFFFFF0000000000
00FFFF00FF000000FFFFFFFF00000000000000FFFFFF000000000000FF00000000FFFFFF
000000FF0000FF0000FF00FF00FFFFFF0000FFFF00
000000FF00FF00FF0000000000000000FF00FF0000000000FFFFFFFFFFFF0000FFFFFF00
00FFFF00FF00FFFF0000FFFFFFFF00FFFF00FF00FF00FF00000000FF00FFFF00FFFFFFFF
FF000000FFFFFFFF00FFFFFFFFFFFF00FFFF00000000FF00FF00FF0000FFFF000000FF00
00FF00FF00FF000000FF000000000000FF0000FF0000FFFF0000FF0000000000FFFF00FF
FF000000FF00FFFF0000000000FFFF00FFFF00FF000000FFFF00FFFF0000FFFF00FF0000
00FFFF0000FFFFFF00FF00FF00FF000000FFFFFFFF
00FFFF0000FF00FF00FFFF00FFFF00FFFFFF0000FFFF00FFFFFFFFFFFFFFFF00FF000000
FFFFFFFF0000FF0000FFFFFFFFFFFF000000FF00FF00FF00FFFF00FF00FF0000FF000000
0000FFFF0000000000FF000000000000FF0000FFFF00FF00FF00FF00FFFFFFFF00FFFFFF
00FF00FF00FF00FFFF0000FFFF00FFFF0000FFFFFF00FF0000FFFFFF00FFFF00FF0000FF
0000FFFF0000FF0000FFFF00FFFFFFFF000000FF00FFFF000000FF0000FFFFFFFF0000FF
FF000000FFFFFFFFFF0000FF00FF00FFFF00000000
FF000000FFFFFF0000FF0000FF0000FF000000FFFFFFFF000000000000000000FF00FFFF
0000000000FFFFFF00FF000000000000FFFF0000FF00FF00FF0000FF00FF00FFFFFF00FF
FF00FF0000FFFF00FFFFFF00FFFF00FFFFFF00FF0000FF00FF00FF00FF00000000FF0000
00FF00FF00FF00FF0000FFFFFFFF000000FFFFFFFFFF0000FFFFFFFFFF000000FF00FFFF
FF00FF0000FFFFFF00FF0000FF00000000FFFF0000FF0000FFFF0000FFFFFFFFFFFF00FF
0000FFFF000000000000FFFFFF0000FF0000FFFF00
FFFF00FFFFFFFFFF00FF00FFFFFF00FF00FFFF0000000000FFFF00FFFF00FFFF0000FF00
00FFFF00FFFFFFFFFF0000FFFF00FFFF000000FFFFFF0000FF00FFFFFF0000FF000000FF
0000FF00FFFFFFFF00000000FF0000FF000000FF00FFFFFF0000FF00FF00FFFF00FF00FF
FF0000FF00FF00FF00FFFFFFFFFFFF00FFFFFFFFFFFFFF00FF0000000000FFFF0000FF00
0000FF00FFFFFFFFFF0000FFFFFF00FFFF000000FFFFFF00FF0000FFFFFFFFFFFFFFFF00
00FFFFFFFF00FFFF00FFFFFFFFFF00FF00FFFFFFFF
000000FF0000000000FF00FF000000FF00FF0000FFFF00FFFFFFFF000000FF0000FFFFFF
00FF0000FF0000000000FFFFFFFF000000FFFF00000000FFFFFF00000000FFFFFF00FFFF
FF00FF00FF00000000FFFF00FF00FFFFFF00FFFFFF00000000FFFFFF0000FF0000FF00FF
0000FFFFFF0000FF00FF000000000000FF00000000000000FF00FFFF00FFFFFFFF00FF00
FFFF0000FF0000000000FFFFFFFFFF000000FFFF00000000FF00FFFFFFFFFFFFFFFFFFFF
00FF00000000FF0000FF0000000000FF00FF000000
00FFFF0000FFFF00FFFFFF0000FFFF0000FF00FFFFFFFF0000000000FFFF0000FFFFFFFF
FF0000FFFFFF00FFFF00FF00000000FFFF000000FFFF00FF000000FFFF00FF000000FF00
0000FF00FF00FFFF00FF0000FF00FF000000FF000000FFFF00FF000000FFFFFF00FF00FF
00FFFFFFFFFF00FF00FF00FFFF00FFFF0000FFFF00FFFF00FF00FF0000FF00000000FF00
FF0000FFFFFF00FFFF00FF0000000000FFFF000000FFFF00FF00FF000000000000000000
00FF00FFFF00FF00FFFFFF00FFFF00FF00FF00FFFF
00FF0000FFFFFFFF00000000FFFFFFFF00FF00FF00000000FFFF00FFFFFFFF00FF000000
0000FFFFFFFFFF000000FF00FFFF00FF0000FFFF000000FF00FFFF000000FF00FFFF0000
FFFF0000FF00FF0000FF00FFFFFF0000FFFF0000FFFF000000FF00FFFF00000000FF00FF
00FF0000000000FF00FF00FF0000FF0000FFFFFFFF000000FF00FF00FFFFFF00FFFF0000
FF00FFFFFFFFFF000000FF00FFFF00FFFFFFFF00FFFFFFFF0000FF00FFFF00FFFF00FFFF
00FF00FF0000FF00FF000000FF0000FF00FF00FF00
FFFFFF00FF00000000FFFF00FF00000000FF00FF00FFFF00FF0000FF00000000FF00FFFF
00FFFFFFFFFFFFFF00FFFFFF000000FF00FFFFFFFF00FFFFFF000000FFFF0000FF0000FF
FFFFFF00FF00FF00FFFFFF00000000FFFFFFFF00FF0000FFFF0000FF0000FFFF00FF00FF
00FF00FFFF00FFFFFF0000FF00FFFFFF00FF00000000FFFF0000FF00FF000000FF0000FF
FFFF000000000000FFFF0000FF0000FF00000000FF00000000FFFFFF000000FF0000FF00
00FF00FF00FFFFFF0000FFFF0000FFFFFF0000FF00
FF000000FF00FFFF00FF0000FF00FFFF00FF00FF00FF0000FF00FFFFFF00FFFF0000FF00
00FF00000000000000FF000000FFFF0000FF00000000FF000000FFFF000000FFFFFF00FF
00000000FF00FF00FF000000FFFF00FF00000000FF00FFFFFFFF00FF00FFFFFFFF0000FF
00FF00FF0000FF000000FFFFFF00000000FF00FFFF00FF0000FFFFFF0000FFFF0000FFFF
FFFFFF00FFFF00FFFFFFFF00FF00FFFFFF00FFFF0000FFFF00FF000000FFFF0000FFFFFF
00FF00FF00FF000000FFFFFFFF00FF000000FFFFFF
0000FFFF0000FF0000FF00FFFFFF000000FF00FF00FF00FFFFFF00000000FF0000FFFFFF
00FF00FFFF00FFFF00FF00FFFF000000FFFFFF00FFFF0000FFFF000000FFFF00000000FF
00FFFF00FF00FF00FF00FFFF000000FF00FFFF00FF00FF00000000FF00FF00000000FFFF
FF0000FF00FFFFFF00FFFFFFFFFF00FFFF0000FF0000FF00FFFFFFFFFF00FF0000FFFFFF
FFFFFFFF000000FF00000000FF00FF000000FF0000FFFFFFFF0000FFFF000000FFFFFFFF
FF0000FF00FF00FFFF0000000000FF00FFFF000000
00FFFFFFFF00FF00FFFFFF00000000FFFF0000FF00FF00FF000000FFFF00FF00FFFFFFFF
FF0000FF0000FF0000FF00FF0000FFFF00000000FF0000FFFFFFFF00FFFFFFFF00FFFF00
00FF0000FF00FF00FF00FF0000FFFF0000FF0000FF00FF00FFFF00FF00FF00FFFF00FF00
0000FFFFFF00000000FF0000000000FF0000FFFFFF00FF00FF0000000000FF00FFFFFFFF
FFFFFFFFFF00FFFFFF00FFFF0000FF00FFFF0000FFFFFFFFFFFF00FF0000FFFF00000000
0000FFFFFF0000FF0000FFFF00FFFFFF000000FFFF
FFFFFFFFFFFF0000FF000000FFFF00FF0000FFFFFF0000FF00FFFF000000FF00FF000000
0000FFFFFF00FF00FFFFFF0000FFFFFFFF00FFFF0000FFFFFFFFFFFF0000000000FF0000
FFFFFF00FF00FF00FF00FF00FFFFFFFF00FF00FFFFFF0000FF0000FF00FF00FF0000FF00
FFFF00000000FFFF00FF00FFFF00FFFFFF00FF000000FF00FF00FFFF00FFFFFF00000000
000000000000FF000000FF0000FFFFFF000000FFFFFFFFFFFFFFFF0000FFFFFFFF00FFFF
00FFFFFFFFFF00FF00FFFFFFFF00000000FFFF0000
FFFFFFFFFFFFFF00FF00FFFF000000FF00FFFFFFFFFF00FF00FF0000FFFF0000FF00FFFF
00FFFFFFFFFF0000FF000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFF00FFFF00FF00FF
FFFFFFFF0000FF00FF00FF00FF00000000FF00FF000000FFFFFF00FF00FF00FF00FFFFFF
000000FFFF00FF0000FF00FF0000FF000000FF00FFFF0000FF00FF0000FF000000FFFF00
FFFF00FFFF00FF00FFFF0000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FF00000000FF00
00FF0000000000FF00FF00000000FFFF00FF0000FF
0000000000000000FF00FF0000FFFF0000FF0000000000FF00FF00FFFFFFFF00FF00FF00
00FF0000000000FFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF000000FF00FF
0000000000FFFFFF0000FF00FF00FFFF00FF00FF00FFFF00000000FF00FF00FF00FF0000
00FFFF000000FF00FFFFFF0000FFFFFF00FFFFFF000000FFFFFF0000FFFFFF00FFFFFFFF
000000FF0000FF00FF0000FFFFFFFFFFFFFF0000000000000000000000FF00FFFF00FF00
FFFFFF00FFFF00FF00FF00FFFF00FF0000FF00FFFF
00FFFF00FFFF00FFFFFF0000FFFFFFFF00FF00FFFF00FFFFFF0000FF00000000FF00FF00
FFFFFF00FFFF00FF000000FF0000000000000000FF00000000000000000000FFFF0000FF
00FFFF00FFFFFFFFFF00FF00FF00FF0000FF00FF00FF0000FFFF00FF00FF00FF00FF00FF
FF000000FFFF0000FF000000FFFFFFFFFF00000000FFFF00000000FFFFFFFFFF00000000
00FFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFF00FF00FF0000FF00
FF000000FF0000FF00FF00FF0000FF00FFFFFF0000
00FF0000FF0000FF000000FFFFFFFFFFFF0000FF0000FF000000FFFFFF00FFFF0000FF00
FF000000FF0000FF00FFFF0000FFFF00FFFF00FFFFFF00FFFF00FFFF00FFFF000000FFFF
FF000000FF0000000000FF00FF00FF00FFFFFF0000FF00FFFFFFFF0000FF00FF00FF00FF
0000FFFF000000FFFFFF00FFFFFFFFFFFFFF00FFFF000000FFFF00FF0000000000FFFF00
FFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFF000000FF0000FF0000FF00FF00FFFFFF
0000FFFF0000FFFFFF0000FF00FFFFFF00000000FF
FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFFFFFF000000FFFFFF
0000FFFF0000FFFFFF000000FFFFFFFF000000FF000000FF0000FF0000FF0000FFFF0000
0000FFFF0000FFFF00FFFFFF0000FF00FF000000FFFFFF0000000000FFFFFF0000FF00FF
00FFFFFFFF00FFFFFFFFFF0000000000000000FF0000FFFF000000FF00FFFF00FFFFFFFF
0000000000FF00FFFF000000000000000000000000FFFF0000FFFFFF00FF00FF00FF0000
00FFFFFFFF00FF000000FFFFFF00000000FFFF00FF
FFFFFFFF0000FF000000FF0000000000000000FF00FF000000FF0000000000FFFF000000
00FFFFFFFF00FF000000FFFF0000000000FFFF0000FFFF0000FFFFFF00FF00FFFFFFFF00
FFFF000000FFFFFFFF00000000FFFFFF0000FFFF00000000FFFF00FFFFFFFFFF00FF00FF
00FF00000000FF0000000000FFFF00FFFF00FFFFFF00FF0000FFFF0000FF0000FF000000
00FFFF00FFFFFF000000FFFF00FFFF00FFFF00FFFF000000FFFFFFFFFF0000FF00FF00FF
FF0000000000FF00FFFF00000000FFFF00FF0000FF
0000000000FFFFFF00FFFFFF00FFFF00FFFF00FF00FF00FFFF0000FFFF00FFFFFFFF00FF
FF0000000000FF00FFFF000000FFFF00FFFFFFFF00FF0000FFFFFFFFFF0000FF00000000
FF0000FFFF0000000000FFFF00FF000000FFFFFFFF00FFFF000000FF0000000000FF00FF
00FF00FFFF00FF00FFFF00FFFFFFFF000000FF000000FF00FFFFFFFF00FF00FFFFFF00FF
FF000000FF000000FFFF000000FF0000FF0000FF0000FFFF000000000000FFFFFF0000FF
0000FFFF00FFFFFF000000FFFF00FF0000FF00FFFF
00FFFF00FFFFFFFFFF00000000FF0000FF0000FF00FF00FF0000FFFFFFFF0000000000FF
0000FFFF00FFFFFF000000FFFF000000FF00000000FF00FFFFFFFFFFFFFF00FF00FFFF00
FF00FFFFFFFF00FFFF00FF0000FF00FFFF0000000000FF0000FFFF0000FFFF00FFFFFF00
00FF00FF0000FF00FF0000FF00000000FFFF0000FFFF0000FF00000000FF00FF000000FF
0000FFFF0000FFFF000000FFFF0000FFFFFF00FF00FFFFFFFF00FFFF00FFFFFFFFFF00FF
00FFFFFFFF00000000FFFF000000FF00FFFFFF0000
00FF0000FF0000000000FFFF00FF00FFFFFF00FF00FF00FF00FFFFFFFFFFFF00FFFF00FF
00FFFFFFFF00000000FFFF000000FFFF0000FFFF00FF00FF00000000000000FF00FF0000
FF00FF00000000FF0000FF00FFFFFF000000FFFF00FFFFFF00FF0000FFFFFFFF00000000
FFFFFF0000FFFFFF0000FFFFFF00FFFF000000FFFFFFFF00FF00FFFF00FF00FF00FFFF00
00FFFFFFFF00FF0000FFFF000000FFFFFFFFFF0000FF00000000FF0000FF0000000000FF
00FF00000000FFFF00FF0000FFFF0000FF000000FF
FFFFFF00FF00FFFF00FFFFFFFF0000FF000000FF00FF00FF00FF000000000000FF0000FF
00FF00000000FFFF00FF0000FFFF000000FFFFFFFF0000FF00FFFF00FFFF00FF00FF00FF
FFFF0000FFFF00FF00FFFFFF00000000FFFF000000FF000000FF00FFFFFFFFFFFF00FFFF
00000000FFFFFFFFFF00FF000000FF0000FFFF0000000000FF00FF0000FF00FF00FF0000
FFFFFFFFFFFF0000FFFFFFFF00FFFFFFFFFFFFFF00FF00FFFF00FF00FFFFFF00FFFF00FF
00FF00FFFF00FF0000FF00FFFFFFFF00FF00FFFF00
00000000FF00FF0000FF00000000FFFFFF00FFFFFF0000FF00FF00FFFF00FFFF0000FFFF
FF0000FFFF00FF0000FF00FFFFFFFF00FFFFFFFFFFFF00FF00FF0000FF0000FF00FF00FF
000000FFFFFFFF0000FF000000FFFF00FF0000FFFF0000FFFF0000FF000000000000FF00
00FFFF00FF0000000000FF00FFFF0000FFFFFFFF00FFFF00FF00FF00FFFFFF0000FF00FF
FFFFFFFFFFFFFF00FF00000000FF00000000000000FF00FF0000FF00FF000000FF0000FF
00FF00FF0000FF00FFFFFF0000000000FF00FF0000
FF00FFFF0000FF00FFFFFF00FFFF00000000FF000000FFFFFF0000FF0000FF0000FFFFFF
FFFF00FF0000FF00FFFFFF0000000000FF000000000000FF00FF00FFFFFF00FF00FF00FF
00FFFF0000000000FFFFFF00FFFFFFFF0000FFFFFFFF00FF0000FFFFFF00FFFF00FFFFFF
00FF0000FF00FFFF00FFFFFF000000FFFFFFFFFFFF000000FF00FF00FF000000FFFFFF00
0000000000000000FF00FFFF00FF00FFFF00FFFF00FF00FF00FFFFFF0000FFFF0000FFFF
FF0000FF00FFFFFF00000000FFFF00FFFFFF0000FF
0000FF0000FFFFFF00000000FF0000FFFF00FF00FFFF00000000FFFFFF00FF00FFFFFFFF
FFFFFF0000FFFFFF00000000FFFF00FFFFFF00FFFF00FFFFFF0000FF000000FF00FF00FF
00FF0000FFFF00FFFFFFFFFF0000000000FFFFFFFFFFFF0000FFFFFFFFFF000000FF0000
00FF00FFFFFF000000FF000000FFFF00000000000000FFFF0000FF00FF00FFFF00000000
FFFF00FFFF00FFFF0000FF0000FF00FF0000FF0000FF00FF00FF000000FFFFFFFF00FF00
0000FFFFFF00000000FFFF00FF0000FF000000FFFF
FFFF0000FFFFFFFFFF00FFFF0000FFFFFFFF0000FF0000FFFF00FF000000FF00FF000000
00000000FFFFFFFFFF00FFFF000000FF000000FF0000FF000000FFFFFF00FFFFFF0000FF
00FF00FFFFFFFF000000000000FFFF00FFFFFFFFFFFFFFFF00FF0000000000FFFF0000FF
FF0000FF000000FFFF0000FFFF000000FFFF00FFFF00FF0000FFFFFF0000FF0000FFFF00
FF0000FF0000FF0000FFFFFF00FF00FF00FFFFFF00FF00FF00FF00FFFF0000000000FF00
FFFF00000000FFFF00FF0000FF00FFFFFF00FFFFFF
FF0000FFFFFFFFFFFFFF000000FFFFFFFFFFFF00FF00FFFFFFFF0000FFFF0000FF00FFFF
00FFFF00FF0000000000FF0000FFFF0000FFFF0000FFFFFF00FFFFFFFFFF00000000FFFF
FF0000FF00000000FFFF00FFFF000000FF0000000000000000FF00FFFF00FFFFFFFF00FF
0000FFFFFF00FFFFFFFF00FF0000FFFF000000FF0000FF00FFFFFFFFFF00FF00FFFFFFFF
0000FFFFFF00FF00FFFFFFFFFF0000FF00FF000000FF00FF00FF00FF0000FFFF00FFFFFF
000000FFFF00FF0000FF00FFFFFF00000000FF0000
FF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF0000FF00000000FFFFFFFF00FF00FF00
00FF0000FF00FFFF00FFFFFF00FF0000FFFFFFFF00FF000000FF0000000000FFFF00FF00
0000FFFFFF00FFFF000000FF0000FFFF0000FFFF00FFFF00FFFFFF000000FF00000000FF
00FFFFFFFFFF0000000000FF00FFFFFFFF00FFFFFF00FF00FF0000000000FF00FF000000
00FFFFFFFFFF0000FF0000000000FFFFFF0000FFFF0000FF00FF00FF00FFFFFFFF000000
00FFFF000000FF00FFFFFF00000000FFFF00FF00FF
0000FF000000000000000000FF0000000000000000FFFFFF00FFFF0000000000FF00FF00
FFFFFF00FF00FF0000FF000000FF00FFFFFFFFFFFF0000FFFF0000FFFF00FFFFFFFF0000
FFFF00000000FF0000FFFF0000FFFFFFFF00FF0000FF0000FF000000FFFF0000FFFF00FF
00FF0000000000FFFF00FFFFFF0000000000FF000000FF00FF00FFFF00FFFFFF0000FFFF
00FF0000000000FFFFFF00FFFF00FF000000FFFFFFFF00FF00FF00FF00FF00000000FFFF
00FF0000FFFF0000FF000000FFFF00FF0000FF00FF
00FFFFFF00FFFF00FFFF00FFFFFF00FFFF00FFFF00FF000000FF0000FFFF00FFFFFF0000
FF000000FF00FF00FFFFFF00FFFFFF00000000000000FFFFFFFF00FF0000FF00000000FF
FFFFFF00FFFF0000FFFFFFFF00FF00000000FF00FFFFFF00FF00FFFF000000FFFFFFFF00
00FF00FFFF00FFFFFFFF00000000FFFF00FFFFFF00FFFFFF0000FF0000FF000000FFFFFF
FF0000FFFF00FFFFFFFFFF000000FF00FFFF0000000000FF00FF00FF00FF00FFFF00FF00
00FF00FFFFFFFF00FF00FFFF000000FF00FFFFFF00
00FF000000FF0000FF0000FF000000FF0000FF0000FF00FFFF0000FFFFFFFF00000000FF
FFFF00FFFFFF0000FF000000FF000000FFFF00FFFF00FF00000000FF00FFFFFF00FFFF00
00000000FF0000FFFFFFFFFFFF0000FFFF00FF00FF000000FF00FF0000FFFF0000000000
FFFFFF000000FF00000000FFFF00FF0000FF000000FF000000FFFFFF00FF00FFFF000000
0000FFFFFFFF000000000000FFFF0000FF0000FFFF00FFFFFF0000FF00FF00FF0000FF00
FFFFFF0000000000FF00FF0000FFFF0000FF000000
00FF00FFFF0000FFFFFF00FF00FFFF0000FFFFFF00FF00FF0000FFFFFFFFFFFF00FFFF00
000000FF000000FFFFFF00FFFFFF00FFFFFFFF000000FF00FFFF00FF00FF000000FF0000
FFFF00FFFFFF00FF000000000000FFFFFFFF0000FF00FFFF0000FF00FFFFFFFF00FFFF00
FF000000FFFF0000FFFF00FF0000FF00FFFFFF00FFFFFF00FFFFFFFFFF0000FF0000FFFF
00FFFFFFFFFFFF00FFFF00FFFFFFFF00FF00FFFFFFFF00000000FFFFFF0000FF00FFFFFF
00000000FFFF00FFFFFF0000FFFFFFFF00FF00FFFF
FF0000FF0000FFFFFFFFFF0000FF0000FFFFFFFFFF0000FF00FFFFFFFFFFFFFFFF000000
FFFF00FF00FFFF00000000FF000000FF00000000FFFF0000FF0000FF00FF00FFFF0000FF
FFFFFF00000000FF00FFFF00FFFF0000000000FFFFFF000000FFFFFF0000000000FF0000
FF00FFFF000000FFFFFFFF0000FFFFFF00000000FF000000FF0000000000FFFFFF00FF00
00FF000000000000FF0000FF00000000FF00FF00000000FFFF00FF000000FFFFFF000000
00FFFF00FF0000FF000000FFFFFFFFFFFF0000FF00
FFFF00FF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FF00FF0000000000000000FFFF
000000FF00FF0000FFFF00FF00FFFF0000FFFF00FF0000FFFFFF00FF00FF00FF0000FFFF
FFFFFFFF00FFFF0000FF0000FF0000FFFF00FFFFFFFFFF00FFFFFFFFFF00FFFF00FF00FF
FFFF000000FFFF0000000000FFFFFFFFFF00FFFF0000FFFF0000FFFF00FFFFFFFFFF0000
FFFFFF00FFFF00FFFFFF00FF00FFFF00FF00FF00FFFF00FF0000FF00FFFF00000000FFFF
00FF0000FF00FFFFFF00FFFFFFFFFFFFFFFF00FF00
000000FF00FF00000000000000FF00FF00000000000000FF00FF00FFFF00FFFF00FFFFFF
FF00FFFFFF0000FFFFFFFF0000FF0000FFFFFFFF0000FFFFFFFFFF0000FF00FF00FFFFFF
FFFFFFFFFF000000FFFFFF00FF00FFFFFFFF000000000000FF0000000000FF0000FF00FF
000000FFFF000000FFFF00FFFFFFFFFFFFFF000000FFFFFFFF00FF0000FF0000000000FF
FFFFFFFF000000FF000000FF00FF0000FF00FF00FF0000FF00FFFFFF000000FFFF00FF00
00FF00FFFFFF00000000FF0000000000000000FF00
FF00FFFFFF0000FFFF00FFFF00FF00FF00FFFF00FFFF00FF00FF00FF0000FF0000FF0000
0000FF000000FFFFFFFFFFFF00FF00FFFFFFFFFFFF00FF0000000000FFFFFF0000FF0000
000000000000FFFF00000000FF00FF00000000FFFF00FFFF0000FFFF00FFFFFF00FF00FF
00FFFF000000FFFF000000FF00000000000000FFFF0000000000FF00FFFFFF00FFFF00FF
0000000000FFFF0000FFFF0000FF00FFFFFF0000FF00FFFFFF00000000FFFF000000FF00
FFFFFF00000000FFFF00FF00FFFF00FFFF00FFFFFF
FFFF00000000FFFFFFFF000000FF00FF00FF0000FF0000FF00FF00FF00FFFFFF00FF00FF
FF00FF00FFFF00000000000000FF00FF000000000000FF00FFFF00FFFFFFFFFF00FF00FF
FF00FFFF00FFFFFFFF00FFFF0000FF00FFFF00FF0000FF0000FFFFFFFF00000000FF00FF
00FF0000FFFF000000FFFF0000FFFF00FFFF00FF0000FFFF00FFFFFF00000000FF0000FF
00FFFF00FFFFFFFF00FF0000FFFFFF00000000FFFFFF00000000FFFF00FF0000FFFF0000
FF000000FFFF00FF0000FF00FF0000FF0000FF0000
000000FFFF00FF00000000FFFF0000FF00FF00FFFFFF00FF00FF00FF00FF000000FF00FF
0000FF00FF0000FFFF00FFFF00FF00FF00FFFF00FFFF0000FF0000FF0000000000FF00FF
0000FF0000FF00000000FF0000FFFFFF000000FF00FFFFFF00FF00000000FFFF00FF00FF
00FF00FFFFFFFF00FFFFFFFF00FF0000FF0000FF00FFFFFFFF00000000FFFF00FF00FFFF
FF000000FF00000000FF00FFFFFFFFFF00FFFF00000000FFFF00FF0000FF00FFFFFFFF00
FF00FFFF000000FF00FFFFFF0000FFFFFF00FF00FF
FFFF00FF0000FF00FFFF00FF0000FFFFFF0000FF000000FF00FF00FF00FF00FFFF0000FF
00FFFFFF0000FFFFFFFF000000FF00FF00FF0000FF0000FFFFFF00FF00FFFF00FFFFFF00
00FFFFFF00FF00FFFF00FF00FFFFFFFFFF00FFFFFF00000000FF00FFFF00FF0000FF00FF
00FF00FF00000000FF00000000FF00FFFFFF00FF00FF00000000FFFF00FF0000FF00FF00
0000FFFF0000FFFF00FF00FF0000000000FF0000FFFF00FF0000FF00FFFFFF0000000000
FF00FF0000FFFF0000FF000000FFFFFFFFFF0000FF
FFFFFF0000FFFFFF000000FF00FFFFFFFFFF00FF00FFFF0000FF00FF00FF00FF0000FFFF
FF00000000FFFFFFFFFFFF00FFFFFF0000FF00FFFFFF00FF000000FF00FF0000FF000000
FFFFFFFFFF0000FF0000FF00FF0000000000FF000000FFFF00FF00FF0000FF00FFFFFF00
00FF00FF00FFFF00FF00FFFF00FF00FF000000FF00FF00FFFF00FF0000FF00FFFFFF0000
FFFF000000FFFFFFFF0000FF00FFFF00FFFFFF00FF0000FF00FFFFFF00000000FFFF00FF
FFFF0000FFFFFFFF00FF00FFFF000000000000FFFF
FFFFFFFF00FF000000FFFF0000FF0000000000FF00FF0000FFFFFF0000FF00FF00FFFFFF
FFFF00FFFF00000000000000FF000000FFFFFF00000000FF00FFFF0000FF00FFFFFF00FF
FFFFFFFFFFFF00FF00FFFFFF0000FFFF00FFFFFF00FFFFFFFF0000FF00FFFFFF00000000
FFFFFF0000FF0000FF00FF0000FF00FF00FFFF0000FF00FF0000FF00FFFFFF00000000FF
FFFFFF00FFFFFFFFFFFF00FF00FF0000FF000000FF00FFFFFF00000000FFFF00FF0000FF
000000FFFFFFFFFFFF0000FF0000FFFF00FFFF0000
0000000000FF00FFFF000000FFFFFF00FFFF00FF00FF00FFFFFFFFFF00FF00FF00FF0000
000000FF0000FFFF00FFFF00FF00FFFF00000000FFFF00FF00FF0000FFFFFF00000000FF
00000000000000FF00FF000000FFFFFFFF00000000FF00000000FFFFFF00000000FFFF00
FF000000FFFFFF00FF00FF00FFFFFF0000FF0000FFFFFF0000FFFFFF00000000FFFF00FF
00000000FF000000000000FF00FF00FFFFFF00FFFFFF00000000FFFF00FF0000FF00FFFF
FF00FFFFFFFFFFFFFFFF00FF00FFFFFFFF000000FF
FFFF00FFFF0000FF0000FFFF00000000FF0000FF00FF00FF0000000000FF00FF00FF00FF
FF00FFFFFF00FF0000FF0000FF00FF0000FFFF00FF0000FF00FF00FFFFFFFFFF00FFFF00
00FFFF00FFFF00FF00FF00FFFF0000000000FFFF00FF00FFFF00FF000000FFFF00FF0000
FF00FFFF00000000FF00FF00FF000000FFFFFF00FF000000FFFFFFFFFF00FFFF000000FF
00FFFF00FF00FFFF00FFFF0000FF00FF000000FF000000FFFF00FF0000FF00FFFFFF0000
0000FF0000000000000000FF00FF00000000FFFF00
FF0000FF0000FFFFFF00FF0000FFFF00FF00FFFFFF0000FF00FFFF00FFFFFF0000FF00FF
0000FF000000FF00FFFFFF00FF00FF00FFFFFFFF0000FFFFFF0000FF0000000000FF0000
FFFFFFFF000000FF00FF00FF0000FFFF00FFFFFFFF0000FF0000FF00FFFF000000FF00FF
FFFF000000FFFF00FF00FF00FF00FFFF00000000FF00FFFF000000000000FF0000FFFF00
00FF0000FF00FF0000FF0000FFFFFF0000FFFF0000FFFF000000FF00FFFFFF00000000FF
FF00FF00FFFF00FFFF00FFFFFF0000FFFF00FF0000
0000FFFFFF00FF000000FF00FFFFFFFF0000FF000000FFFFFF000000FF000000FFFFFF00
00FFFFFF00FFFFFF00000000FF00FF00FF00000000FFFFFFFFFF00FF00FFFF00FFFFFF00
FF00000000FFFF0000FF00FF00FFFFFFFF0000000000FFFFFF00FF00FF0000FFFF0000FF
000000FFFF000000FF00FF00FF00FF0000FFFF00FF00FF0000FFFF00FFFF0000FFFFFFFF
00FF00FFFFFF0000FFFFFF00FF000000FFFFFFFF00FF0000FFFF0000FF000000FFFF00FF
0000FF00FF0000FF0000FF000000FFFFFFFF0000FF
00FFFFFFFFFF0000FFFF0000FF00000000FFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFF
00FF000000FF000000FFFF00FF00FF00FF00FFFF00FF0000000000FF00FF0000FF000000
FF00FFFF00FF0000FFFFFF0000FF00000000FFFF00FFFFFFFFFF0000FF00FFFFFFFF00FF
00FFFF000000FFFF0000FF00FF00FF00FFFFFFFF0000FF00FFFFFFFF000000FFFFFFFFFF
FF0000FF000000FFFFFFFFFF0000FFFF0000000000FF00FFFFFFFF00FF00FFFF000000FF
00FFFFFF0000FFFFFF00FF00FFFF0000000000FFFF
FF000000000000FFFFFFFF00FF00FFFF00FF000000FF0000000000FF000000FF00000000
00FF00FFFF0000FFFF000000FF00FF00FF00FF0000FF00FFFF00FFFFFF0000FFFFFF00FF
FFFF000000FF00FFFFFFFFFF00FF00FFFF00FF0000FF0000000000FFFFFF0000000000FF
00FF0000FFFF000000FFFFFF0000FF00FF00000000FFFFFF0000000000FFFF0000000000
0000FFFFFF00FFFFFFFFFFFFFF00FF0000FFFF00FFFFFF0000000000FF00FF0000FFFF00
00FF000000FFFFFFFFFF0000FF0000FFFF00FFFFFF
0000FFFF00FFFF0000000000FF00FF0000FF00FFFF0000FFFF00FFFFFF00FFFFFF00FFFF
00FF00FF0000FFFFFFFF00FFFFFF0000FF00FF00FFFFFF000000FF000000FFFFFFFFFF00
000000FFFF0000FF0000000000FF00FF0000FF00FFFFFF00FFFF00FF000000FFFF00FFFF
FF0000FFFFFFFF00FFFFFFFFFF00FF00FF00FFFF00FF000000FFFF00FFFFFFFF00FFFF00
FFFF00000000FF00000000000000FF00FFFFFFFF00000000FFFF00FFFFFF0000FFFFFFFF
00FF00FFFF000000000000FFFFFF00FF0000FF0000
00FFFFFFFF000000FFFF00FFFFFF0000FFFFFF000000FFFFFFFF00000000FF000000FF00
00FF00FF00FFFFFFFFFFFF00000000FFFFFF0000FF000000FFFF0000FFFF000000000000
FFFF00FF0000FFFFFF00FFFF00FF00FF00FFFFFF00000000FF0000FF00FFFF000000FF00
0000FFFFFFFFFFFF000000000000FF00FF00FF0000FF00FFFF000000FF00000000FF0000
FF0000FFFF00FF00FFFF00FFFF00FF00FF00000000FFFF00FF0000FF000000FFFFFFFFFF
FF0000FF0000FFFF00FFFF00000000FF00FFFFFF00
00FF00000000FFFF000000FF000000FFFFFFFFFF00FFFFFFFFFFFF00FFFF0000FFFF0000
FFFFFF0000FF000000000000FFFF00FF000000FFFFFF00FFFFFFFF00FF0000FFFF00FFFF
000000FF00FFFFFFFFFF000000FF00FF00FF000000FFFF00FF00FFFFFF000000FFFF0000
FFFF00000000000000FFFF00FFFF0000FF00FF00FFFFFF000000FFFF0000FFFF00FF00FF
FFFF00FF0000FF00FF0000FF0000FF00FF00FFFF00FF0000FF00FFFFFF00FFFFFFFFFFFF
FFFF00FF00FFFFFFFF000000FFFF00FF00FF000000
00FF00FFFF00FF0000FFFF0000FFFF000000000000FF000000000000FF0000FFFFFFFF00
FF000000FFFFFF00FFFF00FFFFFFFF0000FFFF00000000FF00000000FF00FFFFFFFF0000
00FFFF0000FF0000000000FFFF0000FF00FF00FFFF000000FF00FF000000FFFF000000FF
FFFFFF00FFFF00FFFF000000FF0000FFFFFF0000FF000000FFFF000000FFFFFFFF0000FF
000000FF00FFFFFF0000FFFFFF00FF00FF00FF0000FF00FFFFFF00000000FF0000000000
000000FF00FF00000000FFFF000000FF00FF00FFFF
00FF00FF0000FF00FFFFFFFF00FF0000FFFF00FFFF0000FFFF00FFFF0000FFFFFFFFFFFF
0000FFFF00000000FF0000FF00000000FFFFFFFF00FFFF0000FFFF00FF00FF00000000FF
FF000000FFFFFF00FFFF00FF0000FFFFFF0000FF0000FFFF0000FF00FFFF000000FFFF00
00000000FF0000FF0000FFFF0000FFFFFFFFFF00FF00FFFF000000FFFF0000000000FFFF
FF00FFFFFF00000000FFFFFFFFFF0000FF00FF00FFFFFF00000000FFFF00FF00FFFF00FF
FF00FFFFFF0000FFFF00FF0000FFFF0000FF00FF00
FFFFFF0000FFFFFF0000000000FF00FFFFFFFF000000FFFFFFFF000000FFFFFFFFFFFFFF
FF00FF0000FFFF00FF00FFFFFF00FFFF0000000000FF0000FFFFFFFF0000FF00FFFF00FF
0000FFFF00000000FF0000FF00FFFFFFFFFF00FF00FFFFFFFF00FF00FF0000FFFF000000
FFFF00FFFFFF00FF00FFFFFFFF00FF0000000000FF00FF0000FFFF000000FFFF00FFFFFF
FFFF00000000FFFF00FF0000000000FFFFFF0000FF000000FFFF00FF0000FF00FF0000FF
0000FF000000FFFFFFFF0000FFFFFFFF00FF00FF00
FFFFFFFF00FF000000FFFF00FFFFFF0000000000FFFF0000000000FFFF00000000000000
0000FF00FFFFFFFF0000FF000000FF0000FFFF00FFFFFF00FF00000000FFFFFF000000FF
00FFFFFFFF00FFFF0000FFFFFF000000000000FF00FF00000000FF00FF00FFFFFFFF00FF
FFFFFF00000000FF00FF00000000FF00FFFF00FFFFFF0000FFFFFFFF00FFFFFFFF000000
000000FFFF00FF0000FF00FFFF00FFFFFFFFFF00FF00FFFF000000FF00FFFFFF0000FFFF
FF00FF00FFFF0000000000FFFFFFFFFFFF0000FF00
0000000000FF00FFFF000000FF000000FFFF00FFFFFFFF00FFFF00FF0000FFFF00FFFF00
FFFF0000FF00000000FFFFFF00FFFFFF00FF0000FF000000FF00FFFF00FF000000FFFF00
00FF00000000FF0000FFFFFFFFFF00FFFF00FFFFFF0000FFFF00FF00FF00FF00000000FF
00000000FFFF00FF00FF00FFFF00FF00FF0000FF000000FFFFFFFFFFFF0000000000FFFF
00FFFF000000FF00FFFFFF000000FF0000000000FF00FF0000FFFF0000FF000000FFFFFF
FFFF0000FF0000FFFF00FFFFFFFFFFFFFFFF00FF00
00FFFF00FFFFFF000000FFFF0000FFFF000000FF00000000FF0000FF00FFFFFFFF000000
FF0000FFFFFF00FFFF00000000FF000000FF00FFFFFF00FFFFFF000000FF00FFFF000000
FFFFFF00FFFF0000FFFFFFFFFFFFFF000000FF000000FFFFFFFF0000FF00FF00FFFF00FF
00FFFF00FF0000FF00FF00FF0000FF00FF00FFFFFF00FFFFFFFFFFFFFFFF00FFFF00FF00
00FF0000FFFF0000FF000000FFFF0000FFFF00FFFFFF0000FFFFFFFF00FF00FFFF000000
000000FFFFFF00FF0000FF0000000000000000FF00
FFFFFFFF00000000FFFF000000FFFFFFFF00FFFFFF00FFFF0000FFFFFF0000000000FFFF
0000FFFFFFFFFF000000FFFF00FF00FFFF0000FF000000FF000000FFFF0000FF0000FFFF
00000000FF0000FFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF00FF00FF00FF0000FF
00FF0000FF00FFFFFF0000FF00FFFFFF0000FF000000FF0000000000000000FF0000FF00
FFFFFF00FF0000FFFFFF00FFFFFFFF00FF0000FF000000FFFFFFFFFFFF0000FF0000FFFF
00FFFF00000000FF00FFFFFF00FFFF00FFFF00FF00
0000000000FFFF00FF0000FFFF0000000000FF000000FF0000FFFFFFFFFF00FFFF00FF00
00FFFFFFFFFFFFFF00FFFFFFFF0000FF0000FFFFFF00FFFFFF00FFFFFFFF00FF00FFFFFF
FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFF00000000FF000000000000FF00FF00FF00FFFF
FF0000FFFFFF00000000FFFFFF00000000FFFFFF00FFFFFF00FFFF00FFFF00FF00FFFFFF
00000000FF00FFFFFFFFFF0000000000FF00FFFFFF00FFFFFFFFFFFFFFFF00FF00FFFFFF
FF000000FFFF00FF00FF000000FF0000FF0000FF00
00FFFF00FFFFFFFF0000FFFFFFFF00FFFF00FF00FFFF0000FFFFFFFFFFFFFF000000FF00
FFFFFFFFFFFFFFFFFF0000000000FFFFFF00FF000000FF000000FF00000000FF00FF0000
0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFF00FFFF0000FF00FF00FF00
0000FFFFFFFFFF00FFFF00000000FFFF00FF000000FF000000FF0000FF0000FF00FF0000
00FFFF00FF00FF0000000000FFFF00FFFFFF00000000FF0000000000000000FF00FF0000
0000FFFF000000FF00FF00FFFF0000FFFFFF00FF00
00FF0000FF00000000FFFFFFFFFFFF000000FF00FF0000FFFFFFFFFFFFFFFFFF00FFFFFF
00000000000000000000FFFF00FFFFFFFFFF0000FFFF0000FFFF0000FFFF00FF00FF00FF
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF000000FFFFFF0000FF00
FFFF000000000000FF0000FFFF00FF0000FF00FFFF0000FFFF0000FFFFFF00FF00FF00FF
FF000000FF00FF00FFFF00FFFFFFFF00000000FFFF00FF00FFFF00FFFF00FFFFFF0000FF
FF00FF0000FFFF0000FF00FF0000FFFFFFFFFF0000
00FF00FFFFFF00FFFF00000000000000FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFF000000
00FFFF00FFFF00FFFF00FF0000FF0000000000FFFFFFFF00FF0000FFFFFFFF0000FF00FF
0000FF00FF000000000000000000000000000000FFFF0000000000FFFF00000000FFFFFF
000000FFFF00FFFF0000FFFFFFFF0000FFFFFF000000FFFFFFFF00FF000000FF00FF00FF
0000FFFF0000FF00FF0000FF00000000FFFF00FF0000FF00FF0000FF0000FF000000FFFF
FFFF0000FFFFFFFF00FF00FF00FFFFFFFFFFFFFF00
FFFFFF00000000FF0000FFFF00FFFF00FF0000FFFFFF000000000000000000000000FFFF
00FF0000FF0000FF0000FF00FFFFFF00FFFF00FF00000000FF00FFFFFFFFFFFF00FF00FF
00FFFFFF0000FFFF00FFFF00FFFF00FFFF00FFFF000000FFFF00FFFFFFFF00FFFF000000
00FFFF000000FF0000FFFFFFFFFFFF00FF000000FFFF0000000000FF00FFFF0000FF00FF
00FFFFFFFF00FF00FF00FFFFFF00FFFF000000FF00FFFFFF0000FFFFFF00FF00FFFF0000
000000FFFFFFFFFFFF0000FF00FF00000000000000
00000000FFFF00FF00FFFFFFFF000000FF00FFFFFFFFFF00FFFF00FFFF00FFFF00FFFFFF
FF0000FFFFFF00FF00FFFFFF00000000FF0000FF00FFFF00FF00FF000000000000FF00FF
00FF000000FFFFFFFF000000FF0000FF0000FF0000FFFF000000FF00000000FF0000FFFF
00FF0000FFFF0000FFFFFFFFFFFFFFFF0000FFFF000000FFFF00FFFFFF000000FFFFFF00
00FF00000000FF00FF00FF000000FF0000FFFF0000FF000000FFFFFFFFFF0000FF0000FF
FF00FFFFFFFFFFFFFFFF00FF00FF00FFFF00FFFF00
00FFFF00FF0000FF00FF00000000FFFF0000FF0000000000FF0000FF0000FF0000FF0000
0000FFFFFFFFFF0000FF000000FFFF00FF00FFFFFF000000FF00FF00FFFF00FFFF0000FF
00FF00FFFF0000000000FFFF0000FFFFFF00FF00FFFFFFFF00FFFFFF00FFFF0000FFFFFF
FF0000FFFFFFFF00FF0000000000000000FFFFFFFF00FFFFFFFF00000000FFFF00000000
FFFFFF00FFFF0000FF00FF00FFFF0000FFFFFFFF00FF00FFFF000000000000FFFFFF00FF
0000FF0000000000000000FF00FF00FF0000FF0000
FFFFFFFF0000FFFFFF0000FFFF00FF0000FFFFFF00FFFF00FF00FFFFFF00FF00FFFFFF00
FFFF000000000000FFFFFF00FFFFFFFF0000FF000000FFFF0000FF00FF0000FF0000FFFF
FF0000FF0000FFFF00FFFFFFFF00FF000000FF00FF00000000FF000000FF0000FFFFFFFF
FFFF00FF00000000FF00FFFF00FFFF00FFFFFFFFFFFF0000000000FFFF00FF0000FFFF00
FF000000FF0000FFFFFF0000FF0000FFFFFFFFFFFF0000FF0000FFFF00FFFF00000000FF
00FFFFFF00FFFF00FFFF00FF00FF00FF00FFFFFF00
FF00000000FFFFFFFFFF00FF0000FF00FFFFFFFFFF000000FF00FF000000FF00FF000000
FF0000FFFF00FFFF00000000FF00000000FFFFFF00FFFFFFFF00FF00FF00FFFFFF00FF00
0000FFFFFF00FF0000FF00000000FF00FFFF0000FF00FFFF00FF00FFFF0000FFFFFFFFFF
FFFFFF0000FFFF00FF00FF0000FF0000FF000000000000FFFF00FFFFFFFF0000FFFFFFFF
0000FFFF0000FFFFFFFFFF00FF00FFFFFFFFFFFFFFFF00FF00FFFFFFFF000000FFFF00FF
00FF000000FF0000FF0000FF00FF00FF00FF000000
FFFF00FFFF000000000000FF00FFFFFF000000000000FFFF0000FF00FFFF0000FF00FFFF
0000FFFFFFFF000000FFFF00FF00FFFF00FF000000FF00000000FF00FF00FF000000FF00
FFFF00000000FF00FFFFFF00FFFF0000FF0000FFFFFF000000FF00FF0000FFFFFFFFFFFF
FFFFFFFF00FF0000FF00FF00FFFFFF00FF00FFFF00FFFF000000FF00000000FFFFFFFFFF
FF00FF0000FFFFFFFFFFFFFF0000FF0000000000000000FF00FF00000000FFFF000000FF
00FF00FFFF0000FFFFFF00FF00FF00FF00FF00FFFF
FFFFFF000000FFFF00FFFF0000FF000000FFFF00FFFF000000FFFFFF000000FFFFFF0000
00FFFFFFFFFFFF00FFFFFFFF0000FF0000FF00FFFF0000FFFF00FF00FF00FF00FFFF0000
FF0000FFFF00FF00FF000000FF0000FFFFFF00FF000000FFFF0000FF00FFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFF0000FF000000FF00FF0000FF0000FFFF0000FFFF00FF00000000
0000FF00FFFFFFFFFFFFFFFFFF00FF00FFFF00FFFF00FFFFFF0000FFFF00FF0000FFFF00
00FF00FF0000FFFFFFFFFF0000FF00FF00FF00FF00
00000000FFFF000000FF0000FFFFFF00FFFFFFFF000000FFFF00000000FFFF00000000FF
FF00000000000000FF00000000FFFFFF00FF00FF0000FFFFFFFF0000FF00FF00FF0000FF
FFFF00FF0000FF00FF00FFFF0000FFFFFFFFFF0000FFFF000000FFFFFF00000000000000
000000000000FFFFFFFFFF00FF00FFFF0000FF00FFFFFF00FF0000FFFFFFFF0000FFFF00
FFFF0000FF000000000000000000FF00FF0000FF0000FF000000FFFFFFFF0000FFFFFFFF
00FF00FF00FFFFFFFFFFFFFF00FF00FF00FF00FF00
FFFF00FFFFFFFF00FFFFFF00FF000000FF00000000FFFF000000FFFF00FF0000FFFF00FF
0000FFFF00FFFF00FF00FFFF00FF000000FF00FF00FFFFFFFFFFFF00FF00FF00FF00FFFF
FFFFFF0000FFFFFF0000FF0000FFFFFFFFFFFFFF00FF0000FFFF00000000FFFF00FFFF00
FFFF00FFFF00FF0000000000FF00FF0000FFFFFF00000000FF00FFFFFFFFFFFF00FF0000
FF0000FFFFFF00FFFF00FFFF00FFFFFF0000FFFFFF00FF00FFFF0000000000FFFFFFFFFF
FF0000FF00FF00000000000000FF00FF00FF00FF00
FF0000FF00000000FF000000FF00FFFF0000FFFF00FF0000FFFF000000FF00FFFFFFFF00
00FFFFFFFF000000FF00FF0000FF00FFFF0000FF00FF000000000000FF00FF00FF00FF00
00000000FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFF000000FF0000
FF0000FF0000FF00FFFF00FFFFFF0000FFFFFFFFFF00FFFF0000FF000000000000FF00FF
FFFF00FF000000FF0000FF0000FF000000FFFFFFFFFF0000FF0000FFFF00FFFFFFFFFFFF
FFFF00FF00FF00FFFF00FFFF00FF00FF00FF00FF00
FF00FFFFFF00FFFF0000FFFF0000FF0000FFFFFFFF0000FFFFFFFF00FFFFFF0000000000
FFFFFFFFFFFF00FFFFFF0000FFFFFF000000FFFFFF0000FFFF00FFFF0000FF00FF00FF00
FFFF00FFFFFFFFFFFFFF0000FF000000000000000000FFFFFFFFFFFF000000FFFF0000FF
FFFF00FF00FFFFFF000000FF000000FFFFFFFFFFFFFF000000FFFFFF00FFFF00FFFFFF00
000000FF00FFFF0000FFFFFF00FF00FFFF000000000000FFFFFF00FF0000FF0000000000
000000FF00FF00FF0000FF0000FF00FF00FF00FF00
FF00FF000000FF0000FFFFFFFF00FF00FFFFFFFFFFFF00FF00000000FF000000FFFF00FF
FFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFF00FF0000FF0000FFFFFF0000FF00
FF0000FF00000000000000FFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFF00FFFFFFFF00FF
000000FF00FF000000FFFF0000FFFF0000000000000000FFFF00000000FF0000FF000000
FFFF00FF00FF0000FFFFFFFFFF0000FF0000FFFF00FFFF00000000FF00FFFFFF00FFFF00
FFFF00FF00FF00FF00FFFFFF00FF00FF00FF00FF00
FF00FF00FFFF0000FFFFFFFFFFFF0000FF000000000000FF00FFFF00FF00FFFF000000FF
0000000000000000FFFF00FF0000000000FF0000000000FF00FFFFFF00FF000000FFFFFF
0000FFFFFF00FFFF00FFFF00000000FF0000FF0000FF0000000000000000FF00000000FF
00FFFF0000FF00FFFF000000FFFFFFFF00FFFF00FFFF00FF0000FFFF00FF00FFFFFF00FF
FFFFFF0000FF00FFFFFFFFFFFFFF00FF00FFFFFFFF000000FFFF00FF00FF000000FF0000
FF0000FF00FF00FF00FF000000FF00FF00FF00FF00
0000FF00FF0000FFFFFFFFFFFFFFFF00FF00FFFF00FFFF0000FF0000FF00FF0000FFFF00
00FFFF00FFFF00FFFFFFFF0000FFFF00FFFFFF00FFFF00FF00FF000000FF00FFFF000000
00FFFFFFFFFF000000FF0000FFFF00FF00FFFFFF00FF00FFFF00FFFF00FFFFFF00FFFF00
00FF0000FFFFFF000000FFFF0000000000FF0000FF0000FF00FFFFFFFF0000FF000000FF
00000000FFFFFF0000000000000000FF00FF00000000FFFF000000FF00FF00FFFF0000FF
FFFF00FF00FF00FF00FF00FFFF0000FF00FF00FF00
00FFFFFF0000FFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FFFFFF00FF00FF00FFFFFFFF
00FF0000FF0000FF00000000FFFFFFFF00000000FF0000FF00FF00FFFF0000FF0000FFFF
00FF0000000000FFFF0000FFFFFFFF0000FF000000FF00FF0000FF0000FF000000FF0000
FFFFFF00FF000000FFFF000000FFFF00FFFFFF00FF00FFFFFF0000000000FFFFFF00FFFF
FF00FFFF00000000FFFF00FFFF00FFFFFF0000FFFF00FF0000FFFF0000FF00FF0000FFFF
FFFFFF0000FF00FF00FF00FF0000FFFFFF0000FF00
FFFFFFFFFF00FF00000000000000000000FFFFFF00FF00FFFFFFFFFF0000FF00FF000000
00FF00FFFFFF00FF00FFFF00FF00000000FFFF00FF00FFFFFF0000FF0000FFFFFF00FF00
00FF00FFFF00FFFFFFFF00FF00000000FFFFFF00FFFFFF0000FFFFFF00FF00FFFF0000FF
FFFFFFFF0000FFFF000000FFFF000000FF000000FF00FF000000FFFF00FFFFFFFFFF0000
0000FF0000FFFF00FF0000FF0000FF000000FFFFFFFF0000FFFFFFFF00FF00FF00FFFFFF
FFFFFFFF00FF00FF00FF00FF00FFFFFFFFFF00FF00
000000000000FF00FFFF00FFFF00FFFF00FF000000FF00FF0000000000FFFFFF0000FFFF
00FF00FF000000FF00FF0000FF00FFFF00FF0000FF00FF000000FFFFFF00FF000000FF00
FFFFFF000000FF00000000FF00FFFF00FF000000FF000000FFFFFFFFFF0000FF0000FFFF
FFFFFFFFFF00FF0000FFFF000000FFFF0000FFFF0000FF00FFFF000000FF0000000000FF
FF00FF00FFFFFFFF0000FFFFFF00FF00FFFF0000000000FFFFFFFFFFFF0000FF00FF0000
0000000000FF00FF00FF00FF00FF0000000000FF00
00FFFF00FFFF0000FF0000FF0000FF0000FF00FFFF0000FF00FFFF00FFFFFFFFFF00FF00
00FF00FF00FFFF0000FF00FFFFFF000000FF00FFFFFF0000FFFF00000000FF00FFFF0000
FF000000FFFF0000FFFF00FF00FF0000FF00FFFF0000FFFF000000000000FFFFFF00FF00
000000000000FF00FFFFFFFF00FFFFFFFF00FF0000FFFFFF000000FFFF0000FFFF00FFFF
FFFF0000FF00000000FFFFFFFFFF0000FF0000FFFF00FFFFFFFFFFFFFFFF00FF00FF00FF
FF00FFFF00FF00FF00FF00FF00FF00FFFF00FFFFFF
FFFFFFFF000000FFFFFF00FF00FFFFFF00FF00FF0000FFFFFF000000FF0000000000FF00
FFFFFF0000FF0000FFFFFF00000000FFFF0000FF000000FFFFFFFF00FFFF0000FF0000FF
FFFF00FFFFFFFF00FF0000FF00FF00FFFFFF000000FFFFFFFF00FFFF00FFFFFFFFFF0000
FFFF00FFFF00FF00FF00000000FF00000000FF00FFFFFFFFFF00FFFFFFFF00FF0000FF00
000000FFFFFF00FFFF000000000000FFFFFF00FF0000FF0000000000000000FF00FF00FF
0000FF0000FF00FF00FF00FF00FF00FF0000FF0000
FF00000000FFFF00000000FF00FF000000FF00FF00FFFFFFFFFF00FFFFFF00FFFF00FF00
FF000000FFFFFF00FF000000FFFF00FF0000FFFFFF00FFFFFFFFFFFF000000FFFFFF00FF
000000FF00000000FF00FFFFFF0000FF000000FFFF0000000000FF0000FF0000000000FF
FFFFFF000000FF00FF00FFFF00FF00FFFF00FF00FF0000000000FF00000000FF00FFFFFF
00FFFF00000000FF0000FFFF00FFFF00000000FF00FFFFFF00FFFF00FFFF00FF00FF00FF
00FFFFFF00FF00FF00FF00FF00FF00FF00FFFFFF00
0000FFFF00FF0000FFFF00FF00FF00FFFF0000FF00FF0000000000FF000000FF0000FF00
FF00FFFF00000000FF00FFFF000000FF00FFFFFFFFFF00000000000000FFFF00000000FF
00FFFF0000FFFF00FF00FF000000FFFFFF00FFFFFFFF00FFFF00FF00FFFFFF00FFFF00FF
00000000FFFF0000FF00FF0000FF00FF0000FF00FF00FFFF00FFFFFF00FFFF0000FF0000
00FF0000FFFF00FF00FFFFFFFF000000FFFF00FF00FF000000FF0000FF0000FF00FF00FF
00FF000000FF00FF00FF00FF00FF00FF00FF000000
00FFFFFFFF0000FFFFFFFF0000FF00FF0000FFFFFF0000FFFF00FFFFFF00FFFFFF00FF00
FF00FF0000FFFF00FF00FF0000FFFF0000FF0000000000FFFF00FFFF00FF0000FFFF00FF
00FF0000FFFFFFFF0000FF00FFFF00000000FF00000000FF0000FF00FF000000FF0000FF
00FFFF00FF0000FFFFFF0000FFFFFF0000FFFFFF0000FF0000FF000000FF0000FFFFFF00
FFFFFF00FF0000FF00FF00000000FFFF000000FF00FF00FFFF0000FFFFFF00FF00FF00FF
00FF00FFFF0000FF00FF00FF00FF00FF00FF00FFFF
FF0000000000FFFFFFFFFFFF00FF00FF00FFFFFFFFFF00FF0000FF000000FF000000FF00
FF00FF00FFFFFFFF0000FF00FFFFFFFF00FF00FFFF00FFFFFFFF000000FF00FFFFFFFF00
00FF00FFFFFFFFFFFF00FF00FF0000FFFF00FF00FFFF00FF00FFFFFF0000FFFF0000FFFF
FF000000FF00FFFFFFFFFF00FF000000FFFFFFFFFF00FF00FFFFFF00FFFFFF00FF000000
FF000000FF00FFFFFF0000FFFF00FF0000FFFF0000FF00FF0000FFFFFFFFFF0000FF00FF
00FF00FF0000FFFFFF0000FF00FF00FF00FF00FF00
0000FFFF00FFFFFFFFFFFFFFFF0000FF00FF0000000000FF00FFFFFF00FFFFFF00FFFFFF
0000FF00FF00000000FFFFFF0000000000FF00FF0000FF00000000FFFF0000FF00000000
FFFFFF00000000000000FF00FF00FFFFFFFF0000FF0000FF00FF000000FFFFFFFF00FF00
0000FFFF0000FF0000000000FF00FFFF000000000000FF00FF000000FF000000FF00FFFF
0000FFFF0000FF000000FFFFFFFF0000FFFFFFFF00FF00FF00FFFFFFFFFFFFFF00FF00FF
00FF00FF00FFFFFFFFFF00FF00FF00FF00FF00FF00
FFFF000000FF0000000000000000FFFFFF0000FFFF00FFFFFF00000000FF000000FF0000
00FFFFFF0000FFFF00FF000000FFFF00FFFFFF0000FFFFFF00FFFF000000FFFFFF00FFFF
00000000FFFF00FFFF00FF00FF00FF00000000FFFFFF00FF00FF00FFFF0000000000FF00
FFFF000000FFFFFF00FFFF00FF00FF0000FFFF00FFFF0000FF00FFFF0000FFFF0000FF00
00FFFFFFFF00FF00FFFF0000000000FFFFFFFFFFFF0000FF00FF00000000000000FF00FF
00FF00FF00FF0000000000FF00FF00FF00FF00FF00
FF0000FFFF0000FFFF00FFFF00FFFFFFFFFF00FF0000FF000000FFFF00FF00FFFF0000FF
FF00000000FFFFFFFF0000FFFF000000FF000000FFFFFFFFFF000000FFFF00000000FF00
00FFFF00FF0000FF0000FF00FF00FF00FFFF00FF000000FF00FF00FF0000FFFF00FFFFFF
000000FFFF00000000FF0000FF00FF00FFFFFFFF000000FFFFFF000000FFFFFFFF00FF00
FFFFFFFFFFFF0000FF0000FFFF00FFFFFFFFFFFFFFFF00FF00FF00FFFF00FFFF00FF00FF
00FF00FF00FF00FFFF00FFFFFF0000FF00FF00FF00
FF00FFFFFFFF00FF0000FF0000FF0000000000FF00FFFFFF00FFFFFFFF0000FF0000FFFF
FFFF00FFFF0000000000FFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFFFF00FFFF0000
FFFFFFFF0000FFFFFF00FF00FF00FF00FF0000FF00FFFF0000FF00FF00FFFFFFFF000000
00FFFF000000FFFF00FF00FFFFFF0000FF00000000FFFF00000000FFFF0000000000FF00
FF000000000000FFFFFF00FF0000FF0000000000000000FF00FF00FF0000FF0000FF00FF
00FF00FF00FF00FF0000FF000000FFFFFF0000FF00
0000FF00000000FF00FFFFFF00FF00FFFF00FFFFFF00000000FF00000000FFFFFF00FF00
000000FF0000FFFF00FFFFFFFFFFFF00000000FF00000000000000FF00000000FF0000FF
FFFFFFFFFF00FF000000FF00FF00FF00FF00FFFFFF000000FFFFFF0000FF00000000FFFF
00FF0000FFFF000000FF00FF000000FFFFFF00FFFF000000FFFF00FF0000FFFF00FFFFFF
0000FFFF00FFFF00000000FF00FFFFFF00FFFF00FFFF00FF00FF00FF00FFFFFF00FF00FF
00FF00FF00FF00FF00FFFFFF00FFFFFFFFFF00FF00
00FFFFFF00FFFF0000FF000000FF00FF0000FF000000FFFF00FF00FFFF00FF000000FF00
FFFF00FF00FFFFFFFF00000000000000FFFF00FF00FFFF00FFFF00FF00FFFF00FF00FFFF
FFFFFFFFFFFF0000FFFF0000FF00FF00FF00FF000000FFFF00000000FFFFFF00FFFF0000
00FF00FFFFFFFF00FFFFFF0000FFFF00000000FF0000FFFF000000FF00FFFFFFFF000000
00FFFFFFFF000000FFFF00FF00FF000000FF0000FF0000FF00FF00FF00FF000000FF00FF
00FF00FF00FF00FF00FF000000FF0000000000FF00
FFFFFFFFFF000000FFFFFF00FFFFFF0000FFFFFF00FFFFFFFF0000FF0000FF00FFFF0000
FF0000FF00FF00000000FFFF00FFFF00FF0000FF00FF0000FF0000FF00FF0000FF00FF00
00000000000000FFFFFFFF00FF00FF00FF00FF00FFFF000000FFFF00FF000000FF0000FF
FF0000FF00000000FF000000FFFFFFFF00FFFF0000FFFFFFFF00FFFFFF0000000000FFFF
00FF00000000FFFF000000FF00FF00FFFF0000FFFFFF00FF00FF00FF00FF00FFFF0000FF
00FF00FF00FF00FF00FF00FFFF0000FFFF00FFFFFF
FFFFFFFFFFFF00FFFFFFFFFF00000000FFFFFFFFFF0000000000FFFFFF00FF00FF0000FF
FFFF00FF00FF00FFFF00FF0000FF0000FF00FFFFFF0000FFFFFF00FF00FF00FFFFFF0000
FFFF00FFFF00FFFFFFFFFFFF0000FF00FF00FF00FF0000FFFF000000FF00FFFF0000FFFF
FFFF00FF00FFFF00FF00FFFF0000000000FF0000FFFFFFFFFFFF00000000FFFF00FFFFFF
FF0000FFFF00FF0000FFFF0000FF00FF0000FFFFFFFFFF0000FF00FF00FF00FF0000FFFF
FF0000FF00FF00FF00FF00FF0000FFFFFFFF000000
FFFFFFFFFFFFFF000000000000FFFF00FF0000000000FFFF00FFFFFFFFFF0000FF00FFFF
FFFFFF0000FF00FF0000FF00FFFFFF00FF00FF000000FFFFFFFFFF0000FF00FF000000FF
FFFFFF000000FF000000000000FFFFFF0000FF00FF00FFFFFFFF00FFFFFF000000FFFFFF
FFFFFF0000FF0000FF00FF0000FFFF00FFFFFF00FF000000000000FFFF00FF0000FF0000
0000FFFFFFFF0000FFFFFFFF00FF00FF00FFFFFFFFFFFFFF00FF00FF00FF00FF00FFFFFF
FFFF00FF00FF00FF00FF00FF00FFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFF00FFFF00FFFFFFFF0000FFFF00FFFFFFFF000000000000FFFFFF0000
00000000FFFFFF0000FFFFFF00000000FF00FF00FFFF000000000000FFFFFF0000FFFF00
00000000FFFF0000FFFF00FFFF00000000FFFFFF0000FF00000000FF000000FFFF000000
00000000FFFFFF00FF00FF00FFFFFFFF00000000FF00FFFF00FFFF000000FF00FFFFFF00
FFFF0000000000FFFFFFFFFFFF0000FF00FF00000000000000FF00FF00FF00FF00FF0000
000000FF00FF00FF00FF00FF00FF000000000000FF
FFFFFFFFFFFFFFFFFF000000FF00000000FFFFFFFF0000000000FFFF00FFFF00000000FF
FF00FFFF00000000FFFFFFFFFF00FFFF0000FF00FF0000FFFF00FFFF00000000FFFFFFFF
00FFFF00FF0000FFFFFFFF000000FFFF00FF000000FFFFFF00FFFF0000FFFF000000FFFF
00FFFF00FF000000FF00FF00FF00000000FFFF00FF00FF0000FF0000FFFF0000FF000000
FF0000FFFF00FFFFFFFFFFFFFFFF00FF00FF00FFFF00FFFF00FF00FF00FF00FF00FF00FF
FF00FFFFFF0000FF00FF00FF00FF00FFFF00FFFF00
00000000000000000000FFFF0000FFFF00FF00000000FFFF00FFFFFFFF000000FFFF00FF
0000FF0000FFFF00FF0000000000FF0000FFFFFF0000FFFFFFFF000000FFFF00FF000000
00FF0000FF00FFFFFFFFFFFF00FFFFFFFF0000FFFF00000000FF0000FFFFFFFF00FFFFFF
FF000000FF00FFFF0000FF00FF00FFFF00FF0000FF00FF00FFFFFF00FF0000FFFFFF00FF
FFFF00FF0000FF0000000000000000FF00FF00FF0000FF0000FF00FF00FF00FF00FF00FF
0000FF000000FFFFFF0000FF00FF00FF0000FF0000
00FFFF00FFFF00FFFF00FF0000FFFFFFFF0000FFFF00FF0000FF00000000FFFF000000FF
00FFFFFF00FF0000FF00FFFF00FFFFFF00FF000000FFFFFFFFFFFF00FFFFFFFF0000FFFF
00FF00FFFFFF00000000000000FF00000000FFFFFFFF00FFFF0000FFFFFFFFFFFF000000
0000FFFF0000FF0000FFFFFF0000FF0000FF00FFFFFF0000FF000000FF00FFFFFFFFFF00
000000FF00FFFFFF00FFFF00FFFF00FF00FF00FF00FFFFFF00FF00FF00FF00FF00FF00FF
00FFFFFF00FFFFFFFFFF00FF00FF00FF00FFFFFF00
00FF0000FF0000FF0000FF00FFFFFFFFFFFF00FF0000FF00FFFFFF00FFFF000000FFFF00
00FF000000FF00FFFFFF000000FF000000FF00FFFF00000000000000FF00000000FFFFFF
FF0000FF000000FFFF00FFFF00FF00FFFF00FF00000000FF0000FFFFFFFFFFFFFFFF00FF
FF00FF0000FFFFFF00FF000000FFFFFF00FF00FF000000FFFFFF00FFFFFF000000000000
FFFF00FF00FF000000FF0000FF0000FF00FF00FF00FF000000FF00FF00FF00FF00FF00FF
00FF000000FF0000000000FF00FF00FF00FF000000
FFFFFF00FF00FFFFFF00FF00FF000000000000FF00FFFFFF00000000FF0000FFFF000000
FFFFFF00FFFFFF00000000FFFF0000FFFF0000FF0000FFFF00FFFF00FF00FFFF00FF0000
0000FFFFFF00FFFFFFFF000000FF00FF0000FF00FFFF00FF00FFFFFFFFFFFFFFFFFFFF00
0000FF00FFFFFFFFFF0000FFFF00000000FF00FF00FFFF00000000FF000000FFFF00FFFF
000000FF00FF00FFFF0000FFFFFF00FF00FF00FF00FF00FFFF0000FF00FF00FF00FF00FF
00FF00FFFF0000FFFF00FFFFFF0000FF00FF00FFFF
FF000000FF00FF000000FF00FF00FFFF00FFFF0000FF000000FFFF00FF00FFFFFFFF00FF
FFFFFFFF00000000FFFF00FF0000FFFFFFFF00FF00FFFFFFFF000000FF00FF0000FF00FF
FF00FF000000FF00000000FFFF0000FF00FFFFFF000000FF00FF00000000000000000000
FFFF0000FF0000000000FFFFFFFF00FFFF0000FF00FF0000FFFF00FF00FFFF000000FF00
00FFFF0000FF00FF0000FFFFFFFFFF0000FF00FF00FF00FF0000FFFFFF0000FF00FF00FF
00FF00FF0000FFFFFFFF00000000FFFFFF0000FF00
FFFF00FFFFFF0000FFFF0000FF00FF0000FF0000FFFFFF00FFFFFFFF0000FF00000000FF
0000000000FFFF00FF0000FF00FFFFFFFFFFFF0000FF00000000FFFF0000FF00FFFFFF00
0000FF00FFFF0000FFFF00FF0000FFFFFF00000000FFFF0000FF00FFFF00FFFF00FFFF00
FF0000FFFFFF00FFFF00FF00000000FF0000FFFFFF0000FFFFFFFF0000FF0000FFFF0000
FFFFFFFF00FF00FF00FFFFFFFFFFFFFF00FF00FF00FF00FF00FFFFFFFFFF00FF00FF00FF
00FF00FF00FFFFFFFFFFFF00FFFF00000000FFFFFF
000000FF000000FFFFFFFF00FF00FF00FFFFFF00FF000000FF00000000FFFFFF00FFFF00
00FFFF00FFFFFFFF0000FFFFFF00000000000000FFFFFF00FFFF000000FFFFFF00000000
FFFF0000FF0000FFFFFFFF0000FFFFFFFFFF00FFFF000000FFFFFF000000FF0000FF0000
FF00FFFFFFFFFF000000FF00FFFF00FF00FFFFFFFFFF00FF00000000FFFFFF00FF0000FF
FFFFFFFFFF0000FF00FF00000000000000FF00FF00FF00FF00FF0000000000FF00FF00FF
00FF00FF00FF000000000000FF0000FFFF00FF0000
FF00FFFFFF00FFFFFFFFFFFF0000FF00FF000000FF00FFFF0000FFFF00FF000000FF0000
FFFFFFFF0000000000FFFFFFFFFF00FFFF00FFFF00000000FF0000FFFF00000000FFFF00
FF0000FFFFFF00FF00000000FFFFFFFFFFFFFF000000FFFF00000000FFFF0000FFFFFF00
FF00FF0000000000FFFF0000FF0000FF00FF0000000000FF00FFFF00FF000000FF00FFFF
FFFFFFFFFFFF00FF00FF00FFFF00FFFF00FF00FF00FF00FF00FF00FFFF00FFFFFF0000FF
00FF00FF00FF00FFFF00FFFF0000FFFFFFFF0000FF
FFFF00000000FF000000000000FFFFFF0000FFFF0000FF0000FFFFFFFF0000FFFF0000FF
FFFFFFFFFF00FFFF00FF0000000000FF0000FF0000FFFF00FF00FFFFFFFF00FFFF000000
FF00FFFFFFFFFF0000FFFF00FF00000000000000FFFF000000FFFF00FF0000FFFFFFFFFF
0000FF00FFFF00FFFFFFFF00FF00FFFFFF0000FFFF00FFFFFF000000FF00FFFF0000FF00
00000000000000FF00FF00FF0000FF0000FF00FF00FF00FF00FF00FF0000FF000000FFFF
FF0000FF00FF00FF0000FF0000FFFFFFFFFFFF00FF
FFFFFF00FFFF0000FFFF00FFFF00000000FFFFFFFF00FF00FFFFFFFFFFFF00FF0000FFFF
FFFFFFFFFFFF000000FF00FFFF00FFFFFF00FF00FFFFFFFF0000FF00000000FF0000FFFF
0000FF0000000000FFFFFFFF0000FFFF00FFFF00FF0000FFFF000000FF00FFFFFFFFFFFF
FF00FF00FF0000FF00000000FF00FF000000FFFFFFFF00000000FFFF0000FF0000FFFFFF
00FFFF00FFFF00FF00FF00FF00FFFFFF00FF00FF00FF00FF00FF00FF00FFFFFF00FFFFFF
FFFF00FF00FF00FF00FFFFFF00FF000000000000FF
00000000FF0000FFFFFFFF000000FFFF00FF00000000FF00FF000000000000FF00FFFFFF
FFFFFFFFFFFFFF00FFFFFF000000FF000000FF00FF00000000FFFFFF00FFFF0000FFFFFF
FF00FF00FFFF00FFFFFFFFFFFF00FF0000FF0000FF00FFFFFFFF00FFFFFF000000000000
0000FF00FF00FFFFFF00FFFF0000FF00FFFF0000000000FFFF00FF0000FFFFFF00FF0000
00FF0000FF0000FF00FF00FF00FF000000FF00FF00FF00FF00FF00FF00FF000000FF0000
000000FF00FF00FF00FF000000FF00FFFF00FFFF00
00FFFF00FF00FFFFFFFFFFFF00FFFFFFFF0000FFFF00FF00FF00FFFF00FFFF0000FF0000
0000000000000000FF000000FFFF0000FFFF0000FF00FFFF00FF000000FF0000FFFFFFFF
FFFF0000FF0000FF000000000000FF00FFFFFF00FF00FF00000000FF000000FFFF00FFFF
00FFFFFF0000FF000000FF0000FFFFFF000000FFFF00FFFFFFFF0000FFFFFFFFFF0000FF
FF0000FFFFFF00FF00FF00FF00FF00FFFF0000FF00FF00FF00FF00FF00FF00FFFF0000FF
FF00FFFFFF0000FF00FF00FFFF0000FF0000FF0000
FF000000FF00FF000000000000FF00000000FFFFFFFF0000FF00FF0000FF0000FFFFFF00
FFFF00FFFF00FFFF0000FFFF000000FFFFFFFF00FF00FF0000FF00FFFF0000FFFFFFFFFF
FFFFFF00FF00FFFFFF00FFFF00FFFFFF00000000FF00FF00FFFF00FF00FFFF000000FF00
00FF000000FFFFFF00FFFFFF00FF000000FFFF000000FF00000000FFFFFFFFFFFFFF00FF
0000FFFFFFFFFF0000FF00FF00FF00FF0000FFFFFF0000FF00FF00FF00FF00FF0000FFFF
FFFF00000000FFFFFF0000FF0000FFFFFF00FF00FF
FFFF00FFFFFF0000FFFF00FFFF0000FFFF00FF00000000FFFFFF0000FFFFFF00FF000000
FF0000FF0000FF0000FFFFFFFF00FFFFFFFFFFFF0000FF00FFFFFF000000FFFFFFFFFFFF
FFFFFFFF0000FF000000FF0000FF000000FFFF00FF00FF00FF0000FF00FF0000FFFF0000
FFFFFF00FFFFFFFFFF00000000FF00FFFF000000FFFF0000FFFF00FF00000000000000FF
00FFFFFFFFFFFFFF00FF00FF00FF00FF00FFFFFFFFFF00FF00FF00FF00FF00FF00FFFFFF
FFFFFF00FFFF00000000FFFFFF00FF000000FF00FF
FFFFFF00000000FFFFFFFF000000FFFFFFFF0000FFFF00FF000000FFFFFFFFFF0000FFFF
0000FFFFFF00FF00FFFFFFFFFFFF00000000000000FFFFFF00000000FFFF000000000000
0000000000FFFFFF00FFFFFF00FF00FFFF000000FF00FF00FF00FFFFFF0000FFFFFFFF00
FF000000FF0000000000FFFF00FF00FF0000FFFF000000FFFFFFFF0000FFFF00FFFF00FF
00FF00000000000000FF00FF00FF00FF00FF0000000000FF00FF00FF00FF00FF00FF0000
00000000FF0000FFFF00FF000000FF00FFFF0000FF
00000000FFFF00FF00000000FFFF0000000000FFFFFFFF0000FFFF000000000000FFFFFF
FF00FF000000FF00FF000000000000FFFF00FFFF00FF000000FFFF00FF0000FFFF00FFFF
00FFFF00FFFFFFFFFF00000000FF00FF0000FFFF0000FF00FF00FF000000FFFFFFFFFFFF
0000FFFF0000FFFF00FFFFFFFF0000FF00FFFFFFFF00FFFFFFFFFFFF00FF0000FF0000FF
00FF00FFFF00FFFF00FF00FF00FF00FF00FF00FFFF00FFFFFF0000FF00FF00FF00FF00FF
FF00FFFF0000FFFFFFFF0000FFFF0000FF0000FFFF
FFFF00FFFFFFFF0000FFFF00FF0000FFFF00FFFFFFFFFFFF00FF0000FFFF00FFFF000000
0000FF00FFFF0000FF00FFFF00FFFF000000FF0000FF00FFFF000000FF00FFFFFFFF0000
00FF0000FF0000000000FFFF00FF00FF00FFFFFFFF00FF00FF00FF00FFFF000000000000
00FFFFFFFF00FF0000FF00000000FFFFFF0000000000FF000000000000FF00FFFFFF00FF
00FF00FF0000FF0000FF00FF00FF00FF00FF00FF0000FF000000FFFFFF0000FF00FF00FF
0000FF0000FFFFFFFFFFFF00FF0000FFFFFF00FF00
FF0000FF00000000FFFFFFFF0000FFFFFFFF00000000000000FF00FFFFFFFF000000FFFF
00FFFFFF000000FFFFFF000000FF0000FFFF0000FFFFFF000000FFFF0000FF00000000FF
FF0000FFFFFF00FFFF00FF0000FF00FF00FF00000000FF00FF00FF00FF0000FFFF00FFFF
00FF00000000FF00FFFFFF00FFFF00000000FFFF00FFFFFF00FFFF00FFFFFF00000000FF
00FF00FF00FFFFFF00FF00FF00FF00FF00FF00FF00FFFFFF00FFFFFFFFFF00FF00FF00FF
00FFFFFF00FF000000000000FF00FFFFFFFFFF0000
0000FFFFFF00FFFF0000000000FFFFFFFFFFFF00FFFF00FFFF0000FF00000000FFFF0000
00FF000000FFFF00000000FFFF0000FFFFFFFF00FF000000FFFF000000FFFFFF00FFFF00
0000FFFFFFFFFF000000FF00FFFFFF0000FF00FFFF00FF00FF00FF00FF00FFFFFFFF0000
00FF00FFFF00FF00FF000000FF0000FFFF00FF0000FF000000FF0000FF000000FFFF00FF
00FF00FF00FF000000FF00FF00FF00FF00FF00FF00FF000000FF0000000000FF00FF00FF
00FF000000FF00FFFF00FFFF0000FF0000000000FF
00FFFFFFFFFF000000FFFF00FFFFFFFFFFFFFFFF000000FF0000FFFFFF00FFFF000000FF
FF0000FFFF000000FFFF00FF0000FFFFFFFFFFFF0000FFFF000000FFFF00000000FF0000
FFFF000000000000FFFF0000FF000000FFFFFF000000FF00FF00FF00FF00FF00000000FF
FF0000FF0000FF00FF00FFFF0000FFFFFFFF0000FFFFFF00FFFFFF00FF00FFFF000000FF
00FF00FF00FF00FFFF0000FF00FF00FF00FF00FF00FF00FFFF0000FFFF00FFFFFF0000FF
00FF00FFFF0000FF0000FF0000FFFFFF00FFFF00FF
FF000000000000FFFF000000FF0000000000000000FFFF0000FFFFFFFFFF000000FFFF00
0000FFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFF00FF0000FFFF000000FFFF00FF00FF
FFFFFF00FFFF00FFFFFFFF00FF00FFFF00000000FFFF0000FF00FF00FF00FF00FFFF00FF
0000FFFFFF00FF00FF00FF0000FFFFFFFFFFFF00FF000000FF000000FF00FF0000FFFF00
00FF00FF00FF00FF0000FFFFFF0000FF00FF00FF00FF00FF0000FFFFFFFF00000000FFFF
FF0000FF0000FFFFFF00FF00FFFFFFFFFF000000FF
FFFF00FFFF00FFFFFFFF00FFFFFF00FFFF00FFFF00FF0000FFFFFFFFFFFFFF00FFFFFFFF
00FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFF0000FF
00000000FF0000FF00000000FF00FF0000FFFF00FF0000FFFFFF0000FF00FF00FF0000FF
00FFFFFFFFFF0000FF00FF00FFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FF00FFFFFFFF
00FF00FF00FF00FF00FFFFFFFFFF00FF00FF00FF00FF00FF00FFFFFFFFFFFF00FFFF0000
0000FFFFFF00FF000000FF00FF0000000000FFFF00
000000FF0000FF00000000FF000000FF0000FF0000FF00FFFFFFFFFFFFFFFFFF00000000
00FF000000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FF00000000FFFF
FF00FFFF0000FFFFFF00FFFF0000FF00FFFFFFFF0000FFFFFFFFFF00FF00FF00FF00FFFF
FF000000000000FFFFFF0000FF0000000000000000FFFFFFFF00FF0000FFFFFF00000000
00FF00FF00FF00FF00FF0000000000FF00FF00FF00FF00FF00FF000000000000FF0000FF
FF00FF000000FF00FFFF0000FF00FFFF00FFFFFFFF
00FFFF0000FFFFFF00FFFF0000FFFF0000FFFFFF00FF00FF000000000000000000FFFF00
FFFFFF00FFFF00FFFFFFFF00000000000000000000000000FF00FFFF00FF00FFFF00FF00
0000FF0000FFFFFFFFFF000000FFFFFF0000000000FFFFFFFFFFFFFF0000FF00FF00FF00
0000FFFF00FFFF00000000FFFFFF00FFFF00FFFF00FF00000000FF00FFFFFFFFFF00FFFF
00FF00FF00FF00FF00FF00FFFF00FFFFFF0000FF00FF00FF00FF00FFFF00FFFF0000FFFF
FFFF0000FFFF0000FF0000FFFFFF000000FF000000
00FF0000FFFFFFFFFF000000FFFFFFFF00FF000000FF00FF00FFFF00FFFF00FFFF000000
FF000000FF0000FF00000000FFFF00FFFF00FFFF00FFFF00FF00FF0000FF00FF0000FF00
FFFF0000FFFFFFFFFFFFFF00FFFFFFFFFF00FFFF00FF00000000000000FFFFFF0000FF00
FFFF000000FF0000FFFF00FF000000FF0000FF0000FF00FFFF00FF00FF0000000000FF00
00FF00FF00FF00FF00FF00FF0000FF000000FFFFFF0000FF00FF00FF0000FF0000FFFFFF
FFFFFF00FF0000FFFFFF00FF000000FFFF0000FFFF
FFFFFF00FF0000000000FFFF0000000000FF00FFFF0000FF00FF0000FF0000FF0000FFFF
0000FFFF0000FFFFFF00FFFF000000FF0000FF0000FF0000FF00FF00FFFFFF0000FFFFFF
000000FFFFFFFFFFFFFFFFFF000000000000FF0000FF00FFFF00FFFF00FF000000FFFFFF
000000FFFF0000FFFFFFFF0000FFFF0000FFFFFF00FF00FF0000FF00FF00FFFF00FFFFFF
00FF00FF00FF00FF00FF00FF00FFFFFF00FFFFFFFFFF00FF00FF00FF00FFFFFF00FF0000
00000000FF00FFFFFFFFFF0000FFFF000000FFFFFF
00000000FF00FFFF00FFFFFFFF00FFFF00FF00FF0000FFFFFF0000FFFFFF00FF00FFFFFF
FF00FF0000FFFFFFFFFF000000FFFF0000FFFFFF00FF00FFFFFF0000FF000000FFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF00FF00FF0000FF0000FF00FFFF000000
00FFFF000000FFFFFFFFFFFF00FF0000FFFFFFFFFF0000FF00FFFFFF0000FF0000FF0000
00FF00FF00FF00FF00FF00FF00FF000000FF0000000000FF00FF00FF00FF000000FF00FF
FF00FFFF0000FF0000000000FFFFFFFF00FFFFFFFF
00FFFF00FF00FF0000FF00000000FF0000FF00FF00FFFFFFFFFF00FF000000FF00FF0000
0000FF00FFFFFFFFFFFFFF00FFFFFFFF00FF000000FF00FF000000FFFFFF00FFFFFFFFFF
FFFF000000000000000000000000FF0000FF000000FF00FF00FFFFFF00FF00FF0000FFFF
00FF0000FFFF00000000000000FF00FFFFFFFFFFFFFF00FF00FF000000FFFFFF00FF00FF
FF0000FF00FF00FF00FF00FF00FF00FFFF0000FFFF00FFFFFF0000FF00FF00FFFF0000FF
0000FF0000FFFFFF00FFFF00FF00000000FF000000
FF000000FF00FF00FFFFFF00FFFF0000FFFFFF0000FF0000000000FF00FFFF0000FF00FF
FF00FF00FF00000000000000FF00000000FF00FFFF0000FF00FFFF00000000FF00000000
000000FFFF00FFFF00FFFF00FFFF0000FFFFFF00FFFFFF0000FF000000FF00FF00FFFFFF
FF0000FFFFFFFF00FFFF00FFFF0000FF00000000000000FF00FF00FFFF00000000FF00FF
0000FFFFFF0000FF00FF00FF00FF00FF0000FFFFFFFF00000000FFFFFF0000FF0000FFFF
FF00FF00FFFFFFFFFF000000FF00FFFF00FF00FFFF
0000FFFF0000FF00FF000000FF0000FFFFFFFFFF00FF00FFFF00FFFFFF000000FFFFFF00
0000FF00FF00FFFF00FFFF00FF00FFFF00FF00FF0000FFFFFF000000FFFF00FF00FFFF00
FFFF00FF0000FF0000FF0000FF0000FFFFFFFFFF00000000FFFFFF00FFFFFF0000FF0000
0000FFFFFFFFFFFF000000FF0000FFFFFF00FFFF00FFFF0000FF00FF0000FFFF00FF00FF
00FFFFFFFFFF00FF00FF00FF00FF00FF00FFFFFFFFFFFF00FFFF00000000FFFFFF00FF00
0000FF00FF0000000000FFFF0000FF0000FF00FF00
FF00FF0000FFFFFF0000FFFF0000FFFFFFFFFFFFFF0000FF0000FF000000FFFF00000000
FFFF0000FF00FF0000FF0000FF00FF0000FF00FF00FFFFFFFFFF00FFFFFFFF0000FF0000
FF0000FF00FFFFFF00FF00FFFFFF00FF0000000000FFFF00FF000000FF000000FFFFFF00
FFFF00000000000000FFFF0000FFFFFFFFFF000000FF0000FFFFFF0000FFFFFFFF0000FF
00FF0000000000FF00FF00FF00FF00FF00FF000000000000FF0000FFFF00FF000000FF00
FFFF0000FF00FFFF00FFFFFFFF00FF00FFFFFF0000
0000FF00FFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFFFF00FFFF
000000FFFFFF0000FFFFFF00FF00FF00FFFFFF0000FF0000000000FF00000000FFFFFF00
FF00FFFFFF00000000FF00FF000000FF00FFFF00FFFFFFFF0000FFFF0000FFFF00000000
FF0000FFFF00FFFF00FF0000FFFFFFFFFFFFFF00FFFFFF00FF000000FFFFFFFFFFFF00FF
00FF00FFFF00FFFFFF0000FF00FF00FF00FF00FFFF00FFFF0000FFFFFFFF0000FFFF0000
FF0000FFFFFF000000FF00000000FF00FF000000FF
FFFF0000FF0000000000FF00FFFFFFFFFFFFFFFFFFFFFF0000FF000000FF00000000FF00
00FFFF00000000FFFFFFFFFF0000FF00FF000000FFFFFF00FFFF00FF00FFFF00FF000000
FF00FF000000FFFF00FF00FF00FFFF0000FF0000FF00000000FFFFFFFF00FF0000FFFF00
FF00FFFFFFFF000000FF00FFFFFFFFFFFFFFFFFF00000000FF00FFFF00000000000000FF
00FF00FF0000FF000000FFFFFF0000FF00FF00FF0000FF0000FFFFFFFFFFFF00FF0000FF
FFFF00FF000000FFFF0000FFFF00FF00FF00FFFF00
FF0000FFFFFF00FFFF00FF00FF0000000000000000000000FFFFFF00FFFFFF00FFFF0000
FFFFFFFF00FFFF000000000000FFFFFF0000FFFF00000000FF0000FF00FF0000FF00FFFF
0000FF00FFFF000000FF00FF00FF0000FFFFFF00FF00FFFF00FF00000000FF00FFFFFFFF
0000FF00000000FFFF0000FF000000000000000000FFFF00FF00FF0000FFFF00FFFF00FF
00FF00FF00FFFFFF00FFFFFFFFFF00FF00FF00FF00FFFFFF00FF000000000000FF00FFFF
FFFFFF0000FFFF000000FFFFFFFF0000FF00FF0000
FFFF00FF000000FF0000FF00FF00FFFF00FFFF00FFFF00FFFFFFFFFF00000000FF0000FF
FFFFFFFFFF000000FFFF00FFFF00000000FFFFFFFF00FFFF0000FFFFFF0000FFFFFF0000
00FFFFFF000000FFFF0000FF00FF00FFFFFFFFFF0000FF0000FF00FFFF00FF00FF000000
00FFFFFF00FFFF000000FFFFFF00FFFF00FFFF00FFFFFFFF0000FF00FFFFFFFF000000FF
00FF00FF00FF000000FF0000000000FF00FF00FF00FF000000FF00FFFF00FFFF0000FF00
00000000FFFFFFFF00FFFFFFFFFFFF00FF00FF00FF
FFFFFF0000FFFF0000FFFFFF0000FF0000FF0000FF0000FF0000000000FFFF00FF00FFFF
FFFFFFFFFFFF00FFFFFFFF000000FFFF00FF00000000FF0000FFFFFFFFFF00FF000000FF
FF00000000FFFF000000FFFFFF0000FF0000000000FFFFFF00FF00FF0000FF00FF00FFFF
00FF000000FF0000FFFF00000000FF0000FF0000FF00000000FFFFFF0000000000FFFF00
00FF00FF00FF00FFFF0000FFFF00FFFFFF0000FF00FF00FFFF0000FF0000FF0000FFFFFF
00FFFF00FF00000000FF000000000000FF00FF00FF
00000000FFFFFFFF00FF000000FFFFFF00FF00FFFFFF00FF00FFFF00FFFFFFFF0000FF00
00000000000000FF00000000FFFF000000FF00FFFF00FF00FFFFFFFFFFFFFF0000FFFF00
0000FFFF00FF0000FFFF00000000FFFFFF00FFFF00FF000000FF00FF00FFFFFF0000FF00
00FF00FFFF0000FFFFFFFF00FFFF0000FFFFFF00FF00FFFF00FF000000FFFF00FFFFFFFF
00FF00FF00FF00FF0000FFFFFFFF00000000FFFFFF0000FF0000FFFFFF00FF00FFFFFFFF
FF000000FF00FFFF00FF00FFFF00FFFF0000FF00FF
FFFF00FFFFFFFFFFFF0000FFFF00000000FF00FF000000FF00FF0000FF00000000FFFFFF
00FFFF00FFFF00FF00FFFF00FF0000FFFF0000FF0000FF00FF00000000000000FFFFFFFF
00FFFFFFFF0000FFFFFFFF00FFFF00000000FF0000FF00FFFF0000FF00FF000000FFFFFF
00FF00FF0000FFFFFFFFFFFF000000FFFFFFFFFF0000FF0000FF00FFFF000000FF000000
00FF00FF00FF00FF00FFFFFFFFFFFF00FFFF00000000FFFFFF00FF000000FF00FF000000
0000FFFF0000FF0000FF00FF0000FF0000FFFFFF00
000000FF000000000000FFFFFFFF00FFFF0000FF00FFFF0000FF00FFFFFF00FFFF000000
00FF0000FF0000FF00FF0000FF00FFFFFFFF00FF00FFFFFF0000FFFF00FFFF00FF000000
00FF00000000FFFFFFFFFFFF000000FFFF00FF00FFFFFF000000FFFFFF0000FFFF000000
00FF00FF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF00FFFFFF000000FFFF0000FFFF
00FF00FF00FF00FF00FF000000000000FF0000FFFF00FF000000FF00FFFF0000FF00FFFF
00FFFFFFFF00FF00FFFFFF0000FFFFFF00FF000000
00FFFF0000FFFF00FFFF0000000000FF0000FFFFFF000000FFFFFF00000000FF0000FFFF
00FF00FFFFFF00FF00FF00FFFFFF0000000000FF00FF000000FFFFFFFF000000FF00FFFF
00FF00FFFF00FF000000000000FFFF000000FF00FF000000FFFF00000000FFFFFFFF00FF
FF0000FF00FF0000000000000000FF00000000000000FF00FF000000FFFF000000FFFFFF
FF0000FF00FF00FF00FF00FFFF00FFFF0000FFFFFFFF0000FFFF0000FF0000FFFFFF0000
00FF00000000FF00FF000000FFFFFFFFFF0000FFFF
FFFFFFFF00FF0000FF0000FFFF00FFFFFF00FF000000FFFF00000000FFFF00FF00FFFFFF
FF0000FF000000FF00FF00FF000000FFFF00FFFFFF0000FFFF0000000000FFFF0000FF00
00FF00FF0000FF00FFFF00FFFF000000FFFF0000FF00FFFF000000FFFF00FF00000000FF
0000FFFFFF0000FFFF00FFFF00FFFFFF00FFFF00FFFF0000FF00FFFF000000FFFF000000
0000FFFFFF0000FF00FF00FF0000FF0000FFFFFFFFFFFF00FF0000FFFFFF00FF000000FF
FF0000FFFF00FF00FF00FFFF000000000000FFFFFF
FF00000000FF00FFFFFF00FF0000FF000000FF00FFFF000000FFFF00FF0000FF00FF0000
0000FFFFFF00FFFFFF0000FF00FFFF000000FF000000FFFFFFFF00FFFF00FF0000FFFFFF
00FF00FF00FFFFFF000000FF0000FFFF000000FFFFFF000000FFFF000000FF00FFFF00FF
00FFFFFFFFFF00FF0000FF0000FF000000FF0000FF0000FFFFFF000000FFFF000000FFFF
00FFFFFFFFFF00FF00FF00FF00FFFFFF00FF000000000000FF00FFFFFFFFFF0000FFFF00
0000FFFFFFFF0000FF00FF0000FFFF00FFFF000000
FF00FFFF00FF00FF000000FF00FFFFFF00FFFFFF000000FFFF000000FF00FFFFFF0000FF
FF00FF000000FF000000FFFFFF000000FFFF0000FFFF0000000000FF0000FF00FFFFFFFF
FF0000FF00FF000000FFFF0000FFFFFFFF00FFFFFFFFFF00FFFFFFFF00FFFFFF000000FF
00FF0000000000FF00FFFFFF00FF00FFFF0000FFFFFF00FF000000FFFF000000FFFF0000
00FF0000000000FF00FF00FF00FF000000FF00FFFF00FFFF0000FF0000000000FFFFFFFF
00FFFFFFFFFFFF00FF00FF00FFFFFFFF000000FFFF
FF00FF0000FF00FF00FFFF0000FF000000FF000000FFFF000000FFFF0000FF000000FFFF
FFFF0000FFFF0000FFFF00000000FFFF000000FFFFFFFF00FFFF00FF00FFFFFF00000000
0000FFFFFF0000FFFF000000FFFFFFFFFFFF000000000000FF00000000FF000000FFFF00
00FF00FFFF00FFFFFF00000000FF00FF0000FFFFFFFFFF0000FFFF000000FFFF000000FF
FF0000FFFF00FFFFFF0000FF00FF00FFFF0000FF0000FF0000FFFFFF00FFFF00FF000000
00FF000000000000FF00FF00FF00000000FFFF0000
0000FF00FFFFFF0000FF0000FFFFFF00FFFFFF00FFFFFFFF00FFFFFFFF00FF00FFFF0000
000000FFFFFFFF00FF0000FFFF00FF0000FFFF0000000000FF0000FF00FF000000FFFF00
FFFF00000000FFFFFFFF00FFFFFFFFFFFFFFFF00FFFF00FFFFFF00FFFF0000FFFF000000
FFFFFF000000FF000000FFFF00FF00FF00FFFFFFFFFFFFFF00FF0000FFFF000000FFFF00
0000FFFFFFFF00000000FFFFFF0000FF0000FFFFFF00FF00FFFFFFFFFF000000FF00FFFF
00FF00FFFF00FFFF0000FF00FF00FFFF00FF0000FF
00FFFFFF00000000FFFFFF00FF000000FF000000FF00000000FF00000000FF00FF0000FF
FF00FFFFFFFFFFFF0000FFFFFFFF0000FFFFFFFF00FFFF00FF00FFFFFF0000FFFF000000
FF0000FFFF00FF00000000FF0000000000000000FF0000FF000000FF0000FFFFFFFF00FF
FFFFFFFF00FFFFFF00FFFFFFFF0000FF00FF00000000000000FF00FFFFFFFF00FFFFFFFF
00FFFFFFFFFFFF00FFFF00000000FFFFFF00FF000000FF00FF0000000000FFFF0000FF00
00FF00FF0000FF0000FFFFFF0000FF0000FF00FFFF
00FF000000FFFF00FF000000FF00FFFF0000FFFF0000FFFF00FF00FFFF00FF00FF00FFFF
FFFF00000000000000FFFFFFFFFFFF00FF00000000FF0000FF00FF000000FFFFFFFF00FF
FFFF00FF0000FF00FFFF00FF00FFFF00FFFF00FFFFFF00FF00FFFF0000FFFFFFFFFFFF00
0000000000FF000000FF00000000FFFFFF0000FFFF00FFFF00FF00FF00000000FF000000
00FF000000000000FF0000FFFF00FF000000FF00FFFF0000FF00FFFF00FFFFFFFF00FF00
FFFFFF0000FFFFFF00FF000000FFFFFF00FF00FF00
FF0000FFFF000000FF00FFFF0000FF0000FFFFFFFF00FF0000FF00FF0000FF00FF00FF00
000000FFFF00FFFF00FF000000000000FF00FFFF00FF00FFFFFF0000FFFF0000000000FF
000000FF00FFFFFF000000FF00FF0000FF0000FF000000FF00FF0000FFFFFFFFFFFFFFFF
00FFFF00FFFFFF00FFFFFF00FFFF00000000FFFFFFFF000000FF00FF00FFFF00FF00FFFF
00FF00FFFF00FFFF0000FFFFFFFF0000FFFF0000FF0000FFFFFF000000FF00000000FF00
FF000000FFFFFFFFFF0000FFFF00000000FF00FF00
0000FFFFFFFF00FFFFFF000000FFFFFF00FF00000000FF00FFFFFF0000FFFFFF0000FF00
FFFF00FF0000FF0000FF00FFFF00FFFF0000FF0000FF00FF000000FFFFFFFF00FFFF00FF
00FFFF0000FF000000FFFF0000FF00FFFFFF00FF00FFFF0000FF00FFFFFFFFFFFFFFFFFF
FF000000FF000000FF000000FF0000FFFF00FF00000000FFFF0000FF00FF0000FF00FF00
00FF00FF0000FF0000FFFFFFFFFFFF00FF0000FFFFFF00FF000000FFFF0000FFFF00FF00
FF00FFFF000000000000FFFFFFFF00FFFF0000FF00
00FFFFFFFFFFFF00000000FFFF00000000FF00FFFF00FF00FF000000FFFFFFFFFF00FF00
FF0000FF00FFFFFF00FF00FF0000FF0000FFFFFF00FF00FF00FFFF0000000000FF0000FF
00FF0000FFFFFF00FFFFFFFF00FF00FF000000FF00FF0000FFFFFF000000000000000000
0000FFFF0000FFFF0000FFFF0000FFFFFFFF0000FFFF00FF0000FFFFFF0000FFFFFF0000
FFFFFF0000FFFFFF00FF000000000000FF00FFFFFFFFFF0000FFFF000000FFFFFFFF0000
FF00FF0000FFFF00FFFF0000000000FF0000FFFFFF
00FF000000000000FFFF00FF0000FFFF00FF00FF0000FF00FF00FFFF000000000000FF00
FF00FFFFFF00000000FF00FF00FFFFFF00FF000000FF00FF00FF0000FFFF00FFFFFF00FF
00FF00FFFFFFFFFF0000000000FF00FF00FFFF0000FF00FFFFFFFFFF00FFFF00FFFF00FF
FF00FF0000FFFFFFFF00FF0000FFFFFFFFFFFF00FF0000FF00FFFFFFFFFF00FF000000FF
FFFFFFFF00FF000000FF00FFFF00FFFF0000FF0000000000FFFFFFFF00FFFFFFFFFFFF00
FF00FF00FFFFFFFF000000FFFF00FFFFFF00FF0000
00FF00FFFF00FFFF000000FF00FFFFFFFF0000FF00FFFFFF0000FF0000FFFF00FFFF0000
FF00FF000000FFFF00FF00FF00FF000000FF00FFFF0000FF00FF00FFFFFFFF00000000FF
00FF00FF0000000000FFFF00FFFFFF0000FF0000FFFFFF000000000000FF0000FF0000FF
0000FF00FFFFFFFFFFFF0000FFFFFFFFFFFFFFFF0000FFFFFF000000000000FF00FFFF00
0000000000FF00FFFF0000FF0000FF0000FFFFFF00FFFF00FF00000000FF000000000000
FF00FF00FF00000000FFFF000000FF000000FF00FF
00FF00FF0000FF0000FFFF0000FF00000000FFFFFF00000000FFFFFF00FF0000FF0000FF
FFFF0000FFFF000000FF00FF00FF00FFFF0000FF0000FFFFFF0000FF00000000FFFF00FF
00FF00FF00FFFF00FFFFFFFF00000000FFFFFF00FF000000FFFF00FFFF0000FFFFFF00FF
00FFFFFF00000000000000FFFFFFFFFFFFFFFFFFFF00FF000000FFFF00FFFF0000FF0000
FFFF00FFFF0000FF0000FFFFFF00FF00FFFFFFFFFF000000FF00FFFF00FF00FFFF00FFFF
0000FF00FF00FFFF00FF0000FFFF0000FFFF0000FF
00FF00FF00FFFFFF00FF0000FFFFFF00FFFF00000000FFFF00FF000000FF00FFFFFF00FF
000000FFFFFFFF00FFFFFF0000FF00FF0000FFFFFF00FF000000FFFFFF00FFFF000000FF
00FF00FF00FF0000FF00000000FFFF00FF000000FF00FFFF000000FF0000FFFFFFFFFF00
00FF000000FFFF00FFFF00FF00000000000000000000FF00FFFF000000FF0000FFFFFF00
FF0000FF0000FFFFFF00FF000000FF00FF0000000000FFFF0000FF0000FF00FF0000FF00
00FFFFFF0000FF0000FF00FFFFFFFF00FF0000FFFF
FF0000FF00FF000000FF00FFFFFFFFFF000000FFFF00FF0000FF00FFFF0000FF000000FF
00FFFF0000000000FF000000FFFFFF0000FFFFFFFFFF0000FFFF00000000FF0000FFFF00
00FF00FF00FF00FFFFFF00FFFF000000FF00FFFF0000FF0000FFFF0000FFFFFFFFFFFFFF
00FF00FFFF000000FF0000FF00FFFF00FFFF00FFFF00FF00FF0000FFFF0000FFFFFFFFFF
0000FFFFFF00FF000000FF00FFFF0000FF00FFFF00FFFFFFFF00FF00FFFFFF0000FFFFFF
00FF000000FFFFFF00FF00FF00000000FF00FFFFFF
0000FFFFFF0000FFFF0000FF0000000000FFFF000000FF00FFFFFF000000FFFFFF00FFFF
FF000000FFFF00FFFFFF00FFFFFFFFFF00FF0000000000FFFFFFFF00FFFF0000FFFFFFFF
00FF00FF00FF00FF000000FF0000FFFF0000FF0000FFFFFF00FF0000FFFFFFFFFFFFFFFF
FF0000FF0000FFFF0000FFFFFF000000FF0000FF0000FF00FF00FFFFFFFF00FF00000000
00FFFFFFFFFF0000FFFF0000FF0000FFFFFF000000FF00000000FF00FF000000FFFFFFFF
FF0000FFFF00000000FF00FF00FFFF00FF00FF0000
FF00FF000000FFFFFFFF00FF00FFFF00FFFFFFFF00FFFFFF00000000FFFF00000000FF00
0000FFFF000000FF000000FF0000000000FF00FFFF00FFFFFFFFFFFF000000FFFFFFFFFF
FF0000FF00FF00FF00FFFF0000FFFFFFFF00FF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFF00FF00FFFFFFFF00FF000000FFFF0000FFFFFF00FF00FF00FF00000000FF00FFFF00
FFFFFFFFFFFFFF00FF0000FFFFFF00FF000000FFFF0000FFFF00FF00FF00FFFF00000000
0000FFFFFFFF00FFFF0000FF00FF0000FF00FF00FF
0000FF00FFFF0000000000FF00FF0000FF00000000FF000000FFFF00FF0000FFFF00FF00
FFFF000000FFFF0000FFFF0000FFFF00FFFFFF000000FF000000000000FFFF0000000000
0000FFFFFF0000FF00FF0000FFFFFFFFFFFF0000FF0000000000FFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF00000000FF00FFFF000000FFFFFFFFFF0000FF00FF00FFFF00FF00FF0000
FF00000000000000FF00FFFFFFFFFF0000FFFF000000FFFFFFFF0000FF00FF0000FFFF00
FFFF0000000000FF0000FFFFFF0000FFFFFF0000FF
FFFF0000FF0000FFFF00FFFFFF0000FFFFFF00FFFF0000FFFF000000FF00FFFFFFFF0000
FF0000FFFF000000FFFFFFFF00FF0000FF000000FFFF0000FFFF00FFFF000000FFFF00FF
FF00FF000000FFFFFF0000FFFFFFFFFFFFFFFF00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFF00FF00FF0000FFFF000000000000FFFFFF0000FF0000FF00FF00FF
FFFF00FFFF00FFFF0000FF0000000000FFFFFFFF00FFFFFFFFFFFF00FF00FF00FFFFFFFF
000000FFFF00FFFFFF00FF000000FFFFFFFFFF00FF
000000FFFFFF00FF0000FF000000FFFFFFFFFF000000FFFFFFFF00FFFFFF0000000000FF
FFFF00FF0000FFFF0000000000FF00FFFFFF00FFFFFFFF00FF0000FF0000FFFF000000FF
0000FF00FFFF00000000FFFFFFFFFFFFFFFFFFFF0000FF0000FF00000000000000000000
0000000000FF00FF0000FF00FF00FFFFFFFF00FFFF00FFFFFFFFFF00FF00FFFFFF0000FF
000000FF0000FF0000FFFFFF00FFFF00FF00000000FF000000000000FF00FF00FF000000
00FFFF000000FF000000FF00FFFF000000000000FF
FF00FFFFFFFFFF0000FFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF00000000FFFF00FFFF
FFFFFF0000FFFFFFFF00FFFF00FF00FF000000FF00000000FF00FFFFFF00FF0000FFFF00
00FFFFFF000000FFFF00FF00000000000000000000FFFFFF00FF00FFFF00FFFF00FFFF00
FFFF00FFFF0000FF00FFFFFF0000FF00000000FF0000FF0000000000FF00FF000000FFFF
FF00FFFFFF00FF00FFFFFFFFFF000000FF00FFFF00FF00FFFF00FFFF0000FF00FF00FFFF
00FF0000FFFF0000FFFF0000FF0000FFFF00FFFF00
FFFF000000000000FFFFFFFFFF0000000000000000FF000000000000FFFF00FF0000FF00
00000000FFFFFFFFFFFF000000FF00FF00FFFF0000FFFF00FF00FF000000FF00FFFFFFFF
00FF000000FFFF000000FF00FFFF00FFFF00FFFF00FF000000FF00FF0000FF0000FF0000
FF0000FF0000FFFFFF00000000FFFFFF00FFFF0000FFFFFF00FFFF00FF00FF00FFFF0000
0000FF000000FF00FF0000000000FFFF0000FF0000FF00FF0000FF0000FFFFFF0000FF00
00FF00FFFFFFFF00FF0000FFFFFF00FF0000FF0000
000000FFFF00FFFF000000000000FFFF00FFFF00FFFFFF00FFFF00FFFFFFFF0000FFFFFF
00FFFF00FF000000000000FFFF0000FF00FF0000FFFFFFFF0000FF00FFFF0000FF000000
00FF00FFFF000000FFFF0000FF0000FF0000FF0000FF00FFFF0000FF00FFFFFF00FF00FF
FFFF00FF00FFFFFFFFFF00FFFF00000000FF0000FFFFFFFFFF000000FF00FF00FF0000FF
FF00FF00FFFF0000FF00FFFF00FFFFFFFF00FF00FFFFFF0000FFFFFF00FF000000FFFFFF
00FF00FF00000000FF00FFFFFFFFFF0000FFFFFF00
00FFFF000000FF0000FFFF00FFFF000000FF0000FF000000FF0000FF00000000FFFFFFFF
FF000000FF00FFFF00FFFF000000FFFFFF0000FFFFFFFFFFFF00FF00FF0000FFFFFF00FF
FF0000FF0000FFFF000000FFFFFF00FF00FFFFFF00FF00FF0000FFFFFF00000000FF00FF
000000FF00FF0000000000FF0000FFFF00FF00FFFFFFFFFFFFFF00FFFFFF0000FF00FFFF
FFFF0000FF0000FFFFFF000000FF00000000FF00FF000000FFFFFFFFFF0000FFFF000000
00FF00FF00FFFF00FF00FF0000000000FFFFFFFFFF
00FF0000FFFF0000FFFFFFFF000000FFFF0000FFFFFF00FFFFFF00FF00FFFF00FF000000
0000FFFF0000FF0000FF0000FFFF00000000FFFFFFFFFFFFFFFF0000FF00FFFFFFFFFF00
0000FFFFFF00FF0000FFFF00000000FF00FF000000FF00FF00FFFFFFFFFF00FFFF0000FF
00FFFF0000FF00FFFF00FFFFFF00FF0000FF00FF00000000000000FF000000FFFFFF0000
000000FFFFFF00FF000000FFFF0000FFFF00FF00FF00FFFF000000000000FFFFFFFF00FF
FF0000FF00FF0000FF00FF00FFFF00FFFFFFFFFFFF
FFFFFF00FF0000FFFFFFFFFFFF00FFFFFFFF00FF000000FF000000FF00FF0000FF00FFFF
00FFFFFFFF00FF00FFFFFF00FF0000FFFF00FF0000000000000000FFFFFF000000000000
FFFF00000000FF00FFFFFFFF00FFFF0000FF00FFFF0000FF00FF0000000000FF0000FFFF
FF000000FFFFFF000000FF000000FF00FFFFFF0000FFFF00FFFF00FF00FFFF00000000FF
FF00FFFFFFFFFF0000FFFF000000FFFFFFFF0000FF00FF0000FFFF00FFFF0000000000FF
0000FFFFFF0000FFFFFF0000FF0000FF0000000000
FF000000FF00FFFFFFFFFFFFFFFF0000000000FF00FFFF0000FFFF0000FF00FFFFFF0000
00FF00000000FF00FF000000FF00FFFFFFFF0000FFFF00FFFF00FFFFFFFFFF00FFFF00FF
FFFFFF00FFFF0000FF00000000FF0000FFFFFF000000FFFFFF0000FFFF00FFFFFF00FF00
0000FFFF00000000FFFF0000FFFF0000FF000000FFFFFFFF000000FF00FF0000FFFF00FF
0000FF0000000000FFFFFFFF00FFFFFFFFFFFF00FF00FF00FFFFFFFF000000FFFF00FFFF
FF00FF000000FFFFFFFFFF00FF00FFFFFF00FFFF00
FF00FFFF0000FF0000000000000000FFFF00FFFFFF000000FFFFFFFF00FF00FF000000FF
FF0000FFFF00FF00FF00FFFF0000FF00000000FFFFFFFF000000FF0000000000FF0000FF
00000000FF0000FFFFFF00FFFF0000FFFFFFFFFF00FFFFFFFFFF00FF0000FF000000FF00
FFFF000000FFFF00FF0000FFFFFFFF00FF00FFFF0000000000FFFF0000FF00FFFFFFFF00
00FFFFFF00FFFF00FF00000000FF000000000000FF00FF00FF00000000FFFF000000FF00
0000FF00FFFF000000000000FF00FF000000FF0000
FF00FF0000FFFFFF00FFFF00FFFF00FF0000FF000000FFFF0000000000FF00FF00FFFF00
0000FFFFFFFF0000FF00FF0000FFFFFF00FFFF0000000000FFFF0000FFFF00FFFFFF00FF
00FFFF00FF00FFFFFFFFFF000000FFFFFFFFFFFFFF000000000000FF00FFFFFF00FFFFFF
000000FFFF000000FF00FFFFFFFFFFFF0000FF0000FFFF00FFFFFFFF00FF00FF00000000
FFFFFFFFFF000000FF00FFFF00FF00FFFF00FFFF0000FF00FF00FFFF00FF0000FFFF0000
FFFF0000FF0000FFFF00FFFF0000FF00FFFF0000FF
FF00FF00FFFFFFFFFF000000FF0000FF00FFFFFF00FFFFFFFF00FFFF00FF00FF00FF0000
FFFF0000000000FFFFFF0000FFFFFFFFFF000000FFFF00FFFFFFFF00FF0000FF000000FF
00FF0000FF00FF0000000000FFFF0000000000000000FFFF00FFFF0000FF000000FF0000
00FFFF000000FFFF0000FF000000000000FFFFFF00FF0000FF00000000FF00FF00FFFF00
FF0000000000FFFF0000FF0000FF00FF0000FF0000FFFFFF0000FF0000FF00FFFFFFFF00
FF0000FFFFFF00FF0000FF0000FFFFFF000000FFFF
FFFF0000FF0000000000FFFF0000FFFFFF00000000FF00000000FF0000FF00FF00FF00FF
FFFFFF00FFFF00FF000000FFFFFFFFFFFFFF00FFFFFFFF0000000000FF00FFFFFF00FFFF
FF0000FFFFFF0000FFFF00FFFFFFFF00FFFF00FFFF00FF0000FF0000FFFFFF00FFFFFF00
FFFFFFFF00FFFFFFFF00FF00FFFF00FFFF00000000FF00FFFFFF00FFFF0000FF00FF0000
FF00FFFF00FFFFFFFF00FF00FFFFFF0000FFFFFF00FF000000FFFFFF00FF00FF00000000
FF00FFFFFFFFFF0000FFFFFF00FF000000FFFF0000
FFFFFF00FF00FFFF00FFFFFFFF00FF000000FFFF00FF00FFFF00FF00FFFFFF0000FF00FF
00000000FF0000FF00FFFF0000000000000000FF00000000FFFF00FFFFFF00000000FF00
0000FFFFFFFFFF00FF0000FF00000000FF0000FF0000FF00FFFFFF00FF000000FF000000
FF00000000FF00000000FF00FF0000FF0000FFFF00FF00FF000000FF0000FFFFFF0000FF
FFFF000000FF00000000FF00FF000000FFFFFFFFFF0000FFFF00000000FF00FF00FFFF00
FF00FF0000000000FFFFFFFFFF0000FFFF000000FF
00000000FF00FF0000FF00000000FF00FFFF000000FF00FF0000FF00FF000000FFFFFF00
00FFFF00FF00FFFFFF000000FFFF00FFFF00FFFFFF00FFFF000000FF000000FFFF00FF00
FFFF000000000000FF00FFFFFF00FFFF0000FFFFFF00FF00FF000000FF00FFFF0000FFFF
0000FFFF00FF00FFFF00FF00FF00FFFFFF00FF0000FF00FF00FFFF0000FFFFFFFFFF00FF
000000FFFF0000FFFF00FF00FF00FFFF000000000000FFFFFFFF00FFFF0000FF00FF0000
FF00FF00FFFF00FFFFFFFFFFFFFF00FF0000FFFF00
FF00FFFF0000FF00FFFFFF00FFFF0000FF0000FFFF0000FF00FFFFFF0000FFFF00000000
FFFFFFFF0000FF000000FFFF000000FF0000FF000000FF0000FFFF0000FFFF000000FF00
FF0000FFFF00FFFF0000FF000000FF0000FFFFFFFFFF0000FF00FFFF0000FF0000FFFFFF
FF00FF0000FF00FF0000FF00FF00FF000000FF00FFFFFF0000FF0000FFFFFFFFFFFFFF00
00FFFF000000FFFFFFFF0000FF00FF0000FFFF00FFFF0000000000FF0000FFFFFF0000FF
FFFF0000FF0000FF00000000000000FF00FFFFFFFF
0000FF0000FFFFFF00000000FF0000FFFFFF00FF0000FFFFFF00000000FFFFFFFF00FFFF
0000000000FFFFFF00FFFFFFFF00FFFFFF00FF00FFFF0000FFFFFFFF00FF0000FFFF0000
FF00FFFFFFFF000000FFFFFF00FFFFFF00FF0000000000FFFFFF000000FFFFFF00FF0000
0000FF00FFFFFF0000FFFFFF0000FF00FFFF0000FF000000FFFFFF00FF00000000000000
FFFFFFFF00FFFFFFFFFFFF00FF00FF00FFFFFFFF000000FFFF00FFFFFF00FF000000FFFF
FFFFFF00FF00FFFFFF00FFFF00FFFF0000FF000000
FFFF0000FFFFFFFFFF00FFFF0000FFFFFFFFFF0000FFFFFFFFFF00FFFF0000000000FF00
00FFFF00FFFFFFFFFF0000000000FF000000FF00FF0000FFFFFFFFFFFF0000FFFFFFFF00
FF00FF00000000FFFF00000000FF000000FF00FFFF00FFFFFFFFFF00FFFFFFFFFF0000FF
FF00FF00FF000000FFFFFFFFFF00FF00FF0000FFFFFF00FFFFFFFFFF0000FFFF00FFFF00
FF00000000FF000000000000FF00FF00FF00000000FFFF000000FF000000FF00FFFF0000
00000000FF00FF000000FF0000FF0000FFFFFF00FF
FF0000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFF00FF0000000000FF0000FFFF00FFFFFF
00FF0000FF0000000000FFFF00FFFFFF00FFFFFF0000FFFFFFFFFFFFFFFF00FF00000000
FF00FF00FFFF00FF0000FFFF00FF00FFFF0000FF0000FF0000000000FF0000000000FFFF
FFFF0000FF00FFFF000000000000FF00FF00FFFFFFFFFF000000000000FFFFFFFF000000
FF00FFFF00FF00FFFF00FFFF0000FF00FF00FFFF00FF0000FFFF0000FFFF0000FF0000FF
FF00FFFF0000FF00FFFF0000FFFFFF00FF000000FF
FF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF00FF0000FF0000
00FF00FFFFFF00FFFF00FF0000FF000000FF000000FFFFFFFFFFFFFFFFFFFF0000FFFF00
FF00FF00FF0000FF00FFFFFFFF0000FF0000FFFFFF00FF00FFFF00FFFFFF00FFFF00FF00
000000FFFFFF000000FFFF00FFFF0000FF00FF0000000000FFFF00FFFF0000000000FFFF
0000FF0000FF00FF0000FF0000FFFFFF0000FF0000FF00FFFFFFFF00FF0000FFFFFF00FF
0000FF0000FFFFFF000000FFFFFFFFFF0000FFFF00
0000FF000000000000000000FF000000000000000000FFFFFFFF00000000FF00FFFFFF00
FFFFFF00000000FF0000FF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FF0000
FF00FF00FF00FFFFFF0000000000FFFFFF00FF000000FF00FF0000FF000000FF0000FF00
FFFF00FF000000FFFF000000FF0000FFFFFF0000FFFF00FFFFFFFF000000FFFF00FFFFFF
FF00FF00FFFFFF0000FFFFFF00FF000000FFFFFF00FF00FF00000000FF00FFFFFFFFFF00
00FFFFFF00FF000000FFFF000000000000FFFFFFFF
00FFFFFF00FFFF00FFFF00FFFFFF00FFFF00FFFF00FFFFFFFFFFFF00FFFF0000FF000000
FF000000FFFF00FF00FFFFFF00000000FF000000FF000000000000000000000000FF00FF
FFFF0000FF00FF000000FFFF00FFFFFFFFFF0000FFFF0000FF00FFFFFF00FFFFFF00FF00
FF0000FF00FFFF000000FFFF0000FFFFFFFFFF00FF0000FF00000000FFFF000000FF0000
0000FF00FF000000FFFFFFFFFF0000FFFF00000000FF00FF00FFFF00FF00FF0000000000
FFFFFFFFFF0000FFFF000000FFFF00FFFF00000000
FFFFFFFFFF000000FF0000FF000000FF0000FF0000FF000000000000FF0000FFFFFF00FF
FFFF00FFFFFFFF0000FF000000FFFF00FF00FFFF0000FFFF00FFFF00FFFF00FFFF0000FF
000000FFFFFF0000FFFF000000FF0000000000FFFFFFFF00FF00FF000000FF000000FF00
FF00FFFFFF000000FFFF000000FFFFFFFFFFFFFF0000FFFFFF00FFFF000000FFFF0000FF
FF00FF00FF00FFFF000000000000FFFFFFFF00FFFF0000FF00FF0000FF00FF00FFFF00FF
FFFFFFFFFFFF00FF0000FFFF000000FF0000FFFF00
FF0000000000FFFF0000FFFFFF00FFFFFF00FF00FFFFFF00FFFF00FFFFFF00FF000000FF
000000FF00000000FFFFFF00FFFFFFFF0000FF0000FFFFFFFF000000FF0000FF0000FFFF
FF00FFFFFFFFFF00FF0000FFFF0000FFFF00FFFFFFFFFFFF0000FF00FFFF0000FFFF0000
FF00FF000000FFFF000000FFFF0000000000000000FFFFFFFFFF000000FFFF000000FFFF
FFFF0000FF00FF0000FFFF00FFFF0000000000FF0000FFFFFF0000FFFFFF0000FF0000FF
00000000000000FF00FFFFFFFF00FFFFFF00FF0000
0000FFFF00FFFFFFFF00FF000000FF000000FF00FF000000FF0000FF000000FF00FFFF00
00FFFF0000FFFF00FF000000FF00000000FFFFFF00FF00000000FFFF0000FFFFFF00FF00
0000FF0000000000FF00FFFFFFFF00FF0000FF000000000000FFFFFF000000FFFFFFFF00
FF00FF00FFFF000000FFFF000000FFFF00FFFF00FFFFFFFFFFFFFF00FFFFFFFF00FFFFFF
FFFFFF00FF00FF00FFFFFFFF000000FFFF00FFFFFF00FF000000FFFFFFFFFF00FF00FFFF
FF00FFFF00FFFF0000FF00000000FF000000FF00FF
00FFFFFFFF0000000000FF00FFFF0000FFFF0000FF00FFFF0000FFFFFF00FFFFFF000000
FFFFFFFF00FF0000FF00FFFF0000FFFF00FF000000FF00FFFF00FF0000FFFFFFFFFF0000
FFFF0000FFFF00FFFFFF0000000000FF00FFFFFF00FFFF00FFFFFFFFFF00FFFFFFFFFFFF
0000FF00FF0000FFFF000000FFFF000000FF0000FF00000000000000FF00000000FF0000
00000000FF00FF00FF00000000FFFF000000FF000000FF00FFFF000000000000FF00FF00
0000FF0000FF0000FFFFFF00FFFF0000FFFF0000FF
FF0000000000FFFF00FFFFFF000000FFFFFFFF00FF00FF0000FFFFFFFFFF00000000FFFF
0000000000FF00FFFFFF000000FFFFFFFF0000FFFF0000FF0000FF00FFFFFFFFFFFFFF00
FF0000FFFFFFFF00000000FFFF00FFFFFF00000000FF0000FF0000000000FF0000000000
00FFFFFF0000FFFFFFFF00FFFFFFFF00FFFFFF00FF00FFFF00FFFF00FF00FFFF00FF00FF
FF00FFFF0000FF00FF00FFFF00FF0000FFFF0000FFFF0000FF0000FFFF00FFFF0000FF00
FFFF0000FFFFFF00FF000000FF0000FFFFFFFF00FF
0000FFFF00FFFFFFFF00000000FFFF0000000000FF00FF00FFFFFFFFFFFFFF00FFFF0000
00FFFF00FFFFFF00000000FFFF0000000000FFFFFFFF00FF00FFFFFF0000000000000000
FF00FFFFFFFFFFFF00FFFF000000FF000000FFFF00FF00FFFFFF00FFFF00FF00FFFF00FF
FF00000000FFFFFFFFFFFF0000000000FF000000FF00FF0000FF0000FF00FF0000FF00FF
0000FF0000FFFFFF0000FF0000FF00FFFFFFFF00FF0000FFFFFF00FF0000FF0000FFFFFF
000000FFFFFFFFFF0000FFFF0000FFFFFFFFFFFF00
FF00FF0000FF00000000FFFF00FF0000FFFF00FFFFFF0000FF00000000000000FF0000FF
FF000000FF000000FFFF00FF0000FFFF00FFFFFFFFFFFF0000FF000000FFFF00FFFF00FF
FFFF00000000000000FF0000FFFF0000FFFF000000FF00FF000000FF0000FF00FF0000FF
0000FFFF00FF000000000000FFFF00FFFFFF00FFFFFF0000FFFFFF00FF00FF00FFFFFF00
00FFFFFF00FF000000FFFFFF00FF00FF00000000FF00FFFFFFFFFF0000FFFFFF00FF0000
00FFFF000000000000FFFFFFFF00FF000000000000
FFFF0000FFFFFF00FFFF000000FF00FFFFFFFF00000000FFFFFF00FFFF00FFFF0000FFFF
FFFF00FFFFFF00FFFFFFFF0000FFFFFFFF00000000000000FFFFFF00FFFFFFFF000000FF
000000FFFF00FFFF00FF00FFFFFFFF00FF0000FFFF0000FF00FFFF0000FFFFFF0000FFFF
FF00FF0000FF00FFFF00FFFF000000FF000000FF000000FFFFFFFFFF0000FF00FF000000
FFFFFFFFFF0000FFFF00000000FF00FF00FFFF00FF00FF0000000000FFFFFFFFFF0000FF
FF000000FFFF00FFFF0000000000FF00FFFF00FFFF
000000FFFFFFFFFF000000FFFF0000FF00000000FFFF00FF000000FF0000FF0000FFFFFF
FFFFFF00000000FF00000000FFFFFFFFFFFF00FFFF00FFFF00000000FF00000000FFFF00
00FFFF000000FF0000FF00FF00000000FF00FFFFFFFF00FF00FF0000FFFFFFFFFF00FF00
0000FF00FFFFFF000000FF0000FFFF0000FFFF0000FFFF000000000000FFFFFF0000FFFF
000000000000FFFFFFFF00FFFF0000FF00FF0000FF00FF00FFFF00FFFFFFFFFFFFFF00FF
0000FFFF000000FF0000FFFF00FFFFFF000000FF00
FF00FFFFFFFFFFFFFF00FFFFFFFF00FF00FFFF00FF0000FF00FFFF0000FFFFFF00FF0000
00000000FFFF00FF00FFFF00FF000000000000FF0000FF0000FFFF00FF00FFFF00FF0000
FFFFFFFF00FFFFFF00FF00FF00FFFF00FF00FF00000000FF00FF00FFFFFFFFFFFFFF0000
FFFF0000FF000000FFFF0000FFFFFFFF00FF0000FFFFFFFF00FFFF00FFFFFFFFFF00FF00
00FFFF00FFFF0000000000FF0000FFFFFF0000FFFFFF0000FF0000FF00000000000000FF
00FFFFFFFF00FFFFFF00FF0000FF000000FFFF0000
0000FF00000000000000FF00000000FF00FF0000FF00FFFFFF000000FFFFFFFFFF0000FF
FF00FFFF000000FF00FF0000FF00FFFF00FFFF0000FFFFFF00FF0000FF00FF0000FF00FF
FFFFFFFFFF00000000FF00FF00FF0000FF00FF00FFFF00FF00FF00FF00000000000000FF
FFFFFF00FF00FFFF000000FFFFFFFFFFFF0000FFFFFFFFFFFF000000FF0000000000FF00
FFFFFFFF000000FFFF00FFFFFF00FF000000FFFFFFFFFF00FF00FFFFFF00FFFF00FFFF00
00FF00000000FF000000FF00FFFFFF00FFFFFFFF00
FF00FF00FFFF00FFFF00FF00FFFF00FF00FF00FFFFFF00000000FFFF000000000000FFFF
FFFF000000FFFF0000FF00FFFFFF000000FF0000FFFFFFFFFF0000FFFFFF0000FFFFFF00
000000000000FFFF00FF00FF00FF00FFFFFF0000FF0000FF00FF00FF00FFFF00FFFF00FF
00000000FF00FF0000FFFF00000000000000FFFFFFFFFFFFFFFF00FFFFFF00FFFF00FF00
FF00000000FFFF000000FF000000FF00FFFF000000000000FF00FF000000FF0000FF0000
FFFFFF00FFFF0000FFFF0000FF000000FF00000000
FFFF0000FF0000FF0000FF00FF0000FF00FF00FF000000FFFF00FF0000FFFF00FFFF0000
000000FFFF000000FFFFFF00000000FFFF0000FFFFFFFFFFFFFF00FF000000FFFFFFFFFF
00FFFF00FFFF000000FF00FF00FF00FF000000FFFFFF00FF00FF00FF00FF0000FF0000FF
00FFFF00FF00FF00FFFFFFFF00FFFF00FFFF000000000000000000FF000000FF0000FF00
FF00FFFF00FF0000FFFF0000FFFF0000FF0000FFFF00FFFF0000FF00FFFF0000FFFFFF00
FF000000FF0000FFFFFFFF00FF00FFFF0000FFFF00
000000FFFFFF00FF00FFFFFF0000FFFFFF0000FF00FFFF000000FF00FFFFFFFF000000FF
FF00FFFFFFFF00FFFFFFFFFF00FFFF000000FFFFFFFFFFFFFFFFFF0000FFFF0000000000
00FF0000FF0000FFFF0000FF00FF00FF00FFFF00000000FF00FF00FF00FF00FFFFFF00FF
00FF0000FF00FF00FF00000000FF0000FF0000FFFF00FFFF00FFFF0000FFFF0000FFFFFF
0000FF0000FF00FFFFFFFF00FF0000FFFFFF00FF0000FF0000FFFFFF000000FFFFFFFFFF
0000FFFF0000FFFFFFFFFFFF0000FF0000FFFFFFFF
FF00FFFFFFFFFF0000FF000000FFFFFFFFFF00FF00FF0000FFFF0000FF00000000FFFF00
0000FF00000000FF0000000000FF0000FFFF00000000000000000000FFFFFFFF00FFFF00
FFFFFF00FF00FFFFFFFF00FF00FF00FF00FF0000FFFF00FF00FF00FF00FF00FF000000FF
00FF00FFFFFF0000FF00FFFF00FF00FFFFFF00FF0000FF0000FF0000FFFFFFFF00FF0000
00FFFFFF00FF00FF00000000FF00FFFFFFFFFF0000FFFFFF00FF000000FFFF0000000000
00FFFFFFFF00FF000000000000FFFFFF00FF000000
FFFF000000000000FFFFFF00FFFFFFFFFFFFFF0000FF00FFFFFFFF00FF00FFFF00FF0000
FFFF0000FFFF00FF00FFFF00FFFFFF00FF0000FFFF00FFFF00FFFF00FF00000000FF0000
FF000000FF00FF00000000FF00FF00FF00FF00FFFFFFFF0000FF00FF00FF00FF00FFFF00
00FF00FF000000FFFFFF000000FF00FF000000FF00FFFFFF00FF00FFFFFFFFFFFF0000FF
FF00000000FF00FF00FFFF00FF00FF0000000000FFFFFFFFFF0000FFFF000000FFFF00FF
FF0000000000FF00FFFF00FFFF00000000FF00FFFF
000000FFFF00FFFF00000000FF00000000000000FFFFFF0000000000FF00FF0000FF00FF
FFFFFF00FF0000FF00FF0000FF000000FF00FFFFFFFF000000FF0000FF00FFFF00FF00FF
FFFF00FFFFFF0000FFFF00FF00FF00FF00FF00FF00000000FFFFFF0000FF00FF00FF0000
FFFFFF0000FFFF00000000FFFF0000FF00FFFF0000FF000000FF00FF000000000000FFFF
FFFF00FFFF0000FF00FF0000FF00FF00FFFF00FFFFFFFFFFFFFF00FF0000FFFF000000FF
0000FFFF00FFFFFF000000FF0000FFFF00FF00FF00
FF00FFFFFFFF000000FFFF00FF00FFFF00FFFF00FF000000FFFF00FFFFFF0000FFFFFF00
00000000FF00FFFFFF0000FFFFFF00FFFFFF0000000000FFFF0000FFFFFF000000FF00FF
000000FF000000FFFFFFFF0000FF00FF00FF00FF00FFFF00FF000000FFFFFF0000FF00FF
FFFFFFFF00FF0000FFFF00FF0000FFFFFF000000FFFFFF00FFFFFF0000FFFF00FFFF0000
000000FF0000FFFFFF0000FFFFFF0000FF0000FF00000000000000FF00FFFFFFFF00FFFF
FF00FF0000FF000000FFFF0000FFFFFFFF0000FF00
FFFF0000000000FFFF000000FF00FF0000FF0000FF00FFFF000000FF000000FFFFFFFFFF
00FFFF00FF00FF000000FFFFFFFFFF00000000FFFF00FFFFFFFF00FF000000FFFF0000FF
00FFFF0000FFFF0000000000FFFFFF0000FF00FF00FF0000FF00FFFF00000000FFFFFF00
0000000000FF00FFFFFFFF0000FFFFFFFFFF00FFFFFFFFFF00000000FFFFFFFF000000FF
FF00FFFFFF00FF000000FFFFFFFFFF00FF00FFFFFF00FFFF00FFFF0000FF00000000FF00
0000FF00FFFFFF00FFFFFFFF00FF00000000FFFFFF
000000FFFF00FFFFFFFF00FFFFFF0000FFFFFF00FF00FF0000FFFF0000FFFF0000000000
00FF0000FF00FF00FFFF000000000000FFFF00FF0000FF00000000FF00FFFF000000FFFF
FF000000FFFFFFFF00FFFF00FF000000FFFFFF0000FF00FFFFFF000000FFFF00FF000000
FFFF00FFFF0000FF00000000FFFFFFFFFFFFFF000000000000FFFF00FF00000000FFFF00
0000FF000000FF00FFFF000000000000FF00FF000000FF0000FF0000FFFFFF00FFFF0000
FFFF0000FF000000FF00000000FF00FFFF00FF0000
FFFF00FF0000FF00000000FF000000FFFFFFFFFF0000FF00FFFFFFFF00FF0000FFFF00FF
FF0000FFFFFF0000FF0000FFFF00FFFF000000FF00FFFFFF00FFFF0000FF0000FFFF0000
0000FFFF0000000000FF0000FF00FFFF00000000FFFFFF00000000FFFF000000FF00FFFF
000000FF0000FFFFFF00FFFF0000000000000000FFFF00FFFF000000FF00FFFF00FF0000
FFFF0000FFFF0000FF0000FFFF00FFFF0000FF00FFFF0000FFFFFF00FF000000FF0000FF
FFFFFF00FF00FFFF0000FFFF00FF00FF0000FF00FF
FF0000FF00FFFFFF00FFFF0000FFFF000000000000FFFFFF0000000000FF00FFFFFFFF00
0000FFFFFFFFFF00FF00FFFFFFFF000000FFFF0000FF000000FF0000FFFFFF00FF0000FF
FF00FF0000FFFF00FFFFFF00FF00FF0000FFFF00FF000000FFFF00FF0000FFFF0000FF00
00FFFF0000FFFFFFFFFF000000FFFF00FFFF00FFFFFFFF000000FFFF0000FF0000FF00FF
FFFFFF00FF0000FFFFFF00FF0000FF0000FFFFFF000000FFFFFFFFFF0000FFFF0000FFFF
FFFFFFFF0000FF0000FFFFFFFF0000FF00FFFFFF00
FF00FFFFFF00000000FF0000FFFFFFFF00FFFF00FFFFFFFFFF00FFFF00FF00FF00000000
FFFF000000000000FF00FF00000000FFFF000000FFFFFF00FFFFFF00FF000000FF00FFFF
FFFF0000FFFFFFFF00000000FF00FF00FFFFFFFF0000FFFF000000FF00FFFFFFFF00FF00
FFFFFFFF00FF0000000000FFFF000000FF0000FF00000000FFFF000000FFFFFF00FF00FF
00000000FF00FFFFFFFFFF0000FFFFFF00FF000000FFFF000000000000FFFFFFFF00FF00
0000000000FFFFFF00FF00000000FFFFFF00000000
0000FF000000FFFF00FF00FFFFFFFFFFFF000000FF0000000000FF0000FF00FF00FFFF00
FF0000FFFF00FFFF0000FF00FFFF00FF0000FFFF00000000FF000000FF00FFFF0000FF00
000000FFFFFFFFFFFF00FFFF0000FF00FF00000000FFFFFFFF00FFFFFF0000000000FF00
FF00000000FF00FFFF00FFFFFFFF00FFFFFF00FF00FFFF00FF0000FFFF00000000FF00FF
00FFFF00FF00FF0000000000FFFFFFFFFF0000FFFF000000FFFF00FFFF0000000000FF00
FFFF00FFFF00000000FF00FFFF00FF000000FFFF00
00FFFFFF00FFFFFFFF0000FF000000000000FFFF0000FFFF00FFFFFF00FF00FF00FF0000
FF00FFFFFFFF000000FFFFFF000000FF00FFFFFFFF00FFFF0000FFFF0000FF0000FFFFFF
00FFFF00000000000000FF0000FFFFFF0000FFFF00FF00000000FF000000FFFF00FFFFFF
0000FFFF00FF00FF0000FF00000000FF000000FF00FF0000FF00FFFFFFFF00FFFF0000FF
00FF0000FF00FF00FFFF00FFFFFFFFFFFFFF00FF0000FFFF000000FF0000FFFF00FFFFFF
000000FF0000FFFF00FF00FF0000FF00FFFF000000
00FF000000FF00000000FFFFFF00FFFF00FFFFFFFF00FF0000FF000000FF00FF00FF00FF
FFFF0000000000FFFF00000000FFFF0000FF00000000FF0000FFFFFFFF00FF00FFFFFFFF
FF000000FFFF00FFFF00FF00FFFFFFFFFF00FF0000FF00FFFF00FF00FFFF000000FF0000
00FFFFFFFF0000FF00FFFFFF00FFFF0000FFFF0000FF00FFFFFF0000000000FF0000FFFF
FF0000FFFFFF0000FF0000FF00000000000000FF00FFFFFFFF00FFFFFF00FF0000FF0000
00FFFF0000FFFFFFFF0000FF00FFFFFF000000FFFF
00FF00FFFF0000FFFF00FF000000FF0000FF00000000FF00FFFFFF00FFFFFF0000FF00FF
000000FFFF00FFFFFFFF00FFFF000000FFFFFF00FFFF0000FFFFFFFFFFFF0000FF000000
0000FFFF000000FF0000FF00FF0000000000FF00FFFFFF000000FF00FF0000FFFF0000FF
FF0000000000FFFFFF00000000FF0000FFFFFFFF00FF00FF000000FFFF00FFFFFF00FF00
0000FFFFFFFFFF00FF00FFFFFF00FFFF00FFFF0000FF00000000FF000000FF00FFFFFF00
FFFFFFFF00FF00000000FFFFFF00000000FFFF0000
FFFFFF000000FFFFFFFF0000FFFF0000FFFFFF00FFFF0000FF000000FF000000FFFFFF00
00FFFF000000FF00000000FF0000FFFF00000000FF0000FFFFFFFFFFFFFFFF00FF00FFFF
00FFFFFFFF00FFFFFF00FF00FF00FFFF00FFFFFF00000000FFFF0000FF00FFFFFFFF00FF
0000FFFF00FFFFFFFFFF00FFFF0000FFFFFFFFFFFF0000FF00FFFF000000FF000000FF00
FFFF000000000000FF00FF000000FF0000FF0000FFFFFF00FFFF0000FFFF0000FF000000
FF00000000FF00FFFF00FF000000FFFF00FF0000FF
FF000000FFFF0000000000FFFFFFFF00FF000000FF0000FFFFFF00FFFFFF00FFFFFFFFFF
00FF0000FFFF0000FFFF00FF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFF0000FF00
00FF00000000FF000000FF00FF00FF0000FF000000FFFF00FF0000FFFFFF0000000000FF
00FFFFFFFF000000000000FF0000FFFFFFFFFFFFFFFF00FF00FF0000FFFF0000FFFF0000
FF0000FFFF00FFFF0000FF00FFFF0000FFFFFF00FF000000FF0000FFFFFFFF00FF00FFFF
0000FFFF00FF00FF0000FF00FFFF000000FF00FFFF
FFFF00FFFFFFFF00FFFF00FF00000000FF00FFFF0000FFFFFFFFFF00000000FF00000000
00FF00FFFFFFFF00FF0000FF00FF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFF00FF00
FFFFFF00FFFF0000FFFF0000FF00FF00FFFFFF00FFFFFFFF0000FFFFFFFFFF00FFFF00FF
00FF00000000FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF00FF0000FF
FFFF00FF0000FF0000FFFFFF000000FFFFFFFFFF0000FFFF0000FFFFFFFFFFFF0000FF00
00FFFFFFFF0000FF00FFFFFF000000FFFF0000FF00
FFFFFF0000000000FF0000FF00FFFF00FF00FF0000FFFFFFFFFFFFFF00FFFF0000FFFF00
FFFFFF0000000000FF00FFFFFF0000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF000000FF0000FFFFFFFF00FF00FF00FF000000FF00000000FFFFFFFFFFFFFF000000FF
00FF00FFFF00FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00000000FF00FFFF
FFFFFF0000FFFFFF00FF000000FFFF000000000000FFFFFFFF00FF000000000000FFFFFF
00FF00000000FFFFFF00000000FFFF000000FFFFFF
00000000FFFF00FFFFFF00FF00FF0000FF00FF00FFFFFFFFFFFFFFFFFF000000FFFFFFFF
00000000FFFF00FFFFFF00000000FFFFFFFF0000FF0000000000000000000000000000FF
FFFF00FFFFFF00FF00000000FF00FF00FF00FFFF0000FFFF00FF00000000000000FFFF00
00FF00FF0000FF00FFFFFF00FF000000000000000000000000FF00FF00FFFF00FF00FF00
00000000FFFFFFFFFF0000FFFF000000FFFF00FFFF0000000000FF00FFFF00FFFF000000
00FF00FFFF00FF000000FFFF00FF0000FFFF000000
FFFF00FFFFFFFF00000000FF00FF00FFFFFF0000FF000000000000000000FFFF00000000
00FFFF00FF0000FF000000FFFF00FF00000000FFFFFF00FFFF00FFFF00FFFF00FFFF00FF
000000FF000000FF00FFFF00FF00FF00FF00FF0000FFFFFFFF0000FFFF00FFFF00FF0000
FFFFFF0000FFFFFF00000000FF00FFFF00FFFF00FFFF00FFFF0000FF00FF0000FF00FF00
FFFF00FFFFFFFFFFFFFF00FF0000FFFF000000FF0000FFFF00FFFFFF000000FF0000FFFF
00FF00FF0000FF00FFFF000000FF00FFFFFFFF00FF
000000FF00000000FFFF00FF00FF00FF000000FFFFFF00FFFF00FFFF00FFFFFFFF00FFFF
00FF0000FF00FFFFFF00FFFFFFFF0000FFFF00FF000000FF0000FF0000FF0000FF0000FF
00FFFF0000FFFF0000FF0000FF00FF00FF00FF00FFFFFFFFFFFF00FF0000FF0000FF00FF
FFFFFFFF00FF000000FFFF00FF00FF0000FF0000FF0000FF0000FFFFFF0000FFFFFF0000
FF0000FF00000000000000FF00FFFFFFFF00FFFFFF00FF0000FF000000FFFF0000FFFFFF
FF0000FF00FFFFFF000000FFFF0000FF00000000FF
FF00FFFFFF00FFFF000000FF00FF00FF00FFFF00000000FF0000FF0000FF00000000FF00
00FF00FFFFFF00000000FF00000000FFFFFFFF0000FFFF0000FFFFFF00FF00FFFFFF00FF
00FF0000FFFFFFFF00FF00FFFFFF0000FF00FF00FF000000000000FF00FFFFFF00FF00FF
0000000000FF00FFFF000000FF00FF00FFFFFF00FF00FFFFFF00FF000000FFFFFFFFFF00
FF00FFFFFF00FFFF00FFFF0000FF00000000FF000000FF00FFFFFF00FFFFFFFF00FF0000
0000FFFFFF00000000FFFF000000FFFFFF00FFFF00
FFFF00000000FF0000FFFF0000FF00FF00FF0000FFFF00FF00FFFFFF00FF00FFFF00FF00
FFFFFF00000000FFFF00FF00FFFF00FF00000000FFFFFFFF00FF000000FF00FF000000FF
00FF00FFFFFFFFFFFF0000FF000000FFFFFF0000FF00FFFF00FFFF0000FF000000FF00FF
00FFFF00FFFFFF000000FFFF0000FF00FF000000FF00FF000000FF00FFFF000000000000
FF00FF000000FF0000FF0000FFFFFF00FFFF0000FFFF0000FF000000FF00000000FF00FF
FF00FF000000FFFF00FF0000FFFF00000000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{427.625, 640.313},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006[0002P2000`400?l00000o`00003oo`3AcJV/
0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/
0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/
0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/0=7=Z@003@3AcJT20?ooo`X00000203oool<000000@0oooo
1000000<0?ooo`@000000P3oool4000000D0oooo100000020?ooo`8000000P3oool600000080oooo
1000000:0?ooo`@000000P3oool400000080oooo1P0000020?ooo`800000103oool600000080oooo
200000060?ooo`P000002P3oool8000000@0oooo100000080?ooo`800000103oool5000000P0oooo
0P0000040?ooo`8000001P3oool4000000@0oooo0P0000040?ooo`H000000P3oool600000080oooo
1P0000020?ooo`8000000P3oool2000000P0oooo1P0000020?ooo`8000000P3oool800000080oooo
100000040?ooo`@000000P3oool2000000@0oooo0P0000020?ooo`P00000103oool00`000000oooo
0?ooo`0400000080oooo0P0000060?ooo`X000000P3oool2000000@0oooo0P0000020?ooo`H00000
1P3oool2000000P0oooo1P00000?0=7=Z@003@3AcJT20?ooo`X00000203oool<000000@0oooo1000
000<0?ooo`@000000P3oool4000000D0oooo100000020?ooo`8000000P3oool600000080oooo1000
000:0?ooo`@000000P3oool400000080oooo1P0000020?ooo`800000103oool600000080oooo2000
00060?ooo`P000002P3oool8000000@0oooo100000080?ooo`800000103oool5000000P0oooo0P00
00040?ooo`8000001P3oool4000000@0oooo0P0000040?ooo`H000000P3oool600000080oooo1P00
00020?ooo`8000000P3oool2000000P0oooo1P0000020?ooo`8000000P3oool800000080oooo1000
00040?ooo`@000000P3oool2000000@0oooo0P0000020?ooo`P00000103oool00`000000oooo0?oo
o`0400000080oooo0P0000060?ooo`X000000P3oool2000000@0oooo0P0000020?ooo`H000001P3o
ool2000000P0oooo1P00000?0=7=Z@003@3AcJT4000000@0oooo0P00000<0?ooo`800000103oool2
000000P0oooo0P0000020?ooo``000001P3oool200000080oooo1@0000060?ooo`@00000103oool4
000000h0oooo0P0000020?ooo`8000001P3oool2000000H0oooo1P0000040?ooo`@00000103oool2
00000080oooo1P0000040?ooo`8000000P3oool:000000@0oooo0P0000020?ooo`@00000303oool6
000000<0oooo2P0000020?ooo`@000000P3oool6000000P0oooo1P0000040?ooo`@00000103oool4
000000@0oooo100000020?ooo`8000000P3oool8000000@0oooo100000020?ooo`800000103oool2
00000080oooo0P0000080?ooo`8000000P3oool200000080oooo100000020?ooo`800000103oool2
00000080oooo0`0000020?ooo`8000001P3oool8000000@0oooo0P0000060?ooo`H000000P3oool2
000000@0oooo200000020?ooo`P00000103oool?0=7=Z@003@3AcJT4000000@0oooo0P00000<0?oo
o`800000103oool2000000P0oooo0P0000020?ooo``000001P3oool200000080oooo1@0000060?oo
o`@00000103oool4000000h0oooo0P0000020?ooo`8000001P3oool2000000H0oooo1P0000040?oo
o`@00000103oool200000080oooo1P0000040?ooo`8000000P3oool:000000@0oooo0P0000020?oo
o`@00000303oool6000000<0oooo2P0000020?ooo`@000000P3oool6000000P0oooo1P0000040?oo
o`@00000103oool4000000@0oooo100000020?ooo`8000000P3oool8000000@0oooo100000020?oo
o`800000103oool200000080oooo0P0000080?ooo`8000000P3oool200000080oooo100000020?oo
o`800000103oool200000080oooo0`0000020?ooo`8000001P3oool8000000@0oooo0P0000060?oo
o`H000000P3oool2000000@0oooo200000020?ooo`P00000103oool?0=7=Z@003@3AcJT20?ooo`80
00000P3oool400000080oooo300000020?ooo`@000000P3oool800000080oooo0P0000040?ooo`80
0000103oool800000080oooo0P0000030?ooo`P00000203oool200000080oooo3P0000020?ooo`80
00000P3oool600000080oooo1P0000040?ooo`H00000203oool4000000@0oooo1P0000020?ooo`80
0000103oool2000000P0oooo1000000@0?ooo`8000001`3oool2000000@0oooo0P0000020?ooo`80
00001P3oool2000000`0oooo0P0000080?ooo`8000000P3oool4000000P0oooo0P0000020?ooo`80
00000P3oool2000000@0oooo0P0000020?ooo`@000001P3oool600000080oooo0P0000020?ooo`P0
00000P3oool200000080oooo0P0000060?ooo`H000000P3oool2000000D0oooo200000040?ooo`80
00000P3oool400000080oooo1P0000040?ooo`@000000P3oool4000000@0oooo0P0000020?ooo`80
0000103oool200000080oooo0P00000?0=7=Z@003@3AcJT20?ooo`8000000P3oool400000080oooo
300000020?ooo`@000000P3oool800000080oooo0P0000040?ooo`800000103oool800000080oooo
0P0000030?ooo`P00000203oool200000080oooo3P0000020?ooo`8000000P3oool600000080oooo
1P0000040?ooo`H00000203oool4000000@0oooo1P0000020?ooo`800000103oool2000000P0oooo
1000000@0?ooo`8000001`3oool2000000@0oooo0P0000020?ooo`8000001P3oool2000000`0oooo
0P0000080?ooo`8000000P3oool4000000P0oooo0P0000020?ooo`8000000P3oool2000000@0oooo
0P0000020?ooo`@000001P3oool600000080oooo0P0000020?ooo`P000000P3oool200000080oooo
0P0000060?ooo`H000000P3oool2000000D0oooo200000040?ooo`8000000P3oool400000080oooo
1P0000040?ooo`@000000P3oool4000000@0oooo0P0000020?ooo`800000103oool200000080oooo
0P00000?0=7=Z@003@3AcJT400000080oooo0P0000060?ooo`800000103oool2000000H0oooo0P00
00020?ooo`800000103oool200000080oooo0P0000020?ooo`@000000P3oool4000000@0oooo0P00
00020?ooo`80000000<0oooo0000000000000P0000040?ooo`8000000P3oool800000080oooo0P00
00040?ooo`800000103oool200000080oooo0P0000020?ooo`800000103oool4000000@0oooo1P00
00040?ooo`X00000203oool2000000H0oooo1P0000020?ooo`P00000503oool900000080oooo1000
00020?ooo`8000000P3oool600000080oooo300000020?ooo`P000000P3oool2000000`0oooo1000
00020?ooo`8000000P3oool400000080oooo0P00000:0?ooo`8000001P3oool4000000@0oooo0P00
00020?ooo`8000000P3oool200000080oooo1P0000040?ooo`@0000000<0oooo0000000000001000
00040?ooo`8000000P3oool400000080oooo0P0000060?ooo`800000203oool200000080oooo0P00
00080?ooo`@000000P3oool400000080oooo0P00000?0=7=Z@003@3AcJT400000080oooo0P000006
0?ooo`800000103oool2000000H0oooo0P0000020?ooo`800000103oool200000080oooo0P000002
0?ooo`@000000P3oool4000000@0oooo0P0000020?ooo`80000000<0oooo0000000000000P000004
0?ooo`8000000P3oool800000080oooo0P0000040?ooo`800000103oool200000080oooo0P000002
0?ooo`800000103oool4000000@0oooo1P0000040?ooo`X00000203oool2000000H0oooo1P000002
0?ooo`P00000503oool900000080oooo100000020?ooo`8000000P3oool600000080oooo30000002
0?ooo`P000000P3oool2000000`0oooo100000020?ooo`8000000P3oool400000080oooo0P00000:
0?ooo`8000001P3oool4000000@0oooo0P0000020?ooo`8000000P3oool200000080oooo1P000004
0?ooo`@0000000<0oooo000000000000100000040?ooo`8000000P3oool400000080oooo0P000006
0?ooo`800000203oool200000080oooo0P0000080?ooo`@000000P3oool400000080oooo0P00000?
0=7=Z@003@3AcJT20?ooo`8000000P3oool200000080oooo1P0000020?ooo`@000000P3oool60000
0080oooo0P0000020?ooo`@000000P3oool200000080oooo0P0000060?ooo`8000000P3oool40000
0080oooo0P0000000`3oool00000000000080?ooo`@00000103oool200000080oooo0P0000020?oo
o`@000000P3oool400000080oooo0P0000020?ooo`8000000P3oool4000000P0oooo0P0000080?oo
o`800000103oool200000080oooo200000020?ooo`H00000103oool4000000@0oooo0P0000020?oo
oa@000000`3oool2000000H0oooo0P0000020?ooo`8000000P3oool2000000@0oooo100000040?oo
o`800000103oool4000000@0oooo0P0000020?ooo`8000000P3oool<000000H0oooo100000060?oo
o``000000P3oool6000000P0oooo100000020?ooo`8000000P3oool2000000@0oooo1P0000050?oo
o`800000203oool4000000H0oooo200000020?ooo`P000000P3oool200000080oooo200000060?oo
o`8000000P3oool2000000l0dLfY000=0=7=Z@80oooo0P0000020?ooo`8000000P3oool600000080
oooo100000020?ooo`H000000P3oool200000080oooo100000020?ooo`8000000P3oool2000000H0
oooo0P0000020?ooo`@000000P3oool2000000030?ooo`000000000000P0oooo100000040?ooo`80
00000P3oool200000080oooo100000020?ooo`@000000P3oool200000080oooo0P0000020?ooo`@0
0000203oool2000000P0oooo0P0000040?ooo`8000000P3oool800000080oooo1P0000040?ooo`@0
0000103oool200000080oooo500000030?ooo`8000001P3oool200000080oooo0P0000020?ooo`80
0000103oool4000000@0oooo0P0000040?ooo`@00000103oool200000080oooo0P0000020?ooo``0
00001P3oool4000000H0oooo300000020?ooo`H00000203oool400000080oooo0P0000020?ooo`80
0000103oool6000000D0oooo0P0000080?ooo`@000001P3oool800000080oooo200000020?ooo`80
00000P3oool8000000H0oooo0P0000020?ooo`8000003`3AcJT000d0dLfY100000020?ooo`800000
0P3oool2000000@0oooo100000060?ooo`8000001P3oool4000000H0oooo100000020?ooo`H00000
0P3oool2000000H0oooo0`0000020?ooo`P00000203oool400000080oooo0P0000060?ooo`800000
0P3oool200000080oooo0P0000020?ooo`800000303oool:00000080oooo100000020?ooo`800000
103oool200000080oooo0P0000040?ooo`H00000203oool4000000@0oooo0P0000040?ooo`800000
103oool200000080oooo0`0000020?ooo`H000000P3oool200000080oooo0P0000020?ooo`@00000
203oool6000000P0oooo100000020?ooo`800000103oool2000000@0oooo2000000:0?ooo`800000
103oool2000000H0oooo0P00000<0?ooo`8000000P3oool200000080oooo0P0000020?ooo`@00000
103oool700000080oooo2000000:0?ooo`800000103oool4000000@0oooo0P0000020?ooo`800000
0P3oool2000000@0oooo0P0000020?ooo`H000000P3oool2000000l0dLfY000=0=7=Z@@000000P3o
ool200000080oooo0P0000040?ooo`@000001P3oool2000000H0oooo100000060?ooo`@000000P3o
ool600000080oooo0P0000060?ooo`<000000P3oool8000000P0oooo100000020?ooo`8000001P3o
ool200000080oooo0P0000020?ooo`8000000P3oool2000000`0oooo2P0000020?ooo`@000000P3o
ool2000000@0oooo0P0000020?ooo`800000103oool6000000P0oooo100000040?ooo`800000103o
ool2000000@0oooo0P0000020?ooo`<000000P3oool600000080oooo0P0000020?ooo`8000000P3o
ool4000000P0oooo1P0000080?ooo`@000000P3oool2000000@0oooo0P0000040?ooo`P000002P3o
ool2000000@0oooo0P0000060?ooo`800000303oool200000080oooo0P0000020?ooo`8000000P3o
ool4000000@0oooo1`0000020?ooo`P000002P3oool2000000@0oooo100000040?ooo`8000000P3o
ool200000080oooo0P0000040?ooo`8000000P3oool600000080oooo0P00000?0=7=Z@003@3AcJT4
0?ooo`@000000P3oool200000080oooo1000000:0?ooo`P000002P3oool200000080oooo0P000004
0?ooo`@000000P3oool5000000H0oooo0P0000040?ooo`X000001P3oool800000080oooo0P000002
0?ooo`8000000P3oool200000080oooo300000040?ooo`8000001P3oool200000080oooo0P000002
0?ooo`@000000P3oool200000080oooo100000040?ooo`X00000203oool600000080oooo10000002
0?ooo`030000003oool0oooo00@0oooo0P0000060?ooo`@000000P3oool2000000`0oooo0P00000<
0?ooo`8000000P3oool200000080oooo100000020?ooo`@00000103oool200000080oooo2P000002
0?ooo`@000000P3oool600000080oooo300000020?ooo`8000000P3oool200000080oooo0P000008
0?ooo`030000003oool0oooo0080oooo100000040?ooo`8000000P3oool:00000080oooo10000008
0?ooo`@000000P3oool200000080oooo100000020?ooo`800000103oool4000000l0dLfY000=0=7=
Z@@0oooo100000020?ooo`8000000P3oool4000000X0oooo2000000:0?ooo`8000000P3oool20000
00@0oooo100000020?ooo`D000001P3oool2000000@0oooo2P0000060?ooo`P000000P3oool20000
0080oooo0P0000020?ooo`8000000P3oool<000000@0oooo0P0000060?ooo`8000000P3oool20000
0080oooo100000020?ooo`8000000P3oool4000000@0oooo2P0000080?ooo`H000000P3oool40000
0080oooo00<000000?ooo`3oool0103oool2000000H0oooo100000020?ooo`800000303oool20000
00`0oooo0P0000020?ooo`8000000P3oool400000080oooo100000040?ooo`8000000P3oool:0000
0080oooo100000020?ooo`H000000P3oool<00000080oooo0P0000020?ooo`8000000P3oool20000
00P0oooo00<000000?ooo`3oool00P3oool4000000@0oooo0P0000020?ooo`X000000P3oool40000
00P0oooo100000020?ooo`8000000P3oool400000080oooo0P0000040?ooo`@000003`3AcJT000d0
dLfY1P3oool200000080oooo0P0000020?ooo`8000003P3oool2000000@0oooo300000020?ooo`80
00000P3oool4000000H0oooo0P0000090?ooo`H00000103oool2000000X0oooo0P0000040?ooo`@0
00000P3oool200000080oooo0P0000020?ooo`800000103oool2000000@0oooo1P0000020?ooo`H0
00000P3oool200000080oooo0P0000060?ooo`@00000203oool2000000@0oooo0P0000020?ooo`P0
0000103oool4000000D0oooo200000020?ooo`H000001P3oool>00000080oooo300000020?ooo`80
00000P3oool2000000H0oooo0P0000020?ooo`@000000P3oool2000000@0oooo0P0000060?ooo`80
00000P3oool2000000@0oooo100000040?ooo`800000103oool400000080oooo0P0000020?ooo`80
00000P3oool700000080oooo100000080?ooo`@00000103oool2000000H0oooo0P0000020?ooo`P0
00001P3oool4000000H0oooo1P0000020?ooo`l0dLfY000=0=7=Z@H0oooo0P0000020?ooo`800000
0P3oool2000000h0oooo0P0000040?ooo``000000P3oool200000080oooo100000060?ooo`800000
2@3oool6000000@0oooo0P00000:0?ooo`800000103oool400000080oooo0P0000020?ooo`800000
0P3oool2000000@0oooo0P0000040?ooo`H000000P3oool600000080oooo0P0000020?ooo`800000
1P3oool4000000P0oooo0P0000040?ooo`8000000P3oool8000000@0oooo100000050?ooo`P00000
0P3oool6000000H0oooo3P0000020?ooo``000000P3oool200000080oooo0P0000060?ooo`800000
0P3oool400000080oooo0P0000040?ooo`8000001P3oool200000080oooo0P0000040?ooo`@00000
103oool2000000@0oooo100000020?ooo`8000000P3oool200000080oooo1`0000020?ooo`@00000
203oool4000000@0oooo0P0000060?ooo`8000000P3oool8000000H0oooo100000060?ooo`H00000
0P3oool?0=7=Z@003@3AcJT80?ooo`@000000P3oool200000080oooo3P0000020?ooo`@00000103o
ool2000000@0oooo100000020?ooo`8000002P3oool;000000@0oooo1P0000020?ooo`X000000P3o
ool4000000H0oooo100000020?ooo`8000000P3oool400000080oooo100000040?ooo`@00000103o
ool400000080oooo0P0000020?ooo`H00000303oool600000080oooo0P0000040?ooo`8000000P3o
ool4000000T0oooo0P0000040?ooo`@00000103oool8000000@0oooo0P0000040?ooo`8000000P3o
ool2000000@0oooo0P0000040?ooo`@000000P3oool200000080oooo1P0000020?ooo`8000001P3o
ool600000080oooo1P0000020?ooo`8000000P3oool4000000P0oooo1P0000060?ooo`@000000P3o
ool2000000@0oooo00<000000?ooo`3oool00P00000<0?ooo`8000000P3oool400000080oooo1P00
00020?ooo`800000103oool200000080oooo1P00000:0?ooo`800000103oool?0=7=Z@003@3AcJT8
0?ooo`@000000P3oool200000080oooo3P0000020?ooo`@00000103oool2000000@0oooo10000002
0?ooo`8000002P3oool;000000@0oooo1P0000020?ooo`X000000P3oool4000000H0oooo10000002
0?ooo`8000000P3oool400000080oooo100000040?ooo`@00000103oool400000080oooo0P000002
0?ooo`H00000303oool600000080oooo0P0000040?ooo`8000000P3oool4000000T0oooo0P000004
0?ooo`@00000103oool8000000@0oooo0P0000040?ooo`8000000P3oool2000000@0oooo0P000004
0?ooo`@000000P3oool200000080oooo1P0000020?ooo`8000001P3oool600000080oooo1P000002
0?ooo`8000000P3oool4000000P0oooo1P0000060?ooo`@000000P3oool2000000@0oooo00<00000
0?ooo`3oool00P00000<0?ooo`8000000P3oool400000080oooo1P0000020?ooo`800000103oool2
00000080oooo1P00000:0?ooo`800000103oool?0=7=Z@003@3AcJT:000000H0oooo100000040?oo
o`800000103oool200000080oooo0P0000080?ooo`H000001P3oool;000000@0oooo0P0000040?oo
o`H00000103oool4000000@0oooo0P0000060?ooo`8000000P3oool6000000H0oooo100000060?oo
o`8000000P3oool4000000P0oooo0P0000020?ooo`8000000P3oool2000000@0oooo3P0000040?oo
o`@000000P3oool400000080oooo0P00000=0?ooo`H00000203oool2000000@0oooo1P0000020?oo
o`@000000P3oool200000080oooo100000020?ooo`@000001P3oool4000000@0oooo100000020?oo
o`H00000103oool4000000@0oooo100000020?ooo`800000303oool2000000X0oooo0P0000020?oo
o`8000000P3oool300000080oooo0P0000020?ooo``000000P3oool2000000H0oooo0P0000060?oo
o`H000000P3oool2000000@0oooo300000020?ooo`8000003`3AcJT000d0dLfY2P0000060?ooo`@0
0000103oool2000000@0oooo0P0000020?ooo`800000203oool6000000H0oooo2`0000040?ooo`80
0000103oool6000000@0oooo100000040?ooo`8000001P3oool200000080oooo1P0000060?ooo`@0
00001P3oool200000080oooo100000080?ooo`8000000P3oool200000080oooo0P0000040?ooo`h0
0000103oool400000080oooo100000020?ooo`8000003@3oool6000000P0oooo0P0000040?ooo`H0
00000P3oool400000080oooo0P0000020?ooo`@000000P3oool4000000H0oooo100000040?ooo`@0
00000P3oool6000000@0oooo100000040?ooo`@000000P3oool2000000`0oooo0P00000:0?ooo`80
00000P3oool200000080oooo0`0000020?ooo`8000000P3oool<00000080oooo0P0000060?ooo`80
00001P3oool600000080oooo0P0000040?ooo``000000P3oool2000000l0dLfY000=0=7=Z@@0oooo
0P0000040?ooo`P00000203oool600000080oooo0P0000020?ooo`P00000103oool8000000@0oooo
0P0000030?ooo`H000000P3oool4000000@0oooo1P0000080?ooo`P000000P3oool2000000@0oooo
2000000:0?ooo`@00000303oool400000080oooo0P0000020?ooo`@00000103oool2000000@0oooo
0P0000020?ooo`@000001P3oool200000080oooo0P0000020?ooo`d00000103oool:00000080oooo
100000040?ooo`@000001P3oool4000000H0oooo0P0000020?ooo`H00000203oool200000080oooo
0P0000040?ooo`H00000203oool200000080oooo0P0000020?ooo``000000P3oool:00000080oooo
0P0000020?ooo`8000001@3oool4000000@0oooo0P0000040?ooo`@000000P3oool600000080oooo
1P0000040?ooo`@000000P3oool4000000@0oooo0P0000040?ooo`@000003`3AcJT000d0dLfY103o
ool2000000@0oooo200000080?ooo`H000000P3oool200000080oooo200000040?ooo`P00000103o
ool2000000<0oooo1P0000020?ooo`@00000103oool6000000P0oooo200000020?ooo`800000103o
ool8000000X0oooo1000000<0?ooo`@000000P3oool200000080oooo100000040?ooo`800000103o
ool200000080oooo100000060?ooo`8000000P3oool200000080oooo3@0000040?ooo`X000000P3o
ool4000000@0oooo100000060?ooo`@000001P3oool200000080oooo1P0000080?ooo`8000000P3o
ool2000000@0oooo1P0000080?ooo`8000000P3oool200000080oooo300000020?ooo`X000000P3o
ool200000080oooo0P0000050?ooo`@00000103oool2000000@0oooo100000020?ooo`H000000P3o
ool6000000@0oooo100000020?ooo`@00000103oool2000000@0oooo1000000?0=7=Z@003@3AcJT2
0?ooo`@000000P3oool4000000@0oooo0P0000020?ooo`P00000103oool400000080oooo0P000004
0?ooo`8000000P3oool4000000@0oooo0P0000020?ooo`@000000P3oool3000000@0oooo10000008
0?ooo`800000303oool2000000@0oooo100000020?ooo`@00000103oool200000080oooo2P00000@
0?ooo`8000000P3oool200000080oooo0P0000080?ooo`H000000P3oool2000000X0oooo10000002
0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`8000000P3oool4000000@0oooo0P000006
0?ooo`8000000P3oool4000000X0oooo0P0000020?ooo`H000000P3oool2000000@0oooo2P000002
0?ooo`8000000P3oool4000000@0oooo2P0000020?ooo`8000000P3oool2000000@0oooo0P000004
0?ooo`@00000103oool2000000H0oooo100000000`3oool0000000000004000000P0oooo1P000006
0?ooo`8000001P3oool2000000P0oooo0P0000020?ooo`800000203oool600000080oooo3`3AcJT0
00d0dLfY0P3oool400000080oooo100000040?ooo`8000000P3oool8000000@0oooo100000020?oo
o`800000103oool200000080oooo100000040?ooo`8000000P3oool400000080oooo0`0000040?oo
o`@00000203oool2000000`0oooo0P0000040?ooo`@000000P3oool4000000@0oooo0P0000020?oo
o`X00000403oool200000080oooo0P0000020?ooo`800000203oool600000080oooo0P00000:0?oo
o`@000000P3oool2000000@0oooo00<000000?ooo`3oool00P3oool200000080oooo100000040?oo
o`8000001P3oool200000080oooo1000000:0?ooo`8000000P3oool600000080oooo0P0000040?oo
o`X000000P3oool200000080oooo100000040?ooo`X000000P3oool200000080oooo0P0000040?oo
o`800000103oool4000000@0oooo0P0000060?ooo`@0000000<0oooo000000000000100000080?oo
o`H000001P3oool2000000H0oooo0P0000080?ooo`8000000P3oool2000000P0oooo1P0000020?oo
o`l0dLfY000=0=7=Z@80oooo0P0000060?ooo`8000000P3oool400000080oooo0P0000040?ooo`80
00000P3oool4000000H0oooo1P0000020?ooo`800000203oool4000000D0oooo0P0000020?ooo`@0
0000303oool>00000080oooo100000060?ooo`8000000P3oool400000080oooo0P0000040?ooo`80
0000503oool400000080oooo0P0000020?ooo`P00000103oool400000080oooo2P0000060?ooo`D0
00000P3oool400000080oooo0P0000080?ooo`P000000P3oool2000000h0oooo100000040?ooo`@0
00000P3oool4000000@0oooo0P0000060?ooo`@00000203oool2000000@0oooo0P0000020?ooo`80
00000P3oool200000080oooo100000020?ooo`@00000203oool8000000D0oooo0P00000<0?ooo`80
00002P3oool800000080oooo200000020?ooo`8000000P3oool8000000@0oooo0P00000?0=7=Z@00
3@3AcJT20?ooo`8000001P3oool200000080oooo100000020?ooo`800000103oool200000080oooo
100000060?ooo`H000000P3oool2000000P0oooo100000050?ooo`8000000P3oool4000000`0oooo
3P0000020?ooo`@000001P3oool200000080oooo100000020?ooo`800000103oool2000001@0oooo
100000020?ooo`8000000P3oool8000000@0oooo100000020?ooo`X000001P3oool500000080oooo
100000020?ooo`800000203oool800000080oooo0P00000>0?ooo`@00000103oool400000080oooo
100000040?ooo`8000001P3oool4000000P0oooo0P0000040?ooo`8000000P3oool200000080oooo
0P0000020?ooo`@000000P3oool4000000P0oooo200000050?ooo`800000303oool2000000X0oooo
200000020?ooo`P000000P3oool200000080oooo200000040?ooo`8000003`3AcJT000d0dLfY0P3o
ool200000080oooo1P0000020?ooo`8000001P3oool600000080oooo0P00000:0?ooo`8000001P3o
ool:000000T0oooo1000000@0?ooo`800000103oool2000000@0oooo1000000:0?ooo`@000001P3o
ool600000080oooo500000060?ooo`@00000103oool200000080oooo100000060?ooo`800000103o
ool200000080oooo1P0000030?ooo`@000001P3oool:000000@0oooo0P0000020?ooo`8000000P3o
ool>000000P0oooo0P0000020?ooo`800000203oool8000000`0oooo1P0000020?ooo`8000000P3o
ool200000080oooo0P0000060?ooo`8000000P3oool8000000@0oooo0P0000020?ooo`D000000P3o
ool<00000080oooo2P0000040?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`8000000P3o
ool2000000@0oooo0P0000020?ooo`@000003`3AcJT000d0dLfY0P3oool200000080oooo1P000002
0?ooo`8000001P3oool600000080oooo0P00000:0?ooo`8000001P3oool:000000T0oooo1000000@
0?ooo`800000103oool2000000@0oooo1000000:0?ooo`@000001P3oool600000080oooo50000006
0?ooo`@00000103oool200000080oooo100000060?ooo`800000103oool200000080oooo1P000003
0?ooo`@000001P3oool:000000@0oooo0P0000020?ooo`8000000P3oool>000000P0oooo0P000002
0?ooo`800000203oool8000000`0oooo1P0000020?ooo`8000000P3oool200000080oooo0P000006
0?ooo`8000000P3oool8000000@0oooo0P0000020?ooo`D000000P3oool<00000080oooo2P000004
0?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`8000000P3oool2000000@0oooo0P000002
0?ooo`@000003`3AcJT000d0dLfY100000020?ooo`800000103oool400000080oooo1P0000040?oo
o`@000000P3oool:00000080oooo1P0000040?ooo`8000003@3oool200000080oooo400000020?oo
o`@000000P3oool4000000h0oooo0P0000020?ooo`H00000103oool4000000@0oooo0P0000040?oo
o`800000103oool200000080oooo1P0000080?ooo`@000002P3oool600000080oooo0P0000040?oo
o`D000002P3oool2000000@0oooo0P0000020?ooo`@000000P3oool200000080oooo0P0000040?oo
o`800000103oool200000080oooo200000020?ooo`8000000P3oool8000000@0oooo0P0000020?oo
o``00000103oool400000080oooo0P0000020?ooo`8000000P3oool600000080oooo0P0000040?oo
o`8000000P3oool400000080oooo00<000000?ooo`3oool00P3oool4000000@0oooo0P0000040?oo
o`@00000103oool2000000P0oooo100000020?ooo`@000000P3oool200000080oooo0P0000020?oo
o`@000000P3oool200000080oooo3`3AcJT000d0dLfY100000020?ooo`800000103oool400000080
oooo1P0000040?ooo`@000000P3oool:00000080oooo1P0000040?ooo`8000003@3oool200000080
oooo400000020?ooo`@000000P3oool4000000h0oooo0P0000020?ooo`H00000103oool4000000@0
oooo0P0000040?ooo`800000103oool200000080oooo1P0000080?ooo`@000002P3oool600000080
oooo0P0000040?ooo`D000002P3oool2000000@0oooo0P0000020?ooo`@000000P3oool200000080
oooo0P0000040?ooo`800000103oool200000080oooo200000020?ooo`8000000P3oool8000000@0
oooo0P0000020?ooo``00000103oool400000080oooo0P0000020?ooo`8000000P3oool600000080
oooo0P0000040?ooo`8000000P3oool400000080oooo00<000000?ooo`3oool00P3oool4000000@0
oooo0P0000040?ooo`@00000103oool2000000P0oooo100000020?ooo`@000000P3oool200000080
oooo0P0000020?ooo`@000000P3oool200000080oooo3`3AcJT000d0dLfY0P0000060?ooo`H00000
1P3oool2000000P0oooo0P0000020?ooo`800000103oool2000000H0oooo0P0000080?ooo`l00000
0P3oool2000000@0oooo0P0000040?ooo`8000001P3oool200000080oooo0P00000B0?ooo`@00000
103oool6000000P0oooo1P0000020?ooo`@000000P3oool2000000@0oooo2P00000>0?ooo`800000
1P3oool6000000<0oooo300000020?ooo`@000000P3oool2000000H0oooo100000020?ooo`@00000
0P3oool400000080oooo0P0000040?ooo`8000000P3oool200000080oooo0P0000040?ooo`800000
0P3oool400000080oooo0P0000040?ooo`800000103oool6000000H0oooo100000020?ooo`800000
103oool400000080oooo100000020?ooo`8000001@3oool6000000P0oooo1P0000080?ooo`X00000
1P3oool200000080oooo0P0000020?ooo`8000000P3oool2000000H0oooo0P00000?0=7=Z@003@3A
cJT2000000H0oooo1P0000060?ooo`800000203oool200000080oooo0P0000040?ooo`8000001P3o
ool2000000P0oooo3`0000020?ooo`800000103oool2000000@0oooo0P0000060?ooo`8000000P3o
ool200000180oooo100000040?ooo`H00000203oool600000080oooo100000020?ooo`800000103o
ool:000000h0oooo0P0000060?ooo`H000000`3oool<00000080oooo100000020?ooo`8000001P3o
ool400000080oooo100000020?ooo`@000000P3oool2000000@0oooo0P0000020?ooo`8000000P3o
ool2000000@0oooo0P0000020?ooo`@000000P3oool2000000@0oooo0P0000040?ooo`H000001P3o
ool400000080oooo0P0000040?ooo`@000000P3oool400000080oooo0P0000050?ooo`H00000203o
ool6000000P0oooo2P0000060?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000001P3o
ool2000000l0dLfY000=0=7=Z@8000000P3oool6000000@0oooo200000020?ooo`P000000P3oool2
00000080oooo100000020?ooo`H000000P3oool8000000@0oooo0P0000030?ooo`8000001P3oool6
00000080oooo100000020?ooo`H000000P3oool200000080oooo4P0000080?ooo`800000303oool2
000000H0oooo0P0000020?ooo`8000000P3oool4000000@0oooo0P00000B0?ooo`P00000103oool5
000000@0oooo0P0000040?ooo`@000001P3oool8000000H0oooo0P0000020?ooo`8000001P3oool6
00000080oooo0P0000020?ooo`8000000P3oool400000080oooo0P0000060?ooo`H000000P3oool4
000000@0oooo200000060?ooo`H000001P3oool200000080oooo0P0000020?ooo`D00000103oool:
000000@0oooo2P0000040?ooo`8000002P3oool400000080oooo0P0000020?ooo`8000000P3oool6
000000l0dLfY000=0=7=Z@8000000P3oool6000000@0oooo200000020?ooo`P000000P3oool20000
0080oooo100000020?ooo`H000000P3oool8000000@0oooo0P0000030?ooo`8000001P3oool60000
0080oooo100000020?ooo`H000000P3oool200000080oooo4P0000080?ooo`800000303oool20000
00H0oooo0P0000020?ooo`8000000P3oool4000000@0oooo0P00000B0?ooo`P00000103oool50000
00@0oooo0P0000040?ooo`@000001P3oool8000000H0oooo0P0000020?ooo`8000001P3oool60000
0080oooo0P0000020?ooo`8000000P3oool400000080oooo0P0000060?ooo`H000000P3oool40000
00@0oooo200000060?ooo`H000001P3oool200000080oooo0P0000020?ooo`D00000103oool:0000
00@0oooo2P0000040?ooo`8000002P3oool400000080oooo0P0000020?ooo`8000000P3oool60000
00l0dLfY000=0=7=Z@8000000P3oool2000000@0oooo1P0000040?ooo`8000000P3oool2000000@0
oooo0P0000020?ooo`8000000P3oool2000000H0oooo0P0000060?ooo`800000103oool600000003
0?ooo`0000000000008000000P3oool6000000@0oooo100000060?ooo`8000001P3oool4000000@0
oooo0P0000040?ooo`800000103oool:00000080oooo300000020?ooo`H000000P3oool200000080
oooo0P0000080?oooa@00000103oool200000080oooo0`0000040?ooo`H000000P3oool4000000X0
oooo0P0000040?ooo`P000000P3oool200000080oooo1P0000040?ooo`@000000P3oool200000080
oooo0P0000060?ooo`P00000103oool4000000P0oooo0P0000040?ooo`P00000103oool800000080
oooo0P0000020?ooo`8000000`3oool6000000@0oooo0P0000080?ooo`800000103oool200000080
oooo100000020?ooo`X000001P3oool400000080oooo0P0000040?ooo`l0dLfY000=0=7=Z@800000
0P3oool2000000@0oooo1P0000040?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`800000
0P3oool2000000H0oooo0P0000060?ooo`800000103oool6000000030?ooo`000000000000800000
0P3oool6000000@0oooo100000060?ooo`8000001P3oool4000000@0oooo0P0000040?ooo`800000
103oool:00000080oooo300000020?ooo`H000000P3oool200000080oooo0P0000080?oooa@00000
103oool200000080oooo0`0000040?ooo`H000000P3oool4000000X0oooo0P0000040?ooo`P00000
0P3oool200000080oooo1P0000040?ooo`@000000P3oool200000080oooo0P0000060?ooo`P00000
103oool4000000P0oooo0P0000040?ooo`P00000103oool800000080oooo0P0000020?ooo`800000
0`3oool6000000@0oooo0P0000080?ooo`800000103oool200000080oooo100000020?ooo`X00000
1P3oool400000080oooo0P0000040?ooo`l0dLfY000=0=7=Z@H0oooo1P0000040?ooo`H000000P3o
ool200000080oooo100000020?ooo`8000000P3oool200000080oooo1P0000020?ooo`H000000P3o
ool4000000@0oooo0`0000060?ooo`800000203oool200000080oooo1P0000020?ooo`H00000203o
ool600000080oooo100000040?ooo`8000001P3oool2000000@0oooo0P0000060?ooo`8000001P3o
ool400000080oooo200000040?ooo`800000103oool2000000@0oooo0P0000020?ooo`@000000P3o
ool2000000L0oooo0P0000060?ooo`8000000P3oool:00000080oooo100000040?ooo`8000000P3o
ool200000080oooo0P0000040?ooo`H000001P3oool400000080oooo1P0000040?ooo`8000000P3o
ool4000000`0oooo1P0000040?ooo`8000000P3oool4000000@0oooo0P0000020?ooo`8000000P3o
ool2000000030?ooo`000000000000800000103oool600000080oooo200000020?ooo`@000000P3o
ool2000000H0oooo0P0000040?ooo`8000000P3oool6000000H0oooo1000000?0=7=Z@003@3AcJT6
0?ooo`H00000103oool600000080oooo0P0000020?ooo`@000000P3oool200000080oooo0P000002
0?ooo`H000000P3oool600000080oooo100000040?ooo`<000001P3oool2000000P0oooo0P000002
0?ooo`H000000P3oool6000000P0oooo1P0000020?ooo`@00000103oool2000000H0oooo0P000004
0?ooo`8000001P3oool2000000H0oooo100000020?ooo`P00000103oool2000000@0oooo0P000004
0?ooo`8000000P3oool400000080oooo0P0000070?ooo`8000001P3oool200000080oooo2P000002
0?ooo`@00000103oool200000080oooo0P0000020?ooo`800000103oool6000000H0oooo10000002
0?ooo`H00000103oool200000080oooo1000000<0?ooo`H00000103oool200000080oooo10000004
0?ooo`8000000P3oool200000080oooo0P0000000`3oool0000000000002000000@0oooo1P000002
0?ooo`P000000P3oool400000080oooo0P0000060?ooo`800000103oool200000080oooo1P000006
0?ooo`@000003`3AcJT000d0dLfY200000040?ooo`H00000103oool400000080oooo0P0000060?oo
o`@000000P3oool2000000@0oooo100000040?ooo`@000001`3oool200000080oooo1P0000020?oo
o`P000000P3oool2000000@0oooo100000040?ooo`X00000103oool4000000P0oooo200000020?oo
o`@000000P3oool600000080oooo1P0000060?ooo`800000103oool600000080oooo100000020?oo
o`@000000P3oool2000000H0oooo2@0000020?ooo`H000000P3oool2000000@0oooo0P0000060?oo
o`8000000P3oool400000080oooo0P0000020?ooo`8000000P3oool4000000@0oooo200000060?oo
o`800000203oool400000100oooo0P0000080?ooo`@00000203oool400000080oooo0P0000000`3o
ool00000000000080?ooo`8000001P3oool2000000@0oooo100000060?ooo`P000000P3oool40000
0080oooo0P0000040?ooo`P000000P3oool?0=7=Z@003@3AcJT8000000@0oooo1P0000040?ooo`@0
00000P3oool2000000H0oooo100000020?ooo`800000103oool4000000@0oooo100000070?ooo`80
00000P3oool600000080oooo200000020?ooo`800000103oool4000000@0oooo2P0000040?ooo`@0
0000203oool800000080oooo100000020?ooo`H000000P3oool6000000H0oooo0P0000040?ooo`H0
00000P3oool400000080oooo100000020?ooo`8000001P3oool900000080oooo1P0000020?ooo`80
0000103oool2000000H0oooo0P0000020?ooo`@000000P3oool200000080oooo0P0000020?ooo`@0
0000103oool8000000H0oooo0P0000080?ooo`@00000403oool2000000P0oooo100000080?ooo`@0
00000P3oool2000000030?ooo`000000000000P0oooo0P0000060?ooo`800000103oool4000000H0
oooo200000020?ooo`@000000P3oool2000000@0oooo200000020?ooo`l0dLfY000=0=7=Z@800000
103oool200000080oooo100000040?ooo`H000001P3oool8000000H0oooo1P0000080?ooo`800000
0P3oool700000080oooo0P0000040?ooo`@00000103oool200000080oooo0P0000020?ooo`@00000
203oool2000000@0oooo0P0000020?ooo`@00000303oool2000000@0oooo100000060?ooo`800000
1P3oool2000000X0oooo1P0000040?ooo`@000001P3oool200000080oooo0P0000020?ooo`D00000
103oool2000000H0oooo0P0000060?ooo`H000000P3oool600000080oooo0P0000060?ooo`@00000
0P3oool2000000P0oooo0P0000040?ooo`P000000P3oool8000001@0oooo2P00000<0?ooo`800000
0P3oool2000000030?ooo`00000000000080oooo200000020?ooo`H000000P3oool4000000X0oooo
0P0000040?ooo`@000001P3oool6000000@0oooo0P0000020?ooo`l0dLfY000=0=7=Z@800000103o
ool200000080oooo100000040?ooo`H000001P3oool8000000H0oooo1P0000080?ooo`8000000P3o
ool700000080oooo0P0000040?ooo`@00000103oool200000080oooo0P0000020?ooo`@00000203o
ool2000000@0oooo0P0000020?ooo`@00000303oool2000000@0oooo100000060?ooo`8000001P3o
ool2000000X0oooo1P0000040?ooo`@000001P3oool200000080oooo0P0000020?ooo`D00000103o
ool2000000H0oooo0P0000060?ooo`H000000P3oool600000080oooo0P0000060?ooo`@000000P3o
ool2000000P0oooo0P0000040?ooo`P000000P3oool8000001@0oooo2P00000<0?ooo`8000000P3o
ool2000000030?ooo`00000000000080oooo200000020?ooo`H000000P3oool4000000X0oooo0P00
00040?ooo`@000001P3oool6000000@0oooo0P0000020?ooo`l0dLfY000=0=7=Z@P0oooo10000008
0?ooo`8000002P3oool2000000@0oooo200000040?ooo`X000000P3oool2000000<0oooo0P000002
0?ooo`8000000P3oool4000000P0oooo100000020?ooo`800000303oool600000080oooo0P00000@
0?ooo`H000002P3oool800000080oooo2P0000040?ooo`H000002P3oool400000080oooo0P000003
0?ooo`H000000P3oool600000080oooo1P0000040?ooo`@00000103oool400000080oooo1P000006
0?ooo`X000000P3oool4000000@0oooo0P0000020?ooo`800000103oool200000080oooo50000004
0?ooo`800000403oool4000000030?ooo`00000000000080oooo0P0000040?ooo`8000000P3oool2
000000@0oooo1000000>0?ooo`H000002P3oool2000000P0oooo0P00000?0=7=Z@003@3AcJT80?oo
o`@00000203oool2000000X0oooo0P0000040?ooo`P00000103oool:00000080oooo0P0000030?oo
o`8000000P3oool200000080oooo100000080?ooo`@000000P3oool2000000`0oooo1P0000020?oo
o`800000403oool6000000X0oooo200000020?ooo`X00000103oool6000000X0oooo100000020?oo
o`8000000`3oool600000080oooo1P0000020?ooo`H00000103oool4000000@0oooo100000020?oo
o`H000001P3oool:00000080oooo100000040?ooo`8000000P3oool2000000@0oooo0P0000020?oo
oa@00000103oool200000100oooo100000000`3oool00000000000020?ooo`800000103oool20000
0080oooo0P0000040?ooo`@000003P3oool6000000X0oooo0P0000080?ooo`8000003`3AcJT000d0
dLfY2P00000<0?ooo``000000P3oool4000000@0oooo0P0000020?ooo`@00000103oool2000000H0
oooo1@0000020?ooo`8000000P3oool2000000`0oooo0P0000020?ooo`8000000P3oool<000000@0
oooo100000020?oooa000000103oool<000000@0oooo0P0000020?ooo`800000103oool2000000P0
oooo0P00000>0?ooo`8000000P3oool200000080oooo0`0000040?ooo`@00000103oool4000000@0
oooo1P0000080?ooo`8000000P3oool2000000@0oooo200000040?ooo`8000001P3oool200000080
oooo100000020?ooo`8000000P3oool400000080oooo0P0000040?ooo`800000103oool2000000@0
oooo0P0000020?ooo`@000000P3oool@000000D0oooo100000020?ooo`@000000P3oool200000080
oooo1000000B0?ooo`8000003P3oool:000000l0dLfY000=0=7=Z@X00000303oool<00000080oooo
100000040?ooo`8000000P3oool4000000@0oooo0P0000060?ooo`D000000P3oool200000080oooo
0P00000<0?ooo`8000000P3oool200000080oooo300000040?ooo`@000000P3oool@000000@0oooo
300000040?ooo`8000000P3oool2000000@0oooo0P0000080?ooo`8000003P3oool200000080oooo
0P0000020?ooo`<00000103oool4000000@0oooo100000040?ooo`H00000203oool200000080oooo
0P0000040?ooo`P00000103oool2000000H0oooo0P0000020?ooo`@000000P3oool200000080oooo
100000020?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000000P3oool400000080oooo
400000050?ooo`@000000P3oool400000080oooo0P0000020?ooo`@000004P3oool2000000h0oooo
2P00000?0=7=Z@003@3AcJT20?ooo`800000103oool200000080oooo300000040?ooo`800000103o
ool4000000P0oooo100000080?ooo`P000000`3oool400000080oooo0P0000020?ooo``000000P3o
ool200000080oooo0P0000040?ooo`800000103oool6000000H0oooo0P0000040?ooo`800000103o
ool200000080oooo100000040?ooo`800000103oool600000080oooo0P0000020?ooo`@000000P3o
ool800000080oooo3P0000020?ooo`8000000P3oool00`000000oooo0?ooo`060?ooo`8000000P3o
ool4000000P0oooo0P00000<0?ooo`@000000P3oool4000000@0oooo0P0000020?ooo`@000000P3o
ool600000080oooo0P0000060?ooo`@000001P3oool600000080oooo100000020?ooo`@000000P3o
ool2000000H0oooo0P0000040?ooo`800000103oool200000080oooo1@0000060?ooo`8000000P3o
ool200000080oooo0P00000F0?oooa000000103oool200000080oooo3`3AcJT000d0dLfY0P3oool2
000000@0oooo0P0000020?ooo``00000103oool2000000@0oooo100000080?ooo`@00000203oool8
000000<0oooo100000020?ooo`8000000P3oool<00000080oooo0P0000020?ooo`800000103oool2
000000@0oooo1P0000060?ooo`800000103oool2000000@0oooo0P0000020?ooo`@00000103oool2
000000@0oooo1P0000020?ooo`8000000P3oool400000080oooo200000020?ooo`h000000P3oool2
00000080oooo00<000000?ooo`3oool01P3oool200000080oooo100000080?ooo`800000303oool4
00000080oooo100000040?ooo`8000000P3oool400000080oooo1P0000020?ooo`8000001P3oool4
000000H0oooo1P0000020?ooo`@000000P3oool400000080oooo0P0000060?ooo`800000103oool2
000000@0oooo0P0000020?ooo`D000001P3oool200000080oooo0P0000020?ooo`8000005P3oool@
000000@0oooo0P0000020?ooo`l0dLfY000=0=7=Z@@0oooo1P0000020?ooo`800000103oool20000
00@0oooo1P0000020?ooo`@00000303oool200000080oooo200000040?ooo`80000000<0oooo0000
000000000P0000060?ooo`@00000103oool2000000@0oooo100000020?ooo`8000000P3oool40000
0080oooo100000040?ooo`P000000P3oool400000080oooo100000020?ooo`800000203oool60000
00@0oooo100000020?ooo`8000001P3oool2000000@0oooo100000040?ooo`800000103oool20000
0080oooo0P0000020?ooo`030000003oool0oooo00P000000P3oool2000000`0oooo3P0000060?oo
o`8000000P3oool400000080oooo0P0000060?ooo`8000001P3oool8000000X0oooo0P0000060?oo
o`8000000P3oool2000000H0oooo200000020?ooo`@000000P3oool400000080oooo00<000000?oo
o`3oool00P3oool800000080oooo0P0000020?ooo`8000000P3ooolF000000@0oooo0P0000040?oo
o`800000203oool2000000l0dLfY000=0=7=Z@@0oooo1P0000020?ooo`800000103oool2000000@0
oooo1P0000020?ooo`@00000303oool200000080oooo200000040?ooo`80000000<0oooo00000000
00000P0000060?ooo`@00000103oool2000000@0oooo100000020?ooo`8000000P3oool400000080
oooo100000040?ooo`P000000P3oool400000080oooo100000020?ooo`800000203oool6000000@0
oooo100000020?ooo`8000001P3oool2000000@0oooo100000040?ooo`800000103oool200000080
oooo0P0000020?ooo`030000003oool0oooo00P000000P3oool2000000`0oooo3P0000060?ooo`80
00000P3oool400000080oooo0P0000060?ooo`8000001P3oool8000000X0oooo0P0000060?ooo`80
00000P3oool2000000H0oooo200000020?ooo`@000000P3oool400000080oooo00<000000?ooo`3o
ool00P3oool800000080oooo0P0000020?ooo`8000000P3ooolF000000@0oooo0P0000040?ooo`80
0000203oool2000000l0dLfY000=0=7=Z@H0oooo0P0000060?ooo`H000000P3oool4000000@0oooo
1000000@0?ooo`@00000103oool200000080oooo100000000`3oool000000000000:0?ooo`800000
0P3oool400000080oooo100000060?ooo`@000001P3oool200000080oooo100000040?ooo`800000
0P3oool2000000H0oooo0P0000020?ooo`8000000P3oool8000000@0oooo1P0000060?ooo`P00000
0P3oool4000000P0oooo1P0000020?ooo`8000000P3oool00`000000oooo0?ooo`02000000@0oooo
0P0000020?ooo`8000000P3oool<000000@0oooo0P0000040?ooo`8000000P3oool600000080oooo
0P0000060?ooo`P000000P3oool6000000@0oooo0P0000020?ooo`X000000P3oool600000080oooo
0P0000020?ooo`H00000103oool200000080oooo0P0000060?ooo`8000000P3oool00`000000oooo
0?ooo`04000000@0oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000040?ooo`800000
103oool2000000@0oooo0P0000080?ooo`H000000P3oool8000000l0dLfY000=0=7=Z@H0oooo0P00
00060?ooo`H000000P3oool4000000@0oooo1000000@0?ooo`@00000103oool200000080oooo1000
00000`3oool000000000000:0?ooo`8000000P3oool400000080oooo100000060?ooo`@000001P3o
ool200000080oooo100000040?ooo`8000000P3oool2000000H0oooo0P0000020?ooo`8000000P3o
ool8000000@0oooo1P0000060?ooo`P000000P3oool4000000P0oooo1P0000020?ooo`8000000P3o
ool00`000000oooo0?ooo`02000000@0oooo0P0000020?ooo`8000000P3oool<000000@0oooo0P00
00040?ooo`8000000P3oool600000080oooo0P0000060?ooo`P000000P3oool6000000@0oooo0P00
00020?ooo`X000000P3oool600000080oooo0P0000020?ooo`H00000103oool200000080oooo0P00
00060?ooo`8000000P3oool00`000000oooo0?ooo`04000000@0oooo0P0000020?ooo`8000000P3o
ool200000080oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000080?ooo`H000000P3o
ool8000000l0dLfY000=0=7=Z@P000000P3oool6000000@0oooo100000080?ooo`8000000P3oool@
000000P0oooo100000050?ooo``000000P3oool2000000H0oooo0P0000020?ooo`H000002P3oool4
000000P0oooo100000020?ooo`H000000P3oool200000080oooo0P0000040?ooo`8000000P3oool4
000000@0oooo200000040?ooo`8000000P3oool2000000`0oooo0P0000060?ooo`<000000P3oool2
00000080oooo100000020?ooo`8000000P3oool2000000@0oooo0P0000040?ooo`H000000P3oool4
00000080oooo0P0000040?ooo`@000000P3oool6000000@0oooo0P0000020?ooo`800000103oool6
00000080oooo0P0000040?ooo`8000001P3oool2000000H0oooo100000040?ooo`H000000P3oool2
00000080oooo1P0000020?ooo`030000003oool0oooo00800000203oool400000080oooo0P000002
0?ooo`8000000P3oool400000080oooo100000020?ooo`@000000P3oool8000000@0oooo10000004
0?ooo`8000003`3AcJT000d0dLfY200000020?ooo`H00000103oool4000000P0oooo0P0000020?oo
oa000000203oool4000000D0oooo300000020?ooo`8000001P3oool200000080oooo1P00000:0?oo
o`@00000203oool400000080oooo1P0000020?ooo`8000000P3oool2000000@0oooo0P0000020?oo
o`@00000103oool8000000@0oooo0P0000020?ooo`800000303oool2000000H0oooo0`0000020?oo
o`8000000P3oool400000080oooo0P0000020?ooo`800000103oool2000000@0oooo1P0000020?oo
o`@000000P3oool2000000@0oooo100000020?ooo`H00000103oool200000080oooo0P0000040?oo
o`H000000P3oool2000000@0oooo0P0000060?ooo`8000001P3oool4000000@0oooo1P0000020?oo
o`8000000P3oool600000080oooo00<000000?ooo`3oool00P0000080?ooo`@000000P3oool20000
0080oooo0P0000020?ooo`@000000P3oool400000080oooo100000020?ooo`P00000103oool40000
00@0oooo0P00000?0=7=Z@003@3AcJT40?ooo`8000001P3oool2000000P0oooo0P0000020?ooo`P0
00000P3oool2000000@0oooo0P0000040?ooo`800000303oool200000080oooo1@0000040?ooo`80
0000103oool400000080oooo1P0000020?ooo`800000103oool<000000`0oooo0P0000020?ooo`80
0000103oool400000080oooo0P0000020?ooo`@000000P3oool2000000P0oooo0P0000040?ooo`H0
00000P3oool200000080oooo300000020?ooo`H000001@3oool4000000H0oooo100000020?ooo`@0
00000P3oool4000000@0oooo100000060?ooo`H000001P3oool2000000P0oooo100000020?ooo`@0
0000103oool400000080oooo100000020?ooo`H000000P3oool6000000P0oooo0P0000060?ooo`@0
0000103oool300000080oooo0P0000020?ooo`P000001P3oool400000080oooo0P0000060?ooo`80
00000P3oool2000000H0oooo0P0000040?ooo`H00000203oool?0=7=Z@003@3AcJT40?ooo`800000
1P3oool2000000P0oooo0P0000020?ooo`P000000P3oool2000000@0oooo0P0000040?ooo`800000
303oool200000080oooo1@0000040?ooo`800000103oool400000080oooo1P0000020?ooo`800000
103oool<000000`0oooo0P0000020?ooo`800000103oool400000080oooo0P0000020?ooo`@00000
0P3oool2000000P0oooo0P0000040?ooo`H000000P3oool200000080oooo300000020?ooo`H00000
1@3oool4000000H0oooo100000020?ooo`@000000P3oool4000000@0oooo100000060?ooo`H00000
1P3oool2000000P0oooo100000020?ooo`@00000103oool400000080oooo100000020?ooo`H00000
0P3oool6000000P0oooo0P0000060?ooo`@00000103oool300000080oooo0P0000020?ooo`P00000
1P3oool400000080oooo0P0000060?ooo`8000000P3oool2000000H0oooo0P0000040?ooo`H00000
203oool?0=7=Z@003@3AcJT20?ooo`@000000P3oool600000080oooo200000020?ooo`800000103o
ool200000080oooo0P0000020?ooo`@000000P3oool400000080oooo300000020?ooo`030000003o
ool0oooo0080oooo1P0000020?ooo`@000001P3oool2000000H0oooo1P0000040?ooo`800000103o
ool>00000080oooo0P0000020?ooo`@000001P3oool4000000H0oooo2P0000020?ooo`@00000103o
ool400000080oooo0P0000040?ooo`800000103oool4000000@0oooo1`00000:0?ooo`8000000P3o
ool2000000H0oooo0P0000020?ooo`@000002P3oool2000000X0oooo2P0000060?ooo`8000000P3o
ool4000000H0oooo0P0000020?ooo`800000103oool4000000@0oooo2P0000020?ooo`H00000203o
ool00`000000oooo0?ooo`0200000080oooo0P0000040?ooo`8000000P3oool6000000H0oooo2000
00020?ooo`8000000P3oool600000080oooo100000040?ooo`P000003`3AcJT000d0dLfY0P3oool4
00000080oooo1P0000020?ooo`P000000P3oool2000000@0oooo0P0000020?ooo`8000000P3oool4
00000080oooo100000020?ooo``000000P3oool00`000000oooo0?ooo`020?ooo`H000000P3oool4
000000H0oooo0P0000060?ooo`H00000103oool2000000@0oooo3P0000020?ooo`8000000P3oool4
000000H0oooo100000060?ooo`X000000P3oool4000000@0oooo100000020?ooo`800000103oool2
000000@0oooo100000040?ooo`L000002P3oool200000080oooo0P0000060?ooo`8000000P3oool4
000000X0oooo0P00000:0?ooo`X000001P3oool200000080oooo100000060?ooo`8000000P3oool2
000000@0oooo100000040?ooo`X000000P3oool6000000P0oooo00<000000?ooo`3oool00P000002
0?ooo`800000103oool200000080oooo1P0000060?ooo`P000000P3oool200000080oooo1P000002
0?ooo`@00000103oool8000000l0dLfY000=0=7=Z@80oooo0P0000060?ooo`8000001P3oool20000
00@0oooo100000020?ooo`@000000P3oool200000080oooo0P0000060?ooo`8000000P3oool20000
00@0oooo0P0000040?ooo`<000000P3oool4000000@0oooo1000000:0?ooo`P00000103oool60000
0080oooo100000040?ooo`800000103oool200000080oooo0P0000020?ooo`8000002P3oool20000
0080oooo1P0000040?ooo`8000001P3oool200000080oooo100000060?ooo`H000000P3oool40000
00L0oooo0P0000040?ooo``000000P3oool200000080oooo1P0000020?ooo`8000003P3oool<0000
00@0oooo0P00000:0?ooo`@000002P3oool400000080oooo100000080?ooo`800000103oool20000
0080oooo0P0000040?ooo`T000000P3oool200000080oooo0P0000020?ooo`@000000P3oool20000
00@0oooo200000040?ooo`8000000P3oool200000080oooo0P0000040?ooo`@00000203oool20000
00@0oooo3`3AcJT000d0dLfY0P3oool2000000H0oooo0P0000060?ooo`800000103oool400000080
oooo100000020?ooo`8000000P3oool2000000H0oooo0P0000020?ooo`800000103oool2000000@0
oooo0`0000020?ooo`@00000103oool4000000X0oooo200000040?ooo`H000000P3oool4000000@0
oooo0P0000040?ooo`8000000P3oool200000080oooo0P00000:0?ooo`8000000P3oool6000000@0
oooo0P0000060?ooo`8000000P3oool4000000H0oooo1P0000020?ooo`@000001`3oool2000000@0
oooo300000020?ooo`8000000P3oool600000080oooo0P00000>0?ooo``00000103oool2000000X0
oooo1000000:0?ooo`@000000P3oool4000000P0oooo0P0000040?ooo`8000000P3oool2000000@0
oooo2@0000020?ooo`8000000P3oool200000080oooo100000020?ooo`800000103oool8000000@0
oooo0P0000020?ooo`8000000P3oool2000000@0oooo100000080?ooo`800000103oool?0=7=Z@00
3@3AcJT20?ooo`8000000P3oool600000080oooo1P0000020?ooo`@000001P3oool200000080oooo
0P0000020?ooo`8000000P3oool600000080oooo0P0000020?ooo`@000000P3oool4000000D0oooo
0P0000020?ooo`@000003P3oool2000000@0oooo1P0000040?ooo`@00000203oool600000080oooo
0P0000020?ooo`8000000P3oool:00000080oooo0P0000040?ooo`H000000P3oool600000080oooo
0P00000:0?ooo`8000001P3oool200000080oooo1`0000020?ooo`@00000103oool2000000@0oooo
100000020?ooo`800000103oool400000080oooo3P0000040?ooo`800000103oool600000080oooo
2P00000>0?ooo`8000000P3oool2000000`0oooo1P0000020?ooo`8000000P3oool4000000@0oooo
0P0000050?ooo`@000000P3oool2000000H0oooo1P0000040?ooo`8000000P3oool400000080oooo
0P0000020?ooo`8000000P3oool4000000`0oooo1000000?0=7=Z@003@3AcJT20?ooo`8000000P3o
ool2000000@0oooo100000040?ooo`@000002P3oool400000080oooo0P0000020?ooo`800000103o
ool400000080oooo0P0000060?ooo`80000000<0oooo000000000000100000020?ooo`8000004P3o
ool6000000@0oooo1P00000<0?ooo`8000001P3oool400000080oooo0P0000040?ooo`8000001P3o
ool6000000@0oooo100000040?ooo`@000000P3oool:00000080oooo1P0000020?ooo`8000000`3o
ool200000080oooo0P0000080?ooo`H000001P3oool6000000H0oooo0P0000040?ooo`800000103o
ool600000080oooo100000040?ooo`@00000103oool200000180oooo100000020?ooo``00000103o
ool400000080oooo0P0000080?ooo`L000001P3oool8000000@0oooo1P0000020?ooo`8000001P3o
ool400000080oooo0P00000@0?ooo`8000003`3AcJT000d0dLfY0P3oool200000080oooo0P000004
0?ooo`@00000103oool4000000X0oooo100000020?ooo`8000000P3oool2000000@0oooo10000002
0?ooo`8000001P3oool2000000030?ooo`000000000000@000000P3oool200000180oooo1P000004
0?ooo`H00000303oool2000000H0oooo100000020?ooo`800000103oool2000000H0oooo1P000004
0?ooo`@00000103oool400000080oooo2P0000020?ooo`H000000P3oool2000000<0oooo0P000002
0?ooo`800000203oool6000000H0oooo1P0000060?ooo`800000103oool2000000@0oooo1P000002
0?ooo`@00000103oool4000000@0oooo0P00000B0?ooo`@000000P3oool<000000@0oooo10000002
0?ooo`800000203oool7000000H0oooo200000040?ooo`H000000P3oool2000000H0oooo10000002
0?ooo`800000403oool2000000l0dLfY000=0=7=Z@80oooo0P0000020?ooo`8000000P3oool40000
00P0oooo0P0000020?ooo`X000001P3oool400000080oooo100000060?ooo`P0000000<0oooo0000
00000000103oool400000080oooo4P0000040?ooo`H00000103oool>00000080oooo1P0000060?oo
o`H000000P3oool6000000@0oooo1P0000080?ooo`8000000P3oool2000000@0oooo0P0000060?oo
o`8000001P3oool500000080oooo0P0000020?ooo`P00000103oool8000000@0oooo200000020?oo
o`@000000P3oool4000000@0oooo100000080?ooo`8000000P3oool400000080oooo4P0000060?oo
o`800000103oool2000000P0oooo0P0000020?ooo`8000000P3oool7000000@0oooo0P0000020?oo
o`H00000103oool200000080oooo100000040?ooo`@000000P3oool6000000H0oooo4P00000?0=7=
Z@003@3AcJT20?ooo`8000000P3oool200000080oooo100000080?ooo`8000000P3oool:000000H0
oooo100000020?ooo`@000001P3oool8000000030?ooo`000000000000@0oooo100000020?oooa80
0000103oool6000000@0oooo3P0000020?ooo`H000001P3oool600000080oooo1P0000040?ooo`H0
0000203oool200000080oooo0P0000040?ooo`8000001P3oool2000000H0oooo1@0000020?ooo`80
00000P3oool8000000@0oooo200000040?ooo`P000000P3oool400000080oooo100000040?ooo`@0
0000203oool200000080oooo100000020?oooa8000001P3oool2000000@0oooo0P0000080?ooo`80
00000P3oool200000080oooo1`0000040?ooo`8000000P3oool6000000@0oooo0P0000020?ooo`@0
0000103oool400000080oooo1P0000060?oooa8000003`3AcJT000d0dLfY103oool400000080oooo
0P00000<0?ooo`@00000103oool2000000X0oooo0P0000020?ooo`8000002P3oool2000000@0oooo
0`0000020?ooo`@000001P3oool2000000@0oooo0P0000040?ooo`800000203oool2000000P0oooo
0P0000040?ooo`800000103oool4000000@0oooo200000040?ooo`@00000103oool6000000@0oooo
2P0000020?ooo`8000000P3oool400000080oooo1P0000020?ooo`H000000`3oool400000080oooo
0P0000040?ooo`8000000P3oool4000000@0oooo0P0000020?ooo`@00000103oool200000080oooo
0P0000060?ooo`8000000P3oool4000000`0oooo100000060?ooo`800000103oool2000000@0oooo
0P00000:0?ooo`H000000P3oool800000080oooo0P0000020?ooo`800000103oool00`000000oooo
0?ooo`0400000080oooo0P0000040?ooo`H000000P3oool2000000P0oooo0P0000020?ooo`800000
103oool8000000@0oooo0P0000040?ooo`800000103oool?0=7=Z@003@3AcJT40?ooo`@000000P3o
ool2000000`0oooo100000040?ooo`8000002P3oool200000080oooo0P00000:0?ooo`800000103o
ool300000080oooo100000060?ooo`800000103oool2000000@0oooo0P0000080?ooo`800000203o
ool2000000@0oooo0P0000040?ooo`@00000103oool8000000@0oooo100000040?ooo`H00000103o
ool:00000080oooo0P0000020?ooo`@000000P3oool600000080oooo1P0000030?ooo`@000000P3o
ool2000000@0oooo0P0000020?ooo`@00000103oool200000080oooo100000040?ooo`8000000P3o
ool2000000H0oooo0P0000020?ooo`@00000303oool4000000H0oooo0P0000040?ooo`800000103o
ool2000000X0oooo1P0000020?ooo`P000000P3oool200000080oooo0P0000040?ooo`030000003o
ool0oooo00@000000P3oool2000000@0oooo1P0000020?ooo`800000203oool200000080oooo0P00
00040?ooo`P00000103oool2000000@0oooo0P0000040?ooo`l0dLfY000=0=7=Z@H0oooo0P000002
0?ooo`8000000P3oool<000000P0oooo300000020?ooo`8000000P3oool:00000080oooo0`000006
0?ooo`8000000P3oool600000080oooo100000020?ooo`@000000P3oool800000080oooo20000002
0?ooo`@000000P3oool4000000P0oooo0P0000040?ooo`H00000203oool2000000P0oooo0P000004
0?ooo`8000000P3oool200000080oooo0P0000060?ooo`8000001P3oool2000000L0oooo0P000002
0?ooo`8000000P3oool400000080oooo0P0000080?ooo`@00000203oool400000080oooo1P000002
0?ooo`800000403oool200000080oooo1P0000020?ooo`@000000P3oool400000080oooo2P000004
0?ooo`@00000103oool200000080oooo0P0000020?ooo`8000000P3oool300000080oooo0P000006
0?ooo`H00000103oool400000080oooo200000020?ooo`8000000P3oool4000000@0oooo0P000002
0?ooo`@000000P3oool400000080oooo0P00000?0=7=Z@003@3AcJT60?ooo`8000000P3oool20000
0080oooo300000080?ooo``000000P3oool200000080oooo2P0000020?ooo`<000001P3oool20000
0080oooo1P0000020?ooo`@000000P3oool400000080oooo200000020?ooo`P000000P3oool40000
0080oooo100000080?ooo`800000103oool6000000P0oooo0P0000080?ooo`800000103oool20000
0080oooo0P0000020?ooo`8000001P3oool2000000H0oooo0P0000070?ooo`8000000P3oool20000
0080oooo100000020?ooo`800000203oool4000000P0oooo100000020?ooo`H000000P3oool20000
0100oooo0P0000020?ooo`H000000P3oool400000080oooo100000020?ooo`X00000103oool40000
00@0oooo0P0000020?ooo`8000000P3oool200000080oooo0`0000020?ooo`8000001P3oool60000
00@0oooo100000020?ooo`P000000P3oool200000080oooo100000040?ooo`8000000P3oool40000
0080oooo100000020?ooo`8000003`3AcJT000d0dLfY203oool400000080oooo0P0000040?ooo`80
0000103oool:000000@0oooo0P0000040?ooo`@000000P3oool2000000@0oooo0P0000060?ooo`03
0000003oool0oooo00H000000P3oool2000000@0oooo100000060?ooo`8000000P3oool2000000@0
oooo0P0000020?ooo`800000103oool200000080oooo0P0000060?ooo`8000000P3oool800000080
oooo100000040?ooo`X000000P3oool800000080oooo100000020?ooo`8000000P3oool200000080
oooo1P0000020?ooo`H000000P3oool700000080oooo0P0000020?ooo`8000001P3oool:000000`0
oooo0P0000020?ooo`800000103oool400000080oooo400000020?ooo`800000103oool4000000H0
oooo0P0000020?ooo`800000103oool2000000P0oooo0P0000020?ooo`@000000P3oool200000080
oooo0P0000020?ooo`8000001@3oool8000000@0oooo1P0000060?ooo`800000103oool400000080
oooo0P0000080?ooo`@000001P3oool200000080oooo0P00000?0=7=Z@003@3AcJT80?ooo`@00000
0P3oool2000000@0oooo0P0000040?ooo`X00000103oool2000000@0oooo100000020?ooo`800000
103oool2000000H0oooo00<000000?ooo`3oool01P0000020?ooo`800000103oool4000000H0oooo
0P0000020?ooo`800000103oool200000080oooo0P0000040?ooo`8000000P3oool2000000H0oooo
0P0000020?ooo`P000000P3oool4000000@0oooo2P0000020?ooo`P000000P3oool400000080oooo
0P0000020?ooo`8000000P3oool600000080oooo1P0000020?ooo`L000000P3oool200000080oooo
0P0000060?ooo`X00000303oool200000080oooo0P0000040?ooo`@000000P3oool@00000080oooo
0P0000040?ooo`@000001P3oool200000080oooo0P0000040?ooo`800000203oool200000080oooo
100000020?ooo`8000000P3oool200000080oooo0P0000050?ooo`P00000103oool6000000H0oooo
0P0000040?ooo`@000000P3oool2000000P0oooo100000060?ooo`8000000P3oool2000000l0dLfY
000=0=7=Z@X000001P3oool600000080oooo100000040?ooo`800000203oool6000000H0oooo1P00
00020?ooo`D000000P3oool2000000@0oooo100000020?ooo`@000002P3oool400000080oooo1000
00020?ooo`8000000P3oool400000080oooo0P0000020?ooo`H000000P3oool2000000@0oooo0P00
00020?ooo`800000203oool2000000@0oooo0P0000020?ooo`800000103oool200000080oooo0P00
00060?ooo`@000000P3oool2000000@0oooo100000040?ooo`<00000103oool200000080oooo0P00
00020?ooo`8000000P3oool6000000@0oooo0P00000@0?ooo`@000000P3oool4000000H0oooo0P00
00040?ooo`800000103oool200000080oooo0P0000020?ooo`@000002P3oool400000080oooo1000
00020?ooo`P000000P3oool2000000H0oooo100000020?ooo`80000000<0oooo0000000000001000
00040?ooo`8000000P3oool4000000@0oooo200000020?ooo`@000001P3oool:000000X0oooo1000
000?0=7=Z@003@3AcJT:000000H0oooo1P0000020?ooo`@00000103oool2000000P0oooo1P000006
0?ooo`H000000P3oool500000080oooo0P0000040?ooo`@000000P3oool4000000X0oooo10000002
0?ooo`@000000P3oool200000080oooo100000020?ooo`8000000P3oool600000080oooo0P000004
0?ooo`8000000P3oool2000000P0oooo0P0000040?ooo`8000000P3oool2000000@0oooo0P000002
0?ooo`8000001P3oool400000080oooo0P0000040?ooo`@00000103oool3000000@0oooo0P000002
0?ooo`8000000P3oool200000080oooo1P0000040?ooo`800000403oool400000080oooo10000006
0?ooo`800000103oool2000000@0oooo0P0000020?ooo`8000000P3oool4000000X0oooo10000002
0?ooo`@000000P3oool800000080oooo0P0000060?ooo`@000000P3oool2000000030?ooo`000000
000000@00000103oool200000080oooo100000040?ooo`P000000P3oool4000000H0oooo2P00000:
0?ooo`@000003`3AcJT000d0dLfY0P0000040?ooo`8000002P3oool2000000H0oooo0P0000020?oo
o`@000000P3oool8000000@0oooo200000040?ooo`@000000`3oool400000080oooo100000060?oo
o`8000000P3oool:000000H0oooo0P0000020?ooo`8000000P3oool2000000H0oooo100000040?oo
o`@000000P3oool400000080oooo0P0000020?ooo`P000000P3oool400000080oooo0P0000020?oo
o`@000000P3oool200000080oooo1P0000060?ooo`H00000203oool00`000000oooo0?ooo`040000
0080oooo0P0000020?ooo`8000000P3oool2000000@0oooo1P0000020?oooa0000001P3oool20000
0080oooo1P0000020?ooo`@000000P3oool400000080oooo0P0000020?ooo`8000003P3oool20000
0080oooo0P0000060?ooo`800000103oool400000080oooo1P0000060?ooo`<00000103oool60000
0080oooo0P0000080?ooo`800000103oool4000000X0oooo0P0000040?ooo`8000000P3oool:0000
0080oooo3`3AcJT000d0dLfY0P0000040?ooo`8000002P3oool2000000H0oooo0P0000020?ooo`@0
00000P3oool8000000@0oooo200000040?ooo`@000000`3oool400000080oooo100000060?ooo`80
00000P3oool:000000H0oooo0P0000020?ooo`8000000P3oool2000000H0oooo100000040?ooo`@0
00000P3oool400000080oooo0P0000020?ooo`P000000P3oool400000080oooo0P0000020?ooo`@0
00000P3oool200000080oooo1P0000060?ooo`H00000203oool00`000000oooo0?ooo`0400000080
oooo0P0000020?ooo`8000000P3oool2000000@0oooo1P0000020?oooa0000001P3oool200000080
oooo1P0000020?ooo`@000000P3oool400000080oooo0P0000020?ooo`8000003P3oool200000080
oooo0P0000060?ooo`800000103oool400000080oooo1P0000060?ooo`<00000103oool600000080
oooo0P0000080?ooo`800000103oool4000000X0oooo0P0000040?ooo`8000000P3oool:00000080
oooo3`3AcJT000d0dLfY0P0000020?ooo`@000000P3oool:00000080oooo1P0000020?ooo`800000
1P3oool2000000@0oooo1P0000040?ooo`8000000P3oool4000000L0oooo0P0000020?ooo`800000
2P3oool4000000@0oooo0P00000:0?ooo`@000000P3oool200000080oooo1P0000080?ooo`800000
0P3oool2000000H0oooo100000040?ooo`8000000P3oool2000000H0oooo100000060?ooo`@00000
103oool8000000@0oooo2@0000020?ooo`8000001P3oool400000080oooo0P0000020?ooo`@00000
103oool4000000@0oooo0P0000040?ooo`8000002P3oool4000000@0oooo100000060?ooo`800000
0P3oool200000080oooo0P0000020?ooo`h000000P3oool200000080oooo1P0000020?ooo`@00000
1P3oool2000000T0oooo0P0000020?ooo`@00000103oool400000080oooo200000020?ooo`@00000
3P3oool600000080oooo0P0000040?ooo`800000103oool?0=7=Z@003@3AcJT200000080oooo1000
00020?ooo`X000000P3oool600000080oooo0P0000060?ooo`800000103oool6000000@0oooo0P00
00020?ooo`@000001`3oool200000080oooo0P00000:0?ooo`@00000103oool2000000X0oooo1000
00020?ooo`8000000P3oool6000000P0oooo0P0000020?ooo`8000001P3oool4000000@0oooo0P00
00020?ooo`8000001P3oool4000000H0oooo100000040?ooo`P00000103oool900000080oooo0P00
00060?ooo`@000000P3oool200000080oooo100000040?ooo`@00000103oool2000000@0oooo0P00
000:0?ooo`@00000103oool4000000H0oooo0P0000020?ooo`8000000P3oool200000080oooo3P00
00020?ooo`8000000P3oool600000080oooo100000060?ooo`8000002@3oool200000080oooo1000
00040?ooo`@000000P3oool800000080oooo1000000>0?ooo`H000000P3oool2000000@0oooo0P00
00040?ooo`l0dLfY000=0=7=Z@H0oooo0P0000020?ooo`800000103oool2000000H0oooo0P000006
0?ooo`P000000P3oool4000000@0oooo1P0000020?ooo`8000002`3oool400000080oooo2P000008
0?ooo``000001P3oool4000000@0oooo2P0000020?ooo`8000000P3oool6000000P0oooo10000002
0?ooo`H000002P3oool200000080oooo100000040?ooo`8000000P3oool4000000@0oooo0P000005
0?ooo`P000001P3oool4000000P0oooo0P0000020?ooo`@000000P3oool400000080oooo2P000008
0?ooo`8000000P3oool600000080oooo0P0000020?ooo`8000000P3oool2000000@0oooo0P000004
0?ooo`8000000P3oool200000080oooo0P0000040?ooo`@000002P3oool;00000080oooo0P000008
0?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`8000004P3oool2000000H0oooo1P000002
0?ooo`8000003`3AcJT000d0dLfY1P3oool200000080oooo0P0000040?ooo`8000001P3oool20000
00H0oooo200000020?ooo`@00000103oool600000080oooo0P00000;0?ooo`@000000P3oool:0000
00P0oooo300000060?ooo`@00000103oool:00000080oooo0P0000020?ooo`H00000203oool40000
0080oooo1P00000:0?ooo`8000000P3oool4000000@0oooo0P0000020?ooo`@00000103oool20000
00D0oooo200000060?ooo`@00000203oool200000080oooo100000020?ooo`@000000P3oool:0000
00P0oooo0P0000020?ooo`H000000P3oool200000080oooo0P0000020?ooo`800000103oool20000
00@0oooo0P0000020?ooo`8000000P3oool2000000@0oooo1000000:0?ooo`/000000P3oool20000
00P0oooo0P0000020?ooo`800000103oool200000080oooo0P00000B0?ooo`8000001P3oool60000
0080oooo0P00000?0=7=Z@003@3AcJT20?ooo`H000000P3oool200000080oooo100000020?ooo`H0
00000P3oool6000000@0oooo0P0000020?ooo`800000203oool2000000H0oooo3@0000060?ooo`80
0000103oool200000080oooo200000040?ooo`800000103oool8000000P0oooo0P0000040?ooo`80
00000P3oool200000080oooo0P0000040?ooo`X000001P3oool2000000h0oooo100000080?ooo`@0
0000203oool7000000@0oooo0P0000020?ooo`H00000303oool4000000H0oooo0P0000020?ooo`80
0000103oool2000000`0oooo100000040?ooo`@000000P3oool200000080oooo0P0000020?ooo`@0
00000P3oool400000080oooo0P0000020?ooo`8000000P3oool4000000h0oooo0P0000040?ooo`03
0000003oool0oooo00@0oooo2P0000020?ooo`8000000P3oool400000080oooo0P0000020?oooa80
00000P3oool6000000@0oooo1000000?0=7=Z@003@3AcJT20?ooo`H000000P3oool200000080oooo
100000020?ooo`H000000P3oool6000000@0oooo0P0000020?ooo`800000203oool2000000H0oooo
3@0000060?ooo`800000103oool200000080oooo200000040?ooo`800000103oool8000000P0oooo
0P0000040?ooo`8000000P3oool200000080oooo0P0000040?ooo`X000001P3oool2000000h0oooo
100000080?ooo`@00000203oool7000000@0oooo0P0000020?ooo`H00000303oool4000000H0oooo
0P0000020?ooo`800000103oool2000000`0oooo100000040?ooo`@000000P3oool200000080oooo
0P0000020?ooo`@000000P3oool400000080oooo0P0000020?ooo`8000000P3oool4000000h0oooo
0P0000040?ooo`030000003oool0oooo00@0oooo2P0000020?ooo`8000000P3oool400000080oooo
0P0000020?oooa8000000P3oool6000000@0oooo1000000?0=7=Z@003@3AcJT20?ooo`800000103o
ool400000080oooo0P0000060?ooo`8000001P3oool2000000P0oooo100000020?ooo`P000000P3o
ool6000000@0oooo00<000000?ooo`3oool00P3oool200000080oooo1P0000020?ooo`@000000P3o
ool2000000@0oooo0P0000020?ooo`@000000P3oool4000000@0oooo0P0000020?ooo`P000000P3o
ool400000080oooo0P0000020?ooo`8000000P3oool4000000@0oooo0P00000:0?oooa000000303o
ool200000080oooo1`0000040?ooo`8000000P3oool400000080oooo0P0000040?ooo`h000002P3o
ool400000080oooo100000020?ooo``00000203oool200000080oooo0P0000020?ooo`8000000P3o
ool2000000H0oooo0P0000020?ooo`8000000P3oool200000080oooo0P00000B0?ooo`D000000P3o
ool6000000@0oooo0P0000060?ooo`@000001P3oool4000000@0oooo0P0000040?ooo`800000103o
ool4000000@0oooo1P0000020?ooo`l0dLfY000=0=7=Z@80oooo0P0000040?ooo`@000000P3oool2
000000H0oooo0P0000060?ooo`800000203oool400000080oooo200000020?ooo`H00000103oool0
0`000000oooo0?ooo`020?ooo`8000000P3oool600000080oooo100000020?ooo`800000103oool2
00000080oooo100000020?ooo`@00000103oool200000080oooo200000020?ooo`@000000P3oool2
00000080oooo0P0000020?ooo`@00000103oool2000000X0oooo4000000<0?ooo`8000000P3oool7
000000@0oooo0P0000020?ooo`@000000P3oool2000000@0oooo3P00000:0?ooo`@000000P3oool4
00000080oooo300000080?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000001P3oool2
00000080oooo0P0000020?ooo`8000000P3oool200000180oooo1@0000020?ooo`H00000103oool2
000000H0oooo100000060?ooo`@00000103oool2000000@0oooo0P0000040?ooo`@00000103oool6
00000080oooo3`3AcJT000d0dLfY100000020?ooo`@000001P3oool800000080oooo1P0000020?oo
o`P000001P3oool2000000@0oooo100000040?ooo`D000000P3oool400000080oooo0P0000040?oo
o`@000001P3oool600000080oooo0P0000060?ooo`8000000P3oool400000080oooo0P0000040?oo
o`8000000P3oool2000000H0oooo100000020?ooo`800000203oool<000000@0oooo0P0000040?oo
o`800000403oool4000000@0oooo00<000000?ooo`3oool0100000020?ooo`8000001P3oool60000
00@0oooo0P0000040?ooo`8000000P3oool:000000H0oooo0P0000020?ooo`800000103oool20000
00@0oooo2P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`H000000P3oool20000
0080oooo0P0000020?ooo`8000000P3ooolB000000<0oooo100000040?ooo`H000000P3oool60000
00X0oooo0P0000020?ooo`@000000P3oool400000080oooo100000080?ooo`800000103oool?0=7=
Z@003@3AcJT400000080oooo100000060?ooo`P000000P3oool600000080oooo200000060?ooo`80
0000103oool4000000@0oooo1@0000020?ooo`@000000P3oool2000000@0oooo100000060?ooo`H0
00000P3oool2000000H0oooo0P0000020?ooo`@000000P3oool2000000@0oooo0P0000020?ooo`80
00001P3oool400000080oooo0P0000080?ooo``00000103oool2000000@0oooo0P00000@0?ooo`@0
0000103oool00`000000oooo0?ooo`0400000080oooo0P0000060?ooo`H00000103oool2000000@0
oooo0P0000020?ooo`X000001P3oool200000080oooo0P0000040?ooo`800000103oool:00000080
oooo0P0000020?ooo`8000000P3oool200000080oooo1P0000020?ooo`8000000P3oool200000080
oooo0P0000020?oooa8000000`3oool4000000@0oooo1P0000020?ooo`H000002P3oool200000080
oooo100000020?ooo`@000000P3oool4000000P0oooo0P0000040?ooo`l0dLfY000=0=7=Z@800000
1P3oool200000080oooo1P0000040?ooo`8000000P3oool2000000@0oooo100000040?ooo`800000
0P3oool600000080oooo100000080?ooo`8000001@3oool200000080oooo0P0000020?ooo`@00000
2P3oool2000000H0oooo200000020?ooo`8000001P3oool600000080oooo0P0000020?ooo`H00000
1P3oool:000000@0oooo0P0000040?ooo`H000000P3oool400000080oooo400000070?ooo`@00000
1P3oool8000000@0oooo1P0000020?ooo`@000000P3oool2000000@0oooo0P00000:0?ooo`@00000
0P3oool400000080oooo100000040?ooo`8000001P3oool400000080oooo0P0000020?ooo`800000
103oool400000080oooo0P0000020?ooo`8000000P3oool2000000@0oooo0P0000040?ooo`800000
103oool5000000P0oooo0P0000060?ooo`8000003P3oool4000000H0oooo0P0000020?ooo`800000
303oool4000000l0dLfY000=0=7=Z@8000001P3oool200000080oooo1P0000040?ooo`8000000P3o
ool2000000@0oooo100000040?ooo`8000000P3oool600000080oooo100000080?ooo`8000001@3o
ool200000080oooo0P0000020?ooo`@000002P3oool2000000H0oooo200000020?ooo`8000001P3o
ool600000080oooo0P0000020?ooo`H000001P3oool:000000@0oooo0P0000040?ooo`H000000P3o
ool400000080oooo400000070?ooo`@000001P3oool8000000@0oooo1P0000020?ooo`@000000P3o
ool2000000@0oooo0P00000:0?ooo`@000000P3oool400000080oooo100000040?ooo`8000001P3o
ool400000080oooo0P0000020?ooo`800000103oool400000080oooo0P0000020?ooo`8000000P3o
ool2000000@0oooo0P0000040?ooo`800000103oool5000000P0oooo0P0000060?ooo`8000003P3o
ool4000000H0oooo0P0000020?ooo`800000303oool4000000l0dLfY000=0=7=Z@8000000P3oool6
00000080oooo0P0000040?ooo`H000000P3oool200000080oooo100000080?ooo`@00000103oool4
000000`0oooo1`0000020?ooo`8000000P3oool2000000h0oooo200000040?ooo`8000000P3oool2
00000080oooo1P0000040?ooo`@000000P3oool2000000@0oooo200000040?ooo`800000203oool6
000000@0oooo100000060?ooo`800000103oool2000000@0oooo0P0000020?ooo`L000002P3oool2
000000@0oooo1P0000040?ooo`@000001P3oool600000080oooo2P0000060?ooo`8000000P3oool2
000000P0oooo200000060?ooo`@000000P3oool4000000H0oooo100000020?ooo`8000000P3oool4
00000080oooo100000020?ooo`@000000`3oool:00000080oooo1P0000020?ooo`h000002P3oool4
00000080oooo300000020?ooo`l0dLfY000=0=7=Z@8000000P3oool600000080oooo0P0000040?oo
o`H000000P3oool200000080oooo100000080?ooo`@00000103oool4000000`0oooo1`0000020?oo
o`8000000P3oool2000000h0oooo200000040?ooo`8000000P3oool200000080oooo1P0000040?oo
o`@000000P3oool2000000@0oooo200000040?ooo`800000203oool6000000@0oooo100000060?oo
o`800000103oool2000000@0oooo0P0000020?ooo`L000002P3oool2000000@0oooo1P0000040?oo
o`@000001P3oool600000080oooo2P0000060?ooo`8000000P3oool2000000P0oooo200000060?oo
o`@000000P3oool4000000H0oooo100000020?ooo`8000000P3oool400000080oooo100000020?oo
o`@000000`3oool:00000080oooo1P0000020?ooo`h000002P3oool400000080oooo300000020?oo
o`l0dLfY000=0=7=Z@8000000P3oool2000000@0oooo100000020?ooo`@00000103oool400000080
oooo0P00000<0?ooo`8000000P3oool4000000l0oooo0P0000040?ooo`@000000P3oool200000080
oooo3P0000040?ooo`8000000P3oool400000080oooo0P0000020?ooo`800000103oool6000000H0
oooo1P0000040?ooo`8000000P3oool400000080oooo200000040?ooo`H000002P3oool600000080
oooo100000020?ooo`8000000`3oool200000080oooo2P0000020?ooo`@00000103oool6000000X0
oooo0P0000060?ooo`800000103oool200000080oooo1P0000020?ooo`8000000P3oool8000000@0
oooo0P0000020?ooo`H000001P3oool200000080oooo1P0000060?ooo`@000001P3oool200000080
oooo0P0000070?ooo`800000103oool200000080oooo0P0000040?ooo`@00000103oool2000000@0
oooo0P0000020?ooo`X000001P3oool2000000@0oooo0P0000040?ooo`l0dLfY000=0=7=Z@800000
0P3oool2000000@0oooo100000020?ooo`@00000103oool400000080oooo0P00000<0?ooo`800000
0P3oool4000000l0oooo0P0000040?ooo`@000000P3oool200000080oooo3P0000040?ooo`800000
0P3oool400000080oooo0P0000020?ooo`800000103oool6000000H0oooo1P0000040?ooo`800000
0P3oool400000080oooo200000040?ooo`H000002P3oool600000080oooo100000020?ooo`800000
0`3oool200000080oooo2P0000020?ooo`@00000103oool6000000X0oooo0P0000060?ooo`800000
103oool200000080oooo1P0000020?ooo`8000000P3oool8000000@0oooo0P0000020?ooo`H00000
1P3oool200000080oooo1P0000060?ooo`@000001P3oool200000080oooo0P0000070?ooo`800000
103oool200000080oooo0P0000040?ooo`@00000103oool2000000@0oooo0P0000020?ooo`X00000
1P3oool2000000@0oooo0P0000040?ooo`l0dLfY000=0=7=Z@H0oooo1P0000060?ooo`8000000P3o
ool4000000H0oooo3P0000020?ooo`8000004`3oool6000000H0oooo100000040?ooo`800000103o
ool200000080oooo100000020?ooo`8000001P3oool400000080oooo100000040?ooo`P00000103o
ool600000080oooo0P0000060?ooo`800000103oool6000000@0oooo300000040?ooo`@000001P3o
ool500000080oooo0P0000040?ooo`8000001P3oool200000080oooo100000040?ooo``000000P3o
ool600000080oooo100000020?ooo`800000103oool400000080oooo0P0000040?ooo`8000000P3o
ool400000080oooo0P0000040?ooo`P000000P3oool2000000@0oooo2000000:0?ooo`@000000P3o
ool700000080oooo100000020?ooo`8000000P3oool4000000P0oooo1P0000020?ooo`800000103o
ool2000000X0oooo1P0000020?ooo`8000003`3AcJT000d0dLfY1P3oool6000000H0oooo0P000002
0?ooo`@000001P3oool>00000080oooo0P00000C0?ooo`H000001P3oool4000000@0oooo0P000004
0?ooo`8000000P3oool400000080oooo0P0000060?ooo`@000000P3oool4000000@0oooo20000004
0?ooo`H000000P3oool2000000H0oooo0P0000040?ooo`H00000103oool<000000@0oooo10000006
0?ooo`D000000P3oool2000000@0oooo0P0000060?ooo`8000000P3oool4000000@0oooo30000002
0?ooo`H000000P3oool400000080oooo0P0000040?ooo`@000000P3oool2000000@0oooo0P000002
0?ooo`@000000P3oool2000000@0oooo200000020?ooo`800000103oool8000000X0oooo10000002
0?ooo`L000000P3oool400000080oooo0P0000020?ooo`@00000203oool600000080oooo0P000004
0?ooo`8000002P3oool600000080oooo0P00000?0=7=Z@003@3AcJT20?ooo`H00000103oool80000
0080oooo0P00000:0?ooo`800000103oool2000000@0oooo100000020?oooa<00000103oool80000
00P0oooo1P0000020?ooo`8000001P3oool8000000H0oooo0P0000020?ooo`@00000103oool20000
0080oooo100000040?ooo`@000000P3oool600000080oooo100000040?ooo`H00000103oool20000
00@0oooo1P00000:0?ooo`030000003oool0oooo00@0oooo1P0000020?ooo`H000000P3oool20000
00P0oooo0P0000040?ooo`8000001P3oool2000000H0oooo0P0000020?ooo`8000000P3oool40000
00H0oooo1P0000020?ooo`8000001P3oool6000000@0oooo0P0000020?ooo`8000000P3oool40000
00@0oooo0P0000020?ooo`X000001@3oool2000000@0oooo100000060?ooo`@00000303oool20000
00H0oooo1P0000020?ooo`X00000103oool4000000l0dLfY000=0=7=Z@80oooo1P0000040?ooo`P0
00000P3oool2000000X0oooo0P0000040?ooo`800000103oool400000080oooo4`0000040?ooo`P0
0000203oool600000080oooo0P0000060?ooo`P000001P3oool200000080oooo100000040?ooo`80
00000P3oool4000000@0oooo100000020?ooo`H000000P3oool4000000@0oooo1P0000040?ooo`80
0000103oool6000000X0oooo00<000000?ooo`3oool0103oool600000080oooo1P0000020?ooo`80
0000203oool2000000@0oooo0P0000060?ooo`8000001P3oool200000080oooo0P0000020?ooo`@0
00001P3oool600000080oooo0P0000060?ooo`H00000103oool200000080oooo0P0000020?ooo`@0
0000103oool200000080oooo2P0000050?ooo`800000103oool4000000H0oooo1000000<0?ooo`80
00001P3oool600000080oooo2P0000040?ooo`@000003`3AcJT000d0dLfY100000040?ooo`H00000
103oool200000080oooo0P0000020?ooo`X000000P3oool400000080oooo100000060?ooo`800000
103oool2000000@0oooo00<000000?ooo`3oool00P3oool6000000@0oooo0P0000020?ooo`P00000
103oool400000080oooo1P0000040?ooo`8000000P3oool600000080oooo0P0000080?ooo`@00000
203oool200000080oooo0P0000040?ooo`@00000203oool2000000P0oooo1P0000040?ooo`/00000
0P3oool6000000@0oooo100000040?ooo`@000000P3oool800000080oooo100000020?ooo`H00000
0P3oool600000080oooo0P0000020?ooo`8000002P3oool2000000H0oooo200000040?ooo`H00000
0P3oool200000080oooo0P0000080?ooo`@00000103oool2000000T0oooo1P00000:0?ooo`800000
0P3oool<00000080oooo1P0000040?ooo`@00000103oool2000000P0oooo0P00000?0=7=Z@003@3A
cJT4000000@0oooo1P0000040?ooo`8000000P3oool200000080oooo2P0000020?ooo`@000000P3o
ool4000000H0oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`020?ooo`H00000103o
ool200000080oooo200000040?ooo`@000000P3oool6000000@0oooo0P0000020?ooo`H000000P3o
ool2000000P0oooo100000080?ooo`8000000P3oool2000000@0oooo100000080?ooo`800000203o
ool6000000@0oooo2`0000020?ooo`H00000103oool4000000@0oooo100000020?ooo`P000000P3o
ool400000080oooo1P0000020?ooo`H000000P3oool200000080oooo0P00000:0?ooo`8000001P3o
ool8000000@0oooo1P0000020?ooo`8000000P3oool2000000P0oooo100000040?ooo`8000002@3o
ool6000000X0oooo0P0000020?ooo``000000P3oool6000000@0oooo100000040?ooo`800000203o
ool2000000l0dLfY000=0=7=Z@800000203oool2000000P0oooo100000020?ooo`800000103oool2
000000H0oooo0P0000020?ooo`8000002P3oool600000080oooo0`0000020?ooo`@00000103oool6
00000080oooo0P0000040?ooo`8000000P3oool4000000H0oooo0P0000080?ooo`@00000103oool4
00000080oooo2000000<0?ooo`@000000P3oool4000000`0oooo2P0000040?ooo`H00000103oool2
000000<0oooo100000040?ooo`H00000203oool200000080oooo0P0000040?ooo`8000000P3oool2
000000H0oooo0P0000060?ooo`8000001P3oool400000080oooo2P0000020?ooo`H00000103oool2
00000080oooo100000040?ooo`@000000P3oool200000080oooo200000080?ooo`/00000103oool<
00000080oooo0P0000040?ooo`800000103oool4000000@0oooo1P0000080?ooo`X000003`3AcJT0
00d0dLfY0P0000080?ooo`800000203oool400000080oooo0P0000040?ooo`8000001P3oool20000
0080oooo0P00000:0?ooo`H000000P3oool300000080oooo100000040?ooo`H000000P3oool20000
00@0oooo0P0000020?ooo`@000001P3oool2000000P0oooo100000040?ooo`@000000P3oool80000
00`0oooo100000020?ooo`@00000303oool:000000@0oooo1P0000040?ooo`8000000`3oool40000
00@0oooo1P0000080?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`8000001P3oool20000
00H0oooo0P0000060?ooo`@000000P3oool:00000080oooo1P0000040?ooo`8000000P3oool40000
00@0oooo100000020?ooo`8000000P3oool8000000P0oooo2`0000040?ooo``000000P3oool20000
00@0oooo0P0000040?ooo`@00000103oool6000000P0oooo2P00000?0=7=Z@003@3AcJT20?ooo`X0
00000P3oool8000000H0oooo1P0000020?ooo`H000000P3oool200000080oooo2P0000040?ooo`@0
00001@3oool200000080oooo100000040?ooo`@000000P3oool400000080oooo0P00000:0?ooo`X0
0000203oool200000080oooo0P0000040?ooo`8000000P3oool<000000H0oooo0P0000020?ooo``0
0000103oool2000000P0oooo0P0000080?ooo`D00000203oool2000000`0oooo100000020?ooo`@0
00000P3oool200000080oooo1P0000020?ooo`H000000P3oool6000000H0oooo0P0000040?ooo`80
00000P3oool2000000@0oooo1P0000020?ooo`800000203oool200000080oooo0P0000020?ooo`80
0000103oool200000080oooo200000040?ooo`030000003oool0oooo0080oooo1P0000040?ooo`80
0000103oool400000080oooo100000020?ooo`@00000203oool2000000`0oooo0P0000040?ooo`80
00003`3AcJT000d0dLfY0P3oool:00000080oooo200000060?ooo`H000000P3oool600000080oooo
0P0000020?ooo`X00000103oool4000000D0oooo0P0000020?ooo`@00000103oool400000080oooo
100000020?ooo`8000002P3oool:000000P0oooo0P0000020?ooo`800000103oool200000080oooo
300000060?ooo`8000000P3oool<000000@0oooo0P0000080?ooo`800000203oool5000000P0oooo
0P00000<0?ooo`@000000P3oool400000080oooo0P0000020?ooo`H000000P3oool600000080oooo
1P0000060?ooo`800000103oool200000080oooo0P0000040?ooo`H000000P3oool2000000P0oooo
0P0000020?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`P00000103oool00`000000oooo
0?ooo`020?ooo`H00000103oool2000000@0oooo100000020?ooo`@000000P3oool4000000P0oooo
0P00000<0?ooo`800000103oool2000000l0dLfY000=0=7=Z@@00000103oool2000000H0oooo0P00
00040?ooo`P00000103oool4000000@0oooo100000020?ooo`800000103oool2000000P0oooo0P00
00000`3oool000000000000400000080oooo0P0000080?ooo`8000000P3oool2000000H0oooo3000
00040?ooo`800000303oool400000080oooo100000020?ooo`800000103oool2000000@0oooo2000
00020?ooo`800000103oool2000000@0oooo1P0000020?ooo`P000000P3oool8000000<0oooo2P00
00020?ooo``000001P3oool200000080oooo0P0000020?ooo`800000103oool4000000@0oooo1000
00040?ooo`P000000P3oool400000080oooo0P0000020?ooo`@00000103oool400000080oooo2000
00020?ooo`8000000P3oool200000080oooo100000020?ooo`800000103oool200000080oooo0`00
00020?ooo`@00000103oool600000080oooo100000060?ooo`8000000P3oool2000000`0oooo3P00
00020?ooo`@000003`3AcJT000d0dLfY100000040?ooo`8000001P3oool2000000@0oooo20000004
0?ooo`@00000103oool400000080oooo0P0000040?ooo`800000203oool2000000030?ooo`000000
000000@000000P3oool2000000P0oooo0P0000020?ooo`8000001P3oool<000000@0oooo0P00000<
0?ooo`@000000P3oool400000080oooo0P0000040?ooo`800000103oool800000080oooo0P000004
0?ooo`800000103oool600000080oooo200000020?ooo`P000000`3oool:00000080oooo30000006
0?ooo`8000000P3oool200000080oooo0P0000040?ooo`@00000103oool4000000@0oooo20000002
0?ooo`@000000P3oool200000080oooo100000040?ooo`@000000P3oool800000080oooo0P000002
0?ooo`8000000P3oool400000080oooo0P0000040?ooo`8000000P3oool300000080oooo10000004
0?ooo`H000000P3oool4000000H0oooo0P0000020?ooo`800000303oool>00000080oooo1000000?
0=7=Z@003@3AcJT40?ooo`H000000P3oool600000080oooo100000040?ooo`8000000P3oool40000
00P0oooo0P0000020?ooo`8000000P3oool400000080oooo200000000`3oool00000000000040?oo
o`@000000P3oool800000080oooo0P0000020?ooo`H00000103oool2000000@0oooo1P0000020?oo
o``000001P3oool200000080oooo0P0000020?ooo`@000000P3oool4000000@0oooo0P0000020?oo
o`8000000P3oool400000080oooo100000040?ooo`@00000103oool200000080oooo0P0000040?oo
o`80000000<0oooo0000000000000P0000040?ooo`8000001P3oool2000000@0oooo0P00000:0?oo
o`@000000P3oool200000080oooo100000080?ooo`8000000P3oool4000000@0oooo0P0000020?oo
o`8000001P3oool4000000P0oooo0P0000020?ooo`800000103oool200000080oooo0P0000020?oo
o`8000000P3oool2000000H0oooo1P0000020?ooo`8000001@3oool200000080oooo100000040?oo
o`@000002P3oool400000080oooo300000040?ooo`800000103oool200000080oooo0P0000020?oo
o`l0dLfY000=0=7=Z@@0oooo1P0000020?ooo`H000000P3oool4000000@0oooo0P0000020?ooo`@0
0000203oool200000080oooo0P0000020?ooo`@000000P3oool8000000030?ooo`000000000000@0
oooo100000020?ooo`P000000P3oool200000080oooo1P0000040?ooo`800000103oool600000080
oooo300000060?ooo`8000000P3oool200000080oooo100000020?ooo`@00000103oool200000080
oooo0P0000020?ooo`@000000P3oool4000000@0oooo100000040?ooo`8000000P3oool2000000@0
oooo0P0000000`3oool0000000000002000000@0oooo0P0000060?ooo`800000103oool2000000X0
oooo100000020?ooo`8000000P3oool4000000P0oooo0P0000020?ooo`@00000103oool200000080
oooo0P0000060?ooo`@00000203oool200000080oooo0P0000040?ooo`8000000P3oool200000080
oooo0P0000020?ooo`8000001P3oool600000080oooo0P0000050?ooo`8000000P3oool4000000@0
oooo1000000:0?ooo`@000000P3oool<000000@0oooo0P0000040?ooo`8000000P3oool200000080
oooo3`3AcJT000d0dLfY0P3oool4000000@0oooo100000040?ooo`@00000203oool4000000`0oooo
100000020?ooo`8000001P3oool2000000@0oooo0`0000020?ooo`@000001P3oool2000000@0oooo
100000020?ooo`800000103oool600000080oooo100000040?ooo`@00000103oool2000000@0oooo
200000020?ooo`8000000P3oool2000000H0oooo0P0000020?ooo`@000000P3oool200000080oooo
0P0000060?ooo`8000000P3oool4000000P0oooo100000020?ooo`@0000000<0oooo000000000000
203oool800000080oooo100000020?ooo`X000001P3oool4000000`0oooo100000080?ooo`@00000
0P3oool6000000`0oooo100000020?ooo`@000000P3oool200000080oooo0P0000020?ooo`800000
0P3oool6000000@0oooo100000000`3oool000000000000400000080oooo0P0000080?ooo`800000
0P3oool:000000H0oooo0P0000040?ooo`800000203oool600000080oooo0P0000020?ooo`l0dLfY
000=0=7=Z@80oooo100000040?ooo`@00000103oool4000000P0oooo1000000<0?ooo`@000000P3o
ool2000000H0oooo0P0000040?ooo`<000000P3oool4000000H0oooo0P0000040?ooo`@000000P3o
ool2000000@0oooo1P0000020?ooo`@00000103oool4000000@0oooo0P0000040?ooo`P000000P3o
ool200000080oooo0P0000060?ooo`8000000P3oool400000080oooo0P0000020?ooo`8000001P3o
ool200000080oooo100000080?ooo`@000000P3oool4000000030?ooo`000000000000P0oooo2000
00020?ooo`@000000P3oool:000000H0oooo1000000<0?ooo`@00000203oool400000080oooo1P00
000<0?ooo`@000000P3oool400000080oooo0P0000020?ooo`8000000P3oool200000080oooo1P00
00040?ooo`@0000000<0oooo000000000000100000020?ooo`800000203oool200000080oooo2P00
00060?ooo`800000103oool2000000P0oooo1P0000020?ooo`8000000P3oool?0=7=Z@003@3AcJT2
0?ooo`800000203oool200000080oooo1000000<0?ooo`8000000P3oool<000000H0oooo20000002
0?ooo`<000001P3oool200000080oooo1P0000020?ooo`@000001P3oool6000000@0oooo10000008
0?ooo`8000000P3oool400000080oooo100000040?ooo`8000000P3oool200000080oooo0P000002
0?ooo`H000000P3oool2000000H0oooo100000020?ooo`H000000P3oool2000000`0oooo0P000002
0?ooo`8000001@3oool:000000@0oooo0P0000020?ooo`8000001P3oool2000000@0oooo0P000002
0?ooo`H00000403oool200000080oooo200000060?ooo`800000403oool200000080oooo0P000006
0?ooo`@000000P3oool200000080oooo0P0000040?ooo`H000001@3oool2000000H0oooo2P000002
0?ooo`800000103oool2000000X0oooo1P0000020?ooo`P00000103oool400000080oooo3`3AcJT0
00d0dLfY0P3oool2000000P0oooo0P0000020?ooo`@00000303oool200000080oooo300000060?oo
o`P000000P3oool3000000H0oooo0P0000020?ooo`H000000P3oool4000000H0oooo1P0000040?oo
o`@00000203oool200000080oooo100000020?ooo`@00000103oool200000080oooo0P0000020?oo
o`8000000P3oool600000080oooo0P0000060?ooo`@000000P3oool600000080oooo0P00000<0?oo
o`8000000P3oool2000000D0oooo2P0000040?ooo`8000000P3oool2000000H0oooo0P0000040?oo
o`8000000P3oool600000100oooo0P0000020?ooo`P000001P3oool200000100oooo0P0000020?oo
o`8000001P3oool400000080oooo0P0000020?ooo`800000103oool6000000D0oooo0P0000060?oo
o`X000000P3oool2000000@0oooo0P00000:0?ooo`H000000P3oool8000000@0oooo100000020?oo
o`l0dLfY000=0=7=Z@@000000P3oool800000080oooo0P00000@0?ooo`@00000103oool2000000@0
oooo200000040?ooo`8000000P3oool2000000T0oooo100000040?ooo`@000002P3oool2000000P0
oooo0P0000020?ooo`P000000P3oool2000000H0oooo0P0000020?ooo`@000000P3oool200000080
oooo0P0000020?ooo`800000103oool400000080oooo1P0000060?ooo`8000001P3oool>00000080
oooo0P0000020?ooo`D00000103oool2000000P0oooo100000020?ooo`H000000P3oool400000080
oooo0P0000040?oooa8000000P3oool2000000@0oooo0P0000020?ooo`H000000P3oool@00000080
oooo0P0000020?ooo`H000001P3oool400000080oooo100000040?ooo`L000000P3oool6000000@0
oooo0P0000060?ooo`H000000P3oool:000000@0oooo100000040?ooo`8000000P3oool4000000@0
oooo3`3AcJT000d0dLfY100000020?ooo`P000000P3oool200000100oooo100000040?ooo`800000
103oool8000000@0oooo0P0000020?ooo`8000002@3oool4000000@0oooo1000000:0?ooo`800000
203oool200000080oooo200000020?ooo`8000001P3oool200000080oooo100000020?ooo`800000
0P3oool200000080oooo0P0000040?ooo`@000000P3oool6000000H0oooo0P0000060?ooo`h00000
0P3oool200000080oooo1@0000040?ooo`800000203oool400000080oooo1P0000020?ooo`@00000
0P3oool2000000@0oooo4P0000020?ooo`800000103oool200000080oooo1P0000020?oooa000000
0P3oool200000080oooo1P0000060?ooo`@000000P3oool4000000@0oooo1`0000020?ooo`H00000
103oool2000000H0oooo1P0000020?ooo`X00000103oool4000000@0oooo0P0000020?ooo`@00000
103oool?0=7=Z@003@3AcJT2000000H0oooo0P0000040?ooo`@000000P3oool@000000P0oooo1P00
00040?ooo`8000000P3oool400000080oooo0P0000000`3oool0000000000008000000P0oooo0P00
00020?ooo`X000000P3oool800000080oooo0P0000040?ooo`8000000P3oool200000080oooo1P00
00020?ooo`8000001P3oool400000080oooo0P0000020?ooo`@000001P3oool2000000X0oooo2000
00040?ooo`800000103oool200000080oooo0P0000020?ooo`030000003oool0oooo0080oooo1P00
00020?ooo`P000001P3oool2000000H0oooo0P0000020?ooo`8000000P3oool4000000@0oooo0P00
00040?ooo`800000103oool400000080oooo100000020?ooo`800000103oool4000000@0oooo0P00
00040?ooo`8000001P3oool4000000@0oooo200000060?ooo`8000000P3oool4000000<0oooo0P00
00020?ooo`800000103oool600000080oooo1P0000040?ooo`@00000103oool2000000P0oooo0P00
00020?ooo`@000000P3oool2000000H0oooo3`3AcJT000d0dLfY0P0000060?ooo`800000103oool4
00000080oooo400000080?ooo`H00000103oool200000080oooo100000020?ooo`80000000<0oooo
000000000000200000080?ooo`8000000P3oool:00000080oooo200000020?ooo`800000103oool2
00000080oooo0P0000020?ooo`H000000P3oool2000000H0oooo100000020?ooo`8000000P3oool4
000000H0oooo0P00000:0?ooo`P00000103oool2000000@0oooo0P0000020?ooo`8000000P3oool0
0`000000oooo0?ooo`020?ooo`H000000P3oool8000000H0oooo0P0000060?ooo`8000000P3oool2
00000080oooo100000040?ooo`800000103oool2000000@0oooo100000020?ooo`@000000P3oool2
000000@0oooo100000040?ooo`800000103oool2000000H0oooo100000040?ooo`P000001P3oool2
00000080oooo100000030?ooo`8000000P3oool2000000@0oooo1P0000020?ooo`H00000103oool4
000000@0oooo0P0000080?ooo`8000000P3oool400000080oooo0P0000060?ooo`l0dLfY000=0=7=
Z@8000000P3oool600000080oooo100000060?ooo`800000103oool2000000@0oooo0P0000020?oo
o`P00000103oool600000080oooo0P0000060?ooo`<00000103oool2000000`0oooo100000040?oo
o`8000001P3oool2000000@0oooo100000020?ooo`@000000P3oool200000080oooo0P0000040?oo
o`@000000P3oool6000000H0oooo1000000:0?ooo``00000103oool200000080oooo100000020?oo
o`@000000P3oool200000080oooo00<000000?ooo`3oool0100000040?ooo`@00000103oool20000
0080oooo1P0000020?ooo`H000000P3oool200000080oooo0P0000080?ooo`H000000P3oool40000
00H0oooo0P0000020?ooo`8000000P3oool4000000P0oooo1P0000020?ooo`H00000203oool20000
00@0oooo200000020?ooo`8000001`3oool400000080oooo100000040?ooo`@00000103oool60000
00P0oooo2P0000020?ooo`8000001P3oool6000000l0dLfY000=0=7=Z@8000000P3oool600000080
oooo100000060?ooo`800000103oool2000000@0oooo0P0000020?ooo`P00000103oool600000080
oooo0P0000060?ooo`<00000103oool2000000`0oooo100000040?ooo`8000001P3oool2000000@0
oooo100000020?ooo`@000000P3oool200000080oooo0P0000040?ooo`@000000P3oool6000000H0
oooo1000000:0?ooo``00000103oool200000080oooo100000020?ooo`@000000P3oool200000080
oooo00<000000?ooo`3oool0100000040?ooo`@00000103oool200000080oooo1P0000020?ooo`H0
00000P3oool200000080oooo0P0000080?ooo`H000000P3oool4000000H0oooo0P0000020?ooo`80
00000P3oool4000000P0oooo1P0000020?ooo`H00000203oool2000000@0oooo200000020?ooo`80
00001`3oool400000080oooo100000040?ooo`@00000103oool6000000P0oooo2P0000020?ooo`80
00001P3oool6000000l0dLfY000=0=7=Z@8000000P3oool2000000@0oooo1000000:0?ooo`H00000
0P3oool400000080oooo0P0000040?ooo`8000000P3oool4000000@0oooo100000020?ooo`D00000
203oool>000000P0oooo200000020?ooo`@000001P3oool200000080oooo0P0000020?ooo`800000
0P3oool4000000H0oooo0P00000:0?ooo`8000000P3oool:000000@0oooo0P0000040?ooo`H00000
0P3oool2000000H0oooo0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`02000000P0oooo
0P0000020?ooo`@000000P3oool2000000@0oooo100000040?ooo`@000000P3oool200000080oooo
200000040?ooo`@000002P3oool400000080oooo0P00000<0?ooo`8000001P3oool2000000`0oooo
1P0000040?ooo`8000000P3oool200000080oooo1`0000060?ooo`8000000P3oool4000000P0oooo
0P00000<0?ooo`800000103oool200000080oooo0P0000020?ooo`H00000103oool?0=7=Z@003@3A
cJT200000080oooo0P0000040?ooo`@000002P3oool600000080oooo100000020?ooo`800000103o
ool200000080oooo100000040?ooo`@000000P3oool5000000P0oooo3P0000080?ooo`P000000P3o
ool4000000H0oooo0P0000020?ooo`8000000P3oool200000080oooo100000060?ooo`8000002P3o
ool200000080oooo2P0000040?ooo`800000103oool600000080oooo0P0000060?ooo`8000000P3o
ool200000080oooo00<000000?ooo`3oool00P0000080?ooo`8000000P3oool400000080oooo0P00
00040?ooo`@00000103oool400000080oooo0P0000020?ooo`P00000103oool4000000X0oooo1000
00020?ooo`800000303oool2000000H0oooo0P00000<0?ooo`H00000103oool200000080oooo0P00
00020?ooo`L000001P3oool200000080oooo100000080?ooo`800000303oool2000000@0oooo0P00
00020?ooo`8000000P3oool6000000@0oooo3`3AcJT000d0dLfY0P0000020?ooo`8000000P3oool4
000000h0oooo0P0000060?ooo`8000000P3oool200000080oooo100000020?ooo`800000203oool2
00000080oooo0P0000030?ooo`X00000103oool2000000@0oooo0P0000020?ooo`P00000103oool2
00000080oooo0P00000:0?ooo`@000000P3oool200000080oooo0P00000:0?ooo``000000P3oool2
000000@0oooo0P0000080?ooo`H00000103oool400000080oooo1P0000020?ooo`8000000P3oool0
0`000000oooo0?ooo`0200000080oooo200000020?ooo`8000001P3oool6000000P0oooo0P000002
0?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`@000003P3oool200000080oooo0P000002
0?ooo``000000P3oool600000080oooo300000040?ooo`H000000P3oool200000080oooo00<00000
0?ooo`3oool00P3oool200000080oooo1P0000020?ooo`800000303oool>00000080oooo10000002
0?ooo`8000000P3oool2000000@0oooo1000000?0=7=Z@003@3AcJT200000080oooo0P0000020?oo
o`@000003P3oool2000000H0oooo0P0000020?ooo`8000000P3oool400000080oooo0P0000080?oo
o`8000000P3oool2000000<0oooo2P0000040?ooo`800000103oool200000080oooo200000040?oo
o`8000000P3oool2000000X0oooo100000020?ooo`8000000P3oool2000000X0oooo300000020?oo
o`800000103oool2000000P0oooo1P0000040?ooo`@000000P3oool600000080oooo0P0000020?oo
o`030000003oool0oooo008000000P3oool800000080oooo0P0000060?ooo`H00000203oool20000
0080oooo0P0000020?ooo`800000103oool200000080oooo1000000>0?ooo`8000000P3oool20000
0080oooo300000020?ooo`H000000P3oool<000000@0oooo1P0000020?ooo`8000000P3oool00`00
0000oooo0?ooo`020?ooo`8000000P3oool600000080oooo0P00000<0?ooo`h000000P3oool40000
0080oooo0P0000020?ooo`800000103oool4000000l0dLfY000=0=7=Z@8000000P3oool200000080
oooo0P00000B0?ooo`P000000P3oool200000080oooo0P0000060?ooo`X000000P3oool200000080
oooo0`0000040?ooo`800000203oool600000080oooo0P0000040?ooo`8000000P3oool400000080
oooo0P0000020?ooo`X000001P3oool400000080oooo2P0000040?ooo`800000103oool400000080
oooo100000020?ooo`P00000103oool6000000H0oooo0P0000060?ooo`<000000P3oool200000080
oooo0P0000040?ooo`8000000P3oool200000080oooo1P0000040?ooo`X000000P3oool200000080
oooo0P0000020?ooo`@000000P3oool200000180oooo100000020?ooo`800000103oool2000000@0
oooo100000040?ooo`@00000103oool2000000@0oooo1P0000040?ooo`@000000P3oool00`000000
oooo0?ooo`0400000080oooo0P0000040?ooo`@000000P3oool<000000@0oooo0P0000040?ooo`80
00000P3oool2000000H0oooo100000020?ooo`@000000P3oool?0=7=Z@003@3AcJT200000080oooo
0P0000020?ooo`8000004P3oool800000080oooo0P0000020?ooo`8000001P3oool:00000080oooo
0P0000020?ooo`<00000103oool2000000P0oooo1P0000020?ooo`800000103oool200000080oooo
100000020?ooo`8000000P3oool:000000H0oooo100000020?ooo`X00000103oool2000000@0oooo
100000020?ooo`@000000P3oool8000000@0oooo1P0000060?ooo`8000001P3oool300000080oooo
0P0000020?ooo`800000103oool200000080oooo0P0000020?ooo`H00000103oool:00000080oooo
0P0000020?ooo`8000000P3oool400000080oooo0P00000B0?ooo`@000000P3oool2000000@0oooo
0P0000040?ooo`@00000103oool4000000@0oooo0P0000040?ooo`H00000103oool400000080oooo
00<000000?ooo`3oool0100000020?ooo`800000103oool400000080oooo300000040?ooo`800000
103oool200000080oooo0P0000060?ooo`@000000P3oool400000080oooo3`3AcJT000d0dLfY1P3o
ool400000080oooo4P0000040?ooo`8000000P3oool200000080oooo0P0000020?ooo`H00000103o
ool2000000H0oooo0`0000080?ooo`X00000103oool400000080oooo100000020?ooo`8000001P3o
ool4000000@0oooo0P00000:0?ooo`8000000P3oool2000000@0oooo0P0000080?ooo`H000001P3o
ool200000080oooo0P0000040?ooo`8000000P3oool4000000@0oooo200000020?ooo`H000001@3o
ool400000080oooo100000020?ooo`8000000P3oool2000000@0oooo1P0000040?ooo`8000001P3o
ool400000080oooo0P0000060?oooa@000001P3oool600000080oooo100000080?ooo`8000000P3o
ool400000080oooo100000040?ooo`H000001@3oool4000000H0oooo1P0000060?ooo`800000103o
ool2000000P0oooo1P0000020?ooo`8000000P3oool6000000H0oooo0P0000020?ooo`l0dLfY000=
0=7=Z@H0oooo100000020?oooa800000103oool200000080oooo0P0000020?ooo`8000000P3oool6
000000@0oooo0P0000060?ooo`<00000203oool:000000@0oooo100000020?ooo`@000000P3oool2
000000H0oooo100000040?ooo`8000002P3oool200000080oooo0P0000040?ooo`800000203oool6
000000H0oooo0P0000020?ooo`800000103oool200000080oooo100000040?ooo`P000000P3oool6
000000D0oooo100000020?ooo`@000000P3oool200000080oooo0P0000040?ooo`H00000103oool2
000000H0oooo100000020?ooo`8000001P3ooolD000000H0oooo1P0000020?ooo`@00000203oool2
00000080oooo100000020?ooo`@00000103oool6000000D0oooo100000060?ooo`H000001P3oool2
000000@0oooo0P0000080?ooo`H000000P3oool200000080oooo1P0000060?ooo`8000000P3oool?
0=7=Z@003@3AcJT8000000H0oooo0P0000040?ooo`800000103oool2000000P0oooo100000020?oo
o`8000000P3oool2000000@0oooo1P0000020?ooo`H000002`3oool2000000@0oooo0P0000020?oo
o`@000001P3oool200000080oooo0P0000020?ooo`H00000203oool<00000080oooo0P0000020?oo
o`@000000P3oool8000000@0oooo200000020?ooo`8000000P3oool400000080oooo0P0000080?oo
o`800000103oool4000000@0oooo1`0000060?ooo`8000000P3oool200000080oooo0P0000020?oo
o`@00000103oool600000080oooo1P0000060?ooo`P00000103oool2000000@0oooo0P0000040?oo
o`8000000P3oool6000000@0oooo1000000<0?ooo`@000001P3oool200000080oooo100000040?oo
o`L000002P3oool2000000X0oooo1P0000020?ooo`P00000103oool400000080oooo0P0000040?oo
o`P000000P3oool?0=7=Z@003@3AcJT8000000H0oooo0P0000040?ooo`800000103oool2000000P0
oooo100000020?ooo`8000000P3oool2000000@0oooo1P0000020?ooo`H000002`3oool2000000@0
oooo0P0000020?ooo`@000001P3oool200000080oooo0P0000020?ooo`H00000203oool<00000080
oooo0P0000020?ooo`@000000P3oool8000000@0oooo200000020?ooo`8000000P3oool400000080
oooo0P0000080?ooo`800000103oool4000000@0oooo1`0000060?ooo`8000000P3oool200000080
oooo0P0000020?ooo`@00000103oool600000080oooo1P0000060?ooo`P00000103oool2000000@0
oooo0P0000040?ooo`8000000P3oool6000000@0oooo1000000<0?ooo`@000001P3oool200000080
oooo100000040?ooo`L000002P3oool2000000X0oooo1P0000020?ooo`P00000103oool400000080
oooo0P0000040?ooo`P000000P3oool?0=7=Z@003@3AcJT2000000@0oooo0P0000020?ooo`H00000
0P3oool400000080oooo100000020?ooo`P000001P3oool400000080oooo100000040?ooo`@00000
103oool=00000080oooo100000020?ooo`8000002P3oool400000080oooo0P0000040?ooo`X00000
103oool2000000@0oooo100000020?ooo`8000001P3oool2000000@0oooo1P0000040?ooo`800000
0P3oool200000080oooo0P0000060?ooo`X000000P3oool4000000L0oooo0P0000040?ooo`P00000
0P3oool200000080oooo0P0000020?ooo`800000203oool2000000H0oooo0P00000:0?ooo`800000
103oool600000080oooo100000020?ooo`@000000P3oool2000000@0oooo1P00000@0?ooo`800000
0P3oool600000080oooo0P0000080?ooo`8000000`3oool<00000080oooo2P0000040?ooo`@00000
103oool200000080oooo100000060?ooo`H00000103oool200000080oooo3`3AcJT000d0dLfY0P00
00040?ooo`8000000P3oool600000080oooo100000020?ooo`@000000P3oool8000000H0oooo1000
00020?ooo`@00000103oool4000000@0oooo3@0000020?ooo`@000000P3oool2000000X0oooo1000
00020?ooo`800000103oool:000000@0oooo0P0000040?ooo`@000000P3oool2000000H0oooo0P00
00040?ooo`H00000103oool200000080oooo0P0000020?ooo`8000001P3oool:00000080oooo1000
00070?ooo`800000103oool800000080oooo0P0000020?ooo`8000000P3oool2000000P0oooo0P00
00060?ooo`8000002P3oool2000000@0oooo1P0000020?ooo`@000000P3oool400000080oooo0P00
00040?ooo`H00000403oool200000080oooo1P0000020?ooo`800000203oool2000000<0oooo3000
00020?ooo`X00000103oool4000000@0oooo0P0000020?ooo`@000001P3oool6000000@0oooo0P00
00020?ooo`l0dLfY000=0=7=Z@80oooo1P0000020?ooo`800000103oool4000000H0oooo0P000002
0?ooo`800000103oool200000080oooo1P0000060?ooo`8000000P3oool4000000L0oooo0P000004
0?ooo`800000103oool4000000H0oooo300000060?ooo`H00000103oool2000000P0oooo1P000006
0?ooo`P000000P3oool4000000@0oooo1P0000020?ooo`8000000P3oool200000080oooo1P000004
0?ooo`8000001P3oool200000080oooo1`0000020?ooo`@00000103oool200000080oooo0P000002
0?ooo`8000000P3oool200000080oooo200000020?ooo`H000000P3oool:00000080oooo10000004
0?ooo`@000001P3oool200000080oooo0P0000020?ooo`@00000103ooolB00000080oooo0P000004
0?ooo`@000000P3oool8000000030?ooo`000000000000800000103oool2000000@0oooo10000004
0?ooo`800000203oool200000080oooo100000020?ooo`8000002P3oool2000000P0oooo0P00000?
0=7=Z@003@3AcJT20?ooo`H000000P3oool2000000@0oooo100000060?ooo`8000000P3oool20000
00@0oooo0P0000020?ooo`H000001P3oool200000080oooo100000070?ooo`800000103oool20000
00@0oooo100000060?ooo``000001P3oool6000000@0oooo0P0000080?ooo`H000001P3oool80000
0080oooo100000040?ooo`H000000P3oool200000080oooo0P0000020?ooo`H00000103oool20000
00H0oooo0P0000020?ooo`L000000P3oool4000000@0oooo0P0000020?ooo`8000000P3oool20000
0080oooo0P0000020?ooo`P000000P3oool600000080oooo2P0000020?ooo`@00000103oool40000
00H0oooo0P0000020?ooo`8000000P3oool4000000@0oooo4P0000020?ooo`800000103oool40000
0080oooo200000000`3oool0000000000002000000@0oooo0P0000040?ooo`@00000103oool20000
00P0oooo0P0000020?ooo`@000000P3oool2000000X0oooo0P0000080?ooo`8000003`3AcJT000d0
dLfY103oool2000000H0oooo1P00000:0?ooo`@000000P3oool400000080oooo0P0000040?ooo`P0
00000P3oool2000000/0oooo1P0000020?ooo`@000002P3oool2000000@0oooo0P00000:0?ooo`80
0000203oool:000000@0oooo200000040?ooo`8000000P3oool2000000P0oooo0P0000060?ooo`@0
00000P3oool2000000@0oooo1P0000020?ooo`H000000P3oool2000000<0oooo0P0000020?ooo`80
0000203oool400000080oooo0P0000020?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`80
0000103oool4000000@0oooo0P0000060?ooo`8000000P3oool4000000X0oooo100000020?ooo`80
0000203oool2000000@0oooo0P0000040?ooo`8000001P3oool6000000H0oooo0P0000040?ooo`<0
0000203oool6000000P0oooo2P0000020?ooo`8000001P3oool<00000080oooo2000000?0=7=Z@00
3@3AcJT40?ooo`8000001P3oool6000000X0oooo100000020?ooo`@000000P3oool2000000@0oooo
200000020?ooo`8000002`3oool600000080oooo1000000:0?ooo`800000103oool2000000X0oooo
0P0000080?ooo`X00000103oool8000000@0oooo0P0000020?ooo`800000203oool2000000H0oooo
100000020?ooo`800000103oool600000080oooo1P0000020?ooo`8000000`3oool200000080oooo
0P0000080?ooo`@000000P3oool200000080oooo0P0000020?ooo`800000103oool200000080oooo
0P0000040?ooo`@00000103oool2000000H0oooo0P0000020?ooo`@000002P3oool400000080oooo
0P0000080?ooo`800000103oool2000000@0oooo0P0000060?ooo`H000001P3oool2000000@0oooo
0`0000080?ooo`H00000203oool:00000080oooo0P0000060?ooo``000000P3oool8000000l0dLfY
000=0=7=Z@H0oooo200000040?ooo``000001P3oool200000080oooo0P0000020?ooo`@00000103o
ool200000080oooo0P0000020?ooo`/00000103oool4000000h0oooo1P0000020?ooo`X000000P3o
ool8000000@0oooo0P0000080?ooo`800000103oool600000080oooo0P0000020?ooo`P000000P3o
ool6000000H0oooo1P0000040?ooo`@00000103oool400000080oooo0`0000020?ooo`8000000P3o
ool8000000H0oooo100000020?ooo`8000000P3oool400000080oooo0P0000020?ooo`@00000203o
ool800000080oooo0P00000>0?ooo`8000000P3oool200000080oooo200000020?ooo`@000000P3o
ool400000080oooo1P0000040?ooo`P000000P3oool3000000`0oooo0P00000<0?ooo`800000103o
ool200000080oooo0P0000020?ooo`H00000103oool2000000@0oooo100000040?ooo`8000003`3A
cJT000d0dLfY1P3oool8000000@0oooo300000060?ooo`8000000P3oool200000080oooo10000004
0?ooo`8000000P3oool200000080oooo2`0000040?ooo`@000003P3oool600000080oooo2P000002
0?ooo`P00000103oool2000000P0oooo0P0000040?ooo`H000000P3oool200000080oooo20000002
0?ooo`H000001P3oool6000000@0oooo100000040?ooo`@000000P3oool300000080oooo0P000002
0?ooo`P000001P3oool400000080oooo0P0000020?ooo`@000000P3oool200000080oooo10000008
0?ooo`P000000P3oool2000000h0oooo0P0000020?ooo`8000000P3oool800000080oooo10000002
0?ooo`@000000P3oool6000000@0oooo200000020?ooo`<00000303oool2000000`0oooo0P000004
0?ooo`8000000P3oool200000080oooo1P0000040?ooo`800000103oool4000000@0oooo0P00000?
0=7=Z@003@3AcJT8000000@0oooo0P0000020?ooo`@00000103oool2000000@0oooo200000020?oo
o`8000000P3oool2000000P0oooo100000020?ooo`800000103oool00`000000oooo0?ooo`020?oo
o`H000004P3oool2000000H0oooo0P0000040?ooo`8000000P3oool2000000@0oooo0P0000020?oo
o`@000000P3oool800000080oooo100000040?ooo`@000000P3oool2000000@0oooo0P0000020?oo
o`800000103oool8000000@0oooo1P0000080?ooo`8000000P3oool00`000000oooo0?ooo`040?oo
o`@00000103oool200000080oooo1P0000060?ooo`@000001P3oool4000000`0oooo0P0000040?oo
o`@000000P3oool>00000080oooo0P0000020?ooo`800000103oool200000080oooo0P0000060?oo
o`8000000P3oool2000000@0oooo1P0000040?ooo`8000000P3oool2000000l0oooo3P0000020?oo
o`@000000P3oool200000080oooo0P0000040?ooo`H000000P3oool4000000P0oooo3`3AcJT000d0
dLfY200000040?ooo`8000000P3oool4000000@0oooo0P0000040?ooo`P000000P3oool200000080
oooo0P0000080?ooo`@000000P3oool2000000@0oooo00<000000?ooo`3oool00P3oool600000180
oooo0P0000060?ooo`800000103oool200000080oooo0P0000040?ooo`8000000P3oool400000080
oooo200000020?ooo`@00000103oool400000080oooo0P0000040?ooo`8000000P3oool2000000@0
oooo200000040?ooo`H00000203oool200000080oooo00<000000?ooo`3oool0103oool4000000@0
oooo0P0000020?ooo`H000001P3oool4000000H0oooo1000000<0?ooo`800000103oool400000080
oooo3P0000020?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`8000001P3oool200000080
oooo0P0000040?ooo`H00000103oool200000080oooo0P00000?0?ooo`h000000P3oool400000080
oooo0P0000020?ooo`800000103oool600000080oooo100000080?ooo`l0dLfY000=0=7=Z@@0oooo
0P0000080?ooo`@00000203oool6000000@0oooo0P0000020?ooo`8000000P3oool200000080oooo
200000060?ooo`D000000P3oool4000000@0oooo500000020?ooo`H000000P3oool400000080oooo
0P0000020?ooo`@000000P3oool2000000H0oooo0P0000040?ooo`@00000203oool200000080oooo
0P0000020?ooo`@000000P3oool200000080oooo100000040?ooo`8000000P3oool4000000@0oooo
2P0000020?ooo`030000003oool0oooo00H00000203oool4000000@0oooo2000000:0?ooo`800000
0P3oool<00000080oooo100000060?ooo`800000103oool2000000@0oooo100000020?ooo`800000
0P3oool400000080oooo0P0000020?ooo`H000000P3oool200000080oooo100000040?ooo`H00000
0P3oool2000000030?ooo`000000000000h00000103oool2000000@0oooo0P0000020?ooo`800000
1P3oool400000080oooo100000040?ooo`@000002P3oool?0=7=Z@003@3AcJT40?ooo`800000203o
ool4000000P0oooo1P0000040?ooo`8000000P3oool200000080oooo0P0000020?ooo`P000001P3o
ool500000080oooo100000040?oooa@000000P3oool600000080oooo100000020?ooo`8000000P3o
ool400000080oooo0P0000060?ooo`800000103oool4000000P0oooo0P0000020?ooo`8000000P3o
ool400000080oooo0P0000020?ooo`@00000103oool200000080oooo100000040?ooo`X000000P3o
ool00`000000oooo0?ooo`06000000P0oooo100000040?ooo`P000002P3oool200000080oooo3000
00020?ooo`@000001P3oool2000000@0oooo0P0000040?ooo`@000000P3oool200000080oooo1000
00020?ooo`8000000P3oool600000080oooo0P0000020?ooo`@00000103oool600000080oooo0P00
00000`3oool000000000000>000000@0oooo0P0000040?ooo`8000000P3oool2000000H0oooo1000
00020?ooo`@00000103oool4000000X0oooo3`3AcJT000d0dLfY0P3oool400000080oooo2000000<
0?ooo`800000203oool400000080oooo0P0000020?ooo`800000103oool200000080oooo1P000003
0?ooo`@00000203oool2000000@0oooo0P0000040?ooo`800000103oool4000000@0oooo10000006
0?ooo`@000001P3oool800000080oooo1000000<0?ooo`@000000P3oool2000000H0oooo10000008
0?ooo`@00000203oool2000000@0oooo0P0000020?ooo`030000003oool0oooo00800000103oool:
000000P0oooo0P0000040?ooo``000000P3oool2000000@0oooo0P0000040?ooo`@000002P3oool6
00000080oooo100000060?ooo`@000001P3oool4000000@0oooo100000020?ooo`800000203oool2
000000H0oooo0`0000040?ooo`800000103oool2000000P0oooo1P0000020?ooo`8000000P3oool6
000000H0oooo0P0000020?ooo`@00000303oool?0=7=Z@003@3AcJT20?ooo`@000000P3oool80000
00`0oooo0P0000080?ooo`@000000P3oool200000080oooo0P0000040?ooo`8000000P3oool60000
00<0oooo100000080?ooo`800000103oool2000000@0oooo0P0000040?ooo`@00000103oool40000
00H0oooo100000060?ooo`P000000P3oool4000000`0oooo100000020?ooo`8000001P3oool40000
00P0oooo100000080?ooo`800000103oool200000080oooo00<000000?ooo`3oool00P0000040?oo
o`X00000203oool2000000@0oooo300000020?ooo`800000103oool2000000@0oooo1000000:0?oo
o`H000000P3oool4000000H0oooo100000060?ooo`@00000103oool400000080oooo0P0000080?oo
o`8000001P3oool3000000@0oooo0P0000040?ooo`800000203oool600000080oooo0P0000020?oo
o`H000001P3oool200000080oooo1000000<0?ooo`l0dLfY000=0=7=Z@@000001P3oool2000000@0
oooo3P0000020?ooo`P000001P3oool400000080oooo100000020?ooo`800000103oool5000000`0
oooo1P0000020?ooo`@000000P3oool4000000P0oooo0P0000020?ooo`H000002P3oool2000000@0
oooo1000000@0?ooo`8000000P3oool200000080oooo1P00000<0?ooo`8000000P3oool800000080
oooo100000020?ooo`030000003oool0oooo008000000P3oool4000000@0oooo0P00000<0?ooo`H0
0000103oool2000000@0oooo100000020?ooo`@000000P3oool4000000h0oooo0P0000060?ooo`80
00000P3oool6000000X0oooo0P0000020?ooo`@000001P3oool:00000080oooo1@0000080?ooo`H0
00000P3oool8000000@0oooo100000020?ooo`800000103oool800000080oooo0P00000>0?ooo`l0
dLfY000=0=7=Z@@000001P3oool2000000@0oooo3P0000020?ooo`P000001P3oool400000080oooo
100000020?ooo`800000103oool5000000`0oooo1P0000020?ooo`@000000P3oool4000000P0oooo
0P0000020?ooo`H000002P3oool2000000@0oooo1000000@0?ooo`8000000P3oool200000080oooo
1P00000<0?ooo`8000000P3oool800000080oooo100000020?ooo`030000003oool0oooo00800000
0P3oool4000000@0oooo0P00000<0?ooo`H00000103oool2000000@0oooo100000020?ooo`@00000
0P3oool4000000h0oooo0P0000060?ooo`8000000P3oool6000000X0oooo0P0000020?ooo`@00000
1P3oool:00000080oooo1@0000080?ooo`H000000P3oool8000000@0oooo100000020?ooo`800000
103oool800000080oooo0P00000>0?ooo`l0dLfY000=0=7=Z@8000002P3oool6000000@0oooo0P00
00040?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`H000001P3oool200000080oooo0P00
00020?ooo`@000000`3oool>000000@0oooo100000060?ooo`8000000P3oool800000080oooo0P00
00040?ooo``000000P3oool4000001@0oooo100000020?ooo`800000103oool>00000080oooo0P00
00040?ooo`8000000P3oool2000000D0oooo100000020?ooo`800000203oool>000000@0oooo1P00
00020?ooo`@000001P3oool200000080oooo0P00000B0?ooo`P000000P3oool2000000@0oooo3000
00020?ooo`8000002P3oool2000000@0oooo0P0000020?ooo`8000000`3oool:000000@0oooo1000
00040?ooo`8000000P3oool4000000H0oooo1P0000040?ooo`8000000P3oool200000080oooo3000
000?0=7=Z@003@3AcJT2000000X0oooo1P0000040?ooo`800000103oool200000080oooo0P000004
0?ooo`8000000P3oool6000000H0oooo0P0000020?ooo`8000000P3oool4000000<0oooo3P000004
0?ooo`@000001P3oool200000080oooo200000020?ooo`800000103oool<00000080oooo1000000D
0?ooo`@000000P3oool2000000@0oooo3P0000020?ooo`800000103oool200000080oooo0P000005
0?ooo`@000000P3oool2000000P0oooo3P0000040?ooo`H000000P3oool4000000H0oooo0P000002
0?ooo`8000004P3oool800000080oooo0P0000040?ooo``000000P3oool2000000X0oooo0P000004
0?ooo`8000000P3oool2000000<0oooo2P0000040?ooo`@00000103oool200000080oooo10000006
0?ooo`H00000103oool200000080oooo0P0000020?ooo``000003`3AcJT000d0dLfY0P0000020?oo
o`X00000103oool600000080oooo100000020?ooo`8000000P3oool400000080oooo0P0000040?oo
o`P000000P3oool200000080oooo0P0000070?ooo`800000103oool2000000@0oooo1P00000:0?oo
o`@00000103oool200000080oooo0P0000020?ooo`@00000103oool2000000@0oooo1000000H0?oo
o`8000000P3oool200000080oooo100000040?ooo`800000103oool200000080oooo0P0000020?oo
o`@000000P3oool200000080oooo1@0000060?ooo`X00000103oool2000000@0oooo0P0000020?oo
o`@00000103oool4000000X0oooo100000020?oooa800000103oool200000080oooo0P0000020?oo
o`@00000103oool2000000@0oooo100000020?ooo`X000000P3oool400000080oooo0P0000020?oo
o`<00000103oool2000000P0oooo0P0000020?ooo`@000000P3oool2000000X0oooo0P0000080?oo
o`@000000P3oool2000000@0oooo0P0000040?ooo`l0dLfY000=0=7=Z@8000000P3oool:000000@0
oooo1P0000020?ooo`@000000P3oool200000080oooo100000020?ooo`800000103oool800000080
oooo0P0000020?ooo`8000001`3oool2000000@0oooo0P0000040?ooo`H000002P3oool4000000@0
oooo0P0000020?ooo`8000000P3oool4000000@0oooo0P0000040?ooo`@00000603oool200000080
oooo0P0000020?ooo`@00000103oool2000000@0oooo0P0000020?ooo`8000000P3oool400000080
oooo0P0000020?ooo`D000001P3oool:000000@0oooo0P0000040?ooo`8000000P3oool4000000@0
oooo1000000:0?ooo`@000000P3ooolB000000@0oooo0P0000020?ooo`8000000P3oool4000000@0
oooo0P0000040?ooo`@000000P3oool:00000080oooo100000020?ooo`8000000P3oool3000000@0
oooo0P0000080?ooo`8000000P3oool400000080oooo0P00000:0?ooo`800000203oool400000080
oooo0P0000040?ooo`800000103oool?0=7=Z@003@3AcJT20?ooo`@00000103oool2000000P0oooo
0P0000060?ooo`8000000P3oool200000080oooo0P0000060?ooo`H00000103oool200000080oooo
0P0000020?ooo`8000000P3oool700000080oooo100000020?ooo`@00000103oool<000000P0oooo
100000020?ooo`800000203oool6000001`0oooo100000020?ooo`800000203oool600000080oooo
0P0000020?ooo`8000001P3oool4000000<0oooo200000040?ooo`800000203oool600000080oooo
0P0000080?ooo`8000000P3oool:000000H0oooo0P0000040?ooo`800000103oool2000000P0oooo
100000020?ooo`800000203oool6000000H0oooo0P0000040?ooo`8000000P3oool2000000H0oooo
0`0000080?ooo`X000000P3oool2000000H0oooo300000020?ooo`P000001P3oool600000080oooo
0P00000?0=7=Z@003@3AcJT20?ooo`@00000103oool2000000P0oooo0P0000060?ooo`8000000P3o
ool200000080oooo0P0000060?ooo`H00000103oool200000080oooo0P0000020?ooo`8000000P3o
ool700000080oooo100000020?ooo`@00000103oool<000000P0oooo100000020?ooo`800000203o
ool6000001`0oooo100000020?ooo`800000203oool600000080oooo0P0000020?ooo`8000001P3o
ool4000000<0oooo200000040?ooo`800000203oool600000080oooo0P0000080?ooo`8000000P3o
ool:000000H0oooo0P0000040?ooo`800000103oool2000000P0oooo100000020?ooo`800000203o
ool6000000H0oooo0P0000040?ooo`8000000P3oool2000000H0oooo0`0000080?ooo`X000000P3o
ool2000000H0oooo300000020?ooo`P000001P3oool600000080oooo0P00000?0=7=Z@003@3AcJT4
000000P0oooo2P0000020?ooo`H000000P3oool200000080oooo0P0000020?ooo`H00000103oool6
00000080oooo0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool2
000000H0oooo0P0000020?ooo`@00000103oool2000000@0oooo2P0000060?ooo`X00000103ooolN
000000H0oooo2P0000040?ooo`@000000P3oool200000080oooo1P0000070?ooo`800000103oool6
00000080oooo200000040?ooo`@000000P3oool800000080oooo0P0000040?ooo`8000002P3oool6
00000080oooo100000020?ooo`P000001P3oool:000000@0oooo200000020?ooo`@000000P3oool2
00000080oooo1P00000;0?ooo`800000103oool200000080oooo0P0000020?ooo`H00000103oool2
000000@0oooo100000040?ooo`8000000P3oool6000000@0oooo1000000?0=7=Z@003@3AcJT40000
00P0oooo2P0000020?ooo`H000000P3oool200000080oooo0P0000020?ooo`H00000103oool60000
0080oooo0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool20000
00H0oooo0P0000020?ooo`@00000103oool2000000@0oooo2P0000060?ooo`X00000103ooolN0000
00H0oooo2P0000040?ooo`@000000P3oool200000080oooo1P0000070?ooo`800000103oool60000
0080oooo200000040?ooo`@000000P3oool800000080oooo0P0000040?ooo`8000002P3oool60000
0080oooo100000020?ooo`P000001P3oool:000000@0oooo200000020?ooo`@000000P3oool20000
0080oooo1P00000;0?ooo`800000103oool200000080oooo0P0000020?ooo`H00000103oool20000
00@0oooo100000040?ooo`8000000P3oool6000000@0oooo1000000?0=7=Z@003@3AcJT2000000`0
oooo0P0000040?ooo`8000000P3oool2000000@0oooo100000020?ooo`8000000P3oool2000000@0
oooo1P0000040?ooo`@000000P3oool200000080oooo00<000000?ooo`3oool0100000020?ooo`80
00000P3oool600000080oooo0P0000080?ooo`H00000103oool2000000X0oooo0P0000040?ooo`80
00000P3oool4000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`P0
0000103oool2000000P0oooo0P0000020?ooo`8000000P3oool2000000@0oooo2@0000020?ooo`@0
0000103oool4000000@0oooo0P0000020?ooo`@000001P3oool2000000@0oooo100000020?ooo`@0
00000P3oool:000000@0oooo100000060?ooo`800000103oool8000000@0oooo0P0000080?ooo`80
0000103oool4000000H0oooo100000040?ooo`d000000P3oool400000080oooo0P0000020?ooo`80
0000103oool600000080oooo100000080?ooo`@00000103oool600000080oooo3`3AcJT000d0dLfY
0P00000<0?ooo`800000103oool200000080oooo0P0000040?ooo`@000000P3oool200000080oooo
0P0000040?ooo`H00000103oool400000080oooo0P0000020?ooo`030000003oool0oooo00@00000
0P3oool200000080oooo1P0000020?ooo`800000203oool6000000@0oooo0P00000:0?ooo`800000
103oool200000080oooo100000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000
103oool8000000@0oooo0P0000080?ooo`8000000P3oool200000080oooo0P0000040?ooo`T00000
0P3oool4000000@0oooo100000040?ooo`8000000P3oool4000000H0oooo0P0000040?ooo`@00000
0P3oool400000080oooo2P0000040?ooo`@000001P3oool2000000@0oooo200000040?ooo`800000
203oool2000000@0oooo100000060?ooo`@00000103oool=00000080oooo100000020?ooo`800000
0P3oool2000000@0oooo1P0000020?ooo`@00000203oool4000000@0oooo1P0000020?ooo`l0dLfY
000=0=7=Z@8000000P3oool<00000080oooo100000020?ooo`8000000P3oool4000000H0oooo1000
00020?ooo`@00000103oool6000000H0oooo0`0000020?ooo`8000001P3oool4000000@0oooo1000
00020?ooo`P00000103oool600000080oooo2P0000020?ooo`@000000P3oool2000000P0oooo1P00
00020?ooo`@000000P3oool400000080oooo100000040?ooo`8000000P3oool400000080oooo2000
00020?ooo`8000000P3oool200000080oooo100000030?ooo`8000001P3oool200000080oooo1000
00080?ooo`@000002P3oool6000000H0oooo0P0000020?ooo`800000103oool2000000P0oooo0P00
00020?ooo`H000000P3oool4000000@0oooo0P0000020?ooo`@000000P3oool800000080oooo1000
000:0?ooo`8000000P3oool3000000@0oooo0P0000040?ooo`8000000P3oool2000000H0oooo1000
00020?ooo`@00000103oool4000000`0oooo0P0000020?ooo`@00000103oool2000000l0dLfY000=
0=7=Z@8000000P3oool<00000080oooo100000020?ooo`8000000P3oool4000000H0oooo10000002
0?ooo`@00000103oool6000000H0oooo0`0000020?ooo`8000001P3oool4000000@0oooo10000002
0?ooo`P00000103oool600000080oooo2P0000020?ooo`@000000P3oool2000000P0oooo1P000002
0?ooo`@000000P3oool400000080oooo100000040?ooo`8000000P3oool400000080oooo20000002
0?ooo`8000000P3oool200000080oooo100000030?ooo`8000001P3oool200000080oooo10000008
0?ooo`@000002P3oool6000000H0oooo0P0000020?ooo`800000103oool2000000P0oooo0P000002
0?ooo`H000000P3oool4000000@0oooo0P0000020?ooo`@000000P3oool800000080oooo1000000:
0?ooo`8000000P3oool3000000@0oooo0P0000040?ooo`8000000P3oool2000000H0oooo10000002
0?ooo`@00000103oool4000000`0oooo0P0000020?ooo`@00000103oool2000000l0dLfY000=0=7=
Z@H0oooo0P0000040?ooo`8000001P3oool200000080oooo0P0000020?ooo`8000002P3oool20000
0080oooo0P0000080?ooo`8000002P3oool00`000000oooo0?ooo`0200000080oooo1P0000080?oo
o`8000000P3oool2000000@0oooo0P0000020?ooo`@00000103oool4000000@0oooo0P0000060?oo
o`8000000P3oool200000080oooo200000040?ooo`@000001P3oool200000080oooo0P0000080?oo
o`@000001P3oool2000000@0oooo100000020?ooo`8000000P3oool2000000L0oooo200000020?oo
o`800000303oool200000080oooo2P0000040?ooo`P000000P3oool200000080oooo100000020?oo
o`P000000P3oool2000000@0oooo100000080?ooo`@000001P3oool2000000@0oooo1000000>0?oo
o`@000001`3oool600000080oooo0P0000020?ooo`H000001P3oool200000080oooo1000000@0?oo
o`@00000203oool?0=7=Z@003@3AcJT60?ooo`800000103oool2000000H0oooo0P0000020?ooo`80
00000P3oool2000000X0oooo0P0000020?ooo`800000203oool2000000X0oooo00<000000?ooo`3o
ool00P0000020?ooo`H00000203oool200000080oooo0P0000040?ooo`8000000P3oool4000000@0
oooo100000040?ooo`8000001P3oool200000080oooo0P0000020?ooo`P00000103oool4000000H0
oooo0P0000020?ooo`800000203oool4000000H0oooo0P0000040?ooo`@000000P3oool200000080
oooo0P0000070?ooo`P000000P3oool2000000`0oooo0P0000020?ooo`X00000103oool800000080
oooo0P0000020?ooo`@000000P3oool800000080oooo0P0000040?ooo`@00000203oool4000000H0
oooo0P0000040?ooo`@000003P3oool4000000L0oooo1P0000020?ooo`8000000P3oool6000000H0
oooo0P0000020?ooo`@00000403oool4000000P0oooo3`3AcJT000d0dLfY203oool600000080oooo
1P0000020?ooo`8000000P3oool200000080oooo2P0000020?ooo`8000000P3oool800000080oooo
2@0000020?ooo`8000000P3oool2000000@0oooo2P0000020?ooo`8000000P3oool400000080oooo
0P0000080?ooo`8000000P3oool400000080oooo1P0000020?ooo`8000000P3oool2000000@0oooo
0P0000020?ooo`@000002P3oool400000080oooo2000000:0?ooo`H000001P3oool400000080oooo
1`0000040?ooo`8000000P3oool200000080oooo300000020?ooo`800000103oool2000000P0oooo
0P0000040?ooo`@000000P3oool2000000H0oooo0P0000040?ooo`@000000P3oool4000000`0oooo
0P0000020?ooo`H000000P3oool400000180oooo0P0000000`3oool0000000000006000000@0oooo
100000020?ooo`800000103oool800000080oooo0P00000D0?ooo`8000000P3oool6000000l0dLfY
000=0=7=Z@P0oooo1P0000020?ooo`H000000P3oool200000080oooo0P0000020?ooo`X000000P3o
ool200000080oooo200000020?ooo`T000000P3oool200000080oooo0P0000040?ooo`X000000P3o
ool200000080oooo100000020?ooo`800000203oool200000080oooo100000020?ooo`H000000P3o
ool200000080oooo0P0000040?ooo`8000000P3oool4000000X0oooo100000020?ooo`P000002P3o
ool6000000H0oooo100000020?ooo`L00000103oool200000080oooo0P0000020?ooo``000000P3o
ool2000000@0oooo0P0000080?ooo`800000103oool400000080oooo0P0000060?ooo`800000103o
ool400000080oooo1000000<0?ooo`8000000P3oool600000080oooo1000000B0?ooo`80000000<0
oooo0000000000001P0000040?ooo`@000000P3oool2000000@0oooo200000020?ooo`800000503o
ool200000080oooo1P00000?0=7=Z@003@3AcJT:000000@0oooo100000040?ooo`@000000P3oool2
00000080oooo0P0000040?ooo`8000001P3oool4000000@0oooo0P0000020?ooo`800000103oool2
000000D0oooo100000020?ooo`@00000103oool2000000H0oooo100000060?ooo`X000000P3oool2
000000H0oooo0P0000060?ooo`@000000P3oool400000080oooo0P00000>0?ooo`8000000P3oool2
000000@0oooo0P0000020?ooo`X00000103oool8000000D0oooo0P0000040?ooo`H000000P3oool2
00000080oooo0P0000040?ooo`800000103oool400000080oooo100000020?ooo`P000000P3oool4
000000H0oooo200000020?ooo`@000001P3oool200000080oooo300000020?ooo`800000103oool4
000001H0oooo0`0000040?ooo`8000000P3oool4000000H0oooo1P0000040?ooo`8000000P3oool2
00000080oooo500000020?ooo`800000103oool?0=7=Z@003@3AcJT:000000@0oooo100000040?oo
o`@000000P3oool200000080oooo0P0000040?ooo`8000001P3oool4000000@0oooo0P0000020?oo
o`800000103oool2000000D0oooo100000020?ooo`@00000103oool2000000H0oooo100000060?oo
o`X000000P3oool2000000H0oooo0P0000060?ooo`@000000P3oool400000080oooo0P00000>0?oo
o`8000000P3oool2000000@0oooo0P0000020?ooo`X00000103oool8000000D0oooo0P0000040?oo
o`H000000P3oool200000080oooo0P0000040?ooo`800000103oool400000080oooo100000020?oo
o`P000000P3oool4000000H0oooo200000020?ooo`@000001P3oool200000080oooo300000020?oo
o`800000103oool4000001H0oooo0`0000040?ooo`8000000P3oool4000000H0oooo1P0000040?oo
o`8000000P3oool200000080oooo500000020?ooo`800000103oool?0=7=Z@003@3AcJT2000000@0
oooo0P0000080?ooo`8000000P3oool4000000H0oooo100000020?ooo`@000000P3oool6000000P0
oooo100000020?ooo`@0000000<0oooo000000000000100000060?ooo`8000000P3oool400000080
oooo1P00000:0?ooo`800000103oool200000080oooo0P0000020?ooo`H000000P3oool6000000H0
oooo0P0000020?ooo`8000000P3oool>00000080oooo0P0000020?ooo`@000000P3oool2000000@0
oooo0P0000080?ooo`800000103oool700000080oooo100000040?ooo`@000000P3oool200000080
oooo100000020?ooo`@000001P3oool200000080oooo0P0000040?ooo`8000000P3oool2000000X0
oooo0P0000040?ooo`@000002P3oool4000000@0oooo0P0000040?ooo`@000000P3oool4000001T0
oooo0P0000020?ooo`@000000P3oool2000000X0oooo0P0000080?ooo`@000000P3oool2000000@0
oooo0P0000040?ooo`800000103oool200000080oooo0P0000020?ooo`8000003`3AcJT000d0dLfY
0P0000040?ooo`800000203oool200000080oooo100000060?ooo`@000000P3oool400000080oooo
1P0000080?ooo`@000000P3oool4000000030?ooo`000000000000@000001P3oool200000080oooo
100000020?ooo`H000002P3oool2000000@0oooo0P0000020?ooo`8000000P3oool600000080oooo
1P0000060?ooo`8000000P3oool200000080oooo3P0000020?ooo`8000000P3oool400000080oooo
0P0000040?ooo`800000203oool2000000@0oooo1`0000020?ooo`@00000103oool400000080oooo
0P0000020?ooo`@000000P3oool4000000H0oooo0P0000020?ooo`800000103oool200000080oooo
0P00000:0?ooo`800000103oool4000000X0oooo100000040?ooo`800000103oool400000080oooo
1000000I0?ooo`8000000P3oool400000080oooo0P00000:0?ooo`800000203oool400000080oooo
0P0000040?ooo`800000103oool2000000@0oooo0P0000020?ooo`8000000P3oool2000000l0dLfY
000=0=7=Z@P0oooo2P0000020?ooo`8000002P3oool200000080oooo0P0000060?ooo`800000303o
ool200000080oooo0P0000050?ooo`8000002P3oool4000000H0oooo0P00000>0?ooo`H000000P3o
ool200000080oooo0P0000040?ooo`@00000103oool800000080oooo0P0000020?ooo`800000103o
ool2000000@0oooo0P0000020?ooo`8000000P3oool2000000H0oooo1P0000020?ooo`P000000P3o
ool4000000<0oooo0P0000020?ooo`800000203oool200000080oooo0P0000020?ooo`8000001P3o
ool200000080oooo1P0000020?ooo`8000000P3oool400000080oooo0P0000020?ooo`X000000P3o
ool4000000h0oooo0P0000020?ooo`@000000P3oool4000000H0oooo0P0000020?oooaT000000P3o
ool2000000H0oooo300000020?ooo`P000001P3oool600000080oooo100000020?ooo`@000000P3o
ool200000080oooo0P00000?0=7=Z@003@3AcJT80?ooo`X000000P3oool2000000X0oooo0P000002
0?ooo`8000001P3oool2000000`0oooo0P0000020?ooo`8000001@3oool2000000X0oooo10000006
0?ooo`8000003P3oool600000080oooo0P0000020?ooo`800000103oool4000000@0oooo20000002
0?ooo`8000000P3oool2000000@0oooo0P0000040?ooo`8000000P3oool200000080oooo0P000006
0?ooo`H000000P3oool800000080oooo100000030?ooo`8000000P3oool2000000P0oooo0P000002
0?ooo`8000000P3oool2000000H0oooo0P0000020?ooo`H000000P3oool200000080oooo10000002
0?ooo`8000000P3oool:00000080oooo1000000>0?ooo`8000000P3oool400000080oooo10000006
0?ooo`8000000P3ooolI00000080oooo0P0000060?ooo``000000P3oool8000000H0oooo1P000002
0?ooo`@000000P3oool400000080oooo0P0000020?ooo`8000003`3AcJT000d0dLfY2P0000040?oo
o`8000001P3oool<00000080oooo0P0000020?ooo`H000000P3oool<00000080oooo0P0000020?oo
o`D000000P3oool:000000X0oooo400000040?ooo`@000000P3oool200000080oooo100000080?oo
o`800000103oool400000080oooo0P0000020?ooo`@000000P3oool400000080oooo0P0000020?oo
o`8000000P3oool6000000@0oooo100000040?ooo`8000000P3oool2000000L0oooo100000020?oo
o`P000000P3oool200000080oooo0P0000020?ooo`H000000P3oool2000000@0oooo100000020?oo
o`8000001P3oool4000000@0oooo0P0000060?ooo`8000000P3oool>00000080oooo0P0000060?oo
o`8000000P3oool600000080oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000030?oo
o`8000000P3oool200000080oooo1P0000040?ooo`800000103oool4000000@0oooo0P0000020?oo
o`H00000103oool4000000H0oooo0P0000020?ooo`8000000P3oool2000000l0dLfY000=0=7=Z@X0
0000103oool2000000H0oooo300000020?ooo`8000000P3oool600000080oooo300000020?ooo`80
00000P3oool500000080oooo2P00000:0?oooa000000103oool400000080oooo0P0000020?ooo`@0
0000203oool2000000@0oooo100000020?ooo`8000000P3oool400000080oooo100000020?ooo`80
00000P3oool200000080oooo1P0000040?ooo`@00000103oool200000080oooo0P0000070?ooo`@0
00000P3oool800000080oooo0P0000020?ooo`8000000P3oool600000080oooo0P0000040?ooo`@0
00000P3oool2000000H0oooo100000040?ooo`8000001P3oool200000080oooo3P0000020?ooo`80
00001P3oool200000080oooo1P0000020?ooo`800000103oool2000000@0oooo0P0000040?ooo`80
00000`3oool200000080oooo0P0000020?ooo`H00000103oool2000000@0oooo100000040?ooo`80
00000P3oool6000000@0oooo100000060?ooo`8000000P3oool200000080oooo0P00000?0=7=Z@00
3@3AcJT2000000@0oooo0P0000080?ooo`P00000103oool2000000@0oooo100000020?ooo`800000
103oool4000000@0oooo0P0000040?ooo`@000000P3oool00`000000oooo0?ooo`020?ooo`@00000
103oool2000000h0oooo0P0000040?ooo`800000103oool200000080oooo100000060?ooo`@00000
303oool6000000H0oooo100000060?ooo`8000000P3oool200000080oooo0P0000020?ooo`800000
103oool6000000P0oooo100000020?ooo`L000001P3oool2000000@0oooo100000020?ooo`800000
0P3oool2000000@0oooo100000020?ooo`@000001P3oool8000000P0oooo200000020?ooo`800000
103oool2000000@0oooo0P0000020?ooo`8000000P3oool600000080oooo0P0000040?ooo`@00000
0P3oool400000080oooo100000020?ooo`@000000P3oool300000080oooo0P0000020?ooo`800000
103oool600000080oooo100000080?ooo`@00000103oool6000000X0oooo100000020?ooo`800000
3`3AcJT000d0dLfY0P0000040?ooo`800000203oool8000000@0oooo0P0000040?ooo`@000000P3o
ool2000000@0oooo100000040?ooo`800000103oool400000080oooo00<000000?ooo`3oool00P3o
ool4000000@0oooo0P00000>0?ooo`800000103oool2000000@0oooo0P0000020?ooo`@000001P3o
ool4000000`0oooo1P0000060?ooo`@000001P3oool200000080oooo0P0000020?ooo`8000000P3o
ool2000000@0oooo1P0000080?ooo`@000000P3oool7000000H0oooo0P0000040?ooo`@000000P3o
ool200000080oooo0P0000040?ooo`@000000P3oool4000000H0oooo200000080?ooo`P000000P3o
ool2000000@0oooo0P0000040?ooo`8000000P3oool200000080oooo1P0000020?ooo`800000103o
ool400000080oooo100000020?ooo`@000000P3oool400000080oooo0`0000020?ooo`8000000P3o
ool2000000@0oooo1P0000020?ooo`@00000203oool4000000@0oooo1P00000:0?ooo`@000000P3o
ool2000000l0dLfY000=0=7=Z@80oooo1P0000020?ooo`P00000103oool200000080oooo10000002
0?ooo`@000001P3oool6000000P0oooo1P0000050?ooo`H00000203oool@00000080oooo10000002
0?ooo`@000000P3oool2000000X0oooo0P0000020?ooo``00000103oool8000000X0oooo10000002
0?ooo`8000000P3oool200000080oooo100000040?ooo`X000001P3oool00`000000oooo0?ooo`02
0?ooo`P000000P3oool4000000H0oooo100000020?ooo`@000001P3oool200000080oooo1P000004
0?ooo`8000000P3oool8000000@0oooo0P0000020?ooo`8000000P3oool400000080oooo10000002
0?ooo`8000000P3oool2000000@0oooo100000020?ooo`@000001P3oool200000080oooo0P000006
0?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`@000000P3oool4000000@0oooo1000000<
0?ooo`8000000P3oool4000000@0oooo300000060?ooo`l0dLfY000=0=7=Z@80oooo1P0000020?oo
o`P00000103oool200000080oooo100000020?ooo`@000001P3oool6000000P0oooo1P0000050?oo
o`H00000203oool@00000080oooo100000020?ooo`@000000P3oool2000000X0oooo0P0000020?oo
o``00000103oool8000000X0oooo100000020?ooo`8000000P3oool200000080oooo100000040?oo
o`X000001P3oool00`000000oooo0?ooo`020?ooo`P000000P3oool4000000H0oooo100000020?oo
o`@000001P3oool200000080oooo1P0000040?ooo`8000000P3oool8000000@0oooo0P0000020?oo
o`8000000P3oool400000080oooo100000020?ooo`8000000P3oool2000000@0oooo100000020?oo
o`@000001P3oool200000080oooo0P0000060?ooo`8000000P3oool00`000000oooo0?ooo`040?oo
o`@000000P3oool4000000@0oooo1000000<0?ooo`8000000P3oool4000000@0oooo300000060?oo
o`l0dLfY000=0=7=Z@@0oooo0P0000060?ooo`800000103oool600000080oooo0P0000060?ooo`80
00000P3oool6000000@0oooo2P0000040?ooo`L00000103oool:000000@0oooo0P0000040?ooo`80
00001P3oool200000080oooo0P0000060?ooo``000000P3oool2000000@0oooo0P0000040?ooo`H0
0000103oool200000080oooo2P0000060?ooo`@000000P3oool2000000P0oooo0P0000040?ooo`80
00000P3oool500000080oooo100000040?ooo`8000000P3oool2000000X0oooo0P0000020?ooo`80
00002P3oool4000000@0oooo1P0000020?ooo`800000103oool200000080oooo100000020?ooo`80
00000P3oool2000000H0oooo0P0000020?ooo`8000000P3oool200000080oooo100000060?ooo`80
00000P3oool600000080oooo0P0000020?ooo`H000000P3oool00`000000oooo0?ooo`06000000H0
oooo0P0000020?ooo`@00000403oool4000000P0oooo0P0000040?ooo`800000203oool?0=7=Z@00
3@3AcJT40?ooo`8000001P3oool2000000@0oooo1P0000020?ooo`8000001P3oool200000080oooo
1P0000040?ooo`X00000103oool7000000@0oooo2P0000040?ooo`800000103oool2000000H0oooo
0P0000020?ooo`8000001P3oool<00000080oooo0P0000040?ooo`800000103oool6000000@0oooo
0P0000020?ooo`X000001P3oool400000080oooo0P0000080?ooo`800000103oool200000080oooo
1@0000020?ooo`@00000103oool200000080oooo0P00000:0?ooo`8000000P3oool2000000X0oooo
100000040?ooo`H000000P3oool2000000@0oooo0P0000020?ooo`@000000P3oool200000080oooo
0P0000060?ooo`8000000P3oool200000080oooo0P0000020?ooo`@000001P3oool200000080oooo
1P0000020?ooo`8000000P3oool600000080oooo00<000000?ooo`3oool01P0000060?ooo`800000
0P3oool400000100oooo100000080?ooo`800000103oool2000000P0oooo3`3AcJT000d0dLfY1P00
00020?ooo`H000000P3oool4000000@0oooo100000020?ooo`H000000P3oool2000000@0oooo1P00
00040?ooo`800000203oool2000000<0oooo1P0000040?ooo`800000203oool600000080oooo1P00
00020?ooo`8000000P3oool6000000@0oooo0P0000040?ooo`@000000P3oool400000080oooo1000
00040?ooo`H000000P3oool2000000@0oooo0P00000:0?ooo`8000000P3oool200000080oooo2000
00020?ooo`@000000P3oool2000000<0oooo100000080?ooo`@000000P3oool:00000080oooo0P00
00020?ooo`X00000203oool2000000H0oooo1P0000020?ooo`8000001P3oool400000080oooo1P00
00020?ooo`8000000P3oool200000080oooo0P00000:0?ooo`@00000103oool400000080oooo0P00
00040?ooo`<000000P3oool2000000@0oooo200000020?ooo`800000503oool200000080oooo2000
00020?ooo`@000000P3oool6000000l0dLfY000=0=7=Z@H000000P3oool600000080oooo10000004
0?ooo`@000000P3oool600000080oooo0P0000040?ooo`H00000103oool2000000P0oooo0P000003
0?ooo`H00000103oool2000000P0oooo1P0000020?ooo`H000000P3oool200000080oooo1P000004
0?ooo`800000103oool400000080oooo100000020?ooo`@00000103oool600000080oooo0P000004
0?ooo`8000002P3oool200000080oooo0P0000020?ooo`P000000P3oool400000080oooo0P000003
0?ooo`@00000203oool400000080oooo2P0000020?ooo`8000000P3oool:000000P0oooo0P000006
0?ooo`H000000P3oool2000000H0oooo100000020?ooo`H000000P3oool200000080oooo0P000002
0?ooo`8000002P3oool4000000@0oooo100000020?ooo`800000103oool300000080oooo0P000004
0?ooo`P000000P3oool2000001@0oooo0P0000020?ooo`P000000P3oool400000080oooo1P00000?
0=7=Z@003@3AcJT40?ooo`8000000P3oool2000000@0oooo100000080?ooo`8000000P3oool20000
00@0oooo100000020?ooo`@00000103oool600000080oooo200000000`3oool00000000000020000
00@0oooo1P0000020?ooo`P00000103oool4000000@0oooo100000020?ooo`800000103oool60000
0080oooo100000060?ooo`8000000P3oool2000000P0oooo0P0000060?ooo`H000000P3oool:0000
0080oooo0P0000020?ooo`800000103oool200000080oooo0P0000060?ooo`D00000303oool20000
0080oooo0P0000040?ooo`8000001P3oool4000000@0oooo0P00000<0?ooo`P00000103oool40000
0080oooo1P0000060?ooo`8000001P3oool400000080oooo0P0000020?ooo`X00000203oool20000
0080oooo0P0000020?ooo`@000001@3oool6000000@0oooo0P0000020?ooo`8000000P3ooolD0000
0080oooo0P0000040?ooo`8000000P3oool2000000H0oooo0P0000020?ooo`l0dLfY000=0=7=Z@@0
oooo0P0000020?ooo`800000103oool4000000P0oooo0P0000020?ooo`800000103oool400000080
oooo100000040?ooo`H000000P3oool8000000030?ooo`000000000000800000103oool600000080
oooo200000040?ooo`@00000103oool400000080oooo0P0000040?ooo`H000000P3oool4000000H0
oooo0P0000020?ooo`800000203oool2000000H0oooo1P0000020?ooo`X000000P3oool200000080
oooo0P0000040?ooo`8000000P3oool2000000H0oooo1@00000<0?ooo`8000000P3oool2000000@0
oooo0P0000060?ooo`@00000103oool2000000`0oooo200000040?ooo`@000000P3oool6000000H0
oooo0P0000060?ooo`@000000P3oool200000080oooo2P0000080?ooo`8000000P3oool200000080
oooo100000050?ooo`H00000103oool200000080oooo0P0000020?oooa@000000P3oool2000000@0
oooo0P0000020?ooo`8000001P3oool200000080oooo3`3AcJT000d0dLfY0P3oool400000080oooo
0P0000020?ooo`@00000303oool400000080oooo100000060?ooo`8000000P3oool4000000@0oooo
100000040?ooo`80000000<0oooo000000000000203oool2000000H0oooo0P0000040?ooo`H00000
203oool200000080oooo0P0000020?ooo`@00000103oool4000000X0oooo100000020?ooo`P00000
0P3oool6000000@0oooo100000040?ooo`8000001P3oool400000080oooo100000020?ooo`800000
0P3oool6000000<0oooo3P0000020?ooo`8000000P3oool400000080oooo1P0000080?ooo`h00000
103oool200000080oooo100000060?ooo`8000002P3oool8000000H0oooo100000040?ooo`800000
303oool400000080oooo0P0000090?ooo`800000203oool400000080oooo0P0000040?ooo`800000
103oool2000000@0oooo0P0000020?ooo`8000000P3oool400000080oooo0P0000020?ooo`H00000
0P3oool?0=7=Z@003@3AcJT20?ooo`@000000P3oool200000080oooo1000000<0?ooo`@000000P3o
ool4000000H0oooo0P0000020?ooo`@00000103oool4000000@0oooo0P0000000`3oool000000000
00080?ooo`8000001P3oool2000000@0oooo1P0000080?ooo`8000000P3oool200000080oooo1000
00040?ooo`@000002P3oool400000080oooo200000020?ooo`H00000103oool4000000@0oooo0P00
00060?ooo`@000000P3oool400000080oooo0P0000020?ooo`H000000`3oool>00000080oooo0P00
00020?ooo`@000000P3oool6000000P0oooo3P0000040?ooo`8000000P3oool4000000H0oooo0P00
000:0?ooo`P000001P3oool4000000@0oooo0P00000<0?ooo`@000000P3oool2000000T0oooo0P00
00080?ooo`@000000P3oool2000000@0oooo0P0000040?ooo`800000103oool200000080oooo0P00
00020?ooo`@000000P3oool200000080oooo1P0000020?ooo`l0dLfY000=0=7=Z@@0oooo0P000002
0?ooo`8000000P3oool200000100oooo0P0000020?ooo`8000002P3oool4000000P0oooo0P000002
0?ooo`@0000000<0oooo0000000000000P3oool800000080oooo1P0000020?ooo`@00000103oool:
00000080oooo0P0000020?ooo`800000203oool200000080oooo2P0000060?ooo`800000103oool4
000000@0oooo1P0000080?ooo`P000001P3oool200000080oooo0P0000020?ooo`800000103oool5
000000@0oooo0P0000040?ooo`8000000P3oool200000080oooo0P0000060?ooo`800000303oool2
000000@0oooo0P0000040?ooo`H000000P3oool2000000X0oooo300000040?ooo`8000000P3oool6
000000P0oooo3P0000060?ooo`/000000P3oool8000000H0oooo1P0000020?ooo`@000000P3oool4
00000080oooo0P0000020?ooo`8000001P3oool4000000@0oooo0P00000?0=7=Z@003@3AcJT40?oo
o`8000000P3oool200000080oooo0P00000@0?ooo`8000000P3oool2000000X0oooo100000080?oo
o`8000000P3oool4000000030?ooo`00000000000080oooo200000020?ooo`H000000P3oool40000
00@0oooo2P0000020?ooo`8000000P3oool2000000P0oooo0P0000020?ooo`X000001P3oool20000
00@0oooo100000040?ooo`H00000203oool8000000H0oooo0P0000020?ooo`8000000P3oool20000
00@0oooo1@0000040?ooo`800000103oool200000080oooo0P0000020?ooo`8000001P3oool20000
00`0oooo0P0000040?ooo`800000103oool600000080oooo0P00000:0?ooo``00000103oool20000
0080oooo1P0000080?ooo`h000001P3oool;00000080oooo200000060?ooo`H000000P3oool40000
0080oooo100000020?ooo`8000000P3oool2000000H0oooo100000040?ooo`8000003`3AcJT000d0
dLfY1P0000020?ooo`8000000P3oool200000080oooo400000020?ooo`8000000P3oool:000000`0
oooo100000050?ooo`@00000103oool200000080oooo0P0000040?ooo`@00000203oool2000000@0
oooo0P0000020?ooo`8000000P3oool200000080oooo200000020?ooo`800000103oool2000000X0
oooo1P0000080?ooo`800000303oool2000000@0oooo200000020?ooo`8000000P3oool200000080
oooo0`0000040?ooo`H000000P3oool400000080oooo0P0000020?ooo`8000000P3oool600000080
oooo300000020?ooo`@000000P3oool4000000@0oooo100000020?ooo`X00000103oool2000000@0
oooo1P0000020?ooo`800000103oool:000000@0oooo0P0000040?ooo`8000000P3oool6000000<0
oooo0P0000040?ooo`@00000103oool200000080oooo1P0000040?ooo`@000001P3oool200000080
oooo0P0000020?ooo`8000000P3oool6000000P0oooo3`3AcJT000d0dLfY0P0000040?ooo`@00000
0P3oool200000080oooo0P0000040?ooo`800000103oool2000000H0oooo100000040?ooo`800000
403oool200000080oooo1@0000080?ooo`@000000P3oool4000000`0oooo1P0000020?ooo`800000
0P3oool200000080oooo0P0000040?ooo`8000000P3oool200000080oooo100000020?ooo`X00000
103oool:00000080oooo300000020?ooo`@00000103oool200000080oooo0P0000020?ooo`800000
0P3oool2000000L0oooo0P0000060?ooo`8000000P3oool200000080oooo0P0000020?ooo`800000
103oool4000000@0oooo0P0000040?ooo`@000001P3oool200000080oooo100000060?ooo`800000
103oool200000080oooo100000020?ooo`@00000103oool400000080oooo100000040?ooo`800000
203oool600000080oooo0P0000040?ooo`D000000P3oool4000000P0oooo100000040?ooo`H00000
2P3oool400000080oooo0P0000020?ooo`800000103oool8000000l0dLfY000=0=7=Z@800000103o
ool400000080oooo0P0000020?ooo`800000103oool2000000@0oooo0P0000060?ooo`@00000103o
ool200000100oooo0P0000020?ooo`D00000203oool400000080oooo1000000<0?ooo`H000000P3o
ool200000080oooo0P0000020?ooo`800000103oool200000080oooo0P0000020?ooo`@000000P3o
ool:000000@0oooo2P0000020?ooo``000000P3oool4000000@0oooo0P0000020?ooo`8000000P3o
ool200000080oooo0P0000070?ooo`8000001P3oool200000080oooo0P0000020?ooo`8000000P3o
ool2000000@0oooo100000040?ooo`800000103oool4000000H0oooo0P0000020?ooo`@000001P3o
ool2000000@0oooo0P0000020?ooo`@000000P3oool4000000@0oooo100000020?ooo`@00000103o
ool2000000P0oooo1P0000020?ooo`800000103oool500000080oooo100000080?ooo`@00000103o
ool6000000X0oooo100000020?ooo`8000000P3oool2000000@0oooo2000000?0=7=Z@003@3AcJT2
0?ooo`H000001P3oool400000080oooo100000020?ooo`@000000P3oool6000000P0oooo4P000002
0?ooo`030000003oool0oooo0080oooo2P0000060?ooo`8000000P3oool<000000@0oooo10000002
0?ooo`8000000P3oool200000080oooo100000020?ooo`8000000P3oool2000000H0oooo0P000004
0?ooo`8000000P3oool4000000@0oooo0P0000060?ooo`800000103oool2000000H0oooo0P000002
0?ooo`@000000P3oool200000080oooo0P0000020?ooo`80000000<0oooo0000000000001P000002
0?ooo`H000000P3oool200000080oooo0P0000020?ooo`8000000P3oool4000000P0oooo1P00000:
0?ooo`@000002P3oool600000080oooo0P0000060?ooo`8000000P3oool4000000H0oooo0P000002
0?ooo`@000000P3oool8000000@0oooo100000020?ooo`<00000103oool4000000`0oooo0P000002
0?ooo`@00000103oool<000000H0oooo100000020?ooo`@00000103oool2000000l0dLfY000=0=7=
Z@80oooo1P0000060?ooo`@000000P3oool400000080oooo100000020?ooo`H00000203ooolB0000
0080oooo00<000000?ooo`3oool00P3oool:000000H0oooo0P0000020?ooo``00000103oool40000
0080oooo0P0000020?ooo`8000000P3oool400000080oooo0P0000020?ooo`8000001P3oool20000
00@0oooo0P0000020?ooo`@00000103oool2000000H0oooo0P0000040?ooo`8000001P3oool20000
0080oooo100000020?ooo`8000000P3oool200000080oooo0P0000000`3oool00000000000060000
0080oooo1P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`@00000203oool60000
00X0oooo1000000:0?ooo`H000000P3oool2000000H0oooo0P0000020?ooo`@000001P3oool20000
0080oooo100000020?ooo`P00000103oool400000080oooo0`0000040?ooo`@00000303oool20000
0080oooo100000040?ooo``000001P3oool400000080oooo100000040?ooo`8000003`3AcJT000d0
dLfY103oool2000000X0oooo0P0000020?ooo`8000001P3oool200000080oooo0P0000040?ooo`X0
0000103oool2000000@0oooo0P0000040?ooo`<000000P3oool4000000@0oooo0P00000:0?ooo`@0
0000103oool2000000@0oooo1P0000060?ooo`@000000P3oool2000000H0oooo100000020?ooo`H0
00000P3oool400000080oooo0P0000080?ooo`P000000P3oool400000080oooo1P0000020?ooo`80
00001P3oool400000080oooo0P0000000`3oool00000000000040?ooo`8000000P3oool2000000@0
oooo100000020?ooo`8000000P3oool200000080oooo0P00000<0?ooo`8000003P3oool200000080
oooo2P0000040?ooo`@000000P3oool600000080oooo0P00000:0?ooo`@000001P3oool2000000@0
oooo1P0000060?ooo`030000003oool0oooo00@00000403oool4000000P0oooo0P0000040?ooo`80
00002P3oool200000080oooo0P0000080?ooo`l0dLfY000=0=7=Z@@0oooo0P00000:0?ooo`800000
0P3oool2000000H0oooo0P0000020?ooo`800000103oool:000000@0oooo0P0000040?ooo`800000
103oool300000080oooo100000040?ooo`8000002P3oool4000000@0oooo0P0000040?ooo`H00000
1P3oool400000080oooo0P0000060?ooo`@000000P3oool600000080oooo100000020?ooo`800000
203oool800000080oooo100000020?ooo`H000000P3oool2000000H0oooo100000020?ooo`800000
00<0oooo000000000000103oool200000080oooo0P0000040?ooo`@000000P3oool200000080oooo
0P0000020?ooo`800000303oool2000000h0oooo0P0000020?ooo`X00000103oool400000080oooo
1P0000020?ooo`8000002P3oool4000000H0oooo0P0000040?ooo`H000001P3oool00`000000oooo
0?ooo`0400000100oooo100000080?ooo`800000103oool2000000X0oooo0P0000020?ooo`800000
203oool?0=7=Z@003@3AcJT600000080oooo2P0000020?ooo`8000000P3oool600000080oooo0P00
00020?ooo`@00000103oool2000000P0oooo1P0000020?ooo`@000001@3oool200000080oooo1000
00020?ooo`X00000203oool6000000@0oooo200000060?ooo`P000001P3oool2000000H0oooo0P00
00020?ooo`8000000P3oool8000000@0oooo0P0000020?ooo`8000001P3oool2000000H0oooo2000
00060?ooo`<000000P3oool400000080oooo0P0000020?ooo`@000001P3oool400000080oooo0P00
00020?ooo``000000P3oool>00000080oooo0P0000040?ooo`800000203oool200000080oooo0P00
00040?ooo`@000000P3oool:000000X0oooo1P0000040?ooo`L000000P3oool2000001@0oooo0P00
00020?ooo`P000000P3oool400000080oooo2P0000020?ooo`8000000P3oool6000000l0dLfY000=
0=7=Z@H000000P3oool:00000080oooo0P0000020?ooo`H000000P3oool200000080oooo10000004
0?ooo`800000203oool600000080oooo100000050?ooo`8000000P3oool400000080oooo2P000008
0?ooo`H00000103oool8000000H0oooo200000060?ooo`8000001P3oool200000080oooo0P000002
0?ooo`P00000103oool200000080oooo0P0000060?ooo`8000001P3oool8000000H0oooo0`000002
0?ooo`@000000P3oool200000080oooo100000060?ooo`@000000P3oool200000080oooo30000002
0?ooo`h000000P3oool2000000@0oooo0P0000080?ooo`8000000P3oool2000000@0oooo10000002
0?ooo`X000002P3oool6000000@0oooo1`0000020?ooo`800000503oool200000080oooo20000002
0?ooo`@000000P3oool:00000080oooo0P0000020?ooo`H000003`3AcJT000d0dLfY0P0000040?oo
o`@00000103oool2000000H0oooo100000040?ooo`@000000P3oool2000000P0oooo2P0000040?oo
o`@000002@3oool4000000H0oooo0P0000040?ooo`8000000P3oool8000000@0oooo1P0000040?oo
o`8000000P3oool6000000@0oooo0P0000020?ooo`H000000P3oool600000080oooo0P0000020?oo
o`800000103oool200000080oooo100000020?ooo`8000000P3oool600000080oooo1P0000040?oo
o`8000000P3oool5000000H0oooo0P0000020?ooo`8000000P3oool2000000X0oooo0P0000020?oo
o`8000000P3oool2000000@0oooo0P0000040?ooo`@00000103oool2000000@0oooo0P0000020?oo
o`8000000P3oool400000080oooo200000020?ooo`8000000P3oool4000000H0oooo0P0000040?oo
o`8000000P3oool:000000@0oooo1P0000040?ooo`030000003oool0oooo008000000P3ooolD0000
0080oooo0P0000040?ooo`8000000P3oool2000000H0oooo0P0000040?ooo`8000000P3oool20000
0080oooo0P0000040?ooo`l0dLfY000=0=7=Z@800000103oool4000000@0oooo0P0000060?ooo`@0
0000103oool400000080oooo0P0000080?ooo`X00000103oool4000000T0oooo100000060?ooo`80
0000103oool200000080oooo200000040?ooo`H00000103oool200000080oooo1P0000040?ooo`80
00000P3oool600000080oooo1P0000020?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`@0
00000P3oool200000080oooo1P0000020?ooo`H00000103oool200000080oooo1@0000060?ooo`80
00000P3oool200000080oooo0P00000:0?ooo`8000000P3oool200000080oooo0P0000040?ooo`80
0000103oool4000000@0oooo0P0000040?ooo`8000000P3oool200000080oooo100000020?ooo`P0
00000P3oool200000080oooo100000060?ooo`800000103oool200000080oooo2P0000040?ooo`H0
0000103oool00`000000oooo0?ooo`0200000080oooo500000020?ooo`800000103oool200000080
oooo0P0000060?ooo`800000103oool200000080oooo0P0000020?ooo`800000103oool?0=7=Z@00
3@3AcJT200000080oooo100000080?ooo`P00000203oool200000080oooo0P0000020?ooo`P00000
103oool2000000P0oooo0P0000020?ooo`T000002P3oool600000080oooo0P0000040?ooo`800000
0P3oool4000000@0oooo1P0000020?ooo`800000103oool600000080oooo0P0000040?ooo`@00000
103oool400000080oooo0P0000020?ooo`@000000P3oool2000000H0oooo100000040?ooo`@00000
103oool600000080oooo0P0000030?ooo`P000000P3oool200000080oooo0P0000020?ooo`X00000
0P3oool200000080oooo0P0000020?ooo`@000000P3oool4000000P0oooo1P0000020?ooo`800000
0P3oool2000000H0oooo0P0000040?ooo`@000000P3oool2000000X0oooo1P0000020?ooo`800000
103oool2000000P0oooo0P0000070?ooo`@000000P3oool2000000@0oooo0P0000040?ooo`800000
103oool200000080oooo0P0000020?ooo`@000000P3oool200000080oooo1P0000020?ooo`@00000
0P3oool200000080oooo0P0000020?ooo`8000003`3AcJT000d0dLfY0P0000020?ooo`@00000203o
ool8000000P0oooo0P0000020?ooo`8000000P3oool8000000@0oooo0P0000080?ooo`8000000P3o
ool9000000X0oooo1P0000020?ooo`800000103oool200000080oooo100000040?ooo`H000000P3o
ool2000000@0oooo1P0000020?ooo`800000103oool4000000@0oooo100000020?ooo`8000000P3o
ool400000080oooo0P0000060?ooo`@00000103oool4000000@0oooo1P0000020?ooo`8000000`3o
ool800000080oooo0P0000020?ooo`8000000P3oool:00000080oooo0P0000020?ooo`8000000P3o
ool400000080oooo100000080?ooo`H000000P3oool200000080oooo0P0000060?ooo`800000103o
ool400000080oooo0P00000:0?ooo`H000000P3oool2000000@0oooo0P0000080?ooo`8000001`3o
ool400000080oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000020?ooo`8000000P3o
ool400000080oooo0P0000020?ooo`H000000P3oool400000080oooo0P0000020?ooo`8000000P3o
ool2000000l0dLfY000=0=7=Z@H0oooo0P0000020?ooo`P00000103oool200000080oooo20000002
0?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`@000000P3oool800000080oooo00<00000
0?ooo`3oool00P3oool2000000h0oooo0P0000060?ooo`H000000P3oool2000000P0oooo0P000006
0?ooo`H00000103oool400000080oooo100000080?ooo`8000000P3oool200000080oooo0P000006
0?ooo`P00000203oool200000080oooo100000040?ooo`@000000P3oool3000000@0oooo0P000002
0?ooo`8000000P3oool200000080oooo0P0000040?ooo`8000001P3oool400000080oooo0P000006
0?ooo`8000000P3oool8000000@0oooo100000020?ooo`8000000P3oool600000080oooo10000006
0?ooo``00000103oool400000080oooo100000020?ooo`P000000P3oool7000000H0oooo1P000002
0?ooo`@000000P3oool400000080oooo0P0000020?ooo`8000001P3oool4000000@0oooo10000006
0?ooo`@000000P3oool2000000l0dLfY000=0=7=Z@H0oooo0P0000020?ooo`P00000103oool20000
0080oooo200000020?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`@000000P3oool80000
0080oooo00<000000?ooo`3oool00P3oool2000000h0oooo0P0000060?ooo`H000000P3oool20000
00P0oooo0P0000060?ooo`H00000103oool400000080oooo100000080?ooo`8000000P3oool20000
0080oooo0P0000060?ooo`P00000203oool200000080oooo100000040?ooo`@000000P3oool30000
00@0oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000040?ooo`8000001P3oool40000
0080oooo0P0000060?ooo`8000000P3oool8000000@0oooo100000020?ooo`8000000P3oool60000
0080oooo100000060?ooo``00000103oool400000080oooo100000020?ooo`P000000P3oool70000
00H0oooo1P0000020?ooo`@000000P3oool400000080oooo0P0000020?ooo`8000001P3oool40000
00@0oooo100000060?ooo`@000000P3oool2000000l0dLfY000=0=7=Z@80oooo1P0000020?ooo`80
0000103oool200000080oooo100000020?ooo`800000103oool200000080oooo0P0000020?ooo`80
00000P3oool400000080oooo0P0000060?ooo`800000103oool300000080oooo100000020?ooo`h0
00000P3oool6000000@0oooo100000020?ooo`P000000P3oool6000000@0oooo1P0000060?ooo`80
00000P3oool800000080oooo0P0000020?ooo`8000000P3oool6000000@0oooo0P0000020?ooo`P0
00000P3oool2000000P0oooo0P0000020?ooo`030000003oool0oooo00H0oooo100000020?ooo`80
00000P3oool200000080oooo100000020?ooo`H000001P3oool800000080oooo0P0000040?ooo`80
00000P3oool4000000H0oooo100000040?ooo`@000002P3oool2000000@0oooo0P0000080?ooo`80
00000P3oool2000000H0oooo0P0000040?ooo`@000000`3oool200000080oooo1P0000040?ooo`@0
00001P3oool200000080oooo0P0000020?ooo`8000000P3oool6000000P0oooo0P0000020?ooo`H0
00001P3oool?0=7=Z@003@3AcJT20?ooo`H000000P3oool2000000@0oooo0P0000020?ooo`@00000
0P3oool2000000@0oooo0P0000020?ooo`8000000P3oool200000080oooo100000020?ooo`800000
1P3oool2000000@0oooo0`0000020?ooo`@000000P3oool>00000080oooo1P0000040?ooo`@00000
0P3oool800000080oooo1P0000040?ooo`H000001P3oool200000080oooo200000020?ooo`800000
0P3oool200000080oooo1P0000040?ooo`8000000P3oool800000080oooo0P0000080?ooo`800000
0P3oool00`000000oooo0?ooo`060?ooo`@000000P3oool200000080oooo0P0000020?ooo`@00000
0P3oool6000000H0oooo200000020?ooo`800000103oool200000080oooo100000060?ooo`@00000
103oool4000000X0oooo0P0000040?ooo`800000203oool200000080oooo0P0000060?ooo`800000
103oool4000000<0oooo0P0000020?ooo`H00000103oool4000000H0oooo0P0000020?ooo`800000
0P3oool200000080oooo1P0000080?ooo`8000000P3oool6000000H0oooo3`3AcJT000d0dLfY1000
00040?ooo`@000000P3oool400000080oooo0P0000060?ooo`H000000P3oool200000080oooo0P00
00020?ooo`8000001P3oool800000080oooo100000050?ooo`8000000P3oool2000000@0oooo0P00
00040?ooo`8000000P3oool2000000@0oooo1P0000060?ooo`800000103oool4000000@0oooo1P00
00040?ooo`P000000P3oool2000000@0oooo0P0000020?ooo`8000000P3oool200000080oooo0P00
00040?ooo`H000000P3oool2000000@0oooo0P0000020?ooo`8000000P3oool800000080oooo00<0
00000?ooo`3oool0200000060?ooo`@000000P3oool2000000H0oooo0P00000:0?ooo`800000103o
ool400000080oooo100000020?ooo`8000002P3oool200000080oooo1000000>0?ooo`H000000P3o
ool800000080oooo0P0000020?ooo`H000000P3oool4000000L0oooo100000040?ooo`H000002P3o
ool400000080oooo0P0000020?ooo`800000103oool:00000080oooo0P0000040?ooo`H000003`3A
cJT000d0dLfY100000040?ooo`@000000P3oool400000080oooo0P0000060?ooo`H000000P3oool2
00000080oooo0P0000020?ooo`8000001P3oool800000080oooo100000050?ooo`8000000P3oool2
000000@0oooo0P0000040?ooo`8000000P3oool2000000@0oooo1P0000060?ooo`800000103oool4
000000@0oooo1P0000040?ooo`P000000P3oool2000000@0oooo0P0000020?ooo`8000000P3oool2
00000080oooo0P0000040?ooo`H000000P3oool2000000@0oooo0P0000020?ooo`8000000P3oool8
00000080oooo00<000000?ooo`3oool0200000060?ooo`@000000P3oool2000000H0oooo0P00000:
0?ooo`800000103oool400000080oooo100000020?ooo`8000002P3oool200000080oooo1000000>
0?ooo`H000000P3oool800000080oooo0P0000020?ooo`H000000P3oool4000000L0oooo10000004
0?ooo`H000002P3oool400000080oooo0P0000020?ooo`800000103oool:00000080oooo0P000004
0?ooo`H000003`3AcJT000d0dLfY0P0000080?ooo`8000000P3oool2000000H0oooo200000040?oo
o`@000000P3oool200000080oooo0P0000020?ooo`H00000103oool200000080oooo0P0000090?oo
o`@000000P3oool400000080oooo100000020?ooo`8000000P3oool4000000@0oooo200000020?oo
o`@00000203oool2000000P0oooo0P0000040?ooo`@000000P3oool400000080oooo0P0000020?oo
o`8000000P3oool200000080oooo100000040?ooo`@000000P3oool400000080oooo0P0000020?oo
o`800000103oool200000080oooo00<000000?ooo`3oool00P0000040?ooo`8000000P3oool60000
00H0oooo200000020?ooo`X000000P3oool4000000H0oooo0P0000020?ooo`8000000P3oool:0000
0080oooo0P00000B0?ooo`8000001P3oool2000000@0oooo100000020?ooo`800000103oool40000
00/0oooo0P0000020?ooo`@00000103oool<000000H0oooo100000020?ooo`@00000103oool20000
00H0oooo1P0000040?ooo`l0dLfY000=0=7=Z@800000203oool200000080oooo0P0000060?ooo`P0
0000103oool400000080oooo0P0000020?ooo`8000000P3oool6000000@0oooo0P0000020?ooo`80
00002@3oool400000080oooo100000020?ooo`@000000P3oool200000080oooo100000040?ooo`P0
00000P3oool4000000P0oooo0P0000080?ooo`800000103oool400000080oooo100000020?ooo`80
00000P3oool200000080oooo0P0000020?ooo`@00000103oool400000080oooo100000020?ooo`80
00000P3oool2000000@0oooo0P0000020?ooo`030000003oool0oooo00800000103oool200000080
oooo1P0000060?ooo`P000000P3oool:00000080oooo100000060?ooo`8000000P3oool200000080
oooo2P0000020?ooo`8000004P3oool2000000H0oooo0P0000040?ooo`@000000P3oool2000000@0
oooo1000000;0?ooo`8000000P3oool4000000@0oooo300000060?ooo`@000000P3oool4000000@0
oooo0P0000060?ooo`H00000103oool?0=7=Z@003@3AcJT<0?ooo`@000000P3oool6000000@0oooo
0P0000020?ooo`@000001P3oool400000080oooo0P0000040?ooo`H000000P3oool200000080oooo
2@0000060?ooo`8000000P3oool2000000H0oooo100000080?ooo`800000103oool4000000`0oooo
2P0000020?ooo`@000001P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo
0P0000080?ooo`8000000P3oool2000000H0oooo100000020?ooo`@000000P3oool00`000000oooo
0?ooo`0200000080oooo100000020?ooo`800000103oool8000000@0oooo0P0000020?ooo`800000
103oool2000000H0oooo0P0000020?ooo`H000000P3oool200000080oooo0P0000040?ooo`800000
1P3ooolD00000080oooo1P0000020?ooo`@000001P3oool6000000l0oooo100000080?ooo`800000
103oool2000000X0oooo0P0000020?ooo`800000203oool8000000@0oooo1000000?0=7=Z@003@3A
cJT<0?ooo`@000000P3oool6000000@0oooo0P0000020?ooo`@000001P3oool400000080oooo0P00
00040?ooo`H000000P3oool200000080oooo2@0000060?ooo`8000000P3oool2000000H0oooo1000
00080?ooo`800000103oool4000000`0oooo2P0000020?ooo`@000001P3oool200000080oooo0P00
00020?ooo`8000000P3oool200000080oooo0P0000080?ooo`8000000P3oool2000000H0oooo1000
00020?ooo`@000000P3oool00`000000oooo0?ooo`0200000080oooo100000020?ooo`800000103o
ool8000000@0oooo0P0000020?ooo`800000103oool2000000H0oooo0P0000020?ooo`H000000P3o
ool200000080oooo0P0000040?ooo`8000001P3ooolD00000080oooo1P0000020?ooo`@000001P3o
ool6000000l0oooo100000080?ooo`800000103oool2000000X0oooo0P0000020?ooo`800000203o
ool8000000@0oooo1000000?0=7=Z@003@3AcJT>0?ooo`8000000P3oool2000000@0oooo1P000002
0?ooo`8000002P3oool200000080oooo0P0000020?ooo`@00000103oool400000080oooo00<00000
0?ooo`3oool00P3oool2000000X0oooo100000020?ooo`H00000303oool600000100oooo0P000004
0?ooo`8000000P3oool2000000X0oooo100000020?ooo`8000000P3oool200000080oooo0P000002
0?ooo`P000000P3oool200000080oooo1P0000060?ooo`8000000P3oool00`000000oooo0?ooo`02
00000080oooo0P0000060?ooo`H00000103oool200000080oooo100000020?ooo`8000000P3oool4
00000080oooo1P0000020?ooo`800000103oool400000080oooo0P0000020?ooo`@000000P3oool6
000000@0oooo0P0000040?ooo`800000103oool200000080oooo0P0000040?ooo`@000002P3oool2
000001<0oooo0P0000020?ooo`P000000P3oool400000080oooo2P0000020?ooo`8000000P3oool8
000000@0oooo0P0000020?ooo`@000000P3oool?0=7=Z@003@3AcJT>0?ooo`8000000P3oool20000
00@0oooo1P0000020?ooo`8000002P3oool200000080oooo0P0000020?ooo`@00000103oool40000
0080oooo00<000000?ooo`3oool00P3oool2000000X0oooo100000020?ooo`H00000303oool60000
0100oooo0P0000040?ooo`8000000P3oool2000000X0oooo100000020?ooo`8000000P3oool20000
0080oooo0P0000020?ooo`P000000P3oool200000080oooo1P0000060?ooo`8000000P3oool00`00
0000oooo0?ooo`0200000080oooo0P0000060?ooo`H00000103oool200000080oooo100000020?oo
o`8000000P3oool400000080oooo1P0000020?ooo`800000103oool400000080oooo0P0000020?oo
o`@000000P3oool6000000@0oooo0P0000040?ooo`800000103oool200000080oooo0P0000040?oo
o`@000002P3oool2000001<0oooo0P0000020?ooo`P000000P3oool400000080oooo2P0000020?oo
o`8000000P3oool8000000@0oooo0P0000020?ooo`@000000P3oool?0=7=Z@003@3AcJT@00000080
oooo0P0000020?ooo`@00000103oool400000080oooo2P0000020?ooo`8000000P3oool2000000P0
oooo0P0000020?ooo`030000003oool0oooo00@000000P3oool:000000H0oooo0P00000@0?ooo`80
0000503oool600000080oooo0P0000020?ooo`X000001P3oool400000080oooo0P0000020?ooo`80
0000103oool200000080oooo0P0000020?ooo`800000103oool800000080oooo00<000000?ooo`3o
ool00P0000020?ooo`8000000P3oool6000000@0oooo1P0000020?ooo`8000001P3oool4000000H0
oooo0P0000060?ooo`H000001P3oool4000000H0oooo0P0000080?ooo`H000000P3oool400000080
oooo0P0000020?ooo`@000003P3ooolE00000080oooo0P0000040?ooo`8000000P3oool2000000H0
oooo0P0000040?ooo`8000000P3oool200000080oooo0P0000040?ooo`8000000P3oool400000080
oooo0P0000040?ooo`l0dLfY000=0=7=ZA0000000P3oool200000080oooo100000040?ooo`@00000
0P3oool:00000080oooo0P0000020?ooo`800000203oool200000080oooo00<000000?ooo`3oool0
100000020?ooo`X000001P3oool200000100oooo0P00000D0?ooo`H000000P3oool200000080oooo
2P0000060?ooo`@000000P3oool200000080oooo0P0000040?ooo`8000000P3oool200000080oooo
0P0000040?ooo`P000000P3oool00`000000oooo0?ooo`0200000080oooo0P0000020?ooo`H00000
103oool600000080oooo0P0000060?ooo`@000001P3oool2000000H0oooo1P0000060?ooo`@00000
1P3oool2000000P0oooo1P0000020?ooo`@000000P3oool200000080oooo1000000>0?oooaD00000
0P3oool2000000@0oooo0P0000020?ooo`8000001P3oool2000000@0oooo0P0000020?ooo`800000
0P3oool2000000@0oooo0P0000020?ooo`@000000P3oool2000000@0oooo3`3AcJT000d0dLfY0P00
00040?ooo`800000103oool2000000H0oooo100000080?ooo`8000000P3oool2000000@0oooo0P00
00060?ooo`@000000P3oool800000080oooo00<000000?ooo`3oool00P0000060?ooo`800000103o
ool200000080oooo1P0000020?oooa0000000P3ooolD000000@0oooo100000020?ooo`800000103o
ool2000000X0oooo0P0000020?ooo`8000000P3oool200000080oooo100000020?ooo`8000000P3o
ool200000080oooo100000040?ooo`8000000P3oool00`000000oooo0?ooo`0200000080oooo0P00
00020?ooo`800000103oool6000000@0oooo100000020?ooo`H000002P3oool8000000@0oooo2000
000:0?ooo`X00000103oool4000000H0oooo1000000B0?ooo`800000103oool2000000<0oooo0P00
00040?ooo`8000000P3oool200000080oooo100000020?ooo`8000000P3oool600000080oooo1000
00020?ooo`8000000P3oool200000080oooo100000020?ooo`8000001P3oool4000000l0dLfY000=
0=7=Z@800000103oool2000000@0oooo0P0000060?ooo`@00000203oool200000080oooo0P000004
0?ooo`8000001P3oool400000080oooo200000020?ooo`030000003oool0oooo008000001P3oool2
000000@0oooo0P0000020?ooo`H000000P3oool@00000080oooo500000040?ooo`@000000P3oool2
000000@0oooo0P00000:0?ooo`8000000P3oool200000080oooo0P0000020?ooo`@000000P3oool2
00000080oooo0P0000020?ooo`@00000103oool200000080oooo00<000000?ooo`3oool00P000002
0?ooo`8000000P3oool2000000@0oooo1P0000040?ooo`@000000P3oool6000000X0oooo20000004
0?ooo`P000002P3oool:000000@0oooo100000060?ooo`@000004P3oool2000000@0oooo0P000003
0?ooo`800000103oool200000080oooo0P0000020?ooo`@000000P3oool200000080oooo1P000002
0?ooo`@000000P3oool200000080oooo0P0000020?ooo`@000000P3oool2000000H0oooo1000000?
0=7=Z@003@3AcJT200000080oooo100000020?ooo`@000000P3oool6000000`0oooo100000020?oo
o`@000000P3oool6000000H0oooo0P0000040?ooo`<000000P3oool200000080oooo1P0000020?oo
o`@000000P3oool2000000@0oooo100000040?ooo`800000103oool2000000H0oooo0P0000040?oo
o`800000103oool2000000@0oooo1P0000060?ooo`H000000P3oool:00000080oooo0P0000020?oo
o`8000000P3oool2000000H0oooo100000020?ooo`800000203oool300000080oooo0P0000020?oo
o`8000000P3oool200000080oooo100000040?ooo`H000001P3oool2000000h0oooo0P0000040?oo
o`H00000103oool200000080oooo2P0000040?ooo`800000203oool200000080oooo1P00000F0?oo
o`H0000000<0oooo0000000000000P0000020?ooo`@000000P3oool200000080oooo0P0000060?oo
o`@00000103oool4000000H0oooo100000020?ooo`8000001P3oool800000080oooo3`3AcJT000d0
dLfY0P0000020?ooo`@000000P3oool400000080oooo1P00000<0?ooo`@000000P3oool400000080
oooo1P0000060?ooo`800000103oool300000080oooo0P0000020?ooo`H000000P3oool400000080
oooo0P0000040?ooo`@00000103oool2000000@0oooo0P0000060?ooo`800000103oool2000000@0
oooo0P0000040?ooo`H000001P3oool600000080oooo2P0000020?ooo`8000000P3oool200000080
oooo0P0000060?ooo`@000000P3oool2000000P0oooo0`0000020?ooo`8000000P3oool200000080
oooo0P0000020?ooo`@00000103oool6000000H0oooo0P00000>0?ooo`800000103oool6000000@0
oooo0P0000020?ooo`X00000103oool2000000P0oooo0P0000020?ooo`H000005P3oool600000003
0?ooo`0000000000008000000P3oool400000080oooo0P0000020?ooo`8000001P3oool4000000@0
oooo100000060?ooo`@000000P3oool2000000H0oooo200000020?ooo`l0dLfY000=0=7=Z@H0oooo
0P0000020?ooo`8000001P3oool200000100oooo0P0000020?ooo`8000001P3oool2000000X0oooo
1P0000050?ooo`@00000103oool4000000H0oooo1P0000080?ooo`H000000P3oool600000080oooo
100000020?ooo`@000000P3oool4000000@0oooo200000040?ooo`@00000103oool2000000H0oooo
100000020?ooo`8000000P3oool6000000H0oooo2P0000050?ooo`@000000P3oool200000080oooo
0P0000080?ooo`8000002P3oool@00000080oooo100000040?ooo`H000000P3oool2000000@0oooo
0P0000080?ooo`X000000P3oool2000000@0oooo600000040?ooo`<000001P3oool200000080oooo
0P0000020?ooo`8000000P3oool6000000P0oooo0P0000020?ooo`H000001P3oool8000000@0oooo
0P0000020?ooo`l0dLfY000=0=7=Z@H0oooo0P0000020?ooo`8000001P3oool200000100oooo0P00
00020?ooo`8000001P3oool2000000X0oooo1P0000050?ooo`@00000103oool4000000H0oooo1P00
00080?ooo`H000000P3oool600000080oooo100000020?ooo`@000000P3oool4000000@0oooo2000
00040?ooo`@00000103oool2000000H0oooo100000020?ooo`8000000P3oool6000000H0oooo2P00
00050?ooo`@000000P3oool200000080oooo0P0000080?ooo`8000002P3oool@00000080oooo1000
00040?ooo`H000000P3oool2000000@0oooo0P0000080?ooo`X000000P3oool2000000@0oooo6000
00040?ooo`<000001P3oool200000080oooo0P0000020?ooo`8000000P3oool6000000P0oooo0P00
00020?ooo`H000001P3oool8000000@0oooo0P0000020?ooo`l0dLfY000=0=7=Z@P0oooo10000002
0?ooo`H000000P3oool@00000080oooo0P0000020?ooo`H000000P3oool:000000@0oooo1`000008
0?ooo`8000000P3oool6000000@0oooo2P0000040?ooo`@00000103oool4000000H0oooo0P000002
0?ooo`800000203oool2000000@0oooo1P0000080?ooo`P000001P3oool4000000@0oooo20000004
0?ooo`8000002@3oool200000080oooo0P0000020?ooo`8000000P3oool800000080oooo2P000004
0?ooo`800000103oool2000000H0oooo0P0000020?ooo`@00000103oool400000080oooo10000002
0?ooo`P00000103oool2000000H0oooo1P0000040?ooo`800000103oool2000000@0oooo0P000004
0?ooo`D000002P3oool400000080oooo0P0000020?ooo`800000103oool:00000080oooo0P000004
0?ooo`P00000103oool200000080oooo100000020?ooo`l0dLfY000=0=7=Z@P0oooo100000020?oo
o`H000000P3oool@00000080oooo0P0000020?ooo`H000000P3oool:000000@0oooo1`0000080?oo
o`8000000P3oool6000000@0oooo2P0000040?ooo`@00000103oool4000000H0oooo0P0000020?oo
o`800000203oool2000000@0oooo1P0000080?ooo`P000001P3oool4000000@0oooo200000040?oo
o`8000002@3oool200000080oooo0P0000020?ooo`8000000P3oool800000080oooo2P0000040?oo
o`800000103oool2000000H0oooo0P0000020?ooo`@00000103oool400000080oooo100000020?oo
o`P00000103oool2000000H0oooo1P0000040?ooo`800000103oool2000000@0oooo0P0000040?oo
o`D000002P3oool400000080oooo0P0000020?ooo`800000103oool:00000080oooo0P0000040?oo
o`P00000103oool200000080oooo100000020?ooo`l0dLfY000=0=7=Z@X000001P3oool2000000H0
oooo0P0000040?ooo`800000103oool200000080oooo0P0000020?ooo`800000103oool4000000@0
oooo0P0000070?ooo`800000103oool:00000080oooo0P0000040?ooo`H00000103oool2000000P0
oooo0P0000020?ooo`@000002P3oool400000080oooo200000020?ooo`@00000103oool:000000@0
oooo0P0000020?ooo`H00000203oool2000000@0oooo1P0000020?ooo`T000000P3oool200000080
oooo0P0000020?ooo`800000103oool200000080oooo0P0000040?ooo`800000203oool600000080
oooo1P0000020?ooo`800000203oool200000080oooo0P0000060?ooo`800000103oool600000080
oooo1P0000040?ooo`H000000P3oool400000080oooo100000020?ooo`@000000`3oool<000000H0
oooo100000020?ooo`@00000103oool2000000H0oooo1P0000040?ooo`8000000P3oool400000080
oooo0P0000040?ooo`l0dLfY000=0=7=Z@X000001P3oool2000000H0oooo0P0000040?ooo`800000
103oool200000080oooo0P0000020?ooo`800000103oool4000000@0oooo0P0000070?ooo`800000
103oool:00000080oooo0P0000040?ooo`H00000103oool2000000P0oooo0P0000020?ooo`@00000
2P3oool400000080oooo200000020?ooo`@00000103oool:000000@0oooo0P0000020?ooo`H00000
203oool2000000@0oooo1P0000020?ooo`T000000P3oool200000080oooo0P0000020?ooo`800000
103oool200000080oooo0P0000040?ooo`800000203oool600000080oooo1P0000020?ooo`800000
203oool200000080oooo0P0000060?ooo`800000103oool600000080oooo1P0000040?ooo`H00000
0P3oool400000080oooo100000020?ooo`@000000`3oool<000000H0oooo100000020?ooo`@00000
103oool2000000H0oooo1P0000040?ooo`8000000P3oool400000080oooo0P0000040?ooo`l0dLfY
000=0=7=Z@800000103oool2000000X0oooo200000020?ooo`@000000P3oool400000080oooo0P00
00020?ooo`8000000P3oool4000000P0oooo2@0000020?ooo`@00000103oool2000000H0oooo1P00
00040?ooo`H000000P3oool800000080oooo0P00000>0?ooo`8000000P3oool2000000@0oooo0P00
00020?ooo`800000203oool2000000@0oooo0P0000020?ooo`@000000P3oool2000000@0oooo2P00
00020?ooo`@00000103oool3000000@0oooo0P0000060?ooo`@000000P3oool200000080oooo1000
00020?ooo`8000000P3oool400000080oooo200000040?ooo`@00000103oool400000080oooo2000
00020?ooo`8000000P3oool600000080oooo100000040?ooo`@00000103oool6000000@0oooo1000
00060?ooo`8000000P3oool2000000L0oooo0P0000040?ooo`8000002P3oool200000080oooo0P00
00080?ooo`P00000103oool600000080oooo0P0000060?ooo`@000003`3AcJT000d0dLfY0P000004
0?ooo`8000002P3oool800000080oooo100000020?ooo`@000000P3oool200000080oooo0P000002
0?ooo`@00000203oool900000080oooo100000040?ooo`8000001P3oool6000000@0oooo1P000002
0?ooo`P000000P3oool2000000h0oooo0P0000020?ooo`800000103oool200000080oooo0P000008
0?ooo`800000103oool200000080oooo100000020?ooo`800000103oool:00000080oooo10000004
0?ooo`<00000103oool2000000H0oooo100000020?ooo`8000000P3oool400000080oooo0P000002
0?ooo`@000000P3oool8000000@0oooo100000040?ooo`@000000P3oool800000080oooo0P000002
0?ooo`H000000P3oool4000000@0oooo100000040?ooo`H00000103oool4000000H0oooo0P000002
0?ooo`8000001`3oool2000000@0oooo0P00000:0?ooo`8000000P3oool2000000P0oooo20000004
0?ooo`H000000P3oool2000000H0oooo1000000?0=7=Z@003@3AcJT200000080oooo100000020?oo
o`X00000103oool200000080oooo0P0000060?ooo`8000000P3oool200000080oooo0P0000020?oo
o`800000303oool2000000<0oooo0P0000020?ooo`800000203oool8000000@0oooo1P0000040?oo
o`@00000103oool200000080oooo0P0000020?ooo`h000000P3oool200000080oooo100000020?oo
o`8000000P3oool800000080oooo100000020?ooo`8000001P3oool6000000@0oooo0P0000060?oo
o`8000000P3oool4000000L0oooo200000060?ooo`@000001P3oool4000000H0oooo0P0000040?oo
o`H00000203oool200000080oooo0P0000040?ooo`8000000P3oool200000080oooo0P0000040?oo
o`@00000203oool200000080oooo100000040?ooo`H000002P3oool400000080oooo1`0000020?oo
o`@000000P3oool:00000080oooo0P0000020?ooo`P00000103oool200000080oooo100000040?oo
o`@000000P3oool600000080oooo3`3AcJT000d0dLfY0P0000020?ooo`@000000P3oool:000000@0
oooo0P0000020?ooo`8000001P3oool200000080oooo0P0000020?ooo`8000000P3oool2000000`0
oooo0P0000030?ooo`8000000P3oool2000000P0oooo200000040?ooo`H00000103oool4000000@0
oooo0P0000020?ooo`8000000P3oool>00000080oooo0P0000020?ooo`@000000P3oool200000080
oooo200000020?ooo`@000000P3oool2000000H0oooo1P0000040?ooo`8000001P3oool200000080
oooo100000070?ooo`P000001P3oool4000000H0oooo100000060?ooo`800000103oool6000000P0
oooo0P0000020?ooo`800000103oool200000080oooo0P0000020?ooo`800000103oool4000000P0
oooo0P0000020?ooo`@00000103oool6000000X0oooo100000020?ooo`L000000P3oool400000080
oooo2P0000020?ooo`8000000P3oool8000000@0oooo0P0000020?ooo`@00000103oool400000080
oooo1P0000020?ooo`l0dLfY000=0=7=Z@H0oooo0P0000020?ooo`800000103oool2000000P0oooo
100000020?ooo`H000000P3oool200000080oooo0P0000020?ooo`8000000P3oool<00000080oooo
0`0000020?ooo`8000000P3oool8000000@0oooo0P0000020?ooo`@00000103oool6000000P0oooo
100000020?ooo`800000103oool2000000@0oooo0P0000020?ooo`8000000P3oool2000000H0oooo
100000040?ooo`8000000P3oool2000000H0oooo200000040?ooo`H000000P3oool600000080oooo
0P00000;0?ooo`800000103oool8000000X0oooo0P0000020?ooo`H000000P3oool4000000@0oooo
2P0000020?ooo`8000000P3oool400000080oooo0P0000020?ooo`8000000P3oool4000000`0oooo
100000080?ooo`8000003P3oool200000080oooo0P0000030?ooo`8000000P3oool2000000H0oooo
0P0000040?ooo`8000000P3oool200000080oooo0P0000040?ooo`8000000P3oool400000080oooo
0P0000080?ooo`8000000P3oool2000000@0oooo0P00000?0=7=Z@003@3AcJT60?ooo`8000000P3o
ool2000000@0oooo0P0000080?ooo`@000000P3oool600000080oooo0P0000020?ooo`8000000P3o
ool200000080oooo300000020?ooo`<000000P3oool200000080oooo200000040?ooo`8000000P3o
ool4000000@0oooo1P0000080?ooo`@000000P3oool2000000@0oooo0P0000040?ooo`8000000P3o
ool200000080oooo0P0000060?ooo`@00000103oool200000080oooo0P0000060?ooo`P00000103o
ool600000080oooo1P0000020?ooo`8000002`3oool2000000@0oooo2000000:0?ooo`8000000P3o
ool600000080oooo100000040?ooo`X000000P3oool200000080oooo100000020?ooo`8000000P3o
ool200000080oooo1000000<0?ooo`@00000203oool2000000h0oooo0P0000020?ooo`8000000`3o
ool200000080oooo0P0000060?ooo`800000103oool200000080oooo0P0000020?ooo`800000103o
ool200000080oooo100000020?ooo`800000203oool200000080oooo0P0000040?ooo`8000003`3A
cJT000d0dLfY200000020?ooo`8000000P3oool400000080oooo200000060?ooo`8000001P3oool4
00000080oooo0P0000020?ooo`800000103oool2000000@0oooo0`0000060?ooo`@00000103oool2
00000080oooo100000020?ooo`800000203oool2000000`0oooo0P0000020?ooo`8000000P3oool4
00000080oooo100000020?ooo`8000000P3oool200000080oooo1P0000080?ooo`@000000P3oool6
000000@0oooo0P0000020?ooo`@00000103oool4000000@0oooo100000020?ooo`/000000P3oool4
000000@0oooo0P0000020?ooo`X000000P3oool2000000@0oooo100000080?ooo`800000103oool2
00000080oooo0P0000020?ooo`8000001P3oool400000080oooo0P00000@0?ooo`8000000P3oool8
00000080oooo3P0000020?ooo`80000000<0oooo0000000000000P0000020?ooo`8000000P3oool6
00000080oooo100000020?ooo`8000000P3oool200000080oooo100000020?ooo`8000001P3oool:
00000080oooo0P0000020?ooo`@000003`3AcJT000d0dLfY200000020?ooo`8000000P3oool40000
0080oooo200000060?ooo`8000001P3oool400000080oooo0P0000020?ooo`800000103oool20000
00@0oooo0`0000060?ooo`@00000103oool200000080oooo100000020?ooo`800000203oool20000
00`0oooo0P0000020?ooo`8000000P3oool400000080oooo100000020?ooo`8000000P3oool20000
0080oooo1P0000080?ooo`@000000P3oool6000000@0oooo0P0000020?ooo`@00000103oool40000
00@0oooo100000020?ooo`/000000P3oool4000000@0oooo0P0000020?ooo`X000000P3oool20000
00@0oooo100000080?ooo`800000103oool200000080oooo0P0000020?ooo`8000001P3oool40000
0080oooo0P00000@0?ooo`8000000P3oool800000080oooo3P0000020?ooo`80000000<0oooo0000
000000000P0000020?ooo`8000000P3oool600000080oooo100000020?ooo`8000000P3oool20000
0080oooo100000020?ooo`8000001P3oool:00000080oooo0P0000020?ooo`@000003`3AcJT000d0
dLfY0P3oool2000000@0oooo100000020?ooo`8000001P3oool2000000@0oooo200000020?ooo`H0
00001P3oool400000080oooo100000020?ooo`@000002@3oool200000080oooo100000020?ooo`80
00001P3oool:00000080oooo300000020?ooo`8000000P3oool2000000H0oooo0P0000020?ooo`80
00000P3oool200000080oooo0P0000040?ooo`X000001P3oool2000000P0oooo100000080?ooo`80
00000P3oool4000000D0oooo0P0000040?ooo`8000001P3oool200000080oooo100000020?ooo`80
0000103oool2000000H0oooo1P00000<0?ooo`H000000P3oool200000080oooo0P0000020?ooo`H0
00001P3ooolB00000080oooo0P0000040?ooo`8000000P3oool2000000@0oooo0P0000040?ooo`80
00000P3oool2000000030?ooo`000000000000H0oooo100000040?ooo`@000001P3oool400000080
oooo0P0000060?ooo`P00000103oool2000000H0oooo100000020?ooo`l0dLfY000=0=7=Z@80oooo
0P0000040?ooo`@000000P3oool2000000H0oooo0P0000040?ooo`P000000P3oool6000000H0oooo
100000020?ooo`@000000P3oool4000000T0oooo0P0000020?ooo`@000000P3oool2000000H0oooo
2P0000020?ooo``000000P3oool200000080oooo0P0000060?ooo`8000000P3oool200000080oooo
0P0000020?ooo`800000103oool:000000H0oooo0P0000080?ooo`@00000203oool200000080oooo
100000050?ooo`800000103oool2000000H0oooo0P0000020?ooo`@000000P3oool2000000@0oooo
0P0000060?ooo`H00000303oool600000080oooo0P0000020?ooo`8000000P3oool6000000H0oooo
4P0000020?ooo`800000103oool200000080oooo0P0000040?ooo`800000103oool200000080oooo
0P0000000`3oool00000000000060?ooo`@00000103oool4000000H0oooo100000020?ooo`800000
1P3oool8000000@0oooo0P0000060?ooo`@000000P3oool?0=7=Z@003@3AcJT400000080oooo1000
00060?ooo`P000000P3oool4000000@0oooo0P0000020?ooo`800000103oool8000000H0oooo0P00
00020?ooo`8000003@3oool4000000H0oooo200000040?ooo`8000001P3oool2000000@0oooo0P00
00060?ooo`@000000P3oool600000080oooo0P0000020?ooo`8000000P3oool200000080oooo1000
00040?ooo`8000002P3oool:000000`0oooo100000090?ooo`H000000P3oool600000080oooo0P00
00060?ooo`H000000P3oool6000000@0oooo3P0000040?ooo`@000000P3oool200000080oooo0P00
00040?ooo`P00000103oool2000000@0oooo0P0000040?ooo`@000000P3oool400000080oooo0P00
00020?ooo`@000000P3oool400000080oooo0P0000000`3oool00000000000020?ooo`H00000203o
ool200000080oooo1P0000060?ooo`P00000103oool200000080oooo100000020?ooo`H00000103o
ool?0=7=Z@003@3AcJT400000080oooo100000060?ooo`P000000P3oool4000000@0oooo0P000002
0?ooo`800000103oool8000000H0oooo0P0000020?ooo`8000003@3oool4000000H0oooo20000004
0?ooo`8000001P3oool2000000@0oooo0P0000060?ooo`@000000P3oool600000080oooo0P000002
0?ooo`8000000P3oool200000080oooo100000040?ooo`8000002P3oool:000000`0oooo10000009
0?ooo`H000000P3oool600000080oooo0P0000060?ooo`H000000P3oool6000000@0oooo3P000004
0?ooo`@000000P3oool200000080oooo0P0000040?ooo`P00000103oool2000000@0oooo0P000004
0?ooo`@000000P3oool400000080oooo0P0000020?ooo`@000000P3oool400000080oooo0P000000
0`3oool00000000000020?ooo`H00000203oool200000080oooo1P0000060?ooo`P00000103oool2
00000080oooo100000020?ooo`H00000103oool?0=7=Z@003@3AcJT40?ooo`@000002P3oool20000
00@0oooo100000080?ooo`@000000P3oool4000000@0oooo0P0000020?ooo`H000000P3oool20000
0080oooo3@00000:0?ooo`800000103oool600000080oooo1P0000020?ooo`@000000P3oool60000
00H0oooo0P0000060?ooo`@000000P3oool200000080oooo0P0000080?ooo``00000103oool20000
0100oooo0P0000020?ooo`T00000103oool4000000@0oooo100000020?ooo`H00000103oool40000
00@0oooo1P0000040?ooo`800000103oool200000080oooo100000060?ooo`@000000P3oool40000
00@0oooo0P0000020?ooo`@000000P3oool400000080oooo100000060?ooo`8000000P3oool20000
0080oooo0P0000060?ooo`8000000P3oool2000000030?ooo`00000000000080oooo0P0000040?oo
o`X000000P3oool2000000@0oooo200000040?ooo`8000000P3oool400000080oooo0P0000060?oo
o`8000001P3oool?0=7=Z@003@3AcJT40?ooo`@000002P3oool2000000@0oooo100000080?ooo`@0
00000P3oool4000000@0oooo0P0000020?ooo`H000000P3oool200000080oooo3@00000:0?ooo`80
0000103oool600000080oooo1P0000020?ooo`@000000P3oool6000000H0oooo0P0000060?ooo`@0
00000P3oool200000080oooo0P0000080?ooo``00000103oool200000100oooo0P0000020?ooo`T0
0000103oool4000000@0oooo100000020?ooo`H00000103oool4000000@0oooo1P0000040?ooo`80
0000103oool200000080oooo100000060?ooo`@000000P3oool4000000@0oooo0P0000020?ooo`@0
00000P3oool400000080oooo100000060?ooo`8000000P3oool200000080oooo0P0000060?ooo`80
00000P3oool2000000030?ooo`00000000000080oooo0P0000040?ooo`X000000P3oool2000000@0
oooo200000040?ooo`8000000P3oool400000080oooo0P0000060?ooo`8000001P3oool?0=7=Z@00
3@3AcJT20?ooo`@000003P3oool6000000`0oooo0P0000020?ooo`800000203oool4000000@0oooo
100000020?ooo`030000003oool0oooo0080oooo0P0000040?ooo`8000000P3oool:00000080oooo
100000040?ooo`@00000103oool4000000H0oooo0P00000:0?ooo`P000001P3oool400000080oooo
200000040?ooo`800000103oool600000080oooo400000020?ooo`8000000`3oool2000000P0oooo
0P0000020?ooo`@000001P3oool2000000P0oooo0P0000020?ooo`@00000103oool600000080oooo
100000020?ooo`8000002P3oool200000080oooo0P0000080?ooo`@000001P3oool200000080oooo
0P00000:0?ooo`@000000P3oool200000080oooo1P0000020?ooo`80000000<0oooo000000000000
0P3oool200000080oooo100000040?ooo`8000001P3oool6000000@0oooo0P0000020?ooo`@00000
0P3oool2000000H0oooo200000020?ooo`@000003`3AcJT000d0dLfY0P3oool4000000h0oooo1P00
000<0?ooo`8000000P3oool2000000P0oooo100000040?ooo`@000000P3oool00`000000oooo0?oo
o`020?ooo`800000103oool200000080oooo2P0000020?ooo`@00000103oool4000000@0oooo1000
00060?ooo`8000002P3oool8000000H0oooo100000020?ooo`P00000103oool2000000@0oooo1P00
00020?oooa0000000P3oool2000000<0oooo0P0000080?ooo`8000000P3oool4000000H0oooo0P00
00080?ooo`8000000P3oool4000000@0oooo1P0000020?ooo`@000000P3oool2000000X0oooo0P00
00020?ooo`800000203oool4000000H0oooo0P0000020?ooo`8000002P3oool400000080oooo0P00
00020?ooo`H000000P3oool2000000030?ooo`00000000000080oooo0P0000020?ooo`@00000103o
ool2000000H0oooo1P0000040?ooo`8000000P3oool400000080oooo0P0000060?ooo`P000000P3o
ool4000000l0dLfY000=0=7=Z@80oooo0P00000B0?ooo`800000403oool400000080oooo20000008
0?ooo`8000000P3oool00`000000oooo0?ooo`0400000080oooo100000020?ooo`800000103oool2
000000H0oooo0P0000020?ooo`@00000203oool200000080oooo1P0000020?ooo`X00000103oool2
00000080oooo1P0000060?ooo`800000103oool600000080oooo100000040?ooo`@00000103oool2
000000@0oooo0P0000060?ooo`D000000P3oool800000080oooo0P00000:0?ooo`X000000P3oool2
000000P0oooo0P0000060?ooo`8000000P3oool200000080oooo2P0000020?ooo`8000000P3oool8
000000X0oooo100000020?ooo`X000001P3oool4000000@0oooo100000000`3oool0000000000002
0?ooo`8000000P3oool2000000P0oooo200000040?ooo`H000000P3oool2000000H0oooo20000004
0?ooo`8000000P3oool200000080oooo3`3AcJT000d0dLfY0P3oool200000180oooo0P00000@0?oo
o`@000000P3oool8000000P0oooo0P0000020?ooo`030000003oool0oooo00@000000P3oool40000
0080oooo0P0000040?ooo`8000001P3oool200000080oooo100000080?ooo`8000000P3oool60000
0080oooo2P0000040?ooo`8000000P3oool6000000H0oooo0P0000040?ooo`H000000P3oool40000
00@0oooo100000040?ooo`800000103oool2000000H0oooo1@0000020?ooo`P000000P3oool20000
00X0oooo2P0000020?ooo`800000203oool2000000H0oooo0P0000020?ooo`8000000P3oool:0000
0080oooo0P0000020?ooo`P000002P3oool400000080oooo2P0000060?ooo`@00000103oool40000
00030?ooo`00000000000080oooo0P0000020?ooo`800000203oool8000000@0oooo1P0000020?oo
o`8000001P3oool8000000@0oooo0P0000020?ooo`8000000P3oool?0=7=Z@003@3AcJT400000080
oooo4P0000020?oooa0000001P3oool2000000@0oooo2P0000020?ooo`030000003oool0oooo0080
00001P3oool200000080oooo0P0000020?ooo`@000000P3oool600000080oooo0P00000<0?ooo`@0
0000103oool4000000@0oooo0P0000080?ooo`@00000103oool800000080oooo100000040?ooo`@0
0000203oool200000080oooo100000020?ooo`@000000P3oool6000000<0oooo100000040?ooo`80
00000P3oool200000080oooo2P0000040?ooo`8000001P3oool:00000080oooo1P0000020?ooo`80
00000P3oool2000000@0oooo0P0000060?ooo`@00000103oool200000080oooo2P0000060?ooo`80
0000103oool200000080oooo1P0000080?ooo`80000000<0oooo0000000000000P3oool200000080
oooo0P0000020?ooo`P00000103oool200000080oooo100000040?ooo`@000000P3oool6000000@0
oooo0P0000020?ooo`@000000P3oool200000080oooo3`3AcJT000d0dLfY100000020?oooa800000
0P3oool@000000H0oooo0P0000040?ooo`X000000P3oool00`000000oooo0?ooo`02000000H0oooo
0P0000020?ooo`8000000P3oool400000080oooo1P0000020?ooo`800000303oool4000000@0oooo
100000040?ooo`800000203oool4000000@0oooo200000020?ooo`@00000103oool4000000P0oooo
0P0000020?ooo`@000000P3oool400000080oooo1P0000030?ooo`@00000103oool200000080oooo
0P0000020?ooo`X00000103oool2000000H0oooo2P0000020?ooo`H000000P3oool200000080oooo
0P0000040?ooo`8000001P3oool4000000@0oooo0P0000020?ooo`X000001P3oool2000000@0oooo
0P0000020?ooo`H00000203oool2000000030?ooo`00000000000080oooo0P0000020?ooo`800000
0P3oool8000000@0oooo0P0000020?ooo`@00000103oool400000080oooo1P0000040?ooo`800000
0P3oool400000080oooo0P0000020?ooo`l0dLfY000=0=7=Z@8000001P3oool2000000@0oooo0P00
00040?ooo`8000001P3oool2000000@0oooo0P0000040?ooo`8000000P3oool600000080oooo1000
00040?ooo`8000001@3oool400000080oooo1P0000020?ooo`8000000P3oool2000000H0oooo0P00
00060?ooo`h00000203oool200000080oooo100000020?ooo`P00000203oool2000000@0oooo1000
00080?ooo`8000000P3oool800000080oooo0P0000060?ooo`8000000P3oool2000000@0oooo1@00
00080?ooo`@000000P3oool2000000@0oooo0P0000080?ooo`P00000103oool2000000H0oooo0P00
00060?ooo`@000000P3oool400000080oooo1P0000080?ooo`@00000103oool2000000X0oooo1P00
00020?ooo`800000103oool:000000030?ooo`00000000000080oooo0P0000020?ooo`8000000P3o
ool2000000@0oooo0P0000020?ooo`@000000P3oool2000000P0oooo0P0000020?ooo`800000103o
ool600000080oooo0P0000060?ooo`8000003`3AcJT000d0dLfY0P0000060?ooo`800000103oool2
000000@0oooo0P0000060?ooo`800000103oool2000000@0oooo0P0000020?ooo`H000000P3oool4
000000@0oooo0P0000050?ooo`@000000P3oool600000080oooo0P0000020?ooo`8000001P3oool2
000000H0oooo3P0000080?ooo`8000000P3oool400000080oooo200000080?ooo`800000103oool4
000000P0oooo0P0000020?ooo`P000000P3oool2000000H0oooo0P0000020?ooo`800000103oool5
000000P0oooo100000020?ooo`800000103oool2000000P0oooo200000040?ooo`8000001P3oool2
000000H0oooo100000020?ooo`@000000P3oool6000000P0oooo100000040?ooo`8000002P3oool6
00000080oooo0P0000040?ooo`X0000000<0oooo0000000000000P3oool200000080oooo0P000002
0?ooo`800000103oool200000080oooo100000020?ooo`800000203oool200000080oooo0P000004
0?ooo`H000000P3oool2000000H0oooo0P00000?0=7=Z@003@3AcJT200000080oooo1P0000020?oo
o`@000000P3oool400000080oooo1P0000020?ooo`@000000P3oool400000080oooo0P0000040?oo
o`@00000203oool7000000H0oooo0P0000060?ooo`@000000P3oool600000080oooo1P0000040?oo
o`800000103oool200000080oooo200000020?ooo`8000001P3oool2000000@0oooo2P0000020?oo
o`@00000303oool4000000@0oooo0P0000020?ooo`8000000P3oool600000080oooo0P0000020?oo
o`<00000103oool:000000H0oooo1P0000020?ooo`P00000103oool200000080oooo100000020?oo
o`H000000P3oool6000000H0oooo0P0000020?ooo`800000103oool:000000P0oooo300000040?oo
o`@000000P3oool4000000@0oooo0P0000050?ooo`@000000P3oool200000080oooo0P0000020?oo
o`@000000P3oool2000000H0oooo2P0000020?ooo`8000000P3oool4000000@0oooo100000020?oo
o`H000003`3AcJT000d0dLfY0P0000020?ooo`H000000P3oool400000080oooo100000020?ooo`H0
00000P3oool400000080oooo100000020?ooo`800000103oool4000000P0oooo1`0000060?ooo`80
00001P3oool400000080oooo1P0000020?ooo`H00000103oool2000000@0oooo0P0000020?ooo`P0
00000P3oool2000000H0oooo0P0000040?ooo`X000000P3oool4000000`0oooo100000040?ooo`80
00000P3oool200000080oooo1P0000020?ooo`8000000P3oool3000000@0oooo2P0000060?ooo`H0
00000P3oool8000000@0oooo0P0000020?ooo`@000000P3oool600000080oooo1P0000060?ooo`80
00000P3oool2000000@0oooo2P0000080?ooo``00000103oool400000080oooo100000040?ooo`80
00001@3oool400000080oooo0P0000020?ooo`8000000P3oool400000080oooo0P0000060?ooo`X0
00000P3oool200000080oooo100000040?ooo`@000000P3oool6000000l0dLfY000=0=7=Z@800000
0P3oool2000000@0oooo100000060?ooo`8000000P3oool2000000@0oooo100000060?ooo`800000
0P3oool200000080oooo1000000<0?ooo`8000000`3oool800000080oooo1P0000060?ooo`800000
1P3oool2000000P0oooo1P0000020?ooo`800000103oool200000080oooo0P0000020?ooo`H00000
0P3oool4000000@0oooo0P0000060?ooo`8000000P3oool<000000P0oooo100000020?ooo`800000
103oool400000080oooo0P0000070?ooo`800000103oool200000080oooo1P0000040?ooo`@00000
103oool200000080oooo100000020?ooo`8000001P3oool2000000H0oooo0P00000:0?ooo`@00000
0P3oool4000000@0oooo0P00000<0?ooo`800000103oool2000000P0oooo0P0000020?ooo`800000
203oool7000000H0oooo100000020?ooo`8000001P3oool8000000@0oooo0P0000060?ooo`@00000
203oool200000080oooo0P0000040?ooo`l0dLfY000=0=7=Z@8000000P3oool2000000@0oooo1000
00060?ooo`8000000P3oool2000000@0oooo100000060?ooo`8000000P3oool200000080oooo1000
000<0?ooo`8000000`3oool800000080oooo1P0000060?ooo`8000001P3oool2000000P0oooo1P00
00020?ooo`800000103oool200000080oooo0P0000020?ooo`H000000P3oool4000000@0oooo0P00
00060?ooo`8000000P3oool<000000P0oooo100000020?ooo`800000103oool400000080oooo0P00
00070?ooo`800000103oool200000080oooo1P0000040?ooo`@00000103oool200000080oooo1000
00020?ooo`8000001P3oool2000000H0oooo0P00000:0?ooo`@000000P3oool4000000@0oooo0P00
000<0?ooo`800000103oool2000000P0oooo0P0000020?ooo`800000203oool7000000H0oooo1000
00020?ooo`8000001P3oool8000000@0oooo0P0000060?ooo`@00000203oool200000080oooo0P00
00040?ooo`l0dLfY000=0=7=Z@80oooo100000020?ooo`@000002P3oool400000080oooo1000000:
0?ooo`@000000P3oool200000100oooo1@0000040?ooo`8000000P3oool2000000@0oooo20000002
0?ooo`H000000P3oool8000000@0oooo100000020?ooo`@000000P3oool200000080oooo0P000004
0?ooo`@00000203oool800000080oooo0P0000040?ooo`800000103oool:000000H0oooo1P000006
0?ooo`T000000P3oool400000080oooo0P0000040?ooo`H00000203oool4000000H0oooo20000002
0?ooo`H000000P3oool:000000H0oooo0P0000020?ooo`@000000P3oool<00000080oooo10000002
0?ooo`P000000P3oool200000080oooo200000030?ooo`8000000P3oool6000000H0oooo20000004
0?ooo`8000000P3oool400000080oooo1P00000<0?ooo`@000000P3oool2000000l0dLfY000=0=7=
Z@80oooo100000020?ooo`@000002P3oool400000080oooo1000000:0?ooo`@000000P3oool20000
0100oooo1@0000040?ooo`8000000P3oool2000000@0oooo200000020?ooo`H000000P3oool80000
00@0oooo100000020?ooo`@000000P3oool200000080oooo0P0000040?ooo`@00000203oool80000
0080oooo0P0000040?ooo`800000103oool:000000H0oooo1P0000060?ooo`T000000P3oool40000
0080oooo0P0000040?ooo`H00000203oool4000000H0oooo200000020?ooo`H000000P3oool:0000
00H0oooo0P0000020?ooo`@000000P3oool<00000080oooo100000020?ooo`P000000P3oool20000
0080oooo200000030?ooo`8000000P3oool6000000H0oooo200000040?ooo`8000000P3oool40000
0080oooo1P00000<0?ooo`@000000P3oool2000000l0dLfY000=0=7=Z@@0oooo0P0000020?ooo`80
00003P3oool200000080oooo0P00000>0?ooo`8000000P3oool200000080oooo3`0000040?ooo`H0
00000P3oool200000080oooo100000040?ooo`8000000P3oool2000000@0oooo100000040?ooo`80
00000P3oool4000000H0oooo0P0000020?ooo`8000000P3oool200000080oooo1000000<0?ooo`80
0000103oool400000080oooo100000020?ooo`@00000103oool2000000X0oooo0P0000090?ooo`80
0000103oool200000080oooo0P0000060?ooo`H00000103oool:000000X0oooo0P0000040?ooo`@0
0000103oool4000000@0oooo0P00000:0?ooo`@000001P3oool2000000@0oooo0P0000060?ooo`80
00000P3oool2000000@0oooo0P0000020?ooo`8000000P3oool2000000@0oooo0P0000000`3oool0
00000000000200000080oooo0P0000040?ooo`P00000103oool200000080oooo100000020?ooo`80
00001P3oool200000100oooo0P0000020?ooo`8000003`3AcJT000d0dLfY103oool200000080oooo
0P00000>0?ooo`8000000P3oool2000000h0oooo0P0000020?ooo`8000000P3oool?000000@0oooo
1P0000020?ooo`8000000P3oool4000000@0oooo0P0000020?ooo`800000103oool4000000@0oooo
0P0000020?ooo`@000001P3oool200000080oooo0P0000020?ooo`8000000P3oool4000000`0oooo
0P0000040?ooo`@000000P3oool400000080oooo100000040?ooo`8000002P3oool2000000T0oooo
0P0000040?ooo`8000000P3oool2000000H0oooo1P0000040?ooo`X000002P3oool2000000@0oooo
100000040?ooo`@00000103oool2000000X0oooo100000060?ooo`800000103oool2000000H0oooo
0P0000020?ooo`800000103oool200000080oooo0P0000020?ooo`800000103oool2000000030?oo
o`0000000000008000000P3oool2000000@0oooo200000040?ooo`8000000P3oool400000080oooo
0P0000060?ooo`800000403oool200000080oooo0P00000?0=7=Z@003@3AcJT600000080oooo0P00
00020?ooo`h000000P3oool200000080oooo3P0000020?ooo`8000000P3oool2000000@0oooo0P00
00040?ooo`8000001`3oool2000000H0oooo100000080?ooo`@000000P3oool4000000P0oooo1000
000:0?ooo`@000000P3oool200000080oooo0P00000@0?ooo`H000001P3oool200000080oooo0P00
00080?ooo``000000P3oool900000080oooo100000020?ooo`8000000P3oool6000000@0oooo1P00
00040?ooo`8000003P3oool6000000P0oooo0P0000020?ooo`@000000P3oool:000000X0oooo1P00
00020?ooo`H000000P3oool200000080oooo100000020?ooo`8000000P3oool200000080oooo1000
00000`3oool00000000000060?ooo`H00000103oool200000080oooo100000020?ooo`8000001P3o
ool800000080oooo400000020?ooo`8000003`3AcJT000d0dLfY1P0000020?ooo`8000000P3oool>
00000080oooo0P0000020?ooo`h000000P3oool200000080oooo0P0000040?ooo`800000103oool2
000000L0oooo0P0000060?ooo`@00000203oool400000080oooo100000080?ooo`@000002P3oool4
00000080oooo0P0000020?ooo`800000403oool6000000H0oooo0P0000020?ooo`800000203oool<
00000080oooo2@0000020?ooo`@000000P3oool200000080oooo1P0000040?ooo`H00000103oool2
000000h0oooo1P0000080?ooo`8000000P3oool400000080oooo2P00000:0?ooo`H000000P3oool6
00000080oooo0P0000020?ooo`@000000P3oool200000080oooo0P0000020?ooo`@0000000<0oooo
0000000000001P3oool6000000@0oooo0P0000020?ooo`@000000P3oool2000000H0oooo20000002
0?oooa0000000P3oool2000000l0dLfY000=0=7=Z@80oooo0P0000060?ooo`@00000103oool20000
00@0oooo0P0000020?ooo`8000000P3oool2000000@0oooo0P0000040?ooo`8000000P3oool20000
0080oooo0P0000020?ooo`@000000P3oool4000000030?ooo`000000000000H000000P3oool60000
00`0oooo0P0000020?ooo`800000303oool200000080oooo2P0000060?ooo`@000000P3oool@0000
00@0oooo200000020?ooo`8000000P3oool8000000@0oooo0P0000040?ooo`@00000103oool00`00
0000oooo0?ooo`040?ooo`8000000P3oool200000080oooo0P0000040?ooo`H00000103oool60000
0080oooo3P0000040?ooo`X000000P3oool2000000H0oooo0P0000040?ooo`8000000P3oool:0000
00@0oooo100000040?ooo`@000000P3oool2000000H0oooo100000020?ooo`8000001@3oool80000
00@0oooo1P0000020?ooo`8000001P3oool8000000@0oooo0P0000020?ooo`800000103oool20000
00@0oooo0P0000060?ooo`l0dLfY000=0=7=Z@80oooo0P0000060?ooo`@00000103oool2000000@0
oooo0P0000020?ooo`8000000P3oool2000000@0oooo0P0000040?ooo`8000000P3oool200000080
oooo0P0000020?ooo`@000000P3oool4000000030?ooo`000000000000H000000P3oool6000000`0
oooo0P0000020?ooo`800000303oool200000080oooo2P0000060?ooo`@000000P3oool@000000@0
oooo200000020?ooo`8000000P3oool8000000@0oooo0P0000040?ooo`@00000103oool00`000000
oooo0?ooo`040?ooo`8000000P3oool200000080oooo0P0000040?ooo`H00000103oool600000080
oooo3P0000040?ooo`X000000P3oool2000000H0oooo0P0000040?ooo`8000000P3oool:000000@0
oooo100000040?ooo`@000000P3oool2000000H0oooo100000020?ooo`8000001@3oool8000000@0
oooo1P0000020?ooo`8000001P3oool8000000@0oooo0P0000020?ooo`800000103oool2000000@0
oooo0P0000060?ooo`l0dLfY000=0=7=Z@@0oooo200000080?ooo`H000000P3oool200000080oooo
0P0000020?ooo`@000000P3oool400000080oooo0P0000020?ooo`8000000P3oool2000000H0oooo
0P0000000`3oool00000000000040?ooo`8000000P3oool2000000@0oooo3P0000020?ooo`800000
0P3oool<00000080oooo0P0000040?ooo`8000002P3oool200000080oooo0P0000040?ooo`800000
103oool2000000P0oooo0P0000040?ooo`@000000P3oool2000000@0oooo0P0000020?ooo`@00000
0P3oool4000000L0oooo200000020?ooo`8000000P3oool200000080oooo100000040?ooo`H00000
103oool4000000@0oooo0P0000040?ooo`8000000P3oool4000000@0oooo0P0000060?ooo`P00000
0P3oool400000080oooo0P0000040?ooo`800000203oool200000080oooo100000060?ooo`P00000
1P3oool7000000@0oooo0P0000020?ooo`@00000103oool400000080oooo1P0000040?ooo`800000
0P3oool400000080oooo0P0000020?ooo`@000000P3oool400000080oooo1000000?0=7=Z@003@3A
cJT40?ooo`P00000203oool600000080oooo0P0000020?ooo`8000000P3oool400000080oooo1000
00020?ooo`8000000P3oool200000080oooo0P0000060?ooo`80000000<0oooo000000000000103o
ool200000080oooo0P0000040?ooo`h000000P3oool200000080oooo300000020?ooo`800000103o
ool2000000X0oooo0P0000020?ooo`800000103oool2000000@0oooo0P0000080?ooo`800000103o
ool400000080oooo0P0000040?ooo`8000000P3oool400000080oooo100000070?ooo`P000000P3o
ool200000080oooo0P0000020?ooo`@00000103oool6000000@0oooo100000040?ooo`800000103o
ool200000080oooo100000040?ooo`8000001P3oool800000080oooo100000020?ooo`800000103o
ool2000000P0oooo0P0000020?ooo`@000001P3oool8000000H0oooo1`0000040?ooo`8000000P3o
ool4000000@0oooo100000020?ooo`H00000103oool200000080oooo100000020?ooo`8000000P3o
ool400000080oooo100000020?ooo`@000003`3AcJT000d0dLfY1P0000040?ooo`8000000P3oool8
000000@0oooo100000020?ooo`8000000P3oool2000000H0oooo0P0000020?ooo`8000000P3oool2
00000080oooo0P0000020?ooo`H0000000<0oooo0000000000000P3oool400000080oooo0P000002
0?ooo`@00000103oool2000000@0oooo0P0000020?ooo`8000000P3oool2000000@0oooo0P000004
0?ooo`@000000P3oool400000080oooo2P0000020?ooo`8000000P3oool400000080oooo10000002
0?ooo`P000000P3oool4000000H0oooo1P0000020?ooo`8000001P3oool200000080oooo1`000004
0?ooo`8000000P3oool200000080oooo0P0000020?ooo`800000203oool2000000P0oooo0P000002
0?ooo`@000000P3oool400000080oooo0P0000080?ooo`P00000103oool200000080oooo0P000006
0?ooo`H000000P3oool800000080oooo0P00000:0?ooo`800000103oool8000000<0oooo0P000002
0?ooo`@000000P3oool2000000P0oooo0P0000020?ooo`800000103oool600000080oooo0P000006
0?ooo`@000001P3oool200000080oooo0P0000020?ooo`l0dLfY000=0=7=Z@H00000103oool20000
0080oooo200000040?ooo`@000000P3oool200000080oooo0P0000060?ooo`8000000P3oool20000
0080oooo0P0000020?ooo`8000000P3oool6000000030?ooo`00000000000080oooo100000020?oo
o`8000000P3oool4000000@0oooo0P0000040?ooo`8000000P3oool200000080oooo0P0000040?oo
o`800000103oool400000080oooo100000020?ooo`X000000P3oool200000080oooo100000020?oo
o`@000000P3oool800000080oooo100000060?ooo`H000000P3oool2000000H0oooo0P0000020?oo
o`L00000103oool200000080oooo0P0000020?ooo`8000000P3oool2000000P0oooo0P0000080?oo
o`8000000P3oool400000080oooo100000020?ooo`800000203oool8000000@0oooo0P0000020?oo
o`8000001P3oool600000080oooo200000020?ooo`8000002P3oool2000000@0oooo200000030?oo
o`8000000P3oool400000080oooo0P0000080?ooo`8000000P3oool2000000@0oooo1P0000020?oo
o`8000001P3oool4000000H0oooo0P0000020?ooo`8000000P3oool?0=7=Z@003@3AcJT40?ooo`80
00000P3oool400000080oooo0P0000040?ooo`8000000P3oool4000000H0oooo100000020?ooo`H0
00000P3oool200000080oooo0P0000020?ooo`8000000P3oool2000000@0oooo0`0000020?ooo`80
00001P3oool4000000P0oooo1P0000020?ooo`8000000P3oool200000080oooo100000020?ooo`@0
00001P3oool200000080oooo0P0000040?ooo`8000001P3oool4000000H0oooo0P0000020?ooo`80
0000103oool200000080oooo0P00000:0?ooo`8000001P3oool800000080oooo0P0000030?ooo`80
00000P3oool400000080oooo0P0000020?ooo`8000000P3oool200000080oooo200000020?ooo`P0
00000P3oool2000000H0oooo0P0000020?ooo`8000000P3oool8000000@0oooo0P0000020?ooo`@0
00000P3oool200000080oooo1P0000040?ooo`@00000103oool200000080oooo0P0000020?ooo`X0
00000P3oool4000000@0oooo0P0000000`3oool000000000000200000080oooo0P0000060?ooo`X0
00000P3oool200000080oooo100000040?ooo`@000000P3oool6000000X0oooo100000020?ooo`l0
dLfY000=0=7=Z@@0oooo0P0000020?ooo`@000000P3oool2000000@0oooo0P0000020?ooo`@00000
1P3oool400000080oooo1P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`800000
103oool300000080oooo0P0000060?ooo`@00000203oool600000080oooo0P0000020?ooo`800000
0P3oool400000080oooo100000060?ooo`8000000P3oool2000000@0oooo0P0000060?ooo`@00000
1P3oool200000080oooo0P0000040?ooo`8000000P3oool2000000X0oooo0P0000060?ooo`P00000
0P3oool2000000<0oooo0P0000020?ooo`@000000P3oool200000080oooo0P0000020?ooo`800000
0P3oool800000080oooo200000020?ooo`8000001P3oool200000080oooo0P0000020?ooo`P00000
103oool200000080oooo100000020?ooo`8000000P3oool6000000@0oooo100000040?ooo`800000
0P3oool200000080oooo2P0000020?ooo`@00000103oool2000000030?ooo`000000000000800000
0P3oool2000000H0oooo2P0000020?ooo`8000000P3oool4000000@0oooo100000020?ooo`H00000
2P3oool400000080oooo3`3AcJT000d0dLfY1P3oool4000000H0oooo1P0000020?ooo`8000002P3o
ool200000080oooo0P0000040?ooo`@000000P3oool200000080oooo0P0000020?ooo`8000000P3o
ool3000000H0oooo2000000<0?ooo`8000001P3oool400000080oooo0P0000060?ooo`8000000P3o
ool600000080oooo0P0000020?ooo`@000000P3oool6000000X0oooo100000020?ooo`@000000P3o
ool200000080oooo2P0000020?ooo`H00000103oool200000080oooo0P0000020?ooo`<000000P3o
ool2000000H0oooo100000020?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`800000103o
ool200000080oooo0P0000020?ooo`H000000P3oool200000080oooo0P0000040?ooo`8000000P3o
ool400000080oooo0P0000060?ooo`@00000103oool6000000P0oooo100000020?ooo`800000103o
ool2000000H0oooo0P0000020?ooo`@0000000<0oooo0000000000001P3oool8000000@0oooo0P00
00060?ooo`@00000203oool200000080oooo0P0000040?ooo``00000103oool?0=7=Z@003@3AcJT6
0?ooo`@000001P3oool600000080oooo0P00000:0?ooo`8000000P3oool2000000@0oooo10000002
0?ooo`8000000P3oool200000080oooo0P0000020?ooo`<000001P3oool8000000`0oooo0P000006
0?ooo`@000000P3oool2000000H0oooo0P0000020?ooo`H000000P3oool200000080oooo10000002
0?ooo`H000002P3oool400000080oooo100000020?ooo`8000000P3oool:00000080oooo1P000004
0?ooo`8000000P3oool200000080oooo0`0000020?ooo`8000001P3oool400000080oooo0P000002
0?ooo`800000103oool200000080oooo0P0000040?ooo`8000000P3oool200000080oooo1P000002
0?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`@000000P3oool2000000H0oooo10000004
0?ooo`H00000203oool400000080oooo0P0000040?ooo`8000001P3oool200000080oooo10000000
0`3oool00000000000060?ooo`P00000103oool2000000H0oooo100000080?ooo`8000000P3oool2
000000@0oooo300000040?ooo`l0dLfY000=0=7=Z@P0oooo0P0000020?ooo`H00000103oool40000
0080oooo2P0000020?ooo`8000000P3oool4000000H0oooo100000020?ooo`8000000P3oool20000
00T0oooo0P0000040?ooo`h000000P3oool6000000H0oooo200000020?ooo`800000103oool40000
0080oooo0P0000060?ooo`8000003P3oool200000080oooo0P0000060?ooo`@00000103oool20000
00H0oooo0P0000080?ooo`@000000P3oool00`000000oooo0?ooo`040?ooo`P000001P3oool40000
0080oooo100000020?ooo`8000000P3oool400000080oooo0P0000020?ooo`800000103oool40000
0080oooo0P0000020?ooo`@000000P3oool2000000H0oooo200000080?ooo`800000303oool20000
0080oooo0P0000020?ooo`@000000P3oool600000080oooo0P0000050?ooo`P00000103oool20000
0080oooo100000020?ooo`H00000303oool400000080oooo100000040?ooo`800000103oool40000
00l0dLfY000=0=7=Z@P0oooo0P0000020?ooo`H00000103oool400000080oooo2P0000020?ooo`80
00000P3oool4000000H0oooo100000020?ooo`8000000P3oool2000000T0oooo0P0000040?ooo`h0
00000P3oool6000000H0oooo200000020?ooo`800000103oool400000080oooo0P0000060?ooo`80
00003P3oool200000080oooo0P0000060?ooo`@00000103oool2000000H0oooo0P0000080?ooo`@0
00000P3oool00`000000oooo0?ooo`040?ooo`P000001P3oool400000080oooo100000020?ooo`80
00000P3oool400000080oooo0P0000020?ooo`800000103oool400000080oooo0P0000020?ooo`@0
00000P3oool2000000H0oooo200000080?ooo`800000303oool200000080oooo0P0000020?ooo`@0
00000P3oool600000080oooo0P0000050?ooo`P00000103oool200000080oooo100000020?ooo`H0
0000303oool400000080oooo100000040?ooo`800000103oool4000000l0dLfY000=0=7=Z@X00000
0P3oool2000000@0oooo1P0000060?ooo`800000103oool200000080oooo0P0000020?ooo`800000
2P3oool200000080oooo0P0000020?ooo`80000000<0oooo000000000000200000020?ooo`@00000
103oool2000000@0oooo0P0000020?ooo`800000103oool8000000@0oooo0P0000020?ooo`800000
0P3oool4000000H0oooo200000020?ooo`h000000P3oool200000080oooo1P0000080?ooo`P00000
0P3oool8000000D0oooo200000040?ooo`8000000P3oool6000000H0oooo0P0000020?ooo`800000
0P3oool2000000H0oooo100000020?ooo`@000001P3oool4000000H0oooo200000040?ooo`800000
0P3oool800000080oooo300000020?ooo`8000000P3oool2000000H0oooo0P0000060?ooo`L00000
103oool200000080oooo100000020?ooo`8000001P3oool200000100oooo0P0000020?ooo`800000
203oool600000080oooo3`3AcJT000d0dLfY2P0000020?ooo`800000103oool6000000H0oooo0P00
00040?ooo`8000000P3oool200000080oooo0P00000:0?ooo`8000000P3oool200000080oooo0P00
00000`3oool000000000000800000080oooo100000040?ooo`800000103oool200000080oooo0P00
00040?ooo`P00000103oool200000080oooo0P0000020?ooo`@000001P3oool800000080oooo3P00
00020?ooo`8000000P3oool6000000P0oooo200000020?ooo`P000001@3oool8000000@0oooo0P00
00020?ooo`H000001P3oool200000080oooo0P0000020?ooo`8000001P3oool400000080oooo1000
00060?ooo`@000001P3oool8000000@0oooo0P0000020?ooo`P000000P3oool<00000080oooo0P00
00020?ooo`8000001P3oool2000000H0oooo1`0000040?ooo`8000000P3oool400000080oooo0P00
00060?ooo`800000403oool200000080oooo0P0000080?ooo`H000000P3oool?0=7=Z@003@3AcJT4
0?ooo`800000103oool400000080oooo100000040?ooo`P000000P3oool400000080oooo0P000002
0?ooo`8000000P3oool:00000080oooo0P0000020?ooo`80000000<0oooo000000000000103oool2
000000H0oooo0P0000020?ooo`@000000P3oool400000080oooo0P0000020?ooo`@00000103oool2
00000080oooo100000020?ooo`8000000P3oool2000000X0oooo0P0000040?ooo`@00000103oool2
000000@0oooo0P0000020?ooo`8000000P3oool2000000@0oooo2P0000040?ooo`8000000P3oool2
000000@0oooo0P0000020?ooo`D00000103oool200000080oooo100000020?ooo`800000103oool8
00000080oooo0P0000020?ooo`8000000P3oool6000000H0oooo0P0000020?ooo`H000002P3oool2
000000@0oooo1P0000020?ooo`800000103oool200000080oooo0P0000040?ooo`800000103oool4
00000080oooo0P0000020?ooo`H000000P3oool6000000<0oooo0P0000020?ooo`@000000P3oool2
000000H0oooo200000020?oooa0000000P3oool200000080oooo200000040?ooo`8000003`3AcJT0
00d0dLfY103oool2000000@0oooo100000020?ooo`@00000103oool800000080oooo100000020?oo
o`8000000P3oool200000080oooo2P0000020?ooo`8000000P3oool2000000030?ooo`0000000000
00@0oooo0P0000060?ooo`8000000P3oool400000080oooo100000020?ooo`8000000P3oool40000
00@0oooo0P0000020?ooo`@000000P3oool200000080oooo0P00000:0?ooo`800000103oool40000
00@0oooo0P0000040?ooo`8000000P3oool200000080oooo0P0000040?ooo`X00000103oool20000
0080oooo0P0000040?ooo`8000000P3oool5000000@0oooo0P0000020?ooo`@000000P3oool20000
00@0oooo200000020?ooo`8000000P3oool200000080oooo1P0000060?ooo`8000000P3oool60000
00X0oooo0P0000040?ooo`H000000P3oool2000000@0oooo0P0000020?ooo`800000103oool20000
00@0oooo100000020?ooo`8000000P3oool600000080oooo1P0000030?ooo`8000000P3oool40000
0080oooo0P0000060?ooo`P000000P3oool@00000080oooo0P0000020?ooo`P00000103oool20000
00l0dLfY000=0=7=Z@80oooo100000020?ooo`@000001P3oool200000080oooo100000040?ooo`80
00000P3oool2000000H0oooo100000020?ooo`800000103oool2000000H0oooo100000000`3oool0
0000000000020?ooo`@000000P3oool600000080oooo0P0000060?ooo`8000000P3oool200000080
oooo0P0000080?ooo`@000001P3oool400000080oooo2P0000020?ooo`@00000203oool600000080
oooo0P0000020?ooo`8000000P3oool4000000@0oooo0P0000080?ooo`@000000P3oool400000080
oooo0P0000030?ooo`H000000P3oool2000000H0oooo1P0000040?ooo`8000000P3oool200000080
oooo0P0000020?ooo`800000103oool800000080oooo0P0000040?ooo``000000P3oool4000000@0
oooo100000020?ooo`@000000P3oool200000080oooo100000020?ooo`@000001P3oool4000000@0
oooo100000040?ooo`D000000P3oool2000000H0oooo200000040?ooo`8000000P3oool2000000@0
oooo0P0000040?ooo`8000001P3oool4000000@0oooo0P0000020?ooo`@000003`3AcJT000d0dLfY
0P3oool400000080oooo100000060?ooo`8000000P3oool4000000@0oooo0P0000020?ooo`800000
1P3oool400000080oooo0P0000040?ooo`8000001P3oool4000000030?ooo`00000000000080oooo
100000020?ooo`H000000P3oool2000000H0oooo0P0000020?ooo`8000000P3oool2000000P0oooo
100000060?ooo`@000000P3oool:00000080oooo100000080?ooo`H000000P3oool200000080oooo
0P0000020?ooo`@00000103oool2000000P0oooo100000020?ooo`@000000P3oool2000000<0oooo
1P0000020?ooo`8000001P3oool6000000@0oooo0P0000020?ooo`8000000P3oool200000080oooo
0P0000040?ooo`P000000P3oool2000000@0oooo300000020?ooo`@00000103oool400000080oooo
100000020?ooo`8000000P3oool400000080oooo100000060?ooo`@00000103oool4000000@0oooo
1@0000020?ooo`8000001P3oool8000000@0oooo0P0000020?ooo`800000103oool2000000@0oooo
0P0000060?ooo`@00000103oool200000080oooo1000000?0=7=Z@003@3AcJT4000000H0oooo0P00
00020?ooo`H000000P3oool2000000P0oooo100000020?ooo`H000001P3oool600000080oooo1P00
00050?ooo`@000001P3oool2000000H0oooo200000020?ooo`8000000P3oool200000080oooo2000
000:0?ooo`8000000P3oool2000000@0oooo0P0000060?ooo`8000000P3oool8000000@0oooo1000
00020?ooo`8000000P3oool2000000P0oooo2P0000060?ooo`8000000P3oool2000000030?ooo`00
0000000000800000103oool400000080oooo1P0000040?ooo`H000000P3oool200000080oooo0P00
00020?ooo`8000000P3oool4000000@0oooo0P0000020?ooo`8000000P3oool4000000@0oooo0P00
00040?ooo`@00000203oool200000080oooo0P0000060?ooo`@000001P3oool200000080oooo1P00
00080?ooo`8000000P3oool3000000@0oooo100000020?ooo`H00000103oool200000080oooo1000
00020?ooo`8000000P3oool400000080oooo100000020?ooo`H00000203oool400000080oooo3`3A
cJT000d0dLfY100000060?ooo`8000000P3oool600000080oooo0P0000080?ooo`@000000P3oool6
000000H0oooo1P0000020?ooo`H000001@3oool4000000H0oooo0P0000060?ooo`P000000P3oool2
00000080oooo0P0000020?ooo`P000002P3oool200000080oooo0P0000040?ooo`8000001P3oool2
00000080oooo200000040?ooo`@000000P3oool200000080oooo0P0000080?ooo`X000001P3oool2
00000080oooo0P0000000`3oool0000000000002000000@0oooo100000020?ooo`H00000103oool6
00000080oooo0P0000020?ooo`8000000P3oool200000080oooo100000040?ooo`8000000P3oool2
00000080oooo100000040?ooo`800000103oool4000000P0oooo0P0000020?ooo`8000001P3oool4
000000H0oooo0P0000020?ooo`H00000203oool200000080oooo0`0000040?ooo`@000000P3oool6
000000@0oooo0P0000020?ooo`@000000P3oool200000080oooo100000020?ooo`@000000P3oool6
000000P0oooo100000020?ooo`l0dLfY000=0=7=Z@8000002P3oool4000000@0oooo100000020?oo
o`P000001P3oool2000000X0oooo0P0000060?ooo`8000002@3oool200000080oooo1P0000020?oo
o`H00000103oool200000080oooo0P0000020?ooo`8000000P3oool2000000@0oooo0P0000020?oo
o`X000000P3oool200000080oooo100000020?ooo`H000000P3oool2000000@0oooo0P0000020?oo
o`@000001P3oool400000080oooo200000040?ooo`8000002P3oool4000000030?ooo`0000000000
00P0oooo0P0000020?ooo`800000103oool6000000@0oooo100000020?ooo`8000000P3oool20000
0080oooo0P0000080?ooo`@000000P3oool2000000P0oooo1P00000<0?ooo`@000000P3oool60000
00X0oooo100000040?ooo`X000000P3oool2000000L0oooo0P0000020?ooo`800000103oool60000
0080oooo0P0000060?ooo`@000001P3oool200000080oooo0P0000040?ooo`X00000103oool?0=7=
Z@003@3AcJT2000000X0oooo100000040?ooo`@000000P3oool8000000H0oooo0P00000:0?ooo`80
00001P3oool2000000T0oooo0P0000020?ooo`H000000P3oool6000000@0oooo0P0000020?ooo`80
00000P3oool200000080oooo0P0000040?ooo`8000000P3oool:00000080oooo0P0000020?ooo`@0
00000P3oool600000080oooo0P0000040?ooo`8000000P3oool4000000H0oooo100000020?ooo`P0
0000103oool2000000X0oooo100000000`3oool00000000000080?ooo`8000000P3oool2000000@0
oooo1P0000040?ooo`@000000P3oool200000080oooo0P0000020?ooo`800000203oool400000080
oooo0P0000080?ooo`H00000303oool400000080oooo1P00000:0?ooo`@00000103oool:00000080
oooo0P0000070?ooo`8000000P3oool2000000@0oooo1P0000020?ooo`8000001P3oool4000000H0
oooo0P0000020?ooo`800000103oool:000000@0oooo3`3AcJT000d0dLfY0P3oool<000000P0oooo
0P0000020?ooo`800000103oool200000080oooo1P0000020?ooo`X000000P3oool600000080oooo
2@0000020?ooo`800000103oool4000000@0oooo1P0000020?ooo`8000000P3oool200000080oooo
0P0000020?ooo`@000000P3oool2000000@0oooo0P0000060?ooo`@000001P3oool2000000H0oooo
1P0000020?ooo`8000002P3oool200000080oooo0P0000040?ooo`8000000P3oool400000080oooo
2P0000050?ooo`X000000P3oool200000080oooo100000040?ooo`H000001P3oool400000080oooo
0P0000020?ooo`P000001P3oool:000000@0oooo3P0000060?ooo`8000003P3oool200000080oooo
100000040?ooo`8000001P3oool900000080oooo0P0000020?ooo`@00000103oool400000080oooo
1P00000:0?ooo`@000000P3oool4000000@0oooo0P0000060?ooo`l0dLfY000=0=7=Z@80oooo3000
00080?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`H000000P3oool:00000080oooo1P00
00020?ooo`T000000P3oool2000000@0oooo100000040?ooo`H000000P3oool200000080oooo0P00
00020?ooo`8000000P3oool400000080oooo0P0000040?ooo`8000001P3oool4000000H0oooo0P00
00060?ooo`H000000P3oool2000000X0oooo0P0000020?ooo`800000103oool200000080oooo1000
00020?ooo`X000001@3oool:00000080oooo0P0000020?ooo`@00000103oool6000000H0oooo1000
00020?ooo`8000000P3oool8000000H0oooo2P0000040?ooo`h000001P3oool2000000h0oooo0P00
00020?ooo`@00000103oool2000000H0oooo2@0000020?ooo`8000000P3oool4000000@0oooo1000
00020?ooo`H000002P3oool400000080oooo100000040?ooo`8000001P3oool?0=7=Z@003@3AcJT4
000000@0oooo0P0000040?ooo`X000000P3oool200000080oooo100000020?ooo`800000103oool4
000000@0oooo0P0000060?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool2
00000080oooo100000080?ooo`8000001P3oool400000080oooo0P0000020?ooo`8000001P3oool6
00000080oooo1P00000:0?ooo`P00000103oool400000080oooo2P0000020?ooo`8000000P3oool4
00000080oooo0P0000060?ooo`800000103oool200000080oooo1@0000040?ooo`8000001P3oool4
000000P0oooo0P00000:0?ooo`8000000P3oool200000080oooo0P0000040?ooo`8000000P3oool6
000000@0oooo0P0000080?ooo`800000103oool2000000@0oooo200000020?ooo`h000000P3oool2
000000P0oooo1`0000040?ooo`8000001P3oool4000000P0oooo0P0000020?ooo`800000103oool<
000000H0oooo0P0000020?ooo`@000000P3oool4000000l0dLfY000=0=7=Z@@00000103oool20000
00@0oooo2P0000020?ooo`8000000P3oool400000080oooo0P0000040?ooo`@00000103oool20000
00H0oooo0P0000060?ooo`030000003oool0oooo0080oooo0P0000020?ooo`8000000P3oool40000
00P0oooo0P0000060?ooo`@000000P3oool200000080oooo0P0000060?ooo`H000000P3oool60000
00X0oooo200000040?ooo`@000000P3oool:00000080oooo0P0000020?ooo`@000000P3oool20000
00H0oooo0P0000040?ooo`8000000P3oool5000000@0oooo0P0000060?ooo`@00000203oool20000
00X0oooo0P0000020?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`H00000103oool20000
00P0oooo0P0000040?ooo`800000103oool800000080oooo3P0000020?ooo`800000203oool70000
00@0oooo0P0000060?ooo`@00000203oool200000080oooo0P0000040?ooo``000001P3oool20000
0080oooo100000020?ooo`@000003`3AcJT000d0dLfY0P0000080?ooo`H00000103oool2000000H0
oooo100000060?ooo`H00000203oool800000080oooo1@0000020?ooo`@000000P3oool200000080
oooo0P00000<0?ooo`P000001P3oool400000080oooo1P0000040?ooo`@00000103oool<000000@0
oooo0P0000020?ooo`@000001P3oool2000000@0oooo0P0000020?ooo`8000000P3oool2000000H0
oooo200000020?ooo`@000000P3oool00`000000oooo0?ooo`020?ooo`H000000P3oool6000000`0
oooo300000020?ooo`8000000P3oool200000080oooo100000020?ooo`800000103oool600000080
oooo200000020?ooo`@000000P3oool4000000@0oooo0P0000020?ooo`800000103oool2000000@0
oooo0P0000020?ooo`8000000P3oool8000000@0oooo00<000000?ooo`3oool0100000020?ooo`H0
0000303oool400000080oooo100000040?ooo`800000103oool800000080oooo0P0000060?ooo`80
00003`3AcJT000d0dLfY0P0000080?ooo`H00000103oool2000000H0oooo100000060?ooo`H00000
203oool800000080oooo1@0000020?ooo`@000000P3oool200000080oooo0P00000<0?ooo`P00000
1P3oool400000080oooo1P0000040?ooo`@00000103oool<000000@0oooo0P0000020?ooo`@00000
1P3oool2000000@0oooo0P0000020?ooo`8000000P3oool2000000H0oooo200000020?ooo`@00000
0P3oool00`000000oooo0?ooo`020?ooo`H000000P3oool6000000`0oooo300000020?ooo`800000
0P3oool200000080oooo100000020?ooo`800000103oool600000080oooo200000020?ooo`@00000
0P3oool4000000@0oooo0P0000020?ooo`800000103oool2000000@0oooo0P0000020?ooo`800000
0P3oool8000000@0oooo00<000000?ooo`3oool0100000020?ooo`H00000303oool400000080oooo
100000040?ooo`800000103oool800000080oooo0P0000060?ooo`8000003`3AcJT000d0dLfY0P00
00020?ooo`P00000103oool600000080oooo1P00000:0?ooo`800000303oool2000000@0oooo1000
00030?ooo`@000001P3oool400000080oooo300000040?ooo`8000000P3oool6000000H0oooo0P00
00080?ooo`8000000P3oool4000000@0oooo0P0000040?ooo`H000000P3oool2000000X0oooo1P00
00020?ooo`8000000P3oool200000080oooo1P0000040?ooo`8000000P3oool2000000D0oooo1P00
00040?ooo`@00000103oool>000000@0oooo0P0000040?ooo`@000000P3oool200000080oooo0P00
00060?ooo`H00000103oool4000000@0oooo0P0000020?ooo`8000001P3oool200000080oooo1000
00020?ooo`8000000P3oool400000080oooo100000020?ooo`8000000P3oool2000000@0oooo0P00
00020?ooo`<000000P3oool2000000H0oooo0P00000@0?ooo`8000000P3oool2000000P0oooo1P00
00040?ooo`8000000P3oool200000080oooo1P00000?0=7=Z@003@3AcJT200000080oooo20000004
0?ooo`H000000P3oool6000000X0oooo0P00000<0?ooo`800000103oool4000000<0oooo10000006
0?ooo`@000000P3oool<000000@0oooo0P0000020?ooo`H000001P3oool2000000P0oooo0P000002
0?ooo`@00000103oool2000000@0oooo1P0000020?ooo`8000002P3oool600000080oooo0P000002
0?ooo`8000000P3oool6000000@0oooo0P0000020?ooo`8000001@3oool6000000@0oooo10000004
0?ooo`h00000103oool2000000@0oooo100000020?ooo`8000000P3oool2000000H0oooo1P000004
0?ooo`@00000103oool200000080oooo0P0000060?ooo`8000000P3oool400000080oooo0P000002
0?ooo`@000000P3oool400000080oooo0P0000020?ooo`800000103oool200000080oooo0`000002
0?ooo`8000001P3oool200000100oooo0P0000020?ooo`800000203oool6000000@0oooo0P000002
0?ooo`8000000P3oool6000000l0dLfY000=0=7=Z@8000000P3oool2000000@0oooo0P0000020?oo
o`@00000103oool4000000@0oooo300000020?ooo``000000P3oool4000000L0oooo0P0000020?oo
o`H000001P3oool2000000@0oooo0P0000080?ooo`@00000103oool800000080oooo200000020?oo
o`800000203oool6000000@0oooo100000020?ooo`X00000103oool400000080oooo0P0000020?oo
o`800000103oool600000080oooo0P0000020?ooo`D00000103oool6000000P0oooo0P0000040?oo
o`800000103oool600000080oooo100000060?ooo`@000000P3oool6000000@0oooo1P0000080?oo
o`@000000P3oool600000080oooo0P0000060?ooo`@000001P3oool200000080oooo0P0000020?oo
o`8000000P3oool400000080oooo0P0000050?ooo`P000000P3oool@00000080oooo0P0000020?oo
o`P00000103oool600000080oooo0P0000020?ooo`800000103oool?0=7=Z@003@3AcJT200000080
oooo0P0000040?ooo`8000000P3oool4000000@0oooo100000040?ooo``000000P3oool<00000080
oooo100000070?ooo`8000000P3oool6000000H0oooo0P0000040?ooo`800000203oool4000000@0
oooo200000020?ooo`P000000P3oool2000000P0oooo1P0000040?ooo`@000000P3oool:000000@0
oooo100000020?ooo`8000000P3oool2000000@0oooo1P0000020?ooo`8000000P3oool5000000@0
oooo1P0000080?ooo`800000103oool2000000@0oooo1P0000020?ooo`@000001P3oool400000080
oooo1P0000040?ooo`H00000203oool400000080oooo1P0000020?ooo`8000001P3oool4000000H0
oooo0P0000020?ooo`8000000P3oool200000080oooo100000020?ooo`8000001@3oool800000080
oooo400000020?ooo`8000000P3oool8000000@0oooo1P0000020?ooo`8000000P3oool2000000@0
oooo3`3AcJT000d0dLfY0P0000020?ooo`8000000P3oool400000080oooo0P0000080?ooo`800000
0P3oool4000000@0oooo0P0000040?ooo`@00000103oool2000000@0oooo1000000;0?ooo`@00000
103oool800000080oooo100000020?ooo`P00000203oool2000000@0oooo100000040?ooo`800000
0P3oool200000080oooo200000040?ooo`H000001P3oool2000000@0oooo0P0000020?ooo`@00000
1P3oool400000080oooo100000040?ooo`@000000P3oool2000000<0oooo1P0000040?ooo`X00000
0P3oool400000080oooo100000040?ooo`@000002P3oool200000080oooo0P0000040?ooo`H00000
103oool:000000H0oooo0P0000060?ooo`P000002P3oool400000080oooo0P0000020?ooo`800000
1P3oool7000000@0oooo0P0000020?ooo`800000103oool2000000@0oooo0P0000060?ooo`@00000
103oool200000080oooo100000040?ooo`@000000P3oool200000080oooo0P00000?0=7=Z@003@3A
cJT200000080oooo0P0000020?ooo`@000000P3oool2000000P0oooo0P0000020?ooo`@00000103o
ool2000000@0oooo100000040?ooo`800000103oool4000000/0oooo100000040?ooo`P000000P3o
ool400000080oooo200000080?ooo`800000103oool4000000@0oooo0P0000020?ooo`8000000P3o
ool8000000@0oooo1P0000060?ooo`800000103oool200000080oooo100000060?ooo`@000000P3o
ool4000000@0oooo100000020?ooo`8000000`3oool6000000@0oooo2P0000020?ooo`@000000P3o
ool4000000@0oooo1000000:0?ooo`8000000P3oool2000000@0oooo1P0000040?ooo`X000001P3o
ool2000000H0oooo2000000:0?ooo`@000000P3oool200000080oooo0P0000060?ooo`L00000103o
ool200000080oooo0P0000040?ooo`800000103oool2000000H0oooo100000040?ooo`8000000P3o
ool4000000@0oooo100000020?ooo`8000000P3oool2000000l0dLfY000=0=7=Z@H0oooo10000006
0?ooo`X000000P3oool2000000P0oooo1P0000080?ooo`H000003`3oool200000080oooo10000004
0?ooo`8000000P3oool2000000H0oooo0P0000040?ooo`X000000P3oool4000000P0oooo10000002
0?ooo`800000103oool200000080oooo100000040?ooo`P000000P3oool400000080oooo0P00000:
0?ooo`8000000P3oool2000000P0oooo0P0000020?ooo`80000000<0oooo0000000000000P000004
0?ooo`H00000103oool2000000H0oooo0P0000020?ooo`800000203oool200000080oooo2P000002
0?ooo`8000000P3oool4000000@0oooo1P0000040?ooo`8000002P3oool8000000@0oooo0P000002
0?ooo`X000001P3oool400000080oooo1@0000040?ooo`8000000P3oool400000080oooo0P000002
0?ooo`@000000P3oool400000080oooo1P0000080?ooo`@00000203oool200000080oooo0P000002
0?ooo`8000003`3AcJT000d0dLfY1P3oool4000000H0oooo2P0000020?ooo`800000203oool60000
00P0oooo1P00000?0?ooo`8000000P3oool4000000@0oooo0P0000020?ooo`8000001P3oool20000
00@0oooo2P0000020?ooo`@00000203oool400000080oooo0P0000040?ooo`8000000P3oool40000
00@0oooo200000020?ooo`@000000P3oool2000000X0oooo0P0000020?ooo`800000203oool20000
0080oooo0P0000000`3oool0000000000002000000@0oooo1P0000040?ooo`8000001P3oool20000
0080oooo0P0000080?ooo`8000000P3oool:00000080oooo0P0000020?ooo`@00000103oool60000
00@0oooo0P00000:0?ooo`P00000103oool200000080oooo2P0000060?ooo`@000000P3oool50000
00@0oooo0P0000020?ooo`@000000P3oool200000080oooo100000020?ooo`@000000P3oool60000
00P0oooo100000080?ooo`8000000P3oool200000080oooo0P00000?0=7=Z@003@3AcJT80?ooo`80
00000P3oool6000000@0oooo0P0000060?ooo`X00000103oool:000000@0oooo4@0000020?ooo`80
0000203oool400000080oooo1P0000020?ooo`@00000103oool2000000H0oooo0P0000020?ooo`P0
00001P3oool600000080oooo0P0000080?ooo`800000103oool4000000H0oooo300000020?ooo`80
00000P3oool800000080oooo0P0000000`3oool00000000000080?ooo`800000203oool800000080
oooo0P0000020?ooo`P000000P3oool2000000@0oooo0P0000060?ooo`@00000203oool2000000P0
oooo300000040?ooo`8000000P3oool400000080oooo0P0000040?ooo`8000002P3oool200000080
oooo0P0000030?ooo`H000000P3oool2000000H0oooo100000060?ooo`8000000P3oool2000000@0
oooo2P00000<0?ooo`@000000P3oool2000000l0dLfY000=0=7=Z@P0oooo0P0000020?ooo`H00000
103oool2000000H0oooo2P0000040?ooo`X00000103ooolA00000080oooo0P0000080?ooo`@00000
0P3oool600000080oooo100000040?ooo`8000001P3oool200000080oooo200000060?ooo`H00000
0P3oool2000000P0oooo0P0000040?ooo`@000001P3oool<00000080oooo0P0000020?ooo`P00000
0P3oool2000000030?ooo`000000000000P0oooo0P0000080?ooo`P000000P3oool200000080oooo
200000020?ooo`800000103oool2000000H0oooo100000080?ooo`800000203oool<000000@0oooo
0P0000020?ooo`@000000P3oool2000000@0oooo0P00000:0?ooo`8000000P3oool2000000<0oooo
1P0000020?ooo`8000001P3oool4000000H0oooo0P0000020?ooo`800000103oool:000000`0oooo
100000020?ooo`8000003`3AcJT000d0dLfY2P0000020?ooo`800000103oool600000080oooo1P00
00040?ooo`800000203oool2000000@0oooo0P0000020?ooo`@00000103oool2000000<0oooo0P00
00040?ooo`@000000P3oool8000000H0oooo0P0000060?ooo`8000000P3oool400000080oooo1P00
00020?ooo`800000103oool200000080oooo1P0000040?ooo`@000000P3oool800000080oooo1000
000:0?ooo`800000103oool2000000H0oooo100000040?ooo`8000000P3oool2000000030?ooo`00
000000000080oooo200000020?ooo`P00000103oool200000080oooo0P0000020?ooo`800000103o
ool200000080oooo0P0000020?ooo`@000000P3oool6000000`0oooo2P0000040?ooo`800000103o
ool600000080oooo0P0000060?ooo`H000000P3oool:00000080oooo0P0000020?ooo`<00000103o
ool400000080oooo1P00000:0?ooo`@000000P3oool4000000@0oooo0P00000@0?ooo`8000000P3o
ool2000000l0dLfY000=0=7=Z@X000000P3oool2000000@0oooo1P0000020?ooo`H00000103oool2
000000P0oooo0P0000040?ooo`8000000P3oool4000000@0oooo0P0000030?ooo`800000103oool4
00000080oooo200000060?ooo`8000001P3oool200000080oooo100000020?ooo`H000000P3oool2
000000@0oooo0P0000020?ooo`H00000103oool400000080oooo200000020?ooo`@000002P3oool2
000000@0oooo0P0000060?ooo`@00000103oool200000080oooo0P0000000`3oool0000000000002
0?ooo`P000000P3oool8000000@0oooo0P0000020?ooo`8000000P3oool2000000@0oooo0P000002
0?ooo`8000000P3oool400000080oooo1P00000<0?ooo`X00000103oool2000000@0oooo1P000002
0?ooo`8000001P3oool600000080oooo2P0000020?ooo`8000000P3oool3000000@0oooo10000002
0?ooo`H000002P3oool400000080oooo100000040?ooo`800000403oool200000080oooo0P00000?
0=7=Z@003@3AcJT2000000@0oooo0P0000060?ooo`H00000103oool4000000@0oooo1P0000020?oo
o`P000000P3oool400000080oooo0P0000080?ooo`D000000P3oool4000000H0oooo0P0000040?oo
o`P000000P3oool600000080oooo0P0000060?ooo`8000001P3oool600000080oooo0P0000040?oo
o`H000001P3oool2000000@0oooo1000000>0?ooo`H000000P3oool6000000P0oooo100000000`3o
ool00000000000020?ooo`800000103oool200000080oooo0P0000040?ooo`8000000P3oool40000
0080oooo0P0000020?ooo`8000000P3oool400000080oooo0P0000020?ooo`8000001P3oool20000
0100oooo0P0000040?ooo`8000000P3oool400000080oooo100000040?ooo`@000000P3oool60000
00@0oooo100000040?ooo`8000001P3oool3000000P0oooo0P0000020?ooo`800000103oool<0000
00H0oooo0P0000020?ooo`@000000P3oool@00000080oooo0P00000?0=7=Z@003@3AcJT2000000@0
oooo0P0000060?ooo`H00000103oool4000000@0oooo1P0000020?ooo`P000000P3oool400000080
oooo0P0000080?ooo`D000000P3oool4000000H0oooo0P0000040?ooo`P000000P3oool600000080
oooo0P0000060?ooo`8000001P3oool600000080oooo0P0000040?ooo`H000001P3oool2000000@0
oooo1000000>0?ooo`H000000P3oool6000000P0oooo100000000`3oool00000000000020?ooo`80
0000103oool200000080oooo0P0000040?ooo`8000000P3oool400000080oooo0P0000020?ooo`80
00000P3oool400000080oooo0P0000020?ooo`8000001P3oool200000100oooo0P0000040?ooo`80
00000P3oool400000080oooo100000040?ooo`@000000P3oool6000000@0oooo100000040?ooo`80
00001P3oool3000000P0oooo0P0000020?ooo`800000103oool<000000H0oooo0P0000020?ooo`@0
00000P3oool@00000080oooo0P00000?0=7=Z@003@3AcJT80?ooo`P00000103oool6000000P0oooo
0P0000060?ooo`800000103oool4000000H0oooo2@0000040?ooo`@000002P3oool6000000@0oooo
0P0000020?ooo`800000103oool400000080oooo1P0000020?ooo`H00000103oool400000080oooo
100000040?ooo`P000000P3oool400000180oooo0P0000060?ooo`800000303oool2000000030?oo
o`00000000000080oooo0P0000020?ooo`@000000P3oool200000080oooo100000020?ooo`800000
1P3oool400000080oooo0P0000060?ooo`@000000P3oool600000080oooo400000020?ooo`@00000
0P3oool2000000H0oooo0P0000020?ooo`@000001P3oool2000000P0oooo0P0000020?ooo`@00000
0P3oool6000000/0oooo100000020?ooo`@00000103oool2000000@0oooo200000020?ooo`800000
1P3oool2000000@0oooo0P0000040?ooo`8000000P3oool2000000l0dLfY000=0=7=Z@P0oooo2000
00040?ooo`H00000203oool2000000H0oooo0P0000040?ooo`@000001P3oool9000000@0oooo1000
000:0?ooo`H00000103oool200000080oooo0P0000040?ooo`@000000P3oool600000080oooo1P00
00040?ooo`@000000P3oool4000000@0oooo200000020?ooo`@000004P3oool2000000H0oooo0P00
000<0?ooo`80000000<0oooo0000000000000P3oool200000080oooo100000020?ooo`8000000P3o
ool400000080oooo0P0000060?ooo`@000000P3oool2000000H0oooo100000020?ooo`H000000P3o
ool@00000080oooo100000020?ooo`8000001P3oool200000080oooo100000060?ooo`800000203o
ool200000080oooo100000020?ooo`H000002`3oool400000080oooo100000040?ooo`800000103o
ool800000080oooo0P0000060?ooo`800000103oool2000000@0oooo0P0000020?ooo`8000003`3A
cJT000d0dLfY2P0000040?ooo`8000000P3oool4000000@0oooo2P0000020?ooo`H000000P3oool4
000000X0oooo0P0000040?ooo`030000003oool0oooo00@000003P3oool2000000P0oooo10000002
0?ooo`@000001P3oool2000000H0oooo0P0000080?ooo`8000000P3oool2000000P0oooo0P000004
0?ooo`@000005P3oool800000080oooo300000000`3oool00000000000020?ooo`8000000P3oool2
000000H0oooo100000060?ooo`P000001P3oool8000000H0oooo0P0000060?ooo`800000103oool2
000000@0oooo0P0000020?ooo`8000001P3oool800000080oooo0P00000:0?ooo`X000000P3oool2
000000H0oooo0P00000?0?ooo`8000000P3oool2000000P0oooo1P0000040?ooo`8000000P3oool2
00000080oooo1P0000020?ooo`@000000P3oool400000080oooo0P00000?0=7=Z@003@3AcJT:0000
00@0oooo0P0000020?ooo`@00000103oool:00000080oooo1P0000020?ooo`@000002P3oool20000
00@0oooo00<000000?ooo`3oool01000000>0?ooo`800000203oool400000080oooo100000060?oo
o`8000001P3oool2000000P0oooo0P0000020?ooo`800000203oool2000000@0oooo1000000F0?oo
o`P000000P3oool<000000030?ooo`00000000000080oooo0P0000020?ooo`8000001P3oool40000
00H0oooo200000060?ooo`P000001P3oool2000000H0oooo0P0000040?ooo`800000103oool20000
0080oooo0P0000060?ooo`P000000P3oool2000000X0oooo2P0000020?ooo`8000001P3oool20000
00l0oooo0P0000020?ooo`800000203oool6000000@0oooo0P0000020?ooo`8000000P3oool60000
0080oooo100000020?ooo`@000000P3oool2000000l0dLfY000=0=7=Z@800000103oool2000000P0
oooo100000080?ooo`800000103oool200000080oooo0P0000040?ooo`@000003P3oool500000080
oooo0P00000B0?ooo`X000001P3oool200000080oooo1P0000020?ooo`H000000P3oool800000080
oooo0P0000020?ooo`P000000P3oool4000001X0oooo0P0000040?ooo`@00000103oool2000000@0
oooo0`0000020?ooo`8000000P3oool200000080oooo1P00000:0?ooo`800000103oool8000000@0
oooo0P0000020?ooo`H000000P3oool600000080oooo100000020?ooo`@000000P3oool200000080
oooo1P0000040?ooo`8000000P3oool200000080oooo2P0000040?ooo`8000001P3oool800000080
oooo3`0000020?ooo`8000000P3oool8000000@0oooo1P0000020?ooo`8000000P3oool2000000@0
oooo100000060?ooo`8000000P3oool2000000l0dLfY000=0=7=Z@800000103oool2000000P0oooo
100000080?ooo`800000103oool200000080oooo0P0000040?ooo`@000003P3oool500000080oooo
0P00000B0?ooo`X000001P3oool200000080oooo1P0000020?ooo`H000000P3oool800000080oooo
0P0000020?ooo`P000000P3oool4000001X0oooo0P0000040?ooo`@00000103oool2000000@0oooo
0`0000020?ooo`8000000P3oool200000080oooo1P00000:0?ooo`800000103oool8000000@0oooo
0P0000020?ooo`H000000P3oool600000080oooo100000020?ooo`@000000P3oool200000080oooo
1P0000040?ooo`8000000P3oool200000080oooo2P0000040?ooo`8000001P3oool800000080oooo
3`0000020?ooo`8000000P3oool8000000@0oooo1P0000020?ooo`8000000P3oool2000000@0oooo
100000060?ooo`8000000P3oool2000000l0dLfY000=0=7=Z@8000000P3oool400000080oooo2000
000<0?ooo`H000000P3oool200000080oooo1000000B0?ooo`8000001@3ooolD000000@0oooo0P00
000:0?ooo`@00000103oool4000000@0oooo100000040?ooo`8000000P3oool200000080oooo0P00
00040?ooo`8000000P3oool2000001h0oooo1P0000080?ooo`D000001P3oool400000080oooo0P00
00040?ooo``000000P3oool4000000@0oooo0P0000020?ooo`@000000P3oool2000000@0oooo1000
00040?ooo`@000001P3oool200000080oooo0P0000020?ooo`800000103oool600000080oooo0P00
00020?ooo`800000103oool2000000P0oooo200000040?ooo`8000000P3oool00`000000oooo0?oo
o`020?ooo`800000103oool2000000H0oooo100000040?ooo`8000000P3oool4000000@0oooo1000
00020?ooo`8000000P3oool4000000X0oooo1000000?0=7=Z@003@3AcJT200000080oooo10000002
0?ooo`P00000303oool600000080oooo0P0000020?ooo`@000004P3oool2000000D0oooo50000004
0?ooo`8000002P3oool4000000@0oooo100000040?ooo`@00000103oool200000080oooo0P000002
0?ooo`800000103oool200000080oooo0P00000N0?ooo`H00000203oool5000000H0oooo10000002
0?ooo`800000103oool<00000080oooo100000040?ooo`8000000P3oool400000080oooo0P000004
0?ooo`@00000103oool4000000H0oooo0P0000020?ooo`8000000P3oool2000000@0oooo1P000002
0?ooo`8000000P3oool2000000@0oooo0P0000080?ooo`P00000103oool200000080oooo00<00000
0?ooo`3oool00P3oool2000000@0oooo0P0000060?ooo`@00000103oool200000080oooo10000004
0?ooo`@000000P3oool200000080oooo1000000:0?ooo`@000003`3AcJT000d0dLfY0P0000020?oo
o`8000001P3oool2000000@0oooo3P0000040?ooo`@000000P3oool2000001H0oooo1`0000040?oo
o`800000103oool2000000@0oooo0P0000020?ooo`@000000P3oool:000000P0oooo0P0000020?oo
o`@00000203oool400000080oooo0P0000020?ooo`@000000P3oool200000080oooo7P0000040?oo
o`X000000`3oool8000000H0oooo1P0000040?ooo`800000103oool4000000P0oooo100000060?oo
o`H00000203oool200000080oooo1P0000020?ooo`8000000P3oool200000080oooo100000040?oo
o`@000000P3oool200000080oooo100000020?ooo`P00000103oool200000080oooo100000020?oo
o`030000003oool0oooo00@000000P3oool400000080oooo1P0000080?ooo`@00000203oool20000
0080oooo0P0000020?ooo`8000003P3oool2000000l0dLfY000=0=7=Z@H0oooo200000020?ooo`@0
0000103oool2000000@0oooo0P0000020?ooo`@000001P3ooolG000000@0oooo0P0000020?ooo`@0
00000P3oool400000080oooo100000020?ooo`8000001P3oool2000000@0oooo0P0000020?ooo`P0
00000P3oool2000000`0oooo0P0000020?ooo`8000000P3oool2000000H0oooo100000040?ooo`80
0000103oool2000000@0oooo0P0000040?ooo`800000103oool6000000@0oooo0P0000070?ooo`80
0000103oool8000000@0oooo1P0000020?ooo`@00000303oool200000080oooo1P0000040?ooo`X0
00000P3oool2000000@0oooo100000020?ooo`8000000P3oool2000000P0oooo0P0000020?ooo`80
00000P3oool2000000H0oooo0P0000040?ooo`H000000P3oool2000000D0oooo100000060?ooo`80
00000P3oool2000000@0oooo2P00000<0?ooo`@000000P3oool200000080oooo3P00000?0=7=Z@00
3@3AcJT60?ooo`P000000P3oool4000000@0oooo0P0000040?ooo`8000000P3oool4000000H0oooo
5`0000040?ooo`8000000P3oool400000080oooo100000020?ooo`@000000P3oool2000000H0oooo
0P0000040?ooo`8000000P3oool800000080oooo0P00000<0?ooo`8000000P3oool200000080oooo
0P0000060?ooo`@00000103oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo
1P0000040?ooo`8000001`3oool2000000@0oooo200000040?ooo`H000000P3oool4000000`0oooo
0P0000020?ooo`H00000103oool:00000080oooo0P0000040?ooo`@000000P3oool200000080oooo
0P0000080?ooo`8000000P3oool200000080oooo0P0000060?ooo`800000103oool600000080oooo
0P0000050?ooo`@000001P3oool200000080oooo0P0000040?ooo`X00000303oool400000080oooo
0P0000020?ooo`h000003`3AcJT000d0dLfY200000040?ooo`8000000P3oool2000000P0oooo1P00
00020?ooo`8000002P3oool2000000@0oooo0P0000040?ooo`800000103oool2000000L0oooo1000
00060?ooo`8000000P3oool2000000H0oooo200000020?ooo`@000000P3oool2000000@0oooo0P00
00020?ooo`8000000P3oool<00000080oooo0P0000020?ooo`8000000P3oool6000000P0oooo1P00
00020?ooo`@000000P3oool400000080oooo100000040?ooo`H000000P3oool700000080oooo1000
00040?ooo`8000000P3oool4000000@0oooo1000000@0?ooo`@00000103oool6000000@0oooo0P00
00060?ooo`H000001P3oool400000080oooo200000020?ooo`8000000P3oool200000080oooo1P00
00020?ooo`@00000103oool400000080oooo1@00000:0?ooo`@000000P3oool4000000@0oooo0P00
000@0?ooo`8000000P3oool200000080oooo0P0000040?ooo`800000103oool2000000l0dLfY000=
0=7=Z@P00000103oool200000080oooo0P0000080?ooo`H000000P3oool2000000X0oooo0P000004
0?ooo`800000103oool2000000@0oooo0P0000070?ooo`@000001P3oool200000080oooo0P000006
0?ooo`P000000P3oool400000080oooo0P0000040?ooo`8000000P3oool200000080oooo30000002
0?ooo`8000000P3oool200000080oooo1P0000080?ooo`H000000P3oool400000080oooo10000002
0?ooo`@00000103oool600000080oooo1`0000020?ooo`@00000103oool200000080oooo10000004
0?ooo`@00000403oool4000000@0oooo1P0000040?ooo`8000001P3oool6000000H0oooo10000002
0?ooo`P000000P3oool200000080oooo0P0000020?ooo`H000000P3oool4000000@0oooo10000002
0?ooo`D000002P3oool400000080oooo100000040?ooo`800000403oool200000080oooo0P000002
0?ooo`800000103oool2000000@0oooo0P00000?0=7=Z@003@3AcJT2000000@0oooo0P0000020?oo
o`@000000P3oool200000080oooo200000040?ooo`@000000P3oool:00000080oooo100000020?oo
o`@000000P3oool4000000030?ooo`000000000000H000002P3oool400000080oooo1P0000040?oo
o`8000000P3oool2000000H0oooo1P0000020?ooo`8000000P3oool2000000@0oooo0P0000040?oo
o`@000000P3oool200000080oooo0P0000040?ooo`X00000103oool4000000H0oooo0P0000020?oo
o`800000203oool2000000H0oooo00<000000?ooo`3oool00P3oool4000000P0oooo100000080?oo
o`8000000P3oool@000000P0oooo0P0000080?ooo`P00000103oool8000000H0oooo0P0000040?oo
o`@000000P3oool200000080oooo0P0000040?ooo`@00000203oool200000080oooo0P0000030?oo
o``000001P3oool200000080oooo100000020?oooa0000000P3oool200000080oooo0P0000020?oo
o`@000000P3oool4000000l0dLfY000=0=7=Z@800000103oool200000080oooo100000020?ooo`80
00000P3oool8000000@0oooo100000020?ooo`X000000P3oool400000080oooo100000020?ooo`@0
000000<0oooo0000000000001P00000:0?ooo`@000000P3oool6000000@0oooo0P0000020?ooo`80
00001P3oool600000080oooo0P0000020?ooo`800000103oool2000000@0oooo100000020?ooo`80
00000P3oool2000000@0oooo2P0000040?ooo`@000001P3oool200000080oooo0P0000080?ooo`80
00001P3oool00`000000oooo0?ooo`020?ooo`@00000203oool4000000P0oooo0P0000020?oooa00
0000203oool2000000P0oooo200000040?ooo`P000001P3oool2000000@0oooo100000020?ooo`80
00000P3oool2000000@0oooo100000080?ooo`8000000P3oool2000000<0oooo300000060?ooo`80
00000P3oool400000080oooo400000020?ooo`8000000P3oool200000080oooo100000020?ooo`@0
00003`3AcJT000d0dLfY203oool4000000H0oooo100000040?ooo`8000000P3oool4000000H0oooo
0P0000040?ooo`8000000P3oool2000000H0oooo0P0000020?ooo`8000001@3oool2000000@0oooo
300000060?ooo`800000203oool400000080oooo1P0000040?ooo`@000000P3oool200000080oooo
100000020?ooo`@000001P3oool400000080oooo100000040?ooo`800000203oool200000080oooo
1P0000020?ooo`8000000P3oool800000080oooo1@0000020?ooo`@00000303oool200000080oooo
200000020?ooo`800000103oool2000000@0oooo0P00000<0?ooo`X00000103oool200000080oooo
100000040?ooo`8000000P3oool600000080oooo100000060?ooo`@000000P3oool4000000`0oooo
100000000`3oool0000000000002000000@0oooo0P0000040?ooo`P000000P3oool2000000H0oooo
0P0000040?ooo`800000103oool200000080oooo0P0000020?ooo`8000000P3oool2000000H0oooo
0P00000?0=7=Z@003@3AcJT80?ooo`@000001P3oool4000000@0oooo0P0000020?ooo`@000001P3o
ool2000000@0oooo0P0000020?ooo`8000001P3oool200000080oooo0P0000050?ooo`800000103o
ool<000000H0oooo0P0000080?ooo`@000000P3oool6000000@0oooo100000020?ooo`8000000P3o
ool400000080oooo100000060?ooo`@000000P3oool4000000@0oooo0P0000080?ooo`8000000P3o
ool600000080oooo0P0000020?ooo`P000000P3oool500000080oooo1000000<0?ooo`8000000P3o
ool800000080oooo0P0000040?ooo`800000103oool2000000`0oooo2P0000040?ooo`8000000P3o
ool4000000@0oooo0P0000020?ooo`H000000P3oool4000000H0oooo100000020?ooo`@00000303o
ool4000000030?ooo`000000000000800000103oool2000000@0oooo200000020?ooo`8000001P3o
ool2000000@0oooo0P0000040?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000001P3o
ool2000000l0dLfY000=0=7=Z@80oooo2000000:0?ooo`8000000P3oool400000080oooo0P00000:
0?ooo`H000000P3oool200000080oooo1P0000020?ooo`8000000P3oool500000080oooo10000004
0?ooo`800000103oool800000080oooo200000060?ooo`800000203oool200000080oooo0P000002
0?ooo`8000001P3oool200000080oooo1P0000060?ooo`8000000P3oool400000080oooo20000002
0?ooo`800000103oool400000080oooo0P0000040?ooo`8000000P3oool2000000<0oooo1000000@
0?ooo`@00000103oool200000080oooo0P0000020?ooo`@000000P3oool400000080oooo30000004
0?ooo`800000203oool4000000P0oooo100000040?ooo`@000002P3oool200000080oooo0P00000@
0?ooo`80000000<0oooo000000000000203oool6000000@0oooo0P0000020?ooo`8000000P3oool6
00000080oooo100000020?ooo`@000000P3oool200000080oooo0P0000020?ooo`8000000P3oool6
000000l0dLfY000=0=7=Z@80oooo2000000:0?ooo`8000000P3oool400000080oooo0P00000:0?oo
o`H000000P3oool200000080oooo1P0000020?ooo`8000000P3oool500000080oooo100000040?oo
o`800000103oool800000080oooo200000060?ooo`800000203oool200000080oooo0P0000020?oo
o`8000001P3oool200000080oooo1P0000060?ooo`8000000P3oool400000080oooo200000020?oo
o`800000103oool400000080oooo0P0000040?ooo`8000000P3oool2000000<0oooo1000000@0?oo
o`@00000103oool200000080oooo0P0000020?ooo`@000000P3oool400000080oooo300000040?oo
o`800000203oool4000000P0oooo100000040?ooo`@000002P3oool200000080oooo0P00000@0?oo
o`80000000<0oooo000000000000203oool6000000@0oooo0P0000020?ooo`8000000P3oool60000
0080oooo100000020?ooo`@000000P3oool200000080oooo0P0000020?ooo`8000000P3oool60000
00l0dLfY000=0=7=Z@@0oooo0P0000040?ooo``000000P3oool2000000H0oooo300000040?ooo`@0
00000P3oool2000000@0oooo100000020?ooo`030000003oool0oooo0080oooo100000080?ooo`H0
0000103oool200000080oooo0P0000040?ooo`8000000P3oool600000080oooo200000020?ooo`80
00000P3oool200000080oooo1P0000020?ooo`800000103oool800000080oooo0P0000060?ooo`80
0000103oool400000080oooo100000060?ooo`H000000P3oool200000080oooo0`00000D0?ooo`80
00000P3oool400000080oooo0P0000020?ooo`8000001P3oool200000080oooo0P0000040?ooo`80
0000103oool600000080oooo2000000<0?ooo`8000000P3oool4000000h0oooo100000020?oooa00
000000<0oooo0000000000000P3oool8000000@0oooo1P0000020?ooo`8000000P3oool2000000@0
oooo100000060?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2000000@0
oooo3`3AcJT000d0dLfY103oool2000000@0oooo300000020?ooo`8000001P3oool<000000@0oooo
100000020?ooo`800000103oool400000080oooo00<000000?ooo`3oool00P3oool4000000P0oooo
1P0000040?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`H000000P3oool800000080oooo
0P0000020?ooo`8000000P3oool600000080oooo0P0000040?ooo`P000000P3oool2000000H0oooo
0P0000040?ooo`@000000P3oool4000000H0oooo1P0000020?ooo`8000000P3oool3000001@0oooo
0P0000020?ooo`@000000P3oool200000080oooo0P0000060?ooo`8000000P3oool2000000@0oooo
0P0000040?ooo`H000000P3oool8000000`0oooo0P0000020?ooo`@000003P3oool400000080oooo
400000000`3oool00000000000020?ooo`P00000103oool600000080oooo0P0000020?ooo`800000
103oool4000000H0oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`800000
103oool?0=7=Z@003@3AcJT60?ooo`H00000103oool2000000@0oooo100000020?ooo`H00000103o
ool2000000@0oooo1P0000060?ooo`H000001@3oool6000000`0oooo0P0000080?ooo`@000000P3o
ool400000080oooo0P0000040?ooo`@00000103oool200000080oooo0P0000020?ooo`8000000P3o
ool2000000@0oooo100000020?ooo`@00000103oool200000080oooo0P0000020?ooo`H000000P3o
ool4000000H0oooo0P0000020?ooo`H00000103oool400000080oooo00<000000?ooo`3oool05P3o
ool4000000H0oooo100000020?ooo`H000000P3oool200000080oooo100000020?ooo`@00000103o
ool4000000@0oooo0P0000020?ooo``000000P3oool200000180oooo0P0000020?ooo`800000103o
ool2000000@0oooo0P0000050?ooo`@00000103oool200000080oooo100000040?ooo`@000000P3o
ool200000080oooo1000000:0?ooo`@000000P3oool200000080oooo0P0000020?ooo`8000000P3o
ool2000000l0dLfY000=0=7=Z@H0oooo1P0000040?ooo`800000103oool400000080oooo1P000004
0?ooo`800000103oool6000000H0oooo1P0000050?ooo`H00000303oool2000000P0oooo10000002
0?ooo`@000000P3oool2000000@0oooo100000040?ooo`8000000P3oool200000080oooo0P000002
0?ooo`800000103oool400000080oooo100000040?ooo`8000000P3oool200000080oooo1P000002
0?ooo`@000001P3oool200000080oooo1P0000040?ooo`@000000P3oool00`000000oooo0?ooo`0F
0?ooo`@000001P3oool400000080oooo1P0000020?ooo`8000000P3oool400000080oooo10000004
0?ooo`@00000103oool200000080oooo300000020?ooo`8000004P3oool200000080oooo0P000004
0?ooo`800000103oool2000000D0oooo100000040?ooo`8000000P3oool4000000@0oooo10000002
0?ooo`8000000P3oool4000000X0oooo100000020?ooo`8000000P3oool200000080oooo0P000002
0?ooo`8000003`3AcJT000d0dLfY200000040?ooo`H000000P3oool4000000H0oooo0P0000080?oo
o`H00000103oool8000000@0oooo1`0000040?ooo`h000000P3oool8000000H0oooo0P0000020?oo
o`8000000P3oool4000000P0oooo100000020?ooo`8000000P3oool200000080oooo100000060?oo
o`8000000P3oool400000080oooo0P0000020?ooo`800000103oool4000000X0oooo100000040?oo
o`H000001@3ooolJ000000X0oooo0P0000020?ooo`800000103oool400000080oooo0P0000060?oo
o`8000000P3oool4000000P0oooo100000040?ooo`800000103oool400000080oooo4P0000020?oo
o`8000000P3oool400000080oooo100000020?ooo`D00000203oool4000000P0oooo0P0000020?oo
o`8000000P3oool2000000h0oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?oo
o`8000003`3AcJT000d0dLfY200000040?ooo`H000000P3oool4000000H0oooo0P0000080?ooo`H0
0000103oool8000000@0oooo1`0000040?ooo`h000000P3oool8000000H0oooo0P0000020?ooo`80
00000P3oool4000000P0oooo100000020?ooo`8000000P3oool200000080oooo100000060?ooo`80
00000P3oool400000080oooo0P0000020?ooo`800000103oool4000000X0oooo100000040?ooo`H0
00001@3ooolJ000000X0oooo0P0000020?ooo`800000103oool400000080oooo0P0000060?ooo`80
00000P3oool4000000P0oooo100000040?ooo`800000103oool400000080oooo4P0000020?ooo`80
00000P3oool400000080oooo100000020?ooo`D00000203oool4000000P0oooo0P0000020?ooo`80
00000P3oool2000000h0oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`80
00003`3AcJT000d0dLfY103oool2000000P0oooo0P0000060?ooo`8000000P3oool600000080oooo
200000040?ooo`H00000103oool200000080oooo100000030?ooo`8000000P3oool4000000@0oooo
0P0000040?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`H000000P3oool200000080oooo
0P00000<0?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000002P3oool4000000H0oooo
100000020?ooo`@000003P3oool200000080oooo100000040?ooo`L00000103oool2000000@0oooo
0P0000040?ooo`800000103oool200000080oooo2P0000020?ooo`8000000P3oool4000000H0oooo
200000020?ooo`800000303oool200000080oooo100000020?ooo`@000001P3oool2000000@0oooo
0P0000040?ooo`8000001P3oool4000000H0oooo0P0000020?ooo`030000003oool0oooo0080oooo
2P00000<0?ooo`@000000P3oool200000080oooo3P0000020?ooo`8000000P3oool200000080oooo
0P0000020?ooo`8000003`3AcJT000d0dLfY103oool2000000P0oooo0P0000060?ooo`8000000P3o
ool600000080oooo200000040?ooo`H00000103oool200000080oooo100000030?ooo`8000000P3o
ool4000000@0oooo0P0000040?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`H000000P3o
ool200000080oooo0P00000<0?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000002P3o
ool4000000H0oooo100000020?ooo`@000003P3oool200000080oooo100000040?ooo`L00000103o
ool2000000@0oooo0P0000040?ooo`800000103oool200000080oooo2P0000020?ooo`8000000P3o
ool4000000H0oooo200000020?ooo`800000303oool200000080oooo100000020?ooo`@000001P3o
ool2000000@0oooo0P0000040?ooo`8000001P3oool4000000H0oooo0P0000020?ooo`030000003o
ool0oooo0080oooo2P00000<0?ooo`@000000P3oool200000080oooo3P0000020?ooo`8000000P3o
ool200000080oooo0P0000020?ooo`8000003`3AcJT000d0dLfY0P3oool400000080oooo20000002
0?ooo`H000000P3oool2000000@0oooo100000040?ooo`8000000P3oool4000000@0oooo1P000002
0?ooo`8000001`3oool4000000P0oooo1P0000020?ooo`8000000P3oool400000080oooo0P000004
0?ooo`@000000P3oool200000080oooo300000020?ooo`8000000P3oool200000080oooo0P000002
0?ooo`X000002P3oool200000080oooo0P00000B0?ooo`@00000203oool2000000<0oooo1P000002
0?ooo`@000000P3oool400000080oooo100000020?ooo`800000103oool2000000H0oooo1000000:
0?ooo`800000103oool400000080oooo300000020?ooo`8000001P3oool200000080oooo1P000002
0?ooo`@000000P3oool400000080oooo1P00000:0?ooo`<000000P3oool4000000@0oooo0P00000@
0?ooo`8000000P3oool200000080oooo0P0000040?ooo`800000103oool200000080oooo0P000002
0?ooo`8000000P3oool200000080oooo0P00000?0=7=Z@003@3AcJT20?ooo`@000000P3oool80000
0080oooo1P0000020?ooo`800000103oool4000000@0oooo0P0000020?ooo`@00000103oool60000
0080oooo0P0000070?ooo`@00000203oool600000080oooo0P0000020?ooo`@000000P3oool20000
00@0oooo100000020?ooo`8000000P3oool<00000080oooo0P0000020?ooo`8000000P3oool20000
0080oooo2P00000:0?ooo`8000000P3oool200000180oooo100000080?ooo`8000000`3oool60000
0080oooo100000020?ooo`@000000P3oool400000080oooo0P0000040?ooo`8000001P3oool40000
00X0oooo0P0000040?ooo`@000000P3oool<00000080oooo0P0000060?ooo`8000000P3oool60000
0080oooo100000020?ooo`@000000P3oool6000000X0oooo0`0000020?ooo`@00000103oool20000
0100oooo0P0000020?ooo`8000000P3oool2000000@0oooo0P0000040?ooo`8000000P3oool20000
0080oooo0P0000020?ooo`8000000P3oool2000000l0dLfY000=0=7=Z@80oooo0P0000060?ooo`80
0000103oool4000000@0oooo100000020?ooo`@00000203oool4000000P0oooo0P0000060?ooo`T0
0000303oool2000000H0oooo100000060?ooo`H000001P3oool4000000@0oooo0P0000040?ooo`@0
00000P3oool200000080oooo0P0000020?ooo`800000103oool2000000h0oooo100000020?oooa80
0000303oool5000000@0oooo100000060?ooo`8000000P3oool2000000H0oooo1P0000020?ooo`H0
00003P3oool6000000H0oooo0P0000040?ooo`8000001P3oool800000080oooo0P0000040?ooo`@0
00001P3oool200000080oooo0P0000040?ooo``000001@3oool200000080oooo100000020?oooa00
00000P3oool200000080oooo0P0000020?ooo`@000000P3oool400000080oooo0P0000020?ooo`80
00000P3oool200000080oooo0P00000?0=7=Z@003@3AcJT20?ooo`8000001P3oool2000000@0oooo
100000040?ooo`@000000P3oool4000000P0oooo100000080?ooo`8000001P3oool9000000`0oooo
0P0000060?ooo`@000001P3oool6000000H0oooo100000040?ooo`800000103oool400000080oooo
0P0000020?ooo`8000000P3oool2000000@0oooo0P00000>0?ooo`@000000P3ooolB000000`0oooo
1@0000040?ooo`@000001P3oool200000080oooo0P0000060?ooo`H000000P3oool6000000h0oooo
1P0000060?ooo`800000103oool2000000H0oooo200000020?ooo`800000103oool4000000H0oooo
0P0000020?ooo`800000103oool<000000D0oooo0P0000020?ooo`@000000P3oool@00000080oooo
0P0000020?ooo`8000000P3oool400000080oooo100000020?ooo`8000000P3oool200000080oooo
0P0000020?ooo`8000003`3AcJT000d0dLfY0P3oool200000080oooo1P0000020?ooo`@00000203o
ool200000080oooo0P00000<0?ooo`8000000P3oool800000080oooo1P0000030?ooo`800000403o
ool8000000X0oooo0P00000:0?ooo`8000000P3oool400000080oooo100000060?ooo`@000000P3o
ool200000080oooo100000020?ooo`h000001P3oool2000000@0oooo0P0000040?ooo`8000003`3o
ool2000000P0oooo0P0000020?ooo`H000000P3oool200000080oooo1P0000040?ooo`@00000103o
ool@000000@0oooo200000020?ooo`@000000P3oool6000000@0oooo0P0000020?ooo`8000000P3o
ool4000000X0oooo100000020?ooo`@00000103oool2000000@0oooo1`0000020?ooo`8000001P3o
ool2000000@0oooo0P0000040?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000001P3o
ool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P00000?0=7=Z@003@3AcJT2
0?ooo`8000000P3oool600000080oooo100000080?ooo`8000000P3oool2000000`0oooo0P000002
0?ooo`P000000P3oool6000000<0oooo0P00000@0?ooo`P000002P3oool2000000X0oooo0P000002
0?ooo`@000000P3oool4000000H0oooo100000020?ooo`8000000P3oool400000080oooo3P000006
0?ooo`800000103oool2000000@0oooo0P00000?0?ooo`800000203oool200000080oooo1P000002
0?ooo`8000000P3oool6000000@0oooo100000040?oooa000000103oool800000080oooo10000002
0?ooo`H00000103oool200000080oooo0P0000020?ooo`@000002P3oool400000080oooo10000004
0?ooo`800000103oool700000080oooo0P0000060?ooo`800000103oool2000000@0oooo0P000002
0?ooo`8000000P3oool200000080oooo0P0000060?ooo`8000000P3oool200000080oooo0P000002
0?ooo`8000000P3oool2000000l0dLfY000=0=7=Z@80oooo0P0000020?ooo`800000103oool40000
00`0oooo100000020?ooo``000000P3oool2000000@0oooo0P0000020?ooo`800000103oool50000
0080oooo400000040?ooo`8000000P3oool:00000080oooo2P0000020?ooo`8000001P3oool20000
0080oooo1P0000060?ooo`@000001P3oool2000000@0oooo0P0000040?ooo`P000000P3oool40000
0080oooo100000020?ooo`l000000P3oool800000080oooo0P0000040?ooo`@000000P3oool20000
00@0oooo1P0000080?ooo`800000103oool2000000@0oooo0P0000020?ooo`@00000103oool20000
0080oooo0P0000060?ooo`800000203oool400000080oooo0P00000>0?ooo`8000000P3oool20000
00P0oooo1@0000040?ooo`8000000P3oool200000080oooo1P0000020?ooo`@000000P3oool40000
0080oooo0P0000020?ooo`8000000P3oool200000080oooo1P0000020?ooo`8000000P3oool20000
0080oooo0P0000020?ooo`8000003`3AcJT000d0dLfY0P3oool200000080oooo0P0000040?ooo`@0
0000303oool400000080oooo300000020?ooo`800000103oool200000080oooo0P0000040?ooo`D0
00000P3oool@000000@0oooo0P0000020?ooo`X000000P3oool:00000080oooo0P0000060?ooo`80
00000P3oool6000000H0oooo100000060?ooo`800000103oool2000000@0oooo200000020?ooo`@0
00000P3oool400000080oooo3`0000020?ooo`P000000P3oool2000000@0oooo100000020?ooo`80
0000103oool6000000P0oooo0P0000040?ooo`800000103oool200000080oooo100000040?ooo`80
00000P3oool2000000H0oooo0P0000080?ooo`@000000P3oool2000000h0oooo0P0000020?ooo`80
0000203oool5000000@0oooo0P0000020?ooo`8000000P3oool600000080oooo100000020?ooo`@0
00000P3oool200000080oooo0P0000020?ooo`8000000P3oool600000080oooo0P0000020?ooo`80
00000P3oool200000080oooo0P00000?0=7=Z@003@3AcJT400000080oooo0P0000020?ooo`@00000
403oool200000080oooo0P0000040?ooo`800000103oool400000080oooo100000020?ooo`800000
0P3oool4000000<0oooo100000040?ooo`800000103oool2000000P0oooo100000040?ooo`800000
1P3oool2000000@0oooo0P0000020?ooo`8000000P3oool600000080oooo0P0000040?ooo`P00000
2P3oool600000080oooo100000040?ooo`8000000P3oool2000000H0oooo0P0000020?ooo`800000
103oool2000000@0oooo00<000000?ooo`3oool0103oool2000000@0oooo100000020?ooo`@00000
1P3oool6000000@0oooo2P0000020?ooo`@000000P3oool400000080oooo0P0000080?ooo`@00000
0P3oool600000080oooo200000060?oooa0000000P3oool200000080oooo200000030?ooo`H00000
0P3oool200000080oooo0P0000040?ooo`@000001P3oool200000080oooo0P0000020?ooo`800000
0P3oool200000080oooo0P0000040?ooo`@000000P3oool200000080oooo0P0000020?ooo`800000
3`3AcJT000d0dLfY100000020?ooo`8000000P3oool400000100oooo0P0000020?ooo`800000103o
ool2000000@0oooo100000020?ooo`@000000P3oool200000080oooo100000030?ooo`@00000103o
ool2000000@0oooo0P0000080?ooo`@00000103oool2000000H0oooo0P0000040?ooo`8000000P3o
ool200000080oooo1P0000020?ooo`800000103oool8000000X0oooo1P0000020?ooo`@00000103o
ool200000080oooo0P0000060?ooo`8000000P3oool2000000@0oooo0P0000040?ooo`030000003o
ool0oooo00@0oooo0P0000040?ooo`@000000P3oool4000000H0oooo1P0000040?ooo`X000000P3o
ool400000080oooo100000020?ooo`800000203oool400000080oooo1P0000020?ooo`P000001P3o
ool@00000080oooo0P0000020?ooo`P000000`3oool600000080oooo0P0000020?ooo`800000103o
ool4000000H0oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`800000103o
ool400000080oooo0P0000020?ooo`8000000P3oool2000000l0dLfY000=0=7=Z@8000001P3oool4
000001@0oooo100000020?ooo`@000000P3oool4000000H0oooo0P0000020?ooo`8000000P3oool2
000000L0oooo0P0000020?ooo`@000000P3oool400000080oooo200000080?ooo`P000000P3oool4
00000080oooo0P0000020?ooo`800000103oool400000080oooo100000040?ooo`8000000P3oool:
000000@0oooo100000080?ooo`@000000P3oool600000080oooo0P0000020?ooo`@000000P3oool3
00000080oooo1P0000020?ooo`@000001P3oool200000080oooo1P0000040?ooo`H00000103oool2
000000H0oooo0P0000020?ooo`8000001P3oool:000000H0oooo0P0000060?ooo`800000103oool8
000000@0oooo0P0000040?ooo`8000001P3oool4000000@0oooo0P0000020?ooo`<00000103oool4
00000080oooo0P0000020?ooo`@000002P3oool400000080oooo0P0000020?ooo`8000000P3oool2
00000080oooo100000060?ooo`@000000P3oool2000000l0dLfY000=0=7=Z@8000001P3oool40000
01@0oooo100000020?ooo`@000000P3oool4000000H0oooo0P0000020?ooo`8000000P3oool20000
00L0oooo0P0000020?ooo`@000000P3oool400000080oooo200000080?ooo`P000000P3oool40000
0080oooo0P0000020?ooo`800000103oool400000080oooo100000040?ooo`8000000P3oool:0000
00@0oooo100000080?ooo`@000000P3oool600000080oooo0P0000020?ooo`@000000P3oool30000
0080oooo1P0000020?ooo`@000001P3oool200000080oooo1P0000040?ooo`H00000103oool20000
00H0oooo0P0000020?ooo`8000001P3oool:000000H0oooo0P0000060?ooo`800000103oool80000
00@0oooo0P0000040?ooo`8000001P3oool4000000@0oooo0P0000020?ooo`<00000103oool40000
0080oooo0P0000020?ooo`@000002P3oool400000080oooo0P0000020?ooo`8000000P3oool20000
0080oooo100000060?ooo`@000000P3oool2000000l0dLfY000=0=7=Z@X0oooo0P0000020?oooa@0
00001P3oool200000080oooo0P00000:0?ooo`@000000P3oool200000080oooo1`0000020?ooo`80
00001P3oool200000080oooo0P0000040?ooo`8000000P3oool8000000@0oooo0P0000020?ooo`80
00001P3oool400000080oooo100000060?ooo`8000000P3oool400000080oooo0P0000040?ooo`80
0000203oool200000080oooo200000060?ooo`8000001P3oool4000000H0oooo00<000000?ooo`3o
ool00P0000040?ooo`@000002P3oool4000000@0oooo1P0000040?ooo`H000000P3oool600000080
oooo0P0000020?ooo`H00000103oool2000000X0oooo200000020?ooo`@00000103oool200000080
oooo100000020?ooo`@000000P3oool6000000P0oooo0`0000080?ooo`8000000P3oool200000080
oooo0P00000>0?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2000000X0
oooo0P0000020?ooo`8000003`3AcJT000d0dLfY2P3oool200000080oooo500000060?ooo`800000
0P3oool2000000X0oooo100000020?ooo`8000000P3oool700000080oooo0P0000060?ooo`800000
0P3oool2000000@0oooo0P0000020?ooo`P00000103oool200000080oooo0P0000060?ooo`@00000
0P3oool4000000H0oooo0P0000020?ooo`@000000P3oool2000000@0oooo0P0000080?ooo`800000
0P3oool8000000H0oooo0P0000060?ooo`@000001P3oool00`000000oooo0?ooo`02000000@0oooo
1000000:0?ooo`@00000103oool6000000@0oooo1P0000020?ooo`H000000P3oool200000080oooo
1P0000040?ooo`8000002P3oool800000080oooo100000040?ooo`8000000P3oool400000080oooo
100000020?ooo`H00000203oool3000000P0oooo0P0000020?ooo`8000000P3oool2000000h0oooo
0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000002P3oool200000080oooo
0P00000?0=7=Z@003@3AcJT<00000080oooo0P0000040?ooo`800000103oool2000000@0oooo0P00
00020?ooo`H000000P3oool200000080oooo2P0000060?ooo`<00000103oool200000080oooo0P00
00020?ooo`H000000P3oool200000080oooo100000020?ooo`800000103oool200000080oooo1000
00020?ooo`8000000P3oool6000000H0oooo0P0000020?ooo`H000000P3oool2000000H0oooo1P00
00020?ooo`P000000P3oool2000000@0oooo0P0000020?ooo`H000000P3oool6000000T0oooo1000
00020?ooo`@000003P3oool200000080oooo100000040?ooo`H00000103oool4000000@0oooo1000
00020?ooo`800000103oool600000080oooo2P0000040?ooo`8000000P3oool2000000P0oooo1000
00060?ooo`8000000P3oool2000000@0oooo2P00000;0?ooo`@000000P3oool200000080oooo3P00
00020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool:00000080oooo0P00
000?0=7=Z@003@3AcJT<00000080oooo0P0000040?ooo`800000103oool2000000@0oooo0P000002
0?ooo`H000000P3oool200000080oooo2P0000060?ooo`<00000103oool200000080oooo0P000002
0?ooo`H000000P3oool200000080oooo100000020?ooo`800000103oool200000080oooo10000002
0?ooo`8000000P3oool6000000H0oooo0P0000020?ooo`H000000P3oool2000000H0oooo1P000002
0?ooo`P000000P3oool2000000@0oooo0P0000020?ooo`H000000P3oool6000000T0oooo10000002
0?ooo`@000003P3oool200000080oooo100000040?ooo`H00000103oool4000000@0oooo10000002
0?ooo`800000103oool600000080oooo2P0000040?ooo`8000000P3oool2000000P0oooo10000006
0?ooo`8000000P3oool2000000@0oooo2P00000;0?ooo`@000000P3oool200000080oooo3P000002
0?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool:00000080oooo0P00000?
0=7=Z@003@3AcJT2000000@0oooo0P0000040?ooo`@000000P3oool400000080oooo100000020?oo
o`@000000P3oool2000000@0oooo100000020?ooo`800000103oool2000000X0oooo00<000000?oo
o`3oool0100000020?ooo`8000000P3oool2000000@0oooo100000020?ooo`8000001P3oool60000
0080oooo0P0000060?ooo`@00000103oool800000080oooo0P0000040?ooo`@000000P3oool60000
00@0oooo100000040?ooo`8000000P3oool200000080oooo100000020?ooo`800000103oool40000
00@0oooo2`0000060?ooo`8000000P3oool>00000080oooo0P0000080?ooo`800000203oool20000
0080oooo100000060?ooo`H00000103oool4000000@0oooo0P0000080?ooo`@000000P3oool80000
00X0oooo100000020?ooo`@00000103oool2000000l0oooo0P0000020?ooo`8000000P3oool20000
00@0oooo0P0000040?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool20000
0080oooo0P0000040?ooo`8000001P3oool?0=7=Z@003@3AcJT2000000@0oooo0P0000040?ooo`@0
00000P3oool400000080oooo100000020?ooo`@000000P3oool2000000@0oooo100000020?ooo`80
0000103oool2000000X0oooo00<000000?ooo`3oool0100000020?ooo`8000000P3oool2000000@0
oooo100000020?ooo`8000001P3oool600000080oooo0P0000060?ooo`@00000103oool800000080
oooo0P0000040?ooo`@000000P3oool6000000@0oooo100000040?ooo`8000000P3oool200000080
oooo100000020?ooo`800000103oool4000000@0oooo2`0000060?ooo`8000000P3oool>00000080
oooo0P0000080?ooo`800000203oool200000080oooo100000060?ooo`H00000103oool4000000@0
oooo0P0000080?ooo`@000000P3oool8000000X0oooo100000020?ooo`@00000103oool2000000l0
oooo0P0000020?ooo`8000000P3oool2000000@0oooo0P0000040?ooo`8000000P3oool200000080
oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000040?ooo`8000001P3oool?0=7=Z@00
3@3AcJT80?ooo`H000001P3oool200000080oooo0P0000060?ooo`8000000P3oool200000080oooo
100000060?ooo`H000000P3oool900000080oooo0P0000060?ooo`@000000P3oool4000000H0oooo
200000040?ooo`@000000P3oool6000000P0oooo0P0000040?ooo`@000000P3oool4000000H0oooo
0P0000080?ooo`8000000P3oool400000080oooo0P0000020?ooo`8000001P3oool6000000P0oooo
0P0000040?ooo`030000003oool0oooo00P0oooo100000040?ooo`800000103oool200000080oooo
0P0000020?ooo`P000000P3oool800000080oooo0P00000:0?ooo`800000203oool200000080oooo
100000020?ooo`P000001P3oool2000000@0oooo300000060?ooo`8000000P3oool400000080oooo
3`0000020?ooo`8000000P3oool200000080oooo100000020?ooo`@000000P3oool200000080oooo
0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`@000000P3oool4000000l0dLfY
000=0=7=Z@P0oooo1P0000060?ooo`8000000P3oool2000000H0oooo0P0000020?ooo`8000000P3o
ool4000000H0oooo1P0000020?ooo`T000000P3oool2000000H0oooo100000020?ooo`@000001P3o
ool8000000@0oooo100000020?ooo`H00000203oool2000000@0oooo100000020?ooo`@000001P3o
ool2000000P0oooo0P0000020?ooo`@000000P3oool200000080oooo0P0000060?ooo`H00000203o
ool2000000@0oooo00<000000?ooo`3oool0203oool4000000@0oooo0P0000040?ooo`8000000P3o
ool200000080oooo200000020?ooo`P000000P3oool2000000X0oooo0P0000080?ooo`8000000P3o
ool400000080oooo200000060?ooo`800000103oool<000000H0oooo0P0000020?ooo`@000000P3o
ool?00000080oooo0P0000020?ooo`8000000P3oool400000080oooo100000020?ooo`8000000P3o
ool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo100000020?ooo`@000003`3A
cJT000d0dLfY0P3oool8000000@0oooo200000020?ooo`8000000P3oool600000080oooo0P000002
0?ooo`8000002P3oool2000000H0oooo0P0000040?ooo`030000003oool0oooo008000000P3oool6
000000H0oooo0P0000020?ooo`H00000103oool200000080oooo100000060?ooo`800000303oool6
000000H0oooo0P0000020?ooo`H000000P3oool800000080oooo0P0000060?ooo`@000000P3oool6
000000@0oooo2P0000020?ooo`<000000P3oool:000000P0oooo1P0000020?ooo`8000000P3oool2
000000@0oooo0P0000020?ooo`800000103oool200000080oooo0P0000020?ooo`X000000P3oool8
00000080oooo0P0000060?ooo`800000103oool800000080oooo100000040?ooo`800000103oool8
00000080oooo0P0000050?ooo`800000103oool2000000@0oooo0P0000020?ooo`8000000P3oool2
00000080oooo0P0000060?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2
00000080oooo0P0000020?ooo`8000001P3oool2000000l0dLfY000=0=7=Z@80oooo200000040?oo
o`P000000P3oool200000080oooo1P0000020?ooo`8000000P3oool2000000X0oooo0P0000060?oo
o`800000103oool00`000000oooo0?ooo`0200000080oooo1P0000060?ooo`8000000P3oool60000
00@0oooo0P0000020?ooo`@000001P3oool2000000`0oooo1P0000060?ooo`8000000P3oool60000
0080oooo200000020?ooo`8000001P3oool400000080oooo1P0000040?ooo`X000000P3oool30000
0080oooo2P0000080?ooo`H000000P3oool200000080oooo0P0000040?ooo`8000000P3oool20000
00@0oooo0P0000020?ooo`8000000P3oool:00000080oooo200000020?ooo`8000001P3oool20000
00@0oooo200000020?ooo`@00000103oool2000000@0oooo200000020?ooo`8000001@3oool20000
00@0oooo0P0000040?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000001P3oool20000
0080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool20000
00H0oooo0P00000?0=7=Z@003@3AcJT4000000@0oooo0P0000020?ooo`@00000103oool200000080
oooo0P0000020?ooo`800000103oool400000080oooo0P0000020?ooo`X000000P3oool600000080
oooo0`0000020?ooo`8000000P3oool2000000@0oooo200000020?ooo`800000103oool600000080
oooo0P00000:0?ooo`h00000103oool800000080oooo0P0000040?ooo`@00000103oool200000080
oooo0P0000020?ooo`H000001P3oool2000000P0oooo0P0000040?ooo`8000000P3oool2000000D0
oooo0P0000040?ooo`8000000P3oool8000000@0oooo100000020?ooo`8000000P3oool400000080
oooo0P0000020?ooo`@000000P3oool200000080oooo0P0000040?ooo`8000001P3oool2000000@0
oooo100000020?ooo`H000000P3oool4000000@0oooo0P0000020?ooo`800000203oool6000000@0
oooo0P0000020?ooo`8000000P3oool500000080oooo100000020?ooo`@000000P3oool200000080
oooo0P0000020?ooo`8000000P3oool600000080oooo0P0000020?ooo`8000000P3oool200000080
oooo0P0000020?ooo`8000000P3oool200000080oooo1P00000?0=7=Z@003@3AcJT4000000@0oooo
0P0000020?ooo`@00000103oool200000080oooo0P0000020?ooo`800000103oool400000080oooo
0P0000020?ooo`X000000P3oool600000080oooo0`0000020?ooo`8000000P3oool2000000@0oooo
200000020?ooo`800000103oool600000080oooo0P00000:0?ooo`h00000103oool800000080oooo
0P0000040?ooo`@00000103oool200000080oooo0P0000020?ooo`H000001P3oool2000000P0oooo
0P0000040?ooo`8000000P3oool2000000D0oooo0P0000040?ooo`8000000P3oool8000000@0oooo
100000020?ooo`8000000P3oool400000080oooo0P0000020?ooo`@000000P3oool200000080oooo
0P0000040?ooo`8000001P3oool2000000@0oooo100000020?ooo`H000000P3oool4000000@0oooo
0P0000020?ooo`800000203oool6000000@0oooo0P0000020?ooo`8000000P3oool500000080oooo
100000020?ooo`@000000P3oool200000080oooo0P0000020?ooo`8000000P3oool600000080oooo
0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo
1P00000?0=7=Z@003@3AcJT2000000P0oooo100000080?ooo`@000000P3oool200000080oooo1000
00060?ooo`@00000103oool2000000H0oooo0P0000060?ooo`030000003oool0oooo008000000P3o
ool200000080oooo100000040?ooo`8000000P3oool200000080oooo100000040?ooo`@000000P3o
ool:000000@0oooo0P0000040?ooo`8000000P3oool4000000@0oooo0P0000020?ooo`8000000P3o
ool4000000P0oooo100000020?ooo`800000103oool800000080oooo200000020?ooo`@000000P3o
ool2000000030?ooo`000000000000@000000P3oool400000080oooo0P0000040?ooo`8000000P3o
ool4000000H0oooo100000060?ooo`@000001P3oool400000080oooo100000020?ooo`H000000P3o
ool4000000H0oooo0P0000060?ooo`8000000P3oool400000080oooo0P0000020?ooo`P00000103o
ool600000080oooo0P0000020?ooo`8000000`3oool4000000H0oooo0P0000020?ooo`8000000P3o
ool200000080oooo0P0000020?ooo`800000103oool400000080oooo0P0000020?ooo`8000000P3o
ool200000080oooo0P0000020?ooo`8000000P3oool2000000@0oooo3`3AcJT000d0dLfY0P000008
0?ooo`@00000203oool400000080oooo0P0000020?ooo`@000001P3oool4000000@0oooo0P000006
0?ooo`8000001P3oool00`000000oooo0?ooo`0200000080oooo0P0000020?ooo`@00000103oool2
00000080oooo0P0000020?ooo`@00000103oool400000080oooo2P0000040?ooo`800000103oool2
00000080oooo100000040?ooo`8000000P3oool200000080oooo100000080?ooo`@000000P3oool2
000000@0oooo200000020?ooo`P000000P3oool400000080oooo0P0000000`3oool0000000000004
00000080oooo100000020?ooo`800000103oool200000080oooo100000060?ooo`@000001P3oool4
000000H0oooo100000020?ooo`@000000P3oool600000080oooo100000060?ooo`8000001P3oool2
00000080oooo100000020?ooo`8000000P3oool8000000@0oooo1P0000020?ooo`8000000P3oool2
000000<0oooo100000060?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2
000000@0oooo100000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2
00000080oooo0P0000040?ooo`l0dLfY000=0=7=Z@80oooo2P00000<0?ooo`8000000P3oool20000
0080oooo0P00000:0?ooo`8000000P3oool400000080oooo1P0000020?ooo`D000000P3oool20000
0080oooo0P0000020?ooo`800000203oool400000080oooo0P0000080?ooo`8000000P3oool20000
00@0oooo0P0000080?ooo`H000000P3oool2000000P0oooo100000020?ooo`800000303oool20000
0080oooo0P0000020?ooo`@00000103oool200000080oooo0P0000040?ooo`8000000P3oool20000
00H0oooo0`0000040?ooo`@000001P3oool600000080oooo0P00000:0?ooo`8000000P3oool60000
00X0oooo0P0000020?ooo`8000001P3oool2000000H0oooo0P0000020?ooo`H000000P3oool60000
0080oooo0P0000060?ooo`@00000103oool200000080oooo100000040?ooo`@000000P3oool20000
00030?ooo`0000000000008000002P3oool400000080oooo0P0000020?ooo`8000000P3oool20000
0080oooo100000060?ooo`@000000P3oool200000080oooo0P0000020?ooo`8000000P3oool20000
0080oooo0P00000?0=7=Z@003@3AcJT20?ooo`X00000303oool200000080oooo0P0000020?ooo`80
00002P3oool200000080oooo100000020?ooo`H000000P3oool500000080oooo0P0000020?ooo`80
00000P3oool2000000P0oooo100000020?ooo`800000203oool200000080oooo0P0000040?ooo`80
0000203oool600000080oooo0P0000080?ooo`@000000P3oool2000000`0oooo0P0000020?ooo`80
00000P3oool4000000@0oooo0P0000020?ooo`800000103oool200000080oooo0P0000060?ooo`<0
0000103oool4000000H0oooo1P0000020?ooo`8000002P3oool200000080oooo1P00000:0?ooo`80
00000P3oool2000000H0oooo0P0000060?ooo`8000000P3oool600000080oooo1P0000020?ooo`80
00001P3oool4000000@0oooo0P0000020?ooo`@00000103oool400000080oooo0P0000000`3oool0
000000000002000000X0oooo100000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`@0
00001P3oool400000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`80
00003`3AcJT000d0dLfY100000040?ooo`800000403oool400000080oooo0P0000020?ooo`X00000
0P3oool2000000H0oooo0P0000060?ooo`8000001@3oool400000080oooo0P0000020?ooo`P00000
1P3oool:00000080oooo0P0000020?ooo`@000000P3oool8000000@0oooo100000020?ooo`P00000
1P3oool>00000080oooo0P0000020?ooo`800000203oool400000080oooo100000020?ooo`800000
0P3oool5000000P0oooo0P0000020?ooo`H00000103oool400000080oooo2P0000020?ooo`800000
103oool<00000080oooo0P0000020?ooo`H000000P3oool600000080oooo0P0000040?ooo`@00000
103oool400000080oooo1P0000080?ooo`@00000203oool200000080oooo0P0000000`3oool00000
0000000>0?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2000000X0oooo
0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2000000l0dLfY
000=0=7=Z@@00000103oool200000100oooo100000020?ooo`8000000P3oool:00000080oooo0P00
00060?ooo`8000001P3oool2000000D0oooo100000020?ooo`8000000P3oool8000000H0oooo2P00
00020?ooo`8000000P3oool400000080oooo200000040?ooo`@000000P3oool8000000H0oooo3P00
00020?ooo`8000000P3oool2000000P0oooo100000020?ooo`@000000P3oool200000080oooo1@00
00080?ooo`8000000P3oool6000000@0oooo100000020?ooo`X000000P3oool2000000@0oooo3000
00020?ooo`8000000P3oool600000080oooo1P0000020?ooo`800000103oool4000000@0oooo1000
00020?ooo`H00000203oool4000000P0oooo0P0000020?ooo`80000000<0oooo0000000000003P3o
ool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P00000:0?ooo`8000000P3o
ool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P00000?0=7=Z@003@3AcJT4
0?ooo`H000000P3oool@000000H0oooo100000040?ooo`8000001P3oool800000080oooo1P000000
0`3oool0000000000004000000H0oooo100000040?ooo`8000000P3oool6000000@0oooo0P000006
0?ooo`@000001P3oool2000000@0oooo1P0000060?ooo`800000103oool8000000@0oooo0P000004
0?ooo`8000000P3oool200000080oooo0P0000020?ooo`P000001P3oool200000080oooo0P000002
0?ooo`8000000`3oool:00000080oooo0P0000040?ooo`H000001P3oool2000000@0oooo0P000002
0?ooo`8000000P3oool4000000@0oooo0P0000040?ooo`@000000P3oool2000000@0oooo10000004
0?ooo`@000000P3oool4000000P0oooo0P0000020?ooo`800000103oool:000000`0oooo10000000
0`3oool00000000000020?ooo`h000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2
00000080oooo2P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2
000000l0dLfY000=0=7=Z@@0oooo1P0000020?oooa0000001P3oool4000000@0oooo0P0000060?oo
o`P000000P3oool6000000030?ooo`000000000000@000001P3oool4000000@0oooo0P0000020?oo
o`H00000103oool2000000H0oooo100000060?ooo`800000103oool6000000H0oooo0P0000040?oo
o`P00000103oool2000000@0oooo0P0000020?ooo`8000000P3oool200000080oooo200000060?oo
o`8000000P3oool200000080oooo0P0000030?ooo`X000000P3oool2000000@0oooo1P0000060?oo
o`800000103oool200000080oooo0P0000020?ooo`@00000103oool2000000@0oooo100000020?oo
o`800000103oool4000000@0oooo100000020?ooo`@00000203oool200000080oooo0P0000040?oo
o`X00000303oool4000000030?ooo`00000000000080oooo3P0000020?ooo`8000000P3oool20000
0080oooo0P0000020?ooo`8000000P3oool:00000080oooo0P0000020?ooo`8000000P3oool20000
0080oooo0P0000020?ooo`8000003`3AcJT000d0dLfY0P3oool4000000@0oooo100000040?ooo`80
0000103oool2000000X0oooo0P0000020?ooo`@000000P3oool6000000@0oooo0P0000020?ooo`80
0000103oool3000000@0oooo200000080?ooo`@00000103oool600000080oooo1P00000:0?ooo`H0
0000103oool800000080oooo100000040?ooo`8000000P3oool400000080oooo100000020?ooo`80
00000P3oool200000080oooo0P0000040?ooo`8000000P3oool600000080oooo0P0000020?ooo`80
00000P3oool3000000@0oooo0P0000060?ooo`H00000103oool800000080oooo100000020?ooo`80
00000P3oool2000000P0oooo1P0000060?ooo`H00000203oool200000080oooo0P00000<0?ooo`@0
00000P3oool4000000@0oooo0P00000@0?ooo`80000000<0oooo0000000000000P3oool2000000@0
oooo0P0000040?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080
oooo0P0000040?ooo`8000001P3oool400000080oooo0P0000020?ooo`8000000P3oool2000000l0
dLfY000=0=7=Z@80oooo100000040?ooo`@00000103oool2000000@0oooo0P00000:0?ooo`800000
0P3oool400000080oooo1P0000040?ooo`8000000P3oool2000000@0oooo0`0000040?ooo`P00000
203oool4000000@0oooo1P0000020?ooo`H000002P3oool6000000@0oooo200000020?ooo`@00000
103oool200000080oooo100000020?ooo`@000000P3oool200000080oooo0P0000020?ooo`800000
103oool200000080oooo1P0000020?ooo`8000000P3oool200000080oooo0`0000040?ooo`800000
1P3oool6000000@0oooo200000020?ooo`@000000P3oool200000080oooo0P0000080?ooo`H00000
1P3oool6000000P0oooo0P0000020?ooo`800000303oool400000080oooo100000040?ooo`800000
403oool2000000030?ooo`00000000000080oooo0P0000040?ooo`800000103oool200000080oooo
0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`800000103oool2000000H0oooo
100000020?ooo`8000000P3oool200000080oooo0P00000?0=7=Z@003@3AcJT20?ooo`800000203o
ool200000080oooo100000020?ooo`@000000P3oool:00000080oooo0P0000060?ooo`800000203o
ool400000080oooo0`0000080?ooo`800000103oool:000000P0oooo0P0000060?ooo`8000003P3o
ool2000000P0oooo0P0000040?ooo`@00000203oool4000000H0oooo0P0000020?ooo`8000000P3o
ool200000080oooo0P0000020?ooo`@000000P3oool2000000@0oooo100000020?ooo`8000000P3o
ool00`000000oooo0?ooo`060?ooo`P00000103oool6000000@0oooo0P0000020?ooo`8000001P3o
ool400000080oooo200000040?ooo`P00000103oool:00000080oooo0P0000020?ooo``000001P3o
ool200000080oooo100000020?oooa00000000<0oooo0000000000000P3oool200000080oooo1000
00020?ooo`@000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P00
00020?ooo`@000000P3oool6000000H0oooo100000020?ooo`8000003`3AcJT000d0dLfY0P3oool2
000000P0oooo0P0000020?ooo`@000000P3oool400000080oooo2P0000020?ooo`8000001P3oool2
000000P0oooo100000020?ooo`<00000203oool2000000@0oooo2P0000080?ooo`8000001P3oool2
000000h0oooo0P0000080?ooo`800000103oool4000000P0oooo100000060?ooo`8000000P3oool2
00000080oooo0P0000020?ooo`8000000P3oool400000080oooo0P0000040?ooo`@000000P3oool2
00000080oooo00<000000?ooo`3oool01P3oool8000000@0oooo1P0000040?ooo`8000000P3oool2
000000H0oooo100000020?ooo`P00000103oool8000000@0oooo2P0000020?ooo`8000000P3oool<
000000H0oooo0P0000020?ooo`@000000P3oool@000000030?ooo`00000000000080oooo0P000002
0?ooo`@000000P3oool400000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P000002
0?ooo`8000000P3oool400000080oooo1P0000060?ooo`@000000P3oool2000000l0dLfY000=0=7=
Z@@000000P3oool800000080oooo0P0000060?ooo`8000000P3oool2000000@0oooo0P0000060?oo
o`P000000P3oool8000000H0oooo00<000000?ooo`3oool0200000020?ooo`@00000103oool20000
00`0oooo200000020?ooo`h000000P3oool800000080oooo1000000<0?ooo`8000000P3oool60000
0080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000060?ooo`H000001P3oool30000
0080oooo200000040?ooo`8000000P3oool4000000@0oooo1P0000020?ooo`8000000P3oool60000
00H0oooo0P0000040?ooo`H00000103oool200000080oooo100000040?ooo`8000001P3oool40000
00@0oooo0P0000040?ooo`P000000P3oool2000000H0oooo0P0000040?ooo`800000103oool20000
00030?ooo`00000000000080oooo0P0000020?ooo`8000001P3oool200000080oooo0P0000020?oo
o`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2000000H0oooo0P00000:0?oo
o`8000000P3oool2000000l0dLfY000=0=7=Z@@000000P3oool800000080oooo0P0000060?ooo`80
00000P3oool2000000@0oooo0P0000060?ooo`P000000P3oool8000000H0oooo00<000000?ooo`3o
ool0200000020?ooo`@00000103oool2000000`0oooo200000020?ooo`h000000P3oool800000080
oooo1000000<0?ooo`8000000P3oool600000080oooo0P0000020?ooo`8000000P3oool200000080
oooo0P0000060?ooo`H000001P3oool300000080oooo200000040?ooo`8000000P3oool4000000@0
oooo1P0000020?ooo`8000000P3oool6000000H0oooo0P0000040?ooo`H00000103oool200000080
oooo100000040?ooo`8000001P3oool4000000@0oooo0P0000040?ooo`P000000P3oool2000000H0
oooo0P0000040?ooo`800000103oool2000000030?ooo`00000000000080oooo0P0000020?ooo`80
00001P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`80
00000P3oool2000000H0oooo0P00000:0?ooo`8000000P3oool2000000l0dLfY000=0=7=Z@800000
1P3oool2000000@0oooo100000020?ooo`H000000P3oool200000080oooo100000020?ooo`H00000
103oool200000080oooo0P0000040?ooo`8000000P3oool500000080oooo0P0000040?ooo`800000
0P3oool2000000P0oooo3P0000040?ooo`8000000P3oool2000000@0oooo0P0000040?ooo`800000
0P3oool2000000@0oooo0P0000020?ooo`800000403oool4000000@0oooo100000020?ooo`800000
0P3oool200000080oooo0P0000020?ooo`H00000103oool8000000D0oooo0P0000040?ooo`H00000
0P3oool2000000P0oooo0P0000060?ooo`@00000103oool800000080oooo100000040?ooo`H00000
0P3oool2000000P0oooo200000080?ooo`H00000103oool200000080oooo0P0000020?ooo`H00000
0P3oool400000080oooo100000000`3oool00000000000020?ooo`8000000P3oool200000080oooo
1P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo
0P0000020?ooo`H000000P3oool:00000080oooo0P00000?0=7=Z@003@3AcJT2000000H0oooo0P00
00040?ooo`@000000P3oool600000080oooo0P0000020?ooo`@000000P3oool6000000@0oooo0P00
00020?ooo`800000103oool200000080oooo1@0000020?ooo`800000103oool200000080oooo0P00
00080?ooo`h00000103oool200000080oooo0P0000040?ooo`800000103oool200000080oooo0P00
00040?ooo`8000000P3oool200000100oooo100000040?ooo`@000000P3oool200000080oooo0P00
00020?ooo`8000000P3oool6000000@0oooo200000050?ooo`800000103oool600000080oooo0P00
00080?ooo`8000001P3oool4000000@0oooo200000020?ooo`@00000103oool600000080oooo0P00
00080?ooo`P00000203oool6000000@0oooo0P0000020?ooo`8000000P3oool600000080oooo1000
00020?ooo`@0000000<0oooo0000000000000P3oool200000080oooo0P0000020?ooo`H000000P3o
ool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3o
ool600000080oooo2P0000020?ooo`8000003`3AcJT000d0dLfY2P3oool6000000H0oooo0P000006
0?ooo`@000001P3oool2000000P0oooo100000020?ooo`@000000P3oool2000000<0oooo10000002
0?ooo`@000000P3oool200000080oooo200000040?ooo`800000103oool200000080oooo10000002
0?ooo`8000000P3oool400000080oooo100000020?ooo`8000000P3oool400000080oooo0P000002
0?oooa000000203oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P000004
0?ooo`H00000103oool2000000030?ooo`000000000000@000000P3oool4000000@0oooo10000002
0?ooo`P000000P3oool6000000P0oooo0P0000040?ooo`@00000203oool2000000H0oooo2P000004
0?ooo`8000000P3oool8000000@0oooo1P0000020?ooo`8000000P3oool2000000@0oooo10000006
0?ooo`80000000<0oooo0000000000000P3oool200000080oooo0P0000020?ooo`800000103oool4
00000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2
000000@0oooo100000040?ooo`8000001P3oool?0=7=Z@003@3AcJT:0?ooo`H000001P3oool20000
00H0oooo100000060?ooo`800000203oool400000080oooo100000020?ooo`8000000`3oool40000
0080oooo100000020?ooo`8000000P3oool8000000@0oooo0P0000040?ooo`8000000P3oool40000
0080oooo0P0000020?ooo`@000000P3oool400000080oooo0P0000020?ooo`@000000P3oool20000
0080oooo400000080?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool20000
00@0oooo1P0000040?ooo`80000000<0oooo000000000000100000020?ooo`@00000103oool40000
0080oooo200000020?ooo`H00000203oool2000000@0oooo100000080?ooo`8000001P3oool:0000
00@0oooo0P0000020?ooo`P00000103oool600000080oooo0P0000020?ooo`800000103oool40000
00H0oooo0P0000000`3oool00000000000020?ooo`8000000P3oool200000080oooo0P0000040?oo
o`@000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?oo
o`800000103oool4000000@0oooo0P0000060?ooo`l0dLfY000=0=7=Z@`0oooo0P00000:0?ooo`P0
00002P3oool:000000H0oooo0P0000020?ooo`8000000P3oool3000000H0oooo0P0000020?ooo`80
00000P3oool2000000@0oooo0P0000020?ooo`@000000P3oool400000080oooo0P0000060?ooo`@0
00001P3oool200000080oooo0P0000020?ooo`8000001P3oool4000000@0oooo0P0000040?ooo`80
0000303oool400000080oooo0P0000020?ooo`8000000P3oool200000080oooo100000040?ooo`H0
000000<0oooo000000000000103oool4000000P0oooo0P0000020?ooo`800000103oool200000080
oooo0P0000040?ooo`X000000P3oool4000000`0oooo200000040?ooo`800000203oool4000000@0
oooo0P0000020?ooo`@00000103oool400000080oooo0P0000020?ooo`@000002P3oool300000080
oooo0P0000020?ooo`8000000P3oool200000080oooo100000060?ooo`@000000P3oool200000080
oooo0P0000020?ooo`8000000P3oool200000080oooo100000080?ooo`H000003`3AcJT000d0dLfY
303oool2000000X0oooo2000000:0?ooo`X000001P3oool200000080oooo0P0000020?ooo`<00000
1P3oool200000080oooo0P0000020?ooo`800000103oool200000080oooo100000020?ooo`@00000
0P3oool2000000H0oooo100000060?ooo`8000000P3oool200000080oooo0P0000060?ooo`@00000
103oool2000000@0oooo0P00000<0?ooo`@000000P3oool200000080oooo0P0000020?ooo`800000
0P3oool4000000@0oooo1P0000000`3oool00000000000040?ooo`@00000203oool200000080oooo
0P0000040?ooo`8000000P3oool2000000@0oooo2P0000020?ooo`@00000303oool8000000@0oooo
0P0000080?ooo`@00000103oool200000080oooo100000040?ooo`@000000P3oool200000080oooo
1000000:0?ooo`<000000P3oool200000080oooo0P0000020?ooo`8000000P3oool4000000H0oooo
100000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool4000000P0oooo
1P00000?0=7=Z@003@3AcJT>0?ooo``00000103oool200000080oooo2P0000040?ooo`8000002P3o
ool400000080oooo00<000000?ooo`3oool0203oool400000080oooo0P0000020?ooo`@000000P3o
ool2000000H0oooo0P0000020?ooo`8000000P3oool6000000X0oooo100000020?ooo`8000000P3o
ool6000000P0oooo1P0000020?ooo``000001P3oool400000080oooo0P0000020?ooo`800000203o
ool2000000D0oooo1P00000<0?ooo`@000000P3oool400000080oooo0P0000020?ooo`@00000103o
ool2000000H0oooo0P0000020?ooo``00000103oool200000080oooo100000020?ooo`P00000203o
ool4000000P0oooo0P0000020?ooo`8000000P3oool2000000d0oooo0P0000020?ooo`8000000P3o
ool200000080oooo0P0000020?ooo`8000002P3oool200000080oooo0P0000020?ooo`8000000P3o
ool200000080oooo0P0000020?ooo`800000303oool200000080oooo3`3AcJT000d0dLfY3P3oool<
000000@0oooo0P0000020?ooo`X00000103oool2000000X0oooo100000020?ooo`030000003oool0
oooo00P0oooo100000020?ooo`8000000P3oool400000080oooo0P0000060?ooo`8000000P3oool2
00000080oooo1P00000:0?ooo`@000000P3oool200000080oooo1P0000080?ooo`H000000P3oool<
000000H0oooo100000020?ooo`8000000P3oool2000000P0oooo0P0000050?ooo`H00000303oool4
00000080oooo100000020?ooo`8000000P3oool4000000@0oooo0P0000060?ooo`8000000P3oool<
000000@0oooo0P0000020?ooo`@000000P3oool8000000P0oooo100000080?ooo`8000000P3oool2
00000080oooo0P00000=0?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2
000000X0oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2
000000`0oooo0P0000020?ooo`l0dLfY000=0=7=ZA00oooo0P0000040?ooo`800000203oool40000
00@0oooo0P0000080?ooo``000001@3oool<000000H0oooo100000060?ooo`P000000P3oool20000
0080oooo0P0000040?ooo``000001P3oool4000000@0oooo2P0000040?ooo`@00000103oool20000
00@0oooo200000060?ooo`@000000P3oool800000080oooo1@0000040?ooo`h000001P3oool20000
0080oooo0P0000020?ooo`800000203oool800000080oooo0P0000040?ooo`800000103oool60000
0080oooo0P0000060?ooo`800000103oool:000000`0oooo100000020?ooo`8000000P3oool=0000
0080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`X000000P3oool20000
0080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo``000000P3oool?0=7=
Z@003@3AcJT@0?ooo`800000103oool2000000P0oooo100000040?ooo`800000203oool<000000D0
oooo300000060?ooo`@000001P3oool800000080oooo0P0000020?ooo`800000103oool<000000H0
oooo100000040?ooo`X00000103oool4000000@0oooo0P0000040?ooo`P000001P3oool400000080
oooo200000020?ooo`D00000103oool>000000H0oooo0P0000020?ooo`8000000P3oool2000000P0
oooo200000020?ooo`800000103oool2000000@0oooo1P0000020?ooo`8000001P3oool2000000@0
oooo2P00000<0?ooo`@000000P3oool200000080oooo3@0000020?ooo`8000000P3oool200000080
oooo0P0000020?ooo`8000000P3oool:00000080oooo0P0000020?ooo`8000000P3oool200000080
oooo0P0000020?ooo`8000000P3oool<00000080oooo3`3AcJT000d0dLfY4P3oool600000080oooo
200000080?ooo`X00000103oool2000000@0oooo1`0000040?ooo`800000103oool8000000X0oooo
0P0000040?ooo`@000000P3oool200000080oooo100000040?ooo`800000103oool8000000P0oooo
0P0000040?ooo`8000000P3oool4000000P0oooo1P0000040?ooo`8000000P3oool6000000H0oooo
0P0000040?ooo`<00000103oool6000000@0oooo0P0000040?ooo`8000000P3oool600000080oooo
0P0000020?ooo`8000000P3oool8000000@0oooo0P0000020?ooo`8000000P3oool400000080oooo
100000040?ooo`@000000P3oool600000080oooo100000040?ooo`800000403oool200000080oooo
0P0000020?ooo`800000103oool2000000<0oooo0P0000020?ooo`8000000P3oool200000080oooo
0P0000020?ooo`8000000P3oool2000000@0oooo0P0000060?ooo`@000000P3oool200000080oooo
0P0000020?ooo`8000000P3oool2000000@0oooo0P0000040?ooo`8000003`3AcJT000d0dLfY4P3o
ool600000080oooo200000080?ooo`X00000103oool2000000@0oooo1`0000040?ooo`800000103o
ool8000000X0oooo0P0000040?ooo`@000000P3oool200000080oooo100000040?ooo`800000103o
ool8000000P0oooo0P0000040?ooo`8000000P3oool4000000P0oooo1P0000040?ooo`8000000P3o
ool6000000H0oooo0P0000040?ooo`<00000103oool6000000@0oooo0P0000040?ooo`8000000P3o
ool600000080oooo0P0000020?ooo`8000000P3oool8000000@0oooo0P0000020?ooo`8000000P3o
ool400000080oooo100000040?ooo`@000000P3oool600000080oooo100000040?ooo`800000403o
ool200000080oooo0P0000020?ooo`800000103oool2000000<0oooo0P0000020?ooo`8000000P3o
ool200000080oooo0P0000020?ooo`8000000P3oool2000000@0oooo0P0000060?ooo`@000000P3o
ool200000080oooo0P0000020?ooo`8000000P3oool2000000@0oooo0P0000040?ooo`8000003`3A
cJT000d0dLfY500000040?ooo`@00000103oool200000080oooo200000040?ooo`800000203oool6
000000<0oooo0P0000020?ooo`@000000P3oool4000000@0oooo0P0000020?ooo`X000000P3oool4
000000H0oooo100000080?ooo`H00000103oool200000080oooo200000020?ooo`@000000P3oool2
000000`0oooo0P0000080?ooo`@00000103oool800000080oooo100000070?ooo`800000203oool6
00000080oooo0P0000040?ooo`@000000P3oool200000080oooo0P0000040?ooo`8000000P3oool4
00000080oooo0P0000020?ooo`8000001P3oool200000080oooo100000060?ooo`8000001P3oool2
00000080oooo100000020?oooa0000000P3oool200000080oooo0P0000020?ooo`@000000P3oool3
00000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool4
00000080oooo1P0000060?ooo`@000000P3oool200000080oooo0P0000020?ooo`@000000P3oool4
000000l0dLfY000=0=7=ZA@00000103oool4000000@0oooo0P0000020?ooo`P00000103oool20000
00P0oooo1P0000030?ooo`8000000P3oool400000080oooo100000040?ooo`8000000P3oool:0000
0080oooo100000060?ooo`@00000203oool6000000@0oooo0P0000020?ooo`P000000P3oool40000
0080oooo0P00000<0?ooo`800000203oool4000000@0oooo200000020?ooo`@000001`3oool20000
00P0oooo1P0000020?ooo`800000103oool400000080oooo0P0000020?ooo`800000103oool20000
0080oooo100000020?ooo`8000000P3oool2000000H0oooo0P0000020?ooo`@000001P3oool20000
00H0oooo0P0000020?ooo`@000000P3oool@00000080oooo0P0000020?ooo`8000000P3oool40000
0080oooo0`0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool20000
0080oooo100000020?ooo`H000001P3oool400000080oooo0P0000020?ooo`8000000P3oool40000
0080oooo1000000?0=7=Z@003@3AcJT2000000@0oooo0P0000040?ooo`800000103oool200000080
oooo100000080?ooo`@00000103oool200000080oooo100000020?ooo`P00000103oool500000080
oooo0P0000060?ooo`8000000P3oool400000080oooo0P0000040?ooo`8000001P3oool200000080
oooo1P00000<0?ooo`800000203oool4000000@0oooo0P0000020?ooo`8000001P3oool>00000080
oooo200000080?ooo`800000103oool4000000/0oooo2P0000040?ooo`@000000P3oool4000000H0
oooo100000020?ooo`@000000P3oool2000000H0oooo100000020?ooo`H000000P3oool2000000X0
oooo200000020?ooo`8000001P3oool2000000@0oooo0P0000040?ooo`8000000P3oool200000080
oooo0P0000020?ooo`8000001@3oool200000080oooo0P0000020?ooo`8000000P3oool200000080
oooo0P0000020?ooo`8000000P3oool2000000H0oooo0P00000:0?ooo`8000000P3oool200000080
oooo0P0000020?ooo`8000001P3oool2000000l0dLfY000=0=7=Z@800000103oool2000000@0oooo
0P0000040?ooo`8000000P3oool4000000P0oooo100000040?ooo`8000000P3oool400000080oooo
200000040?ooo`D000000P3oool2000000H0oooo0P0000020?ooo`@000000P3oool2000000@0oooo
0P0000060?ooo`8000000P3oool6000000`0oooo0P0000080?ooo`@00000103oool200000080oooo
0P0000060?ooo`h000000P3oool8000000P0oooo0P0000040?ooo`@000002`3oool:000000@0oooo
100000020?ooo`@000001P3oool400000080oooo100000020?ooo`8000001P3oool400000080oooo
1P0000020?ooo`8000002P3oool800000080oooo0P0000060?ooo`800000103oool2000000@0oooo
0P0000020?ooo`8000000P3oool200000080oooo0P0000050?ooo`8000000P3oool200000080oooo
0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000001P3oool2000000X0oooo
0P0000020?ooo`8000000P3oool200000080oooo0P0000060?ooo`8000003`3AcJT000d0dLfY0P00
00020?ooo`@000000P3oool400000080oooo100000020?ooo`800000303oool200000080oooo1000
00020?ooo`8000001P3oool2000000@0oooo1P0000030?ooo`@000000P3oool600000080oooo0P00
00060?ooo`H000000P3oool600000080oooo0P0000040?ooo`h000000P3oool8000000P0oooo1000
00020?ooo`H00000103oool2000000@0oooo0P0000020?ooo`800000103oool200000080oooo2000
00020?ooo`@000003`3oool2000000@0oooo0P0000020?ooo`@000001P3oool200000080oooo1P00
00060?ooo`8000000P3oool200000080oooo1P0000060?ooo`8000001P3oool<000000@0oooo0P00
00020?ooo`8000000P3oool600000080oooo100000020?ooo`@000000P3oool200000080oooo0P00
00020?ooo`8000000P3oool500000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P00
00020?ooo`8000000P3oool200000080oooo1P0000020?ooo`X000000P3oool200000080oooo0P00
00020?ooo`8000000P3oool6000000l0dLfY000=0=7=Z@8000000P3oool400000080oooo10000002
0?ooo`@000000P3oool2000000`0oooo0P0000020?ooo`@000000P3oool2000000H0oooo0P000004
0?ooo`H000000`3oool400000080oooo1P0000020?ooo`8000001P3oool600000080oooo1P000002
0?ooo`800000103oool>00000080oooo200000080?ooo`@000000P3oool6000000@0oooo0P000004
0?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`P000000P3oool4000000l0oooo0P000004
0?ooo`8000000P3oool4000000H0oooo0P0000020?ooo`H000001P3oool200000080oooo0P000002
0?ooo`H000001P3oool2000000H0oooo300000040?ooo`8000000P3oool200000080oooo1P000002
0?ooo`@000000P3oool400000080oooo0P0000020?ooo`8000000P3oool200000080oooo1@000002
0?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P000002
0?ooo`H000000P3oool:00000080oooo0P0000020?ooo`8000000P3oool200000080oooo1P00000?
0=7=Z@003@3AcJT60?ooo`8000000P3oool2000000H0oooo0P0000020?ooo`8000000P3oool<0000
0080oooo0P0000060?ooo`P000000P3oool4000000@0oooo1@0000060?ooo`8000001P3oool80000
00@0oooo100000040?ooo`@000000P3oool4000000@0oooo0P0000040?ooo`8000000P3oool20000
00@0oooo0P0000020?ooo`P000001P3oool2000000P0oooo1P0000020?ooo`8000000P3oool40000
0080oooo0P0000040?ooo`8000000P3oool2000001<0oooo1P0000020?ooo`8000002P3oool40000
00@0oooo200000020?ooo`8000000P3oool2000000@0oooo200000020?ooo`H00000103oool20000
00@0oooo1P0000020?ooo`8000000P3oool2000000@0oooo100000060?ooo`8000000P3oool20000
0080oooo0P0000020?ooo`8000000P3oool2000000<0oooo100000020?ooo`8000000P3oool20000
0080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000040?ooo`@00000103oool20000
00H0oooo100000020?ooo`8000000P3oool2000000@0oooo3`3AcJT000d0dLfY1P3oool200000080
oooo0P0000060?ooo`8000000P3oool200000080oooo300000020?ooo`8000001P3oool800000080
oooo100000040?ooo`D000001P3oool2000000H0oooo200000040?ooo`@00000103oool400000080
oooo100000040?ooo`800000103oool200000080oooo0P0000040?ooo`8000000P3oool8000000H0
oooo0P0000080?ooo`H000000P3oool200000080oooo100000020?ooo`800000103oool200000080
oooo0P00000C0?ooo`H000000P3oool2000000X0oooo100000040?ooo`P000000P3oool200000080
oooo0P0000040?ooo`P000000P3oool6000000@0oooo0P0000040?ooo`H000000P3oool200000080
oooo0P0000040?ooo`@000001P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080
oooo0P0000030?ooo`@000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080
oooo0P0000020?ooo`800000103oool4000000@0oooo0P0000060?ooo`@000000P3oool200000080
oooo0P0000040?ooo`l0dLfY000=0=7=Z@80oooo1P0000020?ooo`8000000P3oool600000080oooo
0P0000020?ooo`800000103oool2000000@0oooo100000020?ooo`H00000103oool200000080oooo
0P0000070?ooo`8000002P3oool8000000@0oooo0P0000020?ooo`@00000203oool200000080oooo
0P0000080?ooo`H000000P3oool200000080oooo100000020?ooo`800000103oool200000080oooo
1P0000020?ooo`P00000103oool400000080oooo0P0000060?ooo`H000000P3oool200000080oooo
4`0000040?ooo`@000000P3oool:000000P0oooo0P0000040?ooo`@000000P3oool200000080oooo
100000040?ooo`8000000P3oool2000000@0oooo1P0000020?ooo`@00000103oool400000080oooo
0P0000020?ooo`@000002P3oool400000080oooo0P0000020?ooo`8000000P3oool2000000030?oo
o`0000000000008000001P3oool400000080oooo0P0000020?ooo`8000000P3oool200000080oooo
0P0000020?ooo`@00000203oool8000000H0oooo100000020?ooo`8000003`3AcJT000d0dLfY0P3o
ool600000080oooo0P0000020?ooo`H000000P3oool200000080oooo0P0000040?ooo`800000103o
ool400000080oooo1P0000040?ooo`8000000P3oool2000000L0oooo0P00000:0?ooo`P00000103o
ool200000080oooo100000080?ooo`8000000P3oool2000000P0oooo1P0000020?ooo`8000000P3o
ool400000080oooo0P0000040?ooo`8000000P3oool600000080oooo200000040?ooo`@000000P3o
ool2000000H0oooo1P0000020?ooo`8000000P3ooolC000000@0oooo100000020?ooo`X00000203o
ool2000000@0oooo100000020?ooo`8000000P3oool4000000@0oooo0P0000020?ooo`800000103o
ool600000080oooo100000040?ooo`@000000P3oool200000080oooo1000000:0?ooo`@000000P3o
ool200000080oooo0P0000020?ooo`80000000<0oooo0000000000000P0000060?ooo`@000000P3o
ool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo100000080?ooo`P000001P3o
ool400000080oooo0P00000?0=7=Z@003@3AcJT40?ooo`8000001P3oool4000000@0oooo10000002
0?ooo`8000000P3oool400000080oooo100000060?ooo`800000203oool400000080oooo1`000002
0?ooo`X00000103oool200000080oooo100000020?ooo`800000303oool400000080oooo20000004
0?ooo`@000000P3oool2000000H0oooo1P0000020?ooo`800000103oool4000000@0oooo0P000002
0?ooo`@000001P3oool8000000@0oooo100000020?ooo`8000000`3oool2000000@0oooo0P000004
0?ooo`8000000P3oool4000000H0oooo0P0000040?ooo`8000000P3oool800000080oooo10000006
0?ooo`@00000203oool400000080oooo100000040?ooo`@00000203oool200000080oooo0P000002
0?ooo`8000003P3oool200000080oooo0P0000020?ooo`8000000P3oool2000000030?ooo`000000
000000X0oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2
000000`0oooo0P0000040?ooo`P000001P3oool?0=7=Z@003@3AcJT40?ooo`8000001P3oool40000
00@0oooo100000020?ooo`8000000P3oool400000080oooo100000060?ooo`800000203oool40000
0080oooo1`0000020?ooo`X00000103oool200000080oooo100000020?ooo`800000303oool40000
0080oooo200000040?ooo`@000000P3oool2000000H0oooo1P0000020?ooo`800000103oool40000
00@0oooo0P0000020?ooo`@000001P3oool8000000@0oooo100000020?ooo`8000000`3oool20000
00@0oooo0P0000040?ooo`8000000P3oool4000000H0oooo0P0000040?ooo`8000000P3oool80000
0080oooo100000060?ooo`@00000203oool400000080oooo100000040?ooo`@00000203oool20000
0080oooo0P0000020?ooo`8000003P3oool200000080oooo0P0000020?ooo`8000000P3oool20000
00030?ooo`000000000000X0oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?oo
o`8000000P3oool2000000`0oooo0P0000040?ooo`P000001P3oool?0=7=Z@003@3AcJT600000080
oooo1P0000080?ooo`8000000P3oool200000080oooo0P0000060?ooo`8000000P3oool600000080
oooo200000060?ooo`8000000`3oool4000000@0oooo0P0000080?ooo`@000001P3oool>000000H0
oooo0P0000040?ooo`H000001P3oool8000000@0oooo100000020?ooo`@00000203oool4000000X0
oooo0P0000040?ooo`H000001P3oool500000080oooo100000020?ooo`@000000P3oool2000000X0
oooo1P0000020?ooo`800000103oool200000080oooo0P00000:0?ooo`8000000P3oool8000000H0
oooo0P0000020?ooo`@00000303oool400000080oooo0P0000020?ooo`h000000P3oool200000080
oooo0P0000020?ooo`80000000<0oooo0000000000000P3oool:00000080oooo0P0000020?ooo`80
00000P3oool200000080oooo0P0000020?ooo`8000000P3oool<00000080oooo100000040?ooo`80
00000P3oool4000000l0dLfY000=0=7=Z@H000000P3oool6000000P0oooo0P0000020?ooo`800000
0P3oool2000000H0oooo0P0000020?ooo`H000000P3oool8000000H0oooo0P0000030?ooo`@00000
103oool2000000P0oooo100000060?ooo`h000001P3oool2000000@0oooo1P0000060?ooo`P00000
103oool400000080oooo100000080?ooo`@000002P3oool2000000@0oooo1P0000060?ooo`D00000
0P3oool400000080oooo100000020?ooo`8000002P3oool600000080oooo0P0000040?ooo`800000
0P3oool2000000X0oooo0P0000020?ooo`P000001P3oool200000080oooo1000000<0?ooo`@00000
0P3oool200000080oooo3P0000020?ooo`8000000P3oool200000080oooo0P0000000`3oool00000
000000020?ooo`X000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo
0P0000020?ooo``000000P3oool4000000@0oooo0P0000020?ooo`@000003`3AcJT000d0dLfY0P3o
ool2000000H0oooo0P00000<0?ooo`@000000P3oool200000080oooo1P0000020?ooo`800000103o
ool4000000@0oooo0P0000020?ooo`H0000000<0oooo0000000000000P0000080?ooo`X000002P3o
ool2000000@0oooo0P0000040?ooo`P000000P3oool4000000@0oooo200000040?ooo`8000000P3o
ool4000000H0oooo0P0000020?ooo`P000003P3oool6000000@0oooo200000030?ooo`@000001P3o
ool200000080oooo0P0000020?ooo`X00000103oool400000080oooo100000020?ooo`8000000P3o
ool:00000080oooo0P0000040?ooo`8000000P3oool600000080oooo0P00000@0?ooo`8000000P3o
ool200000080oooo0P0000040?ooo`800000103oool200000080oooo0P0000020?ooo`8000000P3o
ool2000000030?ooo`00000000000080oooo0P0000040?ooo`8000001P3oool400000080oooo0P00
00020?ooo`8000000P3oool200000080oooo0P0000040?ooo`800000103oool4000000P0oooo1000
00020?ooo`l0dLfY000=0=7=Z@80oooo0P0000060?ooo`800000303oool400000080oooo0P000002
0?ooo`H000000P3oool2000000@0oooo100000040?ooo`8000000P3oool6000000030?ooo`000000
000000800000203oool:000000X0oooo0P0000040?ooo`800000103oool800000080oooo10000004
0?ooo`P00000103oool200000080oooo100000060?ooo`8000000P3oool8000000h0oooo1P000004
0?ooo`P000000`3oool4000000H0oooo0P0000020?ooo`8000000P3oool:000000@0oooo10000002
0?ooo`@000000P3oool200000080oooo2P0000020?ooo`800000103oool200000080oooo1P000002
0?ooo`800000403oool200000080oooo0P0000020?ooo`800000103oool2000000@0oooo0P000002
0?ooo`8000000P3oool200000080oooo0P0000000`3oool00000000000020?ooo`800000103oool2
000000H0oooo100000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`800000103oool2
000000@0oooo100000080?ooo`@000000P3oool?0=7=Z@003@3AcJT40?ooo`P000000P3oool<0000
00H0oooo100000040?ooo`@000000P3oool4000000P0oooo100000040?ooo`<00000303oool20000
00@0oooo0P0000020?ooo`X000000P3oool400000080oooo100000040?ooo`8000000P3oool20000
00P0oooo0P0000040?ooo`H000000P3oool2000000X0oooo100000040?ooo`8000000P3oool>0000
00@0oooo1P0000040?ooo`80000000<0oooo0000000000000P00000:0?ooo`@000000P3oool20000
00@0oooo0P0000080?ooo`8000000P3oool2000000H0oooo100000040?ooo`8000001P3oool60000
0080oooo0P0000040?ooo`@000000P3oool@00000080oooo0P0000020?ooo`8000000P3oool40000
0080oooo100000020?ooo`8000000P3oool200000080oooo0P0000000`3oool00000000000020?oo
o`8000000P3oool400000080oooo1P0000060?ooo`@000000P3oool200000080oooo0P0000020?oo
o`@000000P3oool4000000`0oooo0P0000020?ooo`l0dLfY000=0=7=Z@@0oooo200000020?ooo``0
00001P3oool4000000@0oooo100000020?ooo`@00000203oool4000000@0oooo0`00000<0?ooo`80
0000103oool200000080oooo2P0000020?ooo`@000000P3oool4000000@0oooo0P0000020?ooo`80
0000203oool2000000@0oooo1P0000020?ooo`8000002P3oool4000000@0oooo0P0000020?ooo`h0
0000103oool6000000@0oooo0P0000000`3oool0000000000002000000X0oooo100000020?ooo`80
0000103oool2000000P0oooo0P0000020?ooo`8000001P3oool4000000@0oooo0P0000060?ooo`H0
00000P3oool2000000@0oooo100000020?oooa0000000P3oool200000080oooo0P0000020?ooo`@0
00000P3oool400000080oooo0P0000020?ooo`8000000P3oool2000000030?ooo`00000000000080
oooo0P0000020?ooo`@000000P3oool6000000H0oooo100000020?ooo`8000000P3oool200000080
oooo100000020?ooo`@00000303oool200000080oooo3`3AcJT000d0dLfY1P3oool2000000@0oooo
100000040?ooo`800000103oool8000000P0oooo0P0000020?ooo`800000303oool200000080oooo
0`00000@0?ooo`H000000P3oool2000000@0oooo0P0000060?ooo`8000000P3oool2000000P0oooo
100000020?ooo`P000000P3oool4000000@0oooo100000020?ooo`X00000203oool4000000@0oooo
0P0000040?ooo`8000000P3oool4000000@0oooo1P0000000`3oool000000000000>0?ooo`800000
0P3oool200000080oooo100000020?ooo`P000000P3oool200000080oooo1P0000080?ooo`P00000
103oool400000080oooo100000060?ooo`800000103oool2000000@0oooo0P0000020?ooo`800000
0P3oool200000080oooo0P0000060?ooo`8000000P3oool200000080oooo0P0000020?ooo`800000
00<0oooo0000000000000P3oool200000080oooo0P0000060?ooo`8000002P3oool200000080oooo
0P0000020?ooo`8000000P3oool2000000H0oooo0P0000020?ooo``000000P3oool?0=7=Z@003@3A
cJT60?ooo`800000103oool4000000@0oooo0P0000040?ooo`P00000203oool200000080oooo0P00
000<0?ooo`8000000P3oool300000100oooo1P0000020?ooo`800000103oool2000000H0oooo0P00
00020?ooo`800000203oool400000080oooo200000020?ooo`@00000103oool400000080oooo2P00
00080?ooo`@00000103oool2000000@0oooo0P0000020?ooo`@00000103oool6000000030?ooo`00
0000000000h0oooo0P0000020?ooo`8000000P3oool400000080oooo200000020?ooo`8000000P3o
ool6000000P0oooo200000040?ooo`@000000P3oool4000000H0oooo0P0000040?ooo`800000103o
ool200000080oooo0P0000020?ooo`8000000P3oool2000000H0oooo0P0000020?ooo`8000000P3o
ool200000080oooo0P0000000`3oool00000000000020?ooo`8000000P3oool2000000H0oooo0P00
000:0?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000001P3oool200000080oooo3000
00020?ooo`l0dLfY000=0=7=Z@P000000P3oool4000000P0oooo1P0000040?ooo`8000000P3oool8
00000080oooo0P0000020?ooo``000000P3oool2000001<0oooo0P0000060?ooo`H000000P3oool6
00000080oooo0P0000020?ooo`P000001P3oool2000000@0oooo100000080?ooo`8000000P3oool2
000000@0oooo0P00000<0?ooo`8000000P3oool400000080oooo100000020?ooo`800000203oool2
000000D0oooo400000020?ooo`8000000P3oool2000000H0oooo0P0000040?ooo`@000000P3oool2
000000@0oooo2P0000040?ooo`8000000P3oool4000000H0oooo0P0000020?ooo`H000000P3oool4
00000080oooo100000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`H000000P3oool2
00000080oooo0P0000020?ooo`80000000<0oooo0000000000000P3oool200000080oooo0P000002
0?ooo`H000000P3oool:00000080oooo0P0000020?ooo`8000000P3oool200000080oooo1P000002
0?ooo`800000103oool2000000@0oooo0P00000?0=7=Z@003@3AcJT800000080oooo100000080?oo
o`H00000103oool200000080oooo200000020?ooo`8000000P3oool<00000080oooo0P00000C0?oo
o`8000001P3oool600000080oooo1P0000020?ooo`8000000P3oool8000000H0oooo0P0000040?oo
o`@00000203oool200000080oooo0P0000040?ooo`800000303oool200000080oooo100000020?oo
o`@000000P3oool2000000P0oooo0P0000050?oooa0000000P3oool200000080oooo0P0000060?oo
o`800000103oool400000080oooo0P0000040?ooo`X00000103oool200000080oooo100000060?oo
o`8000000P3oool600000080oooo100000020?ooo`@000000P3oool200000080oooo0P0000020?oo
o`8000000P3oool600000080oooo0P0000020?ooo`8000000P3oool2000000030?ooo`0000000000
0080oooo0P0000020?ooo`8000000P3oool600000080oooo2P0000020?ooo`8000000P3oool20000
0080oooo0P0000020?ooo`H000000P3oool2000000@0oooo0P0000040?ooo`8000003`3AcJT000d0
dLfY0P0000040?ooo`8000000P3oool2000000`0oooo0P0000080?ooo`@00000103oool200000080
oooo0P0000020?ooo`800000103oool2000000@0oooo100000000`3oool000000000000B00000080
oooo1P0000040?ooo`@00000103oool400000080oooo0P0000040?ooo`8000000P3oool600000080
oooo1000000<0?ooo`@000000P3oool400000080oooo300000020?ooo`8000001P3oool200000080
oooo0P0000020?ooo`P000000P3oool5000000@0oooo0P0000040?ooo`8000001P3oool400000080
oooo1P0000020?ooo`@000001P3oool6000000@0oooo0P0000080?ooo`@000002P3oool4000000@0
oooo100000060?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2000000@0
oooo100000020?ooo`8000000P3oool2000000030?ooo`00000000000080oooo0P0000020?ooo`80
00000P3oool2000000@0oooo100000040?ooo`8000001P3oool400000080oooo0P0000020?ooo`80
0000103oool400000080oooo100000020?ooo`@000003`3AcJT000d0dLfY0P0000040?ooo`800000
0P3oool2000000`0oooo0P0000080?ooo`@00000103oool200000080oooo0P0000020?ooo`800000
103oool2000000@0oooo100000000`3oool000000000000B00000080oooo1P0000040?ooo`@00000
103oool400000080oooo0P0000040?ooo`8000000P3oool600000080oooo1000000<0?ooo`@00000
0P3oool400000080oooo300000020?ooo`8000001P3oool200000080oooo0P0000020?ooo`P00000
0P3oool5000000@0oooo0P0000040?ooo`8000001P3oool400000080oooo1P0000020?ooo`@00000
1P3oool6000000@0oooo0P0000080?ooo`@000002P3oool4000000@0oooo100000060?ooo`800000
0P3oool200000080oooo0P0000020?ooo`8000000P3oool2000000@0oooo100000020?ooo`800000
0P3oool2000000030?ooo`00000000000080oooo0P0000020?ooo`8000000P3oool2000000@0oooo
100000040?ooo`8000001P3oool400000080oooo0P0000020?ooo`800000103oool400000080oooo
100000020?ooo`@000003`3AcJT000d0dLfY0P3oool600000080oooo0P0000020?ooo``000000P3o
ool8000000P0oooo100000020?ooo`8000000P3oool400000080oooo100000050?ooo`800000103o
ool2000000@0oooo0P0000040?ooo`@00000103oool6000000P0oooo0P0000020?ooo`8000000P3o
ool400000080oooo0P0000040?ooo`@00000403oool200000080oooo0P0000060?ooo`800000103o
ool2000000H0oooo200000020?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`030000003o
ool0oooo0080oooo1P0000020?ooo`@000000P3oool6000000H0oooo0P0000060?ooo`8000000P3o
ool6000000@0oooo1P0000020?ooo`P000003P3oool200000080oooo1000000:0?ooo`@000000P3o
ool200000080oooo0P0000020?ooo`8000000P3oool4000000H0oooo100000000`3oool000000000
00020?ooo`8000000P3oool200000080oooo0P0000020?ooo`@00000203oool8000000H0oooo1000
00020?ooo`@000001P3oool200000080oooo0P0000020?ooo`l0dLfY000=0=7=Z@80oooo1P000002
0?ooo`8000000P3oool<00000080oooo200000080?ooo`@000000P3oool200000080oooo10000002
0?ooo`@000001@3oool2000000@0oooo0P0000040?ooo`800000103oool4000000@0oooo1P000008
0?ooo`8000000P3oool200000080oooo100000020?ooo`800000103oool400000100oooo0P000002
0?ooo`8000001P3oool2000000@0oooo0P0000060?ooo`P000000P3oool200000080oooo0P000004
0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`H000000P3oool400000080oooo1P000006
0?ooo`8000001P3oool200000080oooo1P0000040?ooo`H000000P3oool8000000h0oooo0P000002
0?ooo`@000002P3oool400000080oooo0P0000020?ooo`8000000P3oool200000080oooo10000006
0?ooo`@0000000<0oooo0000000000000P3oool200000080oooo0P0000020?ooo`8000000P3oool4
000000P0oooo200000060?ooo`@000000P3oool4000000H0oooo0P0000020?ooo`8000000P3oool?
0=7=Z@003@3AcJT40?ooo`8000001P3oool4000000@0oooo0P0000040?ooo`@00000103oool20000
0080oooo200000060?ooo`@000001P3oool200000080oooo1@0000020?ooo`@000000P3oool40000
0080oooo100000080?ooo`800000303oool400000080oooo0P0000060?ooo`H00000503oool40000
0080oooo1P0000020?ooo`@000000P3oool6000000@0oooo0P0000020?ooo`8000000P3oool20000
0080oooo100000020?ooo`030000003oool0oooo00@00000103oool4000000H0oooo0P00000:0?oo
o`P000000P3oool2000000@0oooo1P0000040?ooo`@00000103oool200000080oooo3P0000020?oo
o`8000003P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P00000:0?oo
o`80000000<0oooo0000000000000P3oool200000080oooo0P0000020?ooo`8000000P3oool20000
00`0oooo0P0000040?ooo`P000001P3oool200000080oooo1P0000020?ooo`8000000P3oool?0=7=
Z@003@3AcJT40?ooo`8000001P3oool4000000@0oooo0P0000040?ooo`@00000103oool200000080
oooo200000060?ooo`@000001P3oool200000080oooo1@0000020?ooo`@000000P3oool400000080
oooo100000080?ooo`800000303oool400000080oooo0P0000060?ooo`H00000503oool400000080
oooo1P0000020?ooo`@000000P3oool6000000@0oooo0P0000020?ooo`8000000P3oool200000080
oooo100000020?ooo`030000003oool0oooo00@00000103oool4000000H0oooo0P00000:0?ooo`P0
00000P3oool2000000@0oooo1P0000040?ooo`@00000103oool200000080oooo3P0000020?ooo`80
00003P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P00000:0?ooo`80
000000<0oooo0000000000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2000000`0
oooo0P0000040?ooo`P000001P3oool200000080oooo1P0000020?ooo`8000000P3oool?0=7=Z@00
3@3AcJT60?ooo`P00000203oool6000000P0oooo100000040?ooo`8000000P3oool6000000X0oooo
0`0000040?ooo`@000001P3oool200000080oooo0P00000<0?ooo`h000001P3oool8000000@0oooo
5P0000060?ooo`8000001P3oool200000080oooo0P0000040?ooo`H000000P3oool200000080oooo
0P0000020?ooo`8000001@3oool4000000P0oooo0P0000020?ooo`H000000P3oool:000000@0oooo
0P0000020?ooo`8000000P3oool4000000@0oooo1P0000080?ooo`@00000103oool2000000@0oooo
0P0000020?ooo`8000000P3oool>00000080oooo0P0000020?ooo`8000000P3oool200000080oooo
0P0000020?ooo`X0000000<0oooo0000000000000P3oool200000080oooo0P0000020?ooo`800000
0P3oool200000080oooo300000020?ooo`@00000103oool200000080oooo1P0000020?ooo`800000
103oool400000080oooo3`3AcJT000d0dLfY1P3oool8000000P0oooo1P0000080?ooo`@00000103o
ool200000080oooo1P00000:0?ooo`<00000103oool4000000H0oooo0P0000020?ooo`800000303o
ool>000000H0oooo200000040?oooaH000001P3oool2000000H0oooo0P0000020?ooo`800000103o
ool600000080oooo0P0000020?ooo`8000000P3oool2000000D0oooo100000080?ooo`8000000P3o
ool600000080oooo2P0000040?ooo`8000000P3oool200000080oooo100000040?ooo`H00000203o
ool4000000@0oooo0P0000040?ooo`8000000P3oool200000080oooo3P0000020?ooo`8000000P3o
ool200000080oooo0P0000020?ooo`8000000P3oool:000000030?ooo`00000000000080oooo0P00
00020?ooo`8000000P3oool200000080oooo0P0000020?ooo``000000P3oool4000000@0oooo0P00
00020?ooo`H000000P3oool2000000@0oooo100000020?ooo`l0dLfY000=0=7=Z@P00000103oool2
00000080oooo200000040?ooo`X00000203oool4000000@0oooo300000070?ooo`8000000P3oool6
00000080oooo0P0000020?ooo``00000103oool2000000@0oooo0P0000020?ooo`H00000103oool2
00000080oooo100000040?ooo`800000103oool2000000@0oooo0P00000:0?ooo`P000000P3oool2
00000080oooo100000040?ooo`@000000P3oool200000080oooo0P0000020?ooo`D00000303oool4
000000@0oooo100000040?ooo`800000203oool400000080oooo0P0000080?ooo`800000303oool2
00000080oooo100000020?ooo`@000000P3oool200000080oooo0P0000040?ooo`800000103oool2
00000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`800000103oool2
000000D0oooo100000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`800000103oool2
000000@0oooo100000080?ooo`@00000103oool400000080oooo100000040?ooo`l0dLfY000=0=7=
Z@P00000103oool200000080oooo200000040?ooo`X00000203oool4000000@0oooo300000070?oo
o`8000000P3oool600000080oooo0P0000020?ooo``00000103oool2000000@0oooo0P0000020?oo
o`H00000103oool200000080oooo100000040?ooo`800000103oool2000000@0oooo0P00000:0?oo
o`P000000P3oool200000080oooo100000040?ooo`@000000P3oool200000080oooo0P0000020?oo
o`D00000303oool4000000@0oooo100000040?ooo`800000203oool400000080oooo0P0000080?oo
o`800000303oool200000080oooo100000020?ooo`@000000P3oool200000080oooo0P0000040?oo
o`800000103oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?oo
o`800000103oool2000000D0oooo100000020?ooo`8000000P3oool200000080oooo0P0000020?oo
o`800000103oool2000000@0oooo100000080?ooo`@00000103oool400000080oooo100000040?oo
o`l0dLfY000=0=7=Z@@0oooo0P0000080?ooo`@00000103oool200000080oooo100000040?ooo`80
0000303oool200000080oooo100000040?ooo`800000103oool900000080oooo0P0000040?ooo`@0
00000P3oool2000000@0oooo0P0000040?ooo`H000000P3oool400000080oooo0P0000040?ooo`H0
00000P3oool2000000P0oooo1P0000020?ooo`@000000P3oool:000000@0oooo0P0000020?ooo`80
00000P3oool2000000P0oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000030?ooo`h0
0000203oool200000080oooo100000020?ooo`P000001P3oool:00000080oooo300000020?ooo`80
00001P3oool200000080oooo0P0000020?ooo`8000000P3oool400000080oooo100000020?ooo`80
00000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo100000020?ooo`D0
00001P3oool400000080oooo0P0000020?ooo`8000000P3oool400000080oooo1000000<0?ooo`80
00000P3oool4000000H0oooo0P0000020?ooo`8000003`3AcJT000d0dLfY103oool2000000P0oooo
100000040?ooo`8000000P3oool4000000@0oooo0P00000<0?ooo`8000000P3oool4000000@0oooo
0P0000040?ooo`T000000P3oool2000000@0oooo100000020?ooo`800000103oool2000000@0oooo
1P0000020?ooo`@000000P3oool2000000@0oooo1P0000020?ooo`800000203oool600000080oooo
100000020?ooo`X00000103oool200000080oooo0P0000020?ooo`800000203oool200000080oooo
0P0000020?ooo`8000000P3oool2000000<0oooo3P0000080?ooo`8000000P3oool400000080oooo
200000060?ooo`X000000P3oool<00000080oooo0P0000060?ooo`8000000P3oool200000080oooo
0P0000020?ooo`@000000P3oool400000080oooo0P0000020?ooo`8000000P3oool200000080oooo
0P0000020?ooo`8000000P3oool400000080oooo1@0000060?ooo`@000000P3oool200000080oooo
0P0000020?ooo`@000000P3oool4000000`0oooo0P0000020?ooo`@000001P3oool200000080oooo
0P00000?0=7=Z@003@3AcJT20?ooo`@000000P3oool8000000P0oooo100000080?ooo`h000000P3o
ool2000000P0oooo1@0000040?ooo`8000001P3oool6000000H0oooo1P0000020?ooo`@00000103o
ool4000000H0oooo1P0000040?ooo`@000000P3oool8000000@0oooo100000060?ooo`800000103o
ool200000080oooo100000020?ooo`8000000P3oool200000080oooo200000020?ooo`8000000P3o
ool200000080oooo0P0000000`3oool0000000000002000000@0oooo0P0000040?ooo`8000000P3o
ool800000080oooo0P0000060?ooo`800000103oool8000000@0oooo0P0000060?ooo`800000103o
ool2000000H0oooo200000020?ooo`8000000P3oool200000080oooo0P0000060?ooo`8000000P3o
ool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000001@3o
ool2000000X0oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000060?ooo`8000000P3o
ool<00000080oooo0P00000:0?ooo`@000003`3AcJT000d0dLfY0P3oool400000080oooo20000008
0?ooo`@00000203oool>00000080oooo0P0000080?ooo`D00000103oool2000000H0oooo1P000006
0?ooo`H000000P3oool4000000@0oooo100000060?ooo`H00000103oool400000080oooo20000004
0?ooo`@000001P3oool2000000@0oooo0P0000020?ooo`@000000P3oool200000080oooo0P000002
0?ooo`P000000P3oool200000080oooo0P0000020?ooo`80000000<0oooo0000000000000P000004
0?ooo`800000103oool200000080oooo200000020?ooo`8000001P3oool2000000@0oooo20000004
0?ooo`8000001P3oool2000000@0oooo0P0000060?ooo`P000000P3oool200000080oooo0P000002
0?ooo`8000001P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P000002
0?ooo`8000000P3oool2000000D0oooo0P00000:0?ooo`8000000P3oool200000080oooo0P000002
0?ooo`8000001P3oool200000080oooo300000020?ooo`8000002P3oool4000000l0dLfY000=0=7=
Z@@000001P3oool2000000@0oooo2P00000<0?ooo`800000103oool2000000@0oooo100000020?oo
o`P000000`3oool600000080oooo1P0000040?ooo`P00000103oool4000000P0oooo0P0000020?oo
o`H00000103oool6000000H0oooo0P0000040?ooo`H000002P3oool600000080oooo0P0000060?oo
o`@000000P3oool2000000@0oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000000`3o
ool00000000000080?ooo`H000000P3oool2000000@0oooo0P0000020?ooo`8000000P3oool60000
0080oooo100000040?ooo`8000000P3oool400000080oooo1P0000020?ooo`@000000P3oool60000
00@0oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`H000000P3oool20000
0080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool50000
0080oooo2P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`H000000P3oool20000
00@0oooo0P0000040?ooo`@000000P3oool:00000080oooo3`3AcJT000d0dLfY100000060?ooo`80
0000103oool:000000`0oooo0P0000040?ooo`800000103oool400000080oooo200000030?ooo`H0
00000P3oool6000000@0oooo200000040?ooo`@00000203oool200000080oooo1P0000040?ooo`H0
00001P3oool2000000@0oooo1P00000:0?ooo`H000000P3oool2000000H0oooo100000020?ooo`80
0000103oool200000080oooo0P0000020?ooo`8000000P3oool2000000030?ooo`000000000000P0
oooo1P0000020?ooo`800000103oool200000080oooo0P0000020?ooo`H000000P3oool4000000@0
oooo0P0000020?ooo`@000000P3oool600000080oooo100000020?ooo`H00000103oool200000080
oooo0P0000020?ooo`8000000P3oool200000080oooo1P0000020?ooo`8000000P3oool200000080
oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`D000000P3oool:00000080
oooo0P0000020?ooo`8000000P3oool200000080oooo1P0000020?ooo`800000103oool2000000@0
oooo100000020?ooo`X000000P3oool?0=7=Z@003@3AcJT2000000X0oooo1P0000040?ooo`800000
403oool600000080oooo100000060?ooo`800000103oool5000000@0oooo100000040?ooo`H00000
103oool200000080oooo1000000<0?ooo`@00000103oool6000000@0oooo200000020?ooo`@00000
103oool<000000@0oooo100000020?ooo`H000001P3oool600000080oooo0P0000020?ooo`800000
0P3oool2000000030?ooo`00000000000080oooo200000040?ooo`@000000P3oool400000080oooo
0P0000020?ooo`800000103oool4000000P0oooo100000060?ooo`8000001P3oool200000080oooo
0P0000040?ooo`H000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2000000@0oooo
100000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo
0P0000030?ooo`@00000103oool2000000H0oooo100000020?ooo`8000000P3oool2000000@0oooo
100000020?ooo`@000000P3oool4000000H0oooo0P0000040?ooo`8000000P3oool?0=7=Z@003@3A
cJT2000000X0oooo1P0000040?ooo`800000403oool600000080oooo100000060?ooo`800000103o
ool5000000@0oooo100000040?ooo`H00000103oool200000080oooo1000000<0?ooo`@00000103o
ool6000000@0oooo200000020?ooo`@00000103oool<000000@0oooo100000020?ooo`H000001P3o
ool600000080oooo0P0000020?ooo`8000000P3oool2000000030?ooo`00000000000080oooo2000
00040?ooo`@000000P3oool400000080oooo0P0000020?ooo`800000103oool4000000P0oooo1000
00060?ooo`8000001P3oool200000080oooo0P0000040?ooo`H000000P3oool200000080oooo0P00
00020?ooo`8000000P3oool2000000@0oooo100000020?ooo`8000000P3oool200000080oooo0P00
00020?ooo`8000000P3oool200000080oooo0P0000030?ooo`@00000103oool2000000H0oooo1000
00020?ooo`8000000P3oool2000000@0oooo100000020?ooo`@000000P3oool4000000H0oooo0P00
00040?ooo`8000000P3oool?0=7=Z@003@3AcJT20?ooo``00000103oool600000080oooo40000004
0?ooo`@000002P3oool6000000<0oooo1P0000080?ooo`800000203oool400000100oooo0P000002
0?ooo`@00000103oool6000000@0oooo0P0000020?ooo`800000203oool2000000@0oooo0P000008
0?ooo`8000000P3oool2000000@0oooo200000040?ooo`@000000P3oool200000080oooo0P000000
0`3oool00000000000020?ooo`800000103oool200000080oooo100000060?ooo`8000000P3oool2
00000080oooo0P0000020?ooo`@00000303oool200000080oooo1P0000020?ooo`H000000P3oool2
00000080oooo100000040?ooo`@000000P3oool200000080oooo0P0000020?ooo`8000000P3oool4
000000H0oooo100000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`80000000<0oooo
0000000000000P0000080?ooo`P000001P3oool400000080oooo100000060?ooo`8000000P3oool2
000000X0oooo1P0000020?ooo`l0dLfY000=0=7=Z@80oooo300000040?ooo`H000000P3oool@0000
00@0oooo1000000:0?ooo`H000000`3oool6000000P0oooo0P0000080?ooo`@00000403oool20000
0080oooo100000040?ooo`H00000103oool200000080oooo0P0000080?ooo`800000103oool20000
00P0oooo0P0000020?ooo`800000103oool8000000@0oooo100000020?ooo`8000000P3oool20000
00030?ooo`00000000000080oooo0P0000040?ooo`8000000P3oool4000000H0oooo0P0000020?oo
o`8000000P3oool200000080oooo1000000<0?ooo`8000000P3oool600000080oooo1P0000020?oo
o`8000000P3oool4000000@0oooo100000020?ooo`8000000P3oool200000080oooo0P0000020?oo
o`@000001P3oool400000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000000`3o
ool0000000000002000000P0oooo200000060?ooo`@000000P3oool4000000H0oooo0P0000020?oo
o`8000002P3oool600000080oooo3`3AcJT000d0dLfY103oool2000000@0oooo0P0000080?ooo`80
00001P3oool2000000@0oooo0P0000040?ooo`8000000P3oool4000000h0oooo0P0000070?ooo`80
0000303oool:000001@0oooo100000080?ooo`800000203oool400000080oooo200000020?ooo`@0
00000P3oool800000080oooo0P0000020?ooo`@00000103oool200000080oooo100000060?ooo`@0
000000<0oooo0000000000000P3oool200000080oooo100000020?ooo`8000002P3oool400000080
oooo0P0000020?ooo`800000403oool4000000@0oooo100000040?ooo`@000000P3oool2000000P0
oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000002P3oool200000080
oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000000`3oool000000000000<0?ooo`80
0000103oool8000000H0oooo0P0000020?ooo`H000000P3oool200000080oooo2P0000040?ooo`80
00003`3AcJT000d0dLfY103oool2000000@0oooo0P0000080?ooo`8000001P3oool2000000@0oooo
0P0000040?ooo`8000000P3oool4000000h0oooo0P0000070?ooo`800000303oool:000001@0oooo
100000080?ooo`800000203oool400000080oooo200000020?ooo`@000000P3oool800000080oooo
0P0000020?ooo`@00000103oool200000080oooo100000060?ooo`@0000000<0oooo000000000000
0P3oool200000080oooo100000020?ooo`8000002P3oool400000080oooo0P0000020?ooo`800000
403oool4000000@0oooo100000040?ooo`@000000P3oool2000000P0oooo0P0000020?ooo`800000
0P3oool200000080oooo0P0000020?ooo`8000002P3oool200000080oooo0P0000020?ooo`800000
0P3oool200000080oooo0P0000000`3oool000000000000<0?ooo`800000103oool8000000H0oooo
0P0000020?ooo`H000000P3oool200000080oooo2P0000040?ooo`8000003`3AcJT000d0dLfY1P00
00020?ooo`@000000P3oool800000080oooo1P0000020?ooo`@000000P3oool400000080oooo0P00
000B0?ooo`T000000P3oool<000000@0oooo0P00000H0?ooo`8000000P3oool800000080oooo2000
00060?ooo`800000103oool4000000H0oooo0P0000040?ooo`@000000P3oool2000000P0oooo1000
000:0?ooo`80000000<0oooo0000000000000P3oool200000080oooo0P0000060?ooo``000001P3o
ool400000080oooo400000080?ooo`8000000P3oool4000000H0oooo2P0000020?ooo`8000000P3o
ool200000080oooo0P0000020?ooo`8000000P3oool:00000080oooo0P0000020?ooo`8000000P3o
ool200000080oooo0P0000000`3oool00000000000020?ooo``000000P3oool4000000@0oooo0P00
00020?ooo`H000000P3oool2000000@0oooo100000020?ooo`800000103oool2000000P0oooo3`3A
cJT000d0dLfY1P0000020?ooo`@000000P3oool800000080oooo1P0000020?ooo`@000000P3oool4
00000080oooo0P00000B0?ooo`T000000P3oool<000000@0oooo0P00000H0?ooo`8000000P3oool8
00000080oooo200000060?ooo`800000103oool4000000H0oooo0P0000040?ooo`@000000P3oool2
000000P0oooo1000000:0?ooo`80000000<0oooo0000000000000P3oool200000080oooo0P000006
0?ooo``000001P3oool400000080oooo400000080?ooo`8000000P3oool4000000H0oooo2P000002
0?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool:00000080oooo0P000002
0?ooo`8000000P3oool200000080oooo0P0000000`3oool00000000000020?ooo``000000P3oool4
000000@0oooo0P0000020?ooo`H000000P3oool2000000@0oooo100000020?ooo`800000103oool2
000000P0oooo3`3AcJT000d0dLfY0P0000040?ooo`@000001P3oool2000000@0oooo100000040?oo
o`@000001P3oool200000080oooo0P0000020?oooa8000000`3oool2000000H0oooo0P0000040?oo
o`800000203ooolJ00000080oooo0P0000040?ooo`8000000P3oool2000000@0oooo0P0000020?oo
o`H000000P3oool4000000X0oooo1P0000060?ooo`X000003P3oool300000080oooo0P0000020?oo
o`8000000P3oool6000000@0oooo0P0000040?ooo`P000001P3oool2000000@0oooo0P0000040?oo
o`8000000P3oool800000080oooo0P00000:0?ooo`800000103oool200000080oooo0P0000020?oo
o`8000000P3oool200000080oooo0P0000020?ooo`800000103oool2000000H0oooo100000020?oo
o`8000000P3oool2000000030?ooo`00000000000080oooo0P0000040?ooo`800000103oool40000
00P0oooo100000040?ooo`@000000P3oool4000000H0oooo1P0000020?ooo`H000003`3AcJT000d0
dLfY0P0000040?ooo`@000001P3oool2000000@0oooo100000040?ooo`@000001P3oool200000080
oooo0P0000020?oooa8000000`3oool2000000H0oooo0P0000040?ooo`800000203ooolJ00000080
oooo0P0000040?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`H000000P3oool4000000X0
oooo1P0000060?ooo`X000003P3oool300000080oooo0P0000020?ooo`8000000P3oool6000000@0
oooo0P0000040?ooo`P000001P3oool2000000@0oooo0P0000040?ooo`8000000P3oool800000080
oooo0P00000:0?ooo`800000103oool200000080oooo0P0000020?ooo`8000000P3oool200000080
oooo0P0000020?ooo`800000103oool2000000H0oooo100000020?ooo`8000000P3oool200000003
0?ooo`00000000000080oooo0P0000040?ooo`800000103oool4000000P0oooo100000040?ooo`@0
00000P3oool4000000H0oooo1P0000020?ooo`H000003`3AcJT000d0dLfY0P0000020?ooo`@00000
2P3oool6000000P0oooo0P0000020?ooo`H000000P3oool200000080oooo0P0000040?ooo`800000
103oool2000000@0oooo1@0000020?ooo`H000000P3oool400000080oooo200000040?ooo`800000
103oool2000000@0oooo0P0000040?ooo`8000000P3oool200000080oooo100000020?ooo`800000
0P3oool400000080oooo0P0000040?ooo`@000003P3oool2000000X0oooo0P0000040?ooo`800000
0P3oool=000000H0oooo100000020?ooo`800000103oool600000080oooo100000040?ooo`800000
0P3oool600000080oooo100000020?ooo`@000000P3oool2000000@0oooo0P0000020?ooo`800000
0P3oool:00000080oooo100000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`800000
0P3oool200000080oooo100000020?ooo`H000001P3oool4000000030?ooo`00000000000080oooo
0P0000020?ooo`@000000P3oool4000000`0oooo0P0000020?ooo`@000001P3oool200000080oooo
1P0000040?ooo`@00000103oool?0=7=Z@003@3AcJT200000080oooo1000000:0?ooo`H00000203o
ool200000080oooo1P0000020?ooo`8000000P3oool2000000@0oooo0P0000040?ooo`800000103o
ool500000080oooo1P0000020?ooo`@000000P3oool8000000@0oooo0P0000040?ooo`800000103o
ool2000000@0oooo0P0000020?ooo`8000000P3oool400000080oooo0P0000020?ooo`@000000P3o
ool2000000@0oooo1000000>0?ooo`8000002P3oool2000000@0oooo0P0000020?ooo`d000001P3o
ool400000080oooo0P0000040?ooo`H000000P3oool4000000@0oooo0P0000020?ooo`H000000P3o
ool400000080oooo100000020?ooo`800000103oool200000080oooo0P0000020?ooo`X000000P3o
ool400000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3o
ool400000080oooo1P0000060?ooo`@0000000<0oooo0000000000000P3oool200000080oooo1000
00020?ooo`@00000303oool200000080oooo100000060?ooo`8000000P3oool6000000@0oooo1000
00040?ooo`l0dLfY000=0=7=Z@H0oooo0P0000020?ooo`X00000103oool:00000080oooo0P000004
0?ooo`@000000P3oool200000080oooo100000020?ooo`@000000P3oool3000000@0oooo10000004
0?ooo`@000001P3oool2000000@0oooo1P0000020?ooo`@000000P3oool400000080oooo10000002
0?ooo`8000000P3oool2000000H0oooo100000060?ooo`H000004P3oool<00000080oooo10000002
0?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool01P0000060?ooo`H00000103oool4
000000P0oooo100000040?ooo`@000001P3oool200000080oooo0P0000020?ooo`@000000P3oool2
00000080oooo0P0000040?ooo`8000001P3oool200000080oooo0P0000020?ooo`8000000P3oool2
00000080oooo0P0000020?ooo`8000000P3oool2000000H0oooo0P00000:0?ooo`80000000<0oooo
0000000000000P3oool200000080oooo0P0000060?ooo`8000000P3oool<00000080oooo0P00000:
0?ooo`@00000103oool6000000H0oooo3`3AcJT000d0dLfY200000020?ooo`800000103oool20000
00P0oooo0P0000040?ooo`8000000P3oool200000080oooo100000060?ooo`@000001P3oool20000
0080oooo0P0000070?ooo`8000000P3oool4000000X0oooo1P0000040?ooo`@000001P3oool20000
0080oooo0P0000060?ooo`@000000P3oool6000000X0oooo0P00000F0?ooo`800000103oool20000
00H0oooo0P0000020?ooo`8000000P3oool400000080oooo0`0000020?ooo`800000103oool80000
00@0oooo1P00000<0?ooo`8000000P3oool4000000X0oooo100000020?ooo`8000001P3oool40000
0080oooo100000020?ooo`H000000P3oool200000080oooo0P0000020?ooo`8000000P3oool20000
0080oooo0P0000020?ooo`8000000P3oool600000080oooo2P0000000`3oool00000000000020?oo
o`8000000P3oool200000080oooo1P0000020?ooo`800000103oool2000000@0oooo100000020?oo
o`X00000203oool2000000P0oooo3`3AcJT000d0dLfY200000020?ooo`800000103oool2000000P0
oooo0P0000040?ooo`8000000P3oool200000080oooo100000060?ooo`@000001P3oool200000080
oooo0P0000070?ooo`8000000P3oool4000000X0oooo1P0000040?ooo`@000001P3oool200000080
oooo0P0000060?ooo`@000000P3oool6000000X0oooo0P00000F0?ooo`800000103oool2000000H0
oooo0P0000020?ooo`8000000P3oool400000080oooo0`0000020?ooo`800000103oool8000000@0
oooo1P00000<0?ooo`8000000P3oool4000000X0oooo100000020?ooo`8000001P3oool400000080
oooo100000020?ooo`H000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080
oooo0P0000020?ooo`8000000P3oool600000080oooo2P0000000`3oool00000000000020?ooo`80
00000P3oool200000080oooo1P0000020?ooo`800000103oool2000000@0oooo100000020?ooo`X0
0000203oool2000000P0oooo3`3AcJT000d0dLfY0P0000040?ooo`8000000P3oool200000080oooo
100000020?ooo`P000000P3oool400000080oooo0P0000020?ooo`8000002P3oool200000080oooo
1P0000020?ooo`80000000<0oooo0000000000001P0000020?ooo`8000003P3oool2000000P0oooo
0P0000020?ooo`H000000P3oool200000080oooo1P0000060?ooo`8000003P3ooolH00000080oooo
100000020?ooo`H000000P3oool200000080oooo0P0000060?ooo`030000003oool0oooo00800000
0P3oool4000000@0oooo0P0000020?ooo`@00000103oool>00000080oooo0P00000>0?ooo`800000
0P3oool200000080oooo1P0000060?ooo`8000000P3oool2000000@0oooo100000020?ooo`800000
0P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000040?ooo`@00000
103oool2000000D0oooo100000020?ooo`8000000P3oool2000000@0oooo100000020?ooo`@00000
0P3oool4000000H0oooo0P0000040?ooo`8000000P3oool800000080oooo1P00000?0=7=Z@003@3A
cJT2000000@0oooo0P0000020?ooo`8000000P3oool400000080oooo200000020?ooo`@000000P3o
ool200000080oooo0P00000:0?ooo`8000000P3oool600000080oooo0P0000000`3oool000000000
000600000080oooo0P00000>0?ooo`800000203oool200000080oooo1P0000020?ooo`8000000P3o
ool6000000H0oooo0P00000>0?oooaP000000P3oool400000080oooo1P0000020?ooo`8000000P3o
ool2000000H0oooo00<000000?ooo`3oool00P0000020?ooo`@00000103oool200000080oooo1000
00040?ooo`h000000P3oool2000000h0oooo0P0000020?ooo`8000000P3oool6000000H0oooo0P00
00020?ooo`800000103oool400000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P00
00020?ooo`8000000P3oool2000000@0oooo100000040?ooo`8000001@3oool400000080oooo0P00
00020?ooo`800000103oool400000080oooo100000020?ooo`@000001P3oool2000000@0oooo0P00
00020?ooo`P000000P3oool6000000l0dLfY000=0=7=Z@80oooo1P0000020?ooo`8000000P3oool2
000000H0oooo0P0000040?ooo`@000001P3oool400000080oooo2P0000020?ooo`800000103oool4
000000030?ooo`000000000000@0oooo0P0000020?ooo`8000000P3oool>00000080oooo20000002
0?ooo`800000103oool400000080oooo0P0000040?ooo`P000000P3oool>000000@0oooo0P000004
0?ooo`800000103oool2000000@0oooo100000060?ooo`8000001P3oool400000080oooo1@000002
0?ooo`8000000P3oool2000000P0oooo100000080?ooo`800000103oool2000000@0oooo10000002
0?ooo`h000000P3oool200000080oooo0P0000040?ooo`P000000P3oool200000080oooo10000006
0?ooo`@000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo10000008
0?ooo`L000001P3oool400000080oooo100000060?ooo`8000000P3oool2000000X0oooo1P000002
0?ooo`800000103oool200000080oooo0P0000040?ooo`l0dLfY000=0=7=Z@80oooo1P0000020?oo
o`8000000P3oool2000000H0oooo0P0000040?ooo`@000001P3oool400000080oooo2P0000020?oo
o`800000103oool4000000030?ooo`000000000000@0oooo0P0000020?ooo`8000000P3oool>0000
0080oooo200000020?ooo`800000103oool400000080oooo0P0000040?ooo`P000000P3oool>0000
00@0oooo0P0000040?ooo`800000103oool2000000@0oooo100000060?ooo`8000001P3oool40000
0080oooo1@0000020?ooo`8000000P3oool2000000P0oooo100000080?ooo`800000103oool20000
00@0oooo100000020?ooo`h000000P3oool200000080oooo0P0000040?ooo`P000000P3oool20000
0080oooo100000060?ooo`@000000P3oool200000080oooo0P0000020?ooo`8000000P3oool20000
0080oooo100000080?ooo`L000001P3oool400000080oooo100000060?ooo`8000000P3oool20000
00X0oooo1P0000020?ooo`800000103oool200000080oooo0P0000040?ooo`l0dLfY000=0=7=Z@@0
0000103oool400000080oooo0P0000020?ooo`H000000P3oool4000000X0oooo0P0000020?ooo`80
0000103oool2000000H0oooo1P0000050?ooo`H000000P3oool200000080oooo0P0000040?ooo`80
0000103oool200000080oooo0P0000040?ooo`8000000P3oool200000080oooo100000060?ooo`H0
0000103oool200000080oooo0P0000040?ooo`800000103oool200000080oooo100000020?ooo`@0
00000P3oool400000080oooo1000000:0?ooo`P000001P3oool2000000D0oooo100000020?ooo`P0
0000303oool600000080oooo100000060?ooo`800000103oool2000000@0oooo100000020?ooo`80
00000P3oool4000000@0oooo0P0000020?ooo`8000000P3oool2000000X0oooo0P0000020?ooo`80
00000P3oool200000080oooo0P0000020?ooo`8000000P3oool2000000`0oooo00<000000?ooo`3o
ool00P3oool8000000H0oooo0P0000020?ooo`H000000P3oool200000080oooo2P0000040?ooo`@0
00000P3oool400000080oooo0P0000020?ooo`8000003`3AcJT000d0dLfY100000040?ooo`@00000
0P3oool200000080oooo1P0000020?ooo`@000002P3oool200000080oooo0P0000040?ooo`800000
1P3oool6000000D0oooo1P0000020?ooo`8000000P3oool2000000@0oooo0P0000040?ooo`800000
0P3oool2000000@0oooo0P0000020?ooo`8000000P3oool4000000H0oooo1P0000040?ooo`800000
0P3oool2000000@0oooo0P0000040?ooo`8000000P3oool400000080oooo100000020?ooo`@00000
0P3oool4000000X0oooo200000060?ooo`8000001@3oool400000080oooo2000000<0?ooo`H00000
0P3oool4000000H0oooo0P0000040?ooo`800000103oool400000080oooo0P0000020?ooo`@00000
103oool200000080oooo0P0000020?ooo`8000002P3oool200000080oooo0P0000020?ooo`800000
0P3oool200000080oooo0P0000020?ooo`800000303oool00`000000oooo0?ooo`020?ooo`P00000
1P3oool200000080oooo1P0000020?ooo`8000000P3oool:000000@0oooo100000020?ooo`@00000
0P3oool200000080oooo0P00000?0=7=Z@003@3AcJT20?ooo`8000000P3oool4000000H0oooo1000
00040?ooo`@000003P3oool400000080oooo100000020?ooo`H00000103oool7000000@0oooo1000
00020?ooo`8000000P3oool400000080oooo100000020?ooo`8000000P3oool400000080oooo0P00
00020?ooo`8000002P3oool2000000P0oooo100000020?ooo`@000000P3oool400000080oooo0P00
00060?ooo`8000000P3oool2000000H0oooo0P0000020?ooo`X00000103oool200000080oooo1P00
00000`3oool0000000000004000000H0oooo0P0000040?ooo`h00000103oool4000000X0oooo1P00
00020?ooo`@000001P3oool4000000P0oooo100000020?ooo`8000000P3oool:00000080oooo0P00
00020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool;00000080oooo1000
00040?ooo`8000000P3oool600000080oooo0P0000040?ooo`@000000P3oool2000000@0oooo0P00
00080?ooo`8000000P3oool2000000H0oooo1000000?0=7=Z@003@3AcJT20?ooo`8000000P3oool4
000000H0oooo100000040?ooo`@000003P3oool400000080oooo100000020?ooo`H00000103oool7
000000@0oooo100000020?ooo`8000000P3oool400000080oooo100000020?ooo`8000000P3oool4
00000080oooo0P0000020?ooo`8000002P3oool2000000P0oooo100000020?ooo`@000000P3oool4
00000080oooo0P0000060?ooo`8000000P3oool2000000H0oooo0P0000020?ooo`X00000103oool2
00000080oooo1P0000000`3oool0000000000004000000H0oooo0P0000040?ooo`h00000103oool4
000000X0oooo1P0000020?ooo`@000001P3oool4000000P0oooo100000020?ooo`8000000P3oool:
00000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool;
00000080oooo100000040?ooo`8000000P3oool600000080oooo0P0000040?ooo`@000000P3oool2
000000@0oooo0P0000080?ooo`8000000P3oool2000000H0oooo1000000?0=7=Z@003@3AcJT40000
0080oooo0P00000:0?ooo`8000000P3oool400000180oooo0P0000020?ooo`8000001P3oool20000
00P0oooo00<000000?ooo`3oool00P3oool6000000H0oooo100000060?ooo`8000000P3oool20000
0080oooo0P0000060?ooo`@000000P3oool:00000080oooo200000060?ooo`8000000P3oool20000
00H0oooo200000020?ooo`8000000P3oool600000080oooo0P0000040?ooo`800000203oool40000
00@0oooo0`0000040?ooo`P000000P3oool4000000@0oooo0P0000040?ooo`8000000P3oool40000
00h0oooo0P0000060?ooo`8000000P3oool6000000`0oooo0P0000020?ooo`8000000P3oool20000
00@0oooo0P0000060?ooo`@000000P3oool200000080oooo0P0000020?ooo`8000000P3oool20000
00@0oooo0P0000030?ooo`@00000203oool4000000@0oooo100000020?ooo`@000001P3oool60000
0080oooo200000020?ooo`8000000P3oool600000080oooo3`3AcJT000d0dLfY100000020?ooo`80
00002P3oool200000080oooo1000000B0?ooo`8000000P3oool2000000H0oooo0P0000080?ooo`03
0000003oool0oooo0080oooo1P0000060?ooo`@000001P3oool200000080oooo0P0000020?ooo`80
00001P3oool400000080oooo2P0000020?ooo`P000001P3oool200000080oooo0P0000060?ooo`P0
00000P3oool200000080oooo1P0000020?ooo`800000103oool2000000P0oooo100000040?ooo`<0
0000103oool800000080oooo100000040?ooo`800000103oool200000080oooo1000000>0?ooo`80
00001P3oool200000080oooo1P00000<0?ooo`8000000P3oool200000080oooo0P0000040?ooo`80
00001P3oool400000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000040?ooo`80
00000`3oool4000000P0oooo100000040?ooo`@000000P3oool4000000H0oooo1P0000020?ooo`P0
00000P3oool200000080oooo1P0000020?ooo`l0dLfY000=0=7=Z@@0oooo100000020?ooo`X00000
0P3oool2000001H0oooo100000020?ooo`H000000P3oool700000080oooo100000040?ooo`P00000
2P3oool400000080oooo0P0000020?ooo`H000001P3oool2000000@0oooo0P0000020?ooo`800000
103oool200000080oooo1P0000020?ooo`8000000P3oool6000000@0oooo0P0000020?ooo`800000
0P3oool2000000@0oooo100000020?ooo`@000000P3oool8000000L0oooo0P0000020?ooo`@00000
103oool200000080oooo0P0000080?ooo`H000000P3oool200000180oooo200000020?ooo`800000
103oool>00000080oooo0P0000020?ooo`8000000P3oool400000080oooo1P0000060?ooo`@00000
0P3oool200000080oooo0P0000020?ooo`@000000P3oool3000000`0oooo0P0000020?ooo`@00000
1P3oool200000080oooo1P0000040?ooo`@00000103oool200000080oooo0P0000020?ooo`800000
103oool2000000l0dLfY000=0=7=Z@@0oooo100000020?ooo`X000000P3oool2000001H0oooo1000
00020?ooo`H000000P3oool700000080oooo100000040?ooo`P000002P3oool400000080oooo0P00
00020?ooo`H000001P3oool2000000@0oooo0P0000020?ooo`800000103oool200000080oooo1P00
00020?ooo`8000000P3oool6000000@0oooo0P0000020?ooo`8000000P3oool2000000@0oooo1000
00020?ooo`@000000P3oool8000000L0oooo0P0000020?ooo`@00000103oool200000080oooo0P00
00080?ooo`H000000P3oool200000180oooo200000020?ooo`800000103oool>00000080oooo0P00
00020?ooo`8000000P3oool400000080oooo1P0000060?ooo`@000000P3oool200000080oooo0P00
00020?ooo`@000000P3oool3000000`0oooo0P0000020?ooo`@000001P3oool200000080oooo1P00
00040?ooo`@00000103oool200000080oooo0P0000020?ooo`800000103oool2000000l0dLfY000=
0=7=Z@80oooo100000060?ooo`800000103oool200000080oooo0P0000020?oooaH000001P3oool2
000000H0oooo0P0000030?ooo`@00000203oool2000000@0oooo300000060?ooo`@00000103oool8
00000080oooo100000020?ooo`8000000P3oool400000080oooo0P0000040?ooo`@000000P3oool2
000000@0oooo1P0000020?ooo`8000000P3oool200000080oooo100000060?ooo`8000000P3oool2
000000@0oooo0P0000020?ooo`L000000P3oool2000000P0oooo100000020?ooo`P00000103oool4
00000080oooo4P0000040?ooo`8000000P3oool200000080oooo100000040?ooo`800000103oool2
00000080oooo0P0000020?ooo`8000000P3oool2000000H0oooo0P00000:0?ooo`8000000P3oool2
00000080oooo0P0000020?ooo`8000001@3oool200000080oooo300000020?ooo`8000002P3oool4
000000@0oooo1P0000080?ooo`@000000P3oool200000080oooo1000000?0=7=Z@003@3AcJT20?oo
o`@000001P3oool2000000@0oooo0P0000020?ooo`8000000P3ooolF000000H0oooo0P0000060?oo
o`8000000`3oool4000000P0oooo0P0000040?ooo``000001P3oool4000000@0oooo200000020?oo
o`@000000P3oool200000080oooo100000020?ooo`800000103oool400000080oooo0P0000040?oo
o`H000000P3oool200000080oooo0P0000020?ooo`@000001P3oool200000080oooo0P0000040?oo
o`8000000P3oool700000080oooo0P0000080?ooo`@000000P3oool8000000@0oooo100000020?oo
oa800000103oool200000080oooo0P0000020?ooo`@00000103oool2000000@0oooo0P0000020?oo
o`8000000P3oool200000080oooo0P0000060?ooo`8000002P3oool200000080oooo0P0000020?oo
o`8000000P3oool2000000D0oooo0P0000020?ooo``000000P3oool2000000X0oooo100000040?oo
o`H00000203oool400000080oooo0P0000020?ooo`@000003`3AcJT000d0dLfY103oool200000080
oooo1P0000020?ooo`@000000P3oool200000080oooo0P0000040?ooo`800000103oool2000000@0
oooo0P00000:0?ooo`P000000P3oool3000000`0oooo1P0000040?ooo`800000103oool8000000P0
oooo0P0000040?ooo`@000001P3oool4000000H0oooo1P0000060?ooo`H00000103oool400000080
oooo0P0000020?ooo`8000002P3oool400000080oooo100000020?ooo`8000000`3oool200000080
oooo0P0000020?ooo`P000001P3oool2000000@0oooo1P0000060?ooo`800000103oool2000000@0
oooo0P0000080?ooo`@000000P3oool2000000P0oooo1P0000020?ooo`8000000P3oool200000080
oooo0P0000020?ooo`H000000P3oool:00000080oooo0P0000020?ooo`8000000P3oool200000080
oooo1@0000020?ooo`800000103oool2000000@0oooo100000020?ooo`X00000203oool2000000`0
oooo0P0000020?ooo`8000000P3oool200000080oooo3`3AcJT000d0dLfY103oool200000080oooo
1P0000020?ooo`@000000P3oool200000080oooo0P0000040?ooo`800000103oool2000000@0oooo
0P00000:0?ooo`P000000P3oool3000000`0oooo1P0000040?ooo`800000103oool8000000P0oooo
0P0000040?ooo`@000001P3oool4000000H0oooo1P0000060?ooo`H00000103oool400000080oooo
0P0000020?ooo`8000002P3oool400000080oooo100000020?ooo`8000000`3oool200000080oooo
0P0000020?ooo`P000001P3oool2000000@0oooo1P0000060?ooo`800000103oool2000000@0oooo
0P0000080?ooo`@000000P3oool2000000P0oooo1P0000020?ooo`8000000P3oool200000080oooo
0P0000020?ooo`H000000P3oool:00000080oooo0P0000020?ooo`8000000P3oool200000080oooo
1@0000020?ooo`800000103oool2000000@0oooo100000020?ooo`X00000203oool2000000`0oooo
0P0000020?ooo`8000000P3oool200000080oooo3`3AcJT000d0dLfY1P3oool4000000@0oooo1000
00060?ooo`@000000P3oool400000080oooo100000020?ooo`@000000P3oool:000000@0oooo0P00
00020?ooo`030000003oool0oooo00h0oooo0P0000080?ooo`H00000103oool200000080oooo2000
00020?ooo`@000002P3oool200000080oooo1P0000040?ooo`P00000103oool6000000H0oooo1000
00020?ooo`X000001P3oool200000080oooo0P0000020?ooo`<000000P3oool200000080oooo0P00
00040?ooo`8000000P3oool600000080oooo100000040?ooo`P000000P3oool400000080oooo1000
00020?ooo`P000001P3oool:000000@0oooo100000020?ooo`8000000P3oool200000080oooo0P00
00040?ooo`@00000103oool2000000H0oooo100000020?ooo`8000000P3oool2000000<0oooo1000
00020?ooo`@000000P3oool4000000H0oooo0P0000040?ooo`8000000P3oool800000080oooo3000
00020?ooo`8000000P3oool200000080oooo3`3AcJT000d0dLfY1P3oool4000000@0oooo10000006
0?ooo`@000000P3oool400000080oooo100000020?ooo`@000000P3oool:000000@0oooo0P000002
0?ooo`030000003oool0oooo00h0oooo0P0000080?ooo`H00000103oool200000080oooo20000002
0?ooo`@000002P3oool200000080oooo1P0000040?ooo`P00000103oool6000000H0oooo10000002
0?ooo`X000001P3oool200000080oooo0P0000020?ooo`<000000P3oool200000080oooo0P000004
0?ooo`8000000P3oool600000080oooo100000040?ooo`P000000P3oool400000080oooo10000002
0?ooo`P000001P3oool:000000@0oooo100000020?ooo`8000000P3oool200000080oooo0P000004
0?ooo`@00000103oool2000000H0oooo100000020?ooo`8000000P3oool2000000<0oooo10000002
0?ooo`@000000P3oool4000000H0oooo0P0000040?ooo`8000000P3oool800000080oooo30000002
0?ooo`8000000P3oool200000080oooo3`3AcJT000d0dLfY200000080?ooo`8000000P3oool60000
00H0oooo0P0000020?ooo`8000001P3oool200000080oooo0P0000040?ooo`800000203oool30000
0080oooo400000020?ooo`P00000103oool600000080oooo0P0000040?ooo`8000000P3oool20000
00h0oooo100000040?ooo`H00000103oool200000080oooo100000040?ooo`P000001P3oool20000
00@0oooo0P0000020?ooo`H000000P3oool200000080oooo00<000000?ooo`3oool0103oool40000
0080oooo100000020?ooo`800000103oool4000000P0oooo0P0000040?ooo`@000001P3oool20000
0080oooo0P0000040?ooo`8000000P3oool6000000@0oooo0P0000080?ooo`8000000P3oool20000
0080oooo0P0000020?ooo`8000000P3oool4000000P0oooo200000060?ooo`@0000000<0oooo0000
000000000P0000060?ooo`8000000P3oool2000000X0oooo1P0000020?ooo`800000103oool20000
0080oooo0P0000040?ooo`800000103oool400000080oooo0P0000020?ooo`l0dLfY000=0=7=Z@P0
0000203oool200000080oooo1P0000060?ooo`8000000P3oool2000000H0oooo0P0000020?ooo`80
0000103oool2000000P0oooo0`0000020?oooa0000000P3oool8000000@0oooo1P0000020?ooo`80
0000103oool200000080oooo0P00000>0?ooo`@00000103oool6000000@0oooo0P0000020?ooo`@0
0000103oool8000000H0oooo0P0000040?ooo`8000000P3oool600000080oooo0P0000020?ooo`03
0000003oool0oooo00@0oooo100000020?ooo`@000000P3oool2000000@0oooo100000080?ooo`80
0000103oool4000000H0oooo0P0000020?ooo`800000103oool200000080oooo1P0000040?ooo`80
0000203oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo100000080?ooo`P0
00001P3oool4000000030?ooo`0000000000008000001P3oool200000080oooo0P00000:0?ooo`H0
00000P3oool2000000@0oooo0P0000020?ooo`800000103oool2000000@0oooo100000020?ooo`80
00000P3oool?0=7=Z@003@3AcJT40?ooo`800000303oool4000000@0oooo200000020?ooo`800000
0P3oool600000080oooo0P0000020?ooo`@000000P3oool8000000D0oooo0P0000040?ooo`800000
103oool200000080oooo0P0000040?ooo`8000000P3oool4000000@0oooo100000020?ooo`@00000
0P3oool200000080oooo3P0000080?ooo`800000203oool4000000P0oooo0P0000040?ooo`P00000
0P3oool400000080oooo0P0000040?ooo`@000000P3oool00`000000oooo0?ooo`06000000H0oooo
0P0000020?ooo`8000000P3oool4000000`0oooo1P00000:0?ooo`@000000P3oool400000080oooo
0P0000040?ooo`H000000P3oool800000080oooo0P0000020?ooo`8000000P3oool200000080oooo
0P00000<0?ooo`800000103oool8000000D0oooo0P0000020?ooo`H000000P3oool200000080oooo
2P0000040?ooo`@000000P3oool400000080oooo0P0000020?ooo`@000000P3oool4000000H0oooo
0P00000?0=7=Z@003@3AcJT40?ooo`800000303oool4000000@0oooo200000020?ooo`8000000P3o
ool600000080oooo0P0000020?ooo`@000000P3oool8000000D0oooo0P0000040?ooo`800000103o
ool200000080oooo0P0000040?ooo`8000000P3oool4000000@0oooo100000020?ooo`@000000P3o
ool200000080oooo3P0000080?ooo`800000203oool4000000P0oooo0P0000040?ooo`P000000P3o
ool400000080oooo0P0000040?ooo`@000000P3oool00`000000oooo0?ooo`06000000H0oooo0P00
00020?ooo`8000000P3oool4000000`0oooo1P00000:0?ooo`@000000P3oool400000080oooo0P00
00040?ooo`H000000P3oool800000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P00
000<0?ooo`800000103oool8000000D0oooo0P0000020?ooo`H000000P3oool200000080oooo2P00
00040?ooo`@000000P3oool400000080oooo0P0000020?ooo`@000000P3oool4000000H0oooo0P00
000?0=7=Z@003@3AcJT600000080oooo300000080?ooo`800000103oool400000080oooo0P000004
0?ooo`@000000P3oool2000000H0oooo0P0000040?ooo`L000000P3oool400000080oooo10000002
0?ooo`8000000P3oool400000080oooo0P0000080?ooo`8000000P3oool2000000H0oooo10000004
0?ooo`800000103oool200000080oooo200000020?ooo`P00000303oool6000000@0oooo0P000002
0?ooo`8000001P3oool6000000D0oooo100000040?ooo`P000000P3oool200000080oooo0P00000@
0?ooo`8000003P3oool200000080oooo0P0000060?ooo`H00000103oool4000000@0oooo0P000002
0?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool<00000080oooo10000004
0?ooo`8000000P3oool500000080oooo0P0000040?ooo`@000000P3oool2000000@0oooo0P000008
0?ooo`8000000P3oool2000000H0oooo100000060?ooo`8000000P3oool6000000l0dLfY000=0=7=
Z@H000000P3oool<000000P0oooo0P0000040?ooo`@000000P3oool2000000@0oooo100000020?oo
o`8000001P3oool2000000@0oooo1`0000020?ooo`@000000P3oool400000080oooo0P0000020?oo
o`@000000P3oool2000000P0oooo0P0000020?ooo`8000001P3oool4000000@0oooo0P0000040?oo
o`8000000P3oool800000080oooo2000000<0?ooo`H00000103oool200000080oooo0P0000060?oo
o`H000001@3oool4000000@0oooo200000020?ooo`8000000P3oool200000100oooo0P00000>0?oo
o`8000000P3oool2000000H0oooo1P0000040?ooo`@00000103oool200000080oooo0P0000020?oo
o`8000000P3oool200000080oooo0P0000020?ooo``000000P3oool4000000@0oooo0P0000020?oo
o`D000000P3oool2000000@0oooo100000020?ooo`800000103oool2000000P0oooo0P0000020?oo
o`8000001P3oool4000000H0oooo0P0000020?ooo`H000003`3AcJT000d0dLfY0P0000040?ooo`@0
0000103oool2000000@0oooo2P0000020?ooo`@000001P3oool6000000H0oooo200000020?ooo`<0
0000103oool200000080oooo0P0000060?ooo`8000000P3oool200000080oooo0P0000060?ooo`X0
00000P3oool200000080oooo1P0000080?ooo`H000000P3oool2000000@0oooo0P0000020?ooo`80
0000103oool200000080oooo300000040?ooo`H000000P3oool200000080oooo1P0000040?ooo`L0
0000203oool2000000@0oooo100000020?ooo`8000000P3oool@00000080oooo3P0000020?ooo`80
00000P3oool6000000@0oooo1P0000080?ooo`@000000P3oool200000080oooo0P0000020?ooo`80
00000P3oool2000000@0oooo0P0000040?ooo`@00000203oool3000000@0oooo100000020?ooo`@0
00001P3oool600000080oooo200000020?ooo`8000000P3oool6000000X0oooo100000040?ooo`l0
dLfY000=0=7=Z@800000103oool4000000@0oooo0P0000040?ooo`X000000P3oool4000000H0oooo
1P0000060?ooo`P000000P3oool3000000@0oooo0P0000020?ooo`8000001P3oool200000080oooo
0P0000020?ooo`8000001P3oool:00000080oooo0P0000020?ooo`H00000203oool600000080oooo
0P0000040?ooo`8000000P3oool2000000@0oooo0P0000020?ooo``00000103oool600000080oooo
0P0000020?ooo`H00000103oool7000000P0oooo0P0000040?ooo`@000000P3oool200000080oooo
400000020?ooo`h000000P3oool200000080oooo1P0000040?ooo`H00000203oool400000080oooo
0P0000020?ooo`8000000P3oool200000080oooo0P0000040?ooo`800000103oool4000000P0oooo
0`0000040?ooo`@000000P3oool4000000H0oooo1P0000020?ooo`P000000P3oool200000080oooo
1P00000:0?ooo`@00000103oool?0=7=Z@003@3AcJT80?ooo`8000000P3oool400000080oooo1000
00040?ooo`8000001P3oool200000080oooo1P0000040?ooo`P00000103oool200000080oooo0P00
00070?ooo`@000000P3oool600000080oooo0P0000020?ooo`8000000P3oool6000000@0oooo0P00
00060?ooo`@00000103oool:000000@0oooo100000020?ooo`@000000P3oool200000080oooo1000
00020?ooo`800000103oool2000000@0oooo1P0000040?ooo`@000000P3oool2000000@0oooo1P00
00030?ooo`8000000P3oool800000080oooo100000060?ooo`@00000103oool2000000@0oooo0P00
00060?ooo`800000103oool2000000@0oooo100000020?ooo`800000103oool6000000@0oooo2P00
00060?ooo`@000000P3oool200000080oooo0P0000020?ooo`@000000P3oool4000000`0oooo00<0
00000?ooo`3oool0100000060?ooo`8000000P3oool6000000@0oooo100000040?ooo`8000000P3o
ool200000080oooo0P0000040?ooo``000001P3oool?0=7=Z@003@3AcJT80?ooo`8000000P3oool4
00000080oooo100000040?ooo`8000001P3oool200000080oooo1P0000040?ooo`P00000103oool2
00000080oooo0P0000070?ooo`@000000P3oool600000080oooo0P0000020?ooo`8000000P3oool6
000000@0oooo0P0000060?ooo`@00000103oool:000000@0oooo100000020?ooo`@000000P3oool2
00000080oooo100000020?ooo`800000103oool2000000@0oooo1P0000040?ooo`@000000P3oool2
000000@0oooo1P0000030?ooo`8000000P3oool800000080oooo100000060?ooo`@00000103oool2
000000@0oooo0P0000060?ooo`800000103oool2000000@0oooo100000020?ooo`800000103oool6
000000@0oooo2P0000060?ooo`@000000P3oool200000080oooo0P0000020?ooo`@000000P3oool4
000000`0oooo00<000000?ooo`3oool0100000060?ooo`8000000P3oool6000000@0oooo10000004
0?ooo`8000000P3oool200000080oooo0P0000040?ooo``000001P3oool?0=7=Z@003@3AcJT20?oo
o`P000000P3oool2000000H0oooo0P0000020?ooo`@000000P3oool600000080oooo0P0000040?oo
o`H00000103oool200000080oooo100000020?ooo`80000000<0oooo0000000000001P0000060?oo
o`8000001P3oool400000080oooo0P0000040?ooo`H000000P3oool6000000P0oooo0P0000040?oo
o`8000000P3oool4000000H0oooo0P0000020?ooo`8000000P3oool2000000H0oooo1P0000020?oo
o`@00000103oool6000000H0oooo1P0000040?ooo`D000000P3oool2000000@0oooo0P0000020?oo
o`8000002P3oool200000080oooo100000020?ooo`@000000P3oool600000080oooo100000020?oo
o`@000001P3oool6000000@0oooo1P0000040?ooo`8000002P3oool200000080oooo0P0000020?oo
o`8000000P3oool2000000H0oooo0P0000020?ooo`/000000P3oool2000000X0oooo100000040?oo
o`H00000203oool400000080oooo0P0000020?ooo`@00000103oool2000000@0oooo1P00000?0=7=
Z@003@3AcJT20?ooo`P000000P3oool2000000H0oooo0P0000020?ooo`@000000P3oool600000080
oooo0P0000040?ooo`H00000103oool200000080oooo100000020?ooo`80000000<0oooo00000000
00001P0000060?ooo`8000001P3oool400000080oooo0P0000040?ooo`H000000P3oool6000000P0
oooo0P0000040?ooo`8000000P3oool4000000H0oooo0P0000020?ooo`8000000P3oool2000000H0
oooo1P0000020?ooo`@00000103oool6000000H0oooo1P0000040?ooo`D000000P3oool2000000@0
oooo0P0000020?ooo`8000002P3oool200000080oooo100000020?ooo`@000000P3oool600000080
oooo100000020?ooo`@000001P3oool6000000@0oooo1P0000040?ooo`8000002P3oool200000080
oooo0P0000020?ooo`8000000P3oool2000000H0oooo0P0000020?ooo`/000000P3oool2000000X0
oooo100000040?ooo`H00000203oool400000080oooo0P0000020?ooo`@00000103oool2000000@0
oooo1P00000?0=7=Z@003@3AcJT20?ooo`800000103oool200000080oooo0P0000020?ooo`H00000
0P3oool2000000H0oooo0P0000060?ooo`H00000103oool600000080oooo0P0000060?ooo`<00000
103oool200000080oooo1P0000020?ooo`H000001P3oool6000000@0oooo100000040?ooo`X00000
0P3oool400000080oooo0P00000:0?ooo`@000000P3oool200000080oooo1P0000040?ooo`@00000
203oool2000000X0oooo0P0000080?ooo`030000003oool0oooo00@0oooo1P0000020?ooo`800000
0P3oool:00000080oooo0P0000060?ooo`8000000P3oool2000000@0oooo100000060?ooo`800000
0P3oool6000000@0oooo1P0000040?ooo`H000000P3oool:00000080oooo0P0000020?ooo`800000
0P3oool200000080oooo1P0000020?ooo`800000103oool2000000<0oooo100000020?ooo`X00000
203oool2000000`0oooo0P0000020?ooo`8000000P3oool2000000P0oooo1P0000040?ooo`l0dLfY
000=0=7=Z@80oooo0P0000040?ooo`8000000P3oool200000080oooo1P0000020?ooo`8000001P3o
ool2000000H0oooo1P0000040?ooo`H000000P3oool2000000H0oooo0`0000040?ooo`8000000P3o
ool600000080oooo1P0000060?ooo`H00000103oool4000000@0oooo2P0000020?ooo`@000000P3o
ool2000000X0oooo100000020?ooo`8000000P3oool6000000@0oooo100000080?ooo`8000002P3o
ool2000000P0oooo00<000000?ooo`3oool0103oool600000080oooo0P0000020?ooo`X000000P3o
ool2000000H0oooo0P0000020?ooo`800000103oool4000000H0oooo0P0000020?ooo`H00000103o
ool6000000@0oooo1P0000020?ooo`X000000P3oool200000080oooo0P0000020?ooo`8000000P3o
ool600000080oooo0P0000040?ooo`8000000`3oool400000080oooo2P0000080?ooo`800000303o
ool200000080oooo0P0000020?ooo`800000203oool6000000@0oooo3`3AcJT000d0dLfY0P3oool2
00000080oooo100000020?ooo`8000000P3oool2000000@0oooo100000020?ooo`H000000P3oool6
000000@0oooo1P0000040?ooo`@000000P3oool5000000P0oooo100000040?ooo`@00000103oool8
000000@0oooo1P0000080?ooo`800000103oool200000080oooo0P0000060?ooo``000001P3oool4
000000@0oooo1P00000<0?ooo``000000P3oool700000080oooo1P0000040?ooo`@000000P3oool2
000000@0oooo0P0000060?ooo`P000000P3oool200000080oooo1000000:0?ooo`@00000103oool6
000000@0oooo1P0000040?ooo`@00000103oool2000000H0oooo100000020?ooo`8000000P3oool2
000000@0oooo100000020?ooo`@000000P3oool3000000H0oooo0P0000040?ooo`8000000P3oool8
00000080oooo300000020?ooo`8000000P3oool200000080oooo200000040?ooo`@000003`3AcJT0
00d0dLfY0P3oool200000080oooo100000020?ooo`8000000P3oool2000000@0oooo100000020?oo
o`H000000P3oool6000000@0oooo1P0000040?ooo`@000000P3oool5000000P0oooo100000040?oo
o`@00000103oool8000000@0oooo1P0000080?ooo`800000103oool200000080oooo0P0000060?oo
o``000001P3oool4000000@0oooo1P00000<0?ooo``000000P3oool700000080oooo1P0000040?oo
o`@000000P3oool2000000@0oooo0P0000060?ooo`P000000P3oool200000080oooo1000000:0?oo
o`@00000103oool6000000@0oooo1P0000040?ooo`@00000103oool2000000H0oooo100000020?oo
o`8000000P3oool2000000@0oooo100000020?ooo`@000000P3oool3000000H0oooo0P0000040?oo
o`8000000P3oool800000080oooo300000020?ooo`8000000P3oool200000080oooo200000040?oo
o`@000003`3AcJT000d0dLfY100000020?ooo`8000001P3oool400000080oooo100000060?ooo`80
00001P3oool2000000P0oooo0P0000080?ooo`8000000P3oool2000000<0oooo2P0000080?ooo`80
00000P3oool4000000@0oooo0P0000020?ooo`@00000103oool:00000080oooo100000020?ooo`80
00000P3oool6000000@0oooo0P0000040?ooo`P00000203oool200000100oooo0P0000040?ooo`80
00001P3oool2000000<0oooo100000040?ooo`H000001P3oool600000080oooo1P0000040?ooo`80
00000P3oool200000080oooo0P00000>0?ooo`8000000P3oool4000000@0oooo1P0000040?ooo`H0
0000203oool8000000H0oooo100000020?ooo`@000001P3oool200000080oooo00<000000?ooo`3o
ool0203oool600000080oooo0P0000040?ooo`8000000P3oool2000000@0oooo0P0000040?ooo`@0
00000P3oool200000080oooo0P0000040?ooo`8000000P3oool400000080oooo3`3AcJT000d0dLfY
100000020?ooo`8000001P3oool400000080oooo100000060?ooo`8000001P3oool2000000P0oooo
0P0000080?ooo`8000000P3oool2000000<0oooo2P0000080?ooo`8000000P3oool4000000@0oooo
0P0000020?ooo`@00000103oool:00000080oooo100000020?ooo`8000000P3oool6000000@0oooo
0P0000040?ooo`P00000203oool200000100oooo0P0000040?ooo`8000001P3oool2000000<0oooo
100000040?ooo`H000001P3oool600000080oooo1P0000040?ooo`8000000P3oool200000080oooo
0P00000>0?ooo`8000000P3oool4000000@0oooo1P0000040?ooo`H00000203oool8000000H0oooo
100000020?ooo`@000001P3oool200000080oooo00<000000?ooo`3oool0203oool600000080oooo
0P0000040?ooo`8000000P3oool2000000@0oooo0P0000040?ooo`@000000P3oool200000080oooo
0P0000040?ooo`8000000P3oool400000080oooo3`3AcJT000d0dLfY0P0000060?ooo`P000001P3o
ool200000080oooo1P0000020?ooo`H000000P3oool800000080oooo200000020?ooo`8000000P3o
ool3000000@0oooo0P00000<0?ooo`@00000203oool4000000P0oooo0P0000040?ooo`8000000P3o
ool2000000H0oooo100000040?ooo`H000000P3oool4000000@0oooo0P0000020?ooo`P000000P3o
ool@00000080oooo100000020?ooo`H000000P3oool3000000P0oooo0P00000:0?ooo`8000001P3o
ool2000000P0oooo100000020?ooo`8000000P3oool>00000080oooo0P0000080?ooo`800000203o
ool2000000`0oooo0P0000040?ooo`P000001P3oool200000080oooo1P0000020?ooo`030000003o
ool0oooo00X00000103oool400000080oooo100000020?ooo`8000000P3oool400000080oooo1000
00060?ooo`@000000P3oool400000080oooo0P0000040?ooo`l0dLfY000=0=7=Z@8000001P3oool8
000000H0oooo0P0000020?ooo`H000000P3oool600000080oooo200000020?ooo`P000000P3oool2
00000080oooo0`0000040?ooo`800000303oool4000000P0oooo100000080?ooo`800000103oool2
00000080oooo0P0000060?ooo`@00000103oool600000080oooo100000040?ooo`8000000P3oool8
00000080oooo400000020?ooo`@000000P3oool600000080oooo0`0000080?ooo`8000002P3oool2
000000H0oooo0P0000080?ooo`@000000P3oool200000080oooo3P0000020?ooo`800000203oool2
000000P0oooo0P00000<0?ooo`800000103oool8000000H0oooo0P0000020?ooo`H000000P3oool0
0`000000oooo0?ooo`0:000000@0oooo100000020?ooo`@000000P3oool200000080oooo10000002
0?ooo`@000001P3oool400000080oooo100000020?ooo`800000103oool?0=7=Z@003@3AcJT20000
0080oooo1P0000040?ooo`8000000P3oool600000080oooo0P0000040?ooo`@00000103oool40000
00@0oooo0P0000020?ooo`800000103oool200000080oooo0P0000020?ooo`030000003oool0oooo
00H0oooo3P00000<0?ooo`8000000P3oool800000080oooo100000020?ooo`8000000P3oool60000
00P0oooo0P0000060?ooo`8000000P3oool400000080oooo0P0000040?ooo`8000000P3oool20000
00@0oooo0P0000040?ooo`8000001P3oool200000080oooo0P0000040?ooo`<00000303oool<0000
0080oooo1P0000020?ooo`P000001P3oool4000000@0oooo0P0000040?ooo`8000000P3oool20000
0080oooo200000020?ooo`P000000P3oool<00000080oooo100000040?ooo`8000000P3oool60000
0080oooo0P0000040?ooo`<000000P3oool2000000@0oooo0P0000080?ooo`8000000P3oool20000
00H0oooo100000060?ooo`8000000P3oool6000000H0oooo0P0000020?ooo`8000000P3oool20000
00l0dLfY000=0=7=Z@8000000P3oool6000000@0oooo0P0000020?ooo`H000000P3oool2000000@0
oooo100000040?ooo`@00000103oool200000080oooo0P0000040?ooo`8000000P3oool200000080
oooo00<000000?ooo`3oool01P3oool>000000`0oooo0P0000020?ooo`P000000P3oool400000080
oooo0P0000020?ooo`H00000203oool2000000H0oooo0P0000020?ooo`@000000P3oool2000000@0
oooo0P0000020?ooo`800000103oool2000000@0oooo0P0000060?ooo`8000000P3oool2000000@0
oooo0`00000<0?ooo``000000P3oool600000080oooo200000060?ooo`@00000103oool2000000@0
oooo0P0000020?ooo`8000000P3oool800000080oooo200000020?ooo``000000P3oool4000000@0
oooo0P0000020?ooo`H000000P3oool2000000@0oooo0`0000020?ooo`800000103oool2000000P0
oooo0P0000020?ooo`8000001P3oool4000000H0oooo0P0000020?ooo`H000001P3oool200000080
oooo0P0000020?ooo`8000003`3AcJT000d0dLfY0P3oool4000000@0oooo1P0000020?ooo`800000
103oool400000080oooo100000080?ooo`8000000P3oool400000080oooo0P0000020?ooo`@00000
0P3oool200000080oooo00<000000?ooo`3oool0200000040?ooo`800000103oool200000080oooo
300000020?ooo`800000103oool200000080oooo0P0000060?ooo`@00000103oool:00000080oooo
1P0000020?ooo`8000001P3oool600000080oooo0P0000020?ooo`@000000P3oool400000080oooo
1P0000020?ooo`8000000P3oool4000000l0oooo0P0000040?ooo`8000001P3oool2000000H0oooo
0P0000040?ooo`P00000203oool600000080oooo0P0000020?ooo`800000103oool200000080oooo
0P0000040?ooo`8000000P3oool2000000@0oooo0P0000040?ooo`@00000203oool4000000@0oooo
100000020?ooo`@000001@3oool600000080oooo200000020?ooo`8000000P3oool6000000X0oooo
100000040?ooo`P000000P3oool200000080oooo0P00000?0=7=Z@003@3AcJT20?ooo`@00000103o
ool600000080oooo0P0000040?ooo`@000000P3oool4000000P0oooo0P0000020?ooo`@000000P3o
ool200000080oooo100000020?ooo`8000000P3oool00`000000oooo0?ooo`08000000@0oooo0P00
00040?ooo`8000000P3oool<00000080oooo0P0000040?ooo`8000000P3oool2000000H0oooo1000
00040?ooo`X000000P3oool600000080oooo0P0000060?ooo`H000000P3oool200000080oooo1000
00020?ooo`@000000P3oool600000080oooo0P0000020?ooo`@000003`3oool2000000@0oooo0P00
00060?ooo`8000001P3oool2000000@0oooo200000080?ooo`H000000P3oool200000080oooo0P00
00040?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`800000103oool2000000@0oooo1000
00080?ooo`@00000103oool400000080oooo100000050?ooo`H000000P3oool800000080oooo0P00
00020?ooo`H000002P3oool4000000@0oooo200000020?ooo`8000000P3oool2000000l0dLfY000=
0=7=Z@@00000203oool2000000H0oooo1P0000060?ooo`8000000P3oool800000080oooo0P000006
0?ooo`@000001P3oool300000080oooo0P0000040?ooo`8000000P3oool400000080oooo10000002
0?ooo`800000103oool2000000@0oooo100000020?ooo`@000000P3oool200000080oooo1P000008
0?ooo`800000103oool200000080oooo0P0000040?ooo`@000000P3oool6000000@0oooo10000002
0?ooo`8000001P3oool200000080oooo0P0000040?ooo`@000000P3oool2000001<0oooo1P000002
0?ooo`H000000P3oool600000080oooo100000040?ooo`8000000P3oool8000000@0oooo10000002
0?ooo`8000000P3oool400000080oooo0P0000020?ooo`@000000P3oool200000080oooo10000002
0?ooo`@00000303oool200000080oooo100000060?ooo`80000000<0oooo00000000000010000004
0?ooo`@00000103oool200000080oooo0P0000020?ooo`800000103oool<000000P0oooo0P000004
0?ooo`@000000P3oool2000000l0dLfY000=0=7=Z@@00000203oool2000000H0oooo1P0000060?oo
o`8000000P3oool800000080oooo0P0000060?ooo`@000001P3oool300000080oooo0P0000040?oo
o`8000000P3oool400000080oooo100000020?ooo`800000103oool2000000@0oooo100000020?oo
o`@000000P3oool200000080oooo1P0000080?ooo`800000103oool200000080oooo0P0000040?oo
o`@000000P3oool6000000@0oooo100000020?ooo`8000001P3oool200000080oooo0P0000040?oo
o`@000000P3oool2000001<0oooo1P0000020?ooo`H000000P3oool600000080oooo100000040?oo
o`8000000P3oool8000000@0oooo100000020?ooo`8000000P3oool400000080oooo0P0000020?oo
o`@000000P3oool200000080oooo100000020?ooo`@00000303oool200000080oooo100000060?oo
o`80000000<0oooo000000000000100000040?ooo`@00000103oool200000080oooo0P0000020?oo
o`800000103oool<000000P0oooo0P0000040?ooo`@000000P3oool2000000l0dLfY000=0=7=Z@80
0000303oool8000000@0oooo200000020?ooo`800000103oool200000080oooo0P0000020?ooo`H0
00002P3oool00`000000oooo0?ooo`0200000080oooo100000020?ooo`8000001P3oool200000080
oooo0P0000020?ooo`@000000P3oool4000000H0oooo0P0000020?ooo`8000000P3oool2000000@0
oooo2P0000020?ooo`@000000P3oool200000080oooo100000060?ooo`800000203oool200000080
oooo0P0000020?ooo`H000000P3oool200000080oooo100000060?oooaD00000103oool4000000@0
oooo100000040?ooo`@00000203oool4000000@0oooo0P0000020?ooo`@000001P3oool4000000H0
oooo100000060?ooo`@000001P3oool200000080oooo300000020?ooo`8000002P3oool3000000@0
oooo1P0000080?ooo`@000000P3oool200000080oooo100000040?ooo`800000103oool:00000080
oooo100000060?ooo`l0dLfY000=0=7=Z@800000303oool8000000@0oooo200000020?ooo`800000
103oool200000080oooo0P0000020?ooo`H000002P3oool00`000000oooo0?ooo`0200000080oooo
100000020?ooo`8000001P3oool200000080oooo0P0000020?ooo`@000000P3oool4000000H0oooo
0P0000020?ooo`8000000P3oool2000000@0oooo2P0000020?ooo`@000000P3oool200000080oooo
100000060?ooo`800000203oool200000080oooo0P0000020?ooo`H000000P3oool200000080oooo
100000060?oooaD00000103oool4000000@0oooo100000040?ooo`@00000203oool4000000@0oooo
0P0000020?ooo`@000001P3oool4000000H0oooo100000060?ooo`@000001P3oool200000080oooo
300000020?ooo`8000002P3oool3000000@0oooo1P0000080?ooo`@000000P3oool200000080oooo
100000040?ooo`800000103oool:00000080oooo100000060?ooo`l0dLfY000=0=7=Z@8000000P3o
ool<000000@0oooo0P0000020?ooo`@00000103oool200000080oooo0P0000020?ooo`@000000P3o
ool200000080oooo0P0000040?ooo`/000000P3oool200000080oooo0P0000060?ooo`P000000P3o
ool200000080oooo0P0000060?ooo`8000000P3oool600000080oooo0P0000020?ooo`8000000P3o
ool4000000@0oooo0P0000060?ooo`8000000P3oool200000080oooo0P00000:0?ooo`X000000P3o
ool200000080oooo0P0000040?ooo`@000000P3oool2000000X0oooo00<000000?ooo`3oool00P3o
ool2000000@0oooo0P0000040?ooo`8000000P3oool4000000P0oooo0P0000020?ooo`@00000303o
ool200000080oooo100000020?ooo`8000002P3oool200000080oooo1P00000:0?ooo`8000000P3o
ool600000080oooo0P0000040?ooo`800000103oool400000080oooo2@0000080?ooo`800000303o
ool200000080oooo0P0000020?ooo`800000203oool6000000@0oooo0P0000060?ooo`8000000P3o
ool4000000l0dLfY000=0=7=Z@8000000P3oool<000000@0oooo0P0000020?ooo`@00000103oool2
00000080oooo0P0000020?ooo`@000000P3oool200000080oooo0P0000040?ooo`/000000P3oool2
00000080oooo0P0000060?ooo`P000000P3oool200000080oooo0P0000060?ooo`8000000P3oool6
00000080oooo0P0000020?ooo`8000000P3oool4000000@0oooo0P0000060?ooo`8000000P3oool2
00000080oooo0P00000:0?ooo`X000000P3oool200000080oooo0P0000040?ooo`@000000P3oool2
000000X0oooo00<000000?ooo`3oool00P3oool2000000@0oooo0P0000040?ooo`8000000P3oool4
000000P0oooo0P0000020?ooo`@00000303oool200000080oooo100000020?ooo`8000002P3oool2
00000080oooo1P00000:0?ooo`8000000P3oool600000080oooo0P0000040?ooo`800000103oool4
00000080oooo2@0000080?ooo`800000303oool200000080oooo0P0000020?ooo`800000203oool6
000000@0oooo0P0000060?ooo`8000000P3oool4000000l0dLfY000=0=7=Z@8000000P3oool20000
00@0oooo0P0000040?ooo`H000000P3oool2000000P0oooo100000020?ooo`8000001P3oool40000
0080oooo100000040?ooo`8000000`3oool400000080oooo0P0000020?ooo`H00000103oool20000
0080oooo0P0000020?ooo`8000000P3oool600000080oooo0P0000040?ooo`@000000P3oool20000
0080oooo0P0000080?ooo`P000000P3oool200000080oooo0P0000020?ooo`X00000103oool20000
00H0oooo100000020?ooo`@000001P3oool;00000080oooo100000020?ooo`@000000P3oool40000
0080oooo0P00000<0?ooo`@00000403oool4000000H0oooo300000020?ooo`800000103oool<0000
0080oooo0P0000040?ooo`@000000P3oool400000080oooo100000060?ooo`800000103oool00`00
0000oooo0?ooo`0800000080oooo300000020?ooo`8000000P3oool200000080oooo200000040?oo
o`H000000P3oool600000080oooo0P0000020?ooo`l0dLfY000=0=7=Z@8000000P3oool2000000@0
oooo0P0000040?ooo`H000000P3oool2000000P0oooo100000020?ooo`8000001P3oool400000080
oooo100000040?ooo`8000000`3oool400000080oooo0P0000020?ooo`H00000103oool200000080
oooo0P0000020?ooo`8000000P3oool600000080oooo0P0000040?ooo`@000000P3oool200000080
oooo0P0000080?ooo`P000000P3oool200000080oooo0P0000020?ooo`X00000103oool2000000H0
oooo100000020?ooo`@000001P3oool;00000080oooo100000020?ooo`@000000P3oool400000080
oooo0P00000<0?ooo`@00000403oool4000000H0oooo300000020?ooo`800000103oool<00000080
oooo0P0000040?ooo`@000000P3oool400000080oooo100000060?ooo`800000103oool00`000000
oooo0?ooo`0800000080oooo300000020?ooo`8000000P3oool200000080oooo200000040?ooo`H0
00000P3oool600000080oooo0P0000020?ooo`l0dLfY000=0=7=Z@8000000P3oool200000080oooo
100000020?ooo`@00000103oool400000080oooo200000060?ooo`P000001P3oool200000080oooo
100000020?ooo`<000001P3oool4000000@0oooo1P0000020?ooo`8000000P3oool200000080oooo
0P0000040?ooo`@000000P3oool4000000H0oooo100000020?ooo`P00000103oool200000080oooo
0P0000020?ooo`8000000P3oool2000000@0oooo0P0000080?ooo`P000001P3oool200000080oooo
1P0000040?ooo`8000000`3oool4000000H0oooo0P0000020?ooo`8000001P3oool>000001@0oooo
0P0000020?ooo`H00000103oool2000000@0oooo100000020?ooo`@00000103oool2000000@0oooo
100000020?ooo`@000001P3oool200000080oooo0P00000:0?ooo`D000000P3oool2000000@0oooo
0P0000020?ooo`800000103oool2000000@0oooo100000020?ooo`8000000P3oool2000000@0oooo
0P0000020?ooo`@00000103oool4000000@0oooo100000020?ooo`l0dLfY000=0=7=Z@8000000P3o
ool200000080oooo100000020?ooo`@00000103oool400000080oooo200000060?ooo`P000001P3o
ool200000080oooo100000020?ooo`<000001P3oool4000000@0oooo1P0000020?ooo`8000000P3o
ool200000080oooo0P0000040?ooo`@000000P3oool4000000H0oooo100000020?ooo`P00000103o
ool200000080oooo0P0000020?ooo`8000000P3oool2000000@0oooo0P0000080?ooo`P000001P3o
ool200000080oooo1P0000040?ooo`8000000`3oool4000000H0oooo0P0000020?ooo`8000001P3o
ool>000001@0oooo0P0000020?ooo`H00000103oool2000000@0oooo100000020?ooo`@00000103o
ool2000000@0oooo100000020?ooo`@000001P3oool200000080oooo0P00000:0?ooo`D000000P3o
ool2000000@0oooo0P0000020?ooo`800000103oool2000000@0oooo100000020?ooo`8000000P3o
ool2000000@0oooo0P0000020?ooo`@00000103oool4000000@0oooo100000020?ooo`l0dLfY000=
0=7=Z@8000000P3oool200000080oooo0P0000060?ooo`8000000P3oool4000000H0oooo0P000004
0?ooo`P00000103oool200000080oooo1P0000020?ooo`8000001@3oool200000080oooo1P000008
0?ooo`8000001P3oool400000080oooo0P0000020?ooo`@000001P3oool200000080oooo1P000006
0?ooo`800000103oool600000080oooo0P0000020?ooo`8000000P3oool200000080oooo10000002
0?ooo`P00000103oool200000080oooo1P0000020?ooo`800000103oool600000080oooo0`00000:
0?ooo`@000000P3oool6000000@0oooo0P0000040?ooo`8000000P3ooolD00000080oooo0P000004
0?ooo`H000000P3oool4000000H0oooo0P0000020?ooo`@000000P3oool4000000H0oooo0P000002
0?ooo`H000000P3oool200000080oooo2P0000030?ooo`@000000P3oool400000080oooo0P000002
0?ooo`@000000P3oool4000000H0oooo100000020?ooo`@000000P3oool2000000P0oooo0P000002
0?ooo`@00000103oool?0=7=Z@003@3AcJT200000080oooo0P0000020?ooo`8000001P3oool20000
0080oooo100000060?ooo`800000103oool8000000@0oooo0P0000020?ooo`H000000P3oool20000
00D0oooo0P0000020?ooo`H00000203oool2000000H0oooo100000020?ooo`8000000P3oool40000
00H0oooo0P0000020?ooo`H000001P3oool2000000@0oooo1P0000020?ooo`8000000P3oool20000
0080oooo0P0000020?ooo`@000000P3oool8000000@0oooo0P0000020?ooo`H000000P3oool20000
00@0oooo1P0000020?ooo`<000002P3oool400000080oooo1P0000040?ooo`800000103oool20000
0080oooo500000020?ooo`800000103oool600000080oooo100000060?ooo`8000000P3oool40000
0080oooo100000060?ooo`8000000P3oool600000080oooo0P0000020?ooo`X000000`3oool40000
0080oooo100000020?ooo`8000000P3oool400000080oooo100000060?ooo`@000000P3oool40000
0080oooo0P0000080?ooo`8000000P3oool4000000@0oooo3`3AcJT000d0dLfY0P3oool400000080
oooo0P0000020?ooo`H000000P3oool2000000X0oooo1P0000040?ooo`8000000P3oool400000080
oooo0P0000040?ooo`@000000P3oool500000080oooo0P0000040?ooo`X000000P3oool6000000H0
oooo1000000:0?ooo`@00000103oool800000080oooo100000040?ooo`@000000P3oool200000080
oooo0P0000020?ooo`8000001P3oool2000000@0oooo1P0000020?ooo`800000103oool400000080
oooo100000040?ooo`<000003P3oool200000080oooo0P0000040?ooo`H000000P3oool400000080
oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000020?ooo`8000000P3oool4000000@0
oooo1000000:0?ooo`@000001P3oool200000080oooo1P0000020?ooo`800000103oool400000080
oooo0P0000040?ooo`8000001`3oool200000080oooo0P0000060?ooo`@000001P3oool200000080
oooo1P0000060?ooo`8000000P3oool200000080oooo200000020?ooo`8000001P3oool?0=7=Z@00
3@3AcJT20?ooo`@000000P3oool200000080oooo1P0000020?ooo`8000002P3oool6000000@0oooo
0P0000020?ooo`@000000P3oool2000000@0oooo100000020?ooo`D000000P3oool2000000@0oooo
2P0000020?ooo`H000001P3oool4000000X0oooo100000040?ooo`P000000P3oool4000000@0oooo
100000020?ooo`8000000P3oool200000080oooo0P0000060?ooo`800000103oool600000080oooo
0P0000040?ooo`@000000P3oool4000000@0oooo0`00000>0?ooo`8000000P3oool2000000@0oooo
1P0000020?ooo`@000000P3oool2000000@0oooo0P0000040?ooo`800000103oool200000080oooo
0P0000020?ooo`@00000103oool4000000X0oooo100000060?ooo`8000000P3oool600000080oooo
0P0000040?ooo`@000000P3oool2000000@0oooo0P0000070?ooo`8000000P3oool2000000H0oooo
100000060?ooo`8000000P3oool6000000H0oooo0P0000020?ooo`8000000P3oool800000080oooo
0P0000060?ooo`l0dLfY000=0=7=Z@@000001P3oool4000000@0oooo100000020?ooo`X00000103o
ool600000080oooo0P0000060?ooo`H000001P3oool00`000000oooo0?ooo`040?ooo`H00000103o
ool2000000H0oooo0P00000:0?ooo`8000000P3oool:000000P0oooo0P0000040?ooo`@00000203o
ool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo1P0000020?ooo`@00000103o
ool400000080oooo100000060?ooo`8000000P3oool400000140oooo100000020?ooo`@00000103o
ool4000000H0oooo1P0000020?ooo`@000000P3oool400000080oooo0P0000020?ooo`800000203o
ool200000080oooo2P00000:0?ooo`@00000103oool400000080oooo100000060?ooo`H000000P3o
ool700000080oooo0P0000020?ooo`H000002P3oool4000000@0oooo200000020?ooo`8000000P3o
ool2000000@0oooo0P0000020?ooo`8000000P3oool4000000l0dLfY000=0=7=Z@@000001P3oool4
000000@0oooo100000020?ooo`X00000103oool600000080oooo0P0000060?ooo`H000001P3oool0
0`000000oooo0?ooo`040?ooo`H00000103oool2000000H0oooo0P00000:0?ooo`8000000P3oool:
000000P0oooo0P0000040?ooo`@00000203oool200000080oooo0P0000020?ooo`8000000P3oool2
00000080oooo1P0000020?ooo`@00000103oool400000080oooo100000060?ooo`8000000P3oool4
00000140oooo100000020?ooo`@00000103oool4000000H0oooo1P0000020?ooo`@000000P3oool4
00000080oooo0P0000020?ooo`800000203oool200000080oooo2P00000:0?ooo`@00000103oool4
00000080oooo100000060?ooo`H000000P3oool700000080oooo0P0000020?ooo`H000002P3oool4
000000@0oooo200000020?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`8000000P3oool4
000000l0dLfY000=0=7=Z@80oooo0P0000020?ooo`H00000203oool200000080oooo0P0000040?oo
o`800000203oool2000000H0oooo200000040?ooo`L000000P3oool6000000@0oooo1P0000020?oo
o`H000000P3oool:00000080oooo0P0000040?ooo`800000303oool6000000`0oooo100000020?oo
o`8000000P3oool200000080oooo0P0000040?ooo`@00000203oool200000080oooo0P00000:0?oo
o`@000005@3oool200000080oooo0P0000080?ooo`8000000P3oool6000000@0oooo100000060?oo
o`8000000P3oool200000080oooo0P0000020?ooo`P000000P3oool2000000@0oooo0P00000>0?oo
o`8000000P3oool4000000H0oooo0P0000020?ooo`H00000103oool4000000<0oooo0P0000020?oo
o`8000000P3oool2000000@0oooo300000080?ooo`800000103oool400000080oooo0P0000020?oo
o`@000000P3oool200000080oooo0P0000020?ooo`l0dLfY000=0=7=Z@80oooo0P0000020?ooo`H0
0000203oool200000080oooo0P0000040?ooo`800000203oool2000000H0oooo200000040?ooo`L0
00000P3oool6000000@0oooo1P0000020?ooo`H000000P3oool:00000080oooo0P0000040?ooo`80
0000303oool6000000`0oooo100000020?ooo`8000000P3oool200000080oooo0P0000040?ooo`@0
0000203oool200000080oooo0P00000:0?ooo`@000005@3oool200000080oooo0P0000080?ooo`80
00000P3oool6000000@0oooo100000060?ooo`8000000P3oool200000080oooo0P0000020?ooo`P0
00000P3oool2000000@0oooo0P00000>0?ooo`8000000P3oool4000000H0oooo0P0000020?ooo`H0
0000103oool4000000<0oooo0P0000020?ooo`8000000P3oool2000000@0oooo300000080?ooo`80
0000103oool400000080oooo0P0000020?ooo`@000000P3oool200000080oooo0P0000020?ooo`l0
dLfY000=0=7=Z@@000000P3oool2000000@0oooo2P0000020?ooo`8000000P3oool400000080oooo
200000020?ooo`H00000103oool200000080oooo100000040?ooo`030000003oool0oooo00800000
103oool6000000@0oooo100000040?ooo`@00000103oool2000000H0oooo1P0000020?ooo``00000
103oool>000000H0oooo100000020?ooo`8000000P3oool4000000`0oooo100000020?ooo`X00000
6@3oool400000080oooo200000020?ooo`800000103oool6000000X0oooo100000020?ooo`800000
0P3oool2000000@0oooo0P0000020?ooo`8000000P3oool400000080oooo3P0000020?ooo`800000
2P3oool4000000@0oooo1P0000070?ooo`@000000P3oool200000080oooo100000040?ooo`800000
103oool:00000080oooo100000060?ooo`@000001P3oool400000080oooo3`3AcJT000d0dLfY1000
00020?ooo`800000103oool:00000080oooo0P0000020?ooo`@000000P3oool800000080oooo1P00
00040?ooo`8000000P3oool4000000@0oooo00<000000?ooo`3oool00P0000040?ooo`H00000103o
ool4000000@0oooo100000040?ooo`8000001P3oool600000080oooo300000040?ooo`h000001P3o
ool400000080oooo0P0000020?ooo`@00000303oool400000080oooo2P00000I0?ooo`@000000P3o
ool800000080oooo0P0000040?ooo`H000002P3oool400000080oooo0P0000020?ooo`800000103o
ool200000080oooo0P0000020?ooo`@000000P3oool>00000080oooo0P00000:0?ooo`@00000103o
ool6000000L0oooo100000020?ooo`8000000P3oool4000000@0oooo0P0000040?ooo`X000000P3o
ool4000000H0oooo100000060?ooo`@000000P3oool?0=7=Z@003@3AcJT40?ooo`@000000P3oool4
000000@0oooo0P0000060?ooo`@000001P3oool2000000@0oooo100000040?ooo`H000000P3oool2
000000L0oooo100000020?ooo`@00000103oool6000000P0oooo0P0000020?ooo`@000000P3oool6
000000@0oooo100000040?ooo`800000103oool6000000@0oooo0P0000040?ooo`8000000P3oool6
000000H0oooo1000000@0?ooo`8000000P3oool2000000@0oooo0P00000M0?ooo`8000000P3oool2
000000@0oooo0P0000020?ooo`8000000P3oool4000000@0oooo300000060?ooo`@000000P3oool4
00000080oooo0P0000020?ooo`8000001P3oool2000000@0oooo0P0000040?ooo`@000000P3oool:
000000P0oooo0P00000;0?ooo`8000000P3oool200000080oooo0P0000080?ooo`H00000103oool2
000000H0oooo0P0000020?ooo`H000002P3oool200000080oooo3`3AcJT000d0dLfY103oool40000
0080oooo100000040?ooo`8000001P3oool4000000H0oooo0P0000040?ooo`@00000103oool60000
0080oooo0P0000070?ooo`@000000P3oool4000000@0oooo1P0000080?ooo`8000000P3oool40000
0080oooo1P0000040?ooo`@00000103oool2000000@0oooo1P0000040?ooo`800000103oool20000
0080oooo1P0000060?ooo`@00000403oool200000080oooo0P0000040?ooo`8000007@3oool20000
0080oooo0P0000040?ooo`8000000P3oool200000080oooo100000040?ooo``000001P3oool40000
0080oooo100000020?ooo`8000000P3oool2000000H0oooo0P0000040?ooo`800000103oool40000
0080oooo2P0000080?ooo`8000002`3oool200000080oooo0P0000020?ooo`800000203oool60000
00@0oooo0P0000060?ooo`8000000P3oool6000000X0oooo0P0000020?ooo`l0dLfY000=0=7=Z@H0
00001P3oool200000080oooo100000020?ooo`H000002P3oool6000000P0oooo0P0000060?ooo`T0
00001P3oool200000080oooo100000040?ooo`X000000P3oool2000000H0oooo0P0000080?ooo`80
00000P3oool400000080oooo100000040?ooo`H000000P3oool400000080oooo0P0000040?ooo`P0
0000503oool400000080oooo100000020?oooad000000P3oool200000080oooo100000020?ooo`80
00000P3oool2000000P0oooo0P0000040?ooo`8000002P3oool200000080oooo0P0000060?ooo`@0
00000P3oool600000080oooo100000020?ooo`@000001P3oool2000000@0oooo0P0000020?ooo`P0
00000P3oool;00000080oooo0P0000020?ooo`8000000P3oool8000000@0oooo1P0000020?ooo`H0
00000P3oool2000000@0oooo300000020?ooo`l0dLfY000=0=7=Z@H000001P3oool200000080oooo
100000020?ooo`H000002P3oool6000000P0oooo0P0000060?ooo`T000001P3oool200000080oooo
100000040?ooo`X000000P3oool2000000H0oooo0P0000080?ooo`8000000P3oool400000080oooo
100000040?ooo`H000000P3oool400000080oooo0P0000040?ooo`P00000503oool400000080oooo
100000020?oooad000000P3oool200000080oooo100000020?ooo`8000000P3oool2000000P0oooo
0P0000040?ooo`8000002P3oool200000080oooo0P0000060?ooo`@000000P3oool600000080oooo
100000020?ooo`@000001P3oool2000000@0oooo0P0000020?ooo`P000000P3oool;00000080oooo
0P0000020?ooo`8000000P3oool8000000@0oooo1P0000020?ooo`H000000P3oool2000000@0oooo
300000020?ooo`l0dLfY000=0=7=Z@80oooo0P00000:0?ooo`@000001P3oool2000000h0oooo0P00
000<0?ooo`P00000103oool00`000000oooo0?ooo`080?ooo`@00000203oool2000000@0oooo0P00
00020?ooo`8000000P3oool600000080oooo200000020?ooo`8000001P3oool200000080oooo1000
00040?ooo`@000001P3oool6000000@0oooo0P0000020?oooa@000001P3oool200000080oooo0P00
00030?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool400000080oooo0P00
00060?ooo`@000000P3oool800000080oooo100000020?ooo`X000000P3oool200000080oooo1P00
00060?ooo`8000001P3oool200000080oooo0P00000:0?ooo`H000000P3oool2000000@0oooo0P00
00020?ooo`8000000`3oool2000000@0oooo100000020?ooo`8000000P3oool2000000@0oooo0P00
00020?ooo`@00000103oool4000000@0oooo100000020?ooo`@00000103oool2000000@0oooo0P00
000?0=7=Z@003@3AcJT20?ooo`8000002P3oool4000000H0oooo0P00000>0?ooo`800000303oool8
000000@0oooo00<000000?ooo`3oool0203oool4000000P0oooo0P0000040?ooo`8000000P3oool2
00000080oooo1P0000020?ooo`P000000P3oool2000000H0oooo0P0000020?ooo`@00000103oool4
000000H0oooo1P0000040?ooo`8000000P3ooolD000000H0oooo0P0000020?ooo`8000000`3oool2
000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo100000020?ooo`8000001P3oool4
00000080oooo200000020?ooo`@000000P3oool:00000080oooo0P0000020?ooo`H000001P3oool2
000000H0oooo0P0000020?ooo`8000002P3oool600000080oooo0P0000040?ooo`8000000P3oool2
000000<0oooo0P0000040?ooo`@000000P3oool200000080oooo0P0000040?ooo`8000000P3oool4
000000@0oooo100000040?ooo`@000000P3oool4000000@0oooo0P0000040?ooo`8000003`3AcJT0
00d0dLfY103oool<000000X0oooo400000020?ooo``00000103oool200000080oooo0`0000020?oo
o`X00000303oool600000080oooo0P0000020?ooo`800000103oool4000000@0oooo0P0000020?oo
o`8000000P3oool600000080oooo0P0000080?ooo`8000000P3oool6000000@0oooo1P0000020?oo
o`800000103oool2000000@0oooo0P0000040?ooo`8000000P3oool600000080oooo0P0000020?oo
o`<000000P3oool400000080oooo100000020?ooo`@000000P3oool4000000H0oooo200000060?oo
o`800000103oool4000000H0oooo0P0000040?ooo`8000000P3oool200000080oooo0P0000040?oo
o`P000000P3oool600000080oooo0P0000020?ooo`X00000103oool400000080oooo100000020?oo
o`80000000<0oooo0000000000000P0000020?ooo`@000001P3oool400000080oooo100000020?oo
o`800000203oool200000080oooo100000060?ooo`8000000P3oool400000080oooo1000000?0=7=
Z@003@3AcJT40?ooo``000002P3oool@00000080oooo300000040?ooo`8000000P3oool300000080
oooo2P00000<0?ooo`H000000P3oool200000080oooo0P0000040?ooo`@00000103oool200000080
oooo0P0000020?ooo`H000000P3oool2000000P0oooo0P0000020?ooo`H00000103oool600000080
oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000020?ooo`H000000P3oool200000080
oooo0`0000020?ooo`@000000P3oool400000080oooo100000020?ooo`@000001P3oool8000000H0
oooo0P0000040?ooo`@000001P3oool2000000@0oooo0P0000020?ooo`8000000P3oool2000000@0
oooo200000020?ooo`H000000P3oool200000080oooo2P0000040?ooo`@000000P3oool400000080
oooo0P0000000`3oool000000000000200000080oooo100000060?ooo`@000000P3oool400000080
oooo0P0000080?ooo`8000000P3oool4000000H0oooo0P0000020?ooo`@000000P3oool4000000l0
dLfY000=0=7=Z@H00000103oool2000000@0oooo300000040?ooo`800000103oool2000000H0oooo
0P0000040?ooo`800000203oool4000000D0oooo0P0000040?ooo`8000000P3oool<000000@0oooo
100000020?ooo`8000000P3oool4000000P0oooo100000020?ooo`800000103oool400000080oooo
200000020?ooo`800000103oool6000000@0oooo100000020?ooo`@000000P3oool400000080oooo
100000020?ooo`800000103oool400000080oooo00<000000?ooo`3oool0103oool200000080oooo
0P0000060?ooo`8000000P3oool2000000X0oooo0P0000040?ooo`P000000P3oool4000000X0oooo
1P0000020?ooo`8000000P3oool200000080oooo100000040?ooo`8000000P3oool2000000@0oooo
100000020?ooo`800000103oool2000000P0oooo0P0000020?ooo`8000001P3oool3000000H0oooo
0P0000020?ooo`H000001P3oool200000080oooo0P0000020?ooo`P000000P3oool2000000X0oooo
100000060?ooo`8000003`3AcJT000d0dLfY1P0000040?ooo`800000103oool<000000@0oooo0P00
00040?ooo`8000001P3oool2000000@0oooo0P0000080?ooo`@000001@3oool2000000@0oooo0P00
00020?ooo``00000103oool400000080oooo0P0000020?ooo`@00000203oool400000080oooo0P00
00040?ooo`@000000P3oool800000080oooo0P0000040?ooo`H00000103oool400000080oooo1000
00020?ooo`@000000P3oool400000080oooo0P0000040?ooo`@000000P3oool00`000000oooo0?oo
o`040?ooo`8000000P3oool2000000H0oooo0P0000020?ooo`8000002P3oool2000000@0oooo2000
00020?ooo`@000002P3oool600000080oooo0P0000020?ooo`8000000P3oool4000000@0oooo0P00
00020?ooo`800000103oool400000080oooo0P0000040?ooo`800000203oool200000080oooo0P00
00060?ooo`<000001P3oool200000080oooo1P0000060?ooo`8000000P3oool200000080oooo2000
00020?ooo`8000002P3oool4000000H0oooo0P00000?0=7=Z@003@3AcJT2000000@0oooo1P000002
0?ooo`@00000103oool2000000@0oooo1P0000020?ooo`@000000P3oool600000080oooo10000002
0?ooo`P000002@3oool600000080oooo0P0000040?ooo`800000103oool6000000H0oooo1000000<
0?ooo`8000000P3oool200000080oooo100000060?ooo`800000103oool400000080oooo10000004
0?ooo`H000001P3oool200000080oooo0P0000060?ooo`8000000P3oool200000080oooo10000005
0?ooo`P000000P3oool200000080oooo1P0000020?ooo`8000000P3oool:00000080oooo10000004
0?ooo`8000000P3oool2000000h0oooo0P0000060?ooo`@000000P3oool2000000P0oooo10000002
0?ooo`@000001P3oool600000080oooo200000020?ooo`8000000P3oool5000000X0oooo10000004
0?ooo`P000000P3oool200000080oooo0P0000040?ooo`8000000P3oool200000080oooo2P00000:
0?ooo`l0dLfY000=0=7=Z@800000103oool600000080oooo100000040?ooo`800000103oool60000
0080oooo100000020?ooo`H000000P3oool400000080oooo200000090?ooo`H000000P3oool20000
00@0oooo0P0000040?ooo`H000001P3oool4000000`0oooo0P0000020?ooo`8000000P3oool40000
00H0oooo0P0000040?ooo`@000000P3oool4000000@0oooo1P0000060?ooo`8000000P3oool20000
00H0oooo0P0000020?ooo`8000000P3oool4000000D0oooo200000020?ooo`8000000P3oool60000
0080oooo0P0000020?ooo`X000000P3oool4000000@0oooo0P0000020?ooo`8000003P3oool20000
00H0oooo100000020?ooo`800000203oool400000080oooo100000060?ooo`H000000P3oool80000
0080oooo0P0000020?ooo`D000002P3oool4000000@0oooo200000020?ooo`8000000P3oool20000
00@0oooo0P0000020?ooo`8000000P3oool:000000X0oooo3`3AcJT000d0dLfY0P0000020?ooo`@0
0000103oool4000000P0oooo1P0000040?ooo`@000001P3oool2000000H0oooo0P0000020?ooo`80
0000103oool200000080oooo2@0000040?ooo`@000000P3oool400000080oooo100000040?ooo`P0
0000403oool400000080oooo0P00000:0?ooo`H000001P3oool200000080oooo100000040?ooo`P0
00000P3oool200000080oooo1P0000020?ooo`8000000P3oool2000000T0oooo0P0000040?ooo`@0
00000P3oool2000000@0oooo100000020?ooo`800000103oool2000000H0oooo0P0000020?ooo`@0
00000P3oool200000080oooo3P0000020?ooo`H000001P3oool:000000H0oooo0P0000020?ooo`H0
0000103oool4000000@0oooo0P0000020?ooo`8000000P3oool2000000<0oooo300000080?ooo`80
0000103oool400000080oooo0P0000020?ooo`@000000P3oool200000080oooo0P0000040?ooo`80
0000303oool?0=7=Z@003@3AcJT200000080oooo100000040?ooo`@00000203oool6000000@0oooo
100000060?ooo`8000001P3oool200000080oooo0P0000040?ooo`8000000P3oool9000000@0oooo
100000020?ooo`@000000P3oool4000000@0oooo2000000@0?ooo`@000000P3oool2000000X0oooo
1P0000060?ooo`8000000P3oool4000000@0oooo200000020?ooo`8000000P3oool600000080oooo
0P0000020?ooo`8000002@3oool2000000@0oooo100000020?ooo`800000103oool400000080oooo
0P0000040?ooo`8000001P3oool200000080oooo100000020?ooo`8000000P3oool>00000080oooo
1P0000060?ooo`X000001P3oool200000080oooo1P0000040?ooo`@00000103oool200000080oooo
0P0000020?ooo`8000000`3oool<000000P0oooo0P0000040?ooo`@000000P3oool200000080oooo
100000020?ooo`8000000P3oool2000000@0oooo0P00000<0?ooo`l0dLfY000=0=7=Z@H0oooo0P00
00020?ooo`@00000303oool2000000P0oooo0P0000020?ooo`H000000P3oool600000080oooo0P00
00020?ooo`@000000P3oool00`000000oooo0?ooo`020?ooo`800000203oool200000080oooo0P00
00060?ooo`8000000P3oool4000000@0oooo0P0000020?oooa0000001P3oool<000000@0oooo2000
00020?ooo`800000203oool2000000@0oooo100000020?ooo`800000103oool400000080oooo0P00
00020?ooo`T000000P3oool4000000H0oooo1P0000060?ooo`H000000P3oool600000080oooo0P00
00060?ooo`@00000103oool2000000@0oooo0P0000020?ooo`800000103oool8000000@0oooo0P00
000:0?ooo`@00000103oool6000000P0oooo100000020?ooo`8000000P3oool3000000@0oooo0P00
00040?ooo`X000000P3oool4000000H0oooo100000060?ooo`@000000P3oool400000080oooo2P00
000?0=7=Z@003@3AcJT60?ooo`8000000P3oool4000000`0oooo0P0000080?ooo`8000000P3oool6
00000080oooo1P0000020?ooo`8000000P3oool400000080oooo00<000000?ooo`3oool00P3oool2
000000P0oooo0P0000020?ooo`8000001P3oool200000080oooo100000040?ooo`8000000P3oool@
000000H0oooo300000040?ooo`P000000P3oool2000000P0oooo0P0000040?ooo`@000000P3oool2
000000@0oooo100000020?ooo`8000000P3oool900000080oooo100000060?ooo`H000001P3oool6
00000080oooo1P0000020?ooo`8000001P3oool4000000@0oooo0P0000040?ooo`8000000P3oool2
000000@0oooo200000040?ooo`8000002P3oool4000000@0oooo1P0000080?ooo`@000000P3oool2
00000080oooo0`0000040?ooo`800000103oool:00000080oooo100000060?ooo`@000001P3oool4
00000080oooo100000020?ooo`X000003`3AcJT000d0dLfY0P3oool600000080oooo0P00000@0?oo
o`X000000P3oool2000000@0oooo100000040?ooo`@000000P3oool2000000D0oooo1P0000020?oo
o`P000000P3oool200000080oooo1P0000020?ooo`800000203oool4000000@0oooo0P0000040?oo
o`8000002P3oool2000000@0oooo0P0000080?ooo`800000103oool400000080oooo200000020?oo
o`@000001P3oool6000000H0oooo100000030?ooo`8000001P3oool200000080oooo1P0000040?oo
o`P00000103oool4000000@0oooo100000020?ooo`H00000203oool600000080oooo0P0000020?oo
o`@00000103oool200000080oooo100000020?ooo`X00000203oool2000000`0oooo0P0000020?oo
o`8000000P3oool00`000000oooo0?ooo`060?ooo`H00000103oool2000000H0oooo0P0000020?oo
o`H000002P3oool200000080oooo0P0000060?ooo`800000103oool2000000l0dLfY000=0=7=Z@80
oooo1P0000020?ooo`800000403oool:00000080oooo0P0000040?ooo`@00000103oool400000080
oooo0P0000050?ooo`H000000P3oool800000080oooo0P0000020?ooo`H000000P3oool2000000P0
oooo100000040?ooo`800000103oool2000000X0oooo0P0000040?ooo`800000203oool2000000@0
oooo100000020?ooo`P000000P3oool4000000H0oooo1P0000060?ooo`@000000`3oool2000000H0
oooo0P0000020?ooo`H00000103oool8000000@0oooo100000040?ooo`@000000P3oool6000000P0
oooo1P0000020?ooo`8000000P3oool4000000@0oooo0P0000020?ooo`@000000P3oool:000000P0
oooo0P00000<0?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool01P3oool6000000@0
oooo0P0000060?ooo`8000000P3oool6000000X0oooo0P0000020?ooo`8000001P3oool2000000@0
oooo0P00000?0=7=Z@003@3AcJT20?ooo`800000103oool400000080oooo400000040?ooo`800000
1P3oool6000000P0oooo0P0000020?ooo`8000000P3oool5000000@0oooo100000040?ooo`800000
0P3oool200000080oooo0P0000040?ooo`@000000P3oool8000000P0oooo1P0000020?ooo`X00000
0P3oool400000080oooo200000020?ooo`@000001P3oool2000000@0oooo1000000:0?ooo`800000
2P3oool200000080oooo0`0000020?ooo`H000000P3oool2000000@0oooo1P0000040?ooo`800000
0P3oool4000000P0oooo0P0000020?ooo`800000103oool:000000@0oooo100000020?ooo`800000
203oool4000000H0oooo0P0000040?ooo`8000000P3oool800000080oooo300000020?ooo`800000
0P3oool00`000000oooo0?ooo`08000000@0oooo1P0000020?ooo`H000000P3oool2000000@0oooo
300000020?ooo`8000000P3oool600000080oooo1000000?0=7=Z@003@3AcJT20?ooo`800000103o
ool400000080oooo400000040?ooo`8000001P3oool6000000P0oooo0P0000020?ooo`8000000P3o
ool5000000@0oooo100000040?ooo`8000000P3oool200000080oooo0P0000040?ooo`@000000P3o
ool8000000P0oooo1P0000020?ooo`X000000P3oool400000080oooo200000020?ooo`@000001P3o
ool2000000@0oooo1000000:0?ooo`8000002P3oool200000080oooo0`0000020?ooo`H000000P3o
ool2000000@0oooo1P0000040?ooo`8000000P3oool4000000P0oooo0P0000020?ooo`800000103o
ool:000000@0oooo100000020?ooo`800000203oool4000000H0oooo0P0000040?ooo`8000000P3o
ool800000080oooo300000020?ooo`8000000P3oool00`000000oooo0?ooo`08000000@0oooo1P00
00020?ooo`H000000P3oool2000000@0oooo300000020?ooo`8000000P3oool600000080oooo1000
000?0=7=Z@003@3AcJT20?ooo`8000000P3oool4000000H0oooo0P0000040?ooo`800000103oool2
00000080oooo100000020?ooo`H00000103oool:00000080oooo0P0000020?ooo`8000000`3oool6
000000P0oooo100000020?ooo`8000000P3oool4000000H0oooo0P0000040?ooo`X00000103oool4
000000@0oooo0P0000060?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`8000002P3oool6
000000h0oooo300000020?ooo`030000003oool0oooo00@0oooo0P0000060?ooo`H00000103oool6
00000080oooo0P00000<0?ooo`@000000P3oool4000000@0oooo0P0000080?ooo`8000000P3oool2
00000080oooo2000000:0?ooo`H000000P3oool2000000@0oooo0P0000020?ooo`800000103oool2
000000@0oooo100000020?ooo`030000003oool0oooo00800000103oool200000080oooo10000004
0?ooo`@00000103oool400000080oooo100000040?ooo`800000103oool400000080oooo0P000004
0?ooo`@000000P3oool?0=7=Z@003@3AcJT20?ooo`8000000P3oool4000000H0oooo0P0000040?oo
o`800000103oool200000080oooo100000020?ooo`H00000103oool:00000080oooo0P0000020?oo
o`8000000`3oool6000000P0oooo100000020?ooo`8000000P3oool4000000H0oooo0P0000040?oo
o`X00000103oool4000000@0oooo0P0000060?ooo`8000000P3oool2000000@0oooo0P0000020?oo
o`8000002P3oool6000000h0oooo300000020?ooo`030000003oool0oooo00@0oooo0P0000060?oo
o`H00000103oool600000080oooo0P00000<0?ooo`@000000P3oool4000000@0oooo0P0000080?oo
o`8000000P3oool200000080oooo2000000:0?ooo`H000000P3oool2000000@0oooo0P0000020?oo
o`800000103oool2000000@0oooo100000020?ooo`030000003oool0oooo00800000103oool20000
0080oooo100000040?ooo`@00000103oool400000080oooo100000040?ooo`800000103oool40000
0080oooo0P0000040?ooo`@000000P3oool?0=7=Z@003@3AcJT20?ooo`8000000P3oool2000000X0
oooo1P0000020?ooo`@000000P3oool2000000H0oooo0P0000080?ooo`800000103oool200000080
oooo0P0000020?ooo`80000000<0oooo0000000000000P0000040?ooo`X000001P3oool4000000X0
oooo1P0000040?ooo`800000203oool200000080oooo100000020?ooo`H000000P3oool200000080
oooo100000020?ooo`8000000P3oool:000000@0oooo400000040?ooo`800000103oool300000080
oooo1P0000020?ooo`H00000103oool6000000@0oooo100000020?ooo``000001P3oool200000080
oooo100000020?ooo`P000000P3oool200000080oooo0P0000040?ooo`8000000P3oool:000000@0
oooo100000020?ooo`@000000P3oool200000080oooo100000020?ooo`@000001@3oool400000080
oooo100000020?ooo`800000203oool200000080oooo100000060?ooo`8000000P3oool400000080
oooo100000060?ooo`H00000103oool?0=7=Z@003@3AcJT20?ooo`8000000P3oool2000000X0oooo
1P0000020?ooo`@000000P3oool2000000H0oooo0P0000080?ooo`800000103oool200000080oooo
0P0000020?ooo`80000000<0oooo0000000000000P0000040?ooo`X000001P3oool4000000X0oooo
1P0000040?ooo`800000203oool200000080oooo100000020?ooo`H000000P3oool200000080oooo
100000020?ooo`8000000P3oool:000000@0oooo400000040?ooo`800000103oool300000080oooo
1P0000020?ooo`H00000103oool6000000@0oooo100000020?ooo``000001P3oool200000080oooo
100000020?ooo`P000000P3oool200000080oooo0P0000040?ooo`8000000P3oool:000000@0oooo
100000020?ooo`@000000P3oool200000080oooo100000020?ooo`@000001@3oool400000080oooo
100000020?ooo`800000203oool200000080oooo100000060?ooo`8000000P3oool400000080oooo
100000060?ooo`H00000103oool?0=7=Z@003@3AcJT40?ooo`@000000P3oool:000000@0oooo1000
00060?ooo`P000000P3oool800000080oooo100000020?ooo`8000000P3oool2000000030?ooo`00
0000000000P0oooo0P0000040?ooo`8000000P3oool6000000h0oooo0P0000080?ooo`X000000P3o
ool2000000H0oooo0P0000060?ooo`@000001P3oool4000000@0oooo0P0000080?ooo`800000103o
ool2000000@0oooo0P0000020?ooo`@000000P3oool4000000D0oooo0P0000060?ooo`800000203o
ool2000000P0oooo0P0000020?ooo`800000103oool2000000@0oooo200000020?ooo`8000001P3o
ool2000000@0oooo100000020?ooo`8000000P3oool400000080oooo0P0000040?ooo`800000203o
ool200000080oooo0P0000060?ooo`@000001P3oool200000080oooo1@0000060?ooo`8000000P3o
ool200000080oooo200000020?ooo`8000002P3oool4000000H0oooo0P0000020?ooo`H00000103o
ool4000000l0dLfY000=0=7=Z@@0oooo100000020?ooo`X00000103oool4000000H0oooo20000002
0?ooo`P000000P3oool400000080oooo0P0000020?ooo`80000000<0oooo000000000000203oool2
000000@0oooo0P0000020?ooo`H000003P3oool2000000P0oooo2P0000020?ooo`8000001P3oool2
000000H0oooo100000060?ooo`@00000103oool2000000P0oooo0P0000040?ooo`800000103oool2
00000080oooo100000020?ooo`@000001@3oool2000000H0oooo0P0000080?ooo`800000203oool2
00000080oooo0P0000040?ooo`800000103oool800000080oooo0P0000060?ooo`800000103oool4
00000080oooo0P0000020?ooo`@000000P3oool2000000@0oooo0P0000080?ooo`8000000P3oool2
000000H0oooo100000060?ooo`8000000P3oool5000000H0oooo0P0000020?ooo`8000000P3oool8
00000080oooo0P00000:0?ooo`@000001P3oool200000080oooo1P0000040?ooo`@000003`3AcJT0
00d0dLfY1P3oool200000080oooo0P0000040?ooo`800000203oool200000080oooo1P0000040?oo
o`8000000P3oool2000000@0oooo0P0000020?ooo`8000001P3oool4000000030?ooo`0000000000
0080oooo200000020?ooo`@000000P3oool2000000@0oooo400000020?ooo`P00000103oool20000
00H0oooo200000020?ooo`H000002P3oool200000080oooo100000020?ooo`P000000P3oool40000
0080oooo100000020?ooo`8000001P3oool2000000030?ooo`000000000000@000000P3oool60000
0080oooo200000020?ooo`P000000P3oool200000080oooo100000020?ooo`@00000103oool20000
0080oooo0P0000020?ooo`H000000P3oool4000000H0oooo100000060?ooo`H000000P3oool80000
0080oooo0P0000020?ooo`H000002P3oool4000000<0oooo200000020?ooo`8000000P3oool20000
00@0oooo0P0000020?ooo`8000000P3oool:000000X0oooo100000040?ooo`H000000P3oool?0=7=
Z@003@3AcJT60?ooo`8000000P3oool2000000@0oooo0P0000080?ooo`8000000P3oool6000000@0
oooo0P0000020?ooo`800000103oool200000080oooo0P0000060?ooo`@0000000<0oooo00000000
00000P3oool800000080oooo100000020?ooo`800000103oool@00000080oooo200000040?ooo`80
00001P3oool800000080oooo1P00000:0?ooo`8000000P3oool400000080oooo200000020?ooo`@0
00000P3oool400000080oooo0P0000060?ooo`80000000<0oooo000000000000100000020?ooo`H0
00000P3oool800000080oooo200000020?ooo`8000000P3oool400000080oooo100000040?ooo`80
00000P3oool200000080oooo1P0000020?ooo`@000001P3oool4000000H0oooo1P0000020?ooo`P0
00000P3oool200000080oooo1P00000:0?ooo`@000000`3oool800000080oooo0P0000020?ooo`80
0000103oool200000080oooo0P0000020?ooo`X000002P3oool4000000@0oooo1P0000020?ooo`l0
dLfY000=0=7=Z@P000000P3oool200000080oooo100000020?ooo`P000000P3oool2000000@0oooo
1P0000020?ooo`8000000P3oool400000080oooo0P0000020?ooo`H000001@3oool4000000@0oooo
0P0000020?ooo`8000001P3oool6000000@0oooo0P0000040?ooo`8000001P3oool2000000@0oooo
1P0000020?ooo`H00000103oool200000080oooo0P0000040?ooo``000000P3oool2000000H0oooo
0P0000040?ooo`@000001P3oool200000080oooo0P0000020?ooo`H0000000<0oooo000000000000
103oool4000000@0oooo100000040?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`800000
0P3oool2000000H0oooo0P0000020?ooo`@000000P3oool200000080oooo0P0000040?ooo`@00000
2P3oool200000080oooo1P0000040?ooo`@00000103oool200000080oooo0P0000020?ooo`800000
103oool<000000L0oooo0P0000040?ooo`@000000P3oool200000080oooo100000020?ooo`800000
0P3oool2000000@0oooo0P00000>0?ooo`8000000P3oool4000000@0oooo0P00000?0=7=Z@003@3A
cJT800000080oooo0P0000020?ooo`@000000P3oool800000080oooo0P0000040?ooo`H000000P3o
ool200000080oooo100000020?ooo`8000000P3oool6000000D0oooo100000040?ooo`8000000P3o
ool2000000H0oooo1P0000040?ooo`800000103oool2000000H0oooo0P0000040?ooo`H000000P3o
ool6000000@0oooo0P0000020?ooo`800000103oool<00000080oooo0P0000060?ooo`800000103o
ool4000000H0oooo0P0000020?ooo`8000000P3oool6000000030?ooo`000000000000@0oooo1000
00040?ooo`@00000103oool200000080oooo0P0000040?ooo`8000000P3oool200000080oooo0P00
00060?ooo`8000000P3oool400000080oooo0P0000020?ooo`800000103oool4000000X0oooo0P00
00020?ooo`H00000103oool4000000@0oooo0P0000020?ooo`8000000P3oool2000000@0oooo3000
00070?ooo`800000103oool400000080oooo0P0000020?ooo`@000000P3oool200000080oooo0P00
00040?ooo`8000003P3oool200000080oooo100000040?ooo`8000003`3AcJT000d0dLfY0P3oool2
000000@0oooo100000020?ooo`8000001P3oool2000000@0oooo100000020?ooo`@00000103oool4
00000080oooo0P0000060?ooo`@00000103oool7000000P0oooo100000020?ooo`H00000103oool6
00000080oooo100000020?ooo`H000000P3oool4000000@0oooo100000040?ooo`H000000P3oool2
00000080oooo100000040?ooo`800000103oool400000080oooo1P0000020?ooo`@000002P3oool4
00000080oooo0P0000040?ooo`<000000P3oool4000000P0oooo0P0000020?ooo`@000000P3oool2
00000080oooo100000020?ooo`8000000P3oool200000080oooo1P0000020?ooo`8000001P3oool4
00000080oooo1000000>0?ooo`@00000103oool6000000P0oooo100000020?ooo`8000000P3oool4
000000@0oooo0P0000040?ooo`T000000P3oool4000000H0oooo100000060?ooo`@000000P3oool4
00000080oooo3P0000020?ooo`800000203oool?0=7=Z@003@3AcJT20?ooo`800000103oool40000
0080oooo0P0000060?ooo`800000103oool400000080oooo100000040?ooo`@000000P3oool20000
00H0oooo100000040?ooo`L00000203oool400000080oooo1P0000040?ooo`H000000P3oool40000
0080oooo1P0000020?ooo`@00000103oool4000000@0oooo1P0000020?ooo`8000000P3oool40000
00@0oooo0P0000040?ooo`@000000P3oool600000080oooo1000000:0?ooo`@000000P3oool20000
00@0oooo0`0000020?ooo`@00000203oool200000080oooo100000020?ooo`8000000P3oool40000
0080oooo0P0000020?ooo`8000000P3oool600000080oooo0P0000060?ooo`@000000P3oool40000
00h0oooo100000040?ooo`H00000203oool400000080oooo0P0000020?ooo`@00000103oool20000
00@0oooo2@0000020?ooo`@000001P3oool4000000H0oooo100000020?ooo`@000000P3oool>0000
0080oooo0P0000080?ooo`l0dLfY000=0=7=Z@@000000P3oool4000000H0oooo200000020?ooo`@0
00001P3oool200000080oooo100000060?ooo`P00000203oool00`000000oooo0?ooo`020?ooo`X0
00001P3oool2000000P0oooo0P0000060?ooo`8000000P3oool2000000@0oooo100000080?ooo`80
00000P3oool4000000@0oooo100000020?ooo`800000203oool6000000H0oooo0P0000060?ooo`80
00000P3oool:000000H0oooo1@0000060?ooo`8000000P3oool800000080oooo0P0000060?ooo`@0
00001P3oool400000080oooo0P0000040?ooo`@000000P3oool6000000H0oooo0P0000020?ooo`h0
0000203oool2000000`0oooo0P0000020?ooo`8000000P3oool2000000P0oooo1P0000030?ooo`80
00001P3oool200000080oooo1P00000:0?ooo`8000000P3oool2000000H0oooo0P0000040?ooo`80
0000103oool400000080oooo1P00000?0=7=Z@003@3AcJT400000080oooo100000060?ooo`P00000
0P3oool4000000H0oooo0P0000020?ooo`@000001P3oool8000000P0oooo00<000000?ooo`3oool0
0P3oool:000000H0oooo0P0000080?ooo`8000001P3oool200000080oooo0P0000040?ooo`@00000
203oool200000080oooo100000040?ooo`@000000P3oool2000000P0oooo1P0000060?ooo`800000
1P3oool200000080oooo2P0000060?ooo`D000001P3oool200000080oooo200000020?ooo`800000
1P3oool4000000H0oooo100000020?ooo`800000103oool400000080oooo1P0000060?ooo`800000
0P3oool>000000P0oooo0P00000<0?ooo`8000000P3oool200000080oooo0P0000080?ooo`H00000
0`3oool2000000H0oooo0P0000020?ooo`H000002P3oool200000080oooo0P0000060?ooo`800000
103oool2000000@0oooo100000020?ooo`H000003`3AcJT000d0dLfY103oool4000000X0oooo0P00
00040?ooo`@000002P3oool4000000X0oooo0P0000040?ooo`T000000P3oool4000000@0oooo0P00
000:0?ooo`X000000P3oool600000080oooo0P0000020?ooo`@00000303oool4000000P0oooo0P00
00020?ooo`8000000P3oool8000000@0oooo200000020?ooo`H000000P3oool2000000@0oooo0P00
000:0?ooo`8000002@3oool4000000@0oooo0P0000020?ooo`8000000P3oool6000000X0oooo0P00
00020?ooo`8000000P3oool4000000H0oooo0P00000:0?ooo`@00000103oool2000000@0oooo0P00
00020?ooo`P000000P3oool<00000080oooo0P0000020?ooo`8000000P3oool8000000@0oooo1@00
00020?ooo`H000000P3oool2000000@0oooo300000020?ooo`8000000P3oool600000080oooo1000
00020?ooo`@000001P3oool200000080oooo3`3AcJT000d0dLfY103oool4000000X0oooo0P000004
0?ooo`@000002P3oool4000000X0oooo0P0000040?ooo`T000000P3oool4000000@0oooo0P00000:
0?ooo`X000000P3oool600000080oooo0P0000020?ooo`@00000303oool4000000P0oooo0P000002
0?ooo`8000000P3oool8000000@0oooo200000020?ooo`H000000P3oool2000000@0oooo0P00000:
0?ooo`8000002@3oool4000000@0oooo0P0000020?ooo`8000000P3oool6000000X0oooo0P000002
0?ooo`8000000P3oool4000000H0oooo0P00000:0?ooo`@00000103oool2000000@0oooo0P000002
0?ooo`P000000P3oool<00000080oooo0P0000020?ooo`8000000P3oool8000000@0oooo1@000002
0?ooo`H000000P3oool2000000@0oooo300000020?ooo`8000000P3oool600000080oooo10000002
0?ooo`@000001P3oool200000080oooo3`3AcJT000d0dLfY0P3oool4000000h0oooo1P00000>0?oo
o`8000000P3oool:00000080oooo100000040?ooo`8000001@3oool200000080oooo100000020?oo
o`X00000103oool2000000H0oooo0P0000060?ooo`@00000403oool200000080oooo200000020?oo
o`8000000P3oool2000000@0oooo0P0000020?ooo`@00000103oool200000080oooo0P0000040?oo
o`@000000P3oool400000080oooo2P0000000`3oool0000000000008000000P0oooo100000020?oo
o`800000103oool<00000080oooo0P0000020?ooo`8000002P3oool<000000P0oooo1P0000020?oo
o`800000103oool200000080oooo0P0000040?ooo`800000103oool400000080oooo0P0000020?oo
o`800000103oool200000080oooo0`0000040?ooo`@00000103oool400000080oooo100000040?oo
o`800000103oool400000080oooo0P0000040?ooo`@000001P3oool200000080oooo1P0000020?oo
o`l0dLfY000=0=7=Z@80oooo1000000>0?ooo`H000003P3oool200000080oooo2P0000020?ooo`@0
0000103oool2000000D0oooo0P0000020?ooo`@000000P3oool:000000@0oooo0P0000060?ooo`80
00001P3oool400000100oooo0P0000020?ooo`P000000P3oool200000080oooo0P0000040?ooo`80
00000P3oool4000000@0oooo0P0000020?ooo`800000103oool400000080oooo100000020?ooo`X0
000000<0oooo000000000000200000080?ooo`@000000P3oool2000000@0oooo300000020?ooo`80
00000P3oool2000000X0oooo300000080?ooo`H000000P3oool2000000@0oooo0P0000020?ooo`80
0000103oool2000000@0oooo100000020?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`<0
0000103oool4000000@0oooo100000020?ooo`@00000103oool2000000@0oooo100000020?ooo`80
0000103oool4000000H0oooo0P0000020?ooo`H000000P3oool?0=7=Z@003@3AcJT20?ooo`800000
4P3oool200000180oooo100000040?ooo`8000001P3oool200000080oooo100000000`3oool00000
0000000400000080oooo0P0000060?ooo`800000103oool200000080oooo100000020?ooo`H00000
0P3oool6000001@0oooo100000040?ooo`8000000P3oool200000080oooo0P0000020?ooo`@00000
0P3oool2000000P0oooo100000020?ooo`@000001P3oool200000080oooo0P0000040?ooo`800000
1@3oool2000000@0oooo0P0000020?ooo`P000001P3oool6000000@0oooo0P0000040?ooo`@00000
0P3oool200000080oooo2P0000040?ooo`800000103oool:000000@0oooo100000020?ooo`@00000
0P3oool200000080oooo100000020?ooo`@000001P3oool400000080oooo100000020?ooo`800000
1`3oool200000080oooo100000060?ooo`8000000P3oool400000080oooo100000060?ooo`H00000
2P3oool4000000@0oooo0P00000?0=7=Z@003@3AcJT20?ooo`8000004P3oool200000180oooo1000
00040?ooo`8000001P3oool200000080oooo100000000`3oool000000000000400000080oooo0P00
00060?ooo`800000103oool200000080oooo100000020?ooo`H000000P3oool6000001@0oooo1000
00040?ooo`8000000P3oool200000080oooo0P0000020?ooo`@000000P3oool2000000P0oooo1000
00020?ooo`@000001P3oool200000080oooo0P0000040?ooo`8000001@3oool2000000@0oooo0P00
00020?ooo`P000001P3oool6000000@0oooo0P0000040?ooo`@000000P3oool200000080oooo2P00
00040?ooo`800000103oool:000000@0oooo100000020?ooo`@000000P3oool200000080oooo1000
00020?ooo`@000001P3oool400000080oooo100000020?ooo`8000001`3oool200000080oooo1000
00060?ooo`8000000P3oool400000080oooo100000060?ooo`H000002P3oool4000000@0oooo0P00
000?0=7=Z@003@3AcJT400000080oooo4P0000020?oooa800000203oool800000080oooo0P000005
0?ooo`8000001P3oool800000080oooo100000020?ooo`8000001P3oool2000000H0oooo0P00000H
0?ooo`8000000P3oool400000080oooo0P0000020?ooo`8000000P3oool2000000H0oooo2P000006
0?ooo`8000000P3oool600000080oooo0P0000020?ooo`@000000P3oool500000080oooo10000002
0?ooo`800000103oool200000080oooo1P0000040?ooo`H000000P3oool4000000H0oooo10000004
0?ooo`800000203oool6000000@0oooo0P0000080?ooo`8000000P3oool2000000H0oooo10000006
0?ooo`8000000P3oool6000000H0oooo0P0000020?ooo`80000000<0oooo0000000000001P000002
0?ooo`8000002P3oool4000000H0oooo0P0000020?ooo`H00000103oool<000000P0oooo3`3AcJT0
00d0dLfY100000020?oooa8000000P3ooolB000000P0oooo200000020?ooo`8000001@3oool20000
00H0oooo200000020?ooo`@000000P3oool2000000H0oooo0P0000060?ooo`800000603oool20000
0080oooo100000020?ooo`8000000P3oool200000080oooo0P0000060?ooo`X000001P3oool20000
0080oooo1P0000020?ooo`8000000P3oool400000080oooo1@0000020?ooo`@000000P3oool20000
00@0oooo0P0000020?ooo`H00000103oool600000080oooo100000060?ooo`@00000103oool20000
00P0oooo1P0000040?ooo`800000203oool200000080oooo0P0000060?ooo`@000001P3oool20000
0080oooo1P0000060?ooo`8000000P3oool2000000030?ooo`000000000000H000000P3oool20000
00X0oooo100000060?ooo`8000000P3oool6000000@0oooo300000080?ooo`l0dLfY000=0=7=Z@80
00001P3oool2000000@0oooo0P0000040?ooo`8000001P3oool2000000@0oooo0P0000040?ooo`80
0000303oool2000000@0oooo100000020?ooo`D000000P3oool6000000@0oooo0P0000020?ooo`80
00001P3oool800000080oooo1P0000020?oooaP000000P3oool2000000H0oooo100000020?ooo`80
00000P3oool6000000@0oooo0P00000:0?ooo`@00000103oool400000080oooo0P0000050?ooo`80
00001P3oool200000080oooo0P0000020?ooo`@000000P3oool2000000@0oooo1P0000040?ooo`@0
00002P3oool200000080oooo100000020?ooo`P00000103oool600000080oooo200000020?ooo`80
00000P3oool6000000X0oooo100000040?ooo`P000000P3oool2000000030?ooo`000000000000@0
oooo0P0000020?ooo`8000000P3oool:000000X0oooo100000040?ooo`H00000103oool2000000@0
oooo2000000?0=7=Z@003@3AcJT2000000H0oooo0P0000040?ooo`800000103oool2000000H0oooo
0P0000040?ooo`800000103oool2000000`0oooo0P0000040?ooo`@000000P3oool500000080oooo
1P0000040?ooo`8000000P3oool2000000H0oooo200000020?ooo`H000000P3ooolH00000080oooo
0P0000060?ooo`@000000P3oool200000080oooo1P0000040?ooo`8000002P3oool4000000@0oooo
100000020?ooo`8000001@3oool2000000H0oooo0P0000020?ooo`8000000P3oool400000080oooo
0P0000040?ooo`H00000103oool4000000X0oooo0P0000020?ooo`@000000P3oool8000000@0oooo
1P0000020?ooo`P000000P3oool200000080oooo1P00000:0?ooo`@00000103oool800000080oooo
0P0000000`3oool00000000000040?ooo`8000000P3oool200000080oooo2P00000:0?ooo`@00000
103oool6000000@0oooo0P0000040?ooo`P000003`3AcJT000d0dLfY2P3oool600000080oooo1000
00020?ooo`H000000P3oool400000080oooo100000020?ooo``000000P3oool4000000D0oooo0P00
00060?ooo`800000203oool400000080oooo1P0000040?ooo`8000000P3oool2000000@0oooo1000
00040?ooo`800000103oool2000000@0oooo0P0000040?ooo`@000000P3oool6000000H0oooo1000
00040?ooo`H000000P3oool:000000P0oooo0P0000020?ooo`8000000P3oool500000080oooo1P00
00020?ooo`8000000P3oool2000000H0oooo1P0000040?ooo`H000003P3oool4000000H0oooo0P00
00040?ooo`H00000103oool4000000@0oooo0P0000020?ooo`8000000P3oool2000000@0oooo3000
00080?ooo`800000103oool4000000030?ooo`00000000000080oooo100000020?ooo`8000000P3o
ool2000000@0oooo0P00000>0?ooo`8000000P3oool4000000@0oooo1P0000020?ooo`@00000103o
ool2000000l0dLfY000=0=7=Z@X0oooo1P0000020?ooo`@000000P3oool600000080oooo10000002
0?ooo`@000000P3oool<00000080oooo100000050?ooo`8000001P3oool2000000P0oooo10000002
0?ooo`H00000103oool200000080oooo0P0000040?ooo`@00000103oool2000000@0oooo0P000004
0?ooo`800000103oool400000080oooo1P0000060?ooo`@00000103oool600000080oooo2P000008
0?ooo`8000000P3oool200000080oooo1@0000020?ooo`H000000P3oool200000080oooo0P000006
0?ooo`H00000103oool6000000h0oooo100000060?ooo`800000103oool6000000@0oooo10000004
0?ooo`8000000P3oool200000080oooo0P0000040?ooo``00000203oool2000000@0oooo10000000
0`3oool00000000000020?ooo`@000000P3oool200000080oooo0P0000040?ooo`8000003P3oool2
00000080oooo100000040?ooo`H000000P3oool4000000@0oooo0P00000?0=7=Z@003@3AcJT20?oo
o`X00000103oool4000000H0oooo0P0000060?ooo`8000000P3oool2000000H0oooo0P0000040?oo
o`8000001P3oool200000080oooo1@0000020?ooo`H000000P3oool8000000H0oooo0P0000080?oo
o`@000000P3oool4000000P0oooo1P0000020?ooo`@000000P3oool4000000H0oooo0P00000:0?oo
o`8000000P3oool4000000@0oooo100000040?ooo`800000303oool400000080oooo0P0000030?oo
o`@00000103oool400000080oooo0P0000020?ooo`H00000103oool6000000@0oooo4000000:0?oo
o`H00000103oool6000000P0oooo100000020?ooo`8000000P3oool4000000@0oooo0P0000040?oo
o`X000000P3oool4000000D0oooo100000060?ooo`@000000P3oool400000080oooo3P0000020?oo
o`800000203oool2000000H0oooo0P0000020?ooo`@000003`3AcJT000d0dLfY0P3oool:000000@0
oooo100000060?ooo`8000001P3oool200000080oooo0P0000060?ooo`800000103oool2000000H0
oooo0P0000020?ooo`D000000P3oool600000080oooo200000060?ooo`800000203oool400000080
oooo100000080?ooo`H000000P3oool400000080oooo100000060?ooo`8000002P3oool200000080
oooo100000040?ooo`@00000103oool2000000`0oooo100000020?ooo`8000000`3oool4000000@0
oooo100000020?ooo`8000000P3oool6000000@0oooo1P0000040?oooa0000002P3oool6000000@0
oooo1P0000080?ooo`@000000P3oool200000080oooo100000040?ooo`800000103oool:00000080
oooo100000050?ooo`@000001P3oool400000080oooo100000020?ooo`h000000P3oool2000000P0
oooo0P0000060?ooo`8000000P3oool4000000l0dLfY000=0=7=Z@@00000103oool2000000P0oooo
0P0000020?ooo`H000000P3oool600000080oooo0P0000020?ooo`H000000P3oool400000080oooo
1P0000020?ooo`8000000`3oool4000000@0oooo100000040?ooo`8000000P3oool600000080oooo
200000060?ooo`8000000P3oool8000000@0oooo100000060?ooo`8000000P3oool600000080oooo
2P0000020?ooo`800000203oool200000080oooo100000020?ooo``000001P3oool5000000P0oooo
0P0000020?ooo`8000000P3oool2000000@0oooo1P0000040?ooo`H00000103oool2000000@0oooo
0P00000>0?ooo`800000203oool2000000`0oooo0P0000020?ooo`8000000P3oool2000000P0oooo
1P0000040?ooo`8000001P3oool200000080oooo1@00000:0?ooo`8000000P3oool2000000H0oooo
0P0000040?ooo`800000103oool400000080oooo200000020?ooo`H000000P3oool200000080oooo
3`3AcJT000d0dLfY100000040?ooo`800000203oool200000080oooo1P0000020?ooo`H000000P3o
ool200000080oooo1P0000020?ooo`@000000P3oool600000080oooo0P0000030?ooo`@00000103o
ool4000000@0oooo0P0000020?ooo`H000000P3oool8000000H0oooo0P0000020?ooo`P00000103o
ool4000000H0oooo0P0000020?ooo`H000000P3oool:00000080oooo0P0000080?ooo`8000000P3o
ool400000080oooo300000060?ooo`D00000203oool200000080oooo0P0000020?ooo`800000103o
ool6000000@0oooo1P0000040?ooo`800000103oool2000000h0oooo0P0000080?ooo`800000303o
ool200000080oooo0P0000020?ooo`800000203oool6000000@0oooo0P0000060?ooo`8000000P3o
ool5000000X0oooo0P0000020?ooo`8000001P3oool2000000@0oooo0P0000040?ooo`@000000P3o
ool800000080oooo1P0000020?ooo`8000000P3oool?0=7=Z@003@3AcJT2000000P0oooo2P000002
0?ooo`800000103oool4000000@0oooo100000020?ooo`800000103oool4000000H0oooo0P000006
0?ooo`D00000203oool200000080oooo100000020?ooo`800000103oool4000000@0oooo0P000002
0?ooo`H000000P3oool2000000@0oooo0P0000020?ooo`@000002P3oool4000000@0oooo10000004
0?ooo`8000001P3oool:00000080oooo0P0000060?ooo`800000103oool2000000T0oooo0P00000<
0?ooo`@000000P3oool200000080oooo100000040?ooo`H00000103oool600000080oooo10000002
0?ooo`h000000P3oool800000080oooo300000020?ooo`8000000P3oool200000080oooo20000004
0?ooo`H000000P3oool600000080oooo00<000000?ooo`3oool00P3oool<00000080oooo0P000002
0?ooo`H000000P3oool400000080oooo100000060?ooo`800000103oool4000000@0oooo10000002
0?ooo`l0dLfY000=0=7=Z@800000203oool:00000080oooo0P0000040?ooo`@00000103oool40000
0080oooo0P0000040?ooo`@000001P3oool2000000H0oooo1@0000080?ooo`8000000P3oool40000
0080oooo0P0000040?ooo`@00000103oool200000080oooo1P0000020?ooo`800000103oool20000
0080oooo1000000:0?ooo`@00000103oool4000000@0oooo0P0000060?ooo`X000000P3oool20000
00H0oooo0P0000040?ooo`8000002@3oool2000000`0oooo100000020?ooo`8000000P3oool40000
00@0oooo1P0000040?ooo`H000000P3oool400000080oooo3P0000020?ooo`P000000P3oool<0000
0080oooo0P0000020?ooo`8000000P3oool8000000@0oooo1P0000020?ooo`H000000P3oool00`00
0000oooo0?ooo`020?ooo``000000P3oool200000080oooo1P0000020?ooo`@000000P3oool40000
00H0oooo0P0000040?ooo`@00000103oool400000080oooo3`3AcJT000d0dLfY0P3oool:000000@0
oooo0P0000060?ooo`H00000203oool200000080oooo0P0000020?ooo`@000002P3oool7000000@0
oooo2P0000020?ooo`8000001P3oool6000000P0oooo100000040?ooo`@000000P3oool400000080
oooo0P00000>0?ooo`8000000P3oool4000000P0oooo200000040?ooo`8000001P3oool800000080
oooo100000020?ooo`T000000P3oool<000000H0oooo100000080?ooo`800000203oool2000000H0
oooo0P0000020?ooo`800000103oool2000000@0oooo0P0000020?ooo`800000103oool200000080
oooo0P0000040?ooo`800000103oool400000080oooo0P0000020?ooo`800000103oool200000080
oooo100000040?ooo`@00000103oool300000080oooo100000040?ooo`800000103oool400000080
oooo0P0000040?ooo`@000001P3oool200000080oooo1P0000020?ooo`@00000203oool200000080
oooo3`3AcJT000d0dLfY0P3oool:000000@0oooo0P0000060?ooo`H00000203oool200000080oooo
0P0000020?ooo`@000002P3oool7000000@0oooo2P0000020?ooo`8000001P3oool6000000P0oooo
100000040?ooo`@000000P3oool400000080oooo0P00000>0?ooo`8000000P3oool4000000P0oooo
200000040?ooo`8000001P3oool800000080oooo100000020?ooo`T000000P3oool<000000H0oooo
100000080?ooo`800000203oool2000000H0oooo0P0000020?ooo`800000103oool2000000@0oooo
0P0000020?ooo`800000103oool200000080oooo0P0000040?ooo`800000103oool400000080oooo
0P0000020?ooo`800000103oool200000080oooo100000040?ooo`@00000103oool300000080oooo
100000040?ooo`800000103oool400000080oooo0P0000040?ooo`@000001P3oool200000080oooo
1P0000020?ooo`@00000203oool200000080oooo3`3AcJT000d0dLfY100000040?ooo`800000203o
ool8000000@0oooo2P0000020?ooo`8000000P3oool2000000h0oooo0P0000030?ooo`H00000103o
ool2000000H0oooo200000040?ooo`X00000203oool200000080oooo0P0000060?oooa0000000P3o
ool2000000`0oooo0P0000040?ooo`H000000P3oool6000000@0oooo0P0000020?ooo`8000001P3o
ool2000000<0oooo0P0000020?ooo`800000103oool2000000@0oooo2000000<0?ooo`X000000P3o
ool600000080oooo0P0000020?ooo`@000000P3oool400000080oooo0P0000020?ooo`@000000P3o
ool200000080oooo100000020?ooo`@000001P3oool400000080oooo100000020?ooo`800000203o
ool200000080oooo100000050?ooo`8000000P3oool400000080oooo100000060?ooo`H000002P3o
ool4000000@0oooo1000000<0?ooo`8000003`3AcJT000d0dLfY0P3oool200000080oooo10000002
0?ooo`P00000103oool200000080oooo100000040?ooo`8000001P3oool400000080oooo3P000002
0?ooo`<00000103oool600000080oooo1P0000040?ooo`8000000P3oool4000000@0oooo0P00000<
0?ooo`@000000P3oool6000000@0oooo0P0000040?ooo`8000001P3oool>00000080oooo10000004
0?ooo`@00000103oool600000080oooo0P0000020?ooo`H000000P3oool300000080oooo0P000002
0?ooo`@000000P3oool4000000@0oooo0P0000020?ooo``00000103oool2000000H0oooo0P000006
0?ooo`@000001P3oool200000080oooo0P0000020?ooo`8000001P3oool4000000H0oooo0P000002
0?ooo`H000001P3oool200000080oooo0P0000020?ooo`P000000P3oool2000000T0oooo10000006
0?ooo`8000000P3oool6000000@0oooo300000080?ooo`8000000P3oool<000000l0dLfY000=0=7=
Z@80oooo0P0000020?ooo`@000000P3oool8000000@0oooo0P0000020?ooo`@00000103oool20000
00H0oooo100000020?ooo`h000000P3oool3000000@0oooo1P0000020?ooo`H00000103oool20000
0080oooo100000040?ooo`800000303oool400000080oooo1P0000040?ooo`800000103oool20000
00H0oooo3P0000020?ooo`@00000103oool4000000@0oooo1P0000020?ooo`8000000P3oool60000
0080oooo0`0000020?ooo`8000000P3oool400000080oooo100000040?ooo`8000000P3oool<0000
00@0oooo0P0000060?ooo`8000001P3oool4000000H0oooo0P0000020?ooo`8000000P3oool20000
00H0oooo100000060?ooo`8000000P3oool6000000H0oooo0P0000020?ooo`8000000P3oool80000
0080oooo0P0000090?ooo`@000001P3oool200000080oooo1P0000040?ooo``00000203oool20000
0080oooo3000000?0=7=Z@003@3AcJT40?ooo`@000001P3oool2000000@0oooo1P0000020?ooo`80
0000203oool8000000H0oooo0P0000040?ooo`800000103oool3000000P0oooo0P0000060?ooo`80
0000203oool4000000P0oooo3P0000060?ooo`800000203oool600000080oooo1P0000040?ooo`80
0000103oool200000080oooo0P0000080?ooo`8000000P3oool4000000@0oooo100000020?ooo`80
0000103oool3000000H0oooo100000060?ooo`8000000P3oool400000080oooo0P0000040?ooo`80
0000103oool600000080oooo1P0000020?ooo`H000002P3oool400000080oooo0P0000020?ooo`H0
00002P3oool4000000@0oooo200000020?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`80
00000P3oool9000000X0oooo100000040?ooo`H00000103oool2000000@0oooo2P0000020?ooo`80
0000103oool2000000@0oooo3`3AcJT000d0dLfY103oool4000000H0oooo0P0000040?ooo`H00000
0P3oool2000000P0oooo200000060?ooo`800000103oool2000000@0oooo0`0000080?ooo`800000
1P3oool2000000P0oooo100000080?ooo`h000001P3oool2000000P0oooo1P0000020?ooo`H00000
103oool2000000@0oooo0P0000020?ooo`800000203oool200000080oooo100000040?ooo`@00000
0P3oool2000000@0oooo0`0000060?ooo`@000001P3oool200000080oooo100000020?ooo`800000
103oool2000000@0oooo1P0000020?ooo`H000000P3oool6000000X0oooo100000020?ooo`800000
0P3oool6000000X0oooo100000040?ooo`P000000P3oool200000080oooo0P0000040?ooo`800000
0P3oool200000080oooo2@00000:0?ooo`@00000103oool6000000@0oooo0P0000040?ooo`X00000
0P3oool2000000@0oooo0P0000040?ooo`l0dLfY000=0=7=Z@H000002P3oool6000000@0oooo1000
00020?ooo`P00000103oool200000080oooo1P0000020?ooo`@000000P3oool4000000/0oooo2000
00020?ooo`P00000303oool2000000@0oooo0P0000040?ooo`P000000P3oool8000000@0oooo1000
00040?ooo`H000000P3oool400000080oooo0P0000020?ooo`P000000P3oool2000000P0oooo0P00
00020?ooo`8000000P3oool4000000T0oooo0P0000020?ooo`H000000P3oool2000000H0oooo1P00
00020?ooo`@00000103oool4000000@0oooo100000040?ooo``000001P3oool4000000@0oooo3000
00080?ooo`800000103oool400000080oooo0P0000020?ooo`@000000P3oool200000080oooo00<0
00000?ooo`3oool00P3oool2000000h0oooo0P0000020?ooo`@00000103oool600000080oooo1000
00040?ooo`8000001P3oool600000080oooo0P00000?0=7=Z@003@3AcJT6000000X0oooo1P000004
0?ooo`@000000P3oool8000000@0oooo0P0000020?ooo`H000000P3oool400000080oooo1000000;
0?ooo`P000000P3oool8000000`0oooo0P0000040?ooo`800000103oool800000080oooo20000004
0?ooo`@00000103oool600000080oooo100000020?ooo`8000000P3oool800000080oooo0P000008
0?ooo`8000000P3oool200000080oooo100000090?ooo`8000000P3oool600000080oooo0P000006
0?ooo`H000000P3oool4000000@0oooo100000040?ooo`@00000103oool<000000H0oooo10000004
0?ooo``00000203oool2000000@0oooo100000020?ooo`8000000P3oool400000080oooo0P000002
0?ooo`030000003oool0oooo0080oooo0P00000>0?ooo`8000000P3oool4000000@0oooo1P000002
0?ooo`@00000103oool2000000H0oooo1P0000020?ooo`8000003`3AcJT000d0dLfY0P3oool20000
00h0oooo0P0000080?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`@000000P3oool20000
00@0oooo100000060?ooo`80000000<0oooo0000000000002P0000040?ooo`8000000P3oool20000
00@0oooo0P0000020?ooo``000000P3oool400000080oooo100000040?ooo`8000000P3oool20000
00@0oooo0P0000020?ooo`@00000203oool2000000H0oooo0P0000020?ooo`8000000P3oool20000
00@0oooo0P0000020?ooo`8000000P3oool800000080oooo0P0000020?ooo`8000003@3oool40000
00@0oooo100000020?ooo`H00000103oool4000000P0oooo0P0000020?ooo`@00000203oool20000
00@0oooo0P00000:0?ooo`8000000P3oool4000000@0oooo0P0000040?ooo`X000000P3oool40000
00H0oooo100000060?ooo`<000000P3oool400000080oooo3P0000020?ooo`800000203oool20000
00H0oooo0P0000020?ooo`@000000P3oool6000000@0oooo1000000?0=7=Z@003@3AcJT20?ooo`80
00003P3oool2000000P0oooo0P0000020?ooo`800000103oool200000080oooo100000020?ooo`80
0000103oool4000000H0oooo0P0000000`3oool000000000000:000000@0oooo0P0000020?ooo`80
0000103oool200000080oooo300000020?ooo`@000000P3oool4000000@0oooo0P0000020?ooo`80
0000103oool200000080oooo100000080?ooo`8000001P3oool200000080oooo0P0000020?ooo`80
0000103oool200000080oooo0P0000020?ooo`P000000P3oool200000080oooo0P00000=0?ooo`@0
0000103oool400000080oooo1P0000040?ooo`@00000203oool200000080oooo100000080?ooo`80
0000103oool2000000X0oooo0P0000020?ooo`@00000103oool2000000@0oooo2P0000020?ooo`@0
00001P3oool4000000H0oooo0`0000020?ooo`@000000P3oool>00000080oooo0P0000080?ooo`80
00001P3oool200000080oooo100000020?ooo`H00000103oool4000000l0dLfY000=0=7=Z@@00000
0P3oool>00000080oooo200000020?ooo`8000000P3oool400000080oooo0P0000060?ooo`H00000
2P3oool3000000@0oooo0P0000040?ooo`H000000P3oool200000080oooo100000020?ooo`800000
103oool2000000@0oooo100000060?ooo`8000000P3oool400000080oooo0P0000020?ooo`@00000
0P3oool2000000`0oooo200000020?ooo`8000000P3oool200000080oooo100000020?ooo`800000
0P3oool2000000@0oooo0P0000020?ooo`8000000P3oool200000080oooo3@0000080?ooo`800000
0P3oool2000000@0oooo1P00000<0?ooo`@00000303oool600000080oooo2P0000020?ooo`800000
203oool6000000@0oooo0P0000060?ooo`8000000P3oool6000000X0oooo00<000000?ooo`3oool0
0P0000060?ooo`800000103oool2000000@0oooo100000020?ooo`P000000P3oool600000080oooo
0P0000060?ooo`800000203oool2000000l0dLfY000=0=7=Z@@000000P3oool>00000080oooo2000
00020?ooo`8000000P3oool400000080oooo0P0000060?ooo`H000002P3oool3000000@0oooo0P00
00040?ooo`H000000P3oool200000080oooo100000020?ooo`800000103oool2000000@0oooo1000
00060?ooo`8000000P3oool400000080oooo0P0000020?ooo`@000000P3oool2000000`0oooo2000
00020?ooo`8000000P3oool200000080oooo100000020?ooo`8000000P3oool2000000@0oooo0P00
00020?ooo`8000000P3oool200000080oooo3@0000080?ooo`8000000P3oool2000000@0oooo1P00
000<0?ooo`@00000303oool600000080oooo2P0000020?ooo`800000203oool6000000@0oooo0P00
00060?ooo`8000000P3oool6000000X0oooo00<000000?ooo`3oool00P0000060?ooo`800000103o
ool2000000@0oooo100000020?ooo`P000000P3oool600000080oooo0P0000060?ooo`800000203o
ool2000000l0dLfY000=0=7=Z@80oooo0P0000020?ooo`800000103oool2000000@0oooo0P000002
0?ooo`800000103oool200000080oooo0P0000020?ooo`8000001P3oool8000000@0oooo2`000008
0?ooo`H00000103oool400000080oooo0P0000060?ooo`H000000P3oool4000000X0oooo10000006
0?ooo`@000001P3oool>000000@0oooo0P0000020?ooo`8000000P3oool200000080oooo0P000006
0?ooo`@000000P3oool400000080oooo0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`02
0?ooo`800000103oool200000080oooo200000020?ooo`8000000P3oool4000000@0oooo3P00000@
0?ooo`8000001P3oool2000000@0oooo0P0000020?ooo`8000000P3oool8000000@0oooo1P000002
0?ooo`H000000P3oool2000000@0oooo2`0000020?ooo`8000000P3oool600000080oooo10000002
0?ooo`@000001P3oool2000000@0oooo100000040?ooo`@000000P3oool600000080oooo2000000?
0=7=Z@003@3AcJT20?ooo`8000000P3oool2000000@0oooo0P0000040?ooo`8000000P3oool20000
00@0oooo0P0000020?ooo`8000000P3oool2000000H0oooo200000040?ooo`/00000203oool60000
00@0oooo100000020?ooo`8000001P3oool600000080oooo1000000:0?ooo`@000001P3oool40000
00H0oooo3P0000040?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000001P3oool40000
0080oooo100000020?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00P3oool20000
00@0oooo0P0000020?ooo`P000000P3oool200000080oooo100000040?ooo`h00000403oool20000
00H0oooo0P0000040?ooo`8000000P3oool200000080oooo200000040?ooo`H000000P3oool60000
0080oooo0P0000040?ooo`/000000P3oool200000080oooo1P0000020?ooo`@000000P3oool40000
00H0oooo0P0000040?ooo`@00000103oool400000080oooo1P0000020?ooo`P000003`3AcJT000d0
dLfY103oool400000080oooo100000020?ooo`@000000P3oool200000080oooo100000020?ooo`80
00000P3oool200000080oooo1P0000040?ooo`8000000P3oool4000000@0oooo0P0000030?ooo`X0
0000103oool6000000H0oooo200000040?ooo`@000003P3oool200000080oooo1P00000:0?ooo`80
0000103oool2000000@0oooo1P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`H0
00001P3oool200000080oooo0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`0400000080
oooo100000020?ooo`800000103oool200000080oooo0P0000020?ooo`800000203oool2000000@0
oooo0P0000040?oooa8000000P3oool600000080oooo100000020?ooo`8000000P3oool2000000@0
oooo0P0000020?ooo`@00000103oool4000000@0oooo100000020?ooo`@00000103oool2000000<0
oooo100000020?ooo`800000103oool4000000H0oooo0P0000020?ooo`H000000P3oool4000000P0
oooo0P0000020?ooo`800000103oool4000000@0oooo0P00000?0=7=Z@003@3AcJT40?ooo`@00000
0P3oool400000080oooo100000020?ooo`8000000P3oool400000080oooo0P0000020?ooo`800000
0P3oool6000000@0oooo0P0000020?ooo`@00000103oool2000000<0oooo2P0000040?ooo`H00000
1P3oool8000000@0oooo1000000>0?ooo`8000000P3oool6000000X0oooo0P0000040?ooo`800000
103oool600000080oooo0P0000020?ooo`8000000P3oool200000080oooo1P0000060?ooo`800000
0P3oool200000080oooo0P0000020?ooo`030000003oool0oooo00@000000P3oool400000080oooo
0P0000040?ooo`8000000P3oool200000080oooo0P0000080?ooo`800000103oool2000000@0oooo
4P0000020?ooo`H000000P3oool400000080oooo0P0000020?ooo`800000103oool200000080oooo
100000040?ooo`@00000103oool400000080oooo100000040?ooo`8000000`3oool400000080oooo
0P0000040?ooo`@000001P3oool200000080oooo1P0000020?ooo`@00000203oool200000080oooo
0P0000040?ooo`@00000103oool2000000l0dLfY000=0=7=Z@H000001P3oool200000080oooo0P00
00060?ooo`@000001P3oool400000080oooo0P0000040?ooo`H000000P3oool2000000P0oooo1@00
00040?ooo`800000203oool2000000X0oooo0P0000040?ooo`H000004P3oool4000000@0oooo3000
00020?ooo`@000000P3oool4000000@0oooo100000020?ooo`8000000P3oool200000080oooo0P00
00040?ooo`P000000P3oool200000080oooo0P0000020?ooo`030000003oool0oooo008000001P3o
ool200000080oooo0P0000020?ooo`@000000P3oool200000080oooo0P0000020?ooo`P000000P3o
ool400000080oooo100000040?ooo`800000103oool2000000@0oooo100000040?ooo`@000001P3o
ool400000080oooo100000020?ooo`800000203oool200000080oooo100000060?ooo`8000000P3o
ool400000080oooo0`0000060?ooo`H000002P3oool4000000@0oooo1000000<0?ooo`@000000P3o
ool4000000P0oooo3`3AcJT000d0dLfY1P0000060?ooo`8000000P3oool2000000H0oooo10000006
0?ooo`@000000P3oool2000000@0oooo1P0000020?ooo`800000203oool5000000@0oooo0P000008
0?ooo`8000002P3oool2000000@0oooo1P00000B0?ooo`@00000103oool<00000080oooo10000002
0?ooo`@00000103oool400000080oooo0P0000020?ooo`8000000P3oool2000000@0oooo20000002
0?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00P0000060?ooo`8000000P3oool2
00000080oooo100000020?ooo`8000000P3oool200000080oooo200000020?ooo`@000000P3oool4
000000@0oooo0P0000040?ooo`800000103oool4000000@0oooo100000060?ooo`@000000P3oool4
00000080oooo0P0000080?ooo`8000000P3oool4000000H0oooo0P0000020?ooo`@000000P3oool3
000000H0oooo1P00000:0?ooo`@00000103oool4000000`0oooo100000020?ooo`@00000203oool?
0=7=Z@003@3AcJT20?ooo`8000002P3oool400000080oooo1P00000:0?ooo`8000000P3oool20000
0080oooo100000040?ooo`@000000P3oool8000000<0oooo1P0000020?ooo`P000000P3oool:0000
0080oooo100000040?oooa@00000203oool2000000@0oooo0P0000060?ooo`8000000P3oool20000
00P0oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`@00000103oool20000
0080oooo0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`0200000080oooo1P0000020?oo
o`8000000P3oool2000000H0oooo100000020?ooo`800000103oool200000080oooo0P0000060?oo
o`8000000P3oool400000080oooo100000020?ooo`@00000203oool200000080oooo1P0000060?oo
o`8000000P3oool200000080oooo200000020?ooo`8000002P3oool4000000D0oooo0P0000020?oo
o`H00000103oool<000000P0oooo0P0000020?ooo``000001P3oool200000080oooo1P00000?0=7=
Z@003@3AcJT20?ooo`8000002P3oool400000080oooo1P00000:0?ooo`8000000P3oool200000080
oooo100000040?ooo`@000000P3oool8000000<0oooo1P0000020?ooo`P000000P3oool:00000080
oooo100000040?oooa@00000203oool2000000@0oooo0P0000060?ooo`8000000P3oool2000000P0
oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`@00000103oool200000080
oooo0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`0200000080oooo1P0000020?ooo`80
00000P3oool2000000H0oooo100000020?ooo`800000103oool200000080oooo0P0000060?ooo`80
00000P3oool400000080oooo100000020?ooo`@00000203oool200000080oooo1P0000060?ooo`80
00000P3oool200000080oooo200000020?ooo`8000002P3oool4000000D0oooo0P0000020?ooo`H0
0000103oool<000000P0oooo0P0000020?ooo``000001P3oool200000080oooo1P00000?0=7=Z@00
3@3AcJT40?ooo``000001P3oool2000000h0oooo100000020?ooo`800000203oool200000080oooo
0P0000040?ooo`80000000<0oooo0000000000000P0000040?ooo`@00000103oool200000080oooo
0P0000040?ooo`8000001P3oool200000080oooo100000040?ooo`800000103oool2000000@0oooo
0P0000020?ooo`P000000P3oool400000080oooo1P0000020?ooo`8000000P3oool800000080oooo
0P0000020?ooo`8000000P3oool200000080oooo0P0000080?ooo`@000000P3oool200000080oooo
00<000000?ooo`3oool00P0000020?ooo`800000103oool400000080oooo0P0000020?ooo`H00000
1P3oool600000080oooo0P0000020?ooo`H000000P3oool2000000H0oooo0P0000020?ooo`800000
303oool4000000@0oooo200000020?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`800000
0P3oool:000000T0oooo100000040?ooo`H00000103oool2000000@0oooo2P0000020?ooo`800000
103oool2000000@0oooo200000020?ooo`800000103oool?0=7=Z@003@3AcJT40?ooo``000001P3o
ool2000000h0oooo100000020?ooo`800000203oool200000080oooo0P0000040?ooo`80000000<0
oooo0000000000000P0000040?ooo`@00000103oool200000080oooo0P0000040?ooo`8000001P3o
ool200000080oooo100000040?ooo`800000103oool2000000@0oooo0P0000020?ooo`P000000P3o
ool400000080oooo1P0000020?ooo`8000000P3oool800000080oooo0P0000020?ooo`8000000P3o
ool200000080oooo0P0000080?ooo`@000000P3oool200000080oooo00<000000?ooo`3oool00P00
00020?ooo`800000103oool400000080oooo0P0000020?ooo`H000001P3oool600000080oooo0P00
00020?ooo`H000000P3oool2000000H0oooo0P0000020?ooo`800000303oool4000000@0oooo2000
00020?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`8000000P3oool:000000T0oooo1000
00040?ooo`H00000103oool2000000@0oooo2P0000020?ooo`800000103oool2000000@0oooo2000
00020?ooo`800000103oool?0=7=Z@003@3AcJT6000000@0oooo0P0000040?ooo`P000000P3oool>
000000H0oooo2P0000020?ooo`8000000P3oool4000000030?ooo`000000000000P0oooo0P000002
0?ooo`@000000P3oool200000080oooo100000020?ooo`H000000P3oool2000000P0oooo1P000002
0?ooo`@000000P3oool2000000@0oooo0P0000020?ooo`8000001P3oool2000000H0oooo10000004
0?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo20000006
0?ooo`<000000P3oool200000080oooo0P0000020?ooo`@000001P3oool4000000@0oooo20000004
0?ooo`@000000P3oool2000000@0oooo100000020?ooo`H000000P3oool200000080oooo30000008
0?ooo`800000103oool400000080oooo0P0000020?ooo`@000000P3oool200000080oooo0P000004
0?ooo`8000003@3oool200000080oooo100000040?ooo`H000000P3oool4000000@0oooo0P000006
0?ooo`H000000P3oool4000000@0oooo0P0000020?ooo`8000000P3oool2000000l0dLfY000=0=7=
Z@H00000103oool2000000@0oooo200000020?ooo`h000001P3oool:00000080oooo0P0000020?oo
o`@0000000<0oooo000000000000203oool200000080oooo100000020?ooo`8000000P3oool40000
0080oooo1P0000020?ooo`800000203oool600000080oooo100000020?ooo`800000103oool20000
0080oooo0P0000060?ooo`8000001P3oool4000000@0oooo0P0000020?ooo`8000000P3oool20000
0080oooo0P0000020?ooo`8000000P3oool8000000H0oooo0`0000020?ooo`8000000P3oool20000
0080oooo100000060?ooo`@00000103oool8000000@0oooo100000020?ooo`800000103oool40000
0080oooo1P0000020?ooo`8000000P3oool<000000P0oooo0P0000040?ooo`@000000P3oool20000
0080oooo100000020?ooo`8000000P3oool2000000@0oooo0P00000=0?ooo`8000000P3oool40000
00@0oooo1P0000020?ooo`@00000103oool2000000H0oooo1P0000020?ooo`@00000103oool20000
0080oooo0P0000020?ooo`8000003`3AcJT000d0dLfY0P3oool2000000P0oooo1P0000040?ooo`80
00000P3oool2000000@0oooo0P0000040?ooo`8000000P3oool6000000@0oooo0P0000060?ooo`@0
00001@3oool:00000080oooo0P0000060?ooo`@000001P3oool2000000H0oooo2P0000040?ooo`@0
00001P3oool600000080oooo0P0000020?ooo`H000000P3oool6000000P0oooo100000020?ooo`80
00000P3oool200000080oooo0P0000020?ooo`800000103oool200000080oooo1P0000050?ooo`@0
00000P3oool2000000X0oooo0P0000020?ooo`@00000103oool200000080oooo100000060?ooo`H0
00001P3oool2000000H0oooo100000040?ooo`800000103oool:00000080oooo100000060?ooo`@0
00001P3oool400000080oooo100000020?ooo`d000000P3oool2000000P0oooo0P0000060?ooo`80
00000P3oool400000080oooo1P0000040?ooo`@00000203oool400000080oooo0P00000?0=7=Z@00
3@3AcJT20?ooo`800000203oool6000000@0oooo0P0000020?ooo`800000103oool2000000@0oooo
0P0000020?ooo`H00000103oool2000000H0oooo100000050?ooo`X000000P3oool2000000H0oooo
100000060?ooo`8000001P3oool:000000@0oooo100000060?ooo`H000000P3oool200000080oooo
1P0000020?ooo`H00000203oool400000080oooo0P0000020?ooo`8000000P3oool200000080oooo
0P0000040?ooo`8000000P3oool6000000D0oooo100000020?ooo`8000002P3oool200000080oooo
100000040?ooo`8000000P3oool4000000H0oooo1P0000060?ooo`8000001P3oool4000000@0oooo
0P0000040?ooo`X000000P3oool4000000H0oooo100000060?ooo`@000000P3oool400000080oooo
3@0000020?ooo`800000203oool2000000H0oooo0P0000020?ooo`@000000P3oool6000000@0oooo
100000080?ooo`@000000P3oool2000000l0dLfY000=0=7=Z@@0oooo2P0000040?ooo`H000000P3o
ool200000080oooo100000020?ooo`@000000P3oool2000000@0oooo1P0000020?ooo`H000002@3o
ool2000000@0oooo0P0000020?ooo`8000000P3oool6000000X0oooo200000040?ooo`800000203o
ool200000080oooo1P0000040?ooo`@000000P3oool2000000@0oooo100000040?ooo`X000001P3o
ool400000080oooo0P0000020?ooo`8000000P3oool400000080oooo0P0000040?ooo`L000001P3o
ool<00000080oooo0P0000080?ooo`@000002P3oool2000000X0oooo200000080?ooo`H00000103o
ool2000000H0oooo0P0000020?ooo`H000002P3oool200000080oooo0P0000060?ooo`8000000`3o
ool2000000@0oooo100000020?ooo`P000000P3oool600000080oooo0P0000060?ooo`800000203o
ool200000080oooo200000060?ooo`l0dLfY000=0=7=Z@@0oooo2P0000040?ooo`H000000P3oool2
00000080oooo100000020?ooo`@000000P3oool2000000@0oooo1P0000020?ooo`H000002@3oool2
000000@0oooo0P0000020?ooo`8000000P3oool6000000X0oooo200000040?ooo`800000203oool2
00000080oooo1P0000040?ooo`@000000P3oool2000000@0oooo100000040?ooo`X000001P3oool4
00000080oooo0P0000020?ooo`8000000P3oool400000080oooo0P0000040?ooo`L000001P3oool<
00000080oooo0P0000080?ooo`@000002P3oool2000000X0oooo200000080?ooo`H00000103oool2
000000H0oooo0P0000020?ooo`H000002P3oool200000080oooo0P0000060?ooo`8000000`3oool2
000000@0oooo100000020?ooo`P000000P3oool600000080oooo0P0000060?ooo`800000203oool2
00000080oooo200000060?ooo`l0dLfY000=0=7=Z@H00000103oool2000000P0oooo0P0000060?oo
o`@000001P3oool200000080oooo0P0000020?ooo`@00000103oool4000000@0oooo2`0000020?oo
o`@000000P3oool200000080oooo0P0000040?ooo``00000103oool200000080oooo100000020?oo
o`P000000P3oool2000000@0oooo1P0000060?ooo`H00000203oool2000000@0oooo0P0000020?oo
o`H000001P3oool400000080oooo0P0000060?ooo`D00000103oool200000080oooo1P0000040?oo
o`800000103oool400000080oooo2000000>0?ooo``00000103oool200000080oooo200000040?oo
o`H000000P3oool600000080oooo0P0000040?ooo``000000P3oool200000080oooo1P0000020?oo
o`<000000P3oool4000000H0oooo0P0000040?ooo`@00000103oool400000080oooo1P0000020?oo
o`P000000P3oool2000000@0oooo0P0000020?ooo`@000003`3AcJT000d0dLfY1P0000040?ooo`80
0000203oool2000000H0oooo100000060?ooo`8000000P3oool200000080oooo100000040?ooo`@0
0000103oool;00000080oooo100000020?ooo`8000000P3oool2000000@0oooo300000040?ooo`80
00000P3oool400000080oooo200000020?ooo`800000103oool6000000H0oooo1P0000080?ooo`80
0000103oool200000080oooo1P0000060?ooo`@000000P3oool2000000H0oooo1@0000040?ooo`80
00000P3oool6000000@0oooo0P0000040?ooo`@000000P3oool8000000h0oooo300000040?ooo`80
00000P3oool8000000@0oooo1P0000020?ooo`H000000P3oool2000000@0oooo300000020?ooo`80
00000P3oool600000080oooo0`0000020?ooo`@000001P3oool2000000@0oooo100000040?ooo`@0
00000P3oool600000080oooo200000020?ooo`800000103oool200000080oooo1000000?0=7=Z@00
3@3AcJT40?ooo`8000000P3oool400000080oooo200000020?ooo`H000002P3oool400000080oooo
0P0000080?ooo`8000000P3oool4000000<0oooo0P0000040?ooo`@000001P3oool400000080oooo
100000040?ooo`800000103oool600000080oooo0P0000060?ooo`800000103oool400000080oooo
100000040?ooo`P00000103oool:00000080oooo100000020?ooo`800000103oool8000000H0oooo
200000030?ooo`H000000P3oool2000000@0oooo1P0000020?ooo`@000001P3oool2000000@0oooo
400000040?ooo`800000103oool600000080oooo0P0000040?ooo`8000000P3oool4000000@0oooo
100000040?ooo`@000000P3oool4000000@0oooo0P0000040?ooo`@000000P3oool2000000@0oooo
0`0000060?ooo`8000000P3oool600000080oooo100000080?ooo`8000000P3oool2000000@0oooo
100000040?ooo`8000000P3oool200000080oooo100000020?ooo`8000000P3oool?0=7=Z@003@3A
cJT40?ooo`8000000P3oool400000080oooo200000020?ooo`H000002P3oool400000080oooo0P00
00080?ooo`8000000P3oool4000000<0oooo0P0000040?ooo`@000001P3oool400000080oooo1000
00040?ooo`800000103oool600000080oooo0P0000060?ooo`800000103oool400000080oooo1000
00040?ooo`P00000103oool:00000080oooo100000020?ooo`800000103oool8000000H0oooo2000
00030?ooo`H000000P3oool2000000@0oooo1P0000020?ooo`@000001P3oool2000000@0oooo4000
00040?ooo`800000103oool600000080oooo0P0000040?ooo`8000000P3oool4000000@0oooo1000
00040?ooo`@000000P3oool4000000@0oooo0P0000040?ooo`@000000P3oool2000000@0oooo0`00
00060?ooo`8000000P3oool600000080oooo100000080?ooo`8000000P3oool2000000@0oooo1000
00040?ooo`8000000P3oool200000080oooo100000020?ooo`8000000P3oool?0=7=Z@003@3AcJT2
0?ooo`@000000P3oool2000000H0oooo0P0000040?ooo`@00000103oool<000000H0oooo2P000002
0?ooo`8000001`3oool6000000X0oooo0P0000020?ooo`800000203oool6000000@0oooo10000002
0?ooo`H000000P3oool4000000H0oooo0P0000020?ooo`@00000103oool200000080oooo10000004
0?ooo`8000001P3oool200000080oooo0P0000020?ooo`@00000103oool200000080oooo1P000004
0?ooo`8000000P3oool3000000@0oooo100000020?ooo`@00000103oool4000000X0oooo1P000004
0?ooo`800000103oool2000000P0oooo1P0000040?ooo`@000000P3oool400000080oooo0P000008
0?ooo`8000000P3oool4000000H0oooo0P0000020?ooo`@000000P3oool4000000H0oooo1P000009
0?ooo`@00000103oool4000000`0oooo100000020?ooo`@00000203oool400000080oooo0P000006
0?ooo`8000003`3AcJT000d0dLfY0P3oool400000080oooo0P0000060?ooo`800000103oool40000
00@0oooo300000060?ooo`X000000P3oool2000000L0oooo1P00000:0?ooo`8000000P3oool20000
00P0oooo1P0000040?ooo`@000000P3oool600000080oooo100000060?ooo`8000000P3oool40000
00@0oooo0P0000020?ooo`@00000103oool2000000H0oooo0P0000020?ooo`8000000P3oool40000
00@0oooo0P0000020?ooo`H00000103oool200000080oooo0`0000040?ooo`@000000P3oool40000
00@0oooo1000000:0?ooo`H00000103oool2000000@0oooo0P0000080?ooo`H00000103oool40000
0080oooo100000020?ooo`800000203oool200000080oooo100000060?ooo`8000000P3oool40000
0080oooo100000060?ooo`H000002@3oool4000000@0oooo1000000<0?ooo`@000000P3oool40000
00P0oooo100000020?ooo`8000001P3oool2000000l0dLfY000=0=7=Z@80oooo0P0000060?ooo`P0
00000P3oool4000000P0oooo0P0000040?ooo`8000002P3oool2000000@0oooo0P0000020?ooo`80
00000P3oool7000000@0oooo300000020?ooo`8000000P3oool8000000@0oooo1P0000060?ooo`80
00001P3oool200000080oooo1P0000020?ooo`800000203oool4000000P0oooo200000020?ooo`80
00000P3oool2000000P0oooo100000040?ooo`H000000P3oool00`000000oooo0?ooo`060?ooo`80
00000P3oool2000000P0oooo0P0000020?ooo`X00000103oool600000080oooo100000020?ooo`P0
0000103oool6000000H0oooo0P0000020?ooo`8000000P3oool800000080oooo0P00000:0?ooo`@0
00001P3oool200000080oooo1P0000040?ooo`/00000203oool200000080oooo300000060?ooo`80
00000P3oool8000000H0oooo2000000?0=7=Z@003@3AcJT20?ooo`8000001P3oool800000080oooo
100000080?ooo`800000103oool2000000X0oooo0P0000040?ooo`8000000P3oool200000080oooo
1`0000040?ooo``000000P3oool200000080oooo200000040?ooo`H000001P3oool2000000H0oooo
0P0000020?ooo`H000000P3oool2000000P0oooo100000080?ooo`P000000P3oool200000080oooo
0P0000080?ooo`@00000103oool600000080oooo00<000000?ooo`3oool01P3oool200000080oooo
0P0000080?ooo`8000000P3oool:000000@0oooo1P0000020?ooo`@000000P3oool8000000@0oooo
1P0000060?ooo`8000000P3oool200000080oooo200000020?ooo`8000002P3oool4000000H0oooo
0P0000020?ooo`H00000103oool;000000P0oooo0P0000020?ooo``000001P3oool200000080oooo
200000060?ooo`P000003`3AcJT000d0dLfY100000020?ooo`H00000103oool200000080oooo0P00
000<0?ooo`H000000P3oool:00000080oooo100000020?ooo`8000000P3oool2000000<0oooo0P00
00020?ooo`@00000103oool2000000@0oooo100000020?ooo`800000103oool200000080oooo1000
00040?ooo`P000000P3oool600000080oooo0P0000040?ooo`@000000P3oool8000000`0oooo0P00
00040?ooo`@000000P3oool200000080oooo200000080?ooo`8000001@3oool:00000080oooo0P00
00020?ooo`P000000P3oool2000000@0oooo0P0000080?ooo`8000001P3oool200000080oooo0P00
00040?ooo`8000000P3oool4000000@0oooo200000020?ooo`8000000P3oool2000000@0oooo0P00
00020?ooo`8000000P3oool:000000X0oooo100000040?ooo`D00000103oool2000000@0oooo2P00
00020?ooo`800000103oool2000000@0oooo200000020?ooo`800000103oool200000080oooo1P00
00040?ooo`8000003`3AcJT000d0dLfY100000020?ooo`H00000103oool200000080oooo0P00000<
0?ooo`H000000P3oool:00000080oooo100000020?ooo`8000000P3oool2000000<0oooo0P000002
0?ooo`@00000103oool2000000@0oooo100000020?ooo`800000103oool200000080oooo10000004
0?ooo`P000000P3oool600000080oooo0P0000040?ooo`@000000P3oool8000000`0oooo0P000004
0?ooo`@000000P3oool200000080oooo200000080?ooo`8000001@3oool:00000080oooo0P000002
0?ooo`P000000P3oool2000000@0oooo0P0000080?ooo`8000001P3oool200000080oooo0P000004
0?ooo`8000000P3oool4000000@0oooo200000020?ooo`8000000P3oool2000000@0oooo0P000002
0?ooo`8000000P3oool:000000X0oooo100000040?ooo`D00000103oool2000000@0oooo2P000002
0?ooo`800000103oool2000000@0oooo200000020?ooo`800000103oool200000080oooo1P000004
0?ooo`8000003`3AcJT000d0dLfY0P0000060?ooo`800000203oool400000080oooo300000040?oo
o`@00000103oool2000000H0oooo0P0000020?ooo`8000000P3oool2000000030?ooo`0000000000
008000000P3oool2000000P0oooo1P0000060?ooo`H000000P3oool2000000P0oooo0P0000040?oo
o`@00000103oool400000080oooo100000060?ooo`800000103oool>00000080oooo100000060?oo
o`@00000103oool200000080oooo200000020?ooo`D00000103oool2000000H0oooo100000040?oo
o`8000000P3oool200000080oooo100000020?ooo`P000000P3oool600000080oooo0P0000020?oo
o`@000000P3oool2000000P0oooo0P0000040?ooo`@000000P3oool200000080oooo100000020?oo
o`8000000P3oool2000000@0oooo0P00000>0?ooo`8000000P3oool4000000<0oooo1P0000020?oo
o`@00000103oool2000000H0oooo1P0000020?ooo`@00000103oool200000080oooo0P0000020?oo
o`@000000P3oool2000000@0oooo1P00000?0=7=Z@003@3AcJT2000000H0oooo0P0000080?ooo`@0
00000P3oool<000000@0oooo100000040?ooo`8000001P3oool200000080oooo0P0000020?ooo`80
000000<0oooo0000000000000P0000020?ooo`800000203oool6000000H0oooo1P0000020?ooo`80
0000203oool2000000@0oooo100000040?ooo`@000000P3oool4000000H0oooo0P0000040?ooo`h0
00000P3oool4000000H0oooo100000040?ooo`8000000P3oool800000080oooo1@0000040?ooo`80
00001P3oool4000000@0oooo0P0000020?ooo`8000000P3oool400000080oooo200000020?ooo`H0
00000P3oool200000080oooo100000020?ooo`800000203oool2000000@0oooo100000020?ooo`80
00000P3oool400000080oooo0P0000020?ooo`800000103oool2000000h0oooo0P0000020?ooo`@0
00000`3oool600000080oooo100000040?ooo`8000001P3oool600000080oooo100000040?ooo`80
00000P3oool200000080oooo100000020?ooo`800000103oool6000000l0dLfY000=0=7=Z@800000
0P3oool600000080oooo200000060?ooo`800000103oool2000000P0oooo0P0000020?ooo`@00000
0P3oool600000080oooo0P0000020?ooo`80000000<0oooo0000000000001P3oool:000000@0oooo
200000040?ooo`@000000P3oool800000080oooo100000080?ooo`8000000P3oool2000000X0oooo
1P0000040?ooo`800000103oool200000080oooo0P00000:0?ooo`8000000P3oool400000080oooo
0P0000040?ooo`8000000P3oool2000000<0oooo1P0000020?ooo`H00000203oool400000080oooo
0P0000060?ooo`800000103oool4000000@0oooo100000020?ooo`8000001P3oool:00000080oooo
100000060?ooo`@000001P3oool400000080oooo100000020?ooo`h000000P3oool2000000L0oooo
0P0000060?ooo`8000000P3oool400000080oooo1P0000040?ooo`@00000203oool400000080oooo
0P0000060?ooo`H00000103oool?0=7=Z@003@3AcJT200000080oooo1P0000020?ooo`P000001P3o
ool2000000@0oooo0P0000080?ooo`8000000P3oool400000080oooo1P0000020?ooo`8000000P3o
ool2000000030?ooo`000000000000H0oooo2P0000040?ooo`P00000103oool400000080oooo2000
00020?ooo`@00000203oool200000080oooo0P00000:0?ooo`H00000103oool2000000@0oooo0P00
00020?ooo`8000002P3oool200000080oooo100000020?ooo`800000103oool200000080oooo0P00
00030?ooo`H000000P3oool6000000P0oooo100000020?ooo`8000001P3oool2000000@0oooo1000
00040?ooo`@000000P3oool2000000H0oooo2P0000020?ooo`@000001P3oool4000000H0oooo1000
00020?ooo`@000000P3oool>00000080oooo0P0000070?ooo`8000001P3oool200000080oooo1000
00020?ooo`H00000103oool4000000P0oooo100000020?ooo`8000001P3oool6000000@0oooo3`3A
cJT000d0dLfY0P0000020?ooo`800000103oool4000000@0oooo0P0000020?ooo`H000000P3oool4
00000080oooo200000020?ooo`8000001P3oool2000000H0oooo100000000`3oool0000000000002
0?ooo`H00000103oool2000000P0oooo0P0000040?ooo`H000001P3oool2000000@0oooo1000000<
0?ooo`@000000P3oool:000000@0oooo1P0000020?ooo`@000000P3oool200000080oooo2P000002
0?ooo`8000001P3oool600000080oooo0P0000000`3oool0000000000002000000@0oooo10000004
0?ooo`X000001P3oool800000080oooo100000080?ooo`8000000P3oool200000080oooo1P000004
0?ooo`8000001P3oool200000080oooo1P00000:0?ooo`8000000P3oool2000000H0oooo0P000004
0?ooo`800000103oool400000080oooo1`0000020?ooo`H000000P3oool2000000H0oooo0P000008
0?ooo`8000000P3oool8000000H0oooo200000040?ooo`@000003`3AcJT000d0dLfY0P0000020?oo
o`800000103oool4000000@0oooo0P0000020?ooo`H000000P3oool400000080oooo200000020?oo
o`8000001P3oool2000000H0oooo100000000`3oool00000000000020?ooo`H00000103oool20000
00P0oooo0P0000040?ooo`H000001P3oool2000000@0oooo1000000<0?ooo`@000000P3oool:0000
00@0oooo1P0000020?ooo`@000000P3oool200000080oooo2P0000020?ooo`8000001P3oool60000
0080oooo0P0000000`3oool0000000000002000000@0oooo100000040?ooo`X000001P3oool80000
0080oooo100000080?ooo`8000000P3oool200000080oooo1P0000040?ooo`8000001P3oool20000
0080oooo1P00000:0?ooo`8000000P3oool2000000H0oooo0P0000040?ooo`800000103oool40000
0080oooo1`0000020?ooo`H000000P3oool2000000H0oooo0P0000080?ooo`8000000P3oool80000
00H0oooo200000040?ooo`@000003`3AcJT000d0dLfY1P3oool6000000P0oooo100000040?ooo`@0
00001P3oool2000000@0oooo100000020?ooo`H000000P3oool6000000D0oooo100000040?ooo`H0
00000P3oool800000080oooo100000040?ooo`P000000P3oool400000100oooo0P0000020?ooo`80
0000103oool2000000P0oooo0P0000060?ooo`8000000P3oool200000080oooo0P0000040?ooo`80
00001P3oool8000000@0oooo100000000`3oool00000000000080?ooo`8000000P3oool4000000@0
oooo0P00000:0?ooo`800000103oool4000000`0oooo100000020?ooo`800000103oool600000080
oooo1P0000020?ooo`800000103oool<00000080oooo0P0000020?ooo`H000000P3oool400000080
oooo100000060?ooo`030000003oool0oooo0080oooo100000040?ooo`@000000P3oool600000080
oooo200000020?ooo`800000103oool200000080oooo1P0000040?ooo`8000000P3oool400000080
oooo3`3AcJT000d0dLfY1P3oool6000000P0oooo100000040?ooo`@000001P3oool2000000@0oooo
100000020?ooo`H000000P3oool6000000D0oooo100000040?ooo`H000000P3oool800000080oooo
100000040?ooo`P000000P3oool400000100oooo0P0000020?ooo`800000103oool2000000P0oooo
0P0000060?ooo`8000000P3oool200000080oooo0P0000040?ooo`8000001P3oool8000000@0oooo
100000000`3oool00000000000080?ooo`8000000P3oool4000000@0oooo0P00000:0?ooo`800000
103oool4000000`0oooo100000020?ooo`800000103oool600000080oooo1P0000020?ooo`800000
103oool<00000080oooo0P0000020?ooo`H000000P3oool400000080oooo100000060?ooo`030000
003oool0oooo0080oooo100000040?ooo`@000000P3oool600000080oooo200000020?ooo`800000
103oool200000080oooo1P0000040?ooo`8000000P3oool400000080oooo3`3AcJT000d0dLfY0P3o
ool6000000@0oooo2P0000080?ooo`8000000P3oool600000080oooo100000060?ooo`8000001P3o
ool2000000T0oooo0P0000020?ooo`@00000103oool4000000@0oooo0P0000020?ooo`800000203o
ool2000000@0oooo1000000D0?ooo`@000000P3oool400000080oooo200000020?ooo`H000000P3o
ool200000080oooo0P0000020?ooo`@000000P3oool6000000@0oooo0P0000020?ooo`@000001@3o
ool:00000080oooo0P0000080?ooo``000000P3oool400000100oooo0P0000020?ooo`8000000P3o
ool4000000@0oooo100000040?ooo`@000000P3oool4000000@0oooo0P0000040?ooo`@000000P3o
ool2000000@0oooo100000060?ooo`8000000P3oool500000080oooo100000080?ooo`8000000P3o
ool2000000@0oooo100000040?ooo`8000000P3oool200000080oooo100000020?ooo`800000103o
ool600000080oooo0P0000040?ooo`l0dLfY000=0=7=Z@80oooo1P0000040?ooo`X00000203oool2
00000080oooo1P0000020?ooo`@000001P3oool2000000H0oooo0P0000090?ooo`8000000P3oool4
000000@0oooo100000040?ooo`8000000P3oool2000000P0oooo0P0000040?ooo`@00000503oool4
00000080oooo100000020?ooo`P000000P3oool600000080oooo0P0000020?ooo`8000000P3oool4
00000080oooo1P0000040?ooo`8000000P3oool4000000D0oooo2P0000020?ooo`800000203oool<
00000080oooo1000000@0?ooo`8000000P3oool200000080oooo100000040?ooo`@00000103oool4
00000080oooo100000040?ooo`800000103oool400000080oooo0P0000040?ooo`@000001P3oool2
00000080oooo1@0000020?ooo`@00000203oool200000080oooo0P0000040?ooo`@00000103oool2
00000080oooo0P0000020?ooo`@000000P3oool2000000@0oooo1P0000020?ooo`800000103oool?
0=7=Z@003@3AcJT40?ooo`800000203oool2000000@0oooo0P0000020?ooo`P000000P3oool20000
00@0oooo1000000:0?ooo`P000000P3oool900000080oooo0P0000080?ooo`8000000P3oool40000
0080oooo0P0000020?ooo`P000000P3oool4000001P0oooo0P0000020?ooo`8000001P3oool20000
00@0oooo100000040?ooo`@000000P3oool200000080oooo0P0000060?ooo`800000203oool40000
00T0oooo0P0000040?ooo`8000000P3oool200000080oooo200000040?ooo`800000103oool40000
01@0oooo100000020?ooo`800000203oool200000080oooo100000060?ooo`8000000P3oool40000
0080oooo100000060?ooo`H000002P3oool4000000<0oooo1000000<0?ooo`@000000P3oool40000
00P0oooo100000020?ooo`8000001P3oool6000000@0oooo100000020?ooo`8000003`3AcJT000d0
dLfY103oool2000000P0oooo0P0000040?ooo`8000000P3oool800000080oooo0P0000040?ooo`@0
00002P3oool800000080oooo2@0000020?ooo`800000203oool200000080oooo100000020?ooo`80
00000P3oool800000080oooo1000000H0?ooo`8000000P3oool2000000H0oooo0P0000040?ooo`@0
0000103oool400000080oooo0P0000020?ooo`8000001P3oool2000000P0oooo100000090?ooo`80
0000103oool200000080oooo0P0000020?ooo`P00000103oool2000000@0oooo1000000D0?ooo`@0
00000P3oool2000000P0oooo0P0000020?ooo`@000001P3oool200000080oooo100000020?ooo`@0
00001P3oool6000000X0oooo100000030?ooo`@00000303oool400000080oooo100000080?ooo`@0
00000P3oool2000000H0oooo1P0000040?ooo`@000000P3oool2000000l0dLfY000=0=7=Z@H0oooo
2P0000020?ooo`@000000P3oool2000000@0oooo0P0000020?ooo`8000000P3oool4000000h0oooo
0P0000040?ooo`@000000`3oool2000000H0oooo2P0000020?ooo`8000001P3oool4000000@0oooo
0P0000020?ooo`800000703oool400000080oooo1P0000020?ooo`@00000203oool200000080oooo
0P0000020?ooo`8000000P3oool600000080oooo2000000=0?ooo`H000000P3oool200000080oooo
0P0000040?ooo`8000000P3oool400000080oooo1000000H0?ooo`8000000P3oool200000080oooo
200000020?ooo`8000002P3oool4000000H0oooo0P0000020?ooo`H00000103oool<000000L0oooo
0P0000020?ooo``000001P3oool200000080oooo200000060?ooo`P00000103oool6000000H0oooo
3`3AcJT000d0dLfY1P3oool:00000080oooo100000020?ooo`800000103oool200000080oooo0P00
00020?ooo`@000003P3oool2000000@0oooo100000030?ooo`8000001P3oool:00000080oooo0P00
00060?ooo`@00000103oool200000080oooo0P00000L0?ooo`@000000P3oool600000080oooo1000
00080?ooo`8000000P3oool200000080oooo0P0000020?ooo`H000000P3oool8000000d0oooo1P00
00020?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`@000000P3oool4000001P0oooo0P00
00020?ooo`8000000P3oool800000080oooo0P00000:0?ooo`@000001P3oool200000080oooo1P00
00040?ooo``000001`3oool200000080oooo300000060?ooo`8000000P3oool8000000H0oooo2000
00040?ooo`H000001P3oool?0=7=Z@003@3AcJT8000000@0oooo0P0000060?ooo`8000000P3oool2
00000080oooo100000020?ooo`8000000P3oool200000180oooo1P0000070?ooo`P00000103oool2
000000H0oooo200000080?ooo`@000000P3ooolL000000H0oooo0P0000060?ooo`8000000P3oool8
00000080oooo0P0000020?ooo`8000000P3oool2000000@0oooo100000040?ooo`8000000P3oool=
000000@0oooo100000020?ooo`8000000P3oool400000080oooo0P0000060?ooo`8000000P3ooolH
00000080oooo0P0000020?ooo`800000103oool200000080oooo0P0000020?ooo`X000002P3oool4
000000@0oooo1P0000040?ooo`800000103oool900000080oooo0P0000040?ooo`800000103oool8
00000080oooo0P0000040?ooo`8000000P3oool6000000@0oooo0P0000020?ooo`@00000103oool6
000000l0dLfY000=0=7=Z@P00000103oool2000000H0oooo0P0000020?ooo`8000000P3oool40000
0080oooo0P0000020?ooo`8000004P3oool6000000L0oooo200000040?ooo`8000001P3oool80000
00P0oooo100000020?oooa`000001P3oool2000000H0oooo0P0000020?ooo`P000000P3oool20000
0080oooo0P0000020?ooo`800000103oool4000000@0oooo0P0000020?ooo`d00000103oool40000
0080oooo0P0000020?ooo`@000000P3oool2000000H0oooo0P0000020?oooaP000000P3oool20000
0080oooo0P0000040?ooo`8000000P3oool200000080oooo2P00000:0?ooo`@00000103oool60000
00@0oooo0P0000040?ooo`T000000P3oool2000000@0oooo0P0000040?ooo`P000000P3oool20000
00@0oooo0P0000020?ooo`H00000103oool200000080oooo100000040?ooo`H000003`3AcJT000d0
dLfY103oool2000000P0oooo200000020?ooo`8000000P3oool2000000H0oooo100000020?oooa80
0000103oool9000000@0oooo0P0000020?ooo`@000000P3oool6000000@0oooo0P0000020?ooo`P0
00001P3oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000020?ooo`H0
00000P3oool600000080oooo0P0000040?ooo`8000000P3oool200000080oooo0P0000020?ooo`80
00000P3oool4000000P0oooo100000030?ooo`800000103oool200000080oooo100000060?ooo`@0
00001P3oool800000080oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`@0
00000P3oool200000080oooo100000020?ooo`8000000P3oool2000000@0oooo0P00000>0?ooo`80
00000P3oool4000000@0oooo1P0000020?ooo`@000000`3oool2000000H0oooo1P0000020?ooo`@0
0000103oool200000080oooo0P0000020?ooo`@000000P3oool2000000@0oooo1P0000020?ooo`80
0000203oool200000080oooo3`3AcJT000d0dLfY103oool2000000P0oooo200000020?ooo`800000
0P3oool2000000H0oooo100000020?oooa800000103oool9000000@0oooo0P0000020?ooo`@00000
0P3oool6000000@0oooo0P0000020?ooo`P000001P3oool2000000@0oooo0P0000040?ooo`800000
103oool2000000@0oooo0P0000020?ooo`H000000P3oool600000080oooo0P0000040?ooo`800000
0P3oool200000080oooo0P0000020?ooo`8000000P3oool4000000P0oooo100000030?ooo`800000
103oool200000080oooo100000060?ooo`@000001P3oool800000080oooo0P0000040?ooo`800000
103oool2000000@0oooo0P0000040?ooo`@000000P3oool200000080oooo100000020?ooo`800000
0P3oool2000000@0oooo0P00000>0?ooo`8000000P3oool4000000@0oooo1P0000020?ooo`@00000
0`3oool2000000H0oooo1P0000020?ooo`@00000103oool200000080oooo0P0000020?ooo`@00000
0P3oool2000000@0oooo1P0000020?ooo`800000203oool200000080oooo3`3AcJT000d0dLfY1P00
00020?ooo`P00000103oool200000080oooo0P0000020?ooo`8000000P3oool6000000H0oooo0P00
00040?ooo`800000103oool2000000P0oooo00<000000?ooo`3oool00P3oool200000080oooo1000
00020?ooo`8000001P3oool2000000P0oooo100000040?ooo`8000000P3oool600000080oooo1000
00020?ooo`@000000P3oool400000080oooo100000020?ooo`800000103oool4000000@0oooo1000
00020?ooo`@000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2000000`0oooo0P00
00020?ooo`<000000P3oool400000080oooo0P00000:0?ooo`8000000P3oool6000000@0oooo0P00
00020?ooo`8000000P3oool400000080oooo100000020?ooo`@000000P3oool4000000H0oooo1000
00060?ooo`@000000P3oool400000080oooo3P0000020?ooo`800000203oool2000000H0oooo0P00
00020?ooo`<000000P3oool6000000@0oooo100000080?ooo`@000000P3oool2000000H0oooo1P00
00040?ooo`@000000P3oool800000080oooo3`3AcJT000d0dLfY1P0000020?ooo`P00000103oool2
00000080oooo0P0000020?ooo`8000000P3oool6000000H0oooo0P0000040?ooo`800000103oool2
000000P0oooo00<000000?ooo`3oool00P3oool200000080oooo100000020?ooo`8000001P3oool2
000000P0oooo100000040?ooo`8000000P3oool600000080oooo100000020?ooo`@000000P3oool4
00000080oooo100000020?ooo`800000103oool4000000@0oooo100000020?ooo`@000000P3oool2
00000080oooo0P0000020?ooo`8000000P3oool2000000`0oooo0P0000020?ooo`<000000P3oool4
00000080oooo0P00000:0?ooo`8000000P3oool6000000@0oooo0P0000020?ooo`8000000P3oool4
00000080oooo100000020?ooo`@000000P3oool4000000H0oooo100000060?ooo`@000000P3oool4
00000080oooo3P0000020?ooo`800000203oool2000000H0oooo0P0000020?ooo`<000000P3oool6
000000@0oooo100000080?ooo`@000000P3oool2000000H0oooo1P0000040?ooo`@000000P3oool8
00000080oooo3`3AcJT000d0dLfY0P3oool2000000H0oooo0P0000040?ooo`H000000P3oool20000
0080oooo0P0000020?ooo`800000103oool800000080oooo100000020?ooo`@000000P3oool70000
0080oooo100000020?ooo`8000001P3oool800000080oooo200000080?ooo`@00000103oool40000
00H0oooo0P0000020?ooo`8000001P3oool200000080oooo0P0000020?ooo`@00000203oool20000
0080oooo0P0000060?ooo`@000000P3oool200000080oooo0P0000020?ooo``000000P3oool00`00
0000oooo0?ooo`040?ooo`8000000P3oool200000080oooo2P0000020?ooo`800000103oool60000
0080oooo0P0000020?ooo`8000001P3oool200000080oooo0P0000060?ooo`8000000P3oool60000
00X0oooo0P0000020?ooo`8000001P3oool2000000@0oooo0P0000040?ooo`@000000P3oool80000
0080oooo1P0000020?ooo`030000003oool0oooo00@0oooo0P0000080?ooo`8000000P3oool80000
00H0oooo200000040?ooo`H000001P3oool2000000@0oooo0P00000?0=7=Z@003@3AcJT20?ooo`80
00001P3oool2000000@0oooo1P0000020?ooo`8000000P3oool200000080oooo0P0000040?ooo`P0
00000P3oool400000080oooo100000020?ooo`L000000P3oool400000080oooo0P0000060?ooo`P0
00000P3oool8000000P0oooo100000040?ooo`@000001P3oool200000080oooo0P0000060?ooo`80
00000P3oool200000080oooo100000080?ooo`8000000P3oool2000000H0oooo100000020?ooo`80
00000P3oool200000080oooo300000020?ooo`030000003oool0oooo00@0oooo0P0000020?ooo`80
00000P3oool:00000080oooo0P0000040?ooo`H000000P3oool200000080oooo0P0000060?ooo`80
00000P3oool2000000H0oooo0P0000020?ooo`H000002P3oool200000080oooo0P0000060?ooo`80
0000103oool2000000@0oooo100000020?ooo`P000000P3oool600000080oooo00<000000?ooo`3o
ool0103oool2000000P0oooo0P0000020?ooo`P000001P3oool8000000@0oooo1P0000060?ooo`80
0000103oool2000000l0dLfY000=0=7=Z@@0oooo200000020?ooo`@00000103oool400000080oooo
0P0000020?ooo`8000000P3oool4000000@0oooo0P0000020?ooo`8000001P3oool200000080oooo
0P0000040?ooo`030000003oool0oooo008000001P3oool8000000@0oooo0P0000020?ooo`800000
103oool200000080oooo200000080?ooo`8000000P3oool600000080oooo0P0000020?ooo`H00000
0P3oool200000080oooo0P00000<0?ooo`@000000P3oool6000000H0oooo100000020?ooo`800000
103oool2000000@0oooo0`0000020?ooo`H000000P3oool200000080oooo0P0000040?ooo`800000
1P3oool6000000@0oooo100000020?ooo`8000000P3oool600000080oooo0P0000020?ooo`H00000
0P3oool2000000@0oooo300000020?ooo`8000000P3oool600000080oooo100000020?ooo`@00000
1P3oool2000000@0oooo100000040?ooo`<000000P3oool600000080oooo200000020?ooo`800000
103oool200000080oooo1P0000040?ooo`8000000P3oool4000000@0oooo200000020?ooo`@00000
3`3AcJT000d0dLfY103oool800000080oooo100000040?ooo`@000000P3oool200000080oooo0P00
00020?ooo`@00000103oool200000080oooo0P0000060?ooo`8000000P3oool2000000@0oooo00<0
00000?ooo`3oool00P0000060?ooo`P00000103oool200000080oooo0P0000040?ooo`8000000P3o
ool8000000P0oooo0P0000020?ooo`H000000P3oool200000080oooo1P0000020?ooo`8000000P3o
ool2000000`0oooo100000020?ooo`H000001P3oool400000080oooo0P0000040?ooo`800000103o
ool300000080oooo1P0000020?ooo`8000000P3oool2000000@0oooo0P0000060?ooo`H00000103o
ool400000080oooo0P0000020?ooo`H000000P3oool200000080oooo1P0000020?ooo`800000103o
ool<00000080oooo0P0000020?ooo`H000000P3oool400000080oooo100000060?ooo`800000103o
ool4000000@0oooo0`0000020?ooo`H000000P3oool800000080oooo0P0000040?ooo`8000000P3o
ool6000000@0oooo0P0000020?ooo`@00000103oool800000080oooo1000000?0=7=Z@00o`3AcJV/
0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/
0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/
0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/
0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/
0=7=Z@00_`3AcJT2@00000<0dLfY1D0000000`3AcJU00000@0000003@0000080dLfY0T0000030=7=
Z@E000000P3AcJT2@00000<0dLfY1D0000020=7=Z@900000`03AcJT00;h0dLfY00A000000=7=Z@3A
cJU00000103AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT0
0d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=
Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@2m0=7=Z@00_P3A
cJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0
dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=
Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0
dLfY0;d0dLfY002n0=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT00`3AcJT0
1D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=
Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00=000000=7=Z@3AcJT0_@3AcJT00;h0dLfY00A000000=7=Z@3AcJU00000103AcJT00d000000
dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=
Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0
dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@2m0=7=Z@00_`3AcJT2@00000@0dLfY0T000004
0=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T000030
0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/0=7=Z@00o`3AcJV/0=7=Z@00\
\>"],
  ImageRangeCache->{{{0, 426.625}, {639.313, 0}} -> {-6.98607, -6.02158, \
0.50389, 0.50389}}]
}, Open  ]],

Cell["\<\
The following comprises our first catalog of all possible dyadic CA:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(b = 2;\)\), "\[IndentingNewLine]", 
    \(\(allRules = 
        IntegerDigits[Range[0, b\^\(b\^3\) - 1], b, 
          b\^3];\)\), "\[IndentingNewLine]", 
    \(\(g = 
        Map[showCA[b, cellularSpace[161], #, 40, 1, 40, 120, 2] &, 
          allRules];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Partition[g, 8]], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.99234 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0474366 0.119048 [
[ 0 0 0 0 ]
[ 1 1.99234 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.99234 L
0 1.99234 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0474366 0.133279 0.101495 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(248) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.0474366 0.253695 0.101495 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(249) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.0474366 0.374111 0.101495 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(250) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.0474366 0.494527 0.101495 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(251) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.0474366 0.614943 0.101495 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(252) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.0474366 0.735359 0.101495 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(253) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.0474366 0.855774 0.101495 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(254) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.0474366 0.97619 0.101495 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(255) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.106901 0.133279 0.16096 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(240) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF0000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FF0000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FF00000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000FF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.106901 0.253695 0.16096 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(241) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000FFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000FFFF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000FFFF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000FFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000FFFF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000FFFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000FFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000FFFF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000FFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000FFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000FFFF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000FFFF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000FFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000FFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000FFFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FFFF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FFFF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FFFF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.106901 0.374111 0.16096 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(242) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF0000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.106901 0.494527 0.16096 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(243) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.106901 0.614943 0.16096 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(244) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF0000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFF00
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFF000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFF0000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFF00000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FFFF000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FFFF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FFFF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FFFF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FFFF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FFFF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.106901 0.735359 0.16096 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(245) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000FF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000FF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000FF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.106901 0.855774 0.16096 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(246) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF0000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF0000000000FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFF00FF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
00000000FFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FF00FF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000
0000FFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFF00
FF0000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFF00FF00
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000FFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FFFFFF00FF000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FFFFFF00FF0000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFF00FF00000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FFFFFF00FF000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000FFFFFF00FF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFF00FF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FFFFFF00FF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFF00FF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFF00FF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FFFFFF00FF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FFFFFF00FF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFF00FF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.106901 0.97619 0.16096 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(247) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.166366 0.133279 0.220425 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(232) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.166366 0.253695 0.220425 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(233) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.166366 0.374111 0.220425 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(234) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.166366 0.494527 0.220425 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(235) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.166366 0.614943 0.220425 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(236) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.166366 0.735359 0.220425 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(237) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.166366 0.855774 0.220425 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(238) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.166366 0.97619 0.220425 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(239) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.225831 0.133279 0.279889 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(224) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.225831 0.253695 0.279889 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(225) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00000000FFFF0000FF00000000FF00FFFFFF0000FF00FFFF00FF00FF0000FFFF00FFFFFF
0000FFFFFF0000FF00FFFF0000000000FFFFFF0000FFFF00FFFF00FF000000FF00FFFFFF
FF00000000FF0000FF
0000000000FFFF00FFFFFFFF00FFFF0000FFFFFF000000FF00FFFF00000000FFFF0000FF
FFFF0000FFFFFF000000FFFFFFFFFFFF0000FFFF00FF000000FF00FFFFFF00FF00FF0000
FFFFFFFF00FFFFFF00
000000000000FFFF0000FF000000FFFFFF0000FFFFFFFF000000FFFFFFFF00FF00000000
FF00000000FF0000000000FF0000FF00000000FF00FFFFFF00FFFF0000FF00FF00FFFFFF
0000FF000000FF0000
00000000000000FFFF00FFFFFFFF0000FFFF00FF0000FFFFFF00FF0000FF00FFFFFFFF00
FFFFFFFF00FFFFFFFFFF00FFFF00FFFFFFFFFF000000FF000000FFFF00FF00FFFF0000FF
FF00FFFFFFFF000000
0000000000000000FFFF0000FF00000000FF00FFFFFF0000FF00FFFF00FF00FF0000FFFF
0000FF000000FF0000FF00FF000000FF0000FFFFFFFF0000000000FF00FF00FF00000000
FFFF0000FF00000000
000000000000000000FFFF00FFFFFFFF00FFFF0000FFFFFF000000FF00FFFF00000000FF
FF00FFFFFF00FFFF00FF00FFFFFF00FFFF00FF0000FFFFFFFFFF00FF00FFFF0000000000
00FFFFFF0000000000
00000000000000000000FFFF0000FF000000FFFFFF0000FFFFFFFF000000FFFFFFFF00FF
000000FF000000FFFF000000FF000000FFFF00000000FF0000FF00FF00FF000000000000
0000FF000000000000
0000000000000000000000FFFF00FFFFFFFF0000FFFF00FF0000FFFFFF00FF0000FF00FF
FFFFFF0000000000FFFFFFFF0000000000FFFFFFFF00FFFF00FF00FF00FFFFFFFFFFFFFF
FFFF00000000000000
000000000000000000000000FFFF0000FF00000000FF00FFFFFF0000FF00FFFF00FF00FF
0000FFFFFFFFFF00FF0000FFFFFFFFFFFF0000FF000000FF00FFFF000000FF0000FF0000
FF0000000000000000
00000000000000000000000000FFFF00FFFFFFFF00FFFF0000FFFFFF000000FF00FFFF00
000000FF0000FF00FFFFFF0000FF0000FFFF00FFFFFFFF000000FFFFFF00FFFF00FFFFFF
000000000000000000
0000000000000000000000000000FFFF0000FF000000FFFFFF0000FFFFFFFF000000FFFF
FFFF00FFFF00FFFF0000FFFFFF00000000FF00FF0000FFFFFFFF0000FF00FF000000FF00
000000000000000000
000000000000000000000000000000FFFF00FFFFFFFF0000FFFF00FF0000FFFFFF00FF00
00FF00FF000000FFFFFF0000FFFFFFFF00FF00FFFF00FF0000FFFF00FF00FFFFFFFF0000
000000000000000000
00000000000000000000000000000000FFFF0000FF00000000FF00FFFFFF0000FF00FFFF
00FF00FFFFFFFF0000FFFF00FF0000FFFF000000FFFF00000000FF00FFFF0000FF000000
000000000000000000
0000000000000000000000000000000000FFFF00FFFFFFFF00FFFF0000FFFFFF000000FF
00FFFF0000FF00000000FF00FFFF00FF0000000000FFFFFFFFFF000000FFFFFF00000000
000000000000000000
000000000000000000000000000000000000FFFF0000FF000000FFFFFF0000FFFFFFFF00
0000FFFF00FFFFFFFFFF000000FF00FFFFFFFFFF00FF0000FF0000000000FF0000000000
000000000000000000
00000000000000000000000000000000000000FFFF00FFFFFFFF0000FFFF00FF0000FFFF
FF00FF000000FF0000FFFFFFFF000000FF0000FF00FFFF00FFFFFFFFFFFF000000000000
000000000000000000
0000000000000000000000000000000000000000FFFF0000FF00000000FF00FFFFFF0000
FF00FFFFFF00FFFF00FF0000FFFFFF00FFFF00FF00FF000000FF0000FF00000000000000
000000000000000000
000000000000000000000000000000000000000000FFFF00FFFFFFFF00FFFF0000FFFFFF
000000FF000000FFFF00000000FF000000FF00FF00FFFFFF00FFFFFF0000000000000000
000000000000000000
00000000000000000000000000000000000000000000FFFF0000FF000000FFFFFF0000FF
FFFFFF0000000000FFFFFFFF00FFFFFF00FFFF000000FF000000FF000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FFFF00FFFFFFFF0000FFFF00FF
0000FFFFFFFFFFFF0000FF000000FF000000FFFFFF00FFFFFFFF00000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FFFF0000FF00000000FF00FF
FFFF0000FF0000FFFF00FFFFFF00FFFFFFFF0000FFFF0000FF0000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FFFF00FFFFFFFF00FFFF00
00FFFFFF00000000FFFF0000FFFF0000FF00000000FFFFFF000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FFFF0000FF000000FFFF
FF0000FFFFFFFF00FF00000000FFFFFF000000000000FF00000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FFFF00FFFFFFFF0000
FFFF00FF0000FF00FFFFFFFFFF0000FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FFFF0000FF000000
00FF00FFFFFF000000FF0000FFFFFF0000FF0000FF000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFF00FFFFFFFF
00FFFF0000FFFFFF00FFFFFF0000FFFF00FFFFFF00000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFF0000FF00
0000FFFFFF0000FFFF0000FFFF00FF000000FF0000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFF00FFFF
FFFF0000FFFF00FF00000000FF00FFFFFFFF000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFF0000
FF00000000FF00FFFFFFFF00FFFF0000FF00000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFF00
FFFFFFFF00FFFF0000FF000000FFFFFF0000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
0000FF000000FFFFFF0000000000FF000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF00FFFFFFFF0000FFFFFFFFFFFF00000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFF0000FF00000000FF0000FF0000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF00FFFFFFFF00FFFFFF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFF0000FF000000FF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00FFFFFFFF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF0000FF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.225831 0.374111 0.279889 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(226) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.225831 0.494527 0.279889 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(227) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF0000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF00000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF0000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF00000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FFFF000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FFFF0000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FFFF00000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF0000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FFFF000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF00FF00000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FFFF0000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF00FF000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FFFF00000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00FF0000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FFFF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF00FF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FFFF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.225831 0.614943 0.279889 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(228) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FF00000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FF0000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000FF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF00000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FF000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FF0000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF00000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FF000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.225831 0.735359 0.279889 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(229) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00000000FF000000FF000000FF000000FF00000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
FF000000FF000000FF
0000000000FF00FF0000000000FF00FF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF00FF
0000000000FF00FF00
000000000000FF00000000000000FF000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
000000000000FF0000
00000000000000FF00FF00FF00FF00000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
00FF00FF00FF000000
0000000000000000FF000000FF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF000000FF00000000
000000000000000000FF00FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00FF0000000000
00000000000000000000FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF000000000000
0000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00000000000000
000000000000000000000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF0000000000000000
00000000000000000000000000FF00FF0000000000FF00FF0000000000FF00FF00000000
00FF00FF0000000000FF00FF0000000000FF00FF0000000000FF00FF0000000000FF00FF
000000000000000000
0000000000000000000000000000FF00000000000000FF00000000000000FF0000000000
0000FF00000000000000FF00000000000000FF00000000000000FF00000000000000FF00
000000000000000000
000000000000000000000000000000FF00FF00FF00FF000000000000000000FF00FF00FF
00FF000000000000000000FF00FF00FF00FF000000000000000000FF00FF00FF00FF0000
000000000000000000
00000000000000000000000000000000FF000000FF0000000000000000000000FF000000
FF0000000000000000000000FF000000FF0000000000000000000000FF000000FF000000
000000000000000000
0000000000000000000000000000000000FF00FF00000000000000000000000000FF00FF
00000000000000000000000000FF00FF00000000000000000000000000FF00FF00000000
000000000000000000
000000000000000000000000000000000000FF000000000000000000000000000000FF00
0000000000000000000000000000FF000000000000000000000000000000FF0000000000
000000000000000000
00000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF0000
000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF000000000000
000000000000000000
0000000000000000000000000000000000000000FF000000FF000000FF000000FF000000
00000000000000000000000000000000FF000000FF000000FF000000FF00000000000000
000000000000000000
000000000000000000000000000000000000000000FF00FF0000000000FF00FF00000000
0000000000000000000000000000000000FF00FF0000000000FF00FF0000000000000000
000000000000000000
00000000000000000000000000000000000000000000FF00000000000000FF0000000000
000000000000000000000000000000000000FF00000000000000FF000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FF00FF00FF00FF000000000000
00000000000000000000000000000000000000FF00FF00FF00FF00000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FF000000FF00000000000000
0000000000000000000000000000000000000000FF000000FF0000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FF00FF0000000000000000
000000000000000000000000000000000000000000FF00FF000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FF000000000000000000
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FF00FF00000000
00FF00FF0000000000FF00FF0000000000FF00FF00000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FF0000000000
0000FF00000000000000FF00000000000000FF0000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF00FF00FF
00FF000000000000000000FF00FF00FF00FF000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
FF0000000000000000000000FF000000FF00000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF00FF
00000000000000000000000000FF00FF0000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
0000000000000000000000000000FF000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
00FF00FF00FF00FF00FF00FF00FF00000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF000000FF000000FF000000FF0000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00FF0000000000FF00FF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00000000000000FF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF00FF00FF00FF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF000000FF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF00FF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.225831 0.855774 0.279889 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(230) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFF00FF00000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000FFFFFF00FF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FFFFFF00FF000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFF00FF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FFFFFF00FF0000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FFFFFF00FF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFF00FF00000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFF00FF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FFFFFF00FF000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFF00FF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FFFFFF00FF0000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FFFFFF00FF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFF00FF00000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FFFFFF00FF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFFFF00FF000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFF00FF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFF00FF0000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF00FF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF00FF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.225831 0.97619 0.279889 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(231) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF0000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF00000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FF0000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FF00000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FF0000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FF00000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FF0000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FF0000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000FF000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF00000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF0000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FF000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FF00000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FF0000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FF000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF00000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF0000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.285295 0.133279 0.339354 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(216) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FF0000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000FF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF00000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FF000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FF0000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF00000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FF000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.285295 0.253695 0.339354 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(217) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000FF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000FFFF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000FFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000FFFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000FFFF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000FF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000FFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000FFFF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000FFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FFFF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.285295 0.374111 0.339354 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(218) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.285295 0.494527 0.339354 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(219) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.285295 0.614943 0.339354 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(220) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FF0000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000FF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF00000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FF000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FF0000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF00000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FF000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.285295 0.735359 0.339354 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(221) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000FF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000FF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000FF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000FF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.285295 0.855774 0.339354 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(222) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.285295 0.97619 0.339354 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(223) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.34476 0.133279 0.398819 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(208) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF0000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFF00
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFF000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFF0000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFF00000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FFFF000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FFFF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FFFF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FFFF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FFFF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FFFF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.34476 0.253695 0.398819 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(209) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000FFFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000FFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000FFFF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000FFFF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000FFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000FFFF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000FFFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000FFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000FFFF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000FFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000FFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000FFFF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000FFFF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000FFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000FFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000FFFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FFFF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FFFF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FFFF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.34476 0.374111 0.398819 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(210) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00000000000000000000000000000000000000000000FFFFFFFF000000FFFFFFFF00FFFF
FFFF00FF00FF00FF0000FF0000FFFF00FF00FFFF00000000FF0000FF0000FF00FFFFFF00
FFFF00000000FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF00FF00FF000000
000000FF000000FF0000FFFF00000000FFFF00FFFFFF0000FF0000FFFF000000FF00FFFF
00FFFFFFFF000000FF
0000000000000000000000000000000000000000000000FFFF00FF00FF000000FFFFFFFF
FF0000FFFF0000FFFFFF00FFFFFFFF00000000FF00FF0000FFFFFF00FFFF0000FFFF00FF
FF00FF00FFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFF0000FF00FF00
FFFFFF00FF0000FF00FFFF00FF00FFFFFFFF000000FF0000FF00FFFF00FFFFFF00FFFF00
FF000000FF00FFFFFF
000000000000000000000000000000000000000000000000FFFFFFFF00FFFF000000FF00
00000000FF0000FF00000000FFFF00FF00FFFF0000FF0000FF00000000FF00FF00000000
FFFF0000FF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFF0000FFFF
FFFF0000FF0000FFFFFFFF00000000FFFF00FF0000FF0000FFFFFFFF000000FFFFFFFFFF
00FF0000FFFFFFFFFF
00000000000000000000000000000000000000000000000000FFFF00FFFF00FFFFFF00FF
00FF0000FFFFFF00FF00FFFFFFFF00000000FF0000FFFFFF00FF00FFFFFF000000000000
00FFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FF00FF0000
00FFFF0000000000FFFF00FF00FFFFFF0000FF0000FF00FF000000FF00FFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FFFFFFFF000000FFFFFF
FF00FFFFFFFFFFFF00FF000000FF00FF0000FFFF000000FFFF0000FFFF00FF00FF00FF00
FF0000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF00FF00
FF0000000000000000FFFFFF000000FFFFFF00FFFFFFFF00FFFFFF00FF000000FF000000
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000FFFF00FF00FF000000
FFFFFFFFFFFFFF0000FF00FFFF0000FF00FFFF00FF00FF0000000000FFFF0000FFFFFF00
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFF0000
FF00FF00FF00FF0000FFFF00FF0000FFFF00FF000000FFFFFFFFFFFF00FF0000FF00FFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FFFFFFFF00FFFF00
0000FF000000FFFF00000000FFFF00000000FFFFFF0000000000000000FF0000FF000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFF
0000FFFFFFFF00FFFFFFFFFF00FFFFFF0000FF00FFFFFFFFFFFFFF0000FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000FFFF00FFFF00FF
FFFF00FF00FF00000000000000FF00FFFF000000FF00FF00FF00FF0000FFFF0000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FF
00FF000000FFFFFFFFFFFF0000FFFF00FFFFFF000000FF000000FFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FFFFFFFF0000
00FFFFFFFF00FF00FF00FFFF00000000FF00FFFF0000FFFF0000FF00FF00000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF
FF00FF00FF000000FFFF00FFFFFF0000FFFF00FFFFFF00FFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000FFFF00FF00
FF000000FFFFFF00000000FF00FFFF00000000FF00FFFF00FFFFFF000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000
FFFF0000FF00FFFFFF0000FFFF00FFFFFF0000FF00000000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FFFFFFFF
00FFFF000000FF00FFFF00000000FF00FF0000FFFFFF0000FF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FF00FFFF0000FFFF00FFFFFFFF000000FF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000FFFF00
FFFF00FFFFFF00FFFF00FF00FFFF0000FFFF000000FFFF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
000000FF00FF00000000FFFF00FFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFF000000FFFFFFFF00000000FF00FFFF00FF00FF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FFFFFFFF00FF00FFFFFF0000FFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF00FF00FF000000FF00FFFF00000000FFFFFF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF000000FFFF0000FFFF00FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFF00FFFF00000000FF00FF0000FF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFF00FFFFFFFF000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF00FFFF00FF00FFFF0000FFFF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00000000FFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFF00000000FF00FF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00FF00FFFFFF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF0000FF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.34476 0.494527 0.398819 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(211) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.34476 0.614943 0.398819 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(212) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF0000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFF00
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFF000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFF0000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFF00000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FFFF000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FFFF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FFFF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FFFF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FFFF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FFFF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.34476 0.735359 0.398819 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(213) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000FFFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000FFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000FFFF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000FFFF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000FFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000FFFF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000FFFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000FFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000FFFF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000FFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000FFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000FFFF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000FFFF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000FFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000FFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000FFFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FFFF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FFFF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FFFF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.34476 0.855774 0.398819 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(214) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF00000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000
FFFFFF0000FF0000FF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF00FF00
00000000FF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFF000000FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
00000000FF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFF00
00FF0000FFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FF00FF0000000000
FF00FF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF00
0000FFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FF00000000000000
FF0000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFF0000FF0000
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FF00FF0000000000FF00FF00
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FF00000000000000FF000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFF0000FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000FF00FF0000000000FF00FF0000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000FF00000000000000FF00000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFF0000FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FF00FF0000000000FF00FF000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FF00000000000000FF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF00FF0000000000FF00FF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF00000000000000FF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF0000FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FF00FF0000000000FF00FF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FF00000000000000FF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF0000FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000FF00FF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000FF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF000000FF00FF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF000000FF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.34476 0.97619 0.398819 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(215) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.404225 0.133279 0.458283 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.404225 0.253695 0.458283 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(201) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF00
00000000FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF0000
0000000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000
000000000000FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00000000
00000000000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF0000000000
0000000000000000FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF000000000000
000000000000000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF00000000000000
00000000000000000000FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF0000000000000000
0000000000000000000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000000000000000
000000000000000000000000FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
000000000000000000
00000000000000000000000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
000000000000000000
0000000000000000000000000000FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF000000
000000000000000000
000000000000000000000000000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00000000
000000000000000000
00000000000000000000000000000000FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF0000000000
000000000000000000
0000000000000000000000000000000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000000000
000000000000000000
000000000000000000000000000000000000FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00000000000000
000000000000000000
00000000000000000000000000000000000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000000000000000
000000000000000000
0000000000000000000000000000000000000000FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF000000000000000000
000000000000000000
000000000000000000000000000000000000000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF00000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF0000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF0000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF00000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF0000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF000000FF
000000FF000000FF000000FF000000FF0000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF0000
00FF000000FF000000FF000000FF00000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FF00FFFFFF00FFFFFF00FFFFFF0000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000FF000000FF000000FF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFF00FFFFFF00FFFFFF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FF000000FF000000FF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFF00FFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF000000FF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.404225 0.374111 0.458283 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(202) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000FF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.404225 0.494527 0.458283 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(203) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFF00
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF0000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFF000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF00000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFF0000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFF00000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FF0000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FFFF000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FF00000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FFFF0000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFF00000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FF0000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FFFF000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF00000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FFFF0000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FF000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFF00000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FF0000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FFFF000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF00000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FFFF0000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.404225 0.614943 0.458283 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(204) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.404225 0.735359 0.458283 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(205) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000
0000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000
00000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF0000000000
0000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF000000000000
000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00000000000000
00000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF0000000000000000
0000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
000000000000000000
000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
000000000000000000
00000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000
000000000000000000
0000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000
000000000000000000
000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00000000
000000000000000000
00000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000000000
000000000000000000
0000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000000000
000000000000000000
000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00000000000000
000000000000000000
00000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000000000000000
000000000000000000
0000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000000000000000
000000000000000000
000000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF0000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF00FF
00FF00FF00FF00FF00FF00FF00FF00000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
FF00FF00FF00FF00FF00FF00FF0000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
00FF00FF00FF00FF00FF00FF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF00FF00FF00FF00FF00FF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00FF00FF00FF00FF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00FF00FF00FF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF00FF00FF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.404225 0.855774 0.458283 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(206) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000FF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.404225 0.97619 0.458283 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(207) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF0000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF00000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FF0000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FF00000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FF0000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FF00000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FF0000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FF0000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000FF000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF00000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF0000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FF000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FF00000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FF0000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FF000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF00000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF0000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.463689 0.133279 0.517748 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(192) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFF00000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FFFF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FFFF000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000FFFF0000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FFFF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFF00000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FFFF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FFFF000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFF0000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FFFF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFF00000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FFFF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FFFF000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FFFF0000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.463689 0.253695 0.517748 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(193) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF000000FFFFFFFF00FF00FFFF000000FFFFFFFF00FF00FFFF000000FF
FFFFFF00FF00FFFFFF
00000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFFFFFF00FF00FFFF000000FFFFFFFF00FF00FFFF000000FFFFFFFF00
FF00FFFF000000FF00
0000000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FF00FFFF000000FFFFFFFF00FF00FFFF000000FFFFFFFF00FF00FFFF
000000FFFFFFFF0000
000000000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF000000FFFFFFFF00FF00FFFF000000FFFFFFFF00FF00FFFF000000FF
FFFFFF0000FF000000
00000000000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFFFFFF00FF00FFFF000000FFFFFFFF00FF00FFFF000000FFFFFFFF00
FF00FFFFFF00000000
0000000000000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FF00FFFF000000FFFFFFFF00FF00FFFF000000FFFFFFFF00FF00FFFF
000000FF0000000000
000000000000000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF000000FFFFFFFF00FF00FFFF000000FFFFFFFF00FF00FFFF000000FF
FFFFFF000000000000
00000000000000000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFFFFFF00FF00FFFF000000FFFFFFFF00FF00FFFF000000FFFFFFFF00
00FF00000000000000
0000000000000000000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FF00FFFF000000FFFFFFFF00FF00FFFF000000FFFFFFFF00FF00FFFF
FF0000000000000000
000000000000000000000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF000000FFFFFFFF00FF00FFFF000000FFFFFFFF00FF00FFFF000000FF
000000000000000000
00000000000000000000000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFFFFFF00FF00FFFF000000FFFFFFFF00FF00FFFF000000FFFFFFFF00
000000000000000000
0000000000000000000000000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FF00FFFF000000FFFFFFFF00FF00FFFF000000FFFFFFFF0000FF0000
000000000000000000
000000000000000000000000000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF000000FFFFFFFF00FF00FFFF000000FFFFFFFF00FF00FFFFFF000000
000000000000000000
00000000000000000000000000000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFFFFFF00FF00FFFF000000FFFFFFFF00FF00FFFF000000FF00000000
000000000000000000
0000000000000000000000000000000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FF00FFFF000000FFFFFFFF00FF00FFFF000000FFFFFFFF0000000000
000000000000000000
000000000000000000000000000000000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF000000FFFFFFFF00FF00FFFF000000FFFFFFFF0000FF000000000000
000000000000000000
00000000000000000000000000000000000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFFFFFF00FF00FFFF000000FFFFFFFF00FF00FFFFFF00000000000000
000000000000000000
0000000000000000000000000000000000000000FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FF00FFFF000000FFFFFFFF00FF00FFFF000000FF0000000000000000
000000000000000000
000000000000000000000000000000000000000000FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF000000FFFFFFFF00FF00FFFF000000FFFFFFFF000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFFFFFF00FF00FFFF000000FFFFFFFF0000FF00000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FF00FFFF000000FFFFFFFF00FF00FFFFFF0000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF000000FFFFFFFF00FF00FFFF000000FF000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00FFFFFFFF00FF00FFFF000000FFFFFFFF00000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FF00FFFF000000FFFFFFFF0000FF0000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF000000FFFFFFFF00FF00FFFFFF000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FFFF00FFFF00FFFF
00FFFF00FFFF00FFFFFFFF00FF00FFFF000000FF00000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFF00FFFF00FF
FF00FFFF00FFFF00FF00FFFF000000FFFFFFFF0000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFF00FFFF00
FFFF00FFFF00FFFF000000FFFFFFFF0000FF000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFF00FFFF
00FFFF00FFFF00FFFFFFFF00FF00FFFFFF00000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFF00FF
FF00FFFF00FFFF00FF00FFFF000000FF0000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFF00
FFFF00FFFF00FFFF000000FFFFFFFF000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
00FFFF00FFFF00FFFFFFFF0000FF00000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF00FFFF00FFFF00FF00FFFFFF0000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFF00FFFF00FFFF000000FF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF00FFFF00FFFFFFFF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFF00FFFF0000FF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00FFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF00FF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.463689 0.374111 0.517748 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(194) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00000000000000000000000000000000000000000000FFFFFFFF00FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000FFFFFFFF00FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFF00FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000FFFFFFFF00FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FFFFFFFF00FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000FFFFFFFF00FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FFFFFFFF00FF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000FFFFFFFF00FF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FFFFFFFF00FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000FFFFFFFF00
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FFFFFFFF
00FF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FF00FF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFF00FF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFFFF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFF00FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFFFFFF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFF00FF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFF00FF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.463689 0.494527 0.517748 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(195) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF00FF00FF00FF000000000000000000000000000000000000000000000000
00FF00FF00FF00FF00
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000FFFF00000000000000000000000000000000000000000000000000
00FFFF0000FFFF0000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000FF0000000000000000000000000000000000000000000000000000
00FF000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFF000000000000000000000000000000000000000000000000000000
00FFFFFFFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF00FF00000000000000000000000000000000000000000000000000000000
00FF00FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
00FFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
00FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF00
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF00FF0000000000FF00FF0000000000FF00FF0000000000FF00FF00000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF000000000000FFFF000000000000FFFF000000000000FFFF0000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF00000000000000FF00000000000000FF00000000000000FF000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF00FF00FF00FF000000000000000000FF00FF00FF00FF0000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000FFFF00000000000000000000FFFF0000FFFF000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000FF0000000000000000000000FF000000FF00000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFF000000000000000000000000FFFFFFFF0000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF00FF00000000000000000000000000FF00FF000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000FFFF00000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000FF0000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF00FF00FF00FF00FF00FF00FF00FF00000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000FFFF0000FFFF0000FFFF0000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000FF000000FF000000FF000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFF00000000FFFFFFFF00000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF00FF0000000000FF00FF0000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF000000000000FFFF000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF00000000000000FF00000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF00FF00FF00FF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000FFFF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000FF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF00FF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.463689 0.614943 0.517748 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(196) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFF00000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FFFF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FFFF000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000FFFF0000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FFFF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFF00000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FFFF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FFFF000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFF0000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FFFF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFF00000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FFFF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FFFF000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FFFF0000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.463689 0.735359 0.517748 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(197) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
00000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00
0000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000
000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF000000
00000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000
0000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF0000000000
000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF000000000000
00000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00000000000000
0000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF0000000000000000
000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
000000000000000000
00000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
000000000000000000
0000000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000
000000000000000000
000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000
000000000000000000
00000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00000000
000000000000000000
0000000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000000000
000000000000000000
000000000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000000000
000000000000000000
00000000000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00000000000000
000000000000000000
0000000000000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000000000000000
000000000000000000
000000000000000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FFFF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FFFF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FFFF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FFFF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFF00FF
00FF00FF00FF00FF00FF00FF00FF00FF0000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFF00
FF00FF00FF00FF00FF00FF00FF00FF000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
00FF00FF00FF00FF00FF00FF00FF00000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF00FF00FF00FF00FF00FF00FF0000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFF00FF00FF00FF00FF00FF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF00FF00FF00FF00FF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFF00FF00FF00FF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00FF00FF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF00FF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.463689 0.855774 0.517748 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(198) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00000000000000000000000000000000000000000000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000
FF0000FF00FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF00
00FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FF0000FF0000FF0000FF0000
FF0000FF00FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000FF0000FF0000FF0000FF00
00FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000
FF0000FF00FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF00
00FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000FF0000FF0000FF0000
FF0000FF00FF00FFFF00FFFF00FFFF00FFFF00FFFF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FF0000FF0000FF00
00FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000
FF0000FF00FF00FFFF00FFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000FF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF00FFFF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF00
00FF0000FF00FFFF00FFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FF0000FF0000
FF0000FF00FF00FFFF00FFFF00FFFF00FFFF000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000FF0000FF00
00FF0000FF00FFFF00FFFF00FFFF00FFFF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000
FF0000FF00FF00FFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFF0000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00
00FF0000FF00FFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000FF0000
FF0000FF00FF00FFFF00FFFF00FFFF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
0000FF0000FFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FF00
00FF0000FF00FFFF00FFFF00FFFF00000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000FF00FF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000000000FF
0000FF0000FFFF00FFFF00FFFF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF0000FF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FF0000FF00FF00FFFF00FFFF000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FF0000FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00FF0000FF00FFFF00FFFF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF0000FFFF00FFFF0000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF00FF00FFFF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.463689 0.97619 0.517748 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(199) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF00FF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF00FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF00FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
00FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF00FF
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF00FF00
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF00FF0000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FF00FF000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF00FF00000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FF00FF0000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FF00FF000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FF00FF00000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FF00FF0000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FF00FF000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF00FF00000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF00FF0000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FF00FF000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000FF00FF00000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF00FF0000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF00FF000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FF00FF00000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FF00FF0000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FF00FF000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FF00FF00000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF00FF0000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF00FF000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FF00FF00000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF00FF0000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF00FF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FF00FF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF00FF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF00FF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.523154 0.133279 0.577213 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(184) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.523154 0.253695 0.577213 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(185) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FFFF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FFFF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.523154 0.374111 0.577213 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(186) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FF00FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FF00FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FF00FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FF00FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FF00
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FF00FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.523154 0.494527 0.577213 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(187) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.523154 0.614943 0.577213 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(188) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000FF00FFFFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000FF00FFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000FF00FFFFFF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FF00FFFFFF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000FF00FFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FF00FFFFFF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000FF00FFFFFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FF00FFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000FF00FFFFFF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FF00FFFFFF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000FF00FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FF00FFFF
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000FF00FF
FFFF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FF00
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000000000FF
00FFFFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FF00FFFFFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00FFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF00FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.523154 0.735359 0.577213 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(189) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000FF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000FF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000FF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000FF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.523154 0.855774 0.577213 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(190) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF00FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFF0000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000FF00FFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFF0000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000FF00FFFFFF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFF0000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000FF00FFFFFF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFF0000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000FF00FFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFF0000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000FF00FFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000FF00FFFFFF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000FF00FFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FF00FFFFFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000FF00FFFFFF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000FF00FFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FF00FFFFFF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FF00FFFFFF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FF00FFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FF00FFFFFF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FF00FFFF
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FF00
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FF00FFFFFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.523154 0.97619 0.577213 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(191) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.582619 0.133279 0.636678 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(176) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF0000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.582619 0.253695 0.636678 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(177) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000FFFFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000FFFFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FFFFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FFFFFF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FFFF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FFFFFF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FFFF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FFFFFF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.582619 0.374111 0.636678 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(178) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00000000
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
0000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF000000000000
FFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
00000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF0000000000000000
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FF00
FF00FF00FF00FF00FF00FF00FF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FF00FF00FF00FF00FF00FF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00FF00FF00FF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.582619 0.494527 0.636678 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(179) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.582619 0.614943 0.636678 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(180) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000FF00FFFFFF0000FFFF00FF00FF0000
00FF00FFFF000000FFFF0000FF00FF00000000FF000000FF00FF0000FF000000FF00FFFF
FF000000FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF0000FFFFFF00FFFFFF
FFFF00FFFF00FF0000FFFFFFFF0000FF00FF00FFFFFFFFFF0000FF00FFFFFFFFFF0000FF
FF00FF0000FF0000FF
00000000000000000000000000000000000000000000FF00FF0000FF0000FFFF00000000
FFFF00FFFF0000FF0000000000FF00FFFFFF0000000000FFFFFFFF000000000000FF00FF
FF0000FF0000FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF000000FF00FF00
FFFF000000FF00FFFFFFFFFFFFFF0000FFFF00FF00FF00000000FFFFFFFFFFFFFFFF0000
00FF0000FF00FFFFFF
0000000000000000000000000000000000000000000000FF00FFFFFFFF00FF00FFFFFF00
00FFFFFFFFFF0000000000000000FF0000FFFFFF0000FF00FF00000000000000FFFF00FF
00FFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF00000000FF
000000000000FF00FF00FF00FF0000FF00000000FF00FFFFFF00FF00FF00FF0000FFFFFF
00000000FFFFFFFFFF
000000000000000000000000000000000000000000000000FF00FF00000000FF00FF00FF
FFFFFFFFFFFFFF00FFFFFF0000FF00FFFFFFFFFFFF0000FFFF00FFFFFF0000FF00000000
FF00FF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FFFFFF0000
0000000000FFFF000000FFFFFFFF00000000000000FF00FFFF00000000FF00FFFFFFFFFF
FF00FFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000FF00FFFFFF0000FFFF00FF
00FF00FF00FFFF00FF00000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000000000FF
FF0000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF0000FFFFFF
00FFFFFF00FFFF0000FF00FF00000000000000000000FF0000000000FFFF00FF00FF0000
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FF00FF0000FF0000FFFF
0000FFFF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFFFF0000FF00
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF000000
FF000000FF000000FFFF000000000000000000000000FFFFFF0000FF00000000FF00FFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000FF00FFFFFFFF00FF00
FFFFFFFFFF00FF000000FF00FF00FF00FF00FF00FF00000000FF00FFFFFFFFFFFF000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF00
000000FFFF00FFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFF000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FF00FF00000000FF
00FF00FFFF00000000FFFF0000FFFF0000FFFF00000000000000FF00FF00FF0000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF
FFFF000000FF00FF000000FF000000FF00FFFF00FF00FF00FF00FFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000FF00FFFFFF0000
FFFF00FF00FFFFFF00FF00FFFFFFFFFF0000FFFFFF00FFFFFF0000FFFF00000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00
00FFFFFF000000FFFFFF000000000000FF0000FFFF00000000FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FF00FF0000FF
0000FFFF00FF00000000FF00FF00FF0000FF000000FF00FF0000FF000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000
FF00FFFF0000FF00FF00FFFFFF0000FF00FFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000FF00FFFFFF
FF000000FF00FFFFFF000000FFFFFFFF0000000000FFFFFFFF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFF0000FFFF00FF000000FFFF00FF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FF00FF00
0000000000FF0000FFFFFF00FF0000FFFFFF0000FF00FF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
00FF00FF0000FF0000FFFF0000FF000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000FF00FF
FFFF0000FF0000FF0000FFFFFFFF00FF000000FFFF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FF0000FF0000FF00000000FFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FF00
FF0000FF0000FF0000FF00FF0000FFFF0000FF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF0000FF00FFFFFFFF0000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000000000FF
00FFFFFFFF0000000000FF00FFFFFFFFFF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FF00FF000000000000FFFF00FF00FF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF00FF00FF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00FFFFFF0000FF0000FFFF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00FF0000FF0000FF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF00FFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.582619 0.735359 0.636678 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(181) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000FF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000FF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000FF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000FF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.582619 0.855774 0.636678 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(182) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF00FFFFFF00FF00FF0000000000FFFFFF00FF00FF0000000000FFFFFF00FF00FF00
00000000FFFFFF0000000000FF00FF00FFFFFF0000000000FF00FF00FFFFFF0000000000
FF00FF00FFFFFF00FF
FFFFFF0000000000FFFFFF00FF00FF0000000000FFFFFF00FF00FF0000000000FFFFFF00
FF00FF0000000000FF00FF00FFFFFF0000000000FF00FF00FFFFFF0000000000FF00FF00
FFFFFF0000000000FF
00000000FF00FF0000000000FFFFFF00FF00FF0000000000FFFFFF00FF00FF0000000000
FFFFFF00FF00FF00FFFFFF0000000000FF00FF00FFFFFF0000000000FF00FF00FFFFFF00
00000000FF00FF0000
FFFFFFFFFF000000FF00FF0000000000FFFFFF00FF00FF0000000000FFFFFF00FF00FF00
00000000FFFFFF0000000000FF00FF00FFFFFF0000000000FF00FF00FFFFFF0000000000
FF00FF000000FFFFFF
000000000000FF00FFFFFF00FF00FF0000000000FFFFFF00FF00FF0000000000FFFFFF00
FF00FF0000000000FF00FF00FFFFFF0000000000FF00FF00FFFFFF0000000000FF00FF00
FFFFFF00FF00000000
FFFFFFFFFFFFFF0000000000FFFFFF00FF00FF0000000000FFFFFF00FF00FF0000000000
FFFFFF00FF00FF00FFFFFF0000000000FF00FF00FFFFFF0000000000FF00FF00FFFFFF00
00000000FFFFFFFFFF
0000000000000000FF00FF0000000000FFFFFF00FF00FF0000000000FFFFFF00FF00FF00
00000000FFFFFF0000000000FF00FF00FFFFFF0000000000FF00FF00FFFFFF0000000000
FF00FF000000000000
FFFFFFFFFFFFFFFFFF000000FF00FF0000000000FFFFFF00FF00FF0000000000FFFFFF00
FF00FF0000000000FF00FF00FFFFFF0000000000FF00FF00FFFFFF0000000000FF00FF00
0000FFFFFFFFFFFFFF
00000000000000000000FF00FFFFFF00FF00FF0000000000FFFFFF00FF00FF0000000000
FFFFFF00FF00FF00FFFFFF0000000000FF00FF00FFFFFF0000000000FF00FF00FFFFFF00
FF0000000000000000
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF00FF00FF0000000000FFFFFF00FF00FF00
00000000FFFFFF0000000000FF00FF00FFFFFF0000000000FF00FF00FFFFFF0000000000
FFFFFFFFFFFFFFFFFF
000000000000000000000000FF00FF0000000000FFFFFF00FF00FF0000000000FFFFFF00
FF00FF0000000000FF00FF00FFFFFF0000000000FF00FF00FFFFFF0000000000FF00FF00
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF0000000000FFFFFF00FF00FF0000000000
FFFFFF00FF00FF00FFFFFF0000000000FF00FF00FFFFFF0000000000FF00FF000000FFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000FF00FFFFFF00FF00FF0000000000FFFFFF00FF00FF00
00000000FFFFFF0000000000FF00FF00FFFFFF0000000000FF00FF00FFFFFF00FF000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF00FF00FF0000000000FFFFFF00
FF00FF0000000000FF00FF00FFFFFF0000000000FF00FF00FFFFFF0000000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000FF00FF0000000000FFFFFF00FF00FF0000000000
FFFFFF00FF00FF00FFFFFF0000000000FF00FF00FFFFFF0000000000FF00FF0000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF0000000000FFFFFF00FF00FF00
00000000FFFFFF0000000000FF00FF00FFFFFF0000000000FF00FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FF00FFFFFF00FF00FF0000000000FFFFFF00
FF00FF0000000000FF00FF00FFFFFF0000000000FF00FF00FFFFFF00FF00000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF00FF00FF0000000000
FFFFFF00FF00FF00FFFFFF0000000000FF00FF00FFFFFF0000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000FF00FF0000000000FFFFFF00FF00FF00
00000000FFFFFF0000000000FF00FF00FFFFFF0000000000FF00FF000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF0000000000FFFFFF00
FF00FF0000000000FF00FF00FFFFFF0000000000FF00FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000FF00FFFFFF00FF00FF0000000000
FFFFFF00FF00FF00FFFFFF0000000000FF00FF00FFFFFF00FF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF00FF00FF00
00000000FFFFFF0000000000FF00FF00FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FF00FF0000000000FFFFFF00
FF00FF0000000000FF00FF00FFFFFF0000000000FF00FF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF0000000000
FFFFFF00FF00FF00FFFFFF0000000000FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FF00FFFFFF00FF00FF00
00000000FFFFFF0000000000FF00FF00FFFFFF00FF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF00
FF00FF0000000000FF00FF00FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FF00FF0000000000
FFFFFF00FF00FF00FFFFFF0000000000FF00FF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00
00000000FFFFFF0000000000FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FF00FFFFFF00
FF00FF0000000000FF00FF00FFFFFF00FF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFF00FF00FF00FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FF00FF00
00000000FFFFFF0000000000FF00FF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FF00FF0000000000FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FF00
FFFFFF00FF00FF00FFFFFF00FF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FF00FF0000000000FF00FF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00FFFFFF00FF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.582619 0.97619 0.636678 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(183) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.642083 0.133279 0.696142 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(168) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.642083 0.253695 0.696142 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(169) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF0000FF00000000FFFFFFFF00FF000000FF00FFFF00FFFF0000FFFFFF0000000000
FFFF00FF0000FFFFFF0000FFFFFF00FFFF0000FF00FF00FFFF00FF0000FFFFFF00FF0000
0000FF0000FFFF0000
000000FFFFFF00FFFFFFFF0000FF00FF00FFFFFF00FF000000FF00FFFF0000FFFFFFFFFF
FF000000FFFFFF0000FFFFFF0000FFFF00000000FFFF00FF000000FFFFFF0000FFFF00FF
FFFFFF00FFFF000000
00000000FF000000FF0000FFFFFF00FF00FF0000FFFF00FFFFFF00FF00000000FF0000FF
0000000000FF00000000FF00000000FF00FFFFFFFF000000FFFFFFFF0000FFFFFF000000
FF0000FFFF00000000
0000000000FFFFFFFF00FFFF0000FFFF00FF00FFFF000000FF000000FFFFFFFFFF00FFFF
00FFFFFFFFFF00FFFFFFFF00FFFFFFFF00FF0000FF00FFFFFF0000FF00FFFF0000FFFFFF
FF00FFFF0000000000
000000000000FF0000FFFF00000000FF00FF00FF0000000000FFFFFFFF0000FF000000FF
00FF0000FF000000FF0000FFFF0000FF00FF00FFFF00FF0000FFFFFF00FF00000000FF00
00FFFF000000000000
00000000000000FFFFFF000000000000FFFF00FF00FFFFFFFFFF0000FF00FFFF00FFFFFF
00FF00FFFF00FFFFFF00FFFF00000000FFFF00FF000000FFFFFF0000FFFF00FFFFFFFF00
FFFF00000000000000
0000000000000000FF0000000000000000FF00FF00FF0000FF00000000FFFF000000FF00
0000FFFF000000FF000000FF00FFFFFFFF000000FFFFFFFF0000FFFFFF000000FF0000FF
FF0000000000000000
000000000000000000FFFFFFFFFFFFFFFFFF00FF00FF00FFFF00FFFFFFFF0000000000FF
FFFFFF0000000000FFFFFFFF00FF0000FF00FFFFFF0000FF00FFFF0000FFFFFFFF00FFFF
000000000000000000
00000000000000000000FF0000FF0000FF000000FFFF00FF000000FF0000FFFFFFFFFFFF
0000FF00FFFFFFFFFF0000FF00FF00FFFF00FF0000FFFFFF00FF00000000FF0000FFFF00
000000000000000000
0000000000000000000000FFFFFF00FFFF00FFFFFF000000FFFFFFFF00FFFF0000FF0000
FFFFFF00FF0000FF00000000FFFF00FF000000FFFFFF0000FFFF00FFFFFFFF00FFFF0000
000000000000000000
000000000000000000000000FF000000FF00FF0000FFFFFFFF0000FF00FF00000000FFFF
FF0000FFFF00FFFF00FFFFFFFF000000FFFFFFFF0000FFFFFF000000FF0000FFFF000000
000000000000000000
00000000000000000000000000FFFFFFFF00FF00FFFF0000FF00FFFF00FF00FFFFFFFF00
00FFFFFF000000FF00FF0000FF00FFFFFF0000FF00FFFF0000FFFFFFFF00FFFF00000000
000000000000000000
0000000000000000000000000000FF0000FFFF00FF00000000FFFF000000FFFF0000FF00
FFFF0000FFFFFFFF00FF00FFFF00FF0000FFFFFF00FF00000000FF0000FFFF0000000000
000000000000000000
000000000000000000000000000000FFFFFF000000FFFFFFFFFF0000000000FF00FFFF00
FF00000000FF0000FFFF00FF000000FFFFFF0000FFFF00FFFFFFFF00FFFF000000000000
000000000000000000
00000000000000000000000000000000FF0000000000FF0000FF00FFFFFFFFFF00FF0000
00FFFFFFFFFF00FFFF000000FFFFFFFF0000FFFFFF000000FF0000FFFF00000000000000
000000000000000000
0000000000000000000000000000000000FFFFFFFFFFFF00FFFF00FF0000FF000000FFFF
FFFF0000FF000000FF00FFFFFF0000FF00FFFF0000FFFFFFFF00FFFF0000000000000000
000000000000000000
000000000000000000000000000000000000FF0000FF000000FF00FF00FFFF00FFFFFF00
00FF00FFFF00FFFFFF00FF0000FFFFFF00FF00000000FF0000FFFF000000000000000000
000000000000000000
00000000000000000000000000000000000000FFFFFF00FFFFFF00FF00FF000000FF0000
0000FFFF000000FF000000FFFFFF0000FFFF00FFFFFFFF00FFFF00000000000000000000
000000000000000000
0000000000000000000000000000000000000000FF000000FF000000FFFF00FFFFFF00FF
FFFFFF0000000000FFFFFFFF0000FFFFFF000000FF0000FFFF0000000000000000000000
000000000000000000
000000000000000000000000000000000000000000FFFFFFFF00FFFFFF000000FF000000
FF0000FFFFFFFFFFFF0000FF00FFFF0000FFFFFFFF00FFFF000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FF0000FFFF0000FFFFFFFF00FFFF
FF00FFFF0000FF0000FFFFFF00FF00000000FF0000FFFF00000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FFFFFF00000000FF0000FFFF00
00FFFF00000000FFFFFF0000FFFF00FFFFFFFF00FFFF0000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FF000000000000FFFFFF0000
0000FF00FFFFFFFF0000FFFFFF000000FF0000FFFF000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FFFFFFFFFFFFFF0000FFFF
FFFFFF00FF0000FF00FFFF0000FFFFFFFF00FFFF00000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FF0000FF0000FFFFFF00
00FF000000FFFFFF00FF00000000FF0000FFFF0000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFF00FFFF0000FF
FFFF00FFFFFF0000FFFF00FFFFFFFF00FFFF000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FF000000FF00FFFF
0000FFFF0000FFFFFF000000FF0000FFFF00000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFFFFFF00FF00
000000FF00FFFF0000FFFFFFFF00FFFF0000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FF0000FFFF00
FFFFFFFF00FF00000000FF0000FFFF000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFFFF0000
00FF0000FFFF00FFFFFFFF00FFFF00000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
0000FFFFFF000000FF0000FFFF0000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFF0000FFFFFFFF00FFFF000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
00FF00000000FF0000FFFF00000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFF00FFFFFFFF00FFFF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF000000FF0000FFFF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFFFFFF00FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF0000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.642083 0.374111 0.696142 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(170) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000FF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.642083 0.494527 0.696142 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(171) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFF00
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFF0000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFF000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFF00000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFF0000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FFFF000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFF00000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FFFF0000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FFFF000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFF00000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FFFF0000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FFFF000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFF00000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000FFFF0000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FFFF000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFF00000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FFFF0000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FFFF000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFF00000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFF0000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FFFF000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFF00000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FFFF0000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FFFF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FFFF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.642083 0.614943 0.696142 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(172) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000FF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.642083 0.735359 0.696142 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(173) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF000000FF000000FF000000FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FF000000FF00
0000FF000000FF0000
000000FF00FF0000000000FF00FF00000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF00FF0000
000000FF00FF000000
00000000FF00000000000000FF0000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
00000000FF00000000
0000000000FF00FF00FF00FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF00FF
00FF00FF0000000000
000000000000FF000000FF00000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
0000FF000000000000
00000000000000FF00FF0000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
00FF00000000000000
0000000000000000FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF0000000000000000
000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
000000000000000000
00000000000000000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
000000000000000000
0000000000000000000000FF00FF0000000000FF00FF0000000000FF00FF0000000000FF
00FF0000000000FF00FF0000000000FF00FF0000000000FF00FF0000000000FF00FF0000
000000000000000000
000000000000000000000000FF00000000000000FF00000000000000FF00000000000000
FF00000000000000FF00000000000000FF00000000000000FF00000000000000FF000000
000000000000000000
00000000000000000000000000FF00FF00FF00FF000000000000000000FF00FF00FF00FF
000000000000000000FF00FF00FF00FF000000000000000000FF00FF00FF00FF00000000
000000000000000000
0000000000000000000000000000FF000000FF0000000000000000000000FF000000FF00
00000000000000000000FF000000FF0000000000000000000000FF000000FF0000000000
000000000000000000
000000000000000000000000000000FF00FF00000000000000000000000000FF00FF0000
0000000000000000000000FF00FF00000000000000000000000000FF00FF000000000000
000000000000000000
00000000000000000000000000000000FF000000000000000000000000000000FF000000
000000000000000000000000FF000000000000000000000000000000FF00000000000000
000000000000000000
0000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00000000
00000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF0000000000000000
000000000000000000
000000000000000000000000000000000000FF000000FF000000FF000000FF0000000000
0000000000000000000000000000FF000000FF000000FF000000FF000000000000000000
000000000000000000
00000000000000000000000000000000000000FF00FF0000000000FF00FF000000000000
000000000000000000000000000000FF00FF0000000000FF00FF00000000000000000000
000000000000000000
0000000000000000000000000000000000000000FF00000000000000FF00000000000000
00000000000000000000000000000000FF00000000000000FF0000000000000000000000
000000000000000000
000000000000000000000000000000000000000000FF00FF00FF00FF0000000000000000
0000000000000000000000000000000000FF00FF00FF00FF000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FF000000FF000000000000000000
000000000000000000000000000000000000FF000000FF00000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FF00FF00000000000000000000
00000000000000000000000000000000000000FF00FF0000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FF0000000000000000000000
0000000000000000000000000000000000000000FF000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF0000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FF00FF0000000000FF
00FF0000000000FF00FF0000000000FF00FF000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FF00000000000000
FF00000000000000FF00000000000000FF00000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FF00FF00FF00FF
000000000000000000FF00FF00FF00FF0000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FF000000FF00
00000000000000000000FF000000FF000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF00FF0000
0000000000000000000000FF00FF00000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000000000FF0000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF00FF
00FF00FF00FF00FF00FF00FF000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
0000FF000000FF000000FF00000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
00FF0000000000FF00FF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF00000000000000FF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00FF00FF00FF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF00FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.642083 0.855774 0.696142 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(174) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000FFFF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000FFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000FFFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000FFFF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000FFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000FFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000FFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FFFF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FFFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FFFF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.642083 0.97619 0.696142 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(175) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF0000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF00000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FF0000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FF00000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FF0000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FF00000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FF0000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FF0000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000FF000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF00000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF0000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FF000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FF00000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FF0000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FF000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF00000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF0000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.701548 0.133279 0.755607 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(160) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.701548 0.253695 0.755607 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(161) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFF00
00000000FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFF0000
0000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFF000000
000000000000FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFF00000000
00000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFF0000000000
0000000000000000FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFF000000000000
000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFF00000000000000
00000000000000000000FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FF0000000000000000
0000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
000000000000000000
000000000000000000000000FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF00
000000000000000000
00000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF0000
000000000000000000
0000000000000000000000000000FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF000000
000000000000000000
000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF00000000
000000000000000000
00000000000000000000000000000000FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF0000000000
000000000000000000
0000000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF000000000000
000000000000000000
000000000000000000000000000000000000FFFFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF00000000000000
000000000000000000
00000000000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF0000000000000000
000000000000000000
0000000000000000000000000000000000000000FFFFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF000000000000000000
000000000000000000
000000000000000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF00000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FFFFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF0000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FFFFFF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF00000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FFFF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF0000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FFFFFF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FFFF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF00000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FFFFFF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF0000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FFFF000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFF00FF00
FF00FF00FF00FF00FF00FF00FF00FFFFFF00000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFF00FF00
FF00FF00FF00FF00FF00FF00FF00FFFF0000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFF00
FF00FF00FF00FF00FF00FF00FFFFFF000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFF00
FF00FF00FF00FF00FF00FF00FFFF00000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FF00FF00FF00FF00FF00FFFFFF0000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF00FF00FF00FF00FF00FFFF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFF00FF00FF00FFFFFF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF00FF00FF00FFFF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFF00FFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.701548 0.374111 0.755607 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(162) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FF00FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FF00FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FF00FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FF00FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FF00
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FF00FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.701548 0.494527 0.755607 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(163) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFF00
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFF0000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF00
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF0000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF00000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF0000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF00000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF0000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF00000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF0000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF00000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FFFF0000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FFFFFF000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FF00FFFF00000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FFFFFF0000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FF00FFFF000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FFFFFF00000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FF00FFFF0000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FFFFFF000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FF00FFFF00000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FFFFFF0000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FF00FFFF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FFFFFF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF00FFFF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.701548 0.614943 0.755607 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(164) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.701548 0.735359 0.755607 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(165) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF00FF00FF00FF00FF00FF00FF00FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FF00FF00FF00
FF00FF00FF00FF00FF
000000FF000000FF000000FF000000FF0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF000000FF
000000FF000000FF00
00000000FF00FF0000000000FF00FF000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF00FF00
00000000FF00FF0000
0000000000FF00000000000000FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF0000
0000000000FF000000
000000000000FF00FF00FF00FF0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
FF00FF00FF00000000
00000000000000FF000000FF000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000FF0000000000
0000000000000000FF00FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF00FF000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00000000000000
00000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF0000000000000000
0000000000000000000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000000000000000
000000000000000000000000FF00FF0000000000FF00FF0000000000FF00FF0000000000
FF00FF0000000000FF00FF0000000000FF00FF0000000000FF00FF0000000000FF00FF00
000000000000000000
00000000000000000000000000FF00000000000000FF00000000000000FF000000000000
00FF00000000000000FF00000000000000FF00000000000000FF00000000000000FF0000
000000000000000000
0000000000000000000000000000FF00FF00FF00FF000000000000000000FF00FF00FF00
FF000000000000000000FF00FF00FF00FF000000000000000000FF00FF00FF00FF000000
000000000000000000
000000000000000000000000000000FF000000FF0000000000000000000000FF000000FF
0000000000000000000000FF000000FF0000000000000000000000FF000000FF00000000
000000000000000000
00000000000000000000000000000000FF00FF00000000000000000000000000FF00FF00
000000000000000000000000FF00FF00000000000000000000000000FF00FF0000000000
000000000000000000
0000000000000000000000000000000000FF000000000000000000000000000000FF0000
00000000000000000000000000FF000000000000000000000000000000FF000000000000
000000000000000000
000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF000000
0000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00000000000000
000000000000000000
00000000000000000000000000000000000000FF000000FF000000FF000000FF00000000
000000000000000000000000000000FF000000FF000000FF000000FF0000000000000000
000000000000000000
0000000000000000000000000000000000000000FF00FF0000000000FF00FF0000000000
00000000000000000000000000000000FF00FF0000000000FF00FF000000000000000000
000000000000000000
000000000000000000000000000000000000000000FF00000000000000FF000000000000
0000000000000000000000000000000000FF00000000000000FF00000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FF00FF00FF00FF00000000000000
000000000000000000000000000000000000FF00FF00FF00FF0000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FF000000FF0000000000000000
00000000000000000000000000000000000000FF000000FF000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FF00FF000000000000000000
0000000000000000000000000000000000000000FF00FF00000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FF00000000000000000000
000000000000000000000000000000000000000000FF0000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF00000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FF00FF0000000000
FF00FF0000000000FF00FF0000000000FF00FF0000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
00FF00000000000000FF00000000000000FF000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FF00FF00FF00
FF000000000000000000FF00FF00FF00FF00000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF000000FF
0000000000000000000000FF000000FF0000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF00FF00
000000000000000000000000FF00FF000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF0000
00000000000000000000000000FF00000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
FF00FF00FF00FF00FF00FF00FF0000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000FF000000FF000000FF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF00FF0000000000FF00FF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00000000000000FF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00FF00FF00FF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF000000FF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.701548 0.855774 0.755607 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(166) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFF0000FF000000FFFFFF00FF000000FF0000FF00FF000000FF00000000FF00FF00
00FFFF000000FFFF00FF000000FF00FF00FFFF0000FFFFFF00FF00000000000000000000
000000000000000000
FFFFFF0000FF0000FF00FFFF0000FFFFFFFFFF00FF0000FFFFFFFFFF00FF00FF0000FFFF
FFFF0000FF00FFFF00FFFFFFFFFF00FFFFFF0000FF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000FF0000FF0000FFFF00FF000000000000FFFFFFFF0000000000FFFFFF00FF0000
000000FF0000FFFF00FFFF00000000FFFF0000FF0000FF00FF0000000000000000000000
000000000000000000
FFFFFFFFFF00FF0000FF000000FFFFFFFFFFFFFFFF00000000FF00FF00FFFF0000FFFFFF
FFFFFFFF00FF000000FFFF00FF00FF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000FFFFFFFF00FF00FFFF00000000000000FF00FF0000FFFFFF0000FF000000
0000000000FFFFFFFFFF0000FFFFFF00FF00FFFFFFFF00FF000000000000000000000000
000000000000000000
FFFFFFFFFFFFFF00000000FFFFFF0000FF00FF00FF00FFFFFF00FF00000000FF0000FF00
FF00FF00FF000000000000FF00000000FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000FF00FF00000000FF0000FFFFFF00FFFF0000FFFFFFFFFFFF00FF0000
FFFFFF00FFFFFFFFFFFFFFFF00FF00FF00000000FF00FF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FF00000000FFFF00FF00000000000000FFFFFF
FF000000FFFF00000000000000FFFFFF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000FFFF0000000000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000
0000FF00FFFF00FF00FF00FF00FFFF0000FFFFFF00FF0000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FFFF0000000000FF00000000000000000000FF
00FF0000FFFF00FFFFFF00FFFFFF0000FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000FF0000FFFFFF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFF0000FFFF0000FFFF0000FF0000FF00FF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FF0000FFFFFF0000000000000000000000
00FFFF000000FF000000FF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000FFFFFFFFFFFF00FF00000000FF00FF00FF00FF00FF00
FF000000FF00FFFFFFFFFF00FF00FFFFFFFF00FF00000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFF00FFFF00000000FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000FF00FF00FF00000000000000FFFF0000FFFF0000
FFFF00000000FFFF00FF00FF00000000FF00FF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00FF00FF00FFFF00FF000000FF
000000FF00FF000000FFFFFF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFF0000FFFFFF00FFFFFF0000FFFFFFFFFF
00FF00FFFFFF00FF00FFFF0000FFFFFF00FF000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFF0000FF0000000000
00FFFFFF000000FFFFFF0000FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000FF0000FF00FF000000FF0000FF00FF00
FF00000000FF00FFFF0000FF0000FF00FF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFF00FF0000FFFF
FF00FF00FF0000FFFF00FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000FFFFFFFF0000000000FFFFFFFF00
0000FFFFFF00FF000000FFFFFFFF00FF0000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00FF00FFFF000000
FF00FFFF0000FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FF00FF0000FFFFFF0000FF00
FFFFFF0000FF000000000000FF00FF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF000000FF0000
FFFF0000FF0000FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FFFF000000FF00FFFFFF
FF0000FF0000FF0000FFFFFF00FF00000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFF0000
0000FF0000FF0000FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FF0000FFFF0000FF
00FF0000FF0000FF0000FF00FF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF00
00FFFFFFFF00FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFF00
FF0000000000FFFFFFFF00FF000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FF00FF00
FFFF000000000000FF00FF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF0000FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FFFF
0000FF0000FFFFFF00FF0000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF0000FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FF0000FF0000FF00FF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFF00FF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.701548 0.97619 0.755607 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(167) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF0000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF00000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FF0000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FF00000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FF0000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FF000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FF00000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FF0000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF00000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FF0000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000FF000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF00000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF0000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FF000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FF00000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FF0000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FF000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF00000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF0000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.761013 0.133279 0.815072 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(152) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF00FFFFFFFF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF00FFFFFFFF000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FF00FFFFFFFF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FF00FFFFFFFF0000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FF00FFFFFFFF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FF00FFFFFFFF00000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF00FFFFFFFF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF00FFFFFFFF000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FF00FFFFFFFF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF00FFFFFFFF0000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF00FFFFFFFF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FF00FFFFFFFF00000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF00FFFFFFFF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF00FFFFFFFF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FFFFFFFF0000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF00FFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00FFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.761013 0.253695 0.815072 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(153) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000FF00FF00FF00FF00000000000000000000000000000000000000000000000000FF
00FF00FF00FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000FFFF0000FFFF0000000000000000000000000000000000000000000000000000
FFFF0000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000FF000000FF0000000000000000000000000000000000000000000000000000
00FF000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000FFFFFFFF0000000000000000000000000000000000000000000000000000
0000FFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000FF00FF0000000000000000000000000000000000000000000000000000
000000FF00FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000FFFF0000000000000000000000000000000000000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000FF0000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF0000
0000FFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000FF00FF0000000000FF00FF0000000000FF00FF0000
000000FF00FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000FFFF000000000000FFFF000000000000FFFF0000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000FF00000000000000FF00000000000000FF0000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFF0000000000000000FFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000FF00FF00FF00FF000000000000000000FF
00FF00FF00FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000FFFF0000FFFF00000000000000000000
FFFF0000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000FF000000FF00000000000000000000
00FF000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FFFFFFFF00000000000000000000
0000FFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FF00FF00000000000000000000
000000FF00FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FFFF00000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FF00000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FF00FF00FF00FF00FF
00FF00FF00FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FFFF0000FFFF0000
FFFF0000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000FF0000
00FF000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFF0000
0000FFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF00FF0000
000000FF00FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFF0000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF0000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
00FF00FF00FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFF0000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FF000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF00FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.761013 0.374111 0.815072 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(154) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF00FF00000000FFFF00FFFFFF00FF0000FF0000FF00000000FFFF00FF00FFFF0000
FF0000FF00FF00FF00FFFFFFFF00FFFFFFFF000000FFFFFFFF0000000000000000000000
000000000000000000
FFFFFF000000FFFFFFFF00FFFF00FF000000FFFF0000FF0000FFFFFF00FFFF00000000FF
FF0000FF000000FF000000000000FF00FF00FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000FFFFFF00FF00FFFF00FFFF0000FFFF00FFFFFF0000FF00FF00000000FFFFFFFF
00FFFFFF0000FFFF0000FFFFFFFFFF000000FF00FF00FFFF000000000000000000000000
000000000000000000
FFFFFFFFFF00FF000000FF00FFFF00FFFFFF00FFFF00FF0000FF000000FFFFFFFF00FF00
FFFF00FF0000FF00FFFFFF00FF00FF0000FFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000FF0000FFFF00000000FF00FF00000000FF0000FF0000FFFF00FF00FFFF00
000000FF0000FF0000000000FF000000FFFF00FFFFFFFF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFF0000FF00FFFFFFFFFF000000FFFFFFFF0000FF0000FF00FFFF00000000
FFFFFFFF0000FF0000FFFFFFFF0000FFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000FFFF00000000000000FFFFFF00FF00FFFFFF0000FF00000000FFFFFF
FF00FF00FFFFFF0000FF00FF00FFFFFF00FFFF00FFFF0000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FF000000FF00FF0000FF0000FFFFFF00FF
00FFFF0000000000FFFF000000FF00FF00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000FF00FF00FF00FF00FFFF0000FFFF000000FFFF0000FF00FF0000
00FF00FFFFFFFFFFFF00FFFFFFFF000000FFFFFFFF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FF00FFFFFF00FFFFFFFF00FFFFFF000000FF
FFFF0000000000000000FF00FF00FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFF0000FFFF0000000000FF00FF00FFFF00FF0000FFFF
00FF0000FFFFFFFFFFFFFF000000FF00FF00FFFF00000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF00FFFFFFFFFFFF000000FF00FFFF0000FF00
FFFF0000FF00FF00FF00FF0000FFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000FF0000FF0000000000000000FFFFFF00000000FFFF00
000000FFFF000000FF000000FFFF00FFFFFFFF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFF00FF0000FFFFFF00FF
FFFFFFFF00FFFFFFFF0000FFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000FFFF0000FF00FF00FF00FF000000FFFF00FF0000
0000000000FF00FF00FFFFFF00FFFF00FFFF000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF000000FF000000FFFFFF00FFFF0000
FFFFFFFFFFFF000000FF00FF00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FF00FF0000FFFF0000FFFF00FF00000000FF
FF00FF00FF00FFFFFFFF000000FFFFFFFF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFFFF00FFFF0000FFFFFF
00FFFF000000FF00FF00FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000FFFFFF00FFFF00FF00000000FFFF00FF
00000000FFFFFF000000FF00FF00FFFF0000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FF0000FFFFFF00FFFF
0000FFFFFF00FF0000FFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000FF0000FFFFFF0000FF00FF000000
00FFFF00FF000000FFFF00FFFFFFFF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FF000000FFFF
FFFF00FFFF0000FFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFF000000FFFF0000FFFF00
FF00FFFF00FFFFFF00FFFF00FFFF00000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFF00FF
FF00000000FF00FF00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FF00FF00FFFF00FF0000
0000FFFFFFFF000000FFFFFFFF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFF0000
FFFFFF00FF00FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FFFFFF00000000FF
FF00FF000000FF00FF00FFFF000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFF
00FFFF0000FFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FF0000FF00FF
00000000FFFF00FFFFFFFF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000
00FFFFFFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FFFF0000
FFFF00FF00FFFF00FFFF0000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF00FFFF00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FF00
FF00000000FFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFF00FF00FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF0000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.761013 0.494527 0.815072 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(155) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.761013 0.614943 0.815072 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(156) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FF00FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FF00FF0000FF0000FF0000FF0000FF0000FF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FF00FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF0000FF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FFFF00FFFF00FFFF00FF
FF00FFFF00FF00FF0000FF0000FF0000FF0000FF00000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000FFFF00FFFF00FFFF00
FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FF
FF00FFFF00FF00FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FF000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00
FFFF00FFFF00FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000FFFF00FFFF00FF
FF00FFFF00FF00FF0000FF0000FF0000FF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FFFF00FFFF00
FFFF00FFFF00FF0000FF0000FF0000FF0000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF
FF00FFFF00FF00FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000FFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00
FFFF00FFFF00FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FFFF00FF
FF00FFFF00FF00FF0000FF0000FF00000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
00FFFF00FFFF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000FFFF00
FFFF00FFFF00FF0000FF0000FF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FF00FFFF00FF00FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FFFF
00FFFF00FFFF0000FF0000FF000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF00FFFF00FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF00FFFF00FF00FF0000FF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFF00FFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFF00FFFF00FF0000FF0000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF00FFFF0000FF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFF00FF00FF00000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.761013 0.735359 0.815072 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(157) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000FF00FF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000FF00FF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000FF00FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000FF00FF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000FF00FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000FF00FF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000FF00FF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000FF00FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000FF00FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000FF00FF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000FF00FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000FF00FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000FF00FF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000FF00FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000FF00FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000FF00FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000FF00FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000FF00FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FF00FF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FF00FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FF00FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FF00FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FF00FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FF00FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FF00FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FF00FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FF00FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF00FF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF00FF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF00FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
00FF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF00FF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00FF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF00FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.761013 0.855774 0.815072 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(158) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF00000000000000FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFF0000FF0000FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000FF00FF0000000000FF00FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000FF00000000000000FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFF0000FF0000FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000FF00FF0000000000FF00FF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000FF00000000000000FF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000FF00FF0000000000FF00FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000FF00000000000000FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFF0000FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000FF00FF0000000000FF00FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FF00000000000000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFF0000FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000FF00FF0000000000FF00FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000FF00000000000000FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFF0000FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FF00FF0000000000FF00FF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FF00000000000000FF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFF00
00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FF00FF0000000000
FF00FF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FF0000000000
0000FF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000
FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FF00FF00
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FF00
000000000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FF00FF000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.761013 0.97619 0.815072 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(159) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.820477 0.133279 0.874536 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(144) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FF00FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF00FFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FF00FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
FFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FF00FFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF00FFFF
FFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FF00FFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FF00FFFFFFFF
FF0000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FF00FFFFFFFFFF00
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FF00FFFFFFFFFF000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FF00FFFFFFFFFF0000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF00FFFFFFFFFF00000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000FF00FFFFFFFFFF000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF00FFFFFFFFFF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FF00FFFFFFFFFF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FF00FFFFFFFFFF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF00FFFFFFFFFF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF00FFFFFFFFFF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FF00FFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FFFFFFFFFF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FFFFFFFFFF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.820477 0.253695 0.874536 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(145) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFFFFFFFFFFFF00000000FF00FFFFFF00FFFFFFFF000000FFFFFFFFFFFF00000000
00FFFF000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000FFFF00FF00FFFFFFFFFFFF0000FFFF0000FF00FFFFFFFFFF00FFFF00FF00000000
0000FFFFFFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000FFFFFF0000FFFF00FFFF000000FFFFFFFF0000FFFF00FF0000FFFFFF00000000
000000FFFF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000FFFF000000FF0000FFFFFFFFFF00FFFF000000FFFFFF000000FFFF00000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000FFFFFFFFFF000000FFFF00FF0000FFFFFFFFFF00FF00000000FFFFFFFFFF
FFFFFFFFFF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000FFFF00FF00000000FFFFFF000000FFFF00FFFFFF0000000000FFFF00FF
FF00FF00FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000FFFFFF0000000000FFFF00000000FF0000FFFF000000000000FF0000
FFFFFF0000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000FFFF000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFF0000
00FFFF000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000FFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF00FF00FFFF00FF0000
0000FFFFFFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000FFFF00FF00FFFF0000FF0000FFFF00FFFFFF0000FFFFFF0000
000000FFFF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000FFFFFF0000FFFFFFFF000000FFFFFF00FF000000FFFF0000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000FFFF000000FF00FFFFFFFFFF00FFFFFF00000000FFFFFF
FFFFFFFFFF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000FFFFFFFFFF0000FFFF00FFFFFF00FFFFFFFFFFFF00FF
FF00FF00FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000FFFF00FF000000FFFFFF00FFFFFF00FFFF00FF0000
FFFFFF0000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000FFFFFF00000000FFFF0000FFFF0000FFFFFF0000
00FFFF000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000FFFF0000000000FF000000FFFFFFFF00FF0000
0000FFFFFFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFF00000000FF00FFFFFF0000
000000FFFF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000FFFF00FF00FFFFFFFFFFFF0000FFFF0000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000FFFFFF0000FFFF00FFFF000000FFFFFF
FFFFFFFFFF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000FFFF000000FF0000FFFFFFFFFF00FF
00FFFF00FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FFFFFFFFFF000000FFFF00FFFFFF
0000FF0000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FFFF00FF00000000FFFFFF00FF
FFFFFF000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FFFFFF0000000000FFFF0000
FF00FFFFFFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FFFF000000000000FFFFFF
FF0000FFFF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFF00FF
FF000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FFFF00FF00FFFF0000
FFFFFFFFFF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FFFFFF0000FFFFFF
FF00FF00FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFF000000FF00
FFFFFF0000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFF00
00FFFF000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFF00FF00
0000FFFFFFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFF00
000000FFFF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFF00
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF00FF00FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFF0000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF000000FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.820477 0.374111 0.874536 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(146) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFFFFFFFF000000FF00FF00FFFFFFFFFF0000000000FF00FFFFFFFFFFFFFFFFFF00
FF000000FFFFFF000000FF00FFFFFFFFFFFFFFFFFF00FF0000000000FFFFFFFFFF00FF00
FF000000FFFFFFFFFF
FFFFFF00FF00FFFFFFFFFF000000FF00FF00FFFFFFFFFFFFFF0000000000000000000000
FFFFFFFFFF00FFFFFFFFFF0000000000000000000000FFFFFFFFFFFFFF00FF00FF000000
FFFFFFFFFF00FF00FF
00000000FFFFFF00FF00FFFFFFFFFF000000FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF000000FFFFFFFF
FF00FF00FFFFFF0000
FFFFFFFFFF00FF000000FF00FF00FFFFFFFFFF000000FFFFFF00FF00FF00FF00FF00FF00
FFFFFF0000000000FFFFFF00FF00FF00FF00FF00FF00FFFFFF000000FFFFFFFFFF00FF00
FF000000FF00FFFFFF
000000000000FFFFFFFFFF000000FF00FF00FFFFFFFFFF00FFFFFF000000FFFFFF000000
FF00FFFFFFFFFFFFFF00FF000000FFFFFF000000FFFFFF00FFFFFFFFFF00FF00FF000000
FFFFFFFFFF00000000
FFFFFFFFFFFFFF00FF00FFFFFFFFFF000000FF00FF00FFFFFF00FFFFFFFFFF00FFFFFFFF
FF000000000000000000FFFFFFFFFF00FFFFFFFFFF00FFFFFF00FF00FF000000FFFFFFFF
FF00FF00FFFFFFFFFF
0000000000000000FFFFFF00FF00FFFFFFFFFF000000FF00FFFFFF00FF00FFFFFF00FF00
FFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFF00FF000000FFFFFFFFFF00FF00
FFFFFF000000000000
FFFFFFFFFFFFFFFFFF00FF000000FF00FF00FFFFFFFFFF0000000000FFFFFF00FFFFFF00
000000000000000000000000FFFFFF00FFFFFF0000000000FFFFFFFFFF00FF00FF000000
FF00FFFFFFFFFFFFFF
00000000000000000000FFFFFFFFFF000000FF00FF00FFFFFFFFFFFFFF00FFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FF00FF000000FFFFFFFF
FF0000000000000000
FFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF000000FF00FF00FF00FFFFFF00FFFFFF00
FF00FF00FF00FF00FF00FF00FFFFFF00FFFFFF00FF00FF00FF000000FFFFFFFFFF00FF00
FFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFF00FF00FFFFFFFFFF000000FFFFFF00FFFFFF00FFFF
FF000000FFFFFF000000FFFFFF00FFFFFF00FFFFFF000000FFFFFFFFFF00FF00FFFFFF00
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF00FF00FFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFF00FFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFF00FF00FF000000FF00FFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000FFFFFFFFFF000000FF00FF00FFFFFF00FFFFFF00FFFF
FF00FF00FFFFFF00FF00FFFFFF00FFFFFF00FFFFFF00FF00FF000000FFFFFFFFFF000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF000000FF00FFFFFF00FF000000
0000FFFFFF00FFFFFF0000000000FF00FFFFFF00FF000000FFFFFFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000FFFFFF00FF00FFFFFFFFFF0000000000FFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFF0000000000FFFFFFFFFF00FF00FFFFFF0000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF00FF00FFFFFFFFFFFFFF00FF00
FF00FFFFFF00FFFFFF00FF00FF00FFFFFFFFFFFFFF00FF00FF000000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFF000000FF00FF00FF00FFFFFF00
0000FF00FFFFFF00FF000000FFFFFF00FF00FF00FF000000FFFFFFFFFF00000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF000000FFFFFF00FFFF
FFFFFF0000000000FFFFFFFFFF00FFFFFF000000FFFFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000FFFFFF00FF00FFFFFFFFFF00FFFFFF00
FF00FFFFFFFFFFFFFF00FF00FFFFFF00FFFFFFFFFF00FF00FFFFFF000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF00FF00FFFFFF00FFFF
FF000000000000000000FFFFFF00FFFFFF00FF00FF000000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000FFFFFFFFFF000000FF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF000000FFFFFFFFFF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF0000000000
FF00FF00FF00FF00FF00FF0000000000FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFF00FF00FFFFFFFFFFFF
FF000000FFFFFF000000FFFFFFFFFFFFFF00FF00FFFFFF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF00FF00FF00
FFFFFFFFFF00FFFFFFFFFF00FF00FF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FFFFFFFFFF000000FFFF
FF00FF00FFFFFF00FF00FFFFFF000000FFFFFFFFFF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00
FFFFFF0000000000FFFFFF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FFFFFF00FF00FFFF
FF00FFFFFFFFFFFFFF00FFFFFF00FF00FFFFFF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF00
FFFFFF00FF00FF00FFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFF00
00000000FFFFFF0000000000FFFFFFFFFF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FFFFFF00
FF00FF00FFFFFF00FF00FF00FFFFFF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
0000FFFFFF00FFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFFFF00FFFFFF00FFFFFFFFFF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFF00FFFFFF00FFFFFF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF0000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.820477 0.494527 0.874536 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(147) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.820477 0.614943 0.874536 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(148) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFF00FFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFF00FF
FF0000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFF00
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FFFF00FFFF000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FFFFFF0000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFF00FFFF00000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFF000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000FFFF00FFFF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000FFFFFF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FFFF00FFFF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FFFFFF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFF00FFFF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FFFF00FFFF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FFFFFF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF00FFFF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.820477 0.735359 0.874536 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(149) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFFFFFFFFFF000000000000FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000FFFF00FFFF00000000000000FF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000FFFFFF00FF00000000000000FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000FFFF0000FF00000000000000FF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000FFFFFFFF0000000000000000FF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000FFFF00FF0000000000000000FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000FFFFFF000000000000000000FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000FFFF00000000000000000000FF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000FFFF00FFFF00FFFF00FFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000FFFFFF00FF00FFFFFF00FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000FFFF0000FF00FFFF0000FF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000FFFFFFFF0000FFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000FFFF00FF0000FFFF00FF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000FFFFFF000000FFFFFF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000FFFF00000000FFFF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFF00FF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000FFFF00FFFF0000FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000FFFFFF00FF0000FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000FFFF0000FF0000FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FFFFFFFF000000FF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FFFF00FF000000FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FFFFFF00000000FF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FFFF0000000000FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FFFF00FFFF00FF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FFFFFF00FF00FF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFF0000FF00FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFF0000
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFF00FF00
00FF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFF00
0000FF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFF00
000000FF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF00FFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF0000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.820477 0.855774 0.874536 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFF00FFFF00FFFFFF00FFFF00FFFF0000000000000000000000000000000000FFFF
00FFFF00FFFFFF00FFFF00FFFF0000000000000000000000000000000000FFFF00FFFF00
FFFFFF00FFFF00FFFF
FFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FF00FFFFFF00FF00FF
00000000FFFFFF00FFFFFF00FFFFFF000000000000000000000000000000000000000000
FFFFFF00FFFFFF00FFFFFF000000000000000000000000000000000000000000FFFFFF00
FFFFFF00FFFFFF0000
FFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF00FFFFFF00FFFFFF
000000000000FFFF00FF00FFFF0000000000000000000000000000000000000000000000
0000FFFF00FF00FFFF00000000000000000000000000000000000000000000000000FFFF
00FF00FFFF00000000
FFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FFFFFFFFFF
0000000000000000FFFFFF00000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
FFFFFF000000000000
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
00000000000000000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF0000000000000000
FFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00
FF00FFFFFF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00
FFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFF00FFFFFF0000000000FFFFFF00FFFFFF0000000000
FFFFFF00FFFFFF00FFFFFF0000000000FFFFFF00FFFFFF0000000000FFFFFF00FFFFFF00
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF
FF00FFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000FFFF00FF00FFFF00FFFF00FF00FFFF00000000000000
0000FFFF00FF00FFFF000000000000000000FFFF00FF00FFFF00FFFF00FF00FFFF000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000FFFFFF0000000000FFFFFF000000000000000000
00000000FFFFFF00000000000000000000000000FFFFFF0000000000FFFFFF0000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFF00FFFF00FFFFFF00FFFF00FFFF00FFFF
00FFFF00FFFFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF00FFFF00FFFF00000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFF00
FF00FFFFFF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000FFFFFF00FFFFFF00FFFFFF0000000000
FFFFFF00FFFFFF00FFFFFF0000000000FFFFFF00FFFFFF00FFFFFF000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFF
FF00FFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000FFFF00FF00FFFF00000000000000
0000FFFF00FF00FFFF000000000000000000FFFF00FF00FFFF0000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFF000000000000000000
00000000FFFFFF00000000000000000000000000FFFFFF00000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FFFF00FFFF00FFFF00FF
FF00FFFF00FF00FFFF00FFFF00FFFF00FFFF00FFFF000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00
FFFFFF00FF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FFFFFF00FFFFFF00
00000000FFFFFF0000000000FFFFFF00FFFFFF0000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FFFF00FF00FF
FF00FFFF00FF00FFFF00FFFF00FF00FFFF00000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FFFFFF00
00000000FFFFFF0000000000FFFFFF000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FFFF
00FFFF00FFFFFF00FFFF00FFFF0000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFF00FFFFFF00FFFFFF00000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFF00FF00FFFF000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.820477 0.97619 0.874536 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(151) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF000000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.879942 0.133279 0.934001 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(136) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000FFFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000FFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000FFFF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000FFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FFFF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000FFFF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000FFFF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FFFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000FFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FFFF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000FFFF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.879942 0.253695 0.934001 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(137) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFFFF00FF00FFFFFFFF000000FFFF00FF00FFFFFFFF000000FFFF00FF00FFFFFFFF
000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00FFFF00
000000FF000000FFFF00FF00FFFFFFFF000000FFFF00FF00FFFFFFFF000000FFFF00FF00
FFFFFFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF0000
00000000FFFFFFFF000000FFFF00FF00FFFFFFFF000000FFFF00FF00FFFFFFFF000000FF
FF00FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF000000
0000000000FF0000FFFFFFFF000000FFFF00FF00FFFFFFFF000000FFFF00FF00FFFFFFFF
000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00FFFF00000000
000000000000FFFFFF00FF00FFFFFFFF000000FFFF00FF00FFFFFFFF000000FFFF00FF00
FFFFFFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF0000000000
00000000000000FF000000FFFF00FF00FFFFFFFF000000FFFF00FF00FFFFFFFF000000FF
FF00FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF000000000000
0000000000000000FFFFFFFF000000FFFF00FF00FFFFFFFF000000FFFF00FF00FFFFFFFF
000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF00000000000000
000000000000000000FF0000FFFFFFFF000000FFFF00FF00FFFFFFFF000000FFFF00FF00
FFFFFFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF0000000000000000
00000000000000000000FFFFFF00FF00FFFFFFFF000000FFFF00FF00FFFFFFFF000000FF
FF00FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
000000000000000000
0000000000000000000000FF000000FFFF00FF00FFFFFFFF000000FFFF00FF00FFFFFFFF
000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
000000000000000000
000000000000000000000000FFFFFFFF000000FFFF00FF00FFFFFFFF000000FFFF00FF00
FFFFFFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000
000000000000000000
00000000000000000000000000FF0000FFFFFFFF000000FFFF00FF00FFFFFFFF000000FF
FF00FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF000000
000000000000000000
0000000000000000000000000000FFFFFF00FF00FFFFFFFF000000FFFF00FF00FFFFFFFF
000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00000000
000000000000000000
000000000000000000000000000000FF000000FFFF00FF00FFFFFFFF000000FFFF00FF00
FFFFFFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000000000
000000000000000000
00000000000000000000000000000000FFFFFFFF000000FFFF00FF00FFFFFFFF000000FF
FF00FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF000000000000
000000000000000000
0000000000000000000000000000000000FF0000FFFFFFFF000000FFFF00FF00FFFFFFFF
000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00000000000000
000000000000000000
000000000000000000000000000000000000FFFFFF00FF00FFFFFFFF000000FFFF00FF00
FFFFFFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000000000000000
000000000000000000
00000000000000000000000000000000000000FF000000FFFF00FF00FFFFFFFF000000FF
FF00FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF000000000000000000
000000000000000000
0000000000000000000000000000000000000000FFFFFFFF000000FFFF00FF00FFFFFFFF
000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00000000000000000000
000000000000000000
000000000000000000000000000000000000000000FF0000FFFFFFFF000000FFFF00FF00
FFFFFFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FFFFFF00FF00FFFFFFFF000000FF
FF00FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FF000000FFFF00FF00FFFFFFFF
000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFF000000FFFF00FF00
FFFFFFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FF0000FFFFFFFF000000FF
FF00FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FFFFFF00FF00FFFFFFFF
000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FF000000FFFF00FF00
FFFFFFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FFFFFFFF000000FF
FF00FF00FFFF00FFFF00FFFF00FFFF00FFFF000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FF0000FFFFFFFF
000000FFFF00FFFF00FFFF00FFFF00FFFF00000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFF00FF00
FFFFFFFF00FFFF00FFFF00FFFF00FFFF0000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF000000FF
FF00FF00FFFF00FFFF00FFFF00FFFF000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFFFF
000000FFFF00FFFF00FFFF00FFFF00000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF0000
FFFFFFFF00FFFF00FFFF00FFFF0000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FF00FF00FFFF00FFFF00FFFF000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000FFFF00FFFF00FFFF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFF00FFFF00FFFF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FF0000FFFF00FFFF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFF00FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF00FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.879942 0.374111 0.934001 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(138) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000FFFF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000FFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000FFFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000FFFF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000FFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000FFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000FFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FFFF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FFFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FFFF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.879942 0.494527 0.934001 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(139) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFF00
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFF0000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFF000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFF00000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFF0000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FFFF000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFF00000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FFFF0000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FFFF000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFF00000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FFFF0000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FFFF000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFF00000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000FFFF0000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FFFF000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFF00000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FFFF0000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FFFF000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFF00000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFF0000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FFFF000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFF00000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FFFF0000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FFFF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FFFF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.879942 0.614943 0.934001 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(140) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000FFFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000FFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000FFFF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000FFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FFFF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000FFFF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000FFFF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FFFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000FFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FFFF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000FFFF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.879942 0.735359 0.934001 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(141) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFF00
000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FFFF0000
00000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFF000000
0000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FFFF00000000
000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFF0000000000
00000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFF000000000000
0000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFF00000000000000
000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
FF0000000000000000
00000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
000000000000000000
0000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF00
000000000000000000
000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF0000
000000000000000000
00000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF000000
000000000000000000
0000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF00000000
000000000000000000
000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF0000000000
000000000000000000
00000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF000000000000
000000000000000000
0000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF00000000000000
000000000000000000
000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF0000000000000000
000000000000000000
00000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF000000000000000000
000000000000000000
0000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF00000000000000000000
000000000000000000
000000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF0000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF00000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF0000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF00000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FFFF0000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FFFF000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FFFF00000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FFFF0000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF00FF00FF
00FF00FF00FF00FF00FF00FF00FFFF000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF00FF00
FF00FF00FF00FF00FF00FF00FFFF00000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF00FF
00FF00FF00FF00FF00FF00FFFF0000000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
FF00FF00FF00FF00FF00FFFF000000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
00FF00FF00FF00FF00FFFF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF00FF00FF00FF00FFFF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FF00FF00FF00FFFF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FF00FF00FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FF00FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.879942 0.855774 0.934001 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(142) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000FFFF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000FFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000FFFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000FFFF0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000FFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000FFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000FFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFF00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FFFF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FFFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FFFF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.879942 0.97619 0.934001 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(143) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFF00
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFF0000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFF000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFF00000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFF0000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FFFF000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFF00000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FFFF0000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FFFF000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFF00000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FFFF0000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FFFF000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFF00000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000FFFF0000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FFFF000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFF00000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FFFF0000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FFFF000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFF00000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFF0000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FFFF000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFF00000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FFFF0000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FFFF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FFFF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.939407 0.133279 0.993466 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(128) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.939407 0.253695 0.993466 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(129) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000FFFF0000FFFF0000FFFF0000FFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFF0000FFFF
0000FFFF0000FFFF00
00000000FFFFFFFF00000000FFFFFFFF0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFFFFFF00
000000FFFFFFFF0000
0000000000FFFF000000000000FFFF000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFF0000
00000000FFFF000000
000000000000FFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFF00000000
00000000000000FFFF0000FFFF0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
0000FFFF0000000000
0000000000000000FFFFFFFF000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFFFF000000000000
000000000000000000FFFF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFF00000000000000
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000
0000000000000000000000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FF
FF0000FFFF00FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
000000000000000000
000000000000000000000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000
FFFFFFFF000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00
000000000000000000
00000000000000000000000000FFFF000000000000FFFF000000000000FFFF0000000000
00FFFF0000000000FFFF000000000000FFFF000000000000FFFF000000000000FFFF0000
000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFF
FFFF00000000000000FFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF000000
000000000000000000
000000000000000000000000000000FFFF0000FFFF00000000000000000000FFFF0000FF
FF000000000000000000FFFF0000FFFF00000000000000000000FFFF0000FFFF00000000
000000000000000000
00000000000000000000000000000000FFFFFFFF000000000000000000000000FFFFFFFF
0000000000000000000000FFFFFFFF000000000000000000000000FFFFFFFF0000000000
000000000000000000
0000000000000000000000000000000000FFFF0000000000000000000000000000FFFF00
000000000000000000000000FFFF0000000000000000000000000000FFFF000000000000
000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
000000000000000000
00000000000000000000000000000000000000FFFF0000FFFF0000FFFF0000FFFF000000
0000000000000000000000000000FFFF0000FFFF0000FFFF0000FFFF0000000000000000
000000000000000000
0000000000000000000000000000000000000000FFFFFFFF00000000FFFFFFFF00000000
000000000000000000000000000000FFFFFFFF00000000FFFFFFFF000000000000000000
000000000000000000
000000000000000000000000000000000000000000FFFF000000000000FFFF0000000000
00000000000000000000000000000000FFFF000000000000FFFF00000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FFFFFFFFFFFFFFFF000000000000
0000000000000000000000000000000000FFFFFFFFFFFFFFFF0000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FFFF0000FFFF00000000000000
000000000000000000000000000000000000FFFF0000FFFF000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFF0000000000000000
00000000000000000000000000000000000000FFFFFFFF00000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FFFF000000000000000000
0000000000000000000000000000000000000000FFFF0000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FFFF0000FFFF0000FF
FF0000FFFF00FFFF0000FFFF0000FFFF0000FFFF00000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FFFFFFFF00000000
FFFFFFFF000000FFFFFFFF00000000FFFFFFFF0000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFF0000000000
00FFFF0000000000FFFF000000000000FFFF000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFF00000000000000FFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFF0000FF
FF000000000000000000FFFF0000FFFF0000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFFFF
0000000000000000000000FFFFFFFF000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFF00
000000000000000000000000FFFF00000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF0000FFFF00FFFF0000FFFF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFF000000FFFFFFFF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF0000000000FFFF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.939407 0.374111 0.993466 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(130) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFFFFFFFF00FF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFF00FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFF00FF0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000FFFFFFFFFF00FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000FFFFFFFFFF00FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFF00FF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000FFFFFFFFFF00FF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000FFFFFFFFFF00FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFF00FF0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000FFFFFFFFFF00FF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000FFFFFFFFFF00FF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFF00FF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FFFFFFFFFF00FF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FFFFFFFFFF00FF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFF00
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FFFFFFFF
FF00FF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFFFF00FF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFF00FF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.939407 0.494527 0.993466 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(131) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF000000FFFF0000000000FFFFFFFFFFFF000000FFFFFFFF00FFFFFF00FF0000
0000FFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFFFFFF000000000000FF00FFFF00FFFFFFFFFF00FF0000FFFF0000FFFFFF
FFFFFF00FF00FFFF00
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FFFF00000000000000FFFFFF0000FF00FFFF0000FFFFFFFF000000FFFF00
FFFF0000FFFFFF0000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000FFFF000000FFFFFF000000FFFF00FFFFFFFFFF0000
FF000000FFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FFFFFFFFFFFFFFFFFFFF00000000FF00FFFFFFFFFF0000FF00FFFF000000
FFFFFFFFFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF00FF00FFFF00FFFF0000000000FFFFFF00FFFF000000FFFFFF00000000
FF00FFFF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF0000FFFFFF0000FF000000000000FFFF0000FF00000000FFFF0000000000
FFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF000000FFFF000000FFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000
FFFF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFFFFFF00000000FF00FFFF00FF00FFFFFFFFFF00FFFF00FFFFFFFFFFFFFF
FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FFFF0000000000FFFFFF0000FFFFFF00FFFF0000FF0000FFFF00FF00FFFF
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF000000000000FFFF000000FF00FFFFFF000000FFFFFFFF0000FFFFFF00
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FFFFFFFFFFFFFFFF00000000FFFFFF00FFFFFFFFFF00FF000000FFFF0000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF00FF00FFFF00FFFFFFFFFFFF00FFFFFF00FFFF0000FFFFFFFFFF000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF0000FFFFFF0000FF00FFFF00FFFFFF00FFFFFF000000FF00FFFF00000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF000000FFFF000000FFFFFF0000FFFF0000FFFF00000000FFFFFF0000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFFFFFF00000000FF00FFFFFFFF000000FF0000000000FFFF000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FFFF0000000000FFFFFF00FF00000000FFFFFFFFFFFFFF00000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF000000000000FFFF0000FFFFFFFFFFFF00FF00FFFF0000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FFFFFFFFFFFFFFFF000000FFFF00FFFF0000FFFFFF000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF00FFFF00FF00FFFFFFFFFF0000FF000000FFFF00000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF0000FF0000FFFFFF00FFFF000000FFFFFFFFFF0000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF000000FFFFFFFF00FFFFFF00000000FF00FFFF000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFFFFFF00FF0000FFFF0000000000FFFFFF00000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FFFF0000FFFFFFFF000000000000FFFF0000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF000000FFFF00FFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FFFFFFFFFF0000FFFF00FF00FFFF00000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF00FF00FFFFFFFF0000FFFFFF0000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF0000FFFFFF00FF000000FFFF000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF000000FFFF0000FFFFFFFFFF00000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFFFFFF000000FF00FFFF0000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FFFF00000000FFFFFF000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000FFFF00000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FFFFFFFFFFFFFF0000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF00FF00FFFF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFF0000FFFFFF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF000000FFFF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.939407 0.614943 0.993466 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(132) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.939407 0.735359 0.993466 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(133) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000FFFF0000FFFF0000FFFF0000FFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFF0000FFFF
0000FFFF0000FFFF00
00000000FFFFFFFF00000000FFFFFFFF0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFFFFFF00
000000FFFFFFFF0000
0000000000FFFF000000000000FFFF000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFF0000
00000000FFFF000000
000000000000FFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFF00000000
00000000000000FFFF0000FFFF0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
0000FFFF0000000000
0000000000000000FFFFFFFF000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFFFF000000000000
000000000000000000FFFF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFF00000000000000
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000
0000000000000000000000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FF
FF0000FFFF00FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
000000000000000000
000000000000000000000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000
FFFFFFFF000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00
000000000000000000
00000000000000000000000000FFFF000000000000FFFF000000000000FFFF0000000000
00FFFF0000000000FFFF000000000000FFFF000000000000FFFF000000000000FFFF0000
000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFF
FFFF00000000000000FFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF000000
000000000000000000
000000000000000000000000000000FFFF0000FFFF00000000000000000000FFFF0000FF
FF000000000000000000FFFF0000FFFF00000000000000000000FFFF0000FFFF00000000
000000000000000000
00000000000000000000000000000000FFFFFFFF000000000000000000000000FFFFFFFF
0000000000000000000000FFFFFFFF000000000000000000000000FFFFFFFF0000000000
000000000000000000
0000000000000000000000000000000000FFFF0000000000000000000000000000FFFF00
000000000000000000000000FFFF0000000000000000000000000000FFFF000000000000
000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
000000000000000000
00000000000000000000000000000000000000FFFF0000FFFF0000FFFF0000FFFF000000
0000000000000000000000000000FFFF0000FFFF0000FFFF0000FFFF0000000000000000
000000000000000000
0000000000000000000000000000000000000000FFFFFFFF00000000FFFFFFFF00000000
000000000000000000000000000000FFFFFFFF00000000FFFFFFFF000000000000000000
000000000000000000
000000000000000000000000000000000000000000FFFF000000000000FFFF0000000000
00000000000000000000000000000000FFFF000000000000FFFF00000000000000000000
000000000000000000
00000000000000000000000000000000000000000000FFFFFFFFFFFFFFFF000000000000
0000000000000000000000000000000000FFFFFFFFFFFFFFFF0000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000FFFF0000FFFF00000000000000
000000000000000000000000000000000000FFFF0000FFFF000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFF0000000000000000
00000000000000000000000000000000000000FFFFFFFF00000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000FFFF000000000000000000
0000000000000000000000000000000000000000FFFF0000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000FFFF0000FFFF0000FF
FF0000FFFF00FFFF0000FFFF0000FFFF0000FFFF00000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000FFFFFFFF00000000
FFFFFFFF000000FFFFFFFF00000000FFFFFFFF0000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFF0000000000
00FFFF0000000000FFFF000000000000FFFF000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFF00000000000000FFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFF0000FF
FF000000000000000000FFFF0000FFFF0000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFFFF
0000000000000000000000FFFFFFFF000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFF00
000000000000000000000000FFFF00000000000000000000000000000000000000000000
000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000
000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FF0000FFFF00FFFF0000FFFF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFF000000FFFFFFFF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFF0000000000FFFF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFF00FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.939407 0.855774 0.993466 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(134) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFF00FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000FFFF00FFFF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000FFFFFF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000FFFF00FFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000FFFF00FFFF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000FFFFFF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFF00FFFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000FFFFFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000FFFF00FFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000FFFF00FFFF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000FFFFFF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FFFF00FFFF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000000000000000FFFFFF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000000000000000FFFF
00FFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFF00FFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.939407 0.97619 0.993466 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(135) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF000000
000000FFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF00000000
000000FFFF00FFFF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FF0000000000
0000FF00FFFFFF0000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
00FF0000FFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FF00000000000000
00FFFFFFFF00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FF0000000000000000
FF00FFFF0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FF000000000000000000
FFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FF00000000000000000000
FFFF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FFFF00FFFF00FFFF00FFFF
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FF00FFFFFF00FF00FFFFFF00
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FF0000FFFF00FF0000FFFF0000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FFFFFFFF0000FFFFFFFF000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FF00FFFF0000FF00FFFF00000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FFFFFF000000FFFFFF0000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FFFF00000000FFFF000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FF00FFFFFFFFFFFF00000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000FF0000FFFF00FFFF0000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF0000FF00FFFFFF000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF0000FF0000FFFF00000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FF000000FFFFFFFF0000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FF000000FF00FFFF000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FF00000000FFFFFF00000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FF0000000000FFFF0000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF00FFFF00FFFF00000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF00FF00FFFFFF0000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FF00FF0000FFFF000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FF0000FFFFFFFF00000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF0000FF00FFFF0000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FF000000FFFFFF000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF00000000FFFF00000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFFFFFFFFFF0000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF00FFFF000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00FFFFFF00000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF0000FFFF0000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FF00FFFF00000000000000000000000000000000000000000000000000000000
000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.998872 0.133279 1.05293 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(120) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000FF00000000FFFF0000FF00FFFF000000FF00FFFF00FF00000000FFFF00FFFF00
0000FFFF000000FF00FF00FFFFFF0000FFFF000000FFFF00FFFF0000FF0000FF00FFFFFF
00FFFF000000000000
FFFFFF0000FFFF00FFFFFFFF00FF000000FFFF00FF0000FF00FF00FFFF0000FF000000FF
FF000000FFFF00FF0000FFFFFFFFFF000000FFFF0000FF0000FF00FFFFFF00FF00000000
FFFFFFFF00FFFF00FF
FFFFFFFF0000FF00000000FF0000FFFF000000FFFFFF00FF0000FFFFFFFF0000FFFF0000
00FFFF000000FFFFFF000000000000FFFF0000FF00FFFFFF00FF000000FF00FF00FFFF00
000000FF000000FFFF
FFFFFFFFFF0000FFFF00FFFFFF000000FFFF00000000FFFFFF00000000FF00FFFFFFFF00
FFFFFFFF00FFFFFFFFFF00FFFF00FFFFFFFF00FF000000FF0000FFFF00FF00FF000000FF
FF00FFFFFF00FFFFFF
FFFFFFFFFFFF0000FF00000000FFFF0000FF00FFFF000000FF00FFFF00FF00000000FF00
000000FF0000000000FF0000FF0000000000FFFFFF00FFFFFF0000FF00FF0000FFFF0000
FF00000000FFFFFFFF
FFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FF000000FFFF00FF0000FF00FF00FFFF0000FF
FF00FFFFFF00FFFF00FF00FFFFFF00FFFF00000000FFFFFFFFFF00FF00FF00FFFFFFFF00
00FFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF0000FF00000000FF0000FFFF000000FFFFFF00FF0000FFFFFFFF0000
FF000000FF0000FF00FF000000FF0000FF00FFFF0000000000FF00FF0000FFFFFFFFFFFF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF000000FFFF00000000FFFFFF00000000FF00FF
FFFF00FFFFFF0000FFFFFF00FFFFFF0000FFFFFFFF00FFFF00FF00FF00FFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF00000000FFFF0000FF00FFFF000000FF00FFFF00FF0000
0000FFFFFFFFFF00000000FFFFFFFFFF00000000FF0000FF00FF00FF0000000000000000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FF000000FFFF00FF0000FF00FF00FF
FF0000000000FF00FFFF000000000000FFFF00FFFFFF00FF0000FFFFFF00FFFF00FFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF0000FFFF000000FFFFFF00FF0000FFFF
FFFF00FFFF00FF000000FFFF00FFFF0000FF00000000FFFFFF000000FF0000FF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF000000FFFF00000000FFFFFF000000
00FF0000FF0000FFFF000000FFFFFFFF00FF00FFFF00000000FFFF00FF00FFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFF0000FF00FFFF000000FF00FFFF
00FF00FFFFFF000000FFFF00000000FF00FF0000FF00FFFF0000FF00FF00000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FF000000FFFF00FF0000FF
00FF00000000FFFF0000FF00FFFF0000FFFFFF0000FFFFFFFF00FF0000FFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF0000FFFF000000FFFFFF00FF
0000FFFF00FFFFFFFF00FF0000FF00FFFFFFFFFF0000000000FFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF000000FFFF00000000FFFF
FF0000FF0000000000FFFFFF00FF0000000000FF00FFFF00FFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFF0000FF00FFFF000000
FF00FFFFFF00FFFF00000000FFFFFF00FFFF00FF0000FF000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FF000000FFFF00
FF000000FF0000FF00FFFF000000FF0000FF00FF00FFFFFF00FFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF0000FFFF000000FF
FFFF00FFFFFF0000FFFFFFFF00FFFFFF00FF00FF000000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF000000FFFF0000
0000FFFFFFFFFF00000000FF000000FF0000FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFF0000FF00FF
FF000000000000FFFF00FFFFFF00FFFFFF000000FF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FF0000
00FFFF00FFFF0000FF000000FF00000000FFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF0000FFFF
000000FFFFFFFF0000FFFF0000FFFF00FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF000000
FFFF00000000FF00FFFFFFFF000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFF00
00FF00FFFF00FF0000000000FFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF
00FF000000FFFFFF00FFFF000000FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF
0000FFFF000000FF000000FFFF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF
FF000000FFFF0000FFFF0000FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000
00FFFF0000FF00FFFFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00
FFFFFFFF00FF00000000FF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00
000000FF0000FFFF00FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FF00FFFFFF000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00000000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFF00FFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FF00000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 0.998872 0.253695 1.05293 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(121) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF00
00FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF00
00FFFF0000FFFF0000
FFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF00FF
FFFFFFFF000000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FF
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FF
FF0000FFFF0000FFFF
FFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF00FFFFFF
FFFFFFFFFFFF000000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF00
00FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF00
00FFFF0000FFFFFFFF
FFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FF
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF00
00FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FF
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FFFF0000FFFF0000FFFF0000FFFF00
00FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FFFF0000FFFF0000FFFF0000FF
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FFFF0000FFFF0000FFFF00
00FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FFFF0000FFFF0000FF
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FFFF0000FFFF00
00FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FFFF0000FF
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FFFF00
00FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FF
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000
FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00
00FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00
0000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 0.998872 0.374111 1.05293 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(122) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF000000
FFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF0000FF
FFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF000000FFFF
FFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF0000FFFFFF
FFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF000000FFFFFFFF
FFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF
00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF
00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 0.998872 0.494527 1.05293 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(123) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FF
FFFFFFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFF
FFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000
00000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
0000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000
00000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
0000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 0.998872 0.614943 1.05293 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(124) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00000000FF00FF0000FFFFFF00000000FF00FF0000FFFFFF00000000FF00FF
0000FFFFFF00000000
FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FFFFFF00000000FF00FF0000FFFFFF00000000FF00FF0000FFFF
FF00000000FFFF00FF
FFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FFFFFF00000000FF00FF0000FFFFFF00000000FF00FF0000FFFFFF000000
00FF00FF000000FFFF
FFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00000000FF00FF0000FFFFFF00000000FF00FF0000FFFFFF00000000FF00FF
0000FFFFFF00FFFFFF
FFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FFFFFF00000000FF00FF0000FFFFFF00000000FF00FF0000FFFF
FF00000000FFFFFFFF
FFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FFFFFF00000000FF00FF0000FFFFFF00000000FF00FF0000FFFFFF000000
00FFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00000000FF00FF0000FFFFFF00000000FF00FF0000FFFFFF00000000FF00FF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FFFFFF00000000FF00FF0000FFFFFF00000000FF00FF0000FFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FFFFFF00000000FF00FF0000FFFFFF00000000FF00FF0000FFFFFF000000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00000000FF00FF0000FFFFFF00000000FF00FF0000FFFFFF00000000FFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FFFFFF00000000FF00FF0000FFFFFF00000000FF00FF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FFFFFF00000000FF00FF0000FFFFFF00000000FF00FF0000FFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00000000FF00FF0000FFFFFF00000000FF00FF0000FFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FFFFFF00000000FF00FF0000FFFFFF00000000FFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FFFFFF00000000FF00FF0000FFFFFF00000000FF00FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00000000FF00FF0000FFFFFF00000000FF00FF0000FFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FFFFFF00000000FF00FF0000FFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FFFFFF00000000FF00FF0000FFFFFF00000000FFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00000000FF00FF0000FFFFFF00000000FF00FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FFFFFF00000000FF00FF0000FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FFFFFF00000000FF00FF0000FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF00
00FF0000FF00000000FF00FF0000FFFFFF00000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF
0000FF0000FF00FF0000FFFFFF00000000FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000
FF0000FF0000FFFFFF00000000FF00FF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF00
00FF0000FF00000000FF00FF0000FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF
0000FF0000FF00FF0000FFFFFF00000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000
FF0000FF0000FFFFFF00000000FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF00
00FF0000FF00000000FF00FF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF
0000FF0000FF00FF0000FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000
FF0000FF0000FFFFFF00000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00
00FF0000FF00000000FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
0000FF0000FF00FF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000FF0000FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF0000FF00000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FF0000FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 0.998872 0.735359 1.05293 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(125) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000
FFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF00FF
FFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FFFF
FFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF00FFFFFF
FFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FFFFFFFF
FFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF
000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000
FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000
00FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00
0000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 0.998872 0.855774 1.05293 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(126) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
000000000000000000
FFFFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000
FFFF0000FFFF0000FF
FFFFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFF00000000FFFF
FFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFF0000FFFFFF
FFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000000000FFFFFFFF
FFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF00
00FFFF0000FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF
00000000FFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFF
FF0000FFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF000000000000
0000FFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF00
00FFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF00
00FFFF0000FF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
00000000FFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FF0000FFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
0000FFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00
00FFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFF0000FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 0.998872 0.97619 1.05293 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(127) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FF
FFFFFFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFF
FFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000
00000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
0000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000
00000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
0000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.05834 0.133279 1.1124 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(112) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 1.05834 0.253695 1.1124 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(113) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 1.05834 0.374111 1.1124 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(114) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 1.05834 0.494527 1.1124 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(115) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 1.05834 0.614943 1.1124 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(116) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 1.05834 0.735359 1.1124 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(117) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 1.05834 0.855774 1.1124 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(118) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000FF00FF000000000000FFFF0000FFFF00FF0000000000FF0000FF00FFFFFFFFFF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF000000FFFF0000FF0000FFFFFF00000000FFFF0000FF00FFFF000000FFFFFFFFFF
FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFF00FFFF0000000000FF0000FFFFFF000000FFFFFF0000FFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFF0000FF00FFFF0000000000FF00FFFFFFFF000000000000
00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF00FFFFFFFF000000FFFFFF0000FF000000FFFFFFFFFF0000FF0000
FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFF0000FFFFFFFF00FFFF0000FFFFFFFFFFFF00FFFF00
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFF000000000000FFFFFF0000000000000000FFFFFF
0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FF0000FF0000000000FF00FF0000FF00FFFFFF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFF00FFFF0000FF000000FFFF000000FFFFFF
FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFF00000000FFFFFF000000FF00FFFFFF0000FFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FF0000000000FF000000FFFFFFFF00000000
00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF0000FF000000FF000000000000FF0000
FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFF000000FF000000FF0000FF00FFFF00
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF0000FFFF0000FFFF000000FFFFFF
0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FFFFFF00000000FF00FFFFFF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFF00FF000000FFFFFF
FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF000000000000FFFF0000FFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FF0000FFFFFF00000000
00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFF0000000000FF00FF
0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF0000FF000000FF
FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF000000FF0000
0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF0000FFFF00
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF00000000
FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FF0000
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFF00
00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00000000
FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FF00
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 1.05834 0.97619 1.1124 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(119) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.1178 0.133279 1.17186 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(104) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000
00FF000000FF000000
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFF00FFFFFF00FF
FFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFF000000FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FF000000FFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF
000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFF000000FF0000
00FFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFF000000FF000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000
00FFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 1.1178 0.253695 1.17186 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(105) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000FF0000FF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000FF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF
000000FF0000FF0000
FFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FF00FFFFFF00FF00FF
FFFFFFFF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
000000FF000000FFFF
FFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF00FFFFFF00FFFFFF
FFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00FF0000FFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00
FF00FFFFFF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFF000000FF000000FFFFFFFFFF
000000FF000000FF000000FFFFFFFFFF000000FF000000FFFFFFFFFF000000FF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF
FF00FFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FF0000FF00FF0000FFFFFFFFFFFFFF
FFFF0000FF00FF0000FFFFFFFFFFFFFFFFFF0000FF00FF0000FF0000FF00FF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF000000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFF00
FF00FFFFFF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FFFFFFFFFF
000000FF000000FF000000FFFFFFFFFF000000FF000000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFF
FF00FFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFF
FFFF0000FF00FF0000FFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00
FFFFFF00FF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF
FFFFFFFF000000FFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00
00FF0000FF00FF0000FF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000FF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 1.1178 0.374111 1.17186 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(106) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000000000FFFF00FFFFFF00FF0000FF0000FFFF00FFFF000000FFFF0000FFFFFF
00FF00FF000000FFFF000000FFFF00FFFF00000000FF00FFFF00FF000000FFFF00FF0000
FFFF00000000FF0000
FFFFFF00FFFF00FFFFFFFF00000000FF00FFFFFF00FF0000FF0000FFFF000000FFFFFFFF
FF0000FF00FFFF000000FFFF000000FF0000FFFF00FF00FF0000FF00FFFF000000FF00FF
FFFFFF00FFFF0000FF
FFFFFFFF000000FF00000000FFFF00FF00FF000000FF00FFFFFF00FF0000FFFF00000000
0000FFFFFF000000FFFF000000FFFF0000FFFFFFFF0000FF00FFFFFF000000FFFF0000FF
00000000FF0000FFFF
FFFFFFFFFF00FFFFFF00FFFF000000FF00FF00FFFF0000FF000000FF00FFFFFFFF00FFFF
00FFFFFFFFFF00FFFFFFFF00FFFFFFFF00FF00000000FFFFFF00000000FFFF000000FFFF
FF00FFFF0000FFFFFF
FFFFFFFFFFFF00000000FF0000FFFF0000FF00FF0000FFFFFF00FFFFFF0000000000FF00
00FF0000000000FF00000000FF00000000FF00FFFF00FF000000FFFF00FF0000FFFF0000
0000FF0000FFFFFFFF
FFFFFFFFFFFFFF00FFFF0000FFFFFFFF00FF00FF00FFFFFFFFFF00000000FFFF00FFFFFF
00FF00FFFF00FFFFFF00FFFF0000FFFF00FF00FF0000FF00FFFF000000FF00FFFFFFFF00
FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFF0000FF00FF0000000000FFFF00FF0000FF0000
00FF00FF0000FF000000FF0000FFFFFFFF0000FF00FFFFFF000000FFFF0000FF00000000
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FF00FF00FFFF00FFFFFFFF0000FFFFFF00
FFFFFF0000FFFFFF00FFFFFF00FF00000000FFFFFF00000000FFFF000000FFFFFF00FFFF
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000FF00FF00FF0000FF00000000FFFFFFFFFF
00000000FFFFFFFFFF00000000FF00FFFF00FF000000FFFF00FF0000FFFF00000000FF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFF0000FF00FFFFFF00FFFF0000000000
00FFFF00FF0000000000FFFF00FF00FF0000FF00FFFF000000FF00FFFFFFFF00FFFF0000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FF000000FFFFFF00000000FF0000FFFF00FF
FF000000FF00FFFF00FFFFFFFF0000FF00FFFFFF000000FFFF0000FF00000000FF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFF00000000FFFF00FF00FFFFFFFF00
0000FFFF0000FF0000FF00000000FFFFFF00000000FFFF000000FFFFFF00FFFF0000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00FF0000FFFF00FF0000FF00FF00000000
FFFF000000FFFFFF00FF00FFFF00FF000000FFFF00FF0000FFFF00000000FF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FF00FFFFFFFF0000FFFFFF0000FFFF00
FF0000FFFF00000000FF00FF0000FF00FFFF000000FF00FFFFFFFF00FFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF0000000000FFFFFFFFFF00FF0000
FF00FFFFFFFF00FFFF0000FF00FFFFFF000000FFFF0000FF00000000FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFF00FF0000000000FF00FF
FFFF0000000000FF0000FFFFFF00000000FFFF000000FFFFFF00FFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF0000FF00FFFF00FFFFFF00
000000FFFF00FFFFFF00FF000000FFFF00FF0000FFFF00000000FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF00FF00FF0000FF000000
FFFF00FF0000FF000000FF00FFFF000000FF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF00FF00FFFFFF00FF
FFFFFF0000FFFFFF00FFFFFF000000FFFF0000FF00000000FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF0000FF000000FF
00000000FFFFFFFFFF00000000FFFF000000FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF000000FFFFFF00FFFF
FF00FFFF000000000000FFFF00FF0000FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFF00000000FF00
0000FF0000FFFF00FFFF000000FF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF00FFFF0000
FFFF0000FFFFFFFF000000FFFF0000FF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF000000FF
FFFFFF00FF00000000FFFF000000FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFF00
00000000FF00FFFF00FF0000FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF000000
FFFF00FFFFFF000000FF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FFFF
000000FF000000FFFF0000FF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00
00FFFF0000FFFF000000FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00
FFFFFFFF00FF0000FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000
FF00000000FF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFF00FFFF0000FF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFF000000FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 1.1178 0.494527 1.17186 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(107) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF000000
FFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF
FFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF000000FFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FFFFFF
FFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF000000FFFFFFFF
FFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF00
0000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000
FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
0000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 1.1178 0.614943 1.17186 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(108) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FF
FFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FFFF
FFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF
FFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF
000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000
00FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 1.1178 0.735359 1.17186 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(109) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000000000000000000000000000FF000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000
FFFFFF00FF00FF00FF00FF00FF00FF00FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFF000000FF000000FF000000FF0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF000000FF
000000FF000000FFFF
FFFFFFFFFF00FF0000000000FF00FF000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF00FF00
00000000FF00FFFFFF
FFFFFFFFFFFF00000000000000FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF0000
0000000000FFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FF000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000FF00FF0000000000FF00FF0000000000
FF00FF0000000000FF00FF0000000000FF00FF0000000000FF00FF0000000000FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FF00000000000000FF000000000000
00FF00000000000000FF00000000000000FF00000000000000FF00000000000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF000000000000000000FF00FF00FF00
FF000000000000000000FF00FF00FF00FF000000000000000000FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000000000000000000000FF000000FF
0000000000000000000000FF000000FF0000000000000000000000FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000000000000000000000FF00FF00
000000000000000000000000FF00FF00000000000000000000000000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FF0000
00000000000000000000000000FF000000000000000000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF000000
0000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF00000000
000000000000000000000000000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000FF00FF0000000000
00000000000000000000000000000000FF00FF0000000000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FF000000000000
0000000000000000000000000000000000FF00000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00000000000000
000000000000000000000000000000000000FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000000000000000
00000000000000000000000000000000000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000000000000000
0000000000000000000000000000000000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF
000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000
FF00FF0000000000FF00FF0000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
00FF00000000000000FF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF000000000000000000FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
0000000000000000000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
000000000000000000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF0000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 1.1178 0.855774 1.17186 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(110) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FFFFFF00FFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FFFFFFFF000000FF00FF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF
FFFFFFFFFF00FFFFFF0000FF00FF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FFFFFF
FFFFFFFFFFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFFFFFF
FFFFFFFFFFFFFF00FFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FF00FF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF00000000FFFFFF0000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00000000FFFFFF0000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF00000000FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FFFFFF0000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00000000FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000
0000FFFFFF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
00FF00000000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF0000FF00FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF00000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF00FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 1.1178 0.97619 1.17186 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(111) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000
FFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF
FFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FFFFFF
FFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FFFFFFFF
FFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF
000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF00
0000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000
00FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000
FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
0000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.17727 0.133279 1.23132 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(96) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 1.17727 0.253695 1.23132 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(97) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 1.17727 0.374111 1.23132 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(98) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 1.17727 0.494527 1.23132 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(99) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 1.17727 0.614943 1.23132 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 1.17727 0.735359 1.23132 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(101) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 1.17727 0.855774 1.23132 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(102) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFF
FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 1.17727 0.97619 1.23132 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(103) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF0000
00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000
FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF
000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF00
0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF0000
00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000
FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF
000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF00
0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF0000
00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000
FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF
000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF00
0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF0000
00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000
FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF
000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF00
0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000
00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000
FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.23673 0.133279 1.29079 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(88) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFF00FFFFFF00FF
FFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFF00FF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 1.23673 0.253695 1.29079 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(89) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFF00FFFFFF00FF
FFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFF00FF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 1.23673 0.374111 1.29079 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(90) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFF00FFFFFF00FF
FFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFF00FF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 1.23673 0.494527 1.29079 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(91) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFF00FFFFFF00FF
FFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFF00FF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 1.23673 0.614943 1.29079 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(92) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 1.23673 0.735359 1.29079 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(93) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 1.23673 0.855774 1.29079 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(94) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 1.23673 0.97619 1.29079 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(95) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.29619 0.133279 1.35025 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 1.29619 0.253695 1.35025 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(81) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 1.29619 0.374111 1.35025 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(82) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 1.29619 0.494527 1.35025 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(83) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 1.29619 0.614943 1.35025 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(84) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 1.29619 0.735359 1.35025 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(85) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 1.29619 0.855774 1.35025 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(86) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 1.29619 0.97619 1.35025 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(87) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.35566 0.133279 1.40972 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(72) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFF00FFFFFF00FF
FFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFF00FF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 1.35566 0.253695 1.40972 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(73) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFF00FFFFFF00FF
FFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFF00FF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 1.35566 0.374111 1.40972 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(74) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFF00FFFFFF00FF
FFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFF00FF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 1.35566 0.494527 1.40972 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(75) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFF00FFFFFF00FF
FFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFF00FF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 1.35566 0.614943 1.40972 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(76) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 1.35566 0.735359 1.40972 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(77) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 1.35566 0.855774 1.40972 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(78) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 1.35566 0.97619 1.40972 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(79) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.41512 0.133279 1.46918 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 1.41512 0.253695 1.46918 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(65) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 1.41512 0.374111 1.46918 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(66) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 1.41512 0.494527 1.46918 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(67) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 1.41512 0.614943 1.46918 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(68) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 1.41512 0.735359 1.46918 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(69) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 1.41512 0.855774 1.46918 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 1.41512 0.97619 1.46918 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(71) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.47459 0.133279 1.52865 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(56) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 1.47459 0.253695 1.52865 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(57) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 1.47459 0.374111 1.52865 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(58) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 1.47459 0.494527 1.52865 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(59) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
0000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 1.47459 0.614943 1.52865 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 1.47459 0.735359 1.52865 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(61) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 1.47459 0.855774 1.52865 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(62) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFF00FF0000FF0000000000FF00FFFF0000FFFF0000
00000000FF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFFFFFFFF000000FFFF00FF0000FFFF00000000FFFFFF0000
FF0000FFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFF0000FFFFFF000000FFFFFF0000FF0000000000FF
FF00FFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00000000000000000000FFFFFFFF00FF0000000000FFFF00FF0000FFFF
FF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FF0000FF0000FFFFFFFFFF000000FF0000FFFFFF000000FFFFFF
FF00FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF000000FFFF00FFFFFFFFFFFF0000FFFF00FFFFFFFF0000FFFFFFFF
FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF0000FFFFFF0000000000000000FFFFFF000000000000FFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFF00FF0000FF00FF0000000000FF0000FF000000000000
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFFFF000000FFFF000000FF0000FFFF00FFFF0000FF00FF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFF0000FFFFFF00FF000000FFFFFF00000000FFFF000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000000000000000FFFFFFFF000000FF0000000000FF00FFFFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FF0000FF000000000000FF000000FF0000FFFF0000000000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF000000FFFF00FF0000FF000000FF000000FFFFFF00FF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF0000FFFFFF000000FFFF0000FFFF0000FFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFF00FF00000000FFFFFF00FFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFFFF000000FF00FFFFFFFF00000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFF0000FFFF000000000000FF00FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000000000000000FFFFFF0000FF0000FFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF0000FF00FF0000000000FFFF00FFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF00FFFF000000FF0000FFFFFF0000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00000000FF000000FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FF00FFFF0000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFF00000000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFF0000FF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000000000FFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FF00000000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF000000FF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF0000FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 1.47459 0.97619 1.52865 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(63) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
0000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.53405 0.133279 1.58811 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(48) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 1.53405 0.253695 1.58811 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(49) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 1.53405 0.374111 1.58811 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 1.53405 0.494527 1.58811 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 1.53405 0.614943 1.58811 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(52) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 1.53405 0.735359 1.58811 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(53) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 1.53405 0.855774 1.58811 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(54) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 1.53405 0.97619 1.58811 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(55) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.59352 0.133279 1.64758 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 1.59352 0.253695 1.64758 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 1.59352 0.374111 1.64758 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(42) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 1.59352 0.494527 1.64758 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(43) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 1.59352 0.614943 1.64758 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(44) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 1.59352 0.735359 1.64758 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 1.59352 0.855774 1.64758 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(46) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 1.59352 0.97619 1.64758 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(47) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.65298 0.133279 1.70704 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(32) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 1.65298 0.253695 1.70704 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(33) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 1.65298 0.374111 1.70704 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(34) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 1.65298 0.494527 1.70704 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(35) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 1.65298 0.614943 1.70704 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(36) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 1.65298 0.735359 1.70704 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(37) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 1.65298 0.855774 1.70704 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(38) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 1.65298 0.97619 1.70704 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(39) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.71245 0.133279 1.76651 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 1.71245 0.253695 1.76651 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 1.71245 0.374111 1.76651 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(26) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 1.71245 0.494527 1.76651 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(27) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 1.71245 0.614943 1.76651 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(28) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 1.71245 0.735359 1.76651 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(29) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 1.71245 0.855774 1.76651 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 1.71245 0.97619 1.76651 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(31) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.77191 0.133279 1.82597 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 1.77191 0.253695 1.82597 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(17) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 1.77191 0.374111 1.82597 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(18) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 1.77191 0.494527 1.82597 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(19) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 1.77191 0.614943 1.82597 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 1.77191 0.735359 1.82597 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 1.77191 0.855774 1.82597 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(22) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 1.77191 0.97619 1.82597 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.83138 0.133279 1.88544 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -5 0 ]
[.5 .50633 5 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 1.83138 0.253695 1.88544 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -5 0 ]
[.5 .50633 5 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 1.83138 0.374111 1.88544 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 1.83138 0.494527 1.88544 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 1.83138 0.614943 1.88544 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 1.83138 0.735359 1.88544 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 1.83138 0.855774 1.88544 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 1.83138 0.97619 1.88544 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.89084 0.133279 1.9449 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -5 0 ]
[.5 .50633 5 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.144226 1.89084 0.253695 1.9449 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -5 0 ]
[.5 .50633 5 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.264641 1.89084 0.374111 1.9449 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -5 0 ]
[.5 .50633 5 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.385057 1.89084 0.494527 1.9449 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -5 0 ]
[.5 .50633 5 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.505473 1.89084 0.614943 1.9449 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -5 0 ]
[.5 .50633 5 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.625889 1.89084 0.735359 1.9449 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -5 0 ]
[.5 .50633 5 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.746305 1.89084 0.855774 1.9449 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -5 0 ]
[.5 .50633 5 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.866721 1.89084 0.97619 1.9449 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -5 0 ]
[.5 .50633 5 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{462.5, 921.375},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007>0003VB000`400?l00000o`00003oo`3AcJW?
0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?
0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?
0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?
0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?
0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00603AcJTG00000240dLfY5`00
000P0=7=ZAL000008@3AcJTG00000240dLfY5`00000P0=7=ZAL000008@3AcJTG00000200dLfY5`00
000J0=7=Z@00603AcJTG00000240dLfY5`00000P0=7=ZAL000008@3AcJTG00000240dLfY5`00000P
0=7=ZAL000008@3AcJTG00000200dLfY5`00000J0=7=Z@00603AcJTG0?ooob40dLfY5`00000P0=7=
ZAL0oooo8@3AcJTG00000240dLfY5`3ooolP0=7=ZAL000008@3AcJTG0?ooob00dLfY5`00000J0=7=
Z@00603AcJTG0?ooob40dLfY5`00000P0=7=ZAL0oooo8@3AcJTG00000240dLfY5`3ooolP0=7=ZAL0
00008@3AcJTG0?ooob00dLfY5`00000J0=7=Z@00603AcJTG0?ooob40dLfY5`00000P0=7=ZAL0oooo
8@3AcJTG00000240dLfY5`3ooolP0=7=ZAL000008@3AcJTG0?ooob00dLfY5`00000J0=7=Z@00603A
cJTG00000240dLfY5`00000P0=7=ZAL000008@3AcJTG00000240dLfY5`00000P0=7=ZAL000008@3A
cJTG00000200dLfY5`00000J0=7=Z@00603AcJTG00000240dLfY5`00000P0=7=ZAL000008@3AcJTG
00000240dLfY5`00000P0=7=ZAL000008@3AcJTG00000200dLfY5`00000J0=7=Z@00603AcJTG0?oo
ob40dLfY5`00000P0=7=ZAL0oooo8@3AcJTG00000240dLfY5`3ooolP0=7=ZAL000008@3AcJTG0?oo
ob00dLfY5`00000J0=7=Z@00603AcJTG0?ooob40dLfY5`00000P0=7=ZAL0oooo8@3AcJTG00000240
dLfY5`3ooolP0=7=ZAL000008@3AcJTG0?ooob00dLfY5`00000J0=7=Z@00603AcJTG0?ooob40dLfY
5`00000P0=7=ZAL0oooo8@3AcJTG00000240dLfY5`3ooolP0=7=ZAL000008@3AcJTG0?ooob00dLfY
5`00000J0=7=Z@00603AcJTG00000240dLfY5`00000P0=7=ZAL000008@3AcJTG00000240dLfY5`00
000P0=7=ZAL000008@3AcJTG00000200dLfY5`00000J0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=
Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00703AcJT4@00000@0dLfY0d0000020=7=Z@900000:03A
cJT4@00000@0dLfY0d000000103AcJU00000@0000400000Y0=7=Z@A000000`3AcJT2@00000@0dLfY
0T00000X0=7=Z@A000000`3AcJT2@00000<0dLfY1D00000W0=7=Z@A000000`3AcJT2@00000<0dLfY
1400000X0=7=Z@A000000`3AcJT2@00000@0dLfY0T00000X0=7=Z@A000000`3AcJT2@00000D0dLfY
0d00000W0=7=Z@A000000`3AcJT2@00000@0dLfY0T00000N0=7=Z@00703AcJT00d000000dLfY0=7=
Z@060=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT09@3AcJT00d000000dLfY
0=7=Z@060=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT09`3AcJT00d000000dLfY
0=7=Z@030=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000009`3AcJT00d00
0000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT09`3AcJT0
0d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0:@3A
cJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU0
00009`3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@00000D0dLfY00=000000=7=
Z@3AcJT09P3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@0000080dLfY00A00000
0=7=Z@3AcJU000007@3AcJT001d0dLfY00=000000=7=Z@3AcJT00P3AcJT5@00000050=7=ZD000000
dLfY0=7=ZD000000:03AcJT00d000000dLfY0=7=Z@020=7=Z@E000000P3AcJT3@00002T0dLfY00=0
00000=7=Z@3AcJT01@3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02H0dLfY
00=000000=7=Z@3AcJT01@3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY02P0dLfY
00=000000=7=Z@3AcJT01@3AcJT01D000000dLfY0=7=Z@3AcJU0000002/0dLfY00=000000=7=Z@3A
cJT01@3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY02L0dLfY00=000000=7=Z@3A
cJT01@3AcJT00d000000dLfY0=7=Z@05@00002P0dLfY00=000000=7=Z@3AcJT01@3AcJT00d000000
dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY01/0dLfY000N0=7=Z@05@000003AcJT0dLfY0=7=ZD00
00000P3AcJT014000000dLfY0=7=Z@3AcJT2@00002X0dLfY00E000000=7=Z@3AcJT0dLfY@0000002
0=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0:03AcJT00d000000dLfY0=7=
Z@020=7=Z@9000000`3AcJT014000000dLfY0=7=ZD00000Y0=7=Z@03@000003AcJT0dLfY0080dLfY
0T0000050=7=Z@03@000003AcJT0dLfY02T0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000D0dLfY
00=000000=7=Z@3AcJT0:@3AcJT00d000000dLfY0=7=Z@020=7=Z@9000001P3AcJT00d000000dLfY
0=7=Z@0W0=7=Z@03@000003AcJT0dLfY0080dLfY0T0000030=7=Z@04@000003AcJT0dLfY@00002X0
dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000@0dLfY0T00000N0=7=Z@00703AcJT014000000dLfY
0=7=ZD0000030=7=Z@03@000003AcJU000000080dLfY00A000000=7=Z@3AcJU000009`3AcJT01400
0000dLfY0=7=ZD0000030=7=Z@03@000003AcJU000000080dLfY00A000000=7=Z@3AcJU00000:03A
cJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU0
00009`3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=
Z@3AcJT09`3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY0080dLfY00A00000
0=7=Z@3AcJU00000:03AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY0080dLfY
00A000000=7=Z@3AcJU000009`3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY
00<0dLfY00=000000=7=ZD000000:03AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0
dLfY00<0dLfY00=000000=7=Z@3AcJT07@3AcJT001d0dLfY0T0000050=7=Z@9000000`3AcJT2@000
02T0dLfY0T0000050=7=Z@9000000`3AcJT3@00002T0dLfY0T0000040=7=Z@=000000`3AcJT2@000
02T0dLfY0T0000040=7=Z@=000000`3AcJT2@00002X0dLfY0T0000040=7=Z@=000000`3AcJT2@000
02X0dLfY0T0000040=7=Z@=000000`3AcJT2@00002T0dLfY0T0000040=7=Z@=00000103AcJT2@000
02T0dLfY0T0000040=7=Z@=000000`3AcJT3@00001d0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY
003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY000H0=7=ZAH00000
00<0oooo0=7=Z@3AcJT07`3AcJTG00000200dLfY3@0000020?ooo`8000000P3oool3000000030?oo
o`3AcJT0dLfY01l0dLfY5`00000Q0=7=ZAH0000000<0oooo0=7=Z@3AcJT07P3AcJTG00000240dLfY
5@0000020?ooob00dLfY5`00000J0=7=Z@00603AcJTG00000240dLfY5`00000P0=7=Z@d000000P3o
ool200000080oooo1000000Q0=7=ZAL000008@3AcJTG00000200dLfY5`00000Q0=7=ZA@0000000<0
oooo000000000000803AcJTG000001X0dLfY000H0=7=ZA@0oooo00<000000?ooo`3oool08@3AcJTG
00000200dLfY2`3oool200000080oooo0P0000020?ooo`8000000P3ooolQ0=7=ZAL000008@3AcJTD
0?ooo`030000003oool0oooo0200dLfY5`00000Q0=7=ZA<0oooo0P0000020?ooob00dLfY5`00000J
0=7=Z@00603AcJTC0?ooo`040000003oool0oooo0?ooob40dLfY5`00000P0=7=Z@/0oooo0P000002
0?ooo`8000000P3oool010000000oooo0?ooo`3ooolQ0=7=ZAL000008@3AcJTC0?ooo`040000003o
ool0oooo0?ooob00dLfY5`00000Q0=7=ZA80oooo0P0000030?ooob00dLfY5`00000J0=7=Z@00603A
cJTG0?ooob40dLfY1@0000000`3oool000000000000?00000200dLfY2`3oool200000080oooo0P00
00060?ooob40dLfY5`00000Q0=7=ZAL0oooo803AcJTG00000240dLfY403oool2000000D0oooo803A
cJTG000001X0dLfY000H0=7=ZA40000000<0oooo0000000000000`00000Q0=7=ZAL00000803AcJT=
00000080oooo0P0000000`3oool000000000000300000240dLfY5`00000Q0=7=ZA40000000<0oooo
0000000000000`00000P0=7=ZAL000008@3AcJT@00000080oooo1@00000P0=7=ZAL000006P3AcJT0
01P0dLfY5`00000Q0=7=Z@L0000000<0oooo0000000000003@00000P0=7=Z@d000000P3oool80000
0240dLfY5`00000Q0=7=ZAL00000803AcJTG00000240dLfY3`0000000`3oool00000000000050000
0200dLfY5`00000J0=7=Z@00603AcJT?0?ooo`030000003oool0oooo00D0oooo8@3AcJTG00000200
dLfY2`3oool200000080oooo00<000000?ooo`3oool01@3ooolQ0=7=ZAL000008@3AcJT?0?ooo`03
0000003oool0oooo00D0oooo803AcJTG00000240dLfY3P3oool2000000L0oooo803AcJTG000001X0
dLfY000H0=7=ZAL0oooo8@3AcJT9000000030?ooo`000000000000/00000803AcJT;0?ooo`800000
2P3ooolQ0=7=ZAL000008@3AcJTG0?ooob00dLfY5`00000Q0=7=Z@`0oooo0P0000090?ooob00dLfY
5`00000J0=7=Z@00603AcJTG0?ooob40dLfY2P0000000`3oool000000000000:00000200dLfY2`3o
ool2000000X0oooo8@3AcJTG00000240dLfY5`3ooolP0=7=ZAL000008@3AcJT;0?ooo`8000002P3o
oolP0=7=ZAL000006P3AcJT001P0dLfY5`00000Q0=7=Z@/0000000<0oooo0000000000002@00000P
0=7=ZAL000008@3AcJTG00000240dLfY5`00000P0=7=ZAL000008@3AcJTG00000200dLfY5`00000J
0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?
0=7=Z@00703AcJT4@00000@0dLfY0d0000020=7=Z@900000:03AcJT4@00000@0dLfY0d0000000`3A
cJU00000@0000003@00002L0dLfY140000040=7=Z@=0000000<0dLfY@000040000000T00000W0=7=
Z@A00000103AcJT3@0000080dLfY0T00000Y0=7=Z@A00000103AcJT3@00000<0dLfY0d00000W0=7=
Z@A00000103AcJT3@0000080dLfY0T00000X0=7=Z@A00000103AcJT3@00000040=7=ZD0000100000
@00002T0dLfY140000040=7=Z@=000000`3AcJT00d000000dLfY0=7=Z@0L0=7=Z@00703AcJT00d00
0000dLfY0=7=Z@060=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT09@3AcJT0
0d000000dLfY0=7=Z@060=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT09`3AcJT0
0d000000dLfY0=7=Z@060=7=Z@04@000003AcJT0dLfY@00002X0dLfY00=000000=7=Z@3AcJT01P3A
cJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02H0dLfY00=000000=7=Z@3AcJT0
1P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY02H0dLfY00=000000=7=Z@3AcJT0
1P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02D0dLfY00=000000=7=Z@3A
cJT01P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02H0dLfY00=000000=7=
Z@3AcJT01P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY01`0dLfY000M0=7=Z@03
@000003AcJT0dLfY0080dLfY1D0000001@3AcJU000000=7=Z@3AcJU0000002P0dLfY00=000000=7=
Z@3AcJT00P3AcJT5@00000<0dLfY00=000000=7=Z@3AcJT0:03AcJT00d000000dLfY0=7=Z@020=7=
Z@E000000P3AcJT00d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY0080dLfY1D0000030=7=
Z@03@000003AcJT0dLfY02P0dLfY00=000000=7=Z@3AcJT00P3AcJT5@00000030=7=ZD0000100000
00=00000:03AcJT00d000000dLfY0=7=Z@020=7=Z@E00000103AcJT00d000000dLfY0=7=Z@0V0=7=
Z@03@000003AcJT0dLfY0080dLfY1D0000001@3AcJU000000=7=Z@3AcJU0000002T0dLfY00=00000
0=7=Z@3AcJT00P3AcJT5@00000<0dLfY00=000000=7=Z@3AcJT0703AcJT001h0dLfY00E000000=7=
Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT09`3A
cJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY
0=7=Z@0Y0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03
@000003AcJT0dLfY02P0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY
00<0dLfY00=000000=7=Z@3AcJT0:03AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A00000
0=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0X0=7=Z@05@000003AcJT0dLfY0=7=ZD000000
0P3AcJT014000000dLfY0=7=Z@3AcJT2@00002X0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=
Z@03@000003AcJT0dLfY00=00000:`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=00000
0=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0K0=7=Z@00703AcJT014000000dLfY0=7=ZD000003
0=7=Z@03@000003AcJU000000080dLfY00A000000=7=Z@3AcJU000009`3AcJT014000000dLfY0=7=
ZD0000030=7=Z@03@000003AcJU0000000@0dLfY00=000000=7=Z@3AcJT09`3AcJT014000000dLfY
0=7=ZD0000030=7=Z@03@000003AcJU000000080dLfY00A000000=7=Z@3AcJU000009`3AcJT01400
0000dLfY0=7=ZD0000030=7=Z@03@000003AcJU000000080dLfY00A000000=7=Z@3AcJU00000:03A
cJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJU0000000<0dLfY00=000000=7=ZD000000
:03AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJU0000000<0dLfY00=000000=7=Z@3A
cJT09`3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJU0000000<0dLfY00=000000=7=
Z@3AcJT0:03AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJU000000080dLfY00A00000
0=7=Z@3AcJU000007@3AcJT001d0dLfY0T0000050=7=Z@9000000`3AcJT2@00002T0dLfY0T000005
0=7=Z@9000000`3AcJT2@00002X0dLfY0T0000050=7=Z@9000000`3AcJT2@00002T0dLfY0T000005
0=7=Z@9000000`3AcJT2@00002X0dLfY0T0000050=7=Z@900000103AcJT2@00002T0dLfY0T000005
0=7=Z@9000000`3AcJT3@00002P0dLfY0T0000050=7=Z@9000000`3AcJT3@00002T0dLfY0T000005
0=7=Z@9000000P3AcJT4@00001d0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY
003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY000H0=7=ZAL000008@3AcJTG00000200
dLfY5`00000Q0=7=ZAL000008@3AcJTG00000200dLfY5`00000Q0=7=ZAL00000803AcJTG000001X0
dLfY000H0=7=ZAL000008@3AcJTG00000200dLfY5`00000Q0=7=ZAL000008@3AcJTG00000200dLfY
5`00000Q0=7=ZAL00000803AcJTG000001X0dLfY000H0=7=ZAL0oooo8@3AcJTG00000200dLfY5`3o
oolQ0=7=ZAL000008@3AcJTG0?ooob00dLfY5`00000Q0=7=ZAL0oooo803AcJTG000001X0dLfY000H
0=7=ZAL0oooo8@3AcJTG00000200dLfY5`3ooolQ0=7=ZAL000008@3AcJTG0?ooob00dLfY5`00000Q
0=7=ZAL0oooo803AcJTG000001X0dLfY000H0=7=ZAL0oooo8@3AcJTG00000200dLfY5`3ooolQ0=7=
ZAL000008@3AcJTG0?ooob00dLfY5`00000Q0=7=ZAL0oooo803AcJTG000001X0dLfY000H0=7=ZAL0
00008@3AcJTG00000200dLfY5`00000Q0=7=ZAL000008@3AcJTG00000200dLfY5`00000Q0=7=ZAL0
0000803AcJTG000001X0dLfY000H0=7=ZAL000008@3AcJTG00000200dLfY5`00000Q0=7=ZAL00000
8@3AcJTG00000200dLfY5`00000Q0=7=ZAL00000803AcJTG000001X0dLfY000H0=7=ZAL0oooo8@3A
cJTG00000200dLfY5`3ooolQ0=7=ZAL000008@3AcJTG0?ooob00dLfY5`00000Q0=7=ZAL0oooo803A
cJTG000001X0dLfY000H0=7=ZAL0oooo8@3AcJTG00000200dLfY5`3ooolQ0=7=ZAL000008@3AcJTG
0?ooob00dLfY5`00000Q0=7=ZAL0oooo803AcJTG000001X0dLfY000H0=7=ZAL0oooo8@3AcJTG0000
0200dLfY5`3ooolQ0=7=ZAL000008@3AcJTG0?ooob00dLfY5`00000Q0=7=ZAL0oooo803AcJTG0000
01X0dLfY000H0=7=ZAL000008@3AcJTG00000200dLfY5`00000Q0=7=ZAL000008@3AcJTG00000200
dLfY5`00000Q0=7=ZAL00000803AcJTG000001X0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o
0=7=ZLl0dLfY003o0=7=ZLl0dLfY000L0=7=Z@A000000`3AcJT2@00000<0dLfY1400000W0=7=Z@A0
00000`3AcJT2@00000@0dLfY0T00000Y0=7=Z@A000000`3AcJT2@00000D0dLfY0d00000V0=7=Z@A0
00000`3AcJT2@00000@0dLfY0T00000Y0=7=Z@A000000`3AcJT2@00000<0dLfY0d00000Y0=7=Z@A0
00000`3AcJT2@00000D0dLfY00=000000=7=Z@3AcJT09P3AcJT4@00000<0dLfY0T0000040=7=Z@90
0000:@3AcJT4@00000<0dLfY0T0000030=7=Z@=000007P3AcJT001`0dLfY00=000000=7=Z@3AcJT0
0`3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02P0dLfY00=000000=7=Z@3A
cJT00`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00002P0dLfY00=00000
0=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000050=7=Z@03@000003AcJT0dLfY02D0dLfY00=0
00000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00002P0
dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@00002P0dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003A
cJT0dLfY02H0dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000
003AcJT0dLfY@00002P0dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000040=7=
Z@03@000003AcJT0dLfY01`0dLfY000M0=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3A
cJT00P3AcJT00d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3A
cJT00`3AcJT00d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY00@0dLfY00A000000=7=Z@3A
cJT0dLfY1D00000W0=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT0103AcJT00d00
0000dLfY0=7=Z@0W0=7=Z@03@000003AcJT0dLfY00@0dLfY00E000000=7=Z@3AcJT0dLfY@0000002
0=7=Z@03@000003AcJT0dLfY02L0dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@03
0=7=Z@03@000003AcJT0dLfY02L0dLfY00=000000=7=Z@3AcJT0103AcJT01D000000dLfY0=7=Z@3A
cJU000000080dLfY00=000000=7=Z@3AcJT09`3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003A
cJT0dLfY0080dLfY0d00000M0=7=Z@007P3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0
dLfY0080dLfY00=000000=7=Z@3AcJT0:03AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0
dLfY00<0dLfY00=000000=7=Z@3AcJT0:03AcJT00d000000dLfY0=7=Z@040=7=Z@04@000003AcJT0
dLfY@0000080dLfY00=000000=7=Z@3AcJT09`3AcJT00d000000dLfY0=7=Z@040=7=Z@04@000003A
cJT0dLfY0=7=Z@900000:`3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY00=00000
:`3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0
9`3AcJT00d000000dLfY0=7=Z@040=7=Z@04@000003AcJT0dLfY0=7=Z@900000:`3AcJT00d000000
dLfY0=7=Z@040=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT06`3AcJT001`0
dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0
dLfY@00002L0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04
@000003AcJT0dLfY@00002P0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00
00030=7=Z@03@000003AcJU0000002L0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD0000030=7=Z@03@000003AcJT0dLfY02P0dLfY00A000000=7=Z@3AcJU000000P3AcJT01400
0000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY02P0dLfY00A000000=7=Z@3AcJU000000P3A
cJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00002L0dLfY00A000000=7=Z@3A
cJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00002P0dLfY00A0
00000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@000
01d0dLfY000M0=7=Z@900000103AcJT2@00000@0dLfY0T00000Y0=7=Z@900000103AcJT2@00000@0
dLfY0T00000Z0=7=Z@900000103AcJT2@00000D0dLfY0T00000X0=7=Z@900000103AcJT2@00000@0
dLfY0d00000Y0=7=Z@900000103AcJT2@00000@0dLfY0d00000Y0=7=Z@900000103AcJT2@00000<0
dLfY1400000X0=7=Z@900000103AcJT2@00000@0dLfY0T00000Z0=7=Z@900000103AcJT2@00000@0
dLfY0d00000M0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=
Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00603AcJTG00000240dLfY0`0000030?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`000000oooo10000000103oool000000?ooo`3ooolP0=7=ZAL0
00008@3AcJT=00000080oooo0P0000020?ooo`<0000000<0oooo0=7=Z@3AcJT07P3AcJTH00000200
dLfY5P0000000`3oool0dLfY0=7=Z@0O0=7=ZA00000000<0oooo0000000000001000000P0=7=ZAH0
000000<0oooo0=7=Z@3AcJT0603AcJT001P0dLfY5`00000Q0=7=Z@@000001`3oool01@000000oooo
000000000000oooo00@0000000<0oooo000000000000803AcJTG00000240dLfY3@0000020?ooo`80
00000P3oool400000200dLfY6000000P0=7=ZAL000008@3AcJT?00000080oooo1P00000P0=7=ZAL0
00006P3AcJT001P0dLfY5`3ooolQ0=7=Z@@000000P3oool01`000000oooo000000000000oooo0000
003oool00P0000020?ooo`040000003oool0oooo0?ooo`800000803AcJT;0?ooo`030000003oool0
oooo00T0oooo8@3AcJT=00000080oooo0P0000020?ooo`040000003oool0000000000200dLfY603o
oolP0=7=Z@<000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P00
000Q0=7=Z@h0oooo0P0000070?ooob00dLfY500000000`3oool000000000000J0=7=Z@00603AcJTG
0?ooob40dLfY1@0000050?ooo`8000000P3oool00`000000oooo000000030?ooo`<00000803AcJT;
0?ooo`030000003oool0oooo00T0oooo8@3AcJT=00000080oooo0P0000030?ooo`<00000803AcJTH
0?ooob00dLfY100000001@3oool00000000000000000oooo00X0000000@0oooo0000000000000000
8@3AcJT>0?ooo`8000001`3ooolP0=7=ZA<0000000@0oooo00000000000000006P3AcJT001P0dLfY
5`3ooolQ0=7=Z@D000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`00
00001000000P0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@d000000P3oool200000003
0?ooo`000000000000<00000803AcJT?0?ooo`030000003oool0oooo00H0oooo803AcJT700000080
oooo1P0000020?ooo`H000008@3AcJT=0?ooo`800000203ooolP0=7=ZAL000006P3AcJT001P0dLfY
5`00000Q0=7=Z@P0000000D0oooo0000003oool000000?ooo`04000000030?ooo`000000000000<0
0000803AcJTG00000240dLfY3@0000020?ooo`80000000<0oooo0000000000000`00000P0=7=ZAP0
0000803AcJTA000000030?ooo`000000000000<000008@3AcJT=00000080oooo2000000P0=7=ZA40
000000<0oooo0000000000000`00000J0=7=Z@00603AcJTG00000240dLfY1`0000001@3oool00000
0?ooo`000000oooo00/00000803AcJTG00000240dLfY3@0000020?ooo`P00000803AcJT>00000003
0?ooo`000000000000L00000803AcJTG00000240dLfY3@0000000`3oool000000000000700000200
dLfY5`00000J0=7=Z@00603AcJTG0?ooob40dLfY2@0000040?ooo`80000000<0oooo000000000000
1@00000P0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@d000000`3oool700000200dLfY
603ooolP0=7=Z@P0000000D0oooo00000000000000000?ooo`02000000030?ooo`000000000000D0
00008@3AcJT<0?ooo`8000002@3ooolP0=7=Z@l0000000<0oooo0000000000001@00000J0=7=Z@00
603AcJTG0?ooob40dLfY2@0000040?ooo`X00000803AcJT;0?ooo`030000003oool0oooo00T0oooo
8@3AcJT=000000030?ooo`000000000000L00000803AcJT=0?ooo`030000003oool0oooo00P0oooo
803AcJTG00000240dLfY2`3oool2000000X0oooo803AcJTG000001X0dLfY000H0=7=ZAL0oooo8@3A
cJT:000000<0oooo2P00000P0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=ZAL00000803A
cJTH0?ooob00dLfY300000000`3oool000000000000800000240dLfY2`3oool00`000000oooo0?oo
o`090?ooob00dLfY5`00000J0=7=Z@00603AcJTG00000240dLfY2`0000000`3oool0000000000009
00000200dLfY5`00000Q0=7=ZAL00000803AcJT<000000030?ooo`000000000000T00000803AcJTG
00000240dLfY2`0000000`3oool000000000000900000200dLfY5`00000J0=7=Z@00o`3AcJW?0=7=
Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00703AcJT4@000
0080dLfY140000040=7=Z@=000009P3AcJT4@0000080dLfY140000030=7=Z@900000:@3AcJT4@000
0080dLfY140000020=7=Z@=00000:03AcJT4@0000080dLfY140000040=7=Z@03@000003AcJT0dLfY
02L0dLfY140000020=7=Z@A000000`3AcJT2@00002T0dLfY140000020=7=Z@A000000P3AcJT3@000
02P0dLfY140000030=7=Z@900000103AcJT2@00002T0dLfY140000030=7=Z@9000000`3AcJT5@000
01`0dLfY000L0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT01P3AcJT00d000000
dLfY0=7=Z@0U0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT014000000
dLfY0=7=ZD00000X0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT01400
0000dLfY0=7=ZD00000W0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT01@3AcJT0
0d000000dLfY0=7=Z@0W0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT0
14000000dLfY0=7=ZD00000X0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT01@3A
cJT00d000000dLfY0=7=Z@0V0=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU00000
0P3AcJT014000000dLfY0=7=ZD00000X0=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3A
cJU00000103AcJT00d000000dLfY0=7=Z@0L0=7=Z@007@3AcJT00d000000dLfY0=7=Z@030=7=Z@03
@000003AcJT0dLfY0080dLfY1D00000W0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3A
cJT01@3AcJT00d000000dLfY0=7=Z@0W0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3A
cJT00P3AcJT014000000dLfY0=7=ZD00000X0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=
Z@3AcJT0103AcJT00d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=
Z@3AcJT00P3AcJT014000000dLfY0=7=ZD00000Y0=7=Z@03@000003AcJT0dLfY00<0dLfY00=00000
0=7=Z@3AcJT00`3AcJT3@00002P0dLfY00=000000=7=Z@3AcJT0103AcJT01D000000dLfY0=7=Z@3A
cJU000000080dLfY00=000000=7=Z@3AcJT09`3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003A
cJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0703AcJT001h0dLfY00=000000=7=Z@3AcJT00`3AcJT0
1D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT09`3AcJT00d000000dLfY0=7=
Z@030=7=Z@03@000003AcJT0dLfY0080dLfY0T00000[0=7=Z@03@000003AcJT0dLfY00<0dLfY00A0
00000=7=Z@3AcJT0dLfY0d00000Z0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0
103AcJT00d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0
0P3AcJT2@00002/0dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00=000000=7=Z@3AcJT09`3AcJT00d000000dLfY0=7=Z@040=7=Z@04@000003AcJT0dLfY@000
0080dLfY00=000000=7=Z@3AcJT0:03AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY
0080dLfY00=000000=7=Z@3AcJT0703AcJT001`0dLfY00A000000=7=Z@3AcJU000000P3AcJT01400
0000dLfY0=7=ZD0000030=7=Z@03@000003AcJU0000002L0dLfY00A000000=7=Z@3AcJU000000P3A
cJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY02P0dLfY00A000000=7=Z@3AcJU0
00000P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY02L0dLfY00A000000=7=
Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00002P0dLfY
00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@00002P0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000
003AcJT0dLfY@00002L0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD000002
0=7=Z@04@000003AcJT0dLfY@00002P0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD0000040=7=Z@03@000003AcJT0dLfY01`0dLfY000M0=7=Z@900000103AcJT2@00000D0dLfY
0T00000X0=7=Z@900000103AcJT2@00000@0dLfY0d00000Y0=7=Z@900000103AcJT2@00000@0dLfY
0d00000X0=7=Z@900000103AcJT2@00000<0dLfY1400000Y0=7=Z@900000103AcJT2@00000@0dLfY
0T00000Z0=7=Z@900000103AcJT2@00000@0dLfY0d00000X0=7=Z@900000103AcJT2@00000@0dLfY
0T00000Z0=7=Z@900000103AcJT2@00000@0dLfY0T00000N0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?
0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00603AcJTG00000240dLfY00<0
oooo0000000000005000000P0=7=Z@/0000000<0oooo0000000000002@00000Q0=7=Z@/0000000<0
oooo0000000000002@00000P0=7=ZA40000000<0oooo0000000000001000000P0=7=Z@030?ooo`00
0000000001@000008@3AcJT;000000030?ooo`000000000000T00000803AcJTG000001X0dLfY000H
0=7=ZA00oooo00<000000?ooo`3oool0103ooolQ0=7=Z@030000003oool0000001@00000803AcJT;
0?ooo`030000003oool0oooo00T0oooo8@3AcJT;000000030?ooo`000000000000T00000803AcJTH
0?ooob00dLfY00<000000?ooo`0000005000000Q0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP
0=7=ZAL000006P3AcJT001P0dLfY5`3ooolQ0=7=Z@80000000<0oooo0000000000004P00000P0=7=
Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0000000<0oooo0000000000002@00000P0=7=
ZA00oooo00<000000?ooo`3oool01@3ooolP0=7=Z@80000000<0oooo0000000000004P00000Q0=7=
Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=ZAL000006P3AcJT001P0dLfY3`0000000`3oool0
00000000000500000240dLfY0`0000000`3oool000000000000A00000200dLfY2`0000000`3oool0
00000000000900000240dLfY2`0000000`3oool000000000000900000200dLfY6000000P0=7=Z@<0
000000<0oooo0000000000004@00000Q0=7=Z@/0000000<0oooo0000000000002@00000P0=7=ZAL0
00006P3AcJT001P0dLfY5`3ooolQ0=7=Z@@0000000<0oooo0000000000004000000P0=7=Z@/0oooo
00<000000?ooo`3oool02@3ooolQ0=7=Z@/0000000<0oooo0000000000002@00000P0=7=Z@l0oooo
00<000000?ooo`3oool01P3ooolP0=7=ZAL000008@3AcJT;0?ooo`030000003oool0oooo00T0oooo
803AcJTG000001X0dLfY000H0=7=Z@h0oooo00<000000?ooo`3oool01P3ooolQ0=7=Z@D0000000<0
oooo0000000000003`00000P0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0000000<0
oooo0000000000002@00000P0=7=ZAP0oooo803AcJT5000000030?ooo`000000000000l000008@3A
cJT;0?ooo`030000003oool0oooo00T0oooo803AcJTG000001X0dLfY000H0=7=ZAL000008@3AcJTG
00000200dLfY2`0000000`3oool000000000000900000240dLfY2`0000000`3oool0000000000009
00000200dLfY3P0000000`3oool000000000000700000200dLfY5`00000Q0=7=Z@/0000000<0oooo
0000000000002@00000P0=7=ZAL000006P3AcJT001P0dLfY5`3ooolQ0=7=Z@L0000000<0oooo0000
000000003@00000P0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0000000<0oooo0000
000000002@00000P0=7=ZAP0oooo803AcJTG00000240dLfY2`3oool00`000000oooo0?ooo`090?oo
ob00dLfY5`00000J0=7=Z@00603AcJTG0?ooob40dLfY200000000`3oool000000000000<00000200
dLfY2`3oool00`000000oooo0?ooo`090?ooob40dLfY2`0000000`3oool000000000000900000200
dLfY3@3oool00`000000oooo0?ooo`080?ooob00dLfY5`00000Q0=7=Z@/0oooo00<000000?ooo`3o
ool02@3ooolP0=7=ZAL000006P3AcJT001P0dLfY300000000`3oool000000000000800000240dLfY
5`00000P0=7=Z@/0000000<0oooo0000000000002@00000Q0=7=Z@/0000000<0oooo000000000000
2@00000P0=7=ZAP00000803AcJTG00000240dLfY2`0000000`3oool000000000000900000200dLfY
5`00000J0=7=Z@00603AcJTG0?ooob40dLfY5`00000P0=7=Z@/0oooo00<000000?ooo`3oool02@3o
oolQ0=7=Z@/0000000<0oooo0000000000002@00000P0=7=Z@`0oooo00<000000?ooo`3oool02@3o
oolP0=7=ZAL000008@3AcJT;0?ooo`030000003oool0oooo00T0oooo803AcJTG000001X0dLfY000H
0=7=ZAL0oooo8@3AcJT;000000030?ooo`000000000000T00000803AcJTG0?ooob40dLfY2`000000
0`3oool000000000000900000200dLfY603ooolP0=7=ZAL000008@3AcJT;0?ooo`030000003oool0
oooo00T0oooo803AcJTG000001X0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY
003o0=7=ZLl0dLfY000L0=7=Z@A000000P3AcJT5@00000040=7=ZD0000100000@00002P0dLfY1400
00020=7=Z@E000000`3AcJT00d000000dLfY0=7=Z@0W0=7=Z@A000000P3AcJT5@0000080dLfY0T00
000X0=7=Z@A000000P3AcJT5@00000040=7=ZD0000100000@00002T0dLfY140000020=7=Z@A00000
0`3AcJT2@00002T0dLfY140000020=7=Z@A000000P3AcJT5@00002H0dLfY140000020=7=Z@A00000
0P3AcJT4@00002P0dLfY140000020=7=Z@A000000`3AcJT2@00001h0dLfY000L0=7=Z@03@000003A
cJT0dLfY00D0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY02D0dLfY
00=000000=7=Z@3AcJT01@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY02L0dLfY
00=000000=7=Z@3AcJT01@3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3A
cJT09@3AcJT00d000000dLfY0=7=Z@050=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3A
cJT09`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3A
cJU00000:03AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00D0dLfY00=000000=7=
Z@3AcJT09P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=
Z@3AcJT0:@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=
Z@3AcJU000007@3AcJT001d0dLfY00=000000=7=Z@3AcJT0103AcJT01D000000dLfY0=7=Z@3AcJU0
00000080dLfY00=000000=7=Z@3AcJT09P3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0
dLfY00<0dLfY00=000000=7=Z@3AcJT0:03AcJT00d000000dLfY0=7=Z@040=7=Z@05@000003AcJT0
dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0V0=7=Z@03@000003AcJT0dLfY00@0dLfY00=0
00000=7=Z@3AcJT00P3AcJT3@00002T0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=
Z@020=7=Z@04@000003AcJT0dLfY@00002T0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY
0=7=Z@040=7=Z@03@000003AcJT0dLfY02L0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY
0=7=Z@030=7=Z@03@000003AcJT0dLfY02T0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY
0=7=Z@040=7=Z@03@000003AcJT0dLfY01`0dLfY000N0=7=Z@03@000003AcJT0dLfY00<0dLfY00A0
00000=7=Z@3AcJT0dLfY0d00000Z0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0
103AcJT00d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0
0P3AcJT2@00002X0dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00=000000=7=Z@3AcJT0:03AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=
ZD0000000P3AcJT00d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=
Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=
Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0Y0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=
Z@3AcJT0103AcJT00d000000dLfY0=7=Z@0K0=7=Z@00703AcJT014000000dLfY0=7=ZD0000040=7=
Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT09`3AcJT014000000dLfY0=7=ZD000004
0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0V0=7=Z@04@000003A
cJT0dLfY@00000@0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY02D0
dLfY00A000000=7=Z@3AcJU00000103AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=00000
0=7=Z@3AcJT09P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY
00A000000=7=Z@3AcJU00000:03AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@00000@0dLfY00=000000=7=Z@3AcJT09P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003A
cJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000:03AcJT014000000dLfY0=7=ZD0000020=7=
Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000007@3AcJT001d0dLfY0T000004
0=7=Z@900000103AcJT3@00002P0dLfY0T0000040=7=Z@9000000`3AcJT4@00002T0dLfY0T000004
0=7=Z@900000103AcJT2@00002T0dLfY0T0000040=7=Z@900000103AcJT3@00002T0dLfY0T000004
0=7=Z@900000103AcJT2@00002X0dLfY0T0000040=7=Z@900000103AcJT2@00002T0dLfY0T000004
0=7=Z@900000103AcJT2@00002X0dLfY0T0000040=7=Z@900000103AcJT2@00001h0dLfY003o0=7=
ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=
ZLl0dLfY000H0=7=ZAH0000000<0oooo0=7=Z@3AcJT07`3AcJT00`3oool000000000000D00000200
dLfY1P0000001P3oool000000?ooo`3oool000000?ooo`8000000P3oool2000000<0oooo00<00000
0?ooo`3AcJT0803AcJT;000000030?ooo`000000000000T000008@3AcJTF000000030?ooo`3AcJT0
dLfY01h0dLfY00<0oooo0000000000005000000Q0=7=ZAH0000000<0oooo0=7=Z@3AcJT07P3AcJTG
000001X0dLfY000H0=7=ZAL000008@3AcJTG00000200dLfY1P0000020?ooo`030000003oool00000
0080000000<0oooo000000000000100000000`3oool000000000000Q0=7=Z@/0000000<0oooo0000
000000002@00000Q0=7=ZAL00000803AcJTG00000240dLfY5`00000P0=7=ZAL000006P3AcJT001P0
dLfY503oool00`000000oooo0?ooo`0Q0=7=Z@80000000<0oooo0000000000004P00000P0=7=Z@L0
oooo00H000000?ooo`000000oooo0000003oool3000000050?ooo`000000oooo0?ooo`0000000P3o
oolQ0=7=Z@/0000000<0oooo0000000000002@00000Q0=7=ZA@0oooo00<000000?ooo`3oool0803A
cJT2000000030?ooo`0000000000018000008@3AcJTD0?ooo`030000003oool0oooo0200dLfY5`00
000J0=7=Z@00603AcJTC0?ooo`040000003oool0oooo0?ooob40dLfY5`00000P0=7=Z@L0oooo0`00
00000`3oool000000?ooo`020?ooo`030000003oool0oooo008000000`3ooolQ0=7=Z@/0000000<0
oooo0000000000002@00000Q0=7=ZA<0oooo00@000000?ooo`3oool0oooo803AcJTG00000240dLfY
403oool010000000oooo0?ooo`0000030?ooob00dLfY5`00000J0=7=Z@00603AcJTG0?ooob40dLfY
5`00000P0=7=Z@P0oooo0`0000020?ooo`040000003oool00000000000H0oooo8@3AcJT;00000003
0?ooo`000000000000T000008@3AcJTG0?ooob00dLfY5`00000Q0=7=Z@l0oooo00<000000?ooo`3o
ool01@3ooolP0=7=ZAL000006P3AcJT001P0dLfY4@0000000`3oool000000000000300000240dLfY
5`00000P0=7=Z@P000000P3oool00`000000oooo00000002000000030?ooo`000000oooo00D00000
8@3AcJT;000000030?ooo`000000000000T000008@3AcJTA000000030?ooo`000000000000<00000
803AcJTG00000240dLfY3P000000103oool000000000003oool500000200dLfY5`00000J0=7=Z@00
603AcJTG00000240dLfY5`00000P0=7=Z@T0000000@0oooo0000003oool000000P3oool800000240
dLfY2`0000000`3oool000000000000900000240dLfY5`00000P0=7=ZAL000008@3AcJT=00000003
0?ooo`000000000000L00000803AcJTG000001X0dLfY000H0=7=Z@l0oooo00<000000?ooo`3oool0
1@3ooolQ0=7=ZAL00000803AcJT90?ooo`070000003oool000000?ooo`000000oooo000000070?oo
ob40dLfY2`0000000`3oool000000000000900000240dLfY3`3oool00`000000oooo0?ooo`050?oo
ob00dLfY5`00000Q0=7=Z@h0oooo0P0000070?ooob00dLfY5`00000J0=7=Z@00603AcJTG0?ooob40
dLfY5`00000P0=7=Z@X0oooo0P0000000`3oool000000?ooo`080?ooob40dLfY2`0000000`3oool0
00000000000900000240dLfY5`3ooolP0=7=ZAL000008@3AcJT=0?ooo`030000003oool0oooo00L0
oooo803AcJTG000001X0dLfY000H0=7=ZAL0oooo8@3AcJTG00000200dLfY2P3oool00`000000oooo
0000000:0?ooob40dLfY2`0000000`3oool000000000000900000240dLfY5`3ooolP0=7=ZAL00000
8@3AcJT;0?ooo`030000003oool0oooo00T0oooo803AcJTG000001X0dLfY000H0=7=ZAL000008@3A
cJTG00000200dLfY2`0000000`3oool000000000000900000240dLfY2`0000000`3oool000000000
000900000240dLfY5`00000P0=7=ZAL000008@3AcJTG00000200dLfY5`00000J0=7=Z@00o`3AcJW?
0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00703AcJT4
@00000<0dLfY0T0000040=7=Z@900000:03AcJT4@00000<0dLfY0T0000030=7=Z@=00000:@3AcJT4
@0000080dLfY1D0000020=7=Z@900000:03AcJT4@0000080dLfY1D0000000`3AcJU00000@0000003
@00002L0dLfY140000020=7=Z@E0000000<0dLfY@000040000000T00000X0=7=Z@A000000P3AcJT5
@0000080dLfY0T00000X0=7=Z@A000000P3AcJT5@00000<0dLfY0d00000W0=7=Z@A000000P3AcJT5
@0000080dLfY0T00000N0=7=Z@00703AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY
@0000080dLfY00A000000=7=Z@3AcJU000009`3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003A
cJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT09`3AcJT00d000000dLfY0=7=Z@050=7=Z@05@000
003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0U0=7=Z@03@000003AcJT0dLfY00D0
dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0W0=7=Z@03@000003AcJT0dLfY00D0
dLfY00E000000=7=Z@3AcJT0dLfY@000000[0=7=Z@03@000003AcJT0dLfY00D0dLfY00E000000=7=
Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY02D0dLfY00=000000=7=Z@3AcJT01@3AcJT0
0d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY02H0dLfY00=000000=7=Z@3AcJT01@3AcJT0
1D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT06`3AcJT001d0dLfY00=00000
0=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00002P0dLfY
00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000030=7=Z@=00000:@3AcJT00d000000
dLfY0=7=Z@040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0V0=7=
Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0X0=7=
Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0Y0=7=
Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0W0=7=
Z@03@000003AcJT0dLfY00@0dLfY00A000000=7=Z@3AcJT0dLfY1D00000X0=7=Z@03@000003AcJT0
dLfY00@0dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@0K0=7=Z@007P3AcJT01D00
0000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJT0dLfY0T00000Z0=7=Z@05@000003A
cJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02P0
dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=
Z@3AcJT09`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=
Z@3AcJT0:@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=
Z@3AcJT0:@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=
Z@3AcJT09`3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT0
0d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT2
@00001h0dLfY000L0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3A
cJT014000000dLfY0=7=ZD00000W0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3A
cJU000000P3AcJT014000000dLfY0=7=ZD00000X0=7=Z@04@000003AcJT0dLfY@00000@0dLfY00E0
00000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY02D0dLfY00A000000=7=Z@3AcJU0
0000103AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY02L0dLfY00A000000=7=Z@3A
cJU00000103AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT09P3AcJT0
14000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY
0=7=Z@0U0=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000
dLfY@000000X0=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT00P3AcJT00d00
0000dLfY0=7=Z@0M0=7=Z@007@3AcJT2@00000@0dLfY0T0000040=7=Z@900000:@3AcJT2@00000@0
dLfY0T0000040=7=Z@=00000:@3AcJT2@00000@0dLfY0T0000040=7=Z@900000:@3AcJT2@00000@0
dLfY0T0000040=7=Z@900000:P3AcJT2@00000@0dLfY0T0000040=7=Z@900000:P3AcJT2@00000@0
dLfY0T0000040=7=Z@900000:@3AcJT2@00000@0dLfY0T0000050=7=Z@900000:@3AcJT2@00000@0
dLfY0T0000040=7=Z@=000007@3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT0
0?l0dLfYc`3AcJT00?l0dLfYc`3AcJT001P0dLfY5`00000Q0=7=Z@030?ooo`000000000000@00000
0P3oool600000080oooo1P00000P0=7=ZAL000008@3AcJTG00000240dLfY2`0000000`3oool00000
0000000900000200dLfY00<0oooo0000000000000P3oool200000080oooo0P0000020?ooo`800000
0P3oool2000000<0oooo00<000000=7=Z@3AcJT07`3AcJTG00000200dLfY5`00000J0=7=Z@00603A
cJTG0?ooob40dLfY00<000000?ooo`3oool00P0000060?ooo`8000001P3oool400000200dLfY5`3o
oolQ0=7=ZAL000008@3AcJT;0?ooo`030000003oool0oooo00T0oooo803AcJT00`000000oooo0?oo
o`0200000080oooo0P0000020?ooo`8000000P3oool200000080oooo1000000Q0=7=Z@H0oooo00<0
00000?ooo`3oool03P3ooolP0=7=ZAL000006P3AcJT001P0dLfY5`3ooolQ0=7=Z@80000000<0oooo
0000000000001P3oool2000000H0oooo1000000P0=7=ZAL0oooo8@3AcJTG00000240dLfY2`3oool0
0`000000oooo0?ooo`090?ooob00dLfY0P0000000`3oool00000000000020?ooo`8000000P3oool2
00000080oooo0P0000020?ooo`@000008@3AcJTG0?ooob00dLfY5`00000J0=7=Z@00603AcJTG0000
0240dLfY0`0000020?ooo`H000000P3oool6000000040?ooo`000000000000000200dLfY1`000000
0`3oool000000000000=00000240dLfY4`000000103oool0000000000000000Q0=7=Z@/0000000<0
oooo0000000000002@00000P0=7=Z@<000000P3oool200000080oooo0P0000020?ooo`8000000P3o
ool2000000040?ooo`000000000000000240dLfY1`0000000`3oool000000000000=00000200dLfY
4`000000103oool0000000000000000J0=7=Z@00603AcJTG0?ooob40dLfY100000030?ooo`800000
1P3oool200000080oooo1000000P0=7=ZAL0oooo8@3AcJTB000000030?ooo`000000000000800000
8@3AcJT;0?ooo`030000003oool0oooo00T0oooo803AcJT500000080oooo0P0000020?ooo`800000
0P3oool200000080oooo1000000Q0=7=ZAL0oooo803AcJTB000000030?ooo`000000000000800000
6P3AcJT001P0dLfY5`3ooolQ0=7=Z@D000000P3oool2000000H0oooo0P0000000`3oool000000000
000300000200dLfY5`3ooolQ0=7=ZA40000000<0oooo0000000000000`00000Q0=7=Z@/0oooo00<0
00000?ooo`3oool02@3ooolP0=7=Z@D000000P3oool200000080oooo0P0000020?ooo`80000000<0
oooo0000000000000`00000Q0=7=Z@P0oooo00<000000?ooo`3oool0303ooolP0=7=ZA40000000<0
oooo0000000000000`00000J0=7=Z@00603AcJTG00000240dLfY1`0000020?ooo`H000000P3oool6
00000200dLfY5`00000Q0=7=ZA00000000<0oooo0000000000001000000Q0=7=Z@/0000000<0oooo
0000000000002@00000P0=7=Z@L000000P3oool200000080oooo0P0000020?ooo`H000008@3AcJTG
00000200dLfY400000000`3oool0000000000004000001X0dLfY000H0=7=ZAL0oooo8@3AcJT70000
00@0oooo0P0000030?ooo`L00000803AcJTG0?ooob40dLfY3`0000000`3oool00000000000050000
0240dLfY2`3oool00`000000oooo0?ooo`090?ooob00dLfY2@0000020?ooo`8000000P3oool80000
0240dLfY2@3oool00`000000oooo0?ooo`0;0?ooob00dLfY5`00000J0=7=Z@00603AcJTG0?ooob40
dLfY200000030?ooo`8000000P3oool800000200dLfY5`3ooolQ0=7=Z@h0000000<0oooo00000000
00001P00000Q0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=Z@T000000P3oool200000080
oooo2000000Q0=7=ZAL0oooo803AcJT>000000030?ooo`000000000000H000006P3AcJT001P0dLfY
5`00000Q0=7=Z@/000000P3oool:00000200dLfY5`00000Q0=7=ZAL000008@3AcJT;000000030?oo
o`000000000000T00000803AcJT;00000080oooo2P00000Q0=7=ZAL00000803AcJTG000001X0dLfY
000H0=7=ZAL0oooo8@3AcJT:000000<0oooo2P00000P0=7=Z@X0oooo00<000000?ooo`3oool02P3o
oolQ0=7=Z@`0000000<0oooo0000000000002000000Q0=7=Z@/0oooo00<000000?ooo`3oool02@3o
oolP0=7=Z@X0000000<0oooo0000000000002P00000Q0=7=Z@X0oooo00<000000?ooo`3oool02P3o
oolP0=7=ZAL000006P3AcJT001P0dLfY5`3ooolQ0=7=Z@/0000000<0oooo0000000000002@00000P
0=7=ZAL0oooo8@3AcJT;000000030?ooo`000000000000T000008@3AcJT;0?ooo`030000003oool0
oooo00T0oooo803AcJTG00000240dLfY2`3oool00`000000oooo0?ooo`090?ooob00dLfY5`00000J
0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00703AcJT4
@00000<0dLfY0T0000040=7=Z@900000:03AcJT4@00000<0dLfY0T0000030=7=Z@E000009`3AcJT4
@00000<0dLfY0T0000030=7=Z@A000009`3AcJT4@00000<0dLfY0T0000040=7=Z@900000:@3AcJT4
@00000<0dLfY0T0000050=7=Z@=000009`3AcJT4@00000<0dLfY0T0000040=7=Z@900000:03AcJT4
@00000<0dLfY0T0000030=7=Z@=00000:@3AcJT4@00000<0dLfY0T0000050=7=Z@03@000003AcJT0
dLfY01`0dLfY000L0=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU000000P3AcJT0
14000000dLfY0=7=ZD00000W0=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU00000
103AcJT00d000000dLfY0=7=Z@0W0=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU0
00000P3AcJT00d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3A
cJU000000P3AcJT014000000dLfY0=7=ZD00000X0=7=Z@03@000003AcJT0dLfY00<0dLfY00A00000
0=7=Z@3AcJU000001@3AcJT00d000000dLfY0=7=Z@0V0=7=Z@03@000003AcJT0dLfY00<0dLfY00A0
00000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000W0=7=Z@03@000003AcJT0dLfY00<0
dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000X0=7=Z@03@000003AcJT0
dLfY00<0dLfY00A000000=7=Z@3AcJU00000103AcJT00d000000dLfY0=7=Z@0L0=7=Z@007@3AcJT0
0d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000
:03AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3A
cJT0:03AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=
Z@3AcJT0:03AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=00000
0=7=Z@3AcJT0:03AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@0000080dLfY1D00
000X0=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU000001@3AcJT00d000000dLfY
0=7=Z@0V0=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000
dLfY0=7=ZD00000Y0=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU00000103AcJT0
0d000000dLfY0=7=Z@0L0=7=Z@007P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A00000
0=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0W0=7=Z@05@000003AcJT0dLfY0=7=ZD000000
0P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY02T0dLfY00E000000=7=Z@3AcJT0
dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0:03AcJT01D000000
dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0X0=7=
Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003A
cJT0dLfY02P0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY0=7=Z@90
0000:P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00d00000[0=7=
Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0
dLfY01/0dLfY000L0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3A
cJT014000000dLfY0=7=ZD00000W0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3A
cJU00000103AcJT00d000000dLfY0=7=Z@0W0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A00000
0=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000W0=7=Z@04@000003AcJT0dLfY@0000080
dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000X0=7=Z@04@000003AcJT0
dLfY@0000080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY@000000X0=7=Z@04@000
003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@0W0=7=
Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=
Z@0X0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000
dLfY0=7=ZD00000M0=7=Z@007@3AcJT2@00000@0dLfY0T0000040=7=Z@900000:@3AcJT2@00000@0
dLfY0T0000040=7=Z@900000:P3AcJT2@00000@0dLfY0T0000040=7=Z@900000:@3AcJT2@00000@0
dLfY0T0000040=7=Z@900000:P3AcJT2@00000@0dLfY0T0000050=7=Z@900000:@3AcJT2@00000@0
dLfY0T0000040=7=Z@=00000:03AcJT2@00000@0dLfY0T0000040=7=Z@=00000:@3AcJT2@00000@0
dLfY0T0000030=7=Z@A000007@3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT0
0?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT001P0dLfY5`00000Q0=7=Z@@0oooo0P00
00040?ooo`<000001P3oool010000000oooo0000003ooolP0=7=Z@H000000P3oool?00000240dLfY
2`0000030?ooo`H000000`3ooolQ0=7=ZAL00000803AcJT30?ooo`8000000P3oool200000080oooo
0P0000020?ooo`8000000P3oool3000000030?ooo`3AcJT0dLfY01l0dLfY200000020?ooo`800000
103oool700000200dLfY5P0000000`3oool0dLfY0=7=Z@0H0=7=Z@00603AcJT@000000030?ooo`00
0000000000@000008@3AcJT2000000@0oooo0P0000060?ooo`060000003oool000000?ooo`000000
oooo0`00000P0=7=Z@H000000P3oool?00000240dLfY2`0000000`3oool000000000000600000003
0?ooo`00000000000240dLfY400000000`3oool000000000000400000200dLfY0P0000000`3oool0
0000000000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`@000008@3AcJT600000080
oooo0`0000000`3oool00000000000030?ooo`H00000803AcJTG000001X0dLfY000H0=7=ZAL0oooo
8@3AcJT2000000@0oooo0P0000060?ooo`050000003oool000000?ooo`0000000P3oool200000200
dLfY1`3oool00`000000oooo0?ooo`0=0?ooob40dLfY2`0000000`3oool000000000000600000003
0?ooo`00000000000240dLfY5`3ooolP0=7=Z@8000000`3oool200000080oooo0P0000020?ooo`80
00000P3oool200000080oooo0P00000Q0=7=Z@P0oooo0`0000000`3oool00000000000090?ooob00
dLfY500000000`3oool000000000000J0=7=Z@00603AcJT?0?ooo`030000003oool0oooo00D0oooo
8@3AcJT4000000@0oooo0P0000020?ooo`80000000@0oooo0000003oool000000P3oool300000200
dLfY1`3oool2000000h0oooo8@3AcJT;00000080oooo1P000000103oool0000000000000000Q0=7=
Z@l0oooo00<000000?ooo`3oool01@3ooolP0=7=Z@@0000000<0oooo0000000000000P3oool20000
0080oooo0P0000020?ooo`80000000@0oooo00000000000000008@3AcJT70?ooo`<00000103oool2
000000L0oooo803AcJTC000000040?ooo`0000000000000001X0dLfY000H0=7=ZAL0oooo8@3AcJT6
000000@0oooo0`0000050?ooo`D00000803AcJT80?ooo`030000003oool0oooo00`0oooo8@3AcJT;
000000030?ooo`000000000000T000008@3AcJTG0?ooob00dLfY1`0000020?ooo`8000000P3oool2
00000080oooo1P00000Q0=7=Z@X0oooo0P00000;0?ooob00dLfY5`00000J0=7=Z@00603AcJT>0000
00030?ooo`000000000000H000008@3AcJT6000000@0oooo0`0000050?ooo`D00000803AcJT80000
0080oooo3@00000Q0=7=Z@/000000P3oool4000000030?ooo`000000000000<000008@3AcJT>0000
00030?ooo`000000000000H00000803AcJT6000000030?ooo`00000000000080oooo0P0000020?oo
o`80000000<0oooo0000000000000`00000Q0=7=Z@P000000P3oool2000000<0oooo2000000P0=7=
ZA40000000<0oooo0000000000000`00000J0=7=Z@00603AcJTG00000240dLfY200000060?ooo`03
0000003oool0000000H00000803AcJT900000080oooo3000000Q0=7=Z@/0000000<0oooo00000000
00002@00000Q0=7=ZAL00000803AcJT900000080oooo0P0000020?ooo`P000008@3AcJT;00000003
0?ooo`000000000000T00000803AcJTG000001X0dLfY000H0=7=Z@d0oooo00<000000?ooo`3oool0
1`3ooolQ0=7=Z@P000001P3oool00`000000oooo0000000600000200dLfY2@3oool2000000`0oooo
8@3AcJT;00000080oooo0P0000000`3oool000000000000500000240dLfY3@3oool00`000000oooo
0?ooo`070?ooob00dLfY200000000`3oool00000000000020?ooo`80000000<0oooo000000000000
1@00000Q0=7=Z@T0oooo0P0000000`3oool00000000000090?ooob00dLfY3`0000000`3oool00000
00000005000001X0dLfY000H0=7=ZAL0oooo8@3AcJT:00000080oooo2`00000P0=7=Z@X0oooo00<0
00000?ooo`3oool02P3ooolQ0=7=Z@/0000000<0oooo0000000000002@00000Q0=7=ZAL0oooo803A
cJT;00000080oooo2P00000Q0=7=ZAL0oooo803AcJTG000001X0dLfY000H0=7=ZAL0oooo8@3AcJTG
00000200dLfY2P3oool2000000/0oooo8@3AcJT;00000080oooo2P00000Q0=7=ZAL0oooo803AcJT;
00000080oooo2P00000Q0=7=Z@X0oooo0P00000;0?ooob00dLfY300000000`3oool0000000000008
000001X0dLfY000H0=7=ZAL000008@3AcJTG00000200dLfY2`0000000`3oool00000000000090000
0240dLfY2`0000000`3oool000000000000900000240dLfY5`00000P0=7=ZAL000008@3AcJTG0000
0200dLfY5`00000J0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?
0=7=Z@00o`3AcJW?0=7=Z@00703AcJT5@00000040=7=ZD0000100000@00000<0dLfY1400000W0=7=
Z@E0000000@0dLfY@000040000100000103AcJT2@00002T0dLfY1D000000103AcJU00000@0000400
00050=7=Z@=000009P3AcJT5@00000040=7=ZD0000100000@00000@0dLfY0T00000Y0=7=Z@E00000
00@0dLfY@0000400001000000`3AcJT3@00002T0dLfY1D000000103AcJU00000@000040000050=7=
Z@03@000003AcJT0dLfY02H0dLfY1D000000103AcJU00000@000040000040=7=Z@900000:@3AcJT5
@00000040=7=ZD0000100000@00000<0dLfY0d00000N0=7=Z@007P3AcJT00d000000dLfY0=7=Z@03
0=7=Z@05@000003AcJT0dLfY0=7=ZD000000;03AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003A
cJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY00<0dLfY
00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@0W0=7=Z@03@000003AcJT0dLfY00<0dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY02P0dLfY00=000000=7=Z@3A
cJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0:03AcJT00d00
0000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0:03AcJT00d00
0000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0X
0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0L
0=7=Z@007P3AcJT00d000000dLfY0=7=Z@020=7=Z@=000000`3AcJT00d000000dLfY0=7=Z@0Y0=7=
Z@03@000003AcJT0dLfY0080dLfY0d0000040=7=Z@03@000003AcJT0dLfY02T0dLfY00=000000=7=
Z@3AcJT00P3AcJT3@0000080dLfY1D00000X0=7=Z@03@000003AcJT0dLfY0080dLfY0d0000050=7=
Z@03@000003AcJT0dLfY02P0dLfY00=000000=7=Z@3AcJT00P3AcJT3@0000080dLfY00A000000=7=
Z@3AcJU00000:P3AcJT00d000000dLfY0=7=Z@020=7=Z@=00000103AcJT00d000000dLfY0=7=Z@0X
0=7=Z@03@000003AcJT0dLfY0080dLfY0d0000020=7=Z@04@000003AcJT0dLfY@00002X0dLfY00=0
00000=7=Z@3AcJT00P3AcJT3@00000<0dLfY0d00000M0=7=Z@007P3AcJT01D000000dLfY0=7=Z@3A
cJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0X0=7=Z@05@000003A
cJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY02P0dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=
Z@3AcJT09`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJT0dLfY0T00
000[0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@03@00002/0dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3A
cJT09`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJT0dLfY0T00000[
0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000
003AcJT0dLfY01/0dLfY000N0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02L0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=
Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0:03AcJT01D000000dLfY0=7=Z@3A
cJU000000080dLfY00M000000=7=Z@3AcJT0dLfY@000003AcJU0000002T0dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@05@000003AcJT0dLfY0=7=ZD000000;03AcJT01D000000dLfY0=7=Z@3A
cJU000000080dLfY00E000000=7=Z@3AcJT0dLfY@000000/0=7=Z@05@000003AcJT0dLfY0=7=ZD00
00000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02L0dLfY00E000000=7=
Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0:03A
cJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000
dLfY0=7=Z@0K0=7=Z@007@3AcJT2@00000@0dLfY0d0000030=7=Z@900000:@3AcJT2@00000@0dLfY
0d0000030=7=Z@900000:P3AcJT2@00000@0dLfY0d0000040=7=Z@900000:03AcJT2@00000@0dLfY
0d0000030=7=Z@=00000:@3AcJT2@00000@0dLfY0d0000030=7=Z@=00000:@3AcJT2@00000@0dLfY
0d0000020=7=Z@A00000:03AcJT2@00000@0dLfY0d0000030=7=Z@900000:P3AcJT2@00000@0dLfY
0d0000030=7=Z@=000007@3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0
dLfYc`3AcJT00?l0dLfYc`3AcJT001P0dLfY5`00000Q0=7=Z@030000003oool0oooo008000000P3o
ool200000080oooo3000000P0=7=Z@030000003oool0oooo008000000P3oool200000080oooo3000
000Q0=7=ZAL000008@3AcJT6000000030?ooo`000000000000h00000803AcJTG00000240dLfY00<0
00000?ooo`0000005000000P0=7=ZAL000006P3AcJT001P0dLfY2`3oool00`000000oooo0?ooo`09
0?ooob40dLfY00<000000?ooo`3oool00P0000020?ooo`8000000P3oool<00000200dLfY0`3oool2
00000080oooo0P0000020?ooo`030000003oool0oooo00T0oooo8@3AcJTG00000240dLfY1P3oool0
0`000000oooo0?ooo`0>0?ooob00dLfY5`00000Q0=7=Z@030?ooo`000000oooo01@0oooo803AcJTG
000001X0dLfY000H0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@80000000<0oooo0000
000000000P3oool200000080oooo3000000P0=7=Z@<0oooo0P0000020?ooo`8000000P3oool00`00
0000oooo0?ooo`090?ooob40dLfY5`00000Q0=7=Z@L0oooo00<000000?ooo`3oool03@3ooolP0=7=
ZAL000008@3AcJT20?ooo`8000004`3ooolP0=7=ZAL000006P3AcJT001P0dLfY5`00000Q0=7=Z@D0
00000P3oool200000080oooo3000000P0=7=Z@D000000P3oool200000080oooo3000000Q0=7=ZAL0
00008@3AcJTG00000200dLfY5`00000Q0=7=ZAL00000803AcJTG000001X0dLfY000H0=7=Z@/0oooo
00<000000?ooo`3oool02@3ooolQ0=7=Z@D000000P3oool200000080oooo3000000P0=7=Z@@0oooo
00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo00T0oooo8@3AcJTG00000240dLfY
203oool00`000000oooo0?ooo`0<0?ooob00dLfY5`00000Q0=7=Z@@0oooo00<000000?ooo`3oool0
403ooolP0=7=ZAL000006P3AcJT001P0dLfY2`3oool00`000000oooo0?ooo`090?ooob40dLfY1@00
00020?ooo`8000000P3oool<00000200dLfY1`3oool200000080oooo00<000000?ooo`3oool02@3o
oolQ0=7=ZAL000008@3AcJT80?ooo`030000003oool0oooo00`0oooo803AcJTG00000240dLfY1@3o
ool00`000000oooo0?ooo`0?0?ooob00dLfY5`00000J0=7=Z@00603AcJTG00000240dLfY1P000000
0`3oool00000000000020?ooo``00000803AcJT6000000030?ooo`00000000000080oooo3000000Q
0=7=ZAL000008@3AcJT800000080oooo3@00000P0=7=ZAL000008@3AcJT6000000030?ooo`000000
000000h00000803AcJTG000001X0dLfY000H0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=
Z@T000000P3oool<00000200dLfY1`3oool200000080oooo00<000000?ooo`3oool02@3ooolQ0=7=
ZAL000008@3AcJT90?ooo`800000303ooolP0=7=ZAL000008@3AcJT70?ooo`8000003P3ooolP0=7=
ZAL000006P3AcJT001P0dLfY2`3oool00`000000oooo0?ooo`090?ooob40dLfY2@0000020?ooo``0
0000803AcJT80?ooo`040000003oool0oooo000000/0oooo8@3AcJTG00000240dLfY2P3oool00`00
0000oooo0?ooo`0:0?ooob00dLfY5`00000Q0=7=Z@P0oooo00<000000?ooo`3oool0303ooolP0=7=
ZAL000006P3AcJT001P0dLfY5`00000Q0=7=Z@T000000P3oool<00000200dLfY2@0000020?ooo``0
00008@3AcJTG00000240dLfY2P0000000`3oool000000000000:00000200dLfY5`00000Q0=7=Z@T0
000000<0oooo0000000000002`00000P0=7=ZAL000006P3AcJT001P0dLfY2`3oool00`000000oooo
0?ooo`090?ooob40dLfY2P0000000`3oool000000000000:00000200dLfY2`3oool00`000000oooo
0?ooo`090?ooob40dLfY5`00000Q0=7=Z@X0oooo0P00000;0?ooob00dLfY5`00000Q0=7=Z@X0oooo
0P00000;0?ooob00dLfY5`00000J0=7=Z@00603AcJT;0?ooo`030000003oool0oooo00T0oooo8@3A
cJTG00000200dLfY2`3oool00`000000oooo0?ooo`090?ooob40dLfY5`00000Q0=7=Z@/0oooo00<0
00000?ooo`3oool02@3ooolP0=7=ZAL000008@3AcJT;0?ooo`030000003oool0oooo00T0oooo803A
cJTG000001X0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY
000L0=7=Z@E000000P3AcJT2@00000D0dLfY0d00000V0=7=Z@E000000P3AcJT2@00000@0dLfY0T00
000Y0=7=Z@E000000P3AcJT2@00000<0dLfY0d00000X0=7=Z@E000000P3AcJT2@00000D0dLfY00=0
00000=7=Z@3AcJT09`3AcJT5@0000080dLfY0T0000040=7=Z@900000:@3AcJT5@0000080dLfY0T00
00030=7=Z@=00000:03AcJT5@00000040=7=ZD0000100000@00000@0dLfY0T00000Y0=7=Z@E00000
00@0dLfY@0000400001000000`3AcJT5@00001`0dLfY000N0=7=Z@05@000003AcJT0dLfY0=7=ZD00
00000P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY02L0dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0:03AcJT0
1D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY
0=7=Z@0W0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03
@000003AcJT0dLfY02T0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00=000000=7=Z@3AcJT0:03AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=0
00000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY00<0dLfY00E0
00000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY02P0dLfY00=000000=7=Z@3AcJT0
0`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY01`0dLfY000N0=7=Z@05@000003A
cJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@05@00002P0dLfY00E000000=7=Z@3AcJT0
dLfY@00000020=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0:03AcJT01D000000
dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0W
0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003A
cJT0dLfY02T0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080
dLfY00=000000=7=Z@3AcJT0:03AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=
Z@3AcJT0dLfY0d00000Y0=7=Z@03@000003AcJT0dLfY0080dLfY0d0000020=7=Z@04@000003AcJT0
dLfY@00002X0dLfY00=000000=7=Z@3AcJT00P3AcJT3@00000@0dLfY00=000000=7=Z@3AcJT0703A
cJT001h0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000<0dLfY00A000000=7=Z@3AcJU00000:@3A
cJT00d000000dLfY0=7=Z@020=7=Z@900000103AcJT2@00002/0dLfY00=000000=7=Z@3AcJT00P3A
cJT2@00000<0dLfY0d00000Z0=7=Z@03@000003AcJT0dLfY0080dLfY0T0000060=7=Z@03@000003A
cJT0dLfY02P0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000@0dLfY0T00000[0=7=Z@03@000003A
cJT0dLfY0080dLfY0T0000030=7=Z@04@000003AcJT0dLfY@00002T0dLfY00E000000=7=Z@3AcJT0
dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0:03AcJT01D00
0000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0L
0=7=Z@007P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00M000000=7=Z@3AcJT0dLfY@000
003AcJU0000002T0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@05@000003AcJT0dLfY0=7=
ZD000000;03AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00E000000=7=Z@3AcJT0dLfY@000
000[0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03
@000003AcJT0dLfY02P0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00=000000=7=Z@3AcJT0:03AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A0
00000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0W0=7=Z@05@000003AcJT0dLfY0=7=ZD00
00000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02P0dLfY00E000000=7=
Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0703AcJT0
01d0dLfY0T0000040=7=Z@9000001@3AcJT2@00002P0dLfY0T0000040=7=Z@900000103AcJT3@000
02T0dLfY0T0000040=7=Z@900000103AcJT3@00002P0dLfY0T0000040=7=Z@9000000`3AcJT4@000
02T0dLfY0T0000040=7=Z@900000103AcJT2@00002X0dLfY0T0000040=7=Z@900000103AcJT3@000
02P0dLfY0T0000040=7=Z@=000000`3AcJT2@00002X0dLfY0T0000040=7=Z@=000000`3AcJT2@000
01h0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=
ZLl0dLfY003o0=7=ZLl0dLfY000H0=7=Z@d000000P3oool200000080oooo0`0000000`3oool0dLfY
0=7=Z@0O0=7=Z@<0oooo0P0000020?ooo`8000000P3oool<00000200dLfY00<000000?ooo`3oool0
0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`<0000000<0oooo0=7=Z@3AcJT0
7`3AcJTG00000240dLfY1P0000000`3oool000000?ooo`0300000080oooo00<000000?ooo`3oool0
1@0000000`3oool0dLfY0=7=Z@0N0=7=ZAL000008@3AcJT010000000oooo0?ooo`0000020?ooo`<0
000000@0oooo0000003oool000000P3oool200000080oooo0P0000020?ooob00dLfY5`00000J0=7=
Z@00603AcJT=00000080oooo0P0000020?ooo`@000008@3AcJT00`000000oooo0?ooo`0200000080
oooo0P0000020?ooo``00000803AcJT00`000000oooo0?ooo`0200000080oooo0P0000020?ooo`80
00000P3oool200000080oooo1000000Q0=7=ZAL000008@3AcJT7000000030?ooo`000000oooo0080
oooo0`000000103oool000000000000000020?ooo`800000803AcJT00`000000oooo0000000D0000
0240dLfY00<000000?ooo`3oool00P0000020?ooo`8000000P3oool2000000050?ooo`0000000000
0000003oool00P0000000`3oool000000000000P0=7=ZAL000006P3AcJT001P0dLfY2`3oool20000
0080oooo0P0000020?ooo`8000000P3ooolQ0=7=Z@80000000<0oooo0000000000000P3oool20000
0080oooo3000000P0=7=Z@<0oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?oo
o`8000000P3ooolQ0=7=ZAL000008@3AcJT90?ooo`80000000<0oooo0000003oool00P0000001@3o
ool000000000003oool000000080oooo803AcJTG00000240dLfY0P3oool300000080oooo0P000002
0?ooo`80000000D0oooo00000000000000000?ooo`0300000080oooo803AcJTG000001X0dLfY000H
0=7=Z@/0oooo0P0000020?ooo`8000000P3oool010000000oooo0?ooo`3ooolQ0=7=Z@<0000000@0
oooo0000003oool0oooo0P0000020?ooo``00000803AcJT30?ooo`8000000P3oool200000080oooo
0P0000020?ooo`8000000P3oool010000000oooo0?ooo`3ooolQ0=7=ZAL000008@3AcJT70?ooo`D0
000000D0oooo00000000000000000?ooo`03000000<0oooo803AcJT3000000030?ooo`0000000000
014000008@3AcJT30?ooo`<0000000T0oooo00000000000000000?ooo`000000oooo0000003oool0
0`0000000`3oool000000?ooo`020?ooob00dLfY5`00000J0=7=Z@00603AcJT;0?ooo`8000000P3o
ool2000000H0oooo8@3AcJT4000000<0oooo0P0000020?ooo``00000803AcJT40?ooo`030000003o
ool0oooo008000000P3oool200000080oooo0P0000060?ooob40dLfY5`00000Q0=7=Z@T0oooo0P00
00000`3oool0000000000003000000H0oooo803AcJT4000000030?ooo`0000000000010000008@3A
cJT40?ooo`030000003oool000000080000000@0oooo0000003oool000000P3oool2000000H0oooo
803AcJTG000001X0dLfY000H0=7=Z@d000000P3oool2000000030?ooo`000000000000<000008@3A
cJT500000080oooo0P0000020?ooo``00000803AcJT500000080oooo0P0000020?ooo`8000000P3o
ool2000000030?ooo`000000000000<000008@3AcJTG00000240dLfY2P0000020?ooo`040000003o
ool0000000000080oooo1@00000P0=7=Z@D0000000<0oooo0000000000003`00000Q0=7=Z@D00000
00P0oooo00000000000000000?ooo`000000oooo00000080oooo0P0000000`3oool0000000000003
00000200dLfY5`00000J0=7=Z@00603AcJT=00000080oooo2000000Q0=7=Z@H0000000<0oooo0000
000000000P3oool<00000200dLfY1P0000000`3oool00000000000020?ooo`8000000P3oool80000
0240dLfY5`00000Q0=7=Z@T0000000<0oooo0000003oool00`3oool800000200dLfY1P0000000`3o
ool000000000000>00000240dLfY1P0000000`3oool00000000000020?ooo`80000000<0oooo0000
000000001`00000P0=7=ZAL000006P3AcJT001P0dLfY2`3oool200000080oooo00<000000?ooo`3o
ool01@3ooolQ0=7=Z@L0000000@0oooo0000003oool0oooo3000000P0=7=Z@L0oooo0P0000020?oo
o`8000000P3oool00`000000oooo0?ooo`050?ooob40dLfY5`00000Q0=7=Z@T0oooo00<000000?oo
o`3oool0100000070?ooob00dLfY1`0000000`3oool000000000000=00000240dLfY1`3oool20000
0080oooo0P0000000`3oool00000000000070?ooob00dLfY5`00000J0=7=Z@00603AcJT;0?ooo`80
00002P3ooolQ0=7=Z@P000000`3oool<00000200dLfY203oool00`000000oooo0?ooo`02000000X0
oooo8@3AcJTG00000240dLfY2P3oool010000000oooo0?ooo`0000090?ooob00dLfY200000000`3o
ool000000000000<00000240dLfY203oool2000000040?ooo`000000oooo000000T0oooo803AcJTG
000001X0dLfY000H0=7=Z@/0oooo0P00000:0?ooob40dLfY2P0000000`3oool000000000000:0000
0200dLfY2`3oool2000000X0oooo8@3AcJTG00000240dLfY2P3oool2000000/0oooo803AcJTG0000
0240dLfY2P3oool00`000000oooo0000000:0?ooob00dLfY5`00000J0=7=Z@00603AcJTG00000240
dLfY2P0000000`3oool000000000000:00000200dLfY2P0000000`3oool000000000000:00000240
dLfY5`00000Q0=7=Z@/0000000<0oooo0000000000002@00000P0=7=Z@X0000000<0oooo00000000
00002P00000Q0=7=Z@X000000P3oool;00000200dLfY5`00000J0=7=Z@00o`3AcJW?0=7=Z@00o`3A
cJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00703AcJT5@00000<0dLfY00A000000=7=Z@3A
cJT0dLfY0d00000X0=7=Z@E000000`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY
02L0dLfY1D0000030=7=Z@03@000003AcJT0dLfY0080dLfY0T00000X0=7=Z@E000000`3AcJT01400
0000dLfY0=7=Z@3AcJT3@00002T0dLfY1D0000020=7=Z@900000103AcJT2@00002T0dLfY1D000002
0=7=Z@9000000`3AcJT5@00002H0dLfY1D0000020=7=Z@9000000`3AcJT4@00002P0dLfY1D000002
0=7=Z@900000103AcJT2@00001h0dLfY000N0=7=Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=
Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY02L0dLfY00=000000=7=Z@3AcJT00`3AcJT0
0d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY02T0dLfY00=000000=7=Z@3AcJT00`3AcJT0
1D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT09`3AcJT00d000000dLfY0=7=
Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0:@3AcJT01D000000dLfY0=7=
Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0X0=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY
02P0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@00002d0dLfY00E0
00000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3A
cJT06`3AcJT001h0dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00=000000=7=Z@3AcJT09`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0
dLfY00=000000=7=Z@3AcJT0:@3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=
ZD0000000P3AcJT00d000000dLfY0=7=Z@0W0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=
Z@3AcJT00P3AcJT3@00002X0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0
dLfY@0000080dLfY00=000000=7=Z@3AcJT0:03AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY
00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0X0=7=Z@05@000003AcJT0dLfY0=7=ZD00
00000P3AcJT01D000000dLfY0=7=Z@3AcJU0000002`0dLfY00E000000=7=Z@3AcJT0dLfY@0000002
0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0703AcJT001h0dLfY00=000000=7=
Z@3AcJT0103AcJT00d000000dLfY0=7=Z@03@00002X0dLfY00=000000=7=Z@3AcJT0103AcJT00d00
0000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY02P0dLfY00=000000=7=Z@3AcJT0103AcJT01400
0000dLfY0=7=Z@3AcJT2@00002X0dLfY00=000000=7=Z@3AcJT0103AcJT014000000dLfY0=7=ZD00
00020=7=Z@03@000003AcJT0dLfY02P0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000<0dLfY00A0
00000=7=Z@3AcJU00000:P3AcJT00d000000dLfY0=7=Z@020=7=Z@9000001@3AcJT00d000000dLfY
0=7=Z@0X0=7=Z@03@000003AcJT0dLfY0080dLfY0T0000050=7=Z@03@000003AcJT0dLfY02T0dLfY
00=000000=7=Z@3AcJT00P3AcJT2@00000H0dLfY00=000000=7=Z@3AcJT06`3AcJT001h0dLfY00E0
00000=7=Z@3AcJT0dLfY@00000020=7=Z@05@000003AcJT0dLfY0=7=ZD000000:`3AcJT01D000000
dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0X
0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000
003AcJT0dLfY02L0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@000
0080dLfY00=000000=7=Z@3AcJT0:03AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A00000
0=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0X0=7=Z@05@000003AcJT0dLfY0=7=ZD000000
0P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY02P0dLfY00E000000=7=Z@3AcJT0
dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0:03AcJT01D00
0000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=
Z@0K0=7=Z@007@3AcJT2@00000<0dLfY140000030=7=Z@=00000:03AcJT2@00000<0dLfY14000002
0=7=Z@A00000:@3AcJT2@00000<0dLfY140000030=7=Z@900000:@3AcJT2@00000<0dLfY14000003
0=7=Z@=00000:@3AcJT2@00000@0dLfY0T0000040=7=Z@900000:P3AcJT2@00000@0dLfY0T000004
0=7=Z@900000:@3AcJT2@00000@0dLfY0T0000040=7=Z@900000:P3AcJT2@00000@0dLfY0T000004
0=7=Z@9000007P3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3A
cJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT001P0dLfY5`00000Q0=7=Z@8000000P3oool200000003
0?ooo`000000000000@000001`3oool00`000000oooo0000000P0=7=ZAL000008@3AcJTE00000003
0?ooo`000000dLfY0200dLfY5`00000P0=7=Z@030000003oool0oooo00l0000000<0oooo00000000
00000P00000Q0=7=Z@030?ooo`000000000001@00000803AcJTG000001X0dLfY000H0=7=ZAL00000
8@3AcJT01@000000oooo0?ooo`000000oooo008000000P3oool4000000050?ooo`000000oooo0000
003oool00P0000000`3oool000000000000P0=7=Z@030000003oool0000001@000008@3AcJTD0000
00030?ooo`00000000000240dLfY5`00000P0=7=Z@030000003oool0oooo01@000008@3AcJT00`00
0000oooo0000000D00000200dLfY5`00000J0=7=Z@00603AcJTG0?ooob40dLfY0P0000030?ooo`03
0000003oool0oooo0080000000@0oooo0000003oool000001@3oool400000200dLfY5`3ooolQ0=7=
ZAL000008@3AcJTG0?ooob00dLfY0`0000020?ooo`8000000P3oool200000080oooo0P0000020?oo
o`80000000@0oooo00000000000000008@3AcJT20?ooo`030000003oool0oooo0180oooo803AcJTG
000001X0dLfY000H0=7=ZAL0oooo8@3AcJT3000000030?ooo`000000oooo00D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0400000200dLfY0`3oool00`000000oooo0?ooo`0A0?oo
ob40dLfY4P0000000`3oool000000000000200000240dLfY1`3oool00`000000oooo0?ooo`0=0?oo
ob00dLfY0`0000020?ooo`<0000000D0oooo00000000000000000?ooo`0:00000240dLfY0`3oool0
0`000000oooo0?ooo`0A0?ooob00dLfY5`00000J0=7=Z@00603AcJTG0?ooob40dLfY100000040?oo
o`030000003oool000000080000000<0oooo0000000000000P3oool500000200dLfY103oool00`00
0000oooo0?ooo`0@0?ooob40dLfY4@0000000`3oool000000000000300000240dLfY5`3ooolP0=7=
Z@@0000000<0oooo0000000000000P3oool600000080oooo1P00000Q0=7=Z@@0oooo00<000000?oo
o`3oool0403ooolP0=7=ZAL000006P3AcJT001P0dLfY5`00000Q0=7=Z@D000000P3oool02P000000
oooo0000003oool000000?ooo`000000oooo0000003oool600000200dLfY1@0000000`3oool00000
0000000?00000240dLfY400000000`3oool000000000000400000240dLfY5`00000P0=7=Z@D00000
00<0oooo0000000000001P0000000`3oool000000000000600000240dLfY1@0000000`3oool00000
0000000?00000200dLfY5`00000J0=7=Z@00603AcJTG00000240dLfY1P000000103oool000000?oo
o`0000020?ooo`040000003oool0oooo0?ooo`L00000803AcJT6000000030?ooo`000000000000h0
00008@3AcJT?000000030?ooo`000000000000D000008@3AcJTG00000200dLfY1P0000000`3oool0
00000000000>00000240dLfY1P0000000`3oool000000000000>00000200dLfY5`00000J0=7=Z@00
603AcJTG0?ooob40dLfY1`0000020?ooo`800000103oool800000200dLfY1`3oool00`000000oooo
0?ooo`0=0?ooob40dLfY3P0000000`3oool000000000000600000240dLfY2@3oool00`000000oooo
0?ooo`0;0?ooob00dLfY1`0000000`3oool0000000000002000000030?ooo`000000000000P00000
8@3AcJT70?ooo`030000003oool0oooo00d0oooo803AcJTG000001X0dLfY000H0=7=ZAL0oooo8@3A
cJT8000000030?ooo`000000000000<0oooo2@00000P0=7=Z@P0oooo00<000000?ooo`3oool0303o
oolQ0=7=Z@d0000000<0oooo0000000000001`00000Q0=7=ZAL0oooo803AcJT8000000030?ooo`00
0000000000`000008@3AcJT80?ooo`030000003oool0oooo00`0oooo803AcJTG000001X0dLfY000H
0=7=ZAL0oooo8@3AcJT;00000080oooo2P00000P0=7=ZAL0oooo8@3AcJT<000000030?ooo`000000
000000P000008@3AcJT:0?ooo`030000003oool0oooo00X0oooo803AcJT<000000030?ooo`000000
000000P000008@3AcJTG0?ooob00dLfY300000000`3oool0000000000008000001X0dLfY000H0=7=
ZAL000008@3AcJT:00000080oooo2`00000P0=7=Z@X0000000<0oooo0000000000002P00000Q0=7=
Z@/0000000<0oooo0000000000002@00000Q0=7=ZAL00000803AcJT:000000030?ooo`0000000000
00X000008@3AcJT:000000030?ooo`000000000000X00000803AcJTG000001X0dLfY003o0=7=ZLl0
dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY000L0=7=Z@E0
000000@0dLfY@000040000100000103AcJT2@00002P0dLfY1D000000103AcJU00000@00004000003
0=7=Z@=00000:@3AcJT5@00000<0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00002P0dLfY1D000003
0=7=Z@04@000003AcJT0dLfY0=7=Z@E000009`3AcJT5@00000<0dLfY00A000000=7=Z@3AcJT0dLfY
1400000X0=7=Z@E000000`3AcJT00d000000dLfY0=7=Z@020=7=Z@900000:03AcJT5@00000<0dLfY
00=000000=7=Z@3AcJT00`3AcJT3@00002L0dLfY1D0000030=7=Z@03@000003AcJT0dLfY0080dLfY
0T00000N0=7=Z@007P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU0
00000P3AcJT00d000000dLfY0=7=Z@0W0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d00
0000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY02T0dLfY00=000000=7=Z@3AcJT00`3AcJT01D00
0000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT09`3AcJT00d000000dLfY0=7=Z@03
0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0:@3AcJT00d000000dLfY0=7=Z@03
0=7=Z@05@000003AcJT0dLfY0=7=ZD000000;@3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003A
cJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0W0=7=Z@03@000003AcJT0dLfY00<0dLfY
00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY00<0dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY01/0dLfY000N0=7=Z@05@000
003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY
02L0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY0=7=Z@=00000:P3A
cJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY
0=7=Z@0W0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY
0=7=Z@0Y0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY
0=7=Z@0Z0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY
0=7=Z@0X0=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJT0dLfY1D00000Y0=7=Z@03
@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@0K0=7=Z@00
7P3AcJT014000000dLfY0=7=Z@3AcJT3@00000@0dLfY0T00000Z0=7=Z@04@000003AcJT0dLfY0=7=
Z@=000000`3AcJT014000000dLfY0=7=ZD00000Z0=7=Z@03@000003AcJT0dLfY00@0dLfY00A00000
0=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0W0=7=Z@03@000003AcJT0dLfY00@0dLfY00=0
00000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0Y0=7=Z@03@000003AcJT0dLfY00@0dLfY00=0
00000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0Y0=7=Z@03@000003AcJT0dLfY00@0dLfY00=0
00000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0W0=7=Z@03@000003AcJT0dLfY00@0dLfY00A0
00000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY00@0dLfY
00A000000=7=Z@3AcJT0dLfY0T00000N0=7=Z@007P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000
003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU00000:@3AcJT00d000000dLfY0=7=Z@020=7=Z@03
@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU00000:P3AcJT01D000000dLfY0=7=Z@3AcJU0
00000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0W0=7=Z@05@000003A
cJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY02T0dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=
Z@3AcJT0:03AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3A
cJT00d000000dLfY0=7=Z@0W0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT01d000000dLfY
0=7=Z@3AcJU000000=7=ZD000000:P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00E00000
0=7=Z@3AcJT0dLfY@000000O0=7=Z@007@3AcJT2@00000@0dLfY0d0000030=7=Z@900000:@3AcJT2
@00000@0dLfY0d0000030=7=Z@=00000:@3AcJT2@00000<0dLfY140000030=7=Z@900000:@3AcJT2
@00000<0dLfY140000030=7=Z@900000:P3AcJT2@00000<0dLfY140000030=7=Z@900000:P3AcJT2
@00000<0dLfY140000030=7=Z@900000:@3AcJT2@00000<0dLfY140000040=7=Z@900000:@3AcJT2
@00000<0dLfY140000030=7=Z@=000007@3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfY
c`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT001P0dLfY5`00000Q0=7=Z@<0
oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`<0000000<0oooo0=7=Z@3A
cJT07P3AcJT00`000000oooo0?ooo`0200000080oooo0P0000020?ooo``000008@3AcJT=00000080
oooo0P0000020?ooo`<0000000<0oooo0=7=Z@3AcJT07`3AcJT;000000030?ooo`000000000000T0
0000803AcJT00`000000oooo0?ooo`0?000000050?ooo`00000000000000003oool08@3AcJT30?oo
o`@0000000H0oooo0000003oool0oooo0000003oool3000000030?ooo`000000000000@00000803A
cJTF000000030?ooo`3AcJT0dLfY01P0dLfY000H0=7=ZAL000008@3AcJT00`000000oooo0?ooo`02
00000080oooo0P0000020?ooo`8000000P3oool200000080oooo1000000P0=7=Z@030000003oool0
oooo008000000P3oool200000080oooo3000000Q0=7=Z@d000000P3oool200000080oooo1000000Q
0=7=Z@/0000000<0oooo0000000000002@00000P0=7=Z@030000003oool0oooo01@000008@3AcJT0
10000000oooo0000003oool200000080oooo0`0000060?ooo`H00000803AcJTG000001X0dLfY000H
0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@80000000<0oooo0000000000000P3oool2
00000080oooo0P0000020?ooo`8000000P3oool010000000oooo00000000000P0=7=Z@<0oooo0P00
00020?ooo`8000000P3oool00`000000oooo0?ooo`090?ooob40dLfY3@0000020?ooo`8000000P3o
ool010000000oooo00000000000Q0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=ZA@00000
00<0oooo0000000000008@3AcJT50?ooo`@0000000<0oooo0000003oool00`0000080?ooob00dLfY
500000000`3oool000000000000J0=7=Z@00603AcJT;0?ooo`030000003oool0oooo00T0oooo8@3A
cJT3000000040?ooo`000000oooo0?ooo`8000000P3oool200000080oooo0P0000030?ooo`<00000
803AcJT30?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@d00000
0P3oool2000000<0oooo0`00000Q0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=Z@<00000
00<0oooo0000000000001P0000000`3oool0000000000004000000040?ooo`000000000000000240
dLfY0`3oool3000000050?ooo`00000000000000003oool01@0000070?ooob00dLfY4`000000103o
ool0000000000000000J0=7=Z@00603AcJT;0?ooo`030000003oool0oooo00T0oooo8@3AcJT40000
00<0oooo0P0000020?ooo`8000000P3oool2000000030?ooo`000000000000<00000803AcJT40?oo
o`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`090?ooob40dLfY3@0000020?oo
o`80000000<0oooo0000000000000`00000Q0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=
Z@@0000000<0oooo0000000000004000000Q0=7=Z@@0oooo00D000000?ooo`3oool000000?ooo`02
00000080oooo0P0000080?ooob00dLfY5`00000J0=7=Z@00603AcJTG00000240dLfY1@0000020?oo
o`8000000P3oool200000080oooo0P0000000`3oool000000000000300000200dLfY1@0000020?oo
o`8000000P3oool<00000240dLfY3@0000020?ooo`80000000<0oooo0000000000000`00000Q0=7=
Z@/0000000<0oooo0000000000002@00000P0=7=Z@D0000000<0oooo0000000000001P000000103o
ool000000000003oool500000240dLfY1@0000001`3oool00000000000000000oooo0000003oool0
0P0000000`3oool000000000000600000200dLfY4@0000000`3oool0000000000003000001X0dLfY
000H0=7=ZAL000008@3AcJT6000000030?ooo`00000000000080oooo0P0000020?ooo`P00000803A
cJT6000000030?ooo`00000000000080oooo3000000Q0=7=Z@d000000P3oool800000240dLfY2`00
00000`3oool000000000000900000200dLfY1P0000000`3oool000000000000>00000240dLfY1P00
00000`3oool000000?ooo`030?ooo`030000003oool0000000P00000803AcJTG000001X0dLfY000H
0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@L0000000@0oooo0000003oool0oooo0P00
00030?ooo`L00000803AcJT70?ooo`8000000P3oool00`000000oooo0?ooo`090?ooob40dLfY3@00
00030?ooo`L000008@3AcJT;0?ooo`030000003oool0oooo00T0oooo803AcJT700000080oooo1P00
00000`3oool000000000000500000240dLfY1`3oool00`000000oooo000000020?ooo`8000002@3o
oolP0=7=Z@l0000000<0oooo0000000000001@00000J0=7=Z@00603AcJT;0?ooo`030000003oool0
oooo00T0oooo8@3AcJT8000000<0oooo0P0000000`3oool000000000000700000200dLfY203oool0
10000000oooo0?ooo`00000;0?ooob40dLfY3@0000000`3oool000000000000700000240dLfY2`3o
ool00`000000oooo0?ooo`090?ooob00dLfY200000000`3oool000000000000<00000240dLfY203o
ool200000080oooo00<000000?ooo`3oool0203ooolP0=7=ZAL000006P3AcJT001P0dLfY2`3oool0
0`000000oooo0?ooo`090?ooob40dLfY2P0000000`3oool000000000000:00000200dLfY2`3oool0
0`000000oooo0?ooo`090?ooob40dLfY5`00000Q0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP
0=7=ZAL000008@3AcJT:0?ooo`8000002`3ooolP0=7=ZAL000006P3AcJT001P0dLfY5`00000Q0=7=
Z@X0000000<0oooo0000000000002P00000P0=7=Z@X0000000<0oooo0000000000002P00000Q0=7=
ZAL000008@3AcJT;000000030?ooo`000000000000T00000803AcJT:000000030?ooo`0000000000
00X000008@3AcJT:00000080oooo2`00000P0=7=ZAL000006P3AcJT00?l0dLfYc`3AcJT00?l0dLfY
c`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT001`0dLfY1D000000103AcJU00000@00004000004
0=7=Z@900000:03AcJT5@00000040=7=ZD0000100000@00000<0dLfY1D00000W0=7=Z@E0000000@0
dLfY@0000400001000000`3AcJT4@00002L0dLfY1D000000103AcJU00000@000040000040=7=Z@90
0000:@3AcJT5@00000040=7=ZD0000100000@00000D0dLfY0d00000W0=7=Z@E0000000@0dLfY@000
040000100000103AcJT2@00002P0dLfY1D000000103AcJU00000@000040000030=7=Z@=00000:@3A
cJT5@00000040=7=ZD0000100000@00000D0dLfY00=000000=7=Z@3AcJT0703AcJT001h0dLfY00E0
00000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3A
cJT09`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d00
0000dLfY0=7=Z@0Y0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD00
000/0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03
@000003AcJT0dLfY02P0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY
00<0dLfY00=000000=7=Z@3AcJT0:03AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A00000
0=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0W0=7=Z@05@000003AcJT0dLfY0=7=ZD000000
0P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02P0dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0703AcJT001h0
dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=00000
0=7=Z@3AcJT09`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3A
cJT00d000000dLfY0=7=Z@0Y0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT01D000000dLfY
0=7=Z@3AcJU0000002/0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY
0080dLfY00=000000=7=Z@3AcJT0:@3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=00000
0=7=Z@3AcJT01D00000Y0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=
Z@030=7=Z@03@000003AcJT0dLfY02L0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000
003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0:03AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0L0=7=Z@007P3AcJT014000000
dLfY0=7=Z@3AcJT3@00000<0dLfY00A000000=7=Z@3AcJU00000:@3AcJT014000000dLfY0=7=Z@3A
cJT3@00000D0dLfY00=000000=7=Z@3AcJT0:@3AcJT014000000dLfY0=7=Z@3AcJT3@00000D0dLfY
00=000000=7=Z@3AcJT0:03AcJT014000000dLfY0=7=Z@3AcJT3@00000H0dLfY00=000000=7=Z@3A
cJT0:03AcJT014000000dLfY0=7=Z@3AcJT3@00000<0dLfY00A000000=7=Z@3AcJU00000:P3AcJT0
14000000dLfY0=7=Z@3AcJT3@00000@0dLfY0T00000Z0=7=Z@04@000003AcJT0dLfY0=7=Z@=00000
0`3AcJT3@00002/0dLfY00A000000=7=Z@3AcJT0dLfY0d0000060=7=Z@03@000003AcJT0dLfY01/0
dLfY000N0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY
0=7=ZD00000Y0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0103AcJT00d000000
dLfY0=7=Z@0Y0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT014000000
dLfY0=7=ZD00000Y0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT01400
0000dLfY0=7=ZD00000Z0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00`3AcJT0
0d000000dLfY@000000Z0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00`3AcJT0
0d000000dLfY0=7=Z@0Y0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00`3AcJT0
0d000000dLfY0=7=Z@0Z0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT0
14000000dLfY0=7=ZD00000M0=7=Z@007@3AcJT2@00000@0dLfY0d0000030=7=Z@900000:@3AcJT2
@00000@0dLfY0d0000030=7=Z@900000:P3AcJT2@00000@0dLfY0d0000030=7=Z@900000:@3AcJT2
@00000@0dLfY0d0000030=7=Z@900000:P3AcJT2@00000@0dLfY0d0000040=7=Z@900000:@3AcJT2
@00000@0dLfY0d0000030=7=Z@=00000:03AcJT2@00000@0dLfY0d0000030=7=Z@=00000:@3AcJT2
@00000@0dLfY0d0000020=7=Z@A000007@3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfY
c`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT001P0dLfY3`0000020?ooo`H0
00008@3AcJT20?ooo`L000000`3oool;00000200dLfY0P0000020?ooo`<0000000@0oooo00000000
00000000103oool00`000000oooo0000000500000240dLfY2`0000000`3oool00000000000090000
0240dLfY1P0000040?ooo`8000000P3oool900000200dLfY5`00000Q0=7=Z@80000000<0oooo0000
000000004P00000P0=7=ZAL000006P3AcJT001P0dLfY3`0000000`3oool000000000000500000240
dLfY00<000000?ooo`0000001`0000020?ooo`/00000803AcJT01@000000oooo0?ooo`000000oooo
00<000000P3oool3000000<0oooo1`00000Q0=7=Z@/0000000<0oooo0000000000002@00000Q0=7=
Z@H000000P3oool200000080oooo0P0000020?ooo`L00000803AcJT00`000000oooo0000000D0000
0240dLfY00<000000?ooo`0000005000000P0=7=ZAL000006P3AcJT001P0dLfY3`3oool00`000000
oooo0?ooo`050?ooob40dLfY2`0000000`3oool000000000000900000200dLfY1@3oool300000005
0?ooo`000000oooo0000003oool00`0000070?ooob40dLfY2`0000000`3oool00000000000090000
0240dLfY203oool200000080oooo0P0000090?ooob00dLfY5`00000Q0=7=Z@80oooo00<000000?oo
o`0000004P3ooolP0=7=ZAL000006P3AcJT001P0dLfY3P3oool2000000L0oooo8@3AcJT300000080
oooo1P0000000`3oool000000000000900000200dLfY0`3oool01@000000oooo0?ooo`3oool00000
0080oooo1P0000070?ooob40dLfY2`0000000`3oool000000000000900000240dLfY1`3oool00`00
0000oooo0?ooo`020?ooo`@000001`3ooolP0=7=Z@<0000000<0oooo0000000000004@00000Q0=7=
Z@<0oooo00<000000?ooo`3oool04@3ooolP0=7=ZAL000006P3AcJT001P0dLfY5`3ooolQ0=7=Z@@0
000000<0oooo000000000000100000000`3oool000000000000900000200dLfY103oool00`000000
oooo0?ooo`03000000<0oooo00<000000?ooo`3oool01`3ooolQ0=7=Z@/0000000<0oooo00000000
00002@00000Q0=7=Z@X0oooo0P0000020?ooo`030000003oool0oooo00H0oooo803AcJT400000003
0?ooo`0000000000010000008@3AcJT40?ooo`040000003oool0oooo000000l0oooo803AcJTG0000
01X0dLfY000H0=7=Z@d0000000<0oooo0000000000001`00000Q0=7=Z@D000000P3oool400000003
0?ooo`000000000000T00000803AcJT5000000<0oooo0`0000000`3oool000000?ooo`0900000240
dLfY2`0000000`3oool000000000000900000240dLfY200000020?ooo`8000000P3oool900000200
dLfY1@0000000`3oool000000000000?00000240dLfY1@0000000`3oool000000000000?00000200
dLfY5`00000J0=7=Z@00603AcJT=000000030?ooo`000000000000L000008@3AcJT6000000030?oo
o`00000000000080000000<0oooo0000000000002@00000P0=7=Z@H0000000<0oooo000000000000
1@3oool900000240dLfY2`0000000`3oool000000000000900000240dLfY2P0000020?ooo`/00000
803AcJT6000000030?ooo`000000000000h000008@3AcJT6000000040?ooo`00000000000?ooo`d0
0000803AcJTG000001X0dLfY000H0=7=Z@`0oooo0P0000090?ooob40dLfY1`0000020?ooo`800000
00<0oooo0000000000002@00000P0=7=Z@L0oooo0`000000103oool000000?ooo`0000090?ooob40
dLfY2`0000000`3oool000000000000900000240dLfY2@3oool00`000000oooo0?ooo`02000000T0
oooo803AcJT7000000030?ooo`000000000000d000008@3AcJT70?ooo`80000000<0oooo0000003o
ool02`3ooolP0=7=ZAL000006P3AcJT001P0dLfY5`3ooolQ0=7=Z@P0000000@0oooo000000000000
oooo2`00000P0=7=Z@P0oooo0P0000000`3oool000000?ooo`0:0?ooob40dLfY2`0000000`3oool0
00000000000900000240dLfY303oool00`000000oooo0?ooo`080?ooob00dLfY200000000`3oool0
00000000000<00000240dLfY203oool2000000d0oooo803AcJTG000001X0dLfY000H0=7=Z@/0oooo
00<000000?ooo`3oool02@3ooolQ0=7=Z@/0000000<0oooo0000000000002@00000P0=7=ZAL0oooo
8@3AcJT;000000030?ooo`000000000000T000008@3AcJT:0?ooo`8000002`3ooolP0=7=ZAL00000
8@3AcJT:0?ooo`8000002`3ooolP0=7=ZAL000006P3AcJT001P0dLfY2`0000000`3oool000000000
000900000240dLfY2P0000020?ooo`/00000803AcJT:00000080oooo2`00000Q0=7=Z@/0000000<0
oooo0000000000002@00000Q0=7=ZAL00000803AcJT:000000030?ooo`000000000000X000008@3A
cJT:000000030?ooo`000000000000X00000803AcJTG000001X0dLfY003o0=7=ZLl0dLfY003o0=7=
ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY000L0=7=Z@E000000P3AcJT2
@00000<0dLfY1400000W0=7=Z@E000000P3AcJT2@00000@0dLfY0T00000Y0=7=Z@E000000P3AcJT2
@00000D0dLfY0d00000V0=7=Z@E000000P3AcJT2@00000@0dLfY0T00000Y0=7=Z@E000000P3AcJT2
@00000<0dLfY0d00000Y0=7=Z@E000000P3AcJT2@00000D0dLfY00=000000=7=Z@3AcJT09P3AcJT5
@0000080dLfY0T0000040=7=Z@900000:@3AcJT5@0000080dLfY0T0000030=7=Z@=000007P3AcJT0
01h0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@00002`0dLfY00E0
00000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3A
cJT0:03AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00`3AcJT00d00
0000dLfY0=7=Z@0W0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD00
00020=7=Z@03@000003AcJT0dLfY02P0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000
003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0:03AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0X0=7=Z@05@000003AcJT0dLfY
0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02P0dLfY00E0
00000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0
703AcJT001h0dLfY00=000000=7=Z@3AcJT0103AcJT01D000000dLfY0=7=Z@3AcJU0000002/0dLfY
00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY02T0dLfY
00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@05@00002P0dLfY00=000000=7=Z@3AcJT0
103AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY02P0dLfY00=000000=7=Z@3AcJT0
103AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02P0dLfY00=000000=7=Z@3A
cJT0103AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY02P0dLfY00=000000=7=Z@3A
cJT0103AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02P0dLfY00=000000=7=
Z@3AcJT0103AcJT014000000dLfY0=7=Z@3AcJT3@00001d0dLfY000N0=7=Z@03@000003AcJT0dLfY
0080dLfY0T0000050=7=Z@03@000003AcJT0dLfY02P0dLfY00=000000=7=Z@3AcJT00P3AcJT2@000
00H0dLfY00=000000=7=Z@3AcJT0:03AcJT00d000000dLfY0=7=Z@020=7=Z@9000000`3AcJT01400
0000dLfY0=7=ZD00000Y0=7=Z@03@000003AcJT0dLfY0080dLfY0T0000040=7=Z@900000:`3AcJT0
0d000000dLfY0=7=Z@020=7=Z@9000000`3AcJT3@00002/0dLfY00=000000=7=Z@3AcJT00P3AcJT2
@00000H0dLfY00=000000=7=Z@3AcJT09`3AcJT00d000000dLfY0=7=Z@020=7=Z@900000103AcJT2
@00002/0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000<0dLfY00A000000=7=Z@3AcJU000007@3A
cJT001h0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0
dLfY@00002T0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003A
cJT0dLfY@00002X0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000
003AcJU0000002T0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000
003AcJT0dLfY02X0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000
003AcJT0dLfY02X0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000
003AcJT0dLfY@00002T0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@04
@000003AcJT0dLfY@00002X0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=
Z@04@000003AcJT0dLfY@00001d0dLfY000M0=7=Z@900000103AcJT3@00000<0dLfY0T00000Y0=7=
Z@900000103AcJT3@00000<0dLfY0T00000Z0=7=Z@900000103AcJT3@00000@0dLfY0T00000X0=7=
Z@900000103AcJT3@00000<0dLfY0d00000Y0=7=Z@900000103AcJT3@00000<0dLfY0d00000Y0=7=
Z@900000103AcJT3@0000080dLfY1400000X0=7=Z@900000103AcJT3@00000<0dLfY0T00000Z0=7=
Z@900000103AcJT3@00000<0dLfY0d00000M0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3A
cJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00603AcJTE00000080oooo8@3AcJT20?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0000000;00000200dLfY0`3oool00`00
0000oooo000000040?ooo`030000003oool0000000<0oooo0P0000000`3oool00000000000020?oo
ob40dLfY2`0000000`3oool000000000000900000240dLfY5@0000020?ooob00dLfY0P3ooolE0000
0240dLfY103oool5000000D0oooo100000050?ooob00dLfY5`00000J0=7=Z@00603AcJTD0?ooo`80
000000<0oooo0=7=Z@3AcJT07`3AcJT00`000000oooo0?ooo`040?ooo`050000003oool000000000
003oool02`00000P0=7=Z@<0oooo00@000000?ooo`000000oooo0P0000020?ooo`080000003oool0
oooo0?ooo`000000oooo0000003oool3000000030?ooo`3AcJT0dLfY01l0dLfY5`00000Q0=7=ZAD0
oooo00<000000?ooo`3AcJT07`3AcJT01@000000oooo000000000000oooo018000008@3AcJT30?oo
o`030000003oool0oooo00D0oooo0P0000060?ooo`<0000000<0oooo0=7=Z@3AcJT07P3AcJTG0000
01X0dLfY000H0=7=ZA<0oooo0P0000020?ooob40dLfY0P0000001@3oool000000?ooo`3oool00000
0080oooo00<000000?ooo`0000002`00000P0=7=Z@<0oooo0P0000001@3oool00000000000000000
oooo00<000000P3oool200000080oooo0P0000020?ooob40dLfY5`00000Q0=7=ZA@0oooo00<00000
0?ooo`3oool0803AcJT2000000030?ooo`0000000000018000008@3AcJT;0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0803AcJTG000001X0dLfY000H0=7=ZA8000000P3oool30000
0240dLfY0`0000040?ooo`@0000000<0oooo0000000000002@00000P0=7=Z@<0000000@0oooo0000
003oool000000`3oool00`000000oooo000000030?ooo`040000003oool0oooo0?ooo`<000008@3A
cJT;000000030?ooo`000000000000T000008@3AcJTC000000040?ooo`000000000000000200dLfY
0`0000000`3oool000000?ooo`0A00000240dLfY0`0000020?ooo`030000003oool0000000800000
0`3oool00`000000oooo0000000200000080oooo0`00000P0=7=ZAL000006P3AcJT001P0dLfY5`3o
oolQ0=7=Z@H000000`3oool00`000000oooo0?ooo`0;00000200dLfY103oool00`000000oooo0000
0003000000050?ooo`00000000000000003oool00P0000060?ooob40dLfY5`00000Q0=7=ZAL0oooo
803AcJT6000000030?ooo`000000000000h000008@3AcJT40?ooo`040000003oool0oooo000000<0
oooo00@000000?ooo`3oool0oooo0P0000060?ooob00dLfY5`00000J0=7=Z@00603AcJT@0?ooo`03
0000003oool0oooo00@0oooo8@3AcJT5000000<0oooo0`0000000`3oool000000000000900000200
dLfY1`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01@3ooolQ0=7=
ZAL000008@3AcJTG0?ooob00dLfY1@0000000`3oool000000000000?00000240dLfY203oool00`00
0000oooo0?ooo`02000000X0oooo803AcJTG000001X0dLfY000H0=7=ZA00000000<0oooo00000000
00001000000Q0=7=Z@H0000000<0oooo0000003oool00`3oool;00000200dLfY1P0000000`3oool0
0000000000060?ooo`030000003oool0000000D000008@3AcJT;000000030?ooo`000000000000T0
00008@3AcJT@000000030?ooo`000000000000@00000803AcJT6000000030?ooo`000000000000h0
00008@3AcJT7000000030?ooo`00000000000080oooo0`0000020?ooo`H00000803AcJTG000001X0
dLfY000H0=7=Z@l0oooo00<000000?ooo`3oool01@3ooolQ0=7=Z@T0000000<0oooo000000000000
2`00000P0=7=Z@L0oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000001`3ooolQ0=7=ZAL0
00008@3AcJTG0?ooob00dLfY5`00000Q0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=ZAL0
00006P3AcJT001P0dLfY5`3ooolQ0=7=Z@T000000`3oool;00000200dLfY203oool010000000oooo
0?ooo`00000;0?ooob40dLfY5`00000Q0=7=ZAL0oooo803AcJTG00000240dLfY2`3oool00`000000
oooo0?ooo`090?ooob00dLfY5`00000J0=7=Z@00603AcJT=000000030?ooo`000000000000L00000
8@3AcJT9000000030?ooo`000000000000/00000803AcJT9000000<0oooo00<000000?ooo`000000
2000000Q0=7=Z@/0000000<0oooo0000000000002@00000Q0=7=Z@d0000000<0oooo000000000000
1`00000P0=7=Z@T000000P3oool<00000240dLfY2@0000001@3oool000000?ooo`000000oooo00T0
0000803AcJTG000001X0dLfY000H0=7=Z@`0oooo00<000000?ooo`3oool0203ooolQ0=7=Z@X00000
0P3oool;00000200dLfY2`3oool2000000X0oooo8@3AcJTG00000240dLfY303oool00`000000oooo
0?ooo`080?ooob00dLfY2P0000000`3oool000000000000:00000240dLfY2`3oool2000000X0oooo
803AcJTG000001X0dLfY000H0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=ZAL00000803A
cJT;0?ooo`030000003oool0oooo00T0oooo8@3AcJTG00000240dLfY2`3oool00`000000oooo0?oo
o`090?ooob00dLfY5`00000Q0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=ZAL000006P3A
cJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT001`0dLfY1D00
00030=7=Z@=000000`3AcJT3@00002H0dLfY1D0000030=7=Z@=000000P3AcJT2@00002T0dLfY1D00
00030=7=Z@=0000000@0dLfY@000040000100000:03AcJT5@00000<0dLfY0d0000030=7=Z@03@000
003AcJT0dLfY02L0dLfY1D0000030=7=Z@=000000P3AcJT2@00002T0dLfY1D0000030=7=Z@=00000
00@0dLfY@000040000100000:03AcJT5@0000080dLfY0T0000040=7=Z@900000:@3AcJT5@0000080
dLfY0T0000030=7=Z@E00000703AcJT001h0dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY
0=7=Z@030=7=Z@03@000003AcJT0dLfY02L0dLfY00=000000=7=Z@3AcJT0103AcJT014000000dLfY
0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02P0dLfY00=000000=7=Z@3AcJT0103AcJT014000000
dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02L0dLfY00=000000=7=Z@3AcJT0103AcJT00d00
0000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY02T0dLfY00=000000=7=Z@3AcJT0103AcJT01400
0000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02P0dLfY00=000000=7=Z@3AcJT0103AcJT0
0d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY02P0dLfY00E000000=7=Z@3AcJT0dLfY@000
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0:03AcJT01D000000dLfY
0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0L0=7=Z@00
7P3AcJT014000000dLfY0=7=Z@3AcJT5@00000030=7=ZD000010000000=00000:03AcJT014000000
dLfY0=7=Z@3AcJT5@00000@0dLfY00=000000=7=Z@3AcJT0:03AcJT014000000dLfY0=7=Z@3AcJT5
@00000050=7=ZD000000dLfY0=7=ZD000000:@3AcJT014000000dLfY0=7=Z@3AcJT5@00000<0dLfY
00=000000=7=Z@3AcJT0:@3AcJT014000000dLfY0=7=Z@3AcJT5@00000050=7=ZD000000dLfY0=7=
ZD000000:P3AcJT014000000dLfY0=7=Z@3AcJT5@0000080dLfY0d00000Y0=7=Z@03@000003AcJT0
dLfY00@0dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0X0=7=Z@03@000003A
cJT0dLfY00@0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0L0=7=Z@007P3AcJT0
1D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY
0=7=Z@0W0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=Z@3AcJT2@000
02/0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY00=00000:P3AcJT0
1D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=
Z@0X0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=Z@3AcJT2@00002/0
dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=00000
0=7=Z@3AcJT09`3AcJT00d000000dLfY0=7=Z@020=7=Z@9000000`3AcJT014000000dLfY0=7=ZD00
000Z0=7=Z@03@000003AcJT0dLfY0080dLfY0T0000050=7=Z@03@000003AcJT0dLfY01`0dLfY000N
0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=ZD0000000`3AcJT00d000000dLfY@000000Y
0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=ZD0000000`3AcJT00d000000dLfY0=7=Z@0Z
0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=ZD0000000`3AcJT00d000000dLfY0=7=Z@0Y
0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD00
000Z0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=ZD0000000P3AcJT014000000dLfY0=7=
ZD00000Z0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=ZD0000000P3AcJT014000000dLfY
0=7=ZD00000Y0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT014000000
dLfY0=7=ZD00000Z0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0103AcJT00d00
0000dLfY0=7=Z@0L0=7=Z@007@3AcJT2@00000D0dLfY0T0000040=7=Z@900000:03AcJT2@00000D0
dLfY0T0000030=7=Z@=00000:@3AcJT2@00000D0dLfY0T0000030=7=Z@=00000:03AcJT2@00000D0
dLfY0T0000020=7=Z@A00000:@3AcJT2@00000D0dLfY0T0000030=7=Z@900000:P3AcJT2@00000D0
dLfY0T0000030=7=Z@=00000:03AcJT2@00000@0dLfY0d0000030=7=Z@900000:P3AcJT2@00000@0
dLfY0d0000030=7=Z@9000007P3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT0
0?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT001P0dLfY5`00000Q0=7=Z@<0oooo0P00
00001@3oool000000?ooo`000000oooo00800000103oool2000000<0oooo0P00000P0=7=Z@030?oo
o`000000000001@000008@3AcJTG00000240dLfY5`00000P0=7=Z@030000003oool0oooo00800000
0P3oool200000080oooo0P0000020?ooo`8000000P3oool400000240dLfY00<0oooo000000000000
5000000P0=7=ZAL000006P3AcJT001P0dLfY1P0000000`3oool000000000000>00000240dLfY00D0
00000?ooo`3oool0oooo000000090?ooo`800000103oool300000200dLfY00<000000?ooo`000000
5000000Q0=7=ZAL000008@3AcJT6000000030?ooo`000000000000h00000803AcJT00`000000oooo
0?ooo`0200000080oooo0P0000020?ooo`8000000P3oool200000080oooo1000000Q0=7=Z@030000
003oool0000001@00000803AcJTG000001X0dLfY000H0=7=ZAL0oooo8@3AcJT3000000030?ooo`00
0000oooo00P0oooo0P0000040?ooo`<00000803AcJT20?ooo`030000003oool0oooo0180oooo8@3A
cJTG00000240dLfY5`3ooolP0=7=Z@<000000P3oool200000080oooo0P0000020?ooo`8000000P3o
ool2000000040?ooo`000000000000000240dLfY0P3oool00`000000oooo0?ooo`0B0?ooob00dLfY
5`00000J0=7=Z@00603AcJT70?ooo`030000003oool0oooo00d0oooo8@3AcJT300000080oooo00D0
00000?ooo`000000oooo000000020?ooo`800000103oool500000200dLfY0`3oool00`000000oooo
0?ooo`0A0?ooob40dLfY5`00000Q0=7=Z@L0oooo00<000000?ooo`3oool03@3ooolP0=7=Z@<00000
0P3oool200000080oooo0P0000020?ooo`8000000P3oool600000240dLfY0`3oool00`000000oooo
0?ooo`0A0?ooob00dLfY5`00000J0=7=Z@00603AcJTG0?ooob40dLfY100000020?ooo`040000003o
ool000000?ooo`800000103oool700000200dLfY103oool00`000000oooo0?ooo`0@0?ooob40dLfY
5`00000Q0=7=ZAL0oooo803AcJT4000000030?ooo`00000000000080oooo0P0000020?ooo`800000
0P3oool600000240dLfY103oool00`000000oooo0?ooo`0@0?ooob00dLfY5`00000J0=7=Z@00603A
cJT8000000030?ooo`000000000000`000008@3AcJT5000000050?ooo`000000oooo0000003oool0
0P0000040?ooo`L00000803AcJT5000000030?ooo`000000000000l000008@3AcJTG00000240dLfY
200000000`3oool000000000000<00000200dLfY1@0000020?ooo`8000000P3oool200000080oooo
2000000Q0=7=Z@D0000000<0oooo0000000000003`00000P0=7=ZAL000006P3AcJT001P0dLfY5`00
000Q0=7=Z@H00000203oool900000200dLfY1P0000000`3oool000000000000>00000240dLfY5`00
000Q0=7=ZAL00000803AcJT6000000030?ooo`00000000000080oooo0P0000020?ooo`P000008@3A
cJT6000000030?ooo`000000000000h00000803AcJTG000001X0dLfY000H0=7=Z@T0oooo00<00000
0?ooo`3oool02`3ooolQ0=7=Z@L000001`3oool900000200dLfY1`3oool00`000000oooo0?ooo`0=
0?ooob40dLfY5`00000Q0=7=Z@T0oooo00<000000?ooo`3oool02`3ooolP0=7=Z@L000000P3oool2
00000080oooo2P00000Q0=7=Z@L0oooo00<000000?ooo`3oool03@3ooolP0=7=ZAL000006P3AcJT0
01P0dLfY5`3ooolQ0=7=Z@P0000000@0oooo0000003oool0oooo2`00000P0=7=Z@P0oooo00<00000
0?ooo`3oool0303ooolQ0=7=ZAL000008@3AcJTG0?ooob00dLfY200000000`3oool0000000000002
0?ooo`X000008@3AcJT80?ooo`030000003oool0oooo00`0oooo803AcJTG000001X0dLfY000H0=7=
Z@X0oooo00<000000?ooo`3oool02P3ooolQ0=7=Z@`0000000<0oooo0000000000002000000P0=7=
ZAL0oooo8@3AcJT<000000030?ooo`000000000000P000008@3AcJT:0?ooo`030000003oool0oooo
00X0oooo803AcJT;00000080oooo2P00000Q0=7=ZAL0oooo803AcJT<000000030?ooo`0000000000
00P000006P3AcJT001P0dLfY5`00000Q0=7=Z@X0000000<0oooo0000000000002P00000P0=7=Z@X0
000000<0oooo0000000000002P00000Q0=7=ZAL000008@3AcJTG00000200dLfY2P0000000`3oool0
00000000000:00000240dLfY2P0000000`3oool000000000000:00000200dLfY5`00000J0=7=Z@00
o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00
703AcJT5@0000080dLfY0T0000030=7=Z@=00000:03AcJT5@0000080dLfY0T0000050=7=Z@03@000
003AcJT0dLfY02L0dLfY1D0000020=7=Z@900000103AcJT2@00002P0dLfY1D0000020=7=Z@900000
0`3AcJT3@00002T0dLfY1D0000030=7=Z@=000000P3AcJT2@00002T0dLfY1D0000030=7=Z@=00000
00<0dLfY@000040000000d00000V0=7=Z@E000000`3AcJT3@00000030=7=ZD000010000000900000
:03AcJT5@00000<0dLfY0d0000020=7=Z@9000007P3AcJT001h0dLfY00E000000=7=Z@3AcJT0dLfY
@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT09`3AcJT01D000000
dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0Y0=7=
Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003A
cJT0dLfY02L0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY
00=000000=7=Z@3AcJT0:@3AcJT00d000000dLfY0=7=Z@040=7=Z@04@000003AcJT0dLfY@0000080
dLfY00=000000=7=Z@3AcJT0:03AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY0080
dLfY00=000000=7=Z@3AcJT0:03AcJT00d000000dLfY0=7=Z@040=7=Z@04@000003AcJT0dLfY@000
02d0dLfY00=000000=7=Z@3AcJT0103AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0
dLfY01/0dLfY000N0=7=Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@0000002
0=7=Z@03@000003AcJT0dLfY02L0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@03
0=7=Z@03@000003AcJT0dLfY02T0dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3A
cJU000000080dLfY00=000000=7=Z@3AcJT09`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003A
cJT0dLfY0080dLfY0d00000Z0=7=Z@04@000003AcJT0dLfY0=7=Z@E0000000D0dLfY@000003AcJT0
dLfY@000000Z0=7=Z@04@000003AcJT0dLfY0=7=Z@E000000`3AcJT00d000000dLfY0=7=Z@0X0=7=
Z@04@000003AcJT0dLfY0=7=Z@E000000P3AcJT00d000000dLfY0=7=Z@0Z0=7=Z@04@000003AcJT0
dLfY0=7=Z@E000000`3AcJT00d000000dLfY0=7=Z@0L0=7=Z@007P3AcJT00d000000dLfY0=7=Z@04
0=7=Z@03@000003AcJT0dLfY00=00000:P3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0
dLfY00<0dLfY00=000000=7=Z@3AcJT0:03AcJT00d000000dLfY0=7=Z@040=7=Z@04@000003AcJT0
dLfY0=7=Z@900000:P3AcJT00d000000dLfY0=7=Z@040=7=Z@04@000003AcJT0dLfY@0000080dLfY
00=000000=7=Z@3AcJT0:03AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3A
cJU000000P3AcJT00d000000dLfY0=7=Z@0X0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT0
0d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY02P0dLfY00E000000=7=Z@3AcJT0dLfY@000
00020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0:@3AcJT01D000000dLfY0=7=
Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0K0=7=Z@007P3A
cJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00E000000=7=Z@3AcJT0dLfY@000000[0=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0
dLfY02P0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY
00=000000=7=Z@3AcJT09`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3A
cJU000000P3AcJT00d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=
ZD0000000P3AcJT014000000dLfY0=7=ZD00000Z0=7=Z@03@000003AcJT0dLfY0080dLfY00=00000
0=7=ZD000000103AcJT00d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY0080dLfY00=00000
0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD00000Z0=7=Z@03@000003AcJT0dLfY0080dLfY00=0
00000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD00000M0=7=Z@007@3AcJT2@00000@0dLfY0T00
00040=7=Z@=00000:03AcJT2@00000@0dLfY0T0000030=7=Z@A00000:@3AcJT2@00000@0dLfY0T00
00040=7=Z@900000:@3AcJT2@00000@0dLfY0T0000040=7=Z@=00000:@3AcJT2@00000D0dLfY0T00
00030=7=Z@900000:P3AcJT2@00000D0dLfY0T0000030=7=Z@900000:@3AcJT2@00000D0dLfY0T00
00030=7=Z@900000:P3AcJT2@00000D0dLfY0T0000030=7=Z@9000007P3AcJT00?l0dLfYc`3AcJT0
0?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT001P0dLfY2`000000
0`3oool000000000000900000240dLfY1@3oool=000000D0oooo803AcJT20?oooaD000008@3AcJT<
000000050?ooo`000000oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0P0=7=Z@/0000000<0
oooo0000000000002P00000P0=7=Z@D0oooo3@0000050?ooob40dLfY0P3ooolE00000200dLfY5@00
00020?oooaX0dLfY000H0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@040000003oool0
00000?ooo`l0000000@0oooo0000003oool00000803AcJTG0?ooob40dLfY2`000000103oool00000
0000003oool2000000<0oooo00<000000?ooo`000000803AcJTH0?ooob00dLfY00@000000?ooo`00
0000oooo3`000000103oool000000?ooo`00000Q0=7=ZAL0oooo803AcJTD00000080oooo00<00000
0=7=Z@3AcJT0603AcJT001P0dLfY2`3oool00`000000oooo0?ooo`090?ooob40dLfY0P0000000`3o
ool000000000000?000000030?ooo`00000000000200dLfY0`3oool00`000000oooo0?ooo`0A0?oo
ob40dLfY300000001P3oool000000?ooo`3oool000000?ooo`80000000<0oooo000000000000803A
cJTH0?ooob00dLfY0P0000000`3oool000000000000?000000030?ooo`00000000000240dLfY5`3o
oolP0=7=ZA@0000000<0oooo0000000000006P3AcJT001P0dLfY2`0000000`3oool0000000000009
00000240dLfY0`0000000`3oool000000?ooo`02000000080?ooo`000000oooo0000003oool00000
0?ooo`0000020?ooo`030000003oool0000000800000803AcJT3000000030?ooo`00000000000140
00008@3AcJT;000000030?ooo`000000000000<0000000<0oooo0000003oool00`00000P0=7=Z@/0
000000<0oooo0000000000002P00000P0=7=Z@<0000000<0oooo0000003oool00P000000203oool0
00000?ooo`000000oooo0000003oool000000P3oool00`000000oooo0000000200000240dLfY0`00
00000`3oool000000000000A00000200dLfY4@0000030?ooo`<000006P3AcJT001P0dLfY2`3oool0
0`000000oooo0?ooo`090?ooob40dLfY1@000000103oool000000000003oool800000080oooo1000
000P0=7=Z@@0oooo00<000000?ooo`3oool0403ooolQ0=7=Z@/000000P3oool01P000000oooo0?oo
o`3oool000000?ooo`@00000803AcJTH0?ooob00dLfY1@000000103oool000000000003oool80000
0080oooo1000000Q0=7=Z@@0oooo00<000000?ooo`3oool0403ooolP0=7=ZA80000000<0oooo0000
000000000P00000J0=7=Z@00603AcJT;0?ooo`030000003oool0oooo00T0oooo8@3AcJT5000000@0
oooo1P0000030?ooo`D00000803AcJTG0?ooob40dLfY2`0000001`3oool00000000000000000oooo
0000003oool01@00000P0=7=ZAP0oooo803AcJT5000000@0oooo1P0000030?ooo`D000008@3AcJTG
0?ooob00dLfY400000020?ooo`D000006P3AcJT001P0dLfY2`0000000`3oool00000000000090000
0240dLfY1P0000020?ooo`L000000P3oool600000200dLfY1P0000000`3oool000000000000>0000
0240dLfY2`0000001P3oool000000?ooo`3oool000000?ooo`H00000803AcJT;000000030?ooo`00
0000000000X00000803AcJT600000080oooo1`0000020?ooo`H000008@3AcJTG00000200dLfY4000
00000`3oool0000000000004000001X0dLfY000H0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ
0=7=ZAL00000803AcJT70?ooo`030000003oool0oooo00d0oooo8@3AcJT=000000030?ooo`000000
000000L00000803AcJTH0?ooob00dLfY5`00000Q0=7=ZAL0oooo803AcJTG000001X0dLfY000H0=7=
Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@X0000000D0oooo0000003oool000000?ooo`08
00000200dLfY203oool00`000000oooo0?ooo`0<0?ooob40dLfY2`0000040?ooo`P00000803AcJTH
0?ooob00dLfY2P0000001@3oool000000?ooo`000000oooo00P000008@3AcJTG0?ooob00dLfY3P00
00000`3oool0000000000006000001X0dLfY000H0=7=Z@/0000000<0oooo0000000000002@00000Q
0=7=Z@T0000000D0oooo00000000000000000?ooo`0900000200dLfY2@0000020?ooo``000008@3A
cJT=000000030?ooo`000000000000L00000803AcJT;000000030?ooo`000000000000X00000803A
cJT9000000050?ooo`00000000000000003oool02@00000Q0=7=Z@T0000000<0oooo000000000000
2`00000P0=7=Z@d0000000<0oooo0000000000001`00000J0=7=Z@00603AcJT;0?ooo`030000003o
ool0oooo00T0oooo8@3AcJTG00000200dLfY2P3oool00`000000oooo0?ooo`0:0?ooob40dLfY2`00
00000`3oool000000000000900000200dLfY603ooolP0=7=ZAL000008@3AcJTG0?ooob00dLfY5`00
000J0=7=Z@00603AcJT;0?ooo`030000003oool0oooo00T0oooo8@3AcJTG00000200dLfY2`3oool0
0`000000oooo0?ooo`090?ooob40dLfY5`00000P0=7=ZAP0oooo803AcJTG00000240dLfY2`3oool0
0`000000oooo0?ooo`090?ooob00dLfY5`00000J0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00
o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00703AcJT5@00000030=7=ZD0000100000009000000`3AcJT2
@00002P0dLfY1D0000000`3AcJU00000@0000002@0000080dLfY0d00000Y0=7=Z@E000000P3AcJT2
@00000@0dLfY0T00000X0=7=Z@E000000P3AcJT2@00000<0dLfY1D00000W0=7=Z@E000000P3AcJT2
@00000<0dLfY1400000X0=7=Z@E000000P3AcJT2@00000@0dLfY0T00000X0=7=Z@E000000P3AcJT2
@00000D0dLfY0d00000W0=7=Z@E000000P3AcJT2@00000@0dLfY0T00000N0=7=Z@007P3AcJT01D00
0000dLfY0=7=Z@3AcJU0000000D0dLfY00A000000=7=Z@3AcJU00000:@3AcJT01D000000dLfY0=7=
Z@3AcJU0000000L0dLfY00=000000=7=Z@3AcJT0:@3AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0W0=7=Z@05@000003AcJT0dLfY
0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY02T0dLfY00E00000
0=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@00002d0dLfY00E000000=7=Z@3AcJT0
dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT09`3AcJT01D00
0000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0X
0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000
003AcJT0dLfY01/0dLfY000N0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3A
cJT014000000dLfY0=7=ZD00000Y0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0
0`3AcJT3@00002X0dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00=000000=7=Z@3AcJT09`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0
dLfY00=000000=7=Z@3AcJT0:@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080
dLfY00=000000=7=Z@3AcJT0:P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0
dLfY00=000000=7=Z@3AcJT0:03AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY0=7=
Z@E00000:@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=
Z@3AcJT06`3AcJT001h0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@90
0000:P3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d00
0000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY00@0dLfY00A000000=7=Z@3AcJU000000P3AcJT0
0d000000dLfY0=7=Z@0W0=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT00P3AcJT0
0d000000dLfY0=7=Z@0Y0=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT00P3AcJT0
0d000000dLfY0=7=Z@0Y0=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT00`3AcJT0
0d000000dLfY0=7=Z@0W0=7=Z@03@000003AcJT0dLfY00@0dLfY00A000000=7=Z@3AcJU000000P3A
cJT00d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY00@0dLfY00A000000=7=Z@3AcJT0dLfY
0T00000N0=7=Z@007P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU0
00000P3AcJT00d000000dLfY0=7=Z@0W0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02P0dLfY00E000000=7=Z@3AcJT0dLfY@000
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT09`3AcJT01D000000dLfY
0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0Y0=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0
dLfY02P0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY
00=000000=7=Z@3AcJT09`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00M000000=7=Z@3A
cJT0dLfY@000003AcJU0000002X0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@05@000003A
cJT0dLfY0=7=ZD0000007`3AcJT001d0dLfY0T0000040=7=Z@900000103AcJT2@00002T0dLfY0T00
00040=7=Z@900000103AcJT3@00002T0dLfY0T0000040=7=Z@900000103AcJT2@00002T0dLfY0T00
00040=7=Z@900000103AcJT2@00002X0dLfY0T0000040=7=Z@900000103AcJT2@00002X0dLfY0T00
00040=7=Z@900000103AcJT2@00002T0dLfY0T0000040=7=Z@9000001@3AcJT2@00002T0dLfY0T00
00040=7=Z@900000103AcJT3@00001d0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0
dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY000H0=7=Z@8000000P3oool01000
0000oooo0000000000030?ooo`040000003oool0oooo0?ooo`@000000P3oool200000240dLfY00<0
00000?ooo`3oool00P3oool4000000@0oooo100000050?ooo`030000003AcJT0dLfY01h0dLfY0`00
00020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000`3oool00`000000dLfY0=7=
Z@0O0=7=ZAL00000803AcJT3000000<0oooo1@000000103oool000000000003oool3000000030?oo
o`000000000000<00000803AcJT300000080oooo1P0000020?ooo`H000000`3oool00`000000dLfY
0=7=Z@0O0=7=Z@D000003@3oool500000200dLfY5`00000J0=7=Z@00603AcJT00`3oool000000000
00050?ooo`040000003oool0000000000080oooo00<000000?ooo`3oool00P000000103oool00000
0?ooo`3ooolQ0=7=Z@030?ooo`000000oooo0080oooo100000040?ooo`@000001P3ooolP0=7=Z@03
0?ooo`00000000000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000040?ooob40
dLfY00<0oooo0000000000004P0000020?ooob00dLfY00<0oooo0000000000000`0000030?ooo`<0
00000P3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool0803AcJT00`3o
ool00000000000020?ooo`H000000P3oool6000000@0oooo8@3AcJT0103oool0000000000000000?
0?ooo`8000000P3ooolP0=7=Z@030?ooo`0000000000018000000P3ooolJ0=7=Z@00603AcJT20?oo
o`<0000000<0oooo0000003oool00`0000030?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool08@3AcJT20?ooo`<000000P3oool600000080oooo1P0000020?ooob00dLfY0P3oool0
0`000000oooo0?ooo`0200000080oooo0P0000020?ooo`8000000P3oool2000000040?ooo`000000
oooo0?ooob40dLfY0P3ooolC00000080oooo803AcJT20?ooo`@000000`3oool300000080oooo00D0
00000?ooo`000000oooo000000020?ooo`030000003oool0oooo0200dLfY0P3oool300000080oooo
1P0000020?ooo`H000000P3ooolQ0=7=Z@80oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0P0=7=Z@80oooo4`0000020?oooaX0dLfY000H0=7=Z@<0oooo0P0000020?ooo`030000003o
ool0000000<0000000@0oooo0000003oool000000P3oool010000000oooo0?ooo`3ooolQ0=7=Z@<0
oooo0P0000020?ooo`H000000P3oool5000000<0oooo803AcJT30?ooo`040000003oool000000000
0080oooo0P0000020?ooo`8000000P3oool3000000<0oooo8@3AcJT30?oooa4000000`3ooolP0=7=
Z@<0oooo1P0000020?ooo`030000003oool000000080000000<0oooo0000003oool01@3ooolP0=7=
Z@<0oooo0P0000020?ooo`H000000P3oool5000000<0oooo8@3AcJT30?ooo`030000003oool0oooo
00@0oooo00D000000?ooo`000000oooo000000040?ooo`040000003oool0oooo0?ooob00dLfY0`3o
oolA000000<0oooo6P3AcJT001P0dLfY103oool00`000000oooo0?ooo`02000000040?ooo`000000
00000?ooo`80000000<0oooo0000003oool01@3ooolQ0=7=Z@@0oooo00<000000?ooo`3oool01P00
00020?ooo`<000001@3ooolP0=7=Z@@0oooo0`0000020?ooo`8000000P3oool200000080oooo00<0
00000?ooo`3oool00`3ooolQ0=7=Z@@0oooo3P0000050?ooob00dLfY1P3oool5000000040?ooo`00
000000000?ooo`<000001P3ooolP0=7=Z@@0oooo00<000000?ooo`3oool01P0000020?ooo`<00000
1@3ooolQ0=7=Z@@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000T0
oooo803AcJT40?ooo`h000001@3ooolJ0=7=Z@00603AcJT50?ooo`8000000P3oool200000080oooo
0P0000020?ooo`030000003oool0oooo00<0oooo8@3AcJT50?ooo`040000003oool0oooo0?ooo`@0
0000103oool00`000000oooo0?ooo`030?ooob00dLfY1@3oool200000080oooo0P0000020?ooo`80
00000P3oool00`000000oooo0?ooo`030?ooob40dLfY1@3oool=000000D0oooo803AcJT60?ooo`D0
000000@0oooo000000000000oooo0`0000060?ooob00dLfY1@3oool200000080oooo1P0000020?oo
o`030000003oool0oooo00<0oooo8@3AcJT50?ooo`040000003oool0oooo000000D0oooo00@00000
0?ooo`00000000001@3ooolP0=7=Z@D0oooo3@0000050?oooaX0dLfY000H0=7=Z@H0oooo0P000002
0?ooo`040000003oool0oooo000000T0oooo8@3AcJT60?ooo`030000003oool0oooo00@000002P3o
oolP0=7=Z@H0oooo00<000000?ooo`3oool00P0000020?ooo`800000203ooolQ0=7=Z@H0oooo2P00
00070?ooob00dLfY2@3oool300000080oooo00<000000?ooo`0000001`3ooolP0=7=Z@H0oooo00<0
00000?ooo`3oool01P0000080?ooob40dLfY1P3oool2000000L0oooo00<000000?ooo`3oool01@3o
oolP0=7=Z@H0oooo2P0000070?oooaX0dLfY000H0=7=Z@L0oooo0P000000103oool000000?ooo`3o
ool3000000L0oooo8@3AcJT70?ooo`8000000P3oool5000000L0oooo803AcJT70?ooo`040000003o
ool0000000000080oooo0`0000070?ooob40dLfY1`3oool9000000L0oooo803AcJT90?ooo`<00000
0P3oool00`000000oooo0?ooo`070?ooob00dLfY1`3oool200000080oooo1@0000070?ooob40dLfY
1`3oool2000000H0oooo00<000000?ooo`3oool01@3ooolP0=7=Z@L0oooo2@0000070?oooaX0dLfY
000H0=7=Z@P0oooo00@000000?ooo`3oool0oooo0P0000090?ooob40dLfY203oool00`000000oooo
0?ooo`03000000T0oooo803AcJT80?ooo`<000000P3oool00`000000oooo0?ooo`070?ooob40dLfY
203oool6000000T0oooo803AcJT;0?ooo`030000003oool0000000X0oooo803AcJT80?ooo`030000
003oool0oooo00<000002@3ooolQ0=7=Z@P0oooo00<000000?ooo`3oool0303ooolP0=7=Z@P0oooo
1P0000090?oooaX0dLfY000H0=7=ZAL0oooo8@3AcJT;0?ooo`8000002P3ooolP0=7=Z@X0oooo00<0
00000?ooo`3oool02P3ooolQ0=7=Z@X0oooo0`00000:0?ooob00dLfY2P3oool00`000000oooo0000
000;0?ooob00dLfY2`3oool2000000X0oooo8@3AcJTG0?ooob00dLfY2P3oool3000000X0oooo6P3A
cJT001P0dLfY2P3oool2000000/0oooo8@3AcJT:0?ooo`030000003oool0oooo00X0oooo803AcJT:
0?ooo`030000003oool0oooo00X0oooo8@3AcJT:0?ooo`8000002`3ooolP0=7=Z@`0oooo00<00000
0?ooo`3oool02@3ooolP0=7=Z@X0oooo00<000000?ooo`3oool02P3ooolQ0=7=Z@X0oooo0P00000;
0?ooob00dLfY2P3oool2000000/0oooo6P3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfY
c`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT001`0dLfY1D0000000`3AcJU00000@0000002@000
00<0dLfY0T00000X0=7=Z@E0000000<0dLfY@000040000000T0000020=7=Z@E000009`3AcJT5@000
00030=7=ZD0000100000009000000P3AcJT4@00002L0dLfY1D0000000`3AcJU00000@0000002@000
00<0dLfY0T00000Y0=7=Z@E0000000<0dLfY@000040000000T0000040=7=Z@=000009`3AcJT5@000
00030=7=ZD0000100000009000000`3AcJT2@00002P0dLfY1D0000000`3AcJU00000@0000002@000
0080dLfY0d00000Y0=7=Z@E0000000<0dLfY@000040000000T0000040=7=Z@03@000003AcJT0dLfY
01`0dLfY000N0=7=Z@05@000003AcJT0dLfY0=7=ZD0000001@3AcJT014000000dLfY0=7=ZD00000Y
0=7=Z@05@000003AcJT0dLfY0=7=ZD0000001`3AcJT00d000000dLfY0=7=Z@0Y0=7=Z@05@000003A
cJT0dLfY0=7=ZD0000001@3AcJT00d000000dLfY0=7=Z@0Z0=7=Z@05@000003AcJT0dLfY0=7=ZD00
00001@3AcJT014000000dLfY0=7=ZD00000Z0=7=Z@05@000003AcJT0dLfY0=7=ZD000000203AcJT0
0d000000dLfY0=7=Z@0X0=7=Z@05@000003AcJT0dLfY0=7=ZD0000001@3AcJT014000000dLfY0=7=
ZD00000Y0=7=Z@05@000003AcJT0dLfY0=7=ZD0000001@3AcJT014000000dLfY0=7=ZD00000Z0=7=
Z@05@000003AcJT0dLfY0=7=ZD0000001`3AcJT00d000000dLfY0=7=Z@0L0=7=Z@007P3AcJT00d00
0000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU00000:@3AcJT0
0d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT0:@3AcJT0
0d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0:@3AcJT0
0d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT0:@3AcJT0
0d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY1D00000Y0=7=Z@03@000003AcJT0
dLfY0080dLfY00=000000=7=Z@3AcJT01@3AcJT00d000000dLfY0=7=Z@0W0=7=Z@03@000003AcJT0
dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD00000Z0=7=Z@03@000003A
cJT0dLfY0080dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@0L0=7=Z@007P3AcJT0
0d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=
Z@0W0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=
Z@0Y0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=
Z@0X0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=
Z@0X0=7=Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000
003AcJT0dLfY02P0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@900000
:P3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY0=7=Z@=00000:`3AcJT00d000000
dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT06`3AcJT001h0dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=
Z@3AcJT09`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT0
0d000000dLfY0=7=Z@0Y0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=
ZD0000020=7=Z@03@000003AcJT0dLfY02L0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04
@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0:03AcJT01D000000dLfY0=7=Z@3AcJU0
00000080dLfY00M000000=7=Z@3AcJT0dLfY@000003AcJU0000002X0dLfY00E000000=7=Z@3AcJT0
dLfY@00000020=7=Z@05@000003AcJT0dLfY0=7=ZD000000:`3AcJT01D000000dLfY0=7=Z@3AcJU0
00000080dLfY00E000000=7=Z@3AcJT0dLfY@000000/0=7=Z@05@000003AcJT0dLfY0=7=ZD000000
0P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY01/0dLfY000M0=7=Z@900000
103AcJT2@00000@0dLfY0T00000Y0=7=Z@900000103AcJT2@00000@0dLfY0T00000Z0=7=Z@900000
103AcJT2@00000@0dLfY0T00000Y0=7=Z@900000103AcJT2@00000@0dLfY0T00000Z0=7=Z@900000
103AcJT2@00000D0dLfY0T00000Y0=7=Z@900000103AcJT2@00000@0dLfY0d00000X0=7=Z@900000
103AcJT2@00000@0dLfY0d00000Y0=7=Z@900000103AcJT2@00000<0dLfY1400000M0=7=Z@00o`3A
cJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00603A
cJT00`000000oooo0?ooo`0D0?ooob40dLfY00<000000?ooo`3oool0503ooolP0=7=Z@030000003o
ool0oooo008000000P3oool200000080oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@`000002`3o
oolQ0=7=Z@030000003oool0oooo01@0oooo803AcJT00`000000oooo0?ooo`0D0?ooob40dLfY00<0
00000?ooo`0000000`3oool200000080oooo0P00000;0?ooob00dLfY3000000;0?oooaX0dLfY000H
0=7=Z@030?ooo`000000oooo01@0oooo8@3AcJT00`3oool000000?ooo`0D0?ooob00dLfY00<0oooo
0000003oool00P0000020?ooo`8000000P3oool00`000000oooo0?ooo`090?ooob40dLfY00<0oooo
0000000000002@00000;0?ooob40dLfY00<0oooo0000003oool0503ooolP0=7=Z@030?ooo`000000
oooo01@0oooo8@3AcJT01P3oool000000?ooo`000000oooo00000080oooo1000000;0?ooob00dLfY
00<0oooo0000000000002@00000;0?oooaX0dLfY000H0=7=Z@80oooo00<000000?ooo`3oool04P3o
oolQ0=7=Z@80oooo00<000000?ooo`3oool04P3ooolP0=7=Z@80oooo0`0000020?ooo`8000000P3o
ool00`000000oooo0?ooo`090?ooob40dLfY0P3oool:000000/0oooo8@3AcJT20?ooo`030000003o
ool0oooo0180oooo803AcJT20?ooo`030000003oool0oooo0180oooo8@3AcJT20?ooo`8000000P3o
ool200000080oooo0P00000;0?ooob00dLfY0P3oool:000000/0oooo6P3AcJT001P0dLfY0`3oool0
0`000000oooo0?ooo`0A0?ooob40dLfY0`3oool00`000000oooo0?ooo`0A0?ooob00dLfY0`3oool2
00000080oooo0P0000020?ooo`030000003oool0oooo00T0oooo8@3AcJT30?ooo`T000002`3ooolQ
0=7=Z@<0oooo00<000000?ooo`3oool04@3ooolP0=7=Z@<0oooo00<000000?ooo`3oool04@3ooolQ
0=7=Z@<0oooo0`0000000`3oool000000?ooo`03000000/0oooo803AcJT30?ooo`T000002`3ooolJ
0=7=Z@00603AcJTG0?ooob40dLfY5`3ooolP0=7=Z@@0oooo00<000000?ooo`3oool00P0000020?oo
o`030000003oool0oooo00T0oooo8@3AcJT40?ooo`P000002`3ooolQ0=7=ZAL0oooo803AcJTG0?oo
ob40dLfY103oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool02@3ooolP0=7=
Z@@0oooo2000000;0?oooaX0dLfY000H0=7=Z@D0oooo00<000000?ooo`3oool03`3ooolQ0=7=Z@D0
oooo00<000000?ooo`3oool03`3ooolP0=7=Z@D0oooo00@000000?ooo`00000000000P3oool00`00
0000oooo0?ooo`090?ooob40dLfY1@3oool7000000/0oooo8@3AcJT50?ooo`030000003oool0oooo
00l0oooo803AcJT50?ooo`030000003oool0oooo00l0oooo8@3AcJT50?ooo`<0000000@0oooo0000
0000000000002`3ooolP0=7=Z@D0oooo1`00000;0?oooaX0dLfY000H0=7=ZAL0oooo8@3AcJTG0?oo
ob00dLfY1`3oool200000080oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@H0oooo1P00000;0?oo
ob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJT80?ooo`80000000<0oooo0000003oool02P3ooolP0=7=
Z@H0oooo1P00000;0?oooaX0dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY1`3oool200000080
oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@L0oooo1@00000;0?ooob40dLfY5`3ooolP0=7=ZAL0
oooo8@3AcJT70?ooo`<0000000<0oooo0000003oool02P3ooolP0=7=Z@L0oooo1@00000;0?oooaX0
dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY203oool010000000oooo0?ooo`00000;0?ooob40
dLfY203oool4000000/0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=Z@P0oooo00@000000?ooo`3o
ool000002`3ooolP0=7=Z@P0oooo1000000;0?oooaX0dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00
dLfY2`3oool00`000000oooo0?ooo`090?ooob40dLfY2@3oool3000000/0oooo8@3AcJTG0?ooob00
dLfY5`3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=Z@T0oooo0`00000;0?oooaX0
dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY2`3oool00`000000oooo0?ooo`090?ooob40dLfY
2P3oool2000000/0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool0
2@3ooolP0=7=Z@X0oooo0P00000;0?oooaX0dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY2`3o
ool00`000000oooo0?ooo`090?ooob40dLfY2`3oool00`000000oooo0?ooo`090?ooob40dLfY5`3o
oolP0=7=ZAL0oooo8@3AcJT;0?ooo`030000003oool0oooo00T0oooo803AcJT;0?ooo`030000003o
ool0oooo00T0oooo6P3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfY
c`3AcJT001`0dLfY1D0000000`3AcJU00000@0000003@00000030=7=ZD0000100000009000009`3A
cJT5@00000030=7=ZD000010000000=000000P3AcJT2@00002T0dLfY1D0000000`3AcJU00000@000
0003@00000<0dLfY0d00000V0=7=Z@E0000000<0dLfY@000040000000d0000020=7=Z@900000:@3A
cJT5@00000030=7=ZD000010000000=0000000@0dLfY@000040000100000:@3AcJT5@00000030=7=
ZD000010000000=000000`3AcJT00d000000dLfY0=7=Z@0V0=7=Z@E0000000<0dLfY@00004000000
0d0000020=7=Z@900000:@3AcJT5@00000030=7=ZD000010000000=0000000@0dLfY@00004000010
00007P3AcJT001h0dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU0000002`0
dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=
Z@3AcJT0:03AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=
Z@3AcJT09`3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT0
0d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@000
00020=7=Z@03@000003AcJT0dLfY02P0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=
Z@030=7=Z@03@000003AcJT0dLfY02P0dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=
Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0:03AcJT00d000000dLfY0=7=Z@030=7=Z@03@000
003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0703AcJT001h0dLfY00=000000=7=Z@3AcJT00`3A
cJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY02T0dLfY00=000000=7=Z@3AcJT00`3A
cJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY02T0dLfY00=000000=7=Z@3AcJT00`3A
cJT014000000dLfY0=7=Z@3AcJT5@00002P0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY
0=7=Z@040=7=Z@03@000003AcJT0dLfY02P0dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY
0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0:03AcJT00d000000dLfY0=7=Z@030=7=Z@03
@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0:03AcJT00d000000dLfY0=7=Z@030=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY
00<0dLfY00=000000=7=Z@3AcJT00P3AcJT3@00001d0dLfY000N0=7=Z@03@000003AcJT0dLfY00<0
dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY00<0
dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY00<0
dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY02L0dLfY00=000000=7=
Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@900000:`3AcJT00d000000dLfY0=7=Z@030=7=
Z@04@000003AcJT0dLfY0=7=Z@=00000:`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0
dLfY00@0dLfY00=000000=7=Z@3AcJT09`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0
dLfY0080dLfY0T00000[0=7=Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@000
00020=7=Z@03@000003AcJT0dLfY01/0dLfY000N0=7=Z@03@000003AcJT0dLfY00<0dLfY00E00000
0=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY02L0dLfY00=000000=7=Z@3AcJT00`3A
cJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0:03AcJT00d000000dLfY
0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=ZD000000:@3AcJT00d000000dLfY
0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0:P3AcJT00d000000dLfY
0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0:P3AcJT00d000000dLfY
0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0W0=7=Z@03
@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY
02P0dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=00000
0=7=Z@3AcJT06`3AcJT001d0dLfY0T0000040=7=Z@900000103AcJT2@00002T0dLfY0T0000040=7=
Z@900000103AcJT2@00002X0dLfY0T0000040=7=Z@9000001@3AcJT2@00002P0dLfY0T0000040=7=
Z@900000103AcJT3@00002T0dLfY0T0000040=7=Z@900000103AcJT3@00002T0dLfY0T0000040=7=
Z@9000000`3AcJT4@00002P0dLfY0T0000040=7=Z@900000103AcJT2@00002X0dLfY0T0000040=7=
Z@900000103AcJT3@00001d0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o
0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY000H0=7=Z@<000003`3oool01@000000oooo
0?ooo`3oool000000240dLfY100000050?ooo`D00000103oool500000200dLfY0`000000103oool0
00000000003oool2000000040?ooo`000000000000000080oooo00<000000?ooo`3oool00`3oool2
00000240dLfY0`0000040?ooo`@00000103oool4000000<0oooo00<000000=7=Z@3AcJT07`3AcJT3
00000080oooo1P0000020?ooo`H000000`3oool00`000000dLfY0=7=Z@0N0=7=Z@@0000000<0oooo
0000000000004000000Q0=7=Z@060000003oool000000?ooo`000000oooo0P000000103oool00000
0000000000020?ooo`@000000P3oool300000200dLfY0`0000020?ooo`H000000P3oool6000000<0
oooo00<000000=7=Z@3AcJT0603AcJT001P0dLfY00<0oooo000000000000503ooolQ0=7=Z@030?oo
o`000000oooo00L0oooo0P0000080?ooo`030000003oool0oooo0200dLfY00<0oooo0000003oool0
0P3oool01@000000oooo0?ooo`000000oooo00<0000000P0oooo0000003oool000000?ooo`000000
oooo00000080oooo8@3AcJT00`3oool00000000000040?ooo`@00000103oool4000000@0oooo8@3A
cJT00`3oool00000000000020?ooo`H000000P3oool6000000@0oooo803AcJT0103oool000000000
003oool?000000040?ooo`000000oooo0?ooob40dLfY00H0oooo0000003oool000000?ooo`000002
0?ooo`040000003oool000000?ooo`@000000P3oool300000080oooo803AcJT00`3oool000000000
00020?ooo`H000000P3oool6000000@0oooo6P3AcJT001P0dLfY503oool00`000000oooo0?ooo`0Q
0=7=Z@/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0P0=7=Z@D0oooo00@00000
0?ooo`3oool00000103oool2000000040?ooo`000000oooo0?ooo`8000000P3ooolQ0=7=Z@<0oooo
1P0000020?ooo`H000000P3oool200000080oooo8@3AcJT30?ooo`8000001P3oool2000000H0oooo
0P0000020?ooob00dLfY0`3ooolB00000080oooo8@3AcJT30?ooo`030000003oool000000080oooo
00@000000?ooo`000000oooo100000020?ooo`<000000P3ooolP0=7=Z@<0oooo1P0000020?ooo`H0
00000P3oool200000080oooo6P3AcJT001P0dLfY0`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`3oool0oooo8@3AcJT30?ooo`8000001P3oool2000000H0
oooo00@000000?ooo`3oool0oooo803AcJT30?ooo`80000000<0oooo0000003oool00`3oool01000
0000oooo0000003oool200000080oooo00@000000?ooo`3oool0oooo8@3AcJT30?ooo`H000000P3o
ool600000080oooo00@000000?ooo`3oool0oooo8@3AcJT30?ooo`8000001P3oool2000000H0oooo
00@000000?ooo`3oool0oooo803AcJT30?ooo`80000000<0oooo0000000000000P0000001@3oool0
0000000000000000oooo0080000000<0oooo0000000000000`3ooolQ0=7=Z@<0oooo100000020?oo
o`030000003oool00000008000000P3oool4000000<0oooo803AcJT30?ooo`H000000P3oool60000
0080oooo00@000000?ooo`3oool0oooo6P3AcJT001P0dLfY103oool00`000000oooo0?ooo`0@0?oo
ob40dLfY103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo803AcJT40?oo
o`040000003oool0oooo0?ooo`D0000000<0oooo0000000000001`3ooolQ0=7=Z@@0oooo1@000002
0?ooo`H000001P3ooolQ0=7=Z@@0oooo00<000000?ooo`3oool0103oool2000000X0oooo803AcJT4
0?ooo`D0000000D0oooo00000000000000000?ooo`04000000D0oooo8@3AcJT40?ooo`050000003o
ool000000000003oool00`0000020?ooo`@000001@3ooolP0=7=Z@@0oooo1@0000020?ooo`H00000
1P3ooolJ0=7=Z@00603AcJT50?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000
1@3ooolQ0=7=Z@D0oooo0P0000030?ooo`<0000000D0oooo0000003oool0oooo000000050?ooob00
dLfY1@3oool200000080oooo00D000000?ooo`3oool0oooo000000020?ooo`8000001@3ooolQ0=7=
Z@D0oooo0P0000040?ooo`@000000P3oool00`000000oooo0?ooo`030?ooob40dLfY1@3oool20000
0080oooo1P0000020?ooo`030000003oool0oooo00<0oooo803AcJT50?ooo`8000000P3oool60000
0080oooo00<000000?ooo`3oool00`3ooolQ0=7=Z@D0oooo0`000000103oool00000000000000002
0?ooo`@000001@3ooolP0=7=Z@D0oooo0P0000020?ooo`H000000P3oool00`000000oooo0?ooo`03
0?oooaX0dLfY000H0=7=Z@H0oooo00<000000?ooo`3oool03P3ooolQ0=7=Z@H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`090?ooob00dLfY1P3oool00`000000oooo000000020000
00030?ooo`000000oooo008000001`3ooolQ0=7=Z@H0oooo00<000000?ooo`3oool00P3oool40000
00P0oooo8@3AcJT60?ooo`030000003oool0oooo00H00000203ooolP0=7=Z@H0oooo00<000000?oo
o`0000001P0000080?ooob40dLfY1P3oool01P000000oooo0000003oool000000?ooo`@000001`3o
oolP0=7=Z@H0oooo00<000000?ooo`3oool01P0000080?oooaX0dLfY000H0=7=Z@L0oooo0P000006
0?ooo`030000003oool0oooo00D0oooo8@3AcJT70?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`050?ooob00dLfY1`3oool010000000oooo0000000000040?ooo`030000
003oool0oooo00D0oooo8@3AcJT70?ooo`H000000P3oool00`000000oooo0?ooo`050?ooob40dLfY
1`3oool2000000H0oooo00<000000?ooo`3oool01@3ooolP0=7=Z@L0oooo0P0000020?ooo`800000
0P3oool00`000000oooo0?ooo`050?ooob40dLfY1`3oool2000000030?ooo`000000oooo00@00000
1`3ooolP0=7=Z@L0oooo1P0000020?ooo`030000003oool0oooo00D0oooo6P3AcJT001P0dLfY203o
ool00`000000oooo0?ooo`0<0?ooob40dLfY203oool010000000oooo0?ooo`00000;0?ooob00dLfY
203oool3000000`0oooo8@3AcJT80?ooo`D000002P3ooolQ0=7=Z@P0oooo00<000000?ooo`3oool0
303ooolP0=7=Z@P0oooo00<000000?ooo`0000000P00000:0?ooob40dLfY203oool2000000040?oo
o`0000000000000000T0oooo803AcJT80?ooo`D000002P3ooolJ0=7=Z@00603AcJTG0?ooob40dLfY
2`3oool2000000X0oooo803AcJT:0?ooo`030000003oool0oooo00X0oooo8@3AcJT:0?ooo`<00000
2P3ooolQ0=7=ZAL0oooo803AcJT;0?ooo`8000002P3ooolQ0=7=Z@X0oooo0P00000;0?ooob00dLfY
2P3oool3000000X0oooo6P3AcJT001P0dLfY2P3oool00`000000oooo0?ooo`0:0?ooob40dLfY2P3o
ool2000000/0oooo803AcJT:0?ooo`8000002`3ooolQ0=7=Z@X0oooo00<000000?ooo`3oool02P3o
oolQ0=7=Z@X0oooo00<000000?ooo`3oool02P3ooolP0=7=Z@X0oooo0P00000;0?ooob40dLfY2P3o
ool2000000/0oooo803AcJT:0?ooo`030000003oool0oooo00X0oooo6P3AcJT00?l0dLfYc`3AcJT0
0?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT001`0dLfY1D0000020=7=Z@9000001@3A
cJT3@00002H0dLfY1D0000020=7=Z@900000103AcJT2@00002T0dLfY1D0000020=7=Z@9000000`3A
cJT3@00002P0dLfY1D0000020=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@0W0=7=Z@E000000P3A
cJT2@00000@0dLfY0T00000Y0=7=Z@E000000P3AcJT2@00000<0dLfY0d00000X0=7=Z@E0000000<0
dLfY@000040000000d0000020=7=Z@900000:@3AcJT5@00000030=7=ZD000010000000=0000000<0
dLfY@000040000000d00000L0=7=Z@007P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=0
00000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0W0=7=Z@05@000003AcJT0dLfY0=7=ZD000000
0P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02P0dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT09`3AcJT0
1D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=
Z@0Y0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03
@000003AcJT0dLfY02P0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY
0080dLfY00=000000=7=Z@3AcJT0:03AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY
0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY00<0dLfY00=00000
0=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0L0=7=Z@007P3AcJT01D000000dLfY0=7=Z@3AcJU0
00000080dLfY00=000000=7=Z@3AcJT01D00000X0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3A
cJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY02P0dLfY00E000000=7=Z@3AcJT0dLfY
@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT09`3AcJT01D000000
dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0Y0=7=
Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003A
cJT0dLfY02P0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY0=7=Z@=0
0000:@3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d00
0000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d00
0000dLfY0=7=Z@0L0=7=Z@007P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=
Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0W0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3A
cJT014000000dLfY0=7=Z@3AcJT2@00002/0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03
@000003AcJT0dLfY00=00000:P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=
Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0X0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT0
14000000dLfY0=7=Z@3AcJT2@00002/0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000
003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT09`3AcJT00d000000dLfY0=7=Z@030=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0X0=7=Z@03@000003AcJT0dLfY
00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0L0=7=Z@007P3AcJT01D000000
dLfY0=7=Z@3AcJU000000080dLfY00M000000=7=Z@3AcJT0dLfY@000003AcJU0000002T0dLfY00E0
00000=7=Z@3AcJT0dLfY@00000020=7=Z@05@000003AcJT0dLfY0=7=ZD000000;03AcJT01D000000
dLfY0=7=Z@3AcJU000000080dLfY00E000000=7=Z@3AcJT0dLfY@000000[0=7=Z@05@000003AcJT0
dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02P0dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=
Z@3AcJT0:03AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3A
cJT00d000000dLfY0=7=Z@0W0=7=Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY
@00000020=7=Z@03@000003AcJT0dLfY02P0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY
0=7=Z@030=7=Z@03@000003AcJT0dLfY01`0dLfY000M0=7=Z@900000103AcJT2@00000D0dLfY0T00
000X0=7=Z@900000103AcJT2@00000@0dLfY0d00000Y0=7=Z@900000103AcJT2@00000@0dLfY0d00
000X0=7=Z@900000103AcJT2@00000<0dLfY1400000Y0=7=Z@900000103AcJT2@00000@0dLfY0T00
000Z0=7=Z@900000103AcJT2@00000@0dLfY0d00000X0=7=Z@900000103AcJT2@00000@0dLfY0T00
000Z0=7=Z@900000103AcJT2@00000@0dLfY0T00000N0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=
Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00603AcJT00`00
0000oooo0?ooo`0D0?ooob40dLfY00<000000?ooo`3oool0503ooolP0=7=Z@030000003oool0oooo
008000000P3oool200000080oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@030000003oool0oooo
008000000P3oool200000080oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@030000003oool0oooo
01@0oooo803AcJT00`000000oooo0?ooo`0D0?ooob40dLfY0P0000070?ooo`<000002`3ooolP0=7=
Z@<000000P3oool7000000/0oooo6P3AcJT001P0dLfY00<0oooo0000003oool0503ooolQ0=7=Z@03
0?ooo`000000oooo01@0oooo803AcJT00`3oool000000?ooo`0200000080oooo0P0000020?ooo`03
0000003oool0oooo00T0oooo8@3AcJT00`3oool000000?ooo`0200000080oooo0P0000020?ooo`03
0000003oool0oooo00T0oooo8@3AcJT00`3oool000000?ooo`0D0?ooob00dLfY00<0oooo0000003o
ool0503ooolQ0=7=Z@030?ooo`000000oooo00L0oooo0P00000;0?ooob00dLfY00<0oooo00000000
00000P3oool7000000/0oooo6P3AcJT001P0dLfY5`3ooolQ0=7=ZAL0oooo803AcJT30?ooo`800000
0P3oool200000080oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@<0oooo0P0000020?ooo`800000
0P3oool00`000000oooo0?ooo`090?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJT;0?ooo`030000
003oool0oooo00T0oooo803AcJT30?ooo`H000000P3oool00`000000oooo0?ooo`090?oooaX0dLfY
000H0=7=Z@<0oooo00<000000?ooo`3oool04@3ooolQ0=7=Z@<0oooo00<000000?ooo`3oool04@3o
oolP0=7=Z@<0oooo0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`090?ooob40dLfY0`3o
ool200000080oooo0P0000020?ooo`030000003oool0oooo00T0oooo8@3AcJT30?ooo`030000003o
ool0oooo0140oooo803AcJT30?ooo`030000003oool0oooo0140oooo8@3AcJT30?ooo`8000001P3o
ool00`000000oooo0?ooo`090?ooob00dLfY0`3oool600000080oooo00<000000?ooo`3oool02@3o
oolJ0=7=Z@00603AcJT40?ooo`030000003oool0oooo0100oooo8@3AcJT40?ooo`030000003oool0
oooo0100oooo803AcJT40?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`09
0?ooob40dLfY103oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool02@3ooolQ
0=7=Z@@0oooo00<000000?ooo`3oool0403ooolP0=7=Z@@0oooo00<000000?ooo`3oool0403ooolQ
0=7=Z@@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooob00dLfY103oool5
00000080oooo00<000000?ooo`3oool02@3ooolJ0=7=Z@00603AcJT50?ooo`030000003oool0oooo
00l0oooo8@3AcJT50?ooo`030000003oool0oooo00l0oooo803AcJT50?ooo`040000003oool00000
00000080oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@D0oooo00@000000?ooo`00000000000P3o
ool00`000000oooo0?ooo`090?ooob40dLfY1@3oool00`000000oooo0?ooo`0?0?ooob00dLfY1@3o
ool00`000000oooo0?ooo`0?0?ooob40dLfY1@3oool2000000@0oooo00<000000?ooo`3oool02@3o
oolP0=7=Z@D0oooo0P0000020?ooo`<000002`3ooolJ0=7=Z@00603AcJT60?ooo`030000003oool0
oooo00h0oooo8@3AcJT60?ooo`030000003oool0oooo00h0oooo803AcJT60?ooo`<000000P3oool0
0`000000oooo0?ooo`090?ooob40dLfY1P3oool300000080oooo00<000000?ooo`3oool02@3ooolQ
0=7=Z@H0oooo00<000000?ooo`3oool03P3ooolP0=7=Z@H0oooo00<000000?ooo`3oool03P3ooolQ
0=7=Z@H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooob00dLfY1P3oool0
0`000000oooo0?ooo`03000000/0oooo6P3AcJT001P0dLfY1`3oool00`000000oooo0?ooo`0=0?oo
ob40dLfY1`3oool00`000000oooo0?ooo`0=0?ooob00dLfY1`3oool200000080oooo00<000000?oo
o`3oool02@3ooolQ0=7=Z@L0oooo0P0000020?ooo`030000003oool0oooo00T0oooo8@3AcJT70?oo
o`030000003oool0oooo00d0oooo803AcJT70?ooo`030000003oool0oooo00d0oooo8@3AcJT70?oo
o`8000000P3oool00`000000oooo0?ooo`090?ooob00dLfY1`3oool5000000/0oooo6P3AcJT001P0
dLfY203oool00`000000oooo0?ooo`0<0?ooob40dLfY203oool00`000000oooo0?ooo`0<0?ooob00
dLfY203oool010000000oooo0?ooo`00000;0?ooob40dLfY203oool010000000oooo0?ooo`00000;
0?ooob40dLfY203oool00`000000oooo0?ooo`0<0?ooob00dLfY203oool00`000000oooo0?ooo`0<
0?ooob40dLfY203oool010000000oooo0?ooo`00000;0?ooob00dLfY203oool4000000/0oooo6P3A
cJT001P0dLfY5`3ooolQ0=7=ZAL0oooo803AcJT;0?ooo`030000003oool0oooo00T0oooo8@3AcJT;
0?ooo`030000003oool0oooo00T0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=Z@/0oooo00<00000
0?ooo`3oool02@3ooolP0=7=Z@X0oooo0P00000;0?oooaX0dLfY000H0=7=Z@X0oooo00<000000?oo
o`3oool02P3ooolQ0=7=Z@X0oooo00<000000?ooo`3oool02P3ooolP0=7=Z@X0oooo0P00000;0?oo
ob40dLfY2P3oool2000000/0oooo8@3AcJT:0?ooo`030000003oool0oooo00X0oooo803AcJT:0?oo
o`030000003oool0oooo00X0oooo8@3AcJT:0?ooo`8000002`3ooolP0=7=Z@X0oooo0P00000;0?oo
oaX0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=
ZLl0dLfY000O0=7=Z@=000000`3AcJT3@00002h0dLfY0d0000050=7=Z@03@000003AcJT0dLfY02d0
dLfY0d0000040=7=Z@900000;P3AcJT3@00000<0dLfY0d00000/0=7=Z@E000000P3AcJT2@00000@0
dLfY0T00000Y0=7=Z@E000000P3AcJT2@00000<0dLfY1D00000V0=7=Z@E000000P3AcJT2@00000<0
dLfY1400000X0=7=Z@E000000P3AcJT2@00000@0dLfY0T00000N0=7=Z@008@3AcJT01D000000dLfY
0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0;@3AcJT00d000000dLfY0=7=Z@030=7=Z@03
@000003AcJT0dLfY02l0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY
02d0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0/0=7=Z@05@000003AcJT0dLfY
0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02P0dLfY00E0
00000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0
:03AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU00000;@3AcJT01D00
0000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=
Z@0K0=7=Z@00803AcJT3@0000080dLfY00A000000=7=Z@3AcJU00000;P3AcJT3@00000@0dLfY00=0
00000=7=Z@3AcJT0;P3AcJT3@0000080dLfY00A000000=7=Z@3AcJU00000;P3AcJT3@00000<0dLfY
0d00000]0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=
Z@03@000003AcJT0dLfY02P0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0
dLfY0080dLfY00=000000=7=Z@3AcJT0:03AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00E0
00000=7=Z@3AcJT0dLfY@000000/0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000
dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY01`0dLfY000O0=7=Z@04@000003AcJT0dLfY@0000080
dLfY0d00000^0=7=Z@04@000003AcJT0dLfY@00000D0dLfY00=000000=7=Z@3AcJT0;03AcJT01400
0000dLfY0=7=ZD0000030=7=Z@900000;P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003A
cJT0dLfY@00002d0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@000
0080dLfY00=000000=7=Z@3AcJT0:03AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=00000
0=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0X0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3A
cJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY02T0dLfY00E000000=7=Z@3AcJT0dLfY
@00000020=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT06`3AcJT001l0dLfY00A0
00000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@0]0=7=Z@04@000003AcJT0dLfY@0000080
dLfY00A000000=7=Z@3AcJU00000;P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0
dLfY@00002d0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000]0=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0
dLfY02P0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00=0
00000=7=Z@3AcJT0:03AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU0
00000P3AcJT00d000000dLfY0=7=Z@0X0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY01/0dLfY000P0=7=Z@=000000`3AcJT3@000
02h0dLfY0d0000020=7=Z@A00000;`3AcJT3@00000<0dLfY0T00000_0=7=Z@=000000`3AcJT3@000
02`0dLfY0T0000040=7=Z@900000103AcJT2@00002X0dLfY0T0000040=7=Z@900000103AcJT2@000
02T0dLfY0T0000040=7=Z@900000103AcJT2@00002X0dLfY0T0000040=7=Z@900000103AcJT2@000
01h0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=
ZLl0dLfY003o0=7=ZLl0dLfY000H0=7=Z@030?ooo`000000000000l0oooo00D000000?ooo`3oool0
oooo0000000Q0=7=Z@030?ooo`000000000000l0oooo00D000000?ooo`3oool0oooo0000000P0=7=
Z@030?ooo`000000000000l0oooo00D000000?ooo`3oool0oooo0000000Q0=7=Z@030?ooo`000000
000000l0oooo00D000000?ooo`3oool0oooo0000000Q0=7=Z@030?ooo`00000000000080oooo0P00
00020?ooo`8000000P3oool200000080oooo0P0000030?ooo`030000003AcJT0dLfY01h0dLfY00<0
oooo0000000000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2000000<0oooo00<0
00000=7=Z@3AcJT07`3AcJT00`3oool00000000000020?ooo`8000000P3oool200000080oooo0P00
00020?ooo`8000000`3oool00`000000dLfY0=7=Z@0N0=7=Z@030?ooo`00000000000080oooo0P00
00020?ooo`8000000P3oool200000080oooo0P0000030?ooo`030000003AcJT0dLfY01P0dLfY000H
0=7=Z@030?ooo`000000000001@0oooo8@3AcJT00`3oool000000000000D0?ooob00dLfY00<0oooo
000000000000503ooolQ0=7=Z@030?ooo`000000000001@0oooo8@3AcJT00`3oool0000000000002
0?ooo`8000000P3oool200000080oooo0P0000020?ooo`800000103ooolP0=7=Z@030?ooo`000000
00000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000040?ooob40dLfY00<0oooo
0000000000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2000000@0oooo803AcJT0
0`3oool00000000000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`800000103ooolJ
0=7=Z@00603AcJTD0?ooo`030000003oool0oooo0240dLfY503oool00`000000oooo0?ooo`0P0=7=
ZA@0oooo00<000000?ooo`3oool08@3AcJTD0?ooo`030000003oool0oooo0240dLfY0`3oool20000
0080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooob00dLfY0`3oool20000
0080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooob40dLfY0`3oool20000
0080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooob00dLfY0`3oool20000
0080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?oooaX0dLfY000H0=7=Z@<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?oo
ob40dLfY0`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00@000000?oo
o`3oool0oooo803AcJT30?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
10000000oooo0?ooo`3ooolQ0=7=Z@<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`040?ooo`040000003oool0oooo0?ooob40dLfY0`3oool200000080oooo0P0000020?ooo`800000
0P3oool200000080oooo00@000000?ooo`3oool0oooo803AcJT30?ooo`8000000P3oool200000080
oooo0P0000020?ooo`8000000P3oool010000000oooo0?ooo`3ooolQ0=7=Z@<0oooo0P0000020?oo
o`8000000P3oool200000080oooo0P0000020?ooo`040000003oool0oooo0?ooob00dLfY0`3oool2
00000080oooo0P0000020?ooo`8000000P3oool200000080oooo00@000000?ooo`3oool0oooo6P3A
cJT001P0dLfY103oool00`000000oooo0?ooo`0@0?ooob40dLfY103oool00`000000oooo0?ooo`0@
0?ooob00dLfY103oool00`000000oooo0?ooo`0@0?ooob40dLfY103oool00`000000oooo0?ooo`0@
0?ooob40dLfY103oool00`000000oooo0?ooo`0200000080oooo0P0000020?ooo`8000001P3ooolP
0=7=Z@@0oooo00<000000?ooo`3oool00P0000020?ooo`8000000P3oool2000000H0oooo8@3AcJT4
0?ooo`030000003oool0oooo008000000P3oool200000080oooo0P0000060?ooob00dLfY103oool0
0`000000oooo0?ooo`0200000080oooo0P0000020?ooo`8000001P3ooolJ0=7=Z@00603AcJT50?oo
o`030000003oool0oooo00H0oooo00@000000?ooo`3oool000001@3ooolQ0=7=Z@D0oooo00<00000
0?ooo`3oool01P3oool010000000oooo0?ooo`0000050?ooob00dLfY1@3oool00`000000oooo0?oo
o`060?ooo`040000003oool0oooo000000D0oooo8@3AcJT50?ooo`030000003oool0oooo00H0oooo
00@000000?ooo`3oool000001@3ooolQ0=7=Z@D0oooo0P0000020?ooo`8000000P3oool200000080
oooo00<000000?ooo`3oool00`3ooolP0=7=Z@D0oooo0P0000020?ooo`8000000P3oool200000080
oooo00<000000?ooo`3oool00`3ooolQ0=7=Z@D0oooo0P0000020?ooo`8000000P3oool200000080
oooo00<000000?ooo`3oool00`3ooolP0=7=Z@D0oooo0P0000020?ooo`8000000P3oool200000080
oooo00<000000?ooo`3oool00`3ooolJ0=7=Z@00603AcJT60?ooo`030000003oool0oooo00h0oooo
8@3AcJT60?ooo`030000003oool0oooo00h0oooo803AcJT60?ooo`030000003oool0oooo00h0oooo
8@3AcJT60?ooo`030000003oool0oooo00h0oooo8@3AcJT60?ooo`030000003oool0oooo00800000
0P3oool2000000P0oooo803AcJT60?ooo`030000003oool0oooo008000000P3oool2000000P0oooo
8@3AcJT60?ooo`030000003oool0oooo008000000P3oool2000000P0oooo803AcJT60?ooo`030000
003oool0oooo008000000P3oool2000000P0oooo6P3AcJT001P0dLfY1`3oool2000000H0oooo00<0
00000?ooo`3oool01@3ooolQ0=7=Z@L0oooo0P0000060?ooo`030000003oool0oooo00D0oooo803A
cJT70?ooo`8000001P3oool00`000000oooo0?ooo`050?ooob40dLfY1`3oool2000000H0oooo00<0
00000?ooo`3oool01@3ooolQ0=7=Z@L0oooo0P0000020?ooo`8000000P3oool00`000000oooo0?oo
o`050?ooob00dLfY1`3oool200000080oooo0P0000020?ooo`030000003oool0oooo00D0oooo8@3A
cJT70?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool01@3ooolP0=7=Z@L0oooo0P00
00020?ooo`8000000P3oool00`000000oooo0?ooo`050?oooaX0dLfY000H0=7=Z@P0oooo00<00000
0?ooo`3oool0303ooolQ0=7=Z@P0oooo00<000000?ooo`3oool0303ooolP0=7=Z@P0oooo00<00000
0?ooo`3oool0303ooolQ0=7=Z@P0oooo00<000000?ooo`3oool0303ooolQ0=7=Z@P0oooo00<00000
0?ooo`3oool00P00000:0?ooob00dLfY203oool00`000000oooo0?ooo`02000000X0oooo8@3AcJT8
0?ooo`030000003oool0oooo008000002P3ooolP0=7=Z@P0oooo00<000000?ooo`3oool00P00000:
0?oooaX0dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo8@3AcJT;0?oo
o`8000002P3ooolP0=7=Z@/0oooo0P00000:0?ooob40dLfY2`3oool2000000X0oooo803AcJT;0?oo
o`8000002P3ooolJ0=7=Z@00603AcJT:0?ooo`030000003oool0oooo00X0oooo8@3AcJT:0?ooo`03
0000003oool0oooo00X0oooo803AcJT:0?ooo`030000003oool0oooo00X0oooo8@3AcJT:0?ooo`03
0000003oool0oooo00X0oooo8@3AcJT:0?ooo`030000003oool0oooo00X0oooo803AcJT:0?ooo`03
0000003oool0oooo00X0oooo8@3AcJT:0?ooo`030000003oool0oooo00X0oooo803AcJT:0?ooo`03
0000003oool0oooo00X0oooo6P3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT0
0?l0dLfYc`3AcJT00200dLfY0T0000040=7=Z@900000;`3AcJT2@00000<0dLfY0d00000_0=7=Z@=0
0000103AcJT2@00002h0dLfY0d0000030=7=Z@E00000;@3AcJT3@00000<0dLfY1400000^0=7=Z@=0
0000103AcJT2@00002h0dLfY0d0000050=7=Z@=00000;@3AcJT3@00000@0dLfY0T00000Q0=7=Z@00
7`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00002d0dLfY00A000000=7=
Z@3AcJU00000103AcJT00d000000dLfY0=7=Z@0_0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3A
cJT00d000000dLfY0=7=Z@0]0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0;`3A
cJT01D000000dLfY0=7=Z@3AcJU0000003<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03
@000003AcJT0dLfY02d0dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@0^0=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0N0=7=Z@007`3AcJT014000000
dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00002d0dLfY00A000000=7=Z@3AcJU000000`3A
cJT3@00002l0dLfY0d0000020=7=Z@04@000003AcJT0dLfY@00002h0dLfY0d0000040=7=Z@03@000
003AcJT0dLfY02h0dLfY0d0000030=7=Z@03@000003AcJT0dLfY02l0dLfY0d0000040=7=Z@03@000
003AcJT0dLfY02d0dLfY0d0000020=7=Z@E00000;P3AcJT3@00000D0dLfY00=000000=7=Z@3AcJT0
7P3AcJT00200dLfY0T0000040=7=Z@900000;`3AcJT2@00000<0dLfY00A000000=7=Z@3AcJU00000
;P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00002d0dLfY00A000000=7=
Z@3AcJU00000103AcJT00d000000dLfY0=7=Z@0]0=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=0
00000=7=Z@3AcJT0;@3AcJT014000000dLfY0=7=ZD0000050=7=Z@03@000003AcJT0dLfY02/0dLfY
00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000^0=7=Z@04@000003AcJT0dLfY
@00000<0dLfY0T00000Q0=7=Z@007`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0
dLfY@00002d0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000^0=7=Z@04
@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000;@3AcJT014000000dLfY0=7=ZD00
00040=7=Z@03@000003AcJT0dLfY02d0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD00000^0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000;@3AcJT0
14000000dLfY0=7=ZD0000030=7=Z@03@000003AcJU0000002h0dLfY00A000000=7=Z@3AcJU00000
0`3AcJT00d000000dLfY0=7=Z@0P0=7=Z@00803AcJT2@00000@0dLfY0T00000_0=7=Z@900000103A
cJT3@00002l0dLfY0d0000030=7=Z@900000;`3AcJT3@00000<0dLfY0T00000`0=7=Z@=000000`3A
cJT2@0000300dLfY0d0000030=7=Z@900000;`3AcJT3@00000@0dLfY0T00000_0=7=Z@=000000`3A
cJT3@0000200dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY
003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=
ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTG0?oooaX0dLfY000H0=7=Z@03
0?ooo`000000oooo01@0oooo8@3AcJT00`3oool000000?ooo`0D0?ooob00dLfY00<0oooo0000003o
ool0503ooolQ0=7=Z@030?ooo`000000oooo01@0oooo8@3AcJT00`3oool000000?ooo`0D0?ooob00
dLfY00<0oooo0000003oool0503ooolQ0=7=Z@030?ooo`000000oooo01@0oooo803AcJT00`3oool0
00000?ooo`0D0?oooaX0dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo
8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTG0?oooaX0dLfY000H0=7=Z@<0oooo00<0
00000?ooo`3oool04@3ooolQ0=7=Z@<0oooo00<000000?ooo`3oool04@3ooolP0=7=Z@<0oooo00<0
00000?ooo`3oool04@3ooolQ0=7=Z@<0oooo00<000000?ooo`3oool04@3ooolQ0=7=Z@<0oooo00<0
00000?ooo`3oool04@3ooolP0=7=Z@<0oooo00<000000?ooo`3oool04@3ooolQ0=7=Z@<0oooo00<0
00000?ooo`3oool04@3ooolP0=7=Z@<0oooo00<000000?ooo`3oool04@3ooolJ0=7=Z@00603AcJT4
0?ooo`030000003oool0oooo0100oooo8@3AcJT40?ooo`030000003oool0oooo0100oooo803AcJT4
0?ooo`030000003oool0oooo0100oooo8@3AcJT40?ooo`030000003oool0oooo0100oooo8@3AcJT4
0?ooo`030000003oool0oooo0100oooo803AcJT40?ooo`030000003oool0oooo0100oooo8@3AcJT4
0?ooo`030000003oool0oooo0100oooo803AcJT40?ooo`030000003oool0oooo0100oooo6P3AcJT0
01P0dLfY1@3oool00`000000oooo0?ooo`0?0?ooob40dLfY1@3oool00`000000oooo0?ooo`0?0?oo
ob00dLfY1@3oool00`000000oooo0?ooo`0?0?ooob40dLfY1@3oool00`000000oooo0?ooo`0?0?oo
ob40dLfY1@3oool00`000000oooo0?ooo`0?0?ooob00dLfY1@3oool00`000000oooo0?ooo`0?0?oo
ob40dLfY1@3oool00`000000oooo0?ooo`0?0?ooob00dLfY1@3oool00`000000oooo0?ooo`0?0?oo
oaX0dLfY000H0=7=Z@H0oooo00<000000?ooo`3oool03P3ooolQ0=7=Z@H0oooo00<000000?ooo`3o
ool03P3ooolP0=7=Z@H0oooo00<000000?ooo`3oool03P3ooolQ0=7=Z@H0oooo00<000000?ooo`3o
ool03P3ooolQ0=7=Z@H0oooo00<000000?ooo`3oool03P3ooolP0=7=Z@H0oooo00<000000?ooo`3o
ool03P3ooolQ0=7=Z@H0oooo00<000000?ooo`3oool03P3ooolP0=7=Z@H0oooo00<000000?ooo`3o
ool03P3ooolJ0=7=Z@00603AcJT70?ooo`030000003oool0oooo00d0oooo8@3AcJT70?ooo`030000
003oool0oooo00d0oooo803AcJT70?ooo`030000003oool0oooo00d0oooo8@3AcJT70?ooo`030000
003oool0oooo00d0oooo8@3AcJT70?ooo`030000003oool0oooo00d0oooo803AcJT70?ooo`030000
003oool0oooo00d0oooo8@3AcJT70?ooo`030000003oool0oooo00d0oooo803AcJT70?ooo`030000
003oool0oooo00d0oooo6P3AcJT001P0dLfY203oool00`000000oooo0?ooo`0<0?ooob40dLfY203o
ool00`000000oooo0?ooo`0<0?ooob00dLfY203oool00`000000oooo0?ooo`0<0?ooob40dLfY203o
ool00`000000oooo0?ooo`0<0?ooob40dLfY203oool00`000000oooo0?ooo`0<0?ooob00dLfY203o
ool00`000000oooo0?ooo`0<0?ooob40dLfY203oool00`000000oooo0?ooo`0<0?ooob00dLfY203o
ool00`000000oooo0?ooo`0<0?oooaX0dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ
0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTG0?oooaX0dLfY000H0=7=
Z@X0oooo00<000000?ooo`3oool02P3ooolQ0=7=Z@X0oooo00<000000?ooo`3oool02P3ooolP0=7=
Z@X0oooo00<000000?ooo`3oool02P3ooolQ0=7=Z@X0oooo00<000000?ooo`3oool02P3ooolQ0=7=
Z@X0oooo00<000000?ooo`3oool02P3ooolP0=7=Z@X0oooo00<000000?ooo`3oool02P3ooolQ0=7=
Z@X0oooo00<000000?ooo`3oool02P3ooolP0=7=Z@X0oooo00<000000?ooo`3oool02P3ooolJ0=7=
Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=
Z@00803AcJT2@00000@0dLfY0T00000_0=7=Z@9000000`3AcJT5@00002h0dLfY0T0000030=7=Z@A0
0000;P3AcJT2@00000@0dLfY0T00000`0=7=Z@9000001@3AcJT3@00002h0dLfY0T0000040=7=Z@90
0000;`3AcJT2@00000<0dLfY0d00000`0=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@0O0=7=Z@00
7`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00002d0dLfY00A000000=7=
Z@3AcJU00000103AcJT00d000000dLfY0=7=Z@0]0=7=Z@04@000003AcJT0dLfY@0000080dLfY00=0
00000=7=Z@3AcJT0;P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00002h0
dLfY00A000000=7=Z@3AcJU000001@3AcJT00d000000dLfY0=7=Z@0/0=7=Z@04@000003AcJT0dLfY
@0000080dLfY00A000000=7=Z@3AcJU00000;@3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000
003AcJT0dLfY@00002h0dLfY00A000000=7=Z@3AcJU00000103AcJT00d000000dLfY0=7=Z@0O0=7=
Z@007`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00002d0dLfY00A00000
0=7=Z@3AcJU00000103AcJT00d000000dLfY0=7=Z@0]0=7=Z@04@000003AcJT0dLfY@00000<0dLfY
00=000000=7=Z@3AcJT0;@3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY02d0
dLfY00A000000=7=Z@3AcJU000000P3AcJT5@00002d0dLfY00A000000=7=Z@3AcJU000001@3AcJT0
0d000000dLfY0=7=Z@0[0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000
;P3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY01l0dLfY000P0=7=Z@900000
0`3AcJT014000000dLfY0=7=ZD00000^0=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@0^0=7=Z@90
00001@3AcJT00d000000dLfY0=7=Z@0]0=7=Z@9000001P3AcJT00d000000dLfY0=7=Z@0]0=7=Z@90
00000`3AcJT014000000dLfY0=7=ZD00000_0=7=Z@900000103AcJT2@00002l0dLfY0T0000030=7=
Z@=00000<03AcJT2@00000H0dLfY00=000000=7=Z@3AcJT07P3AcJT001l0dLfY00A000000=7=Z@3A
cJU000000P3AcJT014000000dLfY0=7=ZD00000]0=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=0
00000=7=Z@3AcJT0;@3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00002d0
dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000^0=7=Z@04@000003AcJT0
dLfY@00000<0dLfY00=000000=7=ZD000000;P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000
003AcJT0dLfY02d0dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@0^0=7=Z@04
@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000803AcJT00200dLfY0T0000040=7=
Z@900000;`3AcJT2@00000@0dLfY0T00000`0=7=Z@900000103AcJT2@00002l0dLfY0T0000040=7=
Z@900000<03AcJT2@00000D0dLfY0T00000_0=7=Z@900000103AcJT3@00002h0dLfY0T0000040=7=
Z@=00000;`3AcJT2@00000<0dLfY1400000P0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3A
cJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00603AcJT00`3oool000000000000?0?ooo`05
0000003oool0oooo0?ooo`0000008@3AcJT00`3oool000000000000?0?ooo`050000003oool0oooo
0?ooo`000000803AcJT00`3oool000000000000?0?ooo`050000003oool0oooo0?ooo`0000008@3A
cJT00`3oool000000000000?0?ooo`050000003oool0oooo0?ooo`0000008@3AcJT00`3oool00000
000000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000`3oool00`000000dLfY
0=7=Z@0N0=7=Z@030?ooo`00000000000080oooo0P0000020?ooo`8000000P3oool200000080oooo
0P0000030?ooo`030000003AcJT0dLfY01l0dLfY00<0oooo0000000000000P3oool200000080oooo
0P0000020?ooo`8000000P3oool2000000<0oooo00<000000=7=Z@3AcJT07P3AcJT00`3oool00000
000000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000`3oool00`000000dLfY
0=7=Z@0H0=7=Z@00603AcJT30?ooo`030000003oool0oooo00d0oooo00@000000?ooo`000000oooo
8@3AcJT30?ooo`030000003oool0oooo00d0oooo00@000000?ooo`000000oooo803AcJT30?ooo`03
0000003oool0oooo00d0oooo00@000000?ooo`000000oooo8@3AcJT30?ooo`030000003oool0oooo
00d0oooo00@000000?ooo`000000oooo8@3AcJT30?ooo`8000000P3oool200000080oooo0P000002
0?ooo`8000000P3oool3000000030?ooo`3AcJT0dLfY01h0dLfY0`3oool200000080oooo0P000002
0?ooo`8000000P3oool200000080oooo0`0000000`3oool0dLfY0=7=Z@0O0=7=Z@<0oooo0P000002
0?ooo`8000000P3oool200000080oooo0P0000020?ooo`<0000000<0oooo0=7=Z@3AcJT07P3AcJT3
0?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool3000000030?ooo`3AcJT0
dLfY01P0dLfY000H0=7=ZA@0oooo00<000000?ooo`3oool08@3AcJTD0?ooo`030000003oool0oooo
0200dLfY503oool00`000000oooo0?ooo`0Q0=7=ZA@0oooo00<000000?ooo`3oool08@3AcJT30?oo
o`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo803AcJT30?oo
o`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo8@3AcJT30?oo
o`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo803AcJT30?oo
o`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo6P3AcJT001P0
dLfY1@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`030?ooob40dLfY1@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooob00dLfY1@3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooob40dLfY1@3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooob40dLfY1@3oool200000080oooo0P0000020?ooo`8000000P3oool2000000@0oooo
803AcJT50?ooo`8000000P3oool200000080oooo0P0000020?ooo`800000103ooolQ0=7=Z@D0oooo
0P0000020?ooo`8000000P3oool200000080oooo0P0000040?ooob00dLfY1@3oool200000080oooo
0P0000020?ooo`8000000P3oool2000000@0oooo6P3AcJT001P0dLfY203oool00`000000oooo0?oo
o`0<0?ooob40dLfY203oool00`000000oooo0?ooo`0<0?ooob00dLfY203oool00`000000oooo0?oo
o`0<0?ooob40dLfY203oool00`000000oooo0?ooo`0<0?ooob40dLfY103oool00`000000oooo0?oo
o`0200000080oooo0P0000020?ooo`8000001P3ooolP0=7=Z@@0oooo00<000000?ooo`3oool00P00
00020?ooo`8000000P3oool2000000H0oooo8@3AcJT40?ooo`030000003oool0oooo008000000P3o
ool200000080oooo0P0000060?ooob00dLfY103oool00`000000oooo0?ooo`0200000080oooo0P00
00020?ooo`8000001P3ooolJ0=7=Z@00603AcJT70?ooo`8000001P3oool2000000H0oooo8@3AcJT7
0?ooo`8000001P3oool2000000H0oooo803AcJT70?ooo`8000001P3oool2000000H0oooo8@3AcJT7
0?ooo`8000001P3oool2000000H0oooo8@3AcJT70?ooo`8000000P3oool200000080oooo0P000006
0?ooob00dLfY1`3oool200000080oooo0P0000020?ooo`8000001P3ooolQ0=7=Z@L0oooo0P000002
0?ooo`8000000P3oool2000000H0oooo803AcJT70?ooo`8000000P3oool200000080oooo0P000006
0?oooaX0dLfY000H0=7=Z@H0oooo00<000000?ooo`3oool03P3ooolQ0=7=Z@H0oooo00<000000?oo
o`3oool03P3ooolP0=7=Z@H0oooo00<000000?ooo`3oool03P3ooolQ0=7=Z@H0oooo00<000000?oo
o`3oool03P3ooolQ0=7=Z@H0oooo00<000000?ooo`3oool00P0000020?ooo`800000203ooolP0=7=
Z@H0oooo00<000000?ooo`3oool00P0000020?ooo`800000203ooolQ0=7=Z@H0oooo00<000000?oo
o`3oool00P0000020?ooo`800000203ooolP0=7=Z@H0oooo00<000000?ooo`3oool00P0000020?oo
o`800000203ooolJ0=7=Z@00603AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG0?ooob40
dLfY1`3oool200000080oooo0P0000020?ooo`030000003oool0oooo00D0oooo803AcJT70?ooo`80
00000P3oool200000080oooo00<000000?ooo`3oool01@3ooolQ0=7=Z@L0oooo0P0000020?ooo`80
00000P3oool00`000000oooo0?ooo`050?ooob00dLfY1`3oool200000080oooo0P0000020?ooo`03
0000003oool0oooo00D0oooo6P3AcJT001P0dLfY303oool00`000000oooo0?ooo`080?ooob40dLfY
303oool00`000000oooo0?ooo`080?ooob00dLfY303oool00`000000oooo0?ooo`080?ooob40dLfY
303oool00`000000oooo0?ooo`080?ooob40dLfY203oool00`000000oooo0?ooo`02000000X0oooo
803AcJT80?ooo`030000003oool0oooo008000002P3ooolQ0=7=Z@P0oooo00<000000?ooo`3oool0
0P00000:0?ooob00dLfY203oool00`000000oooo0?ooo`02000000X0oooo6P3AcJT001P0dLfY2@3o
ool01@000000oooo0?ooo`3oool0000000T0oooo8@3AcJT90?ooo`050000003oool0oooo0?ooo`00
00002@3ooolP0=7=Z@T0oooo00D000000?ooo`3oool0oooo000000090?ooob40dLfY2@3oool01@00
0000oooo0?ooo`3oool0000000T0oooo8@3AcJT90?ooo`8000000P3oool00`000000oooo0?ooo`07
0?ooob00dLfY2@3oool200000080oooo00<000000?ooo`3oool01`3ooolQ0=7=Z@T0oooo0P000002
0?ooo`030000003oool0oooo00L0oooo803AcJT90?ooo`8000000P3oool00`000000oooo0?ooo`07
0?oooaX0dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo8@3AcJT;0?oo
o`8000002P3ooolP0=7=Z@/0oooo0P00000:0?ooob40dLfY2`3oool2000000X0oooo803AcJT;0?oo
o`8000002P3ooolJ0=7=Z@00603AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG0?ooob40
dLfY2`3oool00`000000oooo0?ooo`090?ooob00dLfY2`3oool00`000000oooo0?ooo`090?ooob40
dLfY2`3oool00`000000oooo0?ooo`090?ooob00dLfY2`3oool00`000000oooo0?ooo`090?oooaX0
dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY000Q0=7=Z@04
@000003AcJT0dLfY0=7=Z@A00000;`3AcJT00d000000dLfY0=7=Z@020=7=Z@900000<@3AcJT00d00
0000dLfY0=7=Z@030=7=Z@=00000;P3AcJT00d000000dLfY0=7=Z@020=7=Z@900000<@3AcJT01400
0000dLfY0=7=Z@3AcJT3@0000340dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0^
0=7=Z@03@000003AcJT0dLfY0080dLfY0T00000a0=7=Z@04@000003AcJT0dLfY0=7=Z@=000008@3A
cJT00240dLfY00E000000=7=Z@3AcJT0dLfY@000000b0=7=Z@05@000003AcJT0dLfY0=7=ZD000000
0P3AcJT00d000000dLfY0=7=Z@0^0=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT0
;@3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0;P3AcJT01D000000
dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0;P3AcJT00d000000dLfY0=7=Z@030=7=
Z@03@000003AcJT0dLfY02h0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0
dLfY02h0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0O0=7=Z@008@3AcJT00d00
0000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY02l0dLfY00=000000=7=Z@3AcJT00`3AcJT00d00
0000dLfY0=7=Z@0_0=7=Z@04@000003AcJT0dLfY0=7=Z@E00000;P3AcJT00d000000dLfY0=7=Z@04
0=7=Z@03@000003AcJT0dLfY02h0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003A
cJT0dLfY02h0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0^0=7=Z@05@000003A
cJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0^0=7=Z@03@000003AcJT0dLfY0080dLfY
0d00000P0=7=Z@008P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY02l0dLfY00=0
00000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0_0=7=Z@04@000003AcJT0dLfY@0000080dLfY
00=000000=7=Z@3AcJT0;P3AcJT014000000dLfY0=7=Z@3AcJT2@0000380dLfY00=000000=7=Z@3A
cJT00d00000b0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0;P3AcJT014000000
dLfY0=7=Z@3AcJT2@0000380dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0N
0=7=Z@007`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00002d0dLfY00A0
00000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000^0=7=Z@04@000003AcJT0dLfY@000
00<0dLfY00=000000=7=ZD000000;@3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0
dLfY02h0dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@0^0=7=Z@04@000003A
cJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000;@3AcJT014000000dLfY0=7=ZD0000020=7=
Z@04@000003AcJT0dLfY@00002h0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=
ZD00000P0=7=Z@007`3AcJT4@00000<0dLfY0T00000^0=7=Z@A000000`3AcJT2@00002l0dLfY1400
00040=7=Z@900000;@3AcJT4@00000<0dLfY0d00000^0=7=Z@A000000`3AcJT3@00002h0dLfY1400
00020=7=Z@A00000;@3AcJT4@00000<0dLfY0T00000_0=7=Z@A000000`3AcJT3@0000200dLfY003o
0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o
0=7=ZLl0dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo8@3AcJTG0?oo
ob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTG0?oooaX0dLfY000H0=7=Z@030?ooo`000000oooo01@0
oooo8@3AcJT00`3oool000000?ooo`0D0?ooob00dLfY00<0oooo0000003oool0503ooolQ0=7=Z@03
0?ooo`000000oooo01@0oooo8@3AcJT00`3oool000000?ooo`0D0?ooob00dLfY00<0oooo0000003o
ool0503ooolQ0=7=Z@030?ooo`000000oooo01@0oooo803AcJT00`3oool000000?ooo`0D0?oooaX0
dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY
5`3ooolQ0=7=ZAL0oooo803AcJTG0?oooaX0dLfY000H0=7=Z@<0oooo00<000000?ooo`3oool04@3o
oolQ0=7=Z@<0oooo00<000000?ooo`3oool04@3ooolP0=7=Z@<0oooo00<000000?ooo`3oool04@3o
oolQ0=7=Z@<0oooo00<000000?ooo`3oool04@3ooolQ0=7=Z@<0oooo00<000000?ooo`3oool04@3o
oolP0=7=Z@<0oooo00<000000?ooo`3oool04@3ooolQ0=7=Z@<0oooo00<000000?ooo`3oool04@3o
oolP0=7=Z@<0oooo00<000000?ooo`3oool04@3ooolJ0=7=Z@00603AcJT40?ooo`030000003oool0
oooo0100oooo8@3AcJT40?ooo`030000003oool0oooo0100oooo803AcJT40?ooo`030000003oool0
oooo0100oooo8@3AcJT40?ooo`030000003oool0oooo0100oooo8@3AcJT40?ooo`030000003oool0
oooo0100oooo803AcJT40?ooo`030000003oool0oooo0100oooo8@3AcJT40?ooo`030000003oool0
oooo0100oooo803AcJT40?ooo`030000003oool0oooo0100oooo6P3AcJT001P0dLfY1@3oool00`00
0000oooo0?ooo`0?0?ooob40dLfY1@3oool00`000000oooo0?ooo`0?0?ooob00dLfY1@3oool00`00
0000oooo0?ooo`0?0?ooob40dLfY1@3oool00`000000oooo0?ooo`0?0?ooob40dLfY1@3oool00`00
0000oooo0?ooo`0?0?ooob00dLfY1@3oool00`000000oooo0?ooo`0?0?ooob40dLfY1@3oool00`00
0000oooo0?ooo`0?0?ooob00dLfY1@3oool00`000000oooo0?ooo`0?0?oooaX0dLfY000H0=7=Z@H0
oooo00<000000?ooo`3oool03P3ooolQ0=7=Z@H0oooo00<000000?ooo`3oool03P3ooolP0=7=Z@H0
oooo00<000000?ooo`3oool03P3ooolQ0=7=Z@H0oooo00<000000?ooo`3oool03P3ooolQ0=7=Z@H0
oooo00<000000?ooo`3oool03P3ooolP0=7=Z@H0oooo00<000000?ooo`3oool03P3ooolQ0=7=Z@H0
oooo00<000000?ooo`3oool03P3ooolP0=7=Z@H0oooo00<000000?ooo`3oool03P3ooolJ0=7=Z@00
603AcJT70?ooo`030000003oool0oooo00d0oooo8@3AcJT70?ooo`030000003oool0oooo00d0oooo
803AcJT70?ooo`030000003oool0oooo00d0oooo8@3AcJT70?ooo`030000003oool0oooo00d0oooo
8@3AcJT70?ooo`030000003oool0oooo00d0oooo803AcJT70?ooo`030000003oool0oooo00d0oooo
8@3AcJT70?ooo`030000003oool0oooo00d0oooo803AcJT70?ooo`030000003oool0oooo00d0oooo
6P3AcJT001P0dLfY203oool00`000000oooo0?ooo`0<0?ooob40dLfY203oool00`000000oooo0?oo
o`0<0?ooob00dLfY203oool00`000000oooo0?ooo`0<0?ooob40dLfY203oool00`000000oooo0?oo
o`0<0?ooob40dLfY203oool00`000000oooo0?ooo`0<0?ooob00dLfY203oool00`000000oooo0?oo
o`0<0?ooob40dLfY203oool00`000000oooo0?ooo`0<0?ooob00dLfY203oool00`000000oooo0?oo
o`0<0?oooaX0dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo8@3AcJTG
0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTG0?oooaX0dLfY000H0=7=Z@X0oooo00<000000?oo
o`3oool02P3ooolQ0=7=Z@X0oooo00<000000?ooo`3oool02P3ooolP0=7=Z@X0oooo00<000000?oo
o`3oool02P3ooolQ0=7=Z@X0oooo00<000000?ooo`3oool02P3ooolQ0=7=Z@X0oooo00<000000?oo
o`3oool02P3ooolP0=7=Z@X0oooo00<000000?ooo`3oool02P3ooolQ0=7=Z@X0oooo00<000000?oo
o`3oool02P3ooolP0=7=Z@X0oooo00<000000?ooo`3oool02P3ooolJ0=7=Z@00o`3AcJW?0=7=Z@00
o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@007`3AcJT3@00000D0
dLfY0d00000/0=7=Z@=00000103AcJT2@00002l0dLfY0d0000030=7=Z@=00000;P3AcJT3@00000D0
dLfY00=000000=7=Z@3AcJT0;@3AcJT3@00000@0dLfY0T00000_0=7=Z@=000000`3AcJT3@0000300
dLfY00=000000=7=Z@3AcJT00P3AcJT2@0000340dLfY00A000000=7=Z@3AcJT0dLfY1D00000O0=7=
Z@007`3AcJT014000000dLfY0=7=ZD0000050=7=Z@03@000003AcJT0dLfY02/0dLfY00A000000=7=
Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000^0=7=Z@04@000003AcJT0dLfY@0000080dLfY
00A000000=7=Z@3AcJU00000;@3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY
02d0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000^0=7=Z@04@000003A
cJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT0;P3AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00=000000=7=Z@3AcJT0;P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY01l0
dLfY000O0=7=Z@04@000003AcJT0dLfY@0000080dLfY1D00000/0=7=Z@04@000003AcJT0dLfY@000
00D0dLfY00=000000=7=Z@3AcJT0;03AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0
dLfY@00002d0dLfY00A000000=7=Z@3AcJU00000103AcJT00d000000dLfY0=7=Z@0]0=7=Z@04@000
003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000;P3AcJT014000000dLfY0=7=ZD000003
0=7=Z@=00000;`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0;P3A
cJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY01l0dLfY000O0=7=Z@=000000`3AcJT0
14000000dLfY0=7=ZD00000]0=7=Z@=00000103AcJT2@00002l0dLfY0d0000030=7=Z@=00000;P3A
cJT3@00000H0dLfY00=000000=7=Z@3AcJT0;03AcJT3@00000@0dLfY0T00000_0=7=Z@=000000`3A
cJT014000000dLfY0=7=ZD00000`0=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3A
cJT0;`3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY01l0dLfY000P0=7=Z@03@000
003AcJT0dLfY00<0dLfY00=000000=7=ZD000000;P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000
003AcJT0dLfY02l0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0^0=7=Z@03@000
003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU00000;`3AcJT00d000000dLfY0=7=Z@020=7=Z@04
@000003AcJT0dLfY@00002l0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD00000]
0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000;P3AcJT014000000dLfY
0=7=ZD0000040=7=Z@03@000003AcJT0dLfY01l0dLfY000P0=7=Z@=00000103AcJT2@00002h0dLfY
0d0000030=7=Z@=00000;`3AcJT3@00000<0dLfY0d00000^0=7=Z@=000000P3AcJT4@00002l0dLfY
0d0000030=7=Z@900000<03AcJT3@00000<0dLfY0d00000]0=7=Z@A000000`3AcJT2@00002l0dLfY
140000030=7=Z@9000008@3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0
dLfYc`3AcJT00?l0dLfYc`3AcJT001P0dLfY2`3oool200000080oooo0P0000020?ooo`@000008@3A
cJT;0?ooo`8000000P3oool200000080oooo1000000P0=7=Z@/0oooo0P0000020?ooo`8000000P3o
ool400000240dLfY2`3oool<00000240dLfY2`3oool3000000H0oooo0`00000P0=7=Z@/0oooo00<0
00000?ooo`0000001@0000030?ooo`030000003AcJT0dLfY01l0dLfY2`3oool2000000070?ooo`00
000000000000003oool000000?ooo`0300000200dLfY2`3oool<000001X0dLfY000H0=7=Z@/0oooo
0P0000020?ooo`8000000P3oool3000000030?ooo`3AcJT0dLfY01l0dLfY2`3oool200000080oooo
0P0000020?ooo`<0000000<0oooo0=7=Z@3AcJT07P3AcJT;0?ooo`8000000P3oool200000080oooo
0`0000000`3oool0dLfY0=7=Z@0O0=7=Z@/0oooo2`0000000`3oool0dLfY0=7=Z@0O0=7=Z@/0oooo
0P0000070?ooo`80000000<0oooo0=7=Z@3AcJT07P3AcJT;0?ooo`8000000P3oool7000000030?oo
o`3AcJT0dLfY01l0dLfY2`3oool4000000030?ooo`000000000000@0000000<0oooo0=7=Z@3AcJT0
7P3AcJT;0?ooo`/0000000<0oooo0=7=Z@3AcJT0603AcJT001P0dLfY2`3oool200000080oooo0P00
00020?ooo`8000000P3ooolQ0=7=Z@/0oooo0P0000020?ooo`8000000P3oool200000080oooo803A
cJT;0?ooo`8000000P3oool200000080oooo0P0000020?ooob40dLfY2`3oool:00000080oooo8@3A
cJT;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0803AcJT;0?ooo`8000000P3o
ool600000080oooo8@3AcJT;0?ooo`80000000D0oooo00000000000000000?ooo`0300000080oooo
803AcJT;0?ooo`X000000P3ooolJ0=7=Z@00603AcJT;0?ooo`8000000P3oool200000080oooo00@0
00000?ooo`3oool0oooo8@3AcJT;0?ooo`8000000P3oool200000080oooo00@000000?ooo`3oool0
oooo803AcJT;0?ooo`8000000P3oool200000080oooo00@000000?ooo`3oool0oooo8@3AcJT;0?oo
o`T000000`3ooolQ0=7=Z@/0oooo0P0000040?ooo`<000000`3ooolP0=7=Z@/0oooo100000020?oo
o`<000000`3ooolQ0=7=Z@/0oooo0`0000001P3oool00000000000000000oooo000000<0oooo803A
cJT;0?ooo`T000000`3ooolJ0=7=Z@00603AcJT;0?ooo`8000000P3oool2000000H0oooo8@3AcJT;
0?ooo`8000000P3oool2000000H0oooo803AcJT;0?ooo`8000000P3oool2000000030?ooo`000000
oooo00<0oooo8@3AcJT;0?ooo`P00000103ooolQ0=7=Z@/0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooob00dLfY2`3oool6000000H0oooo8@3AcJT;0?ooo`80000000H0oooo
00000000000000000?ooo`0000040?ooob00dLfY2`3oool8000000@0oooo6P3AcJT001P0dLfY2`3o
ool200000080oooo0P0000060?ooob40dLfY2`3oool200000080oooo0P0000060?ooob00dLfY2`3o
ool200000080oooo0`0000050?ooob40dLfY2`3oool7000000D0oooo8@3AcJT;0?ooo`8000000`3o
ool00`000000oooo0?ooo`040?ooob00dLfY2`3oool6000000H0oooo8@3AcJT;0?ooo`<0000000@0
oooo0000003oool000001@3ooolP0=7=Z@/0oooo1`0000050?oooaX0dLfY000H0=7=Z@/0oooo0P00
00020?ooo`8000001P3ooolQ0=7=Z@/0oooo0P0000020?ooo`8000001P3ooolP0=7=Z@/0oooo0P00
00020?ooo`8000001P3ooolQ0=7=Z@/0oooo1P0000060?ooob40dLfY2`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo803AcJT;0?ooo`030000003oool0000000<000001P3o
oolQ0=7=Z@/0oooo100000000`3oool000000?ooo`050?ooob00dLfY2`3oool6000000H0oooo6P3A
cJT001P0dLfY2`3oool200000080oooo00<000000?ooo`3oool01@3ooolQ0=7=Z@/0oooo0P000002
0?ooo`030000003oool0oooo00D0oooo803AcJT;0?ooo`8000000P3oool00`000000oooo0?ooo`05
0?ooob40dLfY2`3oool5000000L0oooo8@3AcJT;0?ooo`030000003oool0oooo00T0oooo803AcJT;
0?ooo`8000000P3oool00`000000oooo0?ooo`050?ooob40dLfY2`3oool00`000000oooo00000002
000000L0oooo803AcJT;0?ooo`D000001`3ooolJ0=7=Z@00603AcJT;0?ooo`8000002P3ooolQ0=7=
Z@/0oooo0P00000:0?ooob00dLfY2`3oool2000000030?ooo`000000oooo00L0oooo8@3AcJT;0?oo
o`@00000203ooolQ0=7=Z@/0oooo0P00000:0?ooob00dLfY2`3oool2000000X0oooo8@3AcJT;0?oo
o`80000000<0oooo0000003oool01`3ooolP0=7=Z@/0oooo100000080?oooaX0dLfY000H0=7=Z@/0
oooo0P00000:0?ooob40dLfY2`3oool2000000X0oooo803AcJT;0?ooo`8000002P3ooolQ0=7=Z@/0
oooo0`0000090?ooob40dLfY2`3oool00`000000oooo0?ooo`090?ooob00dLfY2`3oool3000000T0
oooo8@3AcJT;0?ooo`030000003oool0oooo00T0oooo803AcJT;0?ooo`<000002@3ooolJ0=7=Z@00
603AcJT;0?ooo`8000002P3ooolQ0=7=Z@/0oooo0P00000:0?ooob00dLfY2`3oool2000000X0oooo
8@3AcJT;0?ooo`8000002P3ooolQ0=7=Z@/0oooo0P00000:0?ooob00dLfY2`3oool2000000X0oooo
8@3AcJT;0?ooo`8000002P3ooolP0=7=Z@/0oooo0P00000:0?oooaX0dLfY000H0=7=Z@/0oooo00<0
00000?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=Z@/0oooo00<0
00000?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<0
00000?ooo`3oool02@3ooolP0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<0
00000?ooo`3oool02@3ooolP0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolJ0=7=Z@00o`3AcJW?
0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00803AcJT2@00000<0dLfY0d00
000_0=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@0^0=7=Z@900000103AcJT2@00002l0dLfY0T00
00030=7=Z@=00000;`3AcJT3@00000@0dLfY0T00000_0=7=Z@=000000`3AcJT5@00002`0dLfY0d00
00030=7=Z@A00000;P3AcJT3@00000@0dLfY0T00000Q0=7=Z@007`3AcJT014000000dLfY0=7=ZD00
00020=7=Z@04@000003AcJT0dLfY@00002d0dLfY00A000000=7=Z@3AcJU00000103AcJT00d000000
dLfY0=7=Z@0]0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000;@3AcJT0
14000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY02d0dLfY00A000000=7=Z@3AcJU00000
0P3AcJT014000000dLfY0=7=ZD00000^0=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=
Z@3AcJT0;03AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02l0dLfY00A00000
0=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000P0=7=Z@008P3AcJT014000000dLfY0=7=
ZD0000020=7=Z@03@000003AcJT0dLfY02h0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY
0=7=Z@0`0=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0;P3AcJT014000000
dLfY0=7=Z@3AcJT3@00002h0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00
000^0=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT0;03AcJT014000000dLfY
0=7=ZD0000030=7=Z@03@000003AcJT0dLfY02h0dLfY00A000000=7=Z@3AcJU00000103AcJT00d00
0000dLfY0=7=Z@0O0=7=Z@00803AcJT2@00000<0dLfY0d00000_0=7=Z@9000001P3AcJT00d000000
dLfY0=7=Z@0]0=7=Z@900000103AcJT2@00002l0dLfY0T0000030=7=Z@04@000003AcJT0dLfY@000
02h0dLfY0d0000030=7=Z@04@000003AcJT0dLfY@00002h0dLfY0d0000050=7=Z@03@000003AcJT0
dLfY02`0dLfY0d0000050=7=Z@03@000003AcJT0dLfY02d0dLfY0d0000060=7=Z@03@000003AcJT0
dLfY01h0dLfY000P0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0;P3AcJT00d00
0000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@00002l0dLfY00=000000=7=Z@3AcJT00P3AcJT0
14000000dLfY0=7=ZD00000^0=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU00000
;`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@00002l0dLfY00=000000=7=Z@3A
cJT0103AcJT00d000000dLfY0=7=Z@0]0=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3A
cJU00000;`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@0000200dLfY000P0=7=
Z@=000000`3AcJT3@00002h0dLfY0d0000020=7=Z@A00000;`3AcJT3@00000<0dLfY0T00000_0=7=
Z@=000000`3AcJT3@00002l0dLfY0d0000030=7=Z@900000<03AcJT3@00000<0dLfY0T00000_0=7=
Z@=000000`3AcJT2@0000300dLfY0d0000030=7=Z@9000008@3AcJT00?l0dLfYc`3AcJT00?l0dLfY
c`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT001P0dLfY
2`3oool00`000000oooo0?ooo`090?ooob40dLfY2`3oool00`000000oooo0?ooo`090?ooob00dLfY
2`3oool00`000000oooo0?ooo`090?ooob40dLfY2`3oool00`000000oooo0?ooo`090?ooob40dLfY
2`3oool00`000000oooo0?ooo`090?ooob00dLfY2`3oool00`000000oooo0?ooo`090?ooob40dLfY
2`3oool00`000000oooo0?ooo`090?ooob00dLfY2`3oool00`000000oooo0?ooo`090?oooaX0dLfY
000H0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3o
oolP0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3o
oolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=Z@/0oooo00<000000?ooo`3oool02@3o
oolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=Z@/0oooo00<000000?ooo`3oool02@3o
oolJ0=7=Z@00603AcJT;0?ooo`030000003oool0oooo00T0oooo8@3AcJT;0?ooo`030000003oool0
oooo00T0oooo803AcJT;0?ooo`030000003oool0oooo00T0oooo8@3AcJT;0?ooo`030000003oool0
oooo00T0oooo8@3AcJT;0?ooo`030000003oool0oooo00T0oooo803AcJT;0?ooo`030000003oool0
oooo00T0oooo8@3AcJT;0?ooo`030000003oool0oooo00T0oooo803AcJT;0?ooo`030000003oool0
oooo00T0oooo6P3AcJT001P0dLfY2`3oool00`000000oooo0?ooo`090?ooob40dLfY2`3oool00`00
0000oooo0?ooo`090?ooob00dLfY2`3oool00`000000oooo0?ooo`090?ooob40dLfY2`3oool00`00
0000oooo0?ooo`090?ooob40dLfY2`3oool00`000000oooo0?ooo`090?ooob00dLfY2`3oool00`00
0000oooo0?ooo`090?ooob40dLfY2`3oool00`000000oooo0?ooo`090?ooob00dLfY2`3oool00`00
0000oooo0?ooo`090?oooaX0dLfY000H0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0
oooo00<000000?ooo`3oool02@3ooolP0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0
oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=Z@/0
oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=Z@/0
oooo00<000000?ooo`3oool02@3ooolJ0=7=Z@00603AcJT;0?ooo`030000003oool0oooo00T0oooo
8@3AcJT;0?ooo`030000003oool0oooo00T0oooo803AcJT;0?ooo`030000003oool0oooo00T0oooo
8@3AcJT;0?ooo`030000003oool0oooo00T0oooo8@3AcJT;0?ooo`030000003oool0oooo00T0oooo
803AcJT;0?ooo`030000003oool0oooo00T0oooo8@3AcJT;0?ooo`030000003oool0oooo00T0oooo
803AcJT;0?ooo`030000003oool0oooo00T0oooo6P3AcJT001P0dLfY2`3oool00`000000oooo0?oo
o`090?ooob40dLfY2`3oool00`000000oooo0?ooo`090?ooob00dLfY2`3oool00`000000oooo0?oo
o`090?ooob40dLfY2`3oool00`000000oooo0?ooo`090?ooob40dLfY2`3oool00`000000oooo0?oo
o`090?ooob00dLfY2`3oool00`000000oooo0?ooo`090?ooob40dLfY2`3oool00`000000oooo0?oo
o`090?ooob00dLfY2`3oool00`000000oooo0?ooo`090?oooaX0dLfY000H0=7=Z@/0oooo00<00000
0?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=Z@/0oooo00<00000
0?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<00000
0?ooo`3oool02@3ooolP0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<00000
0?ooo`3oool02@3ooolP0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolJ0=7=Z@00603AcJT;0?oo
o`030000003oool0oooo00T0oooo8@3AcJT;0?ooo`030000003oool0oooo00T0oooo803AcJT;0?oo
o`030000003oool0oooo00T0oooo8@3AcJT;0?ooo`030000003oool0oooo00T0oooo8@3AcJT;0?oo
o`030000003oool0oooo00T0oooo803AcJT;0?ooo`030000003oool0oooo00T0oooo8@3AcJT;0?oo
o`030000003oool0oooo00T0oooo803AcJT;0?ooo`030000003oool0oooo00T0oooo6P3AcJT001P0
dLfY2`3oool00`000000oooo0?ooo`090?ooob40dLfY2`3oool00`000000oooo0?ooo`090?ooob00
dLfY2`3oool00`000000oooo0?ooo`090?ooob40dLfY2`3oool00`000000oooo0?ooo`090?ooob40
dLfY2`3oool00`000000oooo0?ooo`090?ooob00dLfY2`3oool00`000000oooo0?ooo`090?ooob40
dLfY2`3oool00`000000oooo0?ooo`090?ooob00dLfY2`3oool00`000000oooo0?ooo`090?oooaX0
dLfY000H0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool0
2@3ooolP0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool0
2@3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=Z@/0oooo00<000000?ooo`3oool0
2@3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=Z@/0oooo00<000000?ooo`3oool0
2@3ooolJ0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00
8@3AcJT3@0000080dLfY0T00000`0=7=Z@=0000000@0dLfY@000040000100000<03AcJT2@00000@0
dLfY0T00000_0=7=Z@9000000`3AcJT5@00002h0dLfY0T0000030=7=Z@A00000;`3AcJT2@00000@0
dLfY0T00000_0=7=Z@9000001@3AcJT3@00002h0dLfY0T0000040=7=Z@9000008@3AcJT00280dLfY
00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0^0=7=Z@03@000003AcJT0dLfY0080
dLfY00=000000=7=Z@3AcJT0;@3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@00002d0dLfY00A000000=7=Z@3AcJU00000103AcJT00d000000dLfY0=7=Z@0]0=7=Z@04@000003A
cJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0;`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04
@000003AcJT0dLfY@00002d0dLfY00A000000=7=Z@3AcJU000001@3AcJT00d000000dLfY0=7=Z@0/
0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000803AcJT001l0dLfY1D00
00001@3AcJU000000=7=Z@3AcJU0000002d0dLfY1D0000020=7=Z@=00000<@3AcJT014000000dLfY
0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02h0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000
dLfY0=7=Z@0`0=7=Z@05@000003AcJT0dLfY0=7=ZD000000<`3AcJT00d000000dLfY0=7=Z@020=7=
Z@03@000003AcJT0dLfY02l0dLfY00=000000=7=Z@3AcJT01D00000`0=7=Z@03@000003AcJT0dLfY
00<0dLfY00=000000=7=Z@3AcJT07P3AcJT001l0dLfY00A000000=7=Z@3AcJU000000`3AcJT2@000
02h0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000_0=7=Z@9000000`3A
cJT014000000dLfY0=7=ZD00000^0=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@0^0=7=Z@900000
1@3AcJT00d000000dLfY0=7=Z@0^0=7=Z@9000001P3AcJT00d000000dLfY0=7=Z@0/0=7=Z@900000
0`3AcJT014000000dLfY0=7=ZD00000_0=7=Z@900000103AcJT2@0000240dLfY000P0=7=Z@03@000
003AcJU000000080dLfY00A000000=7=Z@3AcJU00000;P3AcJT00d000000dLfY@00000020=7=Z@04
@000003AcJT0dLfY@00002l0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD00000^
0=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT0;P3AcJT00d000000dLfY0=7=Z@02
0=7=Z@04@000003AcJT0dLfY@00002l0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=
ZD00000^0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=ZD000000;`3AcJT00d000000dLfY
0=7=Z@030=7=Z@03@000003AcJT0dLfY0200dLfY000Q0=7=Z@9000000`3AcJT2@0000300dLfY0T00
00030=7=Z@=00000;`3AcJT3@00000<0dLfY0T00000_0=7=Z@=000000`3AcJT2@0000300dLfY0d00
00030=7=Z@900000<03AcJT3@00000<0dLfY0T00000_0=7=Z@=00000103AcJT2@00002l0dLfY0d00
00030=7=Z@=00000803AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfY
c`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT001P0dLfY5P3oool00`000000dLfY0=7=Z@0O0=7=
ZAH0oooo00<000000=7=Z@3AcJT07P3AcJTF0?ooo`030000003AcJT0dLfY01l0dLfY5P3oool00`00
0000dLfY0=7=Z@0O0=7=ZAH0oooo00<000000=7=Z@3AcJT07P3AcJTF0?ooo`030000003AcJT0dLfY
01l0dLfY5P3oool00`000000dLfY0=7=Z@0N0=7=ZAH0oooo00<000000=7=Z@3AcJT0603AcJT001P0
dLfY5@3oool00`000000oooo0=7=Z@0P0=7=ZAD0oooo00<000000?ooo`3AcJT07`3AcJTE0?ooo`03
0000003oool0dLfY0200dLfY5@3oool00`000000oooo0=7=Z@0P0=7=ZAD0oooo00<000000?ooo`3A
cJT07`3AcJTE0?ooo`030000003oool0dLfY0200dLfY5@3oool00`000000oooo0=7=Z@0O0=7=ZAD0
oooo00<000000?ooo`3AcJT06@3AcJT001P0dLfY503oool00`000000oooo0?ooo`0Q0=7=ZA@0oooo
00<000000?ooo`3oool0803AcJTD0?ooo`030000003oool0oooo0240dLfY503oool00`000000oooo
0?ooo`0Q0=7=ZA@0oooo00<000000?ooo`3oool0803AcJTD0?ooo`030000003oool0oooo0240dLfY
503oool00`000000oooo0?ooo`0P0=7=ZA@0oooo00<000000?ooo`3oool06P3AcJT001P0dLfY4`3o
ool010000000oooo0?ooo`3ooolQ0=7=ZA<0oooo00@000000?ooo`3oool0oooo803AcJTC0?ooo`04
0000003oool0oooo0?ooob40dLfY4`3oool010000000oooo0?ooo`3ooolQ0=7=ZA<0oooo00@00000
0?ooo`3oool0oooo803AcJTC0?ooo`040000003oool0oooo0?ooob40dLfY4`3oool010000000oooo
0?ooo`3ooolP0=7=ZA<0oooo00@000000?ooo`3oool0oooo6P3AcJT001P0dLfY5`3ooolQ0=7=ZAL0
oooo803AcJTB0?ooo`030000003oool0oooo0080oooo8@3AcJTB0?ooo`030000003oool0oooo0080
oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZA80oooo00<000000?ooo`3oool00P3ooolP0=7=ZA80
oooo00<000000?ooo`3oool00P3ooolJ0=7=Z@00603AcJTG0?ooob40dLfY5`3ooolP0=7=ZA40oooo
00<000000?ooo`3oool00`3ooolQ0=7=ZA40oooo00<000000?ooo`3oool00`3ooolQ0=7=ZAL0oooo
803AcJTG0?ooob40dLfY4@3oool00`000000oooo0?ooo`030?ooob00dLfY4@3oool00`000000oooo
0?ooo`030?oooaX0dLfY000H0=7=ZA00oooo00<000000?ooo`3oool0103ooolQ0=7=ZA00oooo00<0
00000?ooo`3oool0103ooolP0=7=ZA00oooo00<000000?ooo`3oool0103ooolQ0=7=ZA00oooo00<0
00000?ooo`3oool0103ooolQ0=7=ZA00oooo00<000000?ooo`3oool0103ooolP0=7=ZA00oooo00<0
00000?ooo`3oool0103ooolQ0=7=ZA00oooo00<000000?ooo`3oool0103ooolP0=7=ZA00oooo00<0
00000?ooo`3oool0103ooolJ0=7=Z@00603AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG
0?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolJ0=7=Z@00603AcJTG0?oo
ob40dLfY5`3ooolP0=7=Z@h0oooo00<000000?ooo`3oool01P3ooolQ0=7=Z@h0oooo00<000000?oo
o`3oool01P3ooolQ0=7=ZAL0oooo803AcJTG0?ooob40dLfY3P3oool00`000000oooo0?ooo`060?oo
ob00dLfY3P3oool00`000000oooo0?ooo`060?oooaX0dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00
dLfY5`3ooolQ0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTG0?oooaX0
dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY
5`3ooolQ0=7=ZAL0oooo803AcJTG0?oooaX0dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3o
oolQ0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTG0?oooaX0dLfY003o
0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY000Q0=7=Z@=000000P3A
cJT2@0000300dLfY0d0000000`3AcJU00000@0000003@00002l0dLfY0d0000000`3AcJU00000@000
0002@00002l0dLfY0d0000020=7=Z@900000<@3AcJT3@00000<0dLfY0d00000_0=7=Z@=000000P3A
cJT2@0000300dLfY0d000000103AcJU00000@0000400000a0=7=Z@=000000`3AcJT00d000000dLfY
0=7=Z@0O0=7=Z@008P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02h0dLfY
00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0`0=7=Z@04@000003AcJT0dLfY@00003<0
dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0_0=7=Z@03@000003AcJT0dLfY
00<0dLfY00=000000=7=Z@3AcJT0;`3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0
dLfY02h0dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0_0=7=Z@03@000003A
cJT0dLfY0080dLfY00=000000=7=Z@3AcJT07`3AcJT001l0dLfY1D0000001@3AcJU000000=7=Z@3A
cJU0000002d0dLfY1D0000030=7=Z@03@000003AcJT0dLfY02d0dLfY1D0000020=7=Z@03@000003A
cJT0dLfY02d0dLfY1D0000030=7=Z@03@000003AcJT0dLfY02d0dLfY1D0000000`3AcJU00000@000
0003@00002d0dLfY1D0000040=7=Z@03@000003AcJT0dLfY02/0dLfY1D0000001@3AcJU000000=7=
Z@3AcJU0000002h0dLfY1D0000030=7=Z@03@000003AcJT0dLfY01l0dLfY000O0=7=Z@04@000003A
cJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000;@3AcJT014000000dLfY0=7=ZD0000040=7=
Z@03@000003AcJT0dLfY02d0dLfY00A000000=7=Z@3AcJU00000103AcJT00d000000dLfY0=7=Z@0/
0=7=Z@04@000003AcJT0dLfY@00000D0dLfY00=000000=7=Z@3AcJT0;03AcJT014000000dLfY0=7=
ZD0000020=7=Z@04@000003AcJT0dLfY@00002h0dLfY00A000000=7=Z@3AcJU000000`3AcJT2@000
02h0dLfY00A000000=7=Z@3AcJU000000P3AcJT3@00002l0dLfY00A000000=7=Z@3AcJU000001@3A
cJT00d000000dLfY0=7=Z@0N0=7=Z@00803AcJT00d000000dLfY@00000020=7=Z@04@000003AcJT0
dLfY@00002h0dLfY00=000000=7=ZD000000103AcJT00d000000dLfY0=7=Z@0^0=7=Z@03@000003A
cJU000000080dLfY00A000000=7=Z@3AcJU00000;P3AcJT00d000000dLfY@00000020=7=Z@04@000
003AcJT0dLfY@00002l0dLfY00=000000=7=ZD0000000`3AcJT00d000000dLfY@000000_0=7=Z@03
@000003AcJU0000000<0dLfY00=000000=7=Z@3AcJT0;P3AcJT00d000000dLfY@00000030=7=Z@03
@000003AcJT0dLfY02l0dLfY00=000000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD00000P0=7=
Z@008@3AcJT2@00000<0dLfY0T00000`0=7=Z@9000000`3AcJT2@0000340dLfY0T0000030=7=Z@90
0000<03AcJT2@00000<0dLfY0T00000a0=7=Z@900000103AcJT2@0000300dLfY0T0000030=7=Z@=0
0000;`3AcJT2@00000<0dLfY0d00000`0=7=Z@9000000P3AcJT4@0000200dLfY003o0=7=ZLl0dLfY
003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY
000H0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3o
oolP0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3o
oolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=Z@/0oooo00<000000?ooo`3oool02@3o
oolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=Z@/0oooo00<000000?ooo`3oool02@3o
oolJ0=7=Z@00603AcJT;0?ooo`030000003oool0oooo00T0oooo8@3AcJT;0?ooo`030000003oool0
oooo00T0oooo803AcJT;0?ooo`030000003oool0oooo00T0oooo8@3AcJT;0?ooo`030000003oool0
oooo00T0oooo8@3AcJT;0?ooo`030000003oool0oooo00T0oooo803AcJT;0?ooo`030000003oool0
oooo00T0oooo8@3AcJT;0?ooo`030000003oool0oooo00T0oooo803AcJT;0?ooo`030000003oool0
oooo00T0oooo6P3AcJT001P0dLfY2`3oool00`000000oooo0?ooo`090?ooob40dLfY2`3oool00`00
0000oooo0?ooo`090?ooob00dLfY2`3oool00`000000oooo0?ooo`090?ooob40dLfY2`3oool00`00
0000oooo0?ooo`090?ooob40dLfY2`3oool00`000000oooo0?ooo`090?ooob00dLfY2`3oool00`00
0000oooo0?ooo`090?ooob40dLfY2`3oool00`000000oooo0?ooo`090?ooob00dLfY2`3oool00`00
0000oooo0?ooo`090?oooaX0dLfY000H0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0
oooo00<000000?ooo`3oool02@3ooolP0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0
oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=Z@/0
oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=Z@/0
oooo00<000000?ooo`3oool02@3ooolJ0=7=Z@00603AcJT;0?ooo`030000003oool0oooo00T0oooo
8@3AcJT;0?ooo`030000003oool0oooo00T0oooo803AcJT;0?ooo`030000003oool0oooo00T0oooo
8@3AcJT;0?ooo`030000003oool0oooo00T0oooo8@3AcJT;0?ooo`030000003oool0oooo00T0oooo
803AcJT;0?ooo`030000003oool0oooo00T0oooo8@3AcJT;0?ooo`030000003oool0oooo00T0oooo
803AcJT;0?ooo`030000003oool0oooo00T0oooo6P3AcJT001P0dLfY2`3oool00`000000oooo0?oo
o`090?ooob40dLfY2`3oool00`000000oooo0?ooo`090?ooob00dLfY2`3oool00`000000oooo0?oo
o`090?ooob40dLfY2`3oool00`000000oooo0?ooo`090?ooob40dLfY2`3oool00`000000oooo0?oo
o`090?ooob00dLfY2`3oool00`000000oooo0?ooo`090?ooob40dLfY2`3oool00`000000oooo0?oo
o`090?ooob00dLfY2`3oool00`000000oooo0?ooo`090?oooaX0dLfY000H0=7=Z@/0oooo00<00000
0?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=Z@/0oooo00<00000
0?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<00000
0?ooo`3oool02@3ooolP0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<00000
0?ooo`3oool02@3ooolP0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolJ0=7=Z@00603AcJT;0?oo
o`030000003oool0oooo00T0oooo8@3AcJT;0?ooo`030000003oool0oooo00T0oooo803AcJT;0?oo
o`030000003oool0oooo00T0oooo8@3AcJT;0?ooo`030000003oool0oooo00T0oooo8@3AcJT;0?oo
o`030000003oool0oooo00T0oooo803AcJT;0?ooo`030000003oool0oooo00T0oooo8@3AcJT;0?oo
o`030000003oool0oooo00T0oooo803AcJT;0?ooo`030000003oool0oooo00T0oooo6P3AcJT001P0
dLfY2`3oool00`000000oooo0?ooo`090?ooob40dLfY2`3oool00`000000oooo0?ooo`090?ooob00
dLfY2`3oool00`000000oooo0?ooo`090?ooob40dLfY2`3oool00`000000oooo0?ooo`090?ooob40
dLfY2`3oool00`000000oooo0?ooo`090?ooob00dLfY2`3oool00`000000oooo0?ooo`090?ooob40
dLfY2`3oool00`000000oooo0?ooo`090?ooob00dLfY2`3oool00`000000oooo0?ooo`090?oooaX0
dLfY000H0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool0
2@3ooolP0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool0
2@3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=Z@/0oooo00<000000?ooo`3oool0
2@3ooolQ0=7=Z@/0oooo00<000000?ooo`3oool02@3ooolP0=7=Z@/0oooo00<000000?ooo`3oool0
2@3ooolJ0=7=Z@00603AcJT;0?ooo`030000003oool0oooo00T0oooo8@3AcJT;0?ooo`030000003o
ool0oooo00T0oooo803AcJT;0?ooo`030000003oool0oooo00T0oooo8@3AcJT;0?ooo`030000003o
ool0oooo00T0oooo8@3AcJT;0?ooo`030000003oool0oooo00T0oooo803AcJT;0?ooo`030000003o
ool0oooo00T0oooo8@3AcJT;0?ooo`030000003oool0oooo00T0oooo803AcJT;0?ooo`030000003o
ool0oooo00T0oooo6P3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfY
c`3AcJT00200dLfY0T0000030=7=Z@A00000;P3AcJT2@00000@0dLfY0T00000`0=7=Z@9000001@3A
cJT3@00002d0dLfY0T0000040=7=Z@900000<03AcJT2@00000<0dLfY0d00000`0=7=Z@9000001@3A
cJT00d000000dLfY0=7=Z@0]0=7=Z@900000103AcJT2@0000300dLfY0T0000030=7=Z@=000008@3A
cJT001l0dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0^0=7=Z@04@000003A
cJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000;P3AcJT014000000dLfY0=7=ZD0000050=7=
Z@03@000003AcJT0dLfY02/0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00
000^0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000;P3AcJT014000000
dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY02`0dLfY00A000000=7=Z@3AcJU000000P3AcJT0
14000000dLfY0=7=ZD00000^0=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT0
7`3AcJT00240dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0_0=7=Z@03@000003A
cJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0;`3AcJT014000000dLfY0=7=Z@3AcJT5@00002h0dLfY
00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@0^0=7=Z@05@000003AcJT0dLfY0=7=ZD00
00000P3AcJT00d000000dLfY0=7=Z@0^0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3A
cJT0;P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0;P3AcJT00d00
0000dLfY0=7=Z@020=7=Z@=00000803AcJT00280dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000
dLfY0=7=Z@0_0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0;`3AcJT014000000
dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02h0dLfY00A000000=7=Z@3AcJT0dLfY0T00000b
0=7=Z@03@000003AcJT0dLfY00=00000<P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0
dLfY02h0dLfY00A000000=7=Z@3AcJT0dLfY0T00000b0=7=Z@04@000003AcJT0dLfY@0000080dLfY
00=000000=7=Z@3AcJT07P3AcJT001l0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD00000]0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000;P3AcJT0
14000000dLfY0=7=ZD0000030=7=Z@03@000003AcJU0000002d0dLfY00A000000=7=Z@3AcJU00000
0`3AcJT00d000000dLfY0=7=Z@0^0=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3A
cJT0;P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00002d0dLfY00A00000
0=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000^0=7=Z@04@000003AcJT0dLfY@0000080
dLfY00A000000=7=Z@3AcJU00000803AcJT00200dLfY0T0000040=7=Z@900000;`3AcJT2@00000@0
dLfY0T00000`0=7=Z@9000001@3AcJT2@00002h0dLfY0T0000040=7=Z@=00000;`3AcJT2@00000@0
dLfY0d00000_0=7=Z@9000000`3AcJT4@00002h0dLfY0T0000040=7=Z@900000<03AcJT2@00000@0
dLfY0d00000P0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=
Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00603AcJTF0?ooo`030000003AcJT0dLfY01l0dLfY5P3o
ool00`000000dLfY0=7=Z@0N0=7=ZAH0oooo00<000000=7=Z@3AcJT07`3AcJTF0?ooo`030000003A
cJT0dLfY01h0dLfY5`3oool00`000000dLfY0=7=Z@0N0=7=ZAH0oooo00<000000=7=Z@3AcJT07`3A
cJTF0?ooo`030000003AcJT0dLfY01h0dLfY5P3oool00`000000dLfY0=7=Z@0H0=7=Z@00603AcJTG
0?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY603ooolP0=7=ZAL0oooo8@3AcJTG
0?ooob00dLfY5`3ooolJ0=7=Z@00603AcJTD0?ooo`030000003oool0oooo0240dLfY503oool00`00
0000oooo0?ooo`0P0=7=ZA@0oooo00<000000?ooo`3oool08@3AcJTD0?ooo`030000003oool0oooo
0200dLfY5@3oool00`000000oooo0?ooo`0P0=7=ZA@0oooo00<000000?ooo`3oool08@3AcJTD0?oo
o`030000003oool0oooo0200dLfY503oool00`000000oooo0?ooo`0J0=7=Z@00603AcJTC0?ooo`04
0000003oool0oooo0?ooob40dLfY4`3oool010000000oooo0?ooo`3ooolP0=7=ZA<0oooo00@00000
0?ooo`3oool0oooo8@3AcJTC0?ooo`040000003oool0oooo0?ooob00dLfY603ooolP0=7=ZA<0oooo
00@000000?ooo`3oool0oooo8@3AcJTC0?ooo`040000003oool0oooo0?ooob00dLfY4`3oool01000
0000oooo0?ooo`3ooolJ0=7=Z@00603AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG0?oo
ob00dLfY603ooolP0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolJ0=7=Z@00603AcJTA0?ooo`03
0000003oool0oooo00<0oooo8@3AcJTA0?ooo`030000003oool0oooo00<0oooo803AcJTA0?ooo`03
0000003oool0oooo00<0oooo8@3AcJTA0?ooo`030000003oool0oooo00<0oooo803AcJTH0?ooob00
dLfY4@3oool00`000000oooo0?ooo`030?ooob40dLfY4@3oool00`000000oooo0?ooo`030?ooob00
dLfY4@3oool00`000000oooo0?ooo`030?oooaX0dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY
5`3ooolQ0=7=ZAL0oooo803AcJTH0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTG0?oooaX0dLfY
000H0=7=Z@l0oooo00<000000?ooo`3oool01@3ooolQ0=7=Z@l0oooo00<000000?ooo`3oool01@3o
oolP0=7=Z@l0oooo00<000000?ooo`3oool01@3ooolQ0=7=Z@l0oooo00<000000?ooo`3oool01@3o
oolP0=7=ZAP0oooo803AcJT?0?ooo`030000003oool0oooo00D0oooo8@3AcJT?0?ooo`030000003o
ool0oooo00D0oooo803AcJT?0?ooo`030000003oool0oooo00D0oooo6P3AcJT001P0dLfY5`3ooolQ
0=7=ZAL0oooo803AcJTG0?ooob40dLfY5`3ooolP0=7=ZAP0oooo803AcJTG0?ooob40dLfY5`3ooolP
0=7=ZAL0oooo6P3AcJT001P0dLfY5`3ooolQ0=7=ZAL0oooo803AcJTG0?ooob40dLfY5`3ooolP0=7=
ZAP0oooo803AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0oooo6P3AcJT001P0dLfY5`3ooolQ0=7=ZAL0
oooo803AcJTG0?ooob40dLfY5`3ooolP0=7=ZAP0oooo803AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0
oooo6P3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0dLfYc`3AcJT00?l0
dLfYc`3AcJT001l0dLfY140000040=7=Z@=00000;03AcJT4@00000<0dLfY0T00000_0=7=Z@A00000
0P3AcJT3@00002h0dLfY140000040=7=Z@03@000003AcJT0dLfY02d0dLfY140000030=7=Z@900000
;`3AcJT4@0000080dLfY0d00000_0=7=Z@900000103AcJT2@0000300dLfY0T0000030=7=Z@E00000
7`3AcJT001l0dLfY00=000000=7=Z@3AcJT01P3AcJT00d000000dLfY0=7=Z@0[0=7=Z@03@000003A
cJT0dLfY00<0dLfY00A000000=7=Z@3AcJU00000;P3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000
003AcJT0dLfY@00002d0dLfY00=000000=7=Z@3AcJT01@3AcJT00d000000dLfY0=7=Z@0]0=7=Z@03
@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU00000;P3AcJT00d000000dLfY0=7=Z@050=7=
Z@03@000003AcJT0dLfY02`0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00
000^0=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT07`3AcJT00200dLfY00=0
00000=7=Z@3AcJT00P3AcJT5@00002d0dLfY00=000000=7=Z@3AcJT01@3AcJT00d000000dLfY0=7=
Z@0]0=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU00000;P3AcJT00d000000dLfY
0=7=Z@040=7=Z@03@000003AcJT0dLfY02h0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY
0=7=ZD00000_0=7=Z@03@000003AcJT0dLfY00<0dLfY0d00000_0=7=Z@05@000003AcJT0dLfY0=7=
ZD0000000P3AcJT00d000000dLfY0=7=Z@0^0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=
Z@3AcJT07`3AcJT00240dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY
02d0dLfY00=000000=7=Z@3AcJT00P3AcJT2@0000340dLfY00A000000=7=Z@3AcJT0dLfY0d00000`
0=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT0;P3AcJT00d000000dLfY0=7=Z@02
0=7=Z@900000<@3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0;P3A
cJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02l0dLfY00=000000=7=Z@3AcJT0
0P3AcJT00d000000dLfY0=7=Z@0O0=7=Z@007`3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000
003AcJU0000002d0dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@0^0=7=Z@04
@000003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT0;@3AcJT014000000dLfY0=7=ZD000002
0=7=Z@04@000003AcJT0dLfY@00002h0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD00000^0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000;@3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00002h0dLfY00A000000=7=Z@3AcJU0
0000103AcJT00d000000dLfY0=7=Z@0O0=7=Z@00803AcJT2@00000D0dLfY0T00000^0=7=Z@900000
103AcJT3@00002l0dLfY0T0000040=7=Z@=00000;P3AcJT2@00000<0dLfY1400000_0=7=Z@900000
103AcJT2@0000300dLfY0T0000040=7=Z@=00000;P3AcJT2@00000@0dLfY0T00000`0=7=Z@900000
103AcJT2@0000240dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0
dLfY003o0=7=ZLl0dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803A
cJTH0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTG0?oooaX0dLfY000H0=7=ZAL0oooo8@3AcJTG
0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTH0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTG
0?oooaX0dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTH0?oo
ob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTG0?oooaX0dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00
dLfY5`3ooolQ0=7=ZAL0oooo803AcJTH0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTG0?oooaX0
dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTH0?ooob00dLfY
5`3ooolQ0=7=ZAL0oooo803AcJTG0?oooaX0dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3o
oolQ0=7=ZAL0oooo803AcJTH0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTG0?oooaX0dLfY000H
0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTH0?ooob00dLfY5`3ooolQ
0=7=ZAL0oooo803AcJTG0?oooaX0dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=
ZAL0oooo803AcJTH0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTG0?oooaX0dLfY000H0=7=ZAL0
oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTH0?ooob00dLfY5`3ooolQ0=7=ZAL0
oooo803AcJTG0?oooaX0dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo
803AcJTH0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTG0?oooaX0dLfY000H0=7=ZAL0oooo8@3A
cJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTH0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803A
cJTG0?oooaX0dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTH
0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTG0?oooaX0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0
dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY000O0=7=Z@E0000000@0dLfY@000040000100000;P3A
cJT5@00000<0dLfY00=000000=7=Z@3AcJT0;@3AcJT5@0000080dLfY0T00000^0=7=Z@E0000000@0
dLfY@000040000100000;`3AcJT4@00000<0dLfY0T00000_0=7=Z@A000000P3AcJT5@00002`0dLfY
140000020=7=Z@A00000;P3AcJT4@00000<0dLfY0T00000Q0=7=Z@008@3AcJT01D000000dLfY0=7=
Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0;@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000
003AcJT0dLfY02l0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY02d0
dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0]0=7=Z@03@000003AcJT0dLfY00<0
dLfY00A000000=7=Z@3AcJU00000;P3AcJT00d000000dLfY0=7=Z@050=7=Z@03@000003AcJT0dLfY
02`0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0_0=7=Z@03@000003AcJT0dLfY
00<0dLfY00A000000=7=Z@3AcJU00000803AcJT00240dLfY00E000000=7=Z@3AcJT0dLfY@0000002
0=7=Z@03@000003AcJT0dLfY02d0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0_
0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0]0=7=Z@03@000003A
cJT0dLfY0080dLfY0d00000_0=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU00000
;`3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY02d0dLfY00=000000=7=Z@3AcJT0
0`3AcJT00d000000dLfY0=7=Z@0_0=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT0
7`3AcJT00240dLfY00A000000=7=Z@3AcJT0dLfY0d00000`0=7=Z@03@000003AcJT0dLfY00@0dLfY
00=000000=7=Z@3AcJT0;P3AcJT00d000000dLfY0=7=Z@020=7=Z@900000<03AcJT01D000000dLfY
0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0;P3AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00=000000=7=Z@3AcJT0;P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY
02h0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0_0=7=Z@03@000003AcJT0dLfY
00@0dLfY00=000000=7=Z@3AcJT07P3AcJT00240dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000
dLfY0=7=Z@0_0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0^0=7=
Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0]0=7=Z@05@000003AcJT0
dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0/0=7=Z@04@000003AcJT0dLfY@0000080dLfY
00A000000=7=Z@3AcJU00000;P3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY
02`0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000^0=7=Z@04@000003A
cJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000803AcJT00200dLfY0T0000040=7=Z@=00000
;P3AcJT2@00000<0dLfY1400000_0=7=Z@900000103AcJT2@00002l0dLfY0T0000040=7=Z@=00000
;`3AcJT2@00000@0dLfY0T00000`0=7=Z@900000103AcJT2@00002l0dLfY0T0000040=7=Z@900000
<03AcJT2@00000@0dLfY0T00000Q0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=
Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00603AcJTF0?ooo`030000003AcJT0
dLfY01l0dLfY5P3oool00`000000dLfY0=7=Z@0N0=7=ZAH0oooo00<000000=7=Z@3AcJT07`3AcJTF
0?ooo`030000003AcJT0dLfY01l0dLfY5P3oool00`000000dLfY0=7=Z@0N0=7=ZAH0oooo00<00000
0=7=Z@3AcJT07`3AcJTF0?ooo`030000003AcJT0dLfY01h0dLfY5P3oool00`000000dLfY0=7=Z@0H
0=7=Z@00603AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG0?ooob40dLfY5`3ooolP0=7=
ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolJ0=7=Z@00603AcJTD0?ooo`030000003oool0oooo0240
dLfY503oool00`000000oooo0?ooo`0P0=7=ZA@0oooo00<000000?ooo`3oool08@3AcJTD0?ooo`03
0000003oool0oooo0240dLfY503oool00`000000oooo0?ooo`0P0=7=ZA@0oooo00<000000?ooo`3o
ool08@3AcJTD0?ooo`030000003oool0oooo0200dLfY503oool00`000000oooo0?ooo`0J0=7=Z@00
603AcJTC0?ooo`040000003oool0oooo0?ooob40dLfY4`3oool010000000oooo0?ooo`3ooolP0=7=
ZA<0oooo00@000000?ooo`3oool0oooo8@3AcJTC0?ooo`040000003oool0oooo0?ooob40dLfY4`3o
ool010000000oooo0?ooo`3ooolP0=7=ZA<0oooo00@000000?ooo`3oool0oooo8@3AcJTC0?ooo`04
0000003oool0oooo0?ooob00dLfY4`3oool010000000oooo0?ooo`3ooolJ0=7=Z@00603AcJTG0?oo
ob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG0?oo
ob00dLfY5`3ooolJ0=7=Z@00603AcJTA0?ooo`030000003oool0oooo00<0oooo8@3AcJTA0?ooo`03
0000003oool0oooo00<0oooo803AcJTA0?ooo`030000003oool0oooo00<0oooo8@3AcJTA0?ooo`03
0000003oool0oooo00<0oooo8@3AcJTA0?ooo`030000003oool0oooo00<0oooo803AcJTA0?ooo`03
0000003oool0oooo00<0oooo8@3AcJTA0?ooo`030000003oool0oooo00<0oooo803AcJTA0?ooo`03
0000003oool0oooo00<0oooo6P3AcJT001P0dLfY5`3ooolQ0=7=ZAL0oooo803AcJTG0?ooob40dLfY
5`3ooolQ0=7=ZAL0oooo803AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0oooo6P3AcJT001P0dLfY3`3o
ool00`000000oooo0?ooo`050?ooob40dLfY3`3oool00`000000oooo0?ooo`050?ooob00dLfY3`3o
ool00`000000oooo0?ooo`050?ooob40dLfY3`3oool00`000000oooo0?ooo`050?ooob40dLfY3`3o
ool00`000000oooo0?ooo`050?ooob00dLfY3`3oool00`000000oooo0?ooo`050?ooob40dLfY3`3o
ool00`000000oooo0?ooo`050?ooob00dLfY3`3oool00`000000oooo0?ooo`050?oooaX0dLfY000H
0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ
0=7=ZAL0oooo803AcJTG0?oooaX0dLfY000H0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=
ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo803AcJTG0?oooaX0dLfY000H0=7=ZAL0
oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolQ0=7=ZAL0
oooo803AcJTG0?oooaX0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=ZLl0dLfY003o0=7=
ZLl0dLfY003o0=7=ZLl0dLfY000S0=7=Z@900000=03AcJT3@0000380dLfY1D0000020=7=Z@900000
;P3AcJT5@00000030=7=ZD000010000000=00000;@3AcJT5@00000030=7=ZD000010000000900000
;P3AcJT5@0000080dLfY0T00000^0=7=Z@E000000`3AcJT3@00002d0dLfY1D0000020=7=Z@900000
8@3AcJT00280dLfY00A000000=7=Z@3AcJU00000=@3AcJT00d000000dLfY0=7=Z@0b0=7=Z@05@000
003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0]0=7=Z@03@000003AcJT0dLfY00<0
dLfY00=000000=7=Z@3AcJT0;`3AcJT01D000000dLfY0=7=Z@3AcJU0000003<0dLfY00E000000=7=
Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY02d0dLfY00=000000=7=Z@3AcJT0103AcJT0
0d000000dLfY0=7=Z@0^0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=
Z@0N0=7=Z@008P3AcJT014000000dLfY0=7=ZD00000d0=7=Z@=00000<`3AcJT01D000000dLfY0=7=
Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0;@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000
003AcJT0dLfY02l0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0`0=7=Z@03@000
003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0;P3AcJT014000000dLfY0=7=Z@3AcJT5@00002l0
dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@0N0=7=Z@008`3AcJT2@00003@0dLfY
00A000000=7=Z@3AcJU00000<`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=
Z@3AcJT0;@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY02l0dLfY00=000000=7=
Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0_0=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=
Z@3AcJT0;@3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0;P3AcJT0
0d000000dLfY0=7=Z@020=7=Z@9000008@3AcJT00280dLfY00A000000=7=Z@3AcJU00000<`3AcJT0
14000000dLfY0=7=ZD00000c0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY
0=7=Z@0]0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0;`3AcJT01D000000dLfY
0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0;P3AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00=000000=7=Z@3AcJT0;@3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJU00000
0300dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0P0=7=Z@008`3AcJT2@00003D0
dLfY0d00000b0=7=Z@900000103AcJT2@00002l0dLfY0T0000040=7=Z@900000<03AcJT2@00000@0
dLfY0T00000`0=7=Z@900000103AcJT2@00002l0dLfY0T0000050=7=Z@900000;`3AcJT2@00000@0
dLfY0d00000P0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=
Z@00o`3AcJW?0=7=Z@00603AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG0?ooob40dLfY
5`3ooolP0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolJ0=7=Z@00603AcJTG0?ooob40dLfY5`3o
oolP0=7=ZAL0oooo8@3AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3o
oolJ0=7=Z@00603AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG0?ooob40dLfY5`3ooolP
0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolJ0=7=Z@00603AcJTG0?ooob40dLfY5`3ooolP0=7=
ZAL0oooo8@3AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolJ0=7=
Z@00603AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0
oooo8@3AcJTG0?ooob00dLfY5`3ooolJ0=7=Z@00603AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0oooo
8@3AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolJ0=7=Z@00603A
cJTG0?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3A
cJTG0?ooob00dLfY5`3ooolJ0=7=Z@00603AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG
0?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolJ0=7=Z@00603AcJTG0?oo
ob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG0?oo
ob00dLfY5`3ooolJ0=7=Z@00603AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG0?ooob40
dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolJ0=7=Z@00603AcJTG0?ooob40dLfY
5`3ooolP0=7=ZAL0oooo8@3AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY
5`3ooolJ0=7=Z@00603AcJTG0?ooob40dLfY5`3ooolP0=7=ZAL0oooo8@3AcJTG0?ooob40dLfY5`3o
oolP0=7=ZAL0oooo8@3AcJTG0?ooob00dLfY5`3ooolJ0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=
Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@008`3AcJT2@00003@0dLfY1D00000c0=7=Z@A00000=03A
cJT2@00003L0dLfY0d00000d0=7=Z@900000=03AcJT3@00003L0dLfY00=000000=7=Z@3AcJT08P3A
cJT00280dLfY00A000000=7=Z@3AcJU00000=@3AcJT00d000000dLfY0=7=Z@0c0=7=Z@03@000003A
cJT0dLfY03@0dLfY00A000000=7=Z@3AcJU00000=`3AcJT00d000000dLfY0=7=Z@0b0=7=Z@04@000
003AcJT0dLfY@00003<0dLfY00A000000=7=Z@3AcJU00000=P3AcJT00d000000dLfY0=7=Z@0R0=7=
Z@008P3AcJT014000000dLfY0=7=ZD00000e0=7=Z@03@000003AcJT0dLfY03@0dLfY00=000000=7=
Z@3AcJT0=@3AcJT00d000000dLfY0=7=Z@0c0=7=Z@E00000=P3AcJT00d000000dLfY0=7=Z@0a0=7=
Z@04@000003AcJT0dLfY@00003H0dLfY00=000000=7=Z@3AcJT08P3AcJT00280dLfY00A000000=7=
Z@3AcJU00000=@3AcJT00d000000dLfY0=7=Z@0e0=7=Z@03@000003AcJT0dLfY03D0dLfY00=00000
0=7=Z@3AcJT0<P3AcJT014000000dLfY0=7=ZD00000e0=7=Z@900000=03AcJT3@00003P0dLfY00=0
00000=7=Z@3AcJT08@3AcJT00280dLfY00A000000=7=Z@3AcJU00000=@3AcJT00d000000dLfY0=7=
Z@0c0=7=Z@04@000003AcJT0dLfY@00003<0dLfY00A000000=7=Z@3AcJU00000=@3AcJT00d000000
dLfY@000000e0=7=Z@03@000003AcJT0dLfY03@0dLfY00=000000=7=Z@3AcJT0=03AcJT014000000
dLfY0=7=ZD00000S0=7=Z@008`3AcJT2@00003D0dLfY0T00000f0=7=Z@900000=@3AcJT2@00003L0
dLfY0T00000e0=7=Z@=00000=03AcJT3@00003@0dLfY1400000S0=7=Z@00o`3AcJW?0=7=Z@00o`3A
cJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3A
cJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3A
cJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3A
cJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3A
cJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00o`3AcJW?0=7=Z@00\
\>"],
  ImageRangeCache->{{{0, 461.5}, {920.375, 0}} -> {-0.200041, -0.406832, \
0.0182016, 0.0182016}, {{10.9375, 61.5}, {898, 873.063}} -> {-87.5718, \
-79.9198, 3.53607, 3.53607}, {{66.5625, 117.063}, {898, 873.063}} -> \
{-284.155, -79.9198, 3.53607, 3.53607}, {{122.125, 172.625}, {898, 873.063}} -> \
{-480.628, -79.9198, 3.53607, 3.53607}, {{177.688, 228.188}, {898, 873.063}} -> \
{-677.101, -79.9198, 3.53607, 3.53607}, {{233.25, 283.75}, {898, 873.063}} -> \
{-873.574, -79.9198, 3.53607, 3.53607}, {{288.813, 339.313}, {898, 873.063}} -> \
{-1070.05, -79.9198, 3.53607, 3.53607}, {{344.375, 394.938}, {898, 873.063}} -> \
{-1266.63, -79.9198, 3.53607, 3.53607}, {{399.938, 450.5}, {898, 873.063}} -> \
{-1463.1, -79.9198, 3.53607, 3.53607}, {{10.9375, 61.5}, {870.563, 845.625}} -> \
{-87.5718, -176.941, 3.53607, 3.53607}, {{66.5625, 117.063}, {870.563, \
845.625}} -> {-284.155, -176.941, 3.53607, 3.53607}, {{122.125, 172.625}, \
{870.563, 845.625}} -> {-480.628, -176.941, 3.53607, 3.53607}, {{177.688, \
228.188}, {870.563, 845.625}} -> {-677.101, -176.941, 3.53607, 3.53607}, \
{{233.25, 283.75}, {870.563, 845.625}} -> {-873.574, -176.941, 3.53607, \
3.53607}, {{288.813, 339.313}, {870.563, 845.625}} -> {-1070.05, -176.941, \
3.53607, 3.53607}, {{344.375, 394.938}, {870.563, 845.625}} -> {-1266.63, \
-176.941, 3.53607, 3.53607}, {{399.938, 450.5}, {870.563, 845.625}} -> \
{-1463.1, -176.941, 3.53607, 3.53607}, {{10.9375, 61.5}, {843.125, 818.188}} -> \
{-87.5718, -273.962, 3.53607, 3.53607}, {{66.5625, 117.063}, {843.125, \
818.188}} -> {-284.155, -273.962, 3.53607, 3.53607}, {{122.125, 172.625}, \
{843.125, 818.188}} -> {-480.628, -273.962, 3.53607, 3.53607}, {{177.688, \
228.188}, {843.125, 818.188}} -> {-677.101, -273.962, 3.53607, 3.53607}, \
{{233.25, 283.75}, {843.125, 818.188}} -> {-873.574, -273.962, 3.53607, \
3.53607}, {{288.813, 339.313}, {843.125, 818.188}} -> {-1070.05, -273.962, \
3.53607, 3.53607}, {{344.375, 394.938}, {843.125, 818.188}} -> {-1266.63, \
-273.962, 3.53607, 3.53607}, {{399.938, 450.5}, {843.125, 818.188}} -> \
{-1463.1, -273.962, 3.53607, 3.53607}, {{10.9375, 61.5}, {815.688, 790.688}} -> \
{-86.9117, -369.074, 3.51784, 3.51784}, {{66.5625, 117.063}, {815.688, \
790.688}} -> {-282.482, -369.074, 3.51784, 3.51784}, {{122.125, 172.625}, \
{815.688, 790.688}} -> {-477.942, -369.074, 3.51784, 3.51784}, {{177.688, \
228.188}, {815.688, 790.688}} -> {-673.402, -369.074, 3.51784, 3.51784}, \
{{233.25, 283.75}, {815.688, 790.688}} -> {-868.862, -369.074, 3.51784, \
3.51784}, {{288.813, 339.313}, {815.688, 790.688}} -> {-1064.32, -369.074, \
3.51784, 3.51784}, {{344.375, 394.938}, {815.688, 790.688}} -> {-1259.89, \
-369.074, 3.51784, 3.51784}, {{399.938, 450.5}, {815.688, 790.688}} -> \
{-1455.35, -369.074, 3.51784, 3.51784}, {{10.9375, 61.5}, {788.25, 763.25}} -> \
{-86.9117, -465.595, 3.51784, 3.51784}, {{66.5625, 117.063}, {788.25, \
763.25}} -> {-282.482, -465.595, 3.51784, 3.51784}, {{122.125, 172.625}, \
{788.25, 763.25}} -> {-477.942, -465.595, 3.51784, 3.51784}, {{177.688, \
228.188}, {788.25, 763.25}} -> {-673.402, -465.595, 3.51784, 3.51784}, \
{{233.25, 283.75}, {788.25, 763.25}} -> {-868.862, -465.595, 3.51784, \
3.51784}, {{288.813, 339.313}, {788.25, 763.25}} -> {-1064.32, -465.595, \
3.51784, 3.51784}, {{344.375, 394.938}, {788.25, 763.25}} -> {-1259.89, \
-465.595, 3.51784, 3.51784}, {{399.938, 450.5}, {788.25, 763.25}} -> \
{-1455.35, -465.595, 3.51784, 3.51784}, {{10.9375, 61.5}, {760.75, 735.813}} -> \
{-87.5718, -565.245, 3.53607, 3.53607}, {{66.5625, 117.063}, {760.75, \
735.813}} -> {-284.155, -565.245, 3.53607, 3.53607}, {{122.125, 172.625}, \
{760.75, 735.813}} -> {-480.628, -565.245, 3.53607, 3.53607}, {{177.688, \
228.188}, {760.75, 735.813}} -> {-677.101, -565.245, 3.53607, 3.53607}, \
{{233.25, 283.75}, {760.75, 735.813}} -> {-873.574, -565.245, 3.53607, \
3.53607}, {{288.813, 339.313}, {760.75, 735.813}} -> {-1070.05, -565.245, \
3.53607, 3.53607}, {{344.375, 394.938}, {760.75, 735.813}} -> {-1266.63, \
-565.245, 3.53607, 3.53607}, {{399.938, 450.5}, {760.75, 735.813}} -> \
{-1463.1, -565.245, 3.53607, 3.53607}, {{10.9375, 61.5}, {733.313, 708.375}} -> \
{-87.5718, -662.266, 3.53607, 3.53607}, {{66.5625, 117.063}, {733.313, \
708.375}} -> {-284.155, -662.266, 3.53607, 3.53607}, {{122.125, 172.625}, \
{733.313, 708.375}} -> {-480.628, -662.266, 3.53607, 3.53607}, {{177.688, \
228.188}, {733.313, 708.375}} -> {-677.101, -662.266, 3.53607, 3.53607}, \
{{233.25, 283.75}, {733.313, 708.375}} -> {-873.574, -662.266, 3.53607, \
3.53607}, {{288.813, 339.313}, {733.313, 708.375}} -> {-1070.05, -662.266, \
3.53607, 3.53607}, {{344.375, 394.938}, {733.313, 708.375}} -> {-1266.63, \
-662.266, 3.53607, 3.53607}, {{399.938, 450.5}, {733.313, 708.375}} -> \
{-1463.1, -662.266, 3.53607, 3.53607}, {{10.9375, 61.5}, {705.875, 680.938}} -> \
{-87.5718, -759.287, 3.53607, 3.53607}, {{66.5625, 117.063}, {705.875, \
680.938}} -> {-284.155, -759.287, 3.53607, 3.53607}, {{122.125, 172.625}, \
{705.875, 680.938}} -> {-480.628, -759.287, 3.53607, 3.53607}, {{177.688, \
228.188}, {705.875, 680.938}} -> {-677.101, -759.287, 3.53607, 3.53607}, \
{{233.25, 283.75}, {705.875, 680.938}} -> {-873.574, -759.287, 3.53607, \
3.53607}, {{288.813, 339.313}, {705.875, 680.938}} -> {-1070.05, -759.287, \
3.53607, 3.53607}, {{344.375, 394.938}, {705.875, 680.938}} -> {-1266.63, \
-759.287, 3.53607, 3.53607}, {{399.938, 450.5}, {705.875, 680.938}} -> \
{-1463.1, -759.287, 3.53607, 3.53607}, {{10.9375, 61.5}, {678.438, 653.5}} -> \
{-87.5718, -856.308, 3.53607, 3.53607}, {{66.5625, 117.063}, {678.438, \
653.5}} -> {-284.155, -856.308, 3.53607, 3.53607}, {{122.125, 172.625}, \
{678.438, 653.5}} -> {-480.628, -856.308, 3.53607, 3.53607}, {{177.688, \
228.188}, {678.438, 653.5}} -> {-677.101, -856.308, 3.53607, 3.53607}, \
{{233.25, 283.75}, {678.438, 653.5}} -> {-873.574, -856.308, 3.53607, \
3.53607}, {{288.813, 339.313}, {678.438, 653.5}} -> {-1070.05, -856.308, \
3.53607, 3.53607}, {{344.375, 394.938}, {678.438, 653.5}} -> {-1266.63, \
-856.308, 3.53607, 3.53607}, {{399.938, 450.5}, {678.438, 653.5}} -> \
{-1463.1, -856.308, 3.53607, 3.53607}, {{10.9375, 61.5}, {651, 626.063}} -> \
{-87.5718, -953.329, 3.53607, 3.53607}, {{66.5625, 117.063}, {651, 626.063}} -> \
{-284.155, -953.329, 3.53607, 3.53607}, {{122.125, 172.625}, {651, 626.063}} -> \
{-480.628, -953.329, 3.53607, 3.53607}, {{177.688, 228.188}, {651, 626.063}} -> \
{-677.101, -953.329, 3.53607, 3.53607}, {{233.25, 283.75}, {651, 626.063}} -> \
{-873.574, -953.329, 3.53607, 3.53607}, {{288.813, 339.313}, {651, 626.063}} -> \
{-1070.05, -953.329, 3.53607, 3.53607}, {{344.375, 394.938}, {651, 626.063}} -> \
{-1266.63, -953.329, 3.53607, 3.53607}, {{399.938, 450.5}, {651, 626.063}} -> \
{-1463.1, -953.329, 3.53607, 3.53607}, {{10.9375, 61.5}, {623.563, 598.625}} -> \
{-87.5718, -1050.35, 3.53607, 3.53607}, {{66.5625, 117.063}, {623.563, \
598.625}} -> {-284.155, -1050.35, 3.53607, 3.53607}, {{122.125, 172.625}, \
{623.563, 598.625}} -> {-480.628, -1050.35, 3.53607, 3.53607}, {{177.688, \
228.188}, {623.563, 598.625}} -> {-677.101, -1050.35, 3.53607, 3.53607}, \
{{233.25, 283.75}, {623.563, 598.625}} -> {-873.574, -1050.35, 3.53607, \
3.53607}, {{288.813, 339.313}, {623.563, 598.625}} -> {-1070.05, -1050.35, \
3.53607, 3.53607}, {{344.375, 394.938}, {623.563, 598.625}} -> {-1266.63, \
-1050.35, 3.53607, 3.53607}, {{399.938, 450.5}, {623.563, 598.625}} -> \
{-1463.1, -1050.35, 3.53607, 3.53607}, {{10.9375, 61.5}, {596.125, 571.188}} -> \
{-87.5718, -1147.37, 3.53607, 3.53607}, {{66.5625, 117.063}, {596.125, \
571.188}} -> {-284.155, -1147.37, 3.53607, 3.53607}, {{122.125, 172.625}, \
{596.125, 571.188}} -> {-480.628, -1147.37, 3.53607, 3.53607}, {{177.688, \
228.188}, {596.125, 571.188}} -> {-677.101, -1147.37, 3.53607, 3.53607}, \
{{233.25, 283.75}, {596.125, 571.188}} -> {-873.574, -1147.37, 3.53607, \
3.53607}, {{288.813, 339.313}, {596.125, 571.188}} -> {-1070.05, -1147.37, \
3.53607, 3.53607}, {{344.375, 394.938}, {596.125, 571.188}} -> {-1266.63, \
-1147.37, 3.53607, 3.53607}, {{399.938, 450.5}, {596.125, 571.188}} -> \
{-1463.1, -1147.37, 3.53607, 3.53607}, {{10.9375, 61.5}, {568.688, 543.75}} -> \
{-87.5718, -1244.39, 3.53607, 3.53607}, {{66.5625, 117.063}, {568.688, \
543.75}} -> {-284.155, -1244.39, 3.53607, 3.53607}, {{122.125, 172.625}, \
{568.688, 543.75}} -> {-480.628, -1244.39, 3.53607, 3.53607}, {{177.688, \
228.188}, {568.688, 543.75}} -> {-677.101, -1244.39, 3.53607, 3.53607}, \
{{233.25, 283.75}, {568.688, 543.75}} -> {-873.574, -1244.39, 3.53607, \
3.53607}, {{288.813, 339.313}, {568.688, 543.75}} -> {-1070.05, -1244.39, \
3.53607, 3.53607}, {{344.375, 394.938}, {568.688, 543.75}} -> {-1266.63, \
-1244.39, 3.53607, 3.53607}, {{399.938, 450.5}, {568.688, 543.75}} -> \
{-1463.1, -1244.39, 3.53607, 3.53607}, {{10.9375, 61.5}, {541.25, 516.313}} -> \
{-87.5718, -1341.41, 3.53607, 3.53607}, {{66.5625, 117.063}, {541.25, \
516.313}} -> {-284.155, -1341.41, 3.53607, 3.53607}, {{122.125, 172.625}, \
{541.25, 516.313}} -> {-480.628, -1341.41, 3.53607, 3.53607}, {{177.688, \
228.188}, {541.25, 516.313}} -> {-677.101, -1341.41, 3.53607, 3.53607}, \
{{233.25, 283.75}, {541.25, 516.313}} -> {-873.574, -1341.41, 3.53607, \
3.53607}, {{288.813, 339.313}, {541.25, 516.313}} -> {-1070.05, -1341.41, \
3.53607, 3.53607}, {{344.375, 394.938}, {541.25, 516.313}} -> {-1266.63, \
-1341.41, 3.53607, 3.53607}, {{399.938, 450.5}, {541.25, 516.313}} -> \
{-1463.1, -1341.41, 3.53607, 3.53607}, {{10.9375, 61.5}, {513.813, 488.875}} -> \
{-87.5718, -1438.43, 3.53607, 3.53607}, {{66.5625, 117.063}, {513.813, \
488.875}} -> {-284.155, -1438.43, 3.53607, 3.53607}, {{122.125, 172.625}, \
{513.813, 488.875}} -> {-480.628, -1438.43, 3.53607, 3.53607}, {{177.688, \
228.188}, {513.813, 488.875}} -> {-677.101, -1438.43, 3.53607, 3.53607}, \
{{233.25, 283.75}, {513.813, 488.875}} -> {-873.574, -1438.43, 3.53607, \
3.53607}, {{288.813, 339.313}, {513.813, 488.875}} -> {-1070.05, -1438.43, \
3.53607, 3.53607}, {{344.375, 394.938}, {513.813, 488.875}} -> {-1266.63, \
-1438.43, 3.53607, 3.53607}, {{399.938, 450.5}, {513.813, 488.875}} -> \
{-1463.1, -1438.43, 3.53607, 3.53607}, {{10.9375, 61.5}, {486.375, 461.375}} -> \
{-86.9117, -1527.54, 3.51784, 3.51784}, {{66.5625, 117.063}, {486.375, \
461.375}} -> {-282.482, -1527.54, 3.51784, 3.51784}, {{122.125, 172.625}, \
{486.375, 461.375}} -> {-477.942, -1527.54, 3.51784, 3.51784}, {{177.688, \
228.188}, {486.375, 461.375}} -> {-673.402, -1527.54, 3.51784, 3.51784}, \
{{233.25, 283.75}, {486.375, 461.375}} -> {-868.862, -1527.54, 3.51784, \
3.51784}, {{288.813, 339.313}, {486.375, 461.375}} -> {-1064.32, -1527.54, \
3.51784, 3.51784}, {{344.375, 394.938}, {486.375, 461.375}} -> {-1259.89, \
-1527.54, 3.51784, 3.51784}, {{399.938, 450.5}, {486.375, 461.375}} -> \
{-1455.35, -1527.54, 3.51784, 3.51784}, {{10.9375, 61.5}, {458.938, 433.938}} -> \
{-86.9117, -1624.06, 3.51784, 3.51784}, {{66.5625, 117.063}, {458.938, \
433.938}} -> {-282.482, -1624.06, 3.51784, 3.51784}, {{122.125, 172.625}, \
{458.938, 433.938}} -> {-477.942, -1624.06, 3.51784, 3.51784}, {{177.688, \
228.188}, {458.938, 433.938}} -> {-673.402, -1624.06, 3.51784, 3.51784}, \
{{233.25, 283.75}, {458.938, 433.938}} -> {-868.862, -1624.06, 3.51784, \
3.51784}, {{288.813, 339.313}, {458.938, 433.938}} -> {-1064.32, -1624.06, \
3.51784, 3.51784}, {{344.375, 394.938}, {458.938, 433.938}} -> {-1259.89, \
-1624.06, 3.51784, 3.51784}, {{399.938, 450.5}, {458.938, 433.938}} -> \
{-1455.35, -1624.06, 3.51784, 3.51784}, {{10.9375, 61.5}, {431.438, 406.5}} -> \
{-87.5718, -1729.72, 3.53607, 3.53607}, {{66.5625, 117.063}, {431.438, 406.5}}
   -> {-284.155, -1729.72, 3.53607, 3.53607}, {{122.125, 172.625}, {431.438, \
406.5}} -> {-480.628, -1729.72, 3.53607, 3.53607}, {{177.688, 228.188}, \
{431.438, 406.5}} -> {-677.101, -1729.72, 3.53607, 3.53607}, {{233.25, \
283.75}, {431.438, 406.5}} -> {-873.574, -1729.72, 3.53607, 3.53607}, \
{{288.813, 339.313}, {431.438, 406.5}} -> {-1070.05, -1729.72, 3.53607, \
3.53607}, {{344.375, 394.938}, {431.438, 406.5}} -> {-1266.63, -1729.72, \
3.53607, 3.53607}, {{399.938, 450.5}, {431.438, 406.5}} -> {-1463.1, \
-1729.72, 3.53607, 3.53607}, {{10.9375, 61.5}, {404, 379.063}} -> {-87.5718, \
-1826.74, 3.53607, 3.53607}, {{66.5625, 117.063}, {404, 379.063}} -> \
{-284.155, -1826.74, 3.53607, 3.53607}, {{122.125, 172.625}, {404, 379.063}} -> \
{-480.628, -1826.74, 3.53607, 3.53607}, {{177.688, 228.188}, {404, 379.063}} -> \
{-677.101, -1826.74, 3.53607, 3.53607}, {{233.25, 283.75}, {404, 379.063}} -> \
{-873.574, -1826.74, 3.53607, 3.53607}, {{288.813, 339.313}, {404, 379.063}} -> \
{-1070.05, -1826.74, 3.53607, 3.53607}, {{344.375, 394.938}, {404, 379.063}} -> \
{-1266.63, -1826.74, 3.53607, 3.53607}, {{399.938, 450.5}, {404, 379.063}} -> \
{-1463.1, -1826.74, 3.53607, 3.53607}, {{10.9375, 61.5}, {376.563, 351.625}} -> \
{-87.5718, -1923.76, 3.53607, 3.53607}, {{66.5625, 117.063}, {376.563, \
351.625}} -> {-284.155, -1923.76, 3.53607, 3.53607}, {{122.125, 172.625}, \
{376.563, 351.625}} -> {-480.628, -1923.76, 3.53607, 3.53607}, {{177.688, \
228.188}, {376.563, 351.625}} -> {-677.101, -1923.76, 3.53607, 3.53607}, \
{{233.25, 283.75}, {376.563, 351.625}} -> {-873.574, -1923.76, 3.53607, \
3.53607}, {{288.813, 339.313}, {376.563, 351.625}} -> {-1070.05, -1923.76, \
3.53607, 3.53607}, {{344.375, 394.938}, {376.563, 351.625}} -> {-1266.63, \
-1923.76, 3.53607, 3.53607}, {{399.938, 450.5}, {376.563, 351.625}} -> \
{-1463.1, -1923.76, 3.53607, 3.53607}, {{10.9375, 61.5}, {349.125, 324.188}} -> \
{-87.5718, -2020.78, 3.53607, 3.53607}, {{66.5625, 117.063}, {349.125, \
324.188}} -> {-284.155, -2020.78, 3.53607, 3.53607}, {{122.125, 172.625}, \
{349.125, 324.188}} -> {-480.628, -2020.78, 3.53607, 3.53607}, {{177.688, \
228.188}, {349.125, 324.188}} -> {-677.101, -2020.78, 3.53607, 3.53607}, \
{{233.25, 283.75}, {349.125, 324.188}} -> {-873.574, -2020.78, 3.53607, \
3.53607}, {{288.813, 339.313}, {349.125, 324.188}} -> {-1070.05, -2020.78, \
3.53607, 3.53607}, {{344.375, 394.938}, {349.125, 324.188}} -> {-1266.63, \
-2020.78, 3.53607, 3.53607}, {{399.938, 450.5}, {349.125, 324.188}} -> \
{-1463.1, -2020.78, 3.53607, 3.53607}, {{10.9375, 61.5}, {321.688, 296.75}} -> \
{-87.5718, -2117.8, 3.53607, 3.53607}, {{66.5625, 117.063}, {321.688, \
296.75}} -> {-284.155, -2117.8, 3.53607, 3.53607}, {{122.125, 172.625}, \
{321.688, 296.75}} -> {-480.628, -2117.8, 3.53607, 3.53607}, {{177.688, \
228.188}, {321.688, 296.75}} -> {-677.101, -2117.8, 3.53607, 3.53607}, \
{{233.25, 283.75}, {321.688, 296.75}} -> {-873.574, -2117.8, 3.53607, \
3.53607}, {{288.813, 339.313}, {321.688, 296.75}} -> {-1070.05, -2117.8, \
3.53607, 3.53607}, {{344.375, 394.938}, {321.688, 296.75}} -> {-1266.63, \
-2117.8, 3.53607, 3.53607}, {{399.938, 450.5}, {321.688, 296.75}} -> \
{-1463.1, -2117.8, 3.53607, 3.53607}, {{10.9375, 61.5}, {294.25, 269.313}} -> \
{-87.5718, -2214.82, 3.53607, 3.53607}, {{66.5625, 117.063}, {294.25, \
269.313}} -> {-284.155, -2214.82, 3.53607, 3.53607}, {{122.125, 172.625}, \
{294.25, 269.313}} -> {-480.628, -2214.82, 3.53607, 3.53607}, {{177.688, \
228.188}, {294.25, 269.313}} -> {-677.101, -2214.82, 3.53607, 3.53607}, \
{{233.25, 283.75}, {294.25, 269.313}} -> {-873.574, -2214.82, 3.53607, \
3.53607}, {{288.813, 339.313}, {294.25, 269.313}} -> {-1070.05, -2214.82, \
3.53607, 3.53607}, {{344.375, 394.938}, {294.25, 269.313}} -> {-1266.63, \
-2214.82, 3.53607, 3.53607}, {{399.938, 450.5}, {294.25, 269.313}} -> \
{-1463.1, -2214.82, 3.53607, 3.53607}, {{10.9375, 61.5}, {266.813, 241.875}} -> \
{-87.5718, -2311.84, 3.53607, 3.53607}, {{66.5625, 117.063}, {266.813, \
241.875}} -> {-284.155, -2311.84, 3.53607, 3.53607}, {{122.125, 172.625}, \
{266.813, 241.875}} -> {-480.628, -2311.84, 3.53607, 3.53607}, {{177.688, \
228.188}, {266.813, 241.875}} -> {-677.101, -2311.84, 3.53607, 3.53607}, \
{{233.25, 283.75}, {266.813, 241.875}} -> {-873.574, -2311.84, 3.53607, \
3.53607}, {{288.813, 339.313}, {266.813, 241.875}} -> {-1070.05, -2311.84, \
3.53607, 3.53607}, {{344.375, 394.938}, {266.813, 241.875}} -> {-1266.63, \
-2311.84, 3.53607, 3.53607}, {{399.938, 450.5}, {266.813, 241.875}} -> \
{-1463.1, -2311.84, 3.53607, 3.53607}, {{10.9375, 61.5}, {239.375, 214.438}} -> \
{-87.5718, -2408.86, 3.53607, 3.53607}, {{66.5625, 117.063}, {239.375, \
214.438}} -> {-284.155, -2408.86, 3.53607, 3.53607}, {{122.125, 172.625}, \
{239.375, 214.438}} -> {-480.628, -2408.86, 3.53607, 3.53607}, {{177.688, \
228.188}, {239.375, 214.438}} -> {-677.101, -2408.86, 3.53607, 3.53607}, \
{{233.25, 283.75}, {239.375, 214.438}} -> {-873.574, -2408.86, 3.53607, \
3.53607}, {{288.813, 339.313}, {239.375, 214.438}} -> {-1070.05, -2408.86, \
3.53607, 3.53607}, {{344.375, 394.938}, {239.375, 214.438}} -> {-1266.63, \
-2408.86, 3.53607, 3.53607}, {{399.938, 450.5}, {239.375, 214.438}} -> \
{-1463.1, -2408.86, 3.53607, 3.53607}, {{10.9375, 61.5}, {211.938, 187}} -> \
{-87.5718, -2505.88, 3.53607, 3.53607}, {{66.5625, 117.063}, {211.938, 187}} -> \
{-284.155, -2505.88, 3.53607, 3.53607}, {{122.125, 172.625}, {211.938, 187}} -> \
{-480.628, -2505.88, 3.53607, 3.53607}, {{177.688, 228.188}, {211.938, 187}} -> \
{-677.101, -2505.88, 3.53607, 3.53607}, {{233.25, 283.75}, {211.938, 187}} -> \
{-873.574, -2505.88, 3.53607, 3.53607}, {{288.813, 339.313}, {211.938, 187}} -> \
{-1070.05, -2505.88, 3.53607, 3.53607}, {{344.375, 394.938}, {211.938, 187}} -> \
{-1266.63, -2505.88, 3.53607, 3.53607}, {{399.938, 450.5}, {211.938, 187}} -> \
{-1463.1, -2505.88, 3.53607, 3.53607}, {{10.9375, 61.5}, {184.5, 159.563}} -> \
{-87.5718, -2602.9, 3.53607, 3.53607}, {{66.5625, 117.063}, {184.5, 159.563}} -> \
{-284.155, -2602.9, 3.53607, 3.53607}, {{122.125, 172.625}, {184.5, 159.563}} -> \
{-480.628, -2602.9, 3.53607, 3.53607}, {{177.688, 228.188}, {184.5, 159.563}} -> \
{-677.101, -2602.9, 3.53607, 3.53607}, {{233.25, 283.75}, {184.5, 159.563}} -> \
{-873.574, -2602.9, 3.53607, 3.53607}, {{288.813, 339.313}, {184.5, 159.563}} -> \
{-1070.05, -2602.9, 3.53607, 3.53607}, {{344.375, 394.938}, {184.5, 159.563}} -> \
{-1266.63, -2602.9, 3.53607, 3.53607}, {{399.938, 450.5}, {184.5, 159.563}} -> \
{-1463.1, -2602.9, 3.53607, 3.53607}, {{10.9375, 61.5}, {157.063, 132.125}} -> \
{-87.5718, -2699.93, 3.53607, 3.53607}, {{66.5625, 117.063}, {157.063, \
132.125}} -> {-284.155, -2699.93, 3.53607, 3.53607}, {{122.125, 172.625}, \
{157.063, 132.125}} -> {-480.628, -2699.93, 3.53607, 3.53607}, {{177.688, \
228.188}, {157.063, 132.125}} -> {-677.101, -2699.93, 3.53607, 3.53607}, \
{{233.25, 283.75}, {157.063, 132.125}} -> {-873.574, -2699.93, 3.53607, \
3.53607}, {{288.813, 339.313}, {157.063, 132.125}} -> {-1070.05, -2699.93, \
3.53607, 3.53607}, {{344.375, 394.938}, {157.063, 132.125}} -> {-1266.63, \
-2699.93, 3.53607, 3.53607}, {{399.938, 450.5}, {157.063, 132.125}} -> \
{-1463.1, -2699.93, 3.53607, 3.53607}, {{10.9375, 61.5}, {129.625, 104.625}} -> \
{-86.9117, -2782.53, 3.51784, 3.51784}, {{66.5625, 117.063}, {129.625, \
104.625}} -> {-282.482, -2782.53, 3.51784, 3.51784}, {{122.125, 172.625}, \
{129.625, 104.625}} -> {-477.942, -2782.53, 3.51784, 3.51784}, {{177.688, \
228.188}, {129.625, 104.625}} -> {-673.402, -2782.53, 3.51784, 3.51784}, \
{{233.25, 283.75}, {129.625, 104.625}} -> {-868.862, -2782.53, 3.51784, \
3.51784}, {{288.813, 339.313}, {129.625, 104.625}} -> {-1064.32, -2782.53, \
3.51784, 3.51784}, {{344.375, 394.938}, {129.625, 104.625}} -> {-1259.89, \
-2782.53, 3.51784, 3.51784}, {{399.938, 450.5}, {129.625, 104.625}} -> \
{-1455.35, -2782.53, 3.51784, 3.51784}, {{10.9375, 61.5}, {102.188, 77.1875}} -> \
{-86.9117, -2879.05, 3.51784, 3.51784}, {{66.5625, 117.063}, {102.188, \
77.1875}} -> {-282.482, -2879.05, 3.51784, 3.51784}, {{122.125, 172.625}, \
{102.188, 77.1875}} -> {-477.942, -2879.05, 3.51784, 3.51784}, {{177.688, \
228.188}, {102.188, 77.1875}} -> {-673.402, -2879.05, 3.51784, 3.51784}, \
{{233.25, 283.75}, {102.188, 77.1875}} -> {-868.862, -2879.05, 3.51784, \
3.51784}, {{288.813, 339.313}, {102.188, 77.1875}} -> {-1064.32, -2879.05, \
3.51784, 3.51784}, {{344.375, 394.938}, {102.188, 77.1875}} -> {-1259.89, \
-2879.05, 3.51784, 3.51784}, {{399.938, 450.5}, {102.188, 77.1875}} -> \
{-1455.35, -2879.05, 3.51784, 3.51784}, {{10.9375, 61.5}, {74.6875, 49.75}} -> \
{-87.5718, -2991.21, 3.53607, 3.53607}, {{66.5625, 117.063}, {74.6875, \
49.75}} -> {-284.155, -2991.21, 3.53607, 3.53607}, {{122.125, 172.625}, \
{74.6875, 49.75}} -> {-480.628, -2991.21, 3.53607, 3.53607}, {{177.688, \
228.188}, {74.6875, 49.75}} -> {-677.101, -2991.21, 3.53607, 3.53607}, \
{{233.25, 283.75}, {74.6875, 49.75}} -> {-873.574, -2991.21, 3.53607, \
3.53607}, {{288.813, 339.313}, {74.6875, 49.75}} -> {-1070.05, -2991.21, \
3.53607, 3.53607}, {{344.375, 394.938}, {74.6875, 49.75}} -> {-1266.63, \
-2991.21, 3.53607, 3.53607}, {{399.938, 450.5}, {74.6875, 49.75}} -> \
{-1463.1, -2991.21, 3.53607, 3.53607}, {{10.9375, 61.5}, {47.25, 22.3125}} -> \
{-87.5718, -3088.23, 3.53607, 3.53607}, {{66.5625, 117.063}, {47.25, \
22.3125}} -> {-284.155, -3088.23, 3.53607, 3.53607}, {{122.125, 172.625}, \
{47.25, 22.3125}} -> {-480.628, -3088.23, 3.53607, 3.53607}, {{177.688, \
228.188}, {47.25, 22.3125}} -> {-677.101, -3088.23, 3.53607, 3.53607}, \
{{233.25, 283.75}, {47.25, 22.3125}} -> {-873.574, -3088.23, 3.53607, \
3.53607}, {{288.813, 339.313}, {47.25, 22.3125}} -> {-1070.05, -3088.23, \
3.53607, 3.53607}, {{344.375, 394.938}, {47.25, 22.3125}} -> {-1266.63, \
-3088.23, 3.53607, 3.53607}, {{399.938, 450.5}, {47.25, 22.3125}} -> \
{-1463.1, -3088.23, 3.53607, 3.53607}}]
}, Open  ]],

Cell["\<\
Rule 95 above corresponds to the OR operation. Rule 5 to the AND, rule 90 to \
the XOR. Rule 240 to the left NOT and rule 170 to the right NOT.
We mention as a side comment other representations of predicates generated by \
the author based on the work at [3]. For instance, the following are \
representations of the function XOR \
\>", "Text"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0535714 0.0297619 0.0535714 0.0297619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02381 .02381 m
.02381 .05357 L
.05357 .05357 L
.05357 .02381 L
F
.02381 .05357 m
.02381 .08333 L
.05357 .08333 L
.05357 .05357 L
F
.02381 .08333 m
.02381 .1131 L
.05357 .1131 L
.05357 .08333 L
F
.02381 .1131 m
.02381 .14286 L
.05357 .14286 L
.05357 .1131 L
F
.02381 .14286 m
.02381 .17262 L
.05357 .17262 L
.05357 .14286 L
F
.02381 .17262 m
.02381 .20238 L
.05357 .20238 L
.05357 .17262 L
F
.02381 .20238 m
.02381 .23214 L
.05357 .23214 L
.05357 .20238 L
F
.02381 .23214 m
.02381 .2619 L
.05357 .2619 L
.05357 .23214 L
F
.02381 .2619 m
.02381 .29167 L
.05357 .29167 L
.05357 .2619 L
F
.02381 .29167 m
.02381 .32143 L
.05357 .32143 L
.05357 .29167 L
F
.02381 .32143 m
.02381 .35119 L
.05357 .35119 L
.05357 .32143 L
F
.02381 .35119 m
.02381 .38095 L
.05357 .38095 L
.05357 .35119 L
F
.02381 .38095 m
.02381 .41071 L
.05357 .41071 L
.05357 .38095 L
F
.02381 .41071 m
.02381 .44048 L
.05357 .44048 L
.05357 .41071 L
F
.02381 .44048 m
.02381 .47024 L
.05357 .47024 L
.05357 .44048 L
F
.02381 .47024 m
.02381 .5 L
.05357 .5 L
.05357 .47024 L
F
.02381 .5 m
.02381 .52976 L
.05357 .52976 L
.05357 .5 L
F
.02381 .52976 m
.02381 .55952 L
.05357 .55952 L
.05357 .52976 L
F
.02381 .55952 m
.02381 .58929 L
.05357 .58929 L
.05357 .55952 L
F
.02381 .58929 m
.02381 .61905 L
.05357 .61905 L
.05357 .58929 L
F
.02381 .61905 m
.02381 .64881 L
.05357 .64881 L
.05357 .61905 L
F
.02381 .64881 m
.02381 .67857 L
.05357 .67857 L
.05357 .64881 L
F
.02381 .67857 m
.02381 .70833 L
.05357 .70833 L
.05357 .67857 L
F
.02381 .70833 m
.02381 .7381 L
.05357 .7381 L
.05357 .70833 L
F
.02381 .7381 m
.02381 .76786 L
.05357 .76786 L
.05357 .7381 L
F
.02381 .76786 m
.02381 .79762 L
.05357 .79762 L
.05357 .76786 L
F
.02381 .79762 m
.02381 .82738 L
.05357 .82738 L
.05357 .79762 L
F
.02381 .82738 m
.02381 .85714 L
.05357 .85714 L
.05357 .82738 L
F
.02381 .85714 m
.02381 .8869 L
.05357 .8869 L
.05357 .85714 L
F
.02381 .8869 m
.02381 .91667 L
.05357 .91667 L
.05357 .8869 L
F
.02381 .91667 m
.02381 .94643 L
.05357 .94643 L
.05357 .91667 L
F
.02381 .94643 m
.02381 .97619 L
.05357 .97619 L
.05357 .94643 L
F
.05357 .02381 m
.05357 .05357 L
.08333 .05357 L
.08333 .02381 L
F
.968 .032 .032 r
.05357 .05357 m
.05357 .08333 L
.08333 .08333 L
.08333 .05357 L
F
1 0 0 r
.05357 .08333 m
.05357 .1131 L
.08333 .1131 L
.08333 .08333 L
F
.968 .032 .032 r
.05357 .1131 m
.05357 .14286 L
.08333 .14286 L
.08333 .1131 L
F
1 0 0 r
.05357 .14286 m
.05357 .17262 L
.08333 .17262 L
.08333 .14286 L
F
.968 .032 .032 r
.05357 .17262 m
.05357 .20238 L
.08333 .20238 L
.08333 .17262 L
F
1 0 0 r
.05357 .20238 m
.05357 .23214 L
.08333 .23214 L
.08333 .20238 L
F
.968 .032 .032 r
.05357 .23214 m
.05357 .2619 L
.08333 .2619 L
.08333 .23214 L
F
1 0 0 r
.05357 .2619 m
.05357 .29167 L
.08333 .29167 L
.08333 .2619 L
F
.968 .032 .032 r
.05357 .29167 m
.05357 .32143 L
.08333 .32143 L
.08333 .29167 L
F
1 0 0 r
.05357 .32143 m
.05357 .35119 L
.08333 .35119 L
.08333 .32143 L
F
.968 .032 .032 r
.05357 .35119 m
.05357 .38095 L
.08333 .38095 L
.08333 .35119 L
F
1 0 0 r
.05357 .38095 m
.05357 .41071 L
.08333 .41071 L
.08333 .38095 L
F
.968 .032 .032 r
.05357 .41071 m
.05357 .44048 L
.08333 .44048 L
.08333 .41071 L
F
1 0 0 r
.05357 .44048 m
.05357 .47024 L
.08333 .47024 L
.08333 .44048 L
F
.968 .032 .032 r
.05357 .47024 m
.05357 .5 L
.08333 .5 L
.08333 .47024 L
F
1 0 0 r
.05357 .5 m
.05357 .52976 L
.08333 .52976 L
.08333 .5 L
F
.968 .032 .032 r
.05357 .52976 m
.05357 .55952 L
.08333 .55952 L
.08333 .52976 L
F
1 0 0 r
.05357 .55952 m
.05357 .58929 L
.08333 .58929 L
.08333 .55952 L
F
.968 .032 .032 r
.05357 .58929 m
.05357 .61905 L
.08333 .61905 L
.08333 .58929 L
F
1 0 0 r
.05357 .61905 m
.05357 .64881 L
.08333 .64881 L
.08333 .61905 L
F
.968 .032 .032 r
.05357 .64881 m
.05357 .67857 L
.08333 .67857 L
.08333 .64881 L
F
1 0 0 r
.05357 .67857 m
.05357 .70833 L
.08333 .70833 L
.08333 .67857 L
F
.968 .032 .032 r
.05357 .70833 m
.05357 .7381 L
.08333 .7381 L
.08333 .70833 L
F
1 0 0 r
.05357 .7381 m
.05357 .76786 L
.08333 .76786 L
.08333 .7381 L
F
.968 .032 .032 r
.05357 .76786 m
.05357 .79762 L
.08333 .79762 L
.08333 .76786 L
F
1 0 0 r
.05357 .79762 m
.05357 .82738 L
.08333 .82738 L
.08333 .79762 L
F
.968 .032 .032 r
.05357 .82738 m
.05357 .85714 L
.08333 .85714 L
.08333 .82738 L
F
1 0 0 r
.05357 .85714 m
.05357 .8869 L
.08333 .8869 L
.08333 .85714 L
F
.968 .032 .032 r
.05357 .8869 m
.05357 .91667 L
.08333 .91667 L
.08333 .8869 L
F
1 0 0 r
.05357 .91667 m
.05357 .94643 L
.08333 .94643 L
.08333 .91667 L
F
.968 .032 .032 r
.05357 .94643 m
.05357 .97619 L
.08333 .97619 L
.08333 .94643 L
F
1 0 0 r
.08333 .02381 m
.08333 .05357 L
.1131 .05357 L
.1131 .02381 L
F
.08333 .05357 m
.08333 .08333 L
.1131 .08333 L
.1131 .05357 L
F
.935 .065 .065 r
.08333 .08333 m
.08333 .1131 L
.1131 .1131 L
.1131 .08333 L
F
.08333 .1131 m
.08333 .14286 L
.1131 .14286 L
.1131 .1131 L
F
1 0 0 r
.08333 .14286 m
.08333 .17262 L
.1131 .17262 L
.1131 .14286 L
F
.08333 .17262 m
.08333 .20238 L
.1131 .20238 L
.1131 .17262 L
F
.935 .065 .065 r
.08333 .20238 m
.08333 .23214 L
.1131 .23214 L
.1131 .20238 L
F
.08333 .23214 m
.08333 .2619 L
.1131 .2619 L
.1131 .23214 L
F
1 0 0 r
.08333 .2619 m
.08333 .29167 L
.1131 .29167 L
.1131 .2619 L
F
.08333 .29167 m
.08333 .32143 L
.1131 .32143 L
.1131 .29167 L
F
.935 .065 .065 r
.08333 .32143 m
.08333 .35119 L
.1131 .35119 L
.1131 .32143 L
F
.08333 .35119 m
.08333 .38095 L
.1131 .38095 L
.1131 .35119 L
F
1 0 0 r
.08333 .38095 m
.08333 .41071 L
.1131 .41071 L
.1131 .38095 L
F
.08333 .41071 m
.08333 .44048 L
.1131 .44048 L
.1131 .41071 L
F
.935 .065 .065 r
.08333 .44048 m
.08333 .47024 L
.1131 .47024 L
.1131 .44048 L
F
.08333 .47024 m
.08333 .5 L
.1131 .5 L
.1131 .47024 L
F
1 0 0 r
.08333 .5 m
.08333 .52976 L
.1131 .52976 L
.1131 .5 L
F
.08333 .52976 m
.08333 .55952 L
.1131 .55952 L
.1131 .52976 L
F
.935 .065 .065 r
.08333 .55952 m
.08333 .58929 L
.1131 .58929 L
.1131 .55952 L
F
.08333 .58929 m
.08333 .61905 L
.1131 .61905 L
.1131 .58929 L
F
1 0 0 r
.08333 .61905 m
.08333 .64881 L
.1131 .64881 L
.1131 .61905 L
F
.08333 .64881 m
.08333 .67857 L
.1131 .67857 L
.1131 .64881 L
F
.935 .065 .065 r
.08333 .67857 m
.08333 .70833 L
.1131 .70833 L
.1131 .67857 L
F
.08333 .70833 m
.08333 .7381 L
.1131 .7381 L
.1131 .70833 L
F
1 0 0 r
.08333 .7381 m
.08333 .76786 L
.1131 .76786 L
.1131 .7381 L
F
.08333 .76786 m
.08333 .79762 L
.1131 .79762 L
.1131 .76786 L
F
.935 .065 .065 r
.08333 .79762 m
.08333 .82738 L
.1131 .82738 L
.1131 .79762 L
F
.08333 .82738 m
.08333 .85714 L
.1131 .85714 L
.1131 .82738 L
F
1 0 0 r
.08333 .85714 m
.08333 .8869 L
.1131 .8869 L
.1131 .85714 L
F
.08333 .8869 m
.08333 .91667 L
.1131 .91667 L
.1131 .8869 L
F
.935 .065 .065 r
.08333 .91667 m
.08333 .94643 L
.1131 .94643 L
.1131 .91667 L
F
.08333 .94643 m
.08333 .97619 L
.1131 .97619 L
.1131 .94643 L
F
1 0 0 r
.1131 .02381 m
.1131 .05357 L
.14286 .05357 L
.14286 .02381 L
F
.968 .032 .032 r
.1131 .05357 m
.1131 .08333 L
.14286 .08333 L
.14286 .05357 L
F
.935 .065 .065 r
.1131 .08333 m
.1131 .1131 L
.14286 .1131 L
.14286 .08333 L
F
.903 .097 .097 r
.1131 .1131 m
.1131 .14286 L
.14286 .14286 L
.14286 .1131 L
F
1 0 0 r
.1131 .14286 m
.1131 .17262 L
.14286 .17262 L
.14286 .14286 L
F
.968 .032 .032 r
.1131 .17262 m
.1131 .20238 L
.14286 .20238 L
.14286 .17262 L
F
.935 .065 .065 r
.1131 .20238 m
.1131 .23214 L
.14286 .23214 L
.14286 .20238 L
F
.903 .097 .097 r
.1131 .23214 m
.1131 .2619 L
.14286 .2619 L
.14286 .23214 L
F
1 0 0 r
.1131 .2619 m
.1131 .29167 L
.14286 .29167 L
.14286 .2619 L
F
.968 .032 .032 r
.1131 .29167 m
.1131 .32143 L
.14286 .32143 L
.14286 .29167 L
F
.935 .065 .065 r
.1131 .32143 m
.1131 .35119 L
.14286 .35119 L
.14286 .32143 L
F
.903 .097 .097 r
.1131 .35119 m
.1131 .38095 L
.14286 .38095 L
.14286 .35119 L
F
1 0 0 r
.1131 .38095 m
.1131 .41071 L
.14286 .41071 L
.14286 .38095 L
F
.968 .032 .032 r
.1131 .41071 m
.1131 .44048 L
.14286 .44048 L
.14286 .41071 L
F
.935 .065 .065 r
.1131 .44048 m
.1131 .47024 L
.14286 .47024 L
.14286 .44048 L
F
.903 .097 .097 r
.1131 .47024 m
.1131 .5 L
.14286 .5 L
.14286 .47024 L
F
1 0 0 r
.1131 .5 m
.1131 .52976 L
.14286 .52976 L
.14286 .5 L
F
.968 .032 .032 r
.1131 .52976 m
.1131 .55952 L
.14286 .55952 L
.14286 .52976 L
F
.935 .065 .065 r
.1131 .55952 m
.1131 .58929 L
.14286 .58929 L
.14286 .55952 L
F
.903 .097 .097 r
.1131 .58929 m
.1131 .61905 L
.14286 .61905 L
.14286 .58929 L
F
1 0 0 r
.1131 .61905 m
.1131 .64881 L
.14286 .64881 L
.14286 .61905 L
F
.968 .032 .032 r
.1131 .64881 m
.1131 .67857 L
.14286 .67857 L
.14286 .64881 L
F
.935 .065 .065 r
.1131 .67857 m
.1131 .70833 L
.14286 .70833 L
.14286 .67857 L
F
.903 .097 .097 r
.1131 .70833 m
.1131 .7381 L
.14286 .7381 L
.14286 .70833 L
F
1 0 0 r
.1131 .7381 m
.1131 .76786 L
.14286 .76786 L
.14286 .7381 L
F
.968 .032 .032 r
.1131 .76786 m
.1131 .79762 L
.14286 .79762 L
.14286 .76786 L
F
.935 .065 .065 r
.1131 .79762 m
.1131 .82738 L
.14286 .82738 L
.14286 .79762 L
F
.903 .097 .097 r
.1131 .82738 m
.1131 .85714 L
.14286 .85714 L
.14286 .82738 L
F
1 0 0 r
.1131 .85714 m
.1131 .8869 L
.14286 .8869 L
.14286 .85714 L
F
.968 .032 .032 r
.1131 .8869 m
.1131 .91667 L
.14286 .91667 L
.14286 .8869 L
F
.935 .065 .065 r
.1131 .91667 m
.1131 .94643 L
.14286 .94643 L
.14286 .91667 L
F
.903 .097 .097 r
.1131 .94643 m
.1131 .97619 L
.14286 .97619 L
.14286 .94643 L
F
1 0 0 r
.14286 .02381 m
.14286 .05357 L
.17262 .05357 L
.17262 .02381 L
F
.14286 .05357 m
.14286 .08333 L
.17262 .08333 L
.17262 .05357 L
F
.14286 .08333 m
.14286 .1131 L
.17262 .1131 L
.17262 .08333 L
F
.14286 .1131 m
.14286 .14286 L
.17262 .14286 L
.17262 .1131 L
F
.871 .129 .129 r
.14286 .14286 m
.14286 .17262 L
.17262 .17262 L
.17262 .14286 L
F
.14286 .17262 m
.14286 .20238 L
.17262 .20238 L
.17262 .17262 L
F
.14286 .20238 m
.14286 .23214 L
.17262 .23214 L
.17262 .20238 L
F
.14286 .23214 m
.14286 .2619 L
.17262 .2619 L
.17262 .23214 L
F
1 0 0 r
.14286 .2619 m
.14286 .29167 L
.17262 .29167 L
.17262 .2619 L
F
.14286 .29167 m
.14286 .32143 L
.17262 .32143 L
.17262 .29167 L
F
.14286 .32143 m
.14286 .35119 L
.17262 .35119 L
.17262 .32143 L
F
.14286 .35119 m
.14286 .38095 L
.17262 .38095 L
.17262 .35119 L
F
.871 .129 .129 r
.14286 .38095 m
.14286 .41071 L
.17262 .41071 L
.17262 .38095 L
F
.14286 .41071 m
.14286 .44048 L
.17262 .44048 L
.17262 .41071 L
F
.14286 .44048 m
.14286 .47024 L
.17262 .47024 L
.17262 .44048 L
F
.14286 .47024 m
.14286 .5 L
.17262 .5 L
.17262 .47024 L
F
1 0 0 r
.14286 .5 m
.14286 .52976 L
.17262 .52976 L
.17262 .5 L
F
.14286 .52976 m
.14286 .55952 L
.17262 .55952 L
.17262 .52976 L
F
.14286 .55952 m
.14286 .58929 L
.17262 .58929 L
.17262 .55952 L
F
.14286 .58929 m
.14286 .61905 L
.17262 .61905 L
.17262 .58929 L
F
.871 .129 .129 r
.14286 .61905 m
.14286 .64881 L
.17262 .64881 L
.17262 .61905 L
F
.14286 .64881 m
.14286 .67857 L
.17262 .67857 L
.17262 .64881 L
F
.14286 .67857 m
.14286 .70833 L
.17262 .70833 L
.17262 .67857 L
F
.14286 .70833 m
.14286 .7381 L
.17262 .7381 L
.17262 .70833 L
F
1 0 0 r
.14286 .7381 m
.14286 .76786 L
.17262 .76786 L
.17262 .7381 L
F
.14286 .76786 m
.14286 .79762 L
.17262 .79762 L
.17262 .76786 L
F
.14286 .79762 m
.14286 .82738 L
.17262 .82738 L
.17262 .79762 L
F
.14286 .82738 m
.14286 .85714 L
.17262 .85714 L
.17262 .82738 L
F
.871 .129 .129 r
.14286 .85714 m
.14286 .8869 L
.17262 .8869 L
.17262 .85714 L
F
.14286 .8869 m
.14286 .91667 L
.17262 .91667 L
.17262 .8869 L
F
.14286 .91667 m
.14286 .94643 L
.17262 .94643 L
.17262 .91667 L
F
.14286 .94643 m
.14286 .97619 L
.17262 .97619 L
.17262 .94643 L
F
1 0 0 r
.17262 .02381 m
.17262 .05357 L
.20238 .05357 L
.20238 .02381 L
F
.968 .032 .032 r
.17262 .05357 m
.17262 .08333 L
.20238 .08333 L
.20238 .05357 L
F
1 0 0 r
.17262 .08333 m
.17262 .1131 L
.20238 .1131 L
.20238 .08333 L
F
.968 .032 .032 r
.17262 .1131 m
.17262 .14286 L
.20238 .14286 L
.20238 .1131 L
F
.871 .129 .129 r
.17262 .14286 m
.17262 .17262 L
.20238 .17262 L
.20238 .14286 L
F
.839 .161 .161 r
.17262 .17262 m
.17262 .20238 L
.20238 .20238 L
.20238 .17262 L
F
.871 .129 .129 r
.17262 .20238 m
.17262 .23214 L
.20238 .23214 L
.20238 .20238 L
F
.839 .161 .161 r
.17262 .23214 m
.17262 .2619 L
.20238 .2619 L
.20238 .23214 L
F
1 0 0 r
.17262 .2619 m
.17262 .29167 L
.20238 .29167 L
.20238 .2619 L
F
.968 .032 .032 r
.17262 .29167 m
.17262 .32143 L
.20238 .32143 L
.20238 .29167 L
F
1 0 0 r
.17262 .32143 m
.17262 .35119 L
.20238 .35119 L
.20238 .32143 L
F
.968 .032 .032 r
.17262 .35119 m
.17262 .38095 L
.20238 .38095 L
.20238 .35119 L
F
.871 .129 .129 r
.17262 .38095 m
.17262 .41071 L
.20238 .41071 L
.20238 .38095 L
F
.839 .161 .161 r
.17262 .41071 m
.17262 .44048 L
.20238 .44048 L
.20238 .41071 L
F
.871 .129 .129 r
.17262 .44048 m
.17262 .47024 L
.20238 .47024 L
.20238 .44048 L
F
.839 .161 .161 r
.17262 .47024 m
.17262 .5 L
.20238 .5 L
.20238 .47024 L
F
1 0 0 r
.17262 .5 m
.17262 .52976 L
.20238 .52976 L
.20238 .5 L
F
.968 .032 .032 r
.17262 .52976 m
.17262 .55952 L
.20238 .55952 L
.20238 .52976 L
F
1 0 0 r
.17262 .55952 m
.17262 .58929 L
.20238 .58929 L
.20238 .55952 L
F
.968 .032 .032 r
.17262 .58929 m
.17262 .61905 L
.20238 .61905 L
.20238 .58929 L
F
.871 .129 .129 r
.17262 .61905 m
.17262 .64881 L
.20238 .64881 L
.20238 .61905 L
F
.839 .161 .161 r
.17262 .64881 m
.17262 .67857 L
.20238 .67857 L
.20238 .64881 L
F
.871 .129 .129 r
.17262 .67857 m
.17262 .70833 L
.20238 .70833 L
.20238 .67857 L
F
.839 .161 .161 r
.17262 .70833 m
.17262 .7381 L
.20238 .7381 L
.20238 .70833 L
F
1 0 0 r
.17262 .7381 m
.17262 .76786 L
.20238 .76786 L
.20238 .7381 L
F
.968 .032 .032 r
.17262 .76786 m
.17262 .79762 L
.20238 .79762 L
.20238 .76786 L
F
1 0 0 r
.17262 .79762 m
.17262 .82738 L
.20238 .82738 L
.20238 .79762 L
F
.968 .032 .032 r
.17262 .82738 m
.17262 .85714 L
.20238 .85714 L
.20238 .82738 L
F
.871 .129 .129 r
.17262 .85714 m
.17262 .8869 L
.20238 .8869 L
.20238 .85714 L
F
.839 .161 .161 r
.17262 .8869 m
.17262 .91667 L
.20238 .91667 L
.20238 .8869 L
F
.871 .129 .129 r
.17262 .91667 m
.17262 .94643 L
.20238 .94643 L
.20238 .91667 L
F
.839 .161 .161 r
.17262 .94643 m
.17262 .97619 L
.20238 .97619 L
.20238 .94643 L
F
1 0 0 r
.20238 .02381 m
.20238 .05357 L
.23214 .05357 L
.23214 .02381 L
F
.20238 .05357 m
.20238 .08333 L
.23214 .08333 L
.23214 .05357 L
F
.935 .065 .065 r
.20238 .08333 m
.20238 .1131 L
.23214 .1131 L
.23214 .08333 L
F
.20238 .1131 m
.20238 .14286 L
.23214 .14286 L
.23214 .1131 L
F
.871 .129 .129 r
.20238 .14286 m
.20238 .17262 L
.23214 .17262 L
.23214 .14286 L
F
.20238 .17262 m
.20238 .20238 L
.23214 .20238 L
.23214 .17262 L
F
.806 .194 .194 r
.20238 .20238 m
.20238 .23214 L
.23214 .23214 L
.23214 .20238 L
F
.20238 .23214 m
.20238 .2619 L
.23214 .2619 L
.23214 .23214 L
F
1 0 0 r
.20238 .2619 m
.20238 .29167 L
.23214 .29167 L
.23214 .2619 L
F
.20238 .29167 m
.20238 .32143 L
.23214 .32143 L
.23214 .29167 L
F
.935 .065 .065 r
.20238 .32143 m
.20238 .35119 L
.23214 .35119 L
.23214 .32143 L
F
.20238 .35119 m
.20238 .38095 L
.23214 .38095 L
.23214 .35119 L
F
.871 .129 .129 r
.20238 .38095 m
.20238 .41071 L
.23214 .41071 L
.23214 .38095 L
F
.20238 .41071 m
.20238 .44048 L
.23214 .44048 L
.23214 .41071 L
F
.806 .194 .194 r
.20238 .44048 m
.20238 .47024 L
.23214 .47024 L
.23214 .44048 L
F
.20238 .47024 m
.20238 .5 L
.23214 .5 L
.23214 .47024 L
F
1 0 0 r
.20238 .5 m
.20238 .52976 L
.23214 .52976 L
.23214 .5 L
F
.20238 .52976 m
.20238 .55952 L
.23214 .55952 L
.23214 .52976 L
F
.935 .065 .065 r
.20238 .55952 m
.20238 .58929 L
.23214 .58929 L
.23214 .55952 L
F
.20238 .58929 m
.20238 .61905 L
.23214 .61905 L
.23214 .58929 L
F
.871 .129 .129 r
.20238 .61905 m
.20238 .64881 L
.23214 .64881 L
.23214 .61905 L
F
.20238 .64881 m
.20238 .67857 L
.23214 .67857 L
.23214 .64881 L
F
.806 .194 .194 r
.20238 .67857 m
.20238 .70833 L
.23214 .70833 L
.23214 .67857 L
F
.20238 .70833 m
.20238 .7381 L
.23214 .7381 L
.23214 .70833 L
F
1 0 0 r
.20238 .7381 m
.20238 .76786 L
.23214 .76786 L
.23214 .7381 L
F
.20238 .76786 m
.20238 .79762 L
.23214 .79762 L
.23214 .76786 L
F
.935 .065 .065 r
.20238 .79762 m
.20238 .82738 L
.23214 .82738 L
.23214 .79762 L
F
.20238 .82738 m
.20238 .85714 L
.23214 .85714 L
.23214 .82738 L
F
.871 .129 .129 r
.20238 .85714 m
.20238 .8869 L
.23214 .8869 L
.23214 .85714 L
F
.20238 .8869 m
.20238 .91667 L
.23214 .91667 L
.23214 .8869 L
F
.806 .194 .194 r
.20238 .91667 m
.20238 .94643 L
.23214 .94643 L
.23214 .91667 L
F
.20238 .94643 m
.20238 .97619 L
.23214 .97619 L
.23214 .94643 L
F
1 0 0 r
.23214 .02381 m
.23214 .05357 L
.2619 .05357 L
.2619 .02381 L
F
.968 .032 .032 r
.23214 .05357 m
.23214 .08333 L
.2619 .08333 L
.2619 .05357 L
F
.935 .065 .065 r
.23214 .08333 m
.23214 .1131 L
.2619 .1131 L
.2619 .08333 L
F
.903 .097 .097 r
.23214 .1131 m
.23214 .14286 L
.2619 .14286 L
.2619 .1131 L
F
.871 .129 .129 r
.23214 .14286 m
.23214 .17262 L
.2619 .17262 L
.2619 .14286 L
F
.839 .161 .161 r
.23214 .17262 m
.23214 .20238 L
.2619 .20238 L
.2619 .17262 L
F
.806 .194 .194 r
.23214 .20238 m
.23214 .23214 L
.2619 .23214 L
.2619 .20238 L
F
.774 .226 .226 r
.23214 .23214 m
.23214 .2619 L
.2619 .2619 L
.2619 .23214 L
F
1 0 0 r
.23214 .2619 m
.23214 .29167 L
.2619 .29167 L
.2619 .2619 L
F
.968 .032 .032 r
.23214 .29167 m
.23214 .32143 L
.2619 .32143 L
.2619 .29167 L
F
.935 .065 .065 r
.23214 .32143 m
.23214 .35119 L
.2619 .35119 L
.2619 .32143 L
F
.903 .097 .097 r
.23214 .35119 m
.23214 .38095 L
.2619 .38095 L
.2619 .35119 L
F
.871 .129 .129 r
.23214 .38095 m
.23214 .41071 L
.2619 .41071 L
.2619 .38095 L
F
.839 .161 .161 r
.23214 .41071 m
.23214 .44048 L
.2619 .44048 L
.2619 .41071 L
F
.806 .194 .194 r
.23214 .44048 m
.23214 .47024 L
.2619 .47024 L
.2619 .44048 L
F
.774 .226 .226 r
.23214 .47024 m
.23214 .5 L
.2619 .5 L
.2619 .47024 L
F
1 0 0 r
.23214 .5 m
.23214 .52976 L
.2619 .52976 L
.2619 .5 L
F
.968 .032 .032 r
.23214 .52976 m
.23214 .55952 L
.2619 .55952 L
.2619 .52976 L
F
.935 .065 .065 r
.23214 .55952 m
.23214 .58929 L
.2619 .58929 L
.2619 .55952 L
F
.903 .097 .097 r
.23214 .58929 m
.23214 .61905 L
.2619 .61905 L
.2619 .58929 L
F
.871 .129 .129 r
.23214 .61905 m
.23214 .64881 L
.2619 .64881 L
.2619 .61905 L
F
.839 .161 .161 r
.23214 .64881 m
.23214 .67857 L
.2619 .67857 L
.2619 .64881 L
F
.806 .194 .194 r
.23214 .67857 m
.23214 .70833 L
.2619 .70833 L
.2619 .67857 L
F
.774 .226 .226 r
.23214 .70833 m
.23214 .7381 L
.2619 .7381 L
.2619 .70833 L
F
1 0 0 r
.23214 .7381 m
.23214 .76786 L
.2619 .76786 L
.2619 .7381 L
F
.968 .032 .032 r
.23214 .76786 m
.23214 .79762 L
.2619 .79762 L
.2619 .76786 L
F
.935 .065 .065 r
.23214 .79762 m
.23214 .82738 L
.2619 .82738 L
.2619 .79762 L
F
.903 .097 .097 r
.23214 .82738 m
.23214 .85714 L
.2619 .85714 L
.2619 .82738 L
F
.871 .129 .129 r
.23214 .85714 m
.23214 .8869 L
.2619 .8869 L
.2619 .85714 L
F
.839 .161 .161 r
.23214 .8869 m
.23214 .91667 L
.2619 .91667 L
.2619 .8869 L
F
.806 .194 .194 r
.23214 .91667 m
.23214 .94643 L
.2619 .94643 L
.2619 .91667 L
F
.774 .226 .226 r
.23214 .94643 m
.23214 .97619 L
.2619 .97619 L
.2619 .94643 L
F
1 0 0 r
.2619 .02381 m
.2619 .05357 L
.29167 .05357 L
.29167 .02381 L
F
.2619 .05357 m
.2619 .08333 L
.29167 .08333 L
.29167 .05357 L
F
.2619 .08333 m
.2619 .1131 L
.29167 .1131 L
.29167 .08333 L
F
.2619 .1131 m
.2619 .14286 L
.29167 .14286 L
.29167 .1131 L
F
.2619 .14286 m
.2619 .17262 L
.29167 .17262 L
.29167 .14286 L
F
.2619 .17262 m
.2619 .20238 L
.29167 .20238 L
.29167 .17262 L
F
.2619 .20238 m
.2619 .23214 L
.29167 .23214 L
.29167 .20238 L
F
.2619 .23214 m
.2619 .2619 L
.29167 .2619 L
.29167 .23214 L
F
.742 .258 .258 r
.2619 .2619 m
.2619 .29167 L
.29167 .29167 L
.29167 .2619 L
F
.2619 .29167 m
.2619 .32143 L
.29167 .32143 L
.29167 .29167 L
F
.2619 .32143 m
.2619 .35119 L
.29167 .35119 L
.29167 .32143 L
F
.2619 .35119 m
.2619 .38095 L
.29167 .38095 L
.29167 .35119 L
F
.2619 .38095 m
.2619 .41071 L
.29167 .41071 L
.29167 .38095 L
F
.2619 .41071 m
.2619 .44048 L
.29167 .44048 L
.29167 .41071 L
F
.2619 .44048 m
.2619 .47024 L
.29167 .47024 L
.29167 .44048 L
F
.2619 .47024 m
.2619 .5 L
.29167 .5 L
.29167 .47024 L
F
1 0 0 r
.2619 .5 m
.2619 .52976 L
.29167 .52976 L
.29167 .5 L
F
.2619 .52976 m
.2619 .55952 L
.29167 .55952 L
.29167 .52976 L
F
.2619 .55952 m
.2619 .58929 L
.29167 .58929 L
.29167 .55952 L
F
.2619 .58929 m
.2619 .61905 L
.29167 .61905 L
.29167 .58929 L
F
.2619 .61905 m
.2619 .64881 L
.29167 .64881 L
.29167 .61905 L
F
.2619 .64881 m
.2619 .67857 L
.29167 .67857 L
.29167 .64881 L
F
.2619 .67857 m
.2619 .70833 L
.29167 .70833 L
.29167 .67857 L
F
.2619 .70833 m
.2619 .7381 L
.29167 .7381 L
.29167 .70833 L
F
.742 .258 .258 r
.2619 .7381 m
.2619 .76786 L
.29167 .76786 L
.29167 .7381 L
F
.2619 .76786 m
.2619 .79762 L
.29167 .79762 L
.29167 .76786 L
F
.2619 .79762 m
.2619 .82738 L
.29167 .82738 L
.29167 .79762 L
F
.2619 .82738 m
.2619 .85714 L
.29167 .85714 L
.29167 .82738 L
F
.2619 .85714 m
.2619 .8869 L
.29167 .8869 L
.29167 .85714 L
F
.2619 .8869 m
.2619 .91667 L
.29167 .91667 L
.29167 .8869 L
F
.2619 .91667 m
.2619 .94643 L
.29167 .94643 L
.29167 .91667 L
F
.2619 .94643 m
.2619 .97619 L
.29167 .97619 L
.29167 .94643 L
F
1 0 0 r
.29167 .02381 m
.29167 .05357 L
.32143 .05357 L
.32143 .02381 L
F
.968 .032 .032 r
.29167 .05357 m
.29167 .08333 L
.32143 .08333 L
.32143 .05357 L
F
1 0 0 r
.29167 .08333 m
.29167 .1131 L
.32143 .1131 L
.32143 .08333 L
F
.968 .032 .032 r
.29167 .1131 m
.29167 .14286 L
.32143 .14286 L
.32143 .1131 L
F
1 0 0 r
.29167 .14286 m
.29167 .17262 L
.32143 .17262 L
.32143 .14286 L
F
.968 .032 .032 r
.29167 .17262 m
.29167 .20238 L
.32143 .20238 L
.32143 .17262 L
F
1 0 0 r
.29167 .20238 m
.29167 .23214 L
.32143 .23214 L
.32143 .20238 L
F
.968 .032 .032 r
.29167 .23214 m
.29167 .2619 L
.32143 .2619 L
.32143 .23214 L
F
.742 .258 .258 r
.29167 .2619 m
.29167 .29167 L
.32143 .29167 L
.32143 .2619 L
F
.71 .29 .29 r
.29167 .29167 m
.29167 .32143 L
.32143 .32143 L
.32143 .29167 L
F
.742 .258 .258 r
.29167 .32143 m
.29167 .35119 L
.32143 .35119 L
.32143 .32143 L
F
.71 .29 .29 r
.29167 .35119 m
.29167 .38095 L
.32143 .38095 L
.32143 .35119 L
F
.742 .258 .258 r
.29167 .38095 m
.29167 .41071 L
.32143 .41071 L
.32143 .38095 L
F
.71 .29 .29 r
.29167 .41071 m
.29167 .44048 L
.32143 .44048 L
.32143 .41071 L
F
.742 .258 .258 r
.29167 .44048 m
.29167 .47024 L
.32143 .47024 L
.32143 .44048 L
F
.71 .29 .29 r
.29167 .47024 m
.29167 .5 L
.32143 .5 L
.32143 .47024 L
F
1 0 0 r
.29167 .5 m
.29167 .52976 L
.32143 .52976 L
.32143 .5 L
F
.968 .032 .032 r
.29167 .52976 m
.29167 .55952 L
.32143 .55952 L
.32143 .52976 L
F
1 0 0 r
.29167 .55952 m
.29167 .58929 L
.32143 .58929 L
.32143 .55952 L
F
.968 .032 .032 r
.29167 .58929 m
.29167 .61905 L
.32143 .61905 L
.32143 .58929 L
F
1 0 0 r
.29167 .61905 m
.29167 .64881 L
.32143 .64881 L
.32143 .61905 L
F
.968 .032 .032 r
.29167 .64881 m
.29167 .67857 L
.32143 .67857 L
.32143 .64881 L
F
1 0 0 r
.29167 .67857 m
.29167 .70833 L
.32143 .70833 L
.32143 .67857 L
F
.968 .032 .032 r
.29167 .70833 m
.29167 .7381 L
.32143 .7381 L
.32143 .70833 L
F
.742 .258 .258 r
.29167 .7381 m
.29167 .76786 L
.32143 .76786 L
.32143 .7381 L
F
.71 .29 .29 r
.29167 .76786 m
.29167 .79762 L
.32143 .79762 L
.32143 .76786 L
F
.742 .258 .258 r
.29167 .79762 m
.29167 .82738 L
.32143 .82738 L
.32143 .79762 L
F
.71 .29 .29 r
.29167 .82738 m
.29167 .85714 L
.32143 .85714 L
.32143 .82738 L
F
.742 .258 .258 r
.29167 .85714 m
.29167 .8869 L
.32143 .8869 L
.32143 .85714 L
F
.71 .29 .29 r
.29167 .8869 m
.29167 .91667 L
.32143 .91667 L
.32143 .8869 L
F
.742 .258 .258 r
.29167 .91667 m
.29167 .94643 L
.32143 .94643 L
.32143 .91667 L
F
.71 .29 .29 r
.29167 .94643 m
.29167 .97619 L
.32143 .97619 L
.32143 .94643 L
F
1 0 0 r
.32143 .02381 m
.32143 .05357 L
.35119 .05357 L
.35119 .02381 L
F
.32143 .05357 m
.32143 .08333 L
.35119 .08333 L
.35119 .05357 L
F
.935 .065 .065 r
.32143 .08333 m
.32143 .1131 L
.35119 .1131 L
.35119 .08333 L
F
.32143 .1131 m
.32143 .14286 L
.35119 .14286 L
.35119 .1131 L
F
1 0 0 r
.32143 .14286 m
.32143 .17262 L
.35119 .17262 L
.35119 .14286 L
F
.32143 .17262 m
.32143 .20238 L
.35119 .20238 L
.35119 .17262 L
F
.935 .065 .065 r
.32143 .20238 m
.32143 .23214 L
.35119 .23214 L
.35119 .20238 L
F
.32143 .23214 m
.32143 .2619 L
.35119 .2619 L
.35119 .23214 L
F
.742 .258 .258 r
.32143 .2619 m
.32143 .29167 L
.35119 .29167 L
.35119 .2619 L
F
.32143 .29167 m
.32143 .32143 L
.35119 .32143 L
.35119 .29167 L
F
.677 .323 .323 r
.32143 .32143 m
.32143 .35119 L
.35119 .35119 L
.35119 .32143 L
F
.32143 .35119 m
.32143 .38095 L
.35119 .38095 L
.35119 .35119 L
F
.742 .258 .258 r
.32143 .38095 m
.32143 .41071 L
.35119 .41071 L
.35119 .38095 L
F
.32143 .41071 m
.32143 .44048 L
.35119 .44048 L
.35119 .41071 L
F
.677 .323 .323 r
.32143 .44048 m
.32143 .47024 L
.35119 .47024 L
.35119 .44048 L
F
.32143 .47024 m
.32143 .5 L
.35119 .5 L
.35119 .47024 L
F
1 0 0 r
.32143 .5 m
.32143 .52976 L
.35119 .52976 L
.35119 .5 L
F
.32143 .52976 m
.32143 .55952 L
.35119 .55952 L
.35119 .52976 L
F
.935 .065 .065 r
.32143 .55952 m
.32143 .58929 L
.35119 .58929 L
.35119 .55952 L
F
.32143 .58929 m
.32143 .61905 L
.35119 .61905 L
.35119 .58929 L
F
1 0 0 r
.32143 .61905 m
.32143 .64881 L
.35119 .64881 L
.35119 .61905 L
F
.32143 .64881 m
.32143 .67857 L
.35119 .67857 L
.35119 .64881 L
F
.935 .065 .065 r
.32143 .67857 m
.32143 .70833 L
.35119 .70833 L
.35119 .67857 L
F
.32143 .70833 m
.32143 .7381 L
.35119 .7381 L
.35119 .70833 L
F
.742 .258 .258 r
.32143 .7381 m
.32143 .76786 L
.35119 .76786 L
.35119 .7381 L
F
.32143 .76786 m
.32143 .79762 L
.35119 .79762 L
.35119 .76786 L
F
.677 .323 .323 r
.32143 .79762 m
.32143 .82738 L
.35119 .82738 L
.35119 .79762 L
F
.32143 .82738 m
.32143 .85714 L
.35119 .85714 L
.35119 .82738 L
F
.742 .258 .258 r
.32143 .85714 m
.32143 .8869 L
.35119 .8869 L
.35119 .85714 L
F
.32143 .8869 m
.32143 .91667 L
.35119 .91667 L
.35119 .8869 L
F
.677 .323 .323 r
.32143 .91667 m
.32143 .94643 L
.35119 .94643 L
.35119 .91667 L
F
.32143 .94643 m
.32143 .97619 L
.35119 .97619 L
.35119 .94643 L
F
1 0 0 r
.35119 .02381 m
.35119 .05357 L
.38095 .05357 L
.38095 .02381 L
F
.968 .032 .032 r
.35119 .05357 m
.35119 .08333 L
.38095 .08333 L
.38095 .05357 L
F
.935 .065 .065 r
.35119 .08333 m
.35119 .1131 L
.38095 .1131 L
.38095 .08333 L
F
.903 .097 .097 r
.35119 .1131 m
.35119 .14286 L
.38095 .14286 L
.38095 .1131 L
F
1 0 0 r
.35119 .14286 m
.35119 .17262 L
.38095 .17262 L
.38095 .14286 L
F
.968 .032 .032 r
.35119 .17262 m
.35119 .20238 L
.38095 .20238 L
.38095 .17262 L
F
.935 .065 .065 r
.35119 .20238 m
.35119 .23214 L
.38095 .23214 L
.38095 .20238 L
F
.903 .097 .097 r
.35119 .23214 m
.35119 .2619 L
.38095 .2619 L
.38095 .23214 L
F
.742 .258 .258 r
.35119 .2619 m
.35119 .29167 L
.38095 .29167 L
.38095 .2619 L
F
.71 .29 .29 r
.35119 .29167 m
.35119 .32143 L
.38095 .32143 L
.38095 .29167 L
F
.677 .323 .323 r
.35119 .32143 m
.35119 .35119 L
.38095 .35119 L
.38095 .32143 L
F
.645 .355 .355 r
.35119 .35119 m
.35119 .38095 L
.38095 .38095 L
.38095 .35119 L
F
.742 .258 .258 r
.35119 .38095 m
.35119 .41071 L
.38095 .41071 L
.38095 .38095 L
F
.71 .29 .29 r
.35119 .41071 m
.35119 .44048 L
.38095 .44048 L
.38095 .41071 L
F
.677 .323 .323 r
.35119 .44048 m
.35119 .47024 L
.38095 .47024 L
.38095 .44048 L
F
.645 .355 .355 r
.35119 .47024 m
.35119 .5 L
.38095 .5 L
.38095 .47024 L
F
1 0 0 r
.35119 .5 m
.35119 .52976 L
.38095 .52976 L
.38095 .5 L
F
.968 .032 .032 r
.35119 .52976 m
.35119 .55952 L
.38095 .55952 L
.38095 .52976 L
F
.935 .065 .065 r
.35119 .55952 m
.35119 .58929 L
.38095 .58929 L
.38095 .55952 L
F
.903 .097 .097 r
.35119 .58929 m
.35119 .61905 L
.38095 .61905 L
.38095 .58929 L
F
1 0 0 r
.35119 .61905 m
.35119 .64881 L
.38095 .64881 L
.38095 .61905 L
F
.968 .032 .032 r
.35119 .64881 m
.35119 .67857 L
.38095 .67857 L
.38095 .64881 L
F
.935 .065 .065 r
.35119 .67857 m
.35119 .70833 L
.38095 .70833 L
.38095 .67857 L
F
.903 .097 .097 r
.35119 .70833 m
.35119 .7381 L
.38095 .7381 L
.38095 .70833 L
F
.742 .258 .258 r
.35119 .7381 m
.35119 .76786 L
.38095 .76786 L
.38095 .7381 L
F
.71 .29 .29 r
.35119 .76786 m
.35119 .79762 L
.38095 .79762 L
.38095 .76786 L
F
.677 .323 .323 r
.35119 .79762 m
.35119 .82738 L
.38095 .82738 L
.38095 .79762 L
F
.645 .355 .355 r
.35119 .82738 m
.35119 .85714 L
.38095 .85714 L
.38095 .82738 L
F
.742 .258 .258 r
.35119 .85714 m
.35119 .8869 L
.38095 .8869 L
.38095 .85714 L
F
.71 .29 .29 r
.35119 .8869 m
.35119 .91667 L
.38095 .91667 L
.38095 .8869 L
F
.677 .323 .323 r
.35119 .91667 m
.35119 .94643 L
.38095 .94643 L
.38095 .91667 L
F
.645 .355 .355 r
.35119 .94643 m
.35119 .97619 L
.38095 .97619 L
.38095 .94643 L
F
1 0 0 r
.38095 .02381 m
.38095 .05357 L
.41071 .05357 L
.41071 .02381 L
F
.38095 .05357 m
.38095 .08333 L
.41071 .08333 L
.41071 .05357 L
F
.38095 .08333 m
.38095 .1131 L
.41071 .1131 L
.41071 .08333 L
F
.38095 .1131 m
.38095 .14286 L
.41071 .14286 L
.41071 .1131 L
F
.871 .129 .129 r
.38095 .14286 m
.38095 .17262 L
.41071 .17262 L
.41071 .14286 L
F
.38095 .17262 m
.38095 .20238 L
.41071 .20238 L
.41071 .17262 L
F
.38095 .20238 m
.38095 .23214 L
.41071 .23214 L
.41071 .20238 L
F
.38095 .23214 m
.38095 .2619 L
.41071 .2619 L
.41071 .23214 L
F
.742 .258 .258 r
.38095 .2619 m
.38095 .29167 L
.41071 .29167 L
.41071 .2619 L
F
.38095 .29167 m
.38095 .32143 L
.41071 .32143 L
.41071 .29167 L
F
.38095 .32143 m
.38095 .35119 L
.41071 .35119 L
.41071 .32143 L
F
.38095 .35119 m
.38095 .38095 L
.41071 .38095 L
.41071 .35119 L
F
.613 .387 .387 r
.38095 .38095 m
.38095 .41071 L
.41071 .41071 L
.41071 .38095 L
F
.38095 .41071 m
.38095 .44048 L
.41071 .44048 L
.41071 .41071 L
F
.38095 .44048 m
.38095 .47024 L
.41071 .47024 L
.41071 .44048 L
F
.38095 .47024 m
.38095 .5 L
.41071 .5 L
.41071 .47024 L
F
1 0 0 r
.38095 .5 m
.38095 .52976 L
.41071 .52976 L
.41071 .5 L
F
.38095 .52976 m
.38095 .55952 L
.41071 .55952 L
.41071 .52976 L
F
.38095 .55952 m
.38095 .58929 L
.41071 .58929 L
.41071 .55952 L
F
.38095 .58929 m
.38095 .61905 L
.41071 .61905 L
.41071 .58929 L
F
.871 .129 .129 r
.38095 .61905 m
.38095 .64881 L
.41071 .64881 L
.41071 .61905 L
F
.38095 .64881 m
.38095 .67857 L
.41071 .67857 L
.41071 .64881 L
F
.38095 .67857 m
.38095 .70833 L
.41071 .70833 L
.41071 .67857 L
F
.38095 .70833 m
.38095 .7381 L
.41071 .7381 L
.41071 .70833 L
F
.742 .258 .258 r
.38095 .7381 m
.38095 .76786 L
.41071 .76786 L
.41071 .7381 L
F
.38095 .76786 m
.38095 .79762 L
.41071 .79762 L
.41071 .76786 L
F
.38095 .79762 m
.38095 .82738 L
.41071 .82738 L
.41071 .79762 L
F
.38095 .82738 m
.38095 .85714 L
.41071 .85714 L
.41071 .82738 L
F
.613 .387 .387 r
.38095 .85714 m
.38095 .8869 L
.41071 .8869 L
.41071 .85714 L
F
.38095 .8869 m
.38095 .91667 L
.41071 .91667 L
.41071 .8869 L
F
.38095 .91667 m
.38095 .94643 L
.41071 .94643 L
.41071 .91667 L
F
.38095 .94643 m
.38095 .97619 L
.41071 .97619 L
.41071 .94643 L
F
1 0 0 r
.41071 .02381 m
.41071 .05357 L
.44048 .05357 L
.44048 .02381 L
F
.968 .032 .032 r
.41071 .05357 m
.41071 .08333 L
.44048 .08333 L
.44048 .05357 L
F
1 0 0 r
.41071 .08333 m
.41071 .1131 L
.44048 .1131 L
.44048 .08333 L
F
.968 .032 .032 r
.41071 .1131 m
.41071 .14286 L
.44048 .14286 L
.44048 .1131 L
F
.871 .129 .129 r
.41071 .14286 m
.41071 .17262 L
.44048 .17262 L
.44048 .14286 L
F
.839 .161 .161 r
.41071 .17262 m
.41071 .20238 L
.44048 .20238 L
.44048 .17262 L
F
.871 .129 .129 r
.41071 .20238 m
.41071 .23214 L
.44048 .23214 L
.44048 .20238 L
F
.839 .161 .161 r
.41071 .23214 m
.41071 .2619 L
.44048 .2619 L
.44048 .23214 L
F
.742 .258 .258 r
.41071 .2619 m
.41071 .29167 L
.44048 .29167 L
.44048 .2619 L
F
.71 .29 .29 r
.41071 .29167 m
.41071 .32143 L
.44048 .32143 L
.44048 .29167 L
F
.742 .258 .258 r
.41071 .32143 m
.41071 .35119 L
.44048 .35119 L
.44048 .32143 L
F
.71 .29 .29 r
.41071 .35119 m
.41071 .38095 L
.44048 .38095 L
.44048 .35119 L
F
.613 .387 .387 r
.41071 .38095 m
.41071 .41071 L
.44048 .41071 L
.44048 .38095 L
F
.581 .419 .419 r
.41071 .41071 m
.41071 .44048 L
.44048 .44048 L
.44048 .41071 L
F
.613 .387 .387 r
.41071 .44048 m
.41071 .47024 L
.44048 .47024 L
.44048 .44048 L
F
.581 .419 .419 r
.41071 .47024 m
.41071 .5 L
.44048 .5 L
.44048 .47024 L
F
1 0 0 r
.41071 .5 m
.41071 .52976 L
.44048 .52976 L
.44048 .5 L
F
.968 .032 .032 r
.41071 .52976 m
.41071 .55952 L
.44048 .55952 L
.44048 .52976 L
F
1 0 0 r
.41071 .55952 m
.41071 .58929 L
.44048 .58929 L
.44048 .55952 L
F
.968 .032 .032 r
.41071 .58929 m
.41071 .61905 L
.44048 .61905 L
.44048 .58929 L
F
.871 .129 .129 r
.41071 .61905 m
.41071 .64881 L
.44048 .64881 L
.44048 .61905 L
F
.839 .161 .161 r
.41071 .64881 m
.41071 .67857 L
.44048 .67857 L
.44048 .64881 L
F
.871 .129 .129 r
.41071 .67857 m
.41071 .70833 L
.44048 .70833 L
.44048 .67857 L
F
.839 .161 .161 r
.41071 .70833 m
.41071 .7381 L
.44048 .7381 L
.44048 .70833 L
F
.742 .258 .258 r
.41071 .7381 m
.41071 .76786 L
.44048 .76786 L
.44048 .7381 L
F
.71 .29 .29 r
.41071 .76786 m
.41071 .79762 L
.44048 .79762 L
.44048 .76786 L
F
.742 .258 .258 r
.41071 .79762 m
.41071 .82738 L
.44048 .82738 L
.44048 .79762 L
F
.71 .29 .29 r
.41071 .82738 m
.41071 .85714 L
.44048 .85714 L
.44048 .82738 L
F
.613 .387 .387 r
.41071 .85714 m
.41071 .8869 L
.44048 .8869 L
.44048 .85714 L
F
.581 .419 .419 r
.41071 .8869 m
.41071 .91667 L
.44048 .91667 L
.44048 .8869 L
F
.613 .387 .387 r
.41071 .91667 m
.41071 .94643 L
.44048 .94643 L
.44048 .91667 L
F
.581 .419 .419 r
.41071 .94643 m
.41071 .97619 L
.44048 .97619 L
.44048 .94643 L
F
1 0 0 r
.44048 .02381 m
.44048 .05357 L
.47024 .05357 L
.47024 .02381 L
F
.44048 .05357 m
.44048 .08333 L
.47024 .08333 L
.47024 .05357 L
F
.935 .065 .065 r
.44048 .08333 m
.44048 .1131 L
.47024 .1131 L
.47024 .08333 L
F
.44048 .1131 m
.44048 .14286 L
.47024 .14286 L
.47024 .1131 L
F
.871 .129 .129 r
.44048 .14286 m
.44048 .17262 L
.47024 .17262 L
.47024 .14286 L
F
.44048 .17262 m
.44048 .20238 L
.47024 .20238 L
.47024 .17262 L
F
.806 .194 .194 r
.44048 .20238 m
.44048 .23214 L
.47024 .23214 L
.47024 .20238 L
F
.44048 .23214 m
.44048 .2619 L
.47024 .2619 L
.47024 .23214 L
F
.742 .258 .258 r
.44048 .2619 m
.44048 .29167 L
.47024 .29167 L
.47024 .2619 L
F
.44048 .29167 m
.44048 .32143 L
.47024 .32143 L
.47024 .29167 L
F
.677 .323 .323 r
.44048 .32143 m
.44048 .35119 L
.47024 .35119 L
.47024 .32143 L
F
.44048 .35119 m
.44048 .38095 L
.47024 .38095 L
.47024 .35119 L
F
.613 .387 .387 r
.44048 .38095 m
.44048 .41071 L
.47024 .41071 L
.47024 .38095 L
F
.44048 .41071 m
.44048 .44048 L
.47024 .44048 L
.47024 .41071 L
F
.548 .452 .452 r
.44048 .44048 m
.44048 .47024 L
.47024 .47024 L
.47024 .44048 L
F
.44048 .47024 m
.44048 .5 L
.47024 .5 L
.47024 .47024 L
F
1 0 0 r
.44048 .5 m
.44048 .52976 L
.47024 .52976 L
.47024 .5 L
F
.44048 .52976 m
.44048 .55952 L
.47024 .55952 L
.47024 .52976 L
F
.935 .065 .065 r
.44048 .55952 m
.44048 .58929 L
.47024 .58929 L
.47024 .55952 L
F
.44048 .58929 m
.44048 .61905 L
.47024 .61905 L
.47024 .58929 L
F
.871 .129 .129 r
.44048 .61905 m
.44048 .64881 L
.47024 .64881 L
.47024 .61905 L
F
.44048 .64881 m
.44048 .67857 L
.47024 .67857 L
.47024 .64881 L
F
.806 .194 .194 r
.44048 .67857 m
.44048 .70833 L
.47024 .70833 L
.47024 .67857 L
F
.44048 .70833 m
.44048 .7381 L
.47024 .7381 L
.47024 .70833 L
F
.742 .258 .258 r
.44048 .7381 m
.44048 .76786 L
.47024 .76786 L
.47024 .7381 L
F
.44048 .76786 m
.44048 .79762 L
.47024 .79762 L
.47024 .76786 L
F
.677 .323 .323 r
.44048 .79762 m
.44048 .82738 L
.47024 .82738 L
.47024 .79762 L
F
.44048 .82738 m
.44048 .85714 L
.47024 .85714 L
.47024 .82738 L
F
.613 .387 .387 r
.44048 .85714 m
.44048 .8869 L
.47024 .8869 L
.47024 .85714 L
F
.44048 .8869 m
.44048 .91667 L
.47024 .91667 L
.47024 .8869 L
F
.548 .452 .452 r
.44048 .91667 m
.44048 .94643 L
.47024 .94643 L
.47024 .91667 L
F
.44048 .94643 m
.44048 .97619 L
.47024 .97619 L
.47024 .94643 L
F
1 0 0 r
.47024 .02381 m
.47024 .05357 L
.5 .05357 L
.5 .02381 L
F
.968 .032 .032 r
.47024 .05357 m
.47024 .08333 L
.5 .08333 L
.5 .05357 L
F
.935 .065 .065 r
.47024 .08333 m
.47024 .1131 L
.5 .1131 L
.5 .08333 L
F
.903 .097 .097 r
.47024 .1131 m
.47024 .14286 L
.5 .14286 L
.5 .1131 L
F
.871 .129 .129 r
.47024 .14286 m
.47024 .17262 L
.5 .17262 L
.5 .14286 L
F
.839 .161 .161 r
.47024 .17262 m
.47024 .20238 L
.5 .20238 L
.5 .17262 L
F
.806 .194 .194 r
.47024 .20238 m
.47024 .23214 L
.5 .23214 L
.5 .20238 L
F
.774 .226 .226 r
.47024 .23214 m
.47024 .2619 L
.5 .2619 L
.5 .23214 L
F
.742 .258 .258 r
.47024 .2619 m
.47024 .29167 L
.5 .29167 L
.5 .2619 L
F
.71 .29 .29 r
.47024 .29167 m
.47024 .32143 L
.5 .32143 L
.5 .29167 L
F
.677 .323 .323 r
.47024 .32143 m
.47024 .35119 L
.5 .35119 L
.5 .32143 L
F
.645 .355 .355 r
.47024 .35119 m
.47024 .38095 L
.5 .38095 L
.5 .35119 L
F
.613 .387 .387 r
.47024 .38095 m
.47024 .41071 L
.5 .41071 L
.5 .38095 L
F
.581 .419 .419 r
.47024 .41071 m
.47024 .44048 L
.5 .44048 L
.5 .41071 L
F
.548 .452 .452 r
.47024 .44048 m
.47024 .47024 L
.5 .47024 L
.5 .44048 L
F
.516 .484 .484 r
.47024 .47024 m
.47024 .5 L
.5 .5 L
.5 .47024 L
F
1 0 0 r
.47024 .5 m
.47024 .52976 L
.5 .52976 L
.5 .5 L
F
.968 .032 .032 r
.47024 .52976 m
.47024 .55952 L
.5 .55952 L
.5 .52976 L
F
.935 .065 .065 r
.47024 .55952 m
.47024 .58929 L
.5 .58929 L
.5 .55952 L
F
.903 .097 .097 r
.47024 .58929 m
.47024 .61905 L
.5 .61905 L
.5 .58929 L
F
.871 .129 .129 r
.47024 .61905 m
.47024 .64881 L
.5 .64881 L
.5 .61905 L
F
.839 .161 .161 r
.47024 .64881 m
.47024 .67857 L
.5 .67857 L
.5 .64881 L
F
.806 .194 .194 r
.47024 .67857 m
.47024 .70833 L
.5 .70833 L
.5 .67857 L
F
.774 .226 .226 r
.47024 .70833 m
.47024 .7381 L
.5 .7381 L
.5 .70833 L
F
.742 .258 .258 r
.47024 .7381 m
.47024 .76786 L
.5 .76786 L
.5 .7381 L
F
.71 .29 .29 r
.47024 .76786 m
.47024 .79762 L
.5 .79762 L
.5 .76786 L
F
.677 .323 .323 r
.47024 .79762 m
.47024 .82738 L
.5 .82738 L
.5 .79762 L
F
.645 .355 .355 r
.47024 .82738 m
.47024 .85714 L
.5 .85714 L
.5 .82738 L
F
.613 .387 .387 r
.47024 .85714 m
.47024 .8869 L
.5 .8869 L
.5 .85714 L
F
.581 .419 .419 r
.47024 .8869 m
.47024 .91667 L
.5 .91667 L
.5 .8869 L
F
.548 .452 .452 r
.47024 .91667 m
.47024 .94643 L
.5 .94643 L
.5 .91667 L
F
.516 .484 .484 r
.47024 .94643 m
.47024 .97619 L
.5 .97619 L
.5 .94643 L
F
1 0 0 r
.5 .02381 m
.5 .05357 L
.52976 .05357 L
.52976 .02381 L
F
.5 .05357 m
.5 .08333 L
.52976 .08333 L
.52976 .05357 L
F
.5 .08333 m
.5 .1131 L
.52976 .1131 L
.52976 .08333 L
F
.5 .1131 m
.5 .14286 L
.52976 .14286 L
.52976 .1131 L
F
.5 .14286 m
.5 .17262 L
.52976 .17262 L
.52976 .14286 L
F
.5 .17262 m
.5 .20238 L
.52976 .20238 L
.52976 .17262 L
F
.5 .20238 m
.5 .23214 L
.52976 .23214 L
.52976 .20238 L
F
.5 .23214 m
.5 .2619 L
.52976 .2619 L
.52976 .23214 L
F
.5 .2619 m
.5 .29167 L
.52976 .29167 L
.52976 .2619 L
F
.5 .29167 m
.5 .32143 L
.52976 .32143 L
.52976 .29167 L
F
.5 .32143 m
.5 .35119 L
.52976 .35119 L
.52976 .32143 L
F
.5 .35119 m
.5 .38095 L
.52976 .38095 L
.52976 .35119 L
F
.5 .38095 m
.5 .41071 L
.52976 .41071 L
.52976 .38095 L
F
.5 .41071 m
.5 .44048 L
.52976 .44048 L
.52976 .41071 L
F
.5 .44048 m
.5 .47024 L
.52976 .47024 L
.52976 .44048 L
F
.5 .47024 m
.5 .5 L
.52976 .5 L
.52976 .47024 L
F
.484 .516 .516 r
.5 .5 m
.5 .52976 L
.52976 .52976 L
.52976 .5 L
F
.5 .52976 m
.5 .55952 L
.52976 .55952 L
.52976 .52976 L
F
.5 .55952 m
.5 .58929 L
.52976 .58929 L
.52976 .55952 L
F
.5 .58929 m
.5 .61905 L
.52976 .61905 L
.52976 .58929 L
F
.5 .61905 m
.5 .64881 L
.52976 .64881 L
.52976 .61905 L
F
.5 .64881 m
.5 .67857 L
.52976 .67857 L
.52976 .64881 L
F
.5 .67857 m
.5 .70833 L
.52976 .70833 L
.52976 .67857 L
F
.5 .70833 m
.5 .7381 L
.52976 .7381 L
.52976 .70833 L
F
.5 .7381 m
.5 .76786 L
.52976 .76786 L
.52976 .7381 L
F
.5 .76786 m
.5 .79762 L
.52976 .79762 L
.52976 .76786 L
F
.5 .79762 m
.5 .82738 L
.52976 .82738 L
.52976 .79762 L
F
.5 .82738 m
.5 .85714 L
.52976 .85714 L
.52976 .82738 L
F
.5 .85714 m
.5 .8869 L
.52976 .8869 L
.52976 .85714 L
F
.5 .8869 m
.5 .91667 L
.52976 .91667 L
.52976 .8869 L
F
.5 .91667 m
.5 .94643 L
.52976 .94643 L
.52976 .91667 L
F
.5 .94643 m
.5 .97619 L
.52976 .97619 L
.52976 .94643 L
F
1 0 0 r
.52976 .02381 m
.52976 .05357 L
.55952 .05357 L
.55952 .02381 L
F
.968 .032 .032 r
.52976 .05357 m
.52976 .08333 L
.55952 .08333 L
.55952 .05357 L
F
1 0 0 r
.52976 .08333 m
.52976 .1131 L
.55952 .1131 L
.55952 .08333 L
F
.968 .032 .032 r
.52976 .1131 m
.52976 .14286 L
.55952 .14286 L
.55952 .1131 L
F
1 0 0 r
.52976 .14286 m
.52976 .17262 L
.55952 .17262 L
.55952 .14286 L
F
.968 .032 .032 r
.52976 .17262 m
.52976 .20238 L
.55952 .20238 L
.55952 .17262 L
F
1 0 0 r
.52976 .20238 m
.52976 .23214 L
.55952 .23214 L
.55952 .20238 L
F
.968 .032 .032 r
.52976 .23214 m
.52976 .2619 L
.55952 .2619 L
.55952 .23214 L
F
1 0 0 r
.52976 .2619 m
.52976 .29167 L
.55952 .29167 L
.55952 .2619 L
F
.968 .032 .032 r
.52976 .29167 m
.52976 .32143 L
.55952 .32143 L
.55952 .29167 L
F
1 0 0 r
.52976 .32143 m
.52976 .35119 L
.55952 .35119 L
.55952 .32143 L
F
.968 .032 .032 r
.52976 .35119 m
.52976 .38095 L
.55952 .38095 L
.55952 .35119 L
F
1 0 0 r
.52976 .38095 m
.52976 .41071 L
.55952 .41071 L
.55952 .38095 L
F
.968 .032 .032 r
.52976 .41071 m
.52976 .44048 L
.55952 .44048 L
.55952 .41071 L
F
1 0 0 r
.52976 .44048 m
.52976 .47024 L
.55952 .47024 L
.55952 .44048 L
F
.968 .032 .032 r
.52976 .47024 m
.52976 .5 L
.55952 .5 L
.55952 .47024 L
F
.484 .516 .516 r
.52976 .5 m
.52976 .52976 L
.55952 .52976 L
.55952 .5 L
F
.452 .548 .548 r
.52976 .52976 m
.52976 .55952 L
.55952 .55952 L
.55952 .52976 L
F
.484 .516 .516 r
.52976 .55952 m
.52976 .58929 L
.55952 .58929 L
.55952 .55952 L
F
.452 .548 .548 r
.52976 .58929 m
.52976 .61905 L
.55952 .61905 L
.55952 .58929 L
F
.484 .516 .516 r
.52976 .61905 m
.52976 .64881 L
.55952 .64881 L
.55952 .61905 L
F
.452 .548 .548 r
.52976 .64881 m
.52976 .67857 L
.55952 .67857 L
.55952 .64881 L
F
.484 .516 .516 r
.52976 .67857 m
.52976 .70833 L
.55952 .70833 L
.55952 .67857 L
F
.452 .548 .548 r
.52976 .70833 m
.52976 .7381 L
.55952 .7381 L
.55952 .70833 L
F
.484 .516 .516 r
.52976 .7381 m
.52976 .76786 L
.55952 .76786 L
.55952 .7381 L
F
.452 .548 .548 r
.52976 .76786 m
.52976 .79762 L
.55952 .79762 L
.55952 .76786 L
F
.484 .516 .516 r
.52976 .79762 m
.52976 .82738 L
.55952 .82738 L
.55952 .79762 L
F
.452 .548 .548 r
.52976 .82738 m
.52976 .85714 L
.55952 .85714 L
.55952 .82738 L
F
.484 .516 .516 r
.52976 .85714 m
.52976 .8869 L
.55952 .8869 L
.55952 .85714 L
F
.452 .548 .548 r
.52976 .8869 m
.52976 .91667 L
.55952 .91667 L
.55952 .8869 L
F
.484 .516 .516 r
.52976 .91667 m
.52976 .94643 L
.55952 .94643 L
.55952 .91667 L
F
.452 .548 .548 r
.52976 .94643 m
.52976 .97619 L
.55952 .97619 L
.55952 .94643 L
F
1 0 0 r
.55952 .02381 m
.55952 .05357 L
.58929 .05357 L
.58929 .02381 L
F
.55952 .05357 m
.55952 .08333 L
.58929 .08333 L
.58929 .05357 L
F
.935 .065 .065 r
.55952 .08333 m
.55952 .1131 L
.58929 .1131 L
.58929 .08333 L
F
.55952 .1131 m
.55952 .14286 L
.58929 .14286 L
.58929 .1131 L
F
1 0 0 r
.55952 .14286 m
.55952 .17262 L
.58929 .17262 L
.58929 .14286 L
F
.55952 .17262 m
.55952 .20238 L
.58929 .20238 L
.58929 .17262 L
F
.935 .065 .065 r
.55952 .20238 m
.55952 .23214 L
.58929 .23214 L
.58929 .20238 L
F
.55952 .23214 m
.55952 .2619 L
.58929 .2619 L
.58929 .23214 L
F
1 0 0 r
.55952 .2619 m
.55952 .29167 L
.58929 .29167 L
.58929 .2619 L
F
.55952 .29167 m
.55952 .32143 L
.58929 .32143 L
.58929 .29167 L
F
.935 .065 .065 r
.55952 .32143 m
.55952 .35119 L
.58929 .35119 L
.58929 .32143 L
F
.55952 .35119 m
.55952 .38095 L
.58929 .38095 L
.58929 .35119 L
F
1 0 0 r
.55952 .38095 m
.55952 .41071 L
.58929 .41071 L
.58929 .38095 L
F
.55952 .41071 m
.55952 .44048 L
.58929 .44048 L
.58929 .41071 L
F
.935 .065 .065 r
.55952 .44048 m
.55952 .47024 L
.58929 .47024 L
.58929 .44048 L
F
.55952 .47024 m
.55952 .5 L
.58929 .5 L
.58929 .47024 L
F
.484 .516 .516 r
.55952 .5 m
.55952 .52976 L
.58929 .52976 L
.58929 .5 L
F
.55952 .52976 m
.55952 .55952 L
.58929 .55952 L
.58929 .52976 L
F
.419 .581 .581 r
.55952 .55952 m
.55952 .58929 L
.58929 .58929 L
.58929 .55952 L
F
.55952 .58929 m
.55952 .61905 L
.58929 .61905 L
.58929 .58929 L
F
.484 .516 .516 r
.55952 .61905 m
.55952 .64881 L
.58929 .64881 L
.58929 .61905 L
F
.55952 .64881 m
.55952 .67857 L
.58929 .67857 L
.58929 .64881 L
F
.419 .581 .581 r
.55952 .67857 m
.55952 .70833 L
.58929 .70833 L
.58929 .67857 L
F
.55952 .70833 m
.55952 .7381 L
.58929 .7381 L
.58929 .70833 L
F
.484 .516 .516 r
.55952 .7381 m
.55952 .76786 L
.58929 .76786 L
.58929 .7381 L
F
.55952 .76786 m
.55952 .79762 L
.58929 .79762 L
.58929 .76786 L
F
.419 .581 .581 r
.55952 .79762 m
.55952 .82738 L
.58929 .82738 L
.58929 .79762 L
F
.55952 .82738 m
.55952 .85714 L
.58929 .85714 L
.58929 .82738 L
F
.484 .516 .516 r
.55952 .85714 m
.55952 .8869 L
.58929 .8869 L
.58929 .85714 L
F
.55952 .8869 m
.55952 .91667 L
.58929 .91667 L
.58929 .8869 L
F
.419 .581 .581 r
.55952 .91667 m
.55952 .94643 L
.58929 .94643 L
.58929 .91667 L
F
.55952 .94643 m
.55952 .97619 L
.58929 .97619 L
.58929 .94643 L
F
1 0 0 r
.58929 .02381 m
.58929 .05357 L
.61905 .05357 L
.61905 .02381 L
F
.968 .032 .032 r
.58929 .05357 m
.58929 .08333 L
.61905 .08333 L
.61905 .05357 L
F
.935 .065 .065 r
.58929 .08333 m
.58929 .1131 L
.61905 .1131 L
.61905 .08333 L
F
.903 .097 .097 r
.58929 .1131 m
.58929 .14286 L
.61905 .14286 L
.61905 .1131 L
F
1 0 0 r
.58929 .14286 m
.58929 .17262 L
.61905 .17262 L
.61905 .14286 L
F
.968 .032 .032 r
.58929 .17262 m
.58929 .20238 L
.61905 .20238 L
.61905 .17262 L
F
.935 .065 .065 r
.58929 .20238 m
.58929 .23214 L
.61905 .23214 L
.61905 .20238 L
F
.903 .097 .097 r
.58929 .23214 m
.58929 .2619 L
.61905 .2619 L
.61905 .23214 L
F
1 0 0 r
.58929 .2619 m
.58929 .29167 L
.61905 .29167 L
.61905 .2619 L
F
.968 .032 .032 r
.58929 .29167 m
.58929 .32143 L
.61905 .32143 L
.61905 .29167 L
F
.935 .065 .065 r
.58929 .32143 m
.58929 .35119 L
.61905 .35119 L
.61905 .32143 L
F
.903 .097 .097 r
.58929 .35119 m
.58929 .38095 L
.61905 .38095 L
.61905 .35119 L
F
1 0 0 r
.58929 .38095 m
.58929 .41071 L
.61905 .41071 L
.61905 .38095 L
F
.968 .032 .032 r
.58929 .41071 m
.58929 .44048 L
.61905 .44048 L
.61905 .41071 L
F
.935 .065 .065 r
.58929 .44048 m
.58929 .47024 L
.61905 .47024 L
.61905 .44048 L
F
.903 .097 .097 r
.58929 .47024 m
.58929 .5 L
.61905 .5 L
.61905 .47024 L
F
.484 .516 .516 r
.58929 .5 m
.58929 .52976 L
.61905 .52976 L
.61905 .5 L
F
.452 .548 .548 r
.58929 .52976 m
.58929 .55952 L
.61905 .55952 L
.61905 .52976 L
F
.419 .581 .581 r
.58929 .55952 m
.58929 .58929 L
.61905 .58929 L
.61905 .55952 L
F
.387 .613 .613 r
.58929 .58929 m
.58929 .61905 L
.61905 .61905 L
.61905 .58929 L
F
.484 .516 .516 r
.58929 .61905 m
.58929 .64881 L
.61905 .64881 L
.61905 .61905 L
F
.452 .548 .548 r
.58929 .64881 m
.58929 .67857 L
.61905 .67857 L
.61905 .64881 L
F
.419 .581 .581 r
.58929 .67857 m
.58929 .70833 L
.61905 .70833 L
.61905 .67857 L
F
.387 .613 .613 r
.58929 .70833 m
.58929 .7381 L
.61905 .7381 L
.61905 .70833 L
F
.484 .516 .516 r
.58929 .7381 m
.58929 .76786 L
.61905 .76786 L
.61905 .7381 L
F
.452 .548 .548 r
.58929 .76786 m
.58929 .79762 L
.61905 .79762 L
.61905 .76786 L
F
.419 .581 .581 r
.58929 .79762 m
.58929 .82738 L
.61905 .82738 L
.61905 .79762 L
F
.387 .613 .613 r
.58929 .82738 m
.58929 .85714 L
.61905 .85714 L
.61905 .82738 L
F
.484 .516 .516 r
.58929 .85714 m
.58929 .8869 L
.61905 .8869 L
.61905 .85714 L
F
.452 .548 .548 r
.58929 .8869 m
.58929 .91667 L
.61905 .91667 L
.61905 .8869 L
F
.419 .581 .581 r
.58929 .91667 m
.58929 .94643 L
.61905 .94643 L
.61905 .91667 L
F
.387 .613 .613 r
.58929 .94643 m
.58929 .97619 L
.61905 .97619 L
.61905 .94643 L
F
1 0 0 r
.61905 .02381 m
.61905 .05357 L
.64881 .05357 L
.64881 .02381 L
F
.61905 .05357 m
.61905 .08333 L
.64881 .08333 L
.64881 .05357 L
F
.61905 .08333 m
.61905 .1131 L
.64881 .1131 L
.64881 .08333 L
F
.61905 .1131 m
.61905 .14286 L
.64881 .14286 L
.64881 .1131 L
F
.871 .129 .129 r
.61905 .14286 m
.61905 .17262 L
.64881 .17262 L
.64881 .14286 L
F
.61905 .17262 m
.61905 .20238 L
.64881 .20238 L
.64881 .17262 L
F
.61905 .20238 m
.61905 .23214 L
.64881 .23214 L
.64881 .20238 L
F
.61905 .23214 m
.61905 .2619 L
.64881 .2619 L
.64881 .23214 L
F
1 0 0 r
.61905 .2619 m
.61905 .29167 L
.64881 .29167 L
.64881 .2619 L
F
.61905 .29167 m
.61905 .32143 L
.64881 .32143 L
.64881 .29167 L
F
.61905 .32143 m
.61905 .35119 L
.64881 .35119 L
.64881 .32143 L
F
.61905 .35119 m
.61905 .38095 L
.64881 .38095 L
.64881 .35119 L
F
.871 .129 .129 r
.61905 .38095 m
.61905 .41071 L
.64881 .41071 L
.64881 .38095 L
F
.61905 .41071 m
.61905 .44048 L
.64881 .44048 L
.64881 .41071 L
F
.61905 .44048 m
.61905 .47024 L
.64881 .47024 L
.64881 .44048 L
F
.61905 .47024 m
.61905 .5 L
.64881 .5 L
.64881 .47024 L
F
.484 .516 .516 r
.61905 .5 m
.61905 .52976 L
.64881 .52976 L
.64881 .5 L
F
.61905 .52976 m
.61905 .55952 L
.64881 .55952 L
.64881 .52976 L
F
.61905 .55952 m
.61905 .58929 L
.64881 .58929 L
.64881 .55952 L
F
.61905 .58929 m
.61905 .61905 L
.64881 .61905 L
.64881 .58929 L
F
.355 .645 .645 r
.61905 .61905 m
.61905 .64881 L
.64881 .64881 L
.64881 .61905 L
F
.61905 .64881 m
.61905 .67857 L
.64881 .67857 L
.64881 .64881 L
F
.61905 .67857 m
.61905 .70833 L
.64881 .70833 L
.64881 .67857 L
F
.61905 .70833 m
.61905 .7381 L
.64881 .7381 L
.64881 .70833 L
F
.484 .516 .516 r
.61905 .7381 m
.61905 .76786 L
.64881 .76786 L
.64881 .7381 L
F
.61905 .76786 m
.61905 .79762 L
.64881 .79762 L
.64881 .76786 L
F
.61905 .79762 m
.61905 .82738 L
.64881 .82738 L
.64881 .79762 L
F
.61905 .82738 m
.61905 .85714 L
.64881 .85714 L
.64881 .82738 L
F
.355 .645 .645 r
.61905 .85714 m
.61905 .8869 L
.64881 .8869 L
.64881 .85714 L
F
.61905 .8869 m
.61905 .91667 L
.64881 .91667 L
.64881 .8869 L
F
.61905 .91667 m
.61905 .94643 L
.64881 .94643 L
.64881 .91667 L
F
.61905 .94643 m
.61905 .97619 L
.64881 .97619 L
.64881 .94643 L
F
1 0 0 r
.64881 .02381 m
.64881 .05357 L
.67857 .05357 L
.67857 .02381 L
F
.968 .032 .032 r
.64881 .05357 m
.64881 .08333 L
.67857 .08333 L
.67857 .05357 L
F
1 0 0 r
.64881 .08333 m
.64881 .1131 L
.67857 .1131 L
.67857 .08333 L
F
.968 .032 .032 r
.64881 .1131 m
.64881 .14286 L
.67857 .14286 L
.67857 .1131 L
F
.871 .129 .129 r
.64881 .14286 m
.64881 .17262 L
.67857 .17262 L
.67857 .14286 L
F
.839 .161 .161 r
.64881 .17262 m
.64881 .20238 L
.67857 .20238 L
.67857 .17262 L
F
.871 .129 .129 r
.64881 .20238 m
.64881 .23214 L
.67857 .23214 L
.67857 .20238 L
F
.839 .161 .161 r
.64881 .23214 m
.64881 .2619 L
.67857 .2619 L
.67857 .23214 L
F
1 0 0 r
.64881 .2619 m
.64881 .29167 L
.67857 .29167 L
.67857 .2619 L
F
.968 .032 .032 r
.64881 .29167 m
.64881 .32143 L
.67857 .32143 L
.67857 .29167 L
F
1 0 0 r
.64881 .32143 m
.64881 .35119 L
.67857 .35119 L
.67857 .32143 L
F
.968 .032 .032 r
.64881 .35119 m
.64881 .38095 L
.67857 .38095 L
.67857 .35119 L
F
.871 .129 .129 r
.64881 .38095 m
.64881 .41071 L
.67857 .41071 L
.67857 .38095 L
F
.839 .161 .161 r
.64881 .41071 m
.64881 .44048 L
.67857 .44048 L
.67857 .41071 L
F
.871 .129 .129 r
.64881 .44048 m
.64881 .47024 L
.67857 .47024 L
.67857 .44048 L
F
.839 .161 .161 r
.64881 .47024 m
.64881 .5 L
.67857 .5 L
.67857 .47024 L
F
.484 .516 .516 r
.64881 .5 m
.64881 .52976 L
.67857 .52976 L
.67857 .5 L
F
.452 .548 .548 r
.64881 .52976 m
.64881 .55952 L
.67857 .55952 L
.67857 .52976 L
F
.484 .516 .516 r
.64881 .55952 m
.64881 .58929 L
.67857 .58929 L
.67857 .55952 L
F
.452 .548 .548 r
.64881 .58929 m
.64881 .61905 L
.67857 .61905 L
.67857 .58929 L
F
.355 .645 .645 r
.64881 .61905 m
.64881 .64881 L
.67857 .64881 L
.67857 .61905 L
F
.323 .677 .677 r
.64881 .64881 m
.64881 .67857 L
.67857 .67857 L
.67857 .64881 L
F
.355 .645 .645 r
.64881 .67857 m
.64881 .70833 L
.67857 .70833 L
.67857 .67857 L
F
.323 .677 .677 r
.64881 .70833 m
.64881 .7381 L
.67857 .7381 L
.67857 .70833 L
F
.484 .516 .516 r
.64881 .7381 m
.64881 .76786 L
.67857 .76786 L
.67857 .7381 L
F
.452 .548 .548 r
.64881 .76786 m
.64881 .79762 L
.67857 .79762 L
.67857 .76786 L
F
.484 .516 .516 r
.64881 .79762 m
.64881 .82738 L
.67857 .82738 L
.67857 .79762 L
F
.452 .548 .548 r
.64881 .82738 m
.64881 .85714 L
.67857 .85714 L
.67857 .82738 L
F
.355 .645 .645 r
.64881 .85714 m
.64881 .8869 L
.67857 .8869 L
.67857 .85714 L
F
.323 .677 .677 r
.64881 .8869 m
.64881 .91667 L
.67857 .91667 L
.67857 .8869 L
F
.355 .645 .645 r
.64881 .91667 m
.64881 .94643 L
.67857 .94643 L
.67857 .91667 L
F
.323 .677 .677 r
.64881 .94643 m
.64881 .97619 L
.67857 .97619 L
.67857 .94643 L
F
1 0 0 r
.67857 .02381 m
.67857 .05357 L
.70833 .05357 L
.70833 .02381 L
F
.67857 .05357 m
.67857 .08333 L
.70833 .08333 L
.70833 .05357 L
F
.935 .065 .065 r
.67857 .08333 m
.67857 .1131 L
.70833 .1131 L
.70833 .08333 L
F
.67857 .1131 m
.67857 .14286 L
.70833 .14286 L
.70833 .1131 L
F
.871 .129 .129 r
.67857 .14286 m
.67857 .17262 L
.70833 .17262 L
.70833 .14286 L
F
.67857 .17262 m
.67857 .20238 L
.70833 .20238 L
.70833 .17262 L
F
.806 .194 .194 r
.67857 .20238 m
.67857 .23214 L
.70833 .23214 L
.70833 .20238 L
F
.67857 .23214 m
.67857 .2619 L
.70833 .2619 L
.70833 .23214 L
F
1 0 0 r
.67857 .2619 m
.67857 .29167 L
.70833 .29167 L
.70833 .2619 L
F
.67857 .29167 m
.67857 .32143 L
.70833 .32143 L
.70833 .29167 L
F
.935 .065 .065 r
.67857 .32143 m
.67857 .35119 L
.70833 .35119 L
.70833 .32143 L
F
.67857 .35119 m
.67857 .38095 L
.70833 .38095 L
.70833 .35119 L
F
.871 .129 .129 r
.67857 .38095 m
.67857 .41071 L
.70833 .41071 L
.70833 .38095 L
F
.67857 .41071 m
.67857 .44048 L
.70833 .44048 L
.70833 .41071 L
F
.806 .194 .194 r
.67857 .44048 m
.67857 .47024 L
.70833 .47024 L
.70833 .44048 L
F
.67857 .47024 m
.67857 .5 L
.70833 .5 L
.70833 .47024 L
F
.484 .516 .516 r
.67857 .5 m
.67857 .52976 L
.70833 .52976 L
.70833 .5 L
F
.67857 .52976 m
.67857 .55952 L
.70833 .55952 L
.70833 .52976 L
F
.419 .581 .581 r
.67857 .55952 m
.67857 .58929 L
.70833 .58929 L
.70833 .55952 L
F
.67857 .58929 m
.67857 .61905 L
.70833 .61905 L
.70833 .58929 L
F
.355 .645 .645 r
.67857 .61905 m
.67857 .64881 L
.70833 .64881 L
.70833 .61905 L
F
.67857 .64881 m
.67857 .67857 L
.70833 .67857 L
.70833 .64881 L
F
.29 .71 .71 r
.67857 .67857 m
.67857 .70833 L
.70833 .70833 L
.70833 .67857 L
F
.67857 .70833 m
.67857 .7381 L
.70833 .7381 L
.70833 .70833 L
F
.484 .516 .516 r
.67857 .7381 m
.67857 .76786 L
.70833 .76786 L
.70833 .7381 L
F
.67857 .76786 m
.67857 .79762 L
.70833 .79762 L
.70833 .76786 L
F
.419 .581 .581 r
.67857 .79762 m
.67857 .82738 L
.70833 .82738 L
.70833 .79762 L
F
.67857 .82738 m
.67857 .85714 L
.70833 .85714 L
.70833 .82738 L
F
.355 .645 .645 r
.67857 .85714 m
.67857 .8869 L
.70833 .8869 L
.70833 .85714 L
F
.67857 .8869 m
.67857 .91667 L
.70833 .91667 L
.70833 .8869 L
F
.29 .71 .71 r
.67857 .91667 m
.67857 .94643 L
.70833 .94643 L
.70833 .91667 L
F
.67857 .94643 m
.67857 .97619 L
.70833 .97619 L
.70833 .94643 L
F
1 0 0 r
.70833 .02381 m
.70833 .05357 L
.7381 .05357 L
.7381 .02381 L
F
.968 .032 .032 r
.70833 .05357 m
.70833 .08333 L
.7381 .08333 L
.7381 .05357 L
F
.935 .065 .065 r
.70833 .08333 m
.70833 .1131 L
.7381 .1131 L
.7381 .08333 L
F
.903 .097 .097 r
.70833 .1131 m
.70833 .14286 L
.7381 .14286 L
.7381 .1131 L
F
.871 .129 .129 r
.70833 .14286 m
.70833 .17262 L
.7381 .17262 L
.7381 .14286 L
F
.839 .161 .161 r
.70833 .17262 m
.70833 .20238 L
.7381 .20238 L
.7381 .17262 L
F
.806 .194 .194 r
.70833 .20238 m
.70833 .23214 L
.7381 .23214 L
.7381 .20238 L
F
.774 .226 .226 r
.70833 .23214 m
.70833 .2619 L
.7381 .2619 L
.7381 .23214 L
F
1 0 0 r
.70833 .2619 m
.70833 .29167 L
.7381 .29167 L
.7381 .2619 L
F
.968 .032 .032 r
.70833 .29167 m
.70833 .32143 L
.7381 .32143 L
.7381 .29167 L
F
.935 .065 .065 r
.70833 .32143 m
.70833 .35119 L
.7381 .35119 L
.7381 .32143 L
F
.903 .097 .097 r
.70833 .35119 m
.70833 .38095 L
.7381 .38095 L
.7381 .35119 L
F
.871 .129 .129 r
.70833 .38095 m
.70833 .41071 L
.7381 .41071 L
.7381 .38095 L
F
.839 .161 .161 r
.70833 .41071 m
.70833 .44048 L
.7381 .44048 L
.7381 .41071 L
F
.806 .194 .194 r
.70833 .44048 m
.70833 .47024 L
.7381 .47024 L
.7381 .44048 L
F
.774 .226 .226 r
.70833 .47024 m
.70833 .5 L
.7381 .5 L
.7381 .47024 L
F
.484 .516 .516 r
.70833 .5 m
.70833 .52976 L
.7381 .52976 L
.7381 .5 L
F
.452 .548 .548 r
.70833 .52976 m
.70833 .55952 L
.7381 .55952 L
.7381 .52976 L
F
.419 .581 .581 r
.70833 .55952 m
.70833 .58929 L
.7381 .58929 L
.7381 .55952 L
F
.387 .613 .613 r
.70833 .58929 m
.70833 .61905 L
.7381 .61905 L
.7381 .58929 L
F
.355 .645 .645 r
.70833 .61905 m
.70833 .64881 L
.7381 .64881 L
.7381 .61905 L
F
.323 .677 .677 r
.70833 .64881 m
.70833 .67857 L
.7381 .67857 L
.7381 .64881 L
F
.29 .71 .71 r
.70833 .67857 m
.70833 .70833 L
.7381 .70833 L
.7381 .67857 L
F
.258 .742 .742 r
.70833 .70833 m
.70833 .7381 L
.7381 .7381 L
.7381 .70833 L
F
.484 .516 .516 r
.70833 .7381 m
.70833 .76786 L
.7381 .76786 L
.7381 .7381 L
F
.452 .548 .548 r
.70833 .76786 m
.70833 .79762 L
.7381 .79762 L
.7381 .76786 L
F
.419 .581 .581 r
.70833 .79762 m
.70833 .82738 L
.7381 .82738 L
.7381 .79762 L
F
.387 .613 .613 r
.70833 .82738 m
.70833 .85714 L
.7381 .85714 L
.7381 .82738 L
F
.355 .645 .645 r
.70833 .85714 m
.70833 .8869 L
.7381 .8869 L
.7381 .85714 L
F
.323 .677 .677 r
.70833 .8869 m
.70833 .91667 L
.7381 .91667 L
.7381 .8869 L
F
.29 .71 .71 r
.70833 .91667 m
.70833 .94643 L
.7381 .94643 L
.7381 .91667 L
F
.258 .742 .742 r
.70833 .94643 m
.70833 .97619 L
.7381 .97619 L
.7381 .94643 L
F
1 0 0 r
.7381 .02381 m
.7381 .05357 L
.76786 .05357 L
.76786 .02381 L
F
.7381 .05357 m
.7381 .08333 L
.76786 .08333 L
.76786 .05357 L
F
.7381 .08333 m
.7381 .1131 L
.76786 .1131 L
.76786 .08333 L
F
.7381 .1131 m
.7381 .14286 L
.76786 .14286 L
.76786 .1131 L
F
.7381 .14286 m
.7381 .17262 L
.76786 .17262 L
.76786 .14286 L
F
.7381 .17262 m
.7381 .20238 L
.76786 .20238 L
.76786 .17262 L
F
.7381 .20238 m
.7381 .23214 L
.76786 .23214 L
.76786 .20238 L
F
.7381 .23214 m
.7381 .2619 L
.76786 .2619 L
.76786 .23214 L
F
.742 .258 .258 r
.7381 .2619 m
.7381 .29167 L
.76786 .29167 L
.76786 .2619 L
F
.7381 .29167 m
.7381 .32143 L
.76786 .32143 L
.76786 .29167 L
F
.7381 .32143 m
.7381 .35119 L
.76786 .35119 L
.76786 .32143 L
F
.7381 .35119 m
.7381 .38095 L
.76786 .38095 L
.76786 .35119 L
F
.7381 .38095 m
.7381 .41071 L
.76786 .41071 L
.76786 .38095 L
F
.7381 .41071 m
.7381 .44048 L
.76786 .44048 L
.76786 .41071 L
F
.7381 .44048 m
.7381 .47024 L
.76786 .47024 L
.76786 .44048 L
F
.7381 .47024 m
.7381 .5 L
.76786 .5 L
.76786 .47024 L
F
.484 .516 .516 r
.7381 .5 m
.7381 .52976 L
.76786 .52976 L
.76786 .5 L
F
.7381 .52976 m
.7381 .55952 L
.76786 .55952 L
.76786 .52976 L
F
.7381 .55952 m
.7381 .58929 L
.76786 .58929 L
.76786 .55952 L
F
.7381 .58929 m
.7381 .61905 L
.76786 .61905 L
.76786 .58929 L
F
.7381 .61905 m
.7381 .64881 L
.76786 .64881 L
.76786 .61905 L
F
.7381 .64881 m
.7381 .67857 L
.76786 .67857 L
.76786 .64881 L
F
.7381 .67857 m
.7381 .70833 L
.76786 .70833 L
.76786 .67857 L
F
.7381 .70833 m
.7381 .7381 L
.76786 .7381 L
.76786 .70833 L
F
.226 .774 .774 r
.7381 .7381 m
.7381 .76786 L
.76786 .76786 L
.76786 .7381 L
F
.7381 .76786 m
.7381 .79762 L
.76786 .79762 L
.76786 .76786 L
F
.7381 .79762 m
.7381 .82738 L
.76786 .82738 L
.76786 .79762 L
F
.7381 .82738 m
.7381 .85714 L
.76786 .85714 L
.76786 .82738 L
F
.7381 .85714 m
.7381 .8869 L
.76786 .8869 L
.76786 .85714 L
F
.7381 .8869 m
.7381 .91667 L
.76786 .91667 L
.76786 .8869 L
F
.7381 .91667 m
.7381 .94643 L
.76786 .94643 L
.76786 .91667 L
F
.7381 .94643 m
.7381 .97619 L
.76786 .97619 L
.76786 .94643 L
F
1 0 0 r
.76786 .02381 m
.76786 .05357 L
.79762 .05357 L
.79762 .02381 L
F
.968 .032 .032 r
.76786 .05357 m
.76786 .08333 L
.79762 .08333 L
.79762 .05357 L
F
1 0 0 r
.76786 .08333 m
.76786 .1131 L
.79762 .1131 L
.79762 .08333 L
F
.968 .032 .032 r
.76786 .1131 m
.76786 .14286 L
.79762 .14286 L
.79762 .1131 L
F
1 0 0 r
.76786 .14286 m
.76786 .17262 L
.79762 .17262 L
.79762 .14286 L
F
.968 .032 .032 r
.76786 .17262 m
.76786 .20238 L
.79762 .20238 L
.79762 .17262 L
F
1 0 0 r
.76786 .20238 m
.76786 .23214 L
.79762 .23214 L
.79762 .20238 L
F
.968 .032 .032 r
.76786 .23214 m
.76786 .2619 L
.79762 .2619 L
.79762 .23214 L
F
.742 .258 .258 r
.76786 .2619 m
.76786 .29167 L
.79762 .29167 L
.79762 .2619 L
F
.71 .29 .29 r
.76786 .29167 m
.76786 .32143 L
.79762 .32143 L
.79762 .29167 L
F
.742 .258 .258 r
.76786 .32143 m
.76786 .35119 L
.79762 .35119 L
.79762 .32143 L
F
.71 .29 .29 r
.76786 .35119 m
.76786 .38095 L
.79762 .38095 L
.79762 .35119 L
F
.742 .258 .258 r
.76786 .38095 m
.76786 .41071 L
.79762 .41071 L
.79762 .38095 L
F
.71 .29 .29 r
.76786 .41071 m
.76786 .44048 L
.79762 .44048 L
.79762 .41071 L
F
.742 .258 .258 r
.76786 .44048 m
.76786 .47024 L
.79762 .47024 L
.79762 .44048 L
F
.71 .29 .29 r
.76786 .47024 m
.76786 .5 L
.79762 .5 L
.79762 .47024 L
F
.484 .516 .516 r
.76786 .5 m
.76786 .52976 L
.79762 .52976 L
.79762 .5 L
F
.452 .548 .548 r
.76786 .52976 m
.76786 .55952 L
.79762 .55952 L
.79762 .52976 L
F
.484 .516 .516 r
.76786 .55952 m
.76786 .58929 L
.79762 .58929 L
.79762 .55952 L
F
.452 .548 .548 r
.76786 .58929 m
.76786 .61905 L
.79762 .61905 L
.79762 .58929 L
F
.484 .516 .516 r
.76786 .61905 m
.76786 .64881 L
.79762 .64881 L
.79762 .61905 L
F
.452 .548 .548 r
.76786 .64881 m
.76786 .67857 L
.79762 .67857 L
.79762 .64881 L
F
.484 .516 .516 r
.76786 .67857 m
.76786 .70833 L
.79762 .70833 L
.79762 .67857 L
F
.452 .548 .548 r
.76786 .70833 m
.76786 .7381 L
.79762 .7381 L
.79762 .70833 L
F
.226 .774 .774 r
.76786 .7381 m
.76786 .76786 L
.79762 .76786 L
.79762 .7381 L
F
.194 .806 .806 r
.76786 .76786 m
.76786 .79762 L
.79762 .79762 L
.79762 .76786 L
F
.226 .774 .774 r
.76786 .79762 m
.76786 .82738 L
.79762 .82738 L
.79762 .79762 L
F
.194 .806 .806 r
.76786 .82738 m
.76786 .85714 L
.79762 .85714 L
.79762 .82738 L
F
.226 .774 .774 r
.76786 .85714 m
.76786 .8869 L
.79762 .8869 L
.79762 .85714 L
F
.194 .806 .806 r
.76786 .8869 m
.76786 .91667 L
.79762 .91667 L
.79762 .8869 L
F
.226 .774 .774 r
.76786 .91667 m
.76786 .94643 L
.79762 .94643 L
.79762 .91667 L
F
.194 .806 .806 r
.76786 .94643 m
.76786 .97619 L
.79762 .97619 L
.79762 .94643 L
F
1 0 0 r
.79762 .02381 m
.79762 .05357 L
.82738 .05357 L
.82738 .02381 L
F
.79762 .05357 m
.79762 .08333 L
.82738 .08333 L
.82738 .05357 L
F
.935 .065 .065 r
.79762 .08333 m
.79762 .1131 L
.82738 .1131 L
.82738 .08333 L
F
.79762 .1131 m
.79762 .14286 L
.82738 .14286 L
.82738 .1131 L
F
1 0 0 r
.79762 .14286 m
.79762 .17262 L
.82738 .17262 L
.82738 .14286 L
F
.79762 .17262 m
.79762 .20238 L
.82738 .20238 L
.82738 .17262 L
F
.935 .065 .065 r
.79762 .20238 m
.79762 .23214 L
.82738 .23214 L
.82738 .20238 L
F
.79762 .23214 m
.79762 .2619 L
.82738 .2619 L
.82738 .23214 L
F
.742 .258 .258 r
.79762 .2619 m
.79762 .29167 L
.82738 .29167 L
.82738 .2619 L
F
.79762 .29167 m
.79762 .32143 L
.82738 .32143 L
.82738 .29167 L
F
.677 .323 .323 r
.79762 .32143 m
.79762 .35119 L
.82738 .35119 L
.82738 .32143 L
F
.79762 .35119 m
.79762 .38095 L
.82738 .38095 L
.82738 .35119 L
F
.742 .258 .258 r
.79762 .38095 m
.79762 .41071 L
.82738 .41071 L
.82738 .38095 L
F
.79762 .41071 m
.79762 .44048 L
.82738 .44048 L
.82738 .41071 L
F
.677 .323 .323 r
.79762 .44048 m
.79762 .47024 L
.82738 .47024 L
.82738 .44048 L
F
.79762 .47024 m
.79762 .5 L
.82738 .5 L
.82738 .47024 L
F
.484 .516 .516 r
.79762 .5 m
.79762 .52976 L
.82738 .52976 L
.82738 .5 L
F
.79762 .52976 m
.79762 .55952 L
.82738 .55952 L
.82738 .52976 L
F
.419 .581 .581 r
.79762 .55952 m
.79762 .58929 L
.82738 .58929 L
.82738 .55952 L
F
.79762 .58929 m
.79762 .61905 L
.82738 .61905 L
.82738 .58929 L
F
.484 .516 .516 r
.79762 .61905 m
.79762 .64881 L
.82738 .64881 L
.82738 .61905 L
F
.79762 .64881 m
.79762 .67857 L
.82738 .67857 L
.82738 .64881 L
F
.419 .581 .581 r
.79762 .67857 m
.79762 .70833 L
.82738 .70833 L
.82738 .67857 L
F
.79762 .70833 m
.79762 .7381 L
.82738 .7381 L
.82738 .70833 L
F
.226 .774 .774 r
.79762 .7381 m
.79762 .76786 L
.82738 .76786 L
.82738 .7381 L
F
.79762 .76786 m
.79762 .79762 L
.82738 .79762 L
.82738 .76786 L
F
.161 .839 .839 r
.79762 .79762 m
.79762 .82738 L
.82738 .82738 L
.82738 .79762 L
F
.79762 .82738 m
.79762 .85714 L
.82738 .85714 L
.82738 .82738 L
F
.226 .774 .774 r
.79762 .85714 m
.79762 .8869 L
.82738 .8869 L
.82738 .85714 L
F
.79762 .8869 m
.79762 .91667 L
.82738 .91667 L
.82738 .8869 L
F
.161 .839 .839 r
.79762 .91667 m
.79762 .94643 L
.82738 .94643 L
.82738 .91667 L
F
.79762 .94643 m
.79762 .97619 L
.82738 .97619 L
.82738 .94643 L
F
1 0 0 r
.82738 .02381 m
.82738 .05357 L
.85714 .05357 L
.85714 .02381 L
F
.968 .032 .032 r
.82738 .05357 m
.82738 .08333 L
.85714 .08333 L
.85714 .05357 L
F
.935 .065 .065 r
.82738 .08333 m
.82738 .1131 L
.85714 .1131 L
.85714 .08333 L
F
.903 .097 .097 r
.82738 .1131 m
.82738 .14286 L
.85714 .14286 L
.85714 .1131 L
F
1 0 0 r
.82738 .14286 m
.82738 .17262 L
.85714 .17262 L
.85714 .14286 L
F
.968 .032 .032 r
.82738 .17262 m
.82738 .20238 L
.85714 .20238 L
.85714 .17262 L
F
.935 .065 .065 r
.82738 .20238 m
.82738 .23214 L
.85714 .23214 L
.85714 .20238 L
F
.903 .097 .097 r
.82738 .23214 m
.82738 .2619 L
.85714 .2619 L
.85714 .23214 L
F
.742 .258 .258 r
.82738 .2619 m
.82738 .29167 L
.85714 .29167 L
.85714 .2619 L
F
.71 .29 .29 r
.82738 .29167 m
.82738 .32143 L
.85714 .32143 L
.85714 .29167 L
F
.677 .323 .323 r
.82738 .32143 m
.82738 .35119 L
.85714 .35119 L
.85714 .32143 L
F
.645 .355 .355 r
.82738 .35119 m
.82738 .38095 L
.85714 .38095 L
.85714 .35119 L
F
.742 .258 .258 r
.82738 .38095 m
.82738 .41071 L
.85714 .41071 L
.85714 .38095 L
F
.71 .29 .29 r
.82738 .41071 m
.82738 .44048 L
.85714 .44048 L
.85714 .41071 L
F
.677 .323 .323 r
.82738 .44048 m
.82738 .47024 L
.85714 .47024 L
.85714 .44048 L
F
.645 .355 .355 r
.82738 .47024 m
.82738 .5 L
.85714 .5 L
.85714 .47024 L
F
.484 .516 .516 r
.82738 .5 m
.82738 .52976 L
.85714 .52976 L
.85714 .5 L
F
.452 .548 .548 r
.82738 .52976 m
.82738 .55952 L
.85714 .55952 L
.85714 .52976 L
F
.419 .581 .581 r
.82738 .55952 m
.82738 .58929 L
.85714 .58929 L
.85714 .55952 L
F
.387 .613 .613 r
.82738 .58929 m
.82738 .61905 L
.85714 .61905 L
.85714 .58929 L
F
.484 .516 .516 r
.82738 .61905 m
.82738 .64881 L
.85714 .64881 L
.85714 .61905 L
F
.452 .548 .548 r
.82738 .64881 m
.82738 .67857 L
.85714 .67857 L
.85714 .64881 L
F
.419 .581 .581 r
.82738 .67857 m
.82738 .70833 L
.85714 .70833 L
.85714 .67857 L
F
.387 .613 .613 r
.82738 .70833 m
.82738 .7381 L
.85714 .7381 L
.85714 .70833 L
F
.226 .774 .774 r
.82738 .7381 m
.82738 .76786 L
.85714 .76786 L
.85714 .7381 L
F
.194 .806 .806 r
.82738 .76786 m
.82738 .79762 L
.85714 .79762 L
.85714 .76786 L
F
.161 .839 .839 r
.82738 .79762 m
.82738 .82738 L
.85714 .82738 L
.85714 .79762 L
F
.129 .871 .871 r
.82738 .82738 m
.82738 .85714 L
.85714 .85714 L
.85714 .82738 L
F
.226 .774 .774 r
.82738 .85714 m
.82738 .8869 L
.85714 .8869 L
.85714 .85714 L
F
.194 .806 .806 r
.82738 .8869 m
.82738 .91667 L
.85714 .91667 L
.85714 .8869 L
F
.161 .839 .839 r
.82738 .91667 m
.82738 .94643 L
.85714 .94643 L
.85714 .91667 L
F
.129 .871 .871 r
.82738 .94643 m
.82738 .97619 L
.85714 .97619 L
.85714 .94643 L
F
1 0 0 r
.85714 .02381 m
.85714 .05357 L
.8869 .05357 L
.8869 .02381 L
F
.85714 .05357 m
.85714 .08333 L
.8869 .08333 L
.8869 .05357 L
F
.85714 .08333 m
.85714 .1131 L
.8869 .1131 L
.8869 .08333 L
F
.85714 .1131 m
.85714 .14286 L
.8869 .14286 L
.8869 .1131 L
F
.871 .129 .129 r
.85714 .14286 m
.85714 .17262 L
.8869 .17262 L
.8869 .14286 L
F
.85714 .17262 m
.85714 .20238 L
.8869 .20238 L
.8869 .17262 L
F
.85714 .20238 m
.85714 .23214 L
.8869 .23214 L
.8869 .20238 L
F
.85714 .23214 m
.85714 .2619 L
.8869 .2619 L
.8869 .23214 L
F
.742 .258 .258 r
.85714 .2619 m
.85714 .29167 L
.8869 .29167 L
.8869 .2619 L
F
.85714 .29167 m
.85714 .32143 L
.8869 .32143 L
.8869 .29167 L
F
.85714 .32143 m
.85714 .35119 L
.8869 .35119 L
.8869 .32143 L
F
.85714 .35119 m
.85714 .38095 L
.8869 .38095 L
.8869 .35119 L
F
.613 .387 .387 r
.85714 .38095 m
.85714 .41071 L
.8869 .41071 L
.8869 .38095 L
F
.85714 .41071 m
.85714 .44048 L
.8869 .44048 L
.8869 .41071 L
F
.85714 .44048 m
.85714 .47024 L
.8869 .47024 L
.8869 .44048 L
F
.85714 .47024 m
.85714 .5 L
.8869 .5 L
.8869 .47024 L
F
.484 .516 .516 r
.85714 .5 m
.85714 .52976 L
.8869 .52976 L
.8869 .5 L
F
.85714 .52976 m
.85714 .55952 L
.8869 .55952 L
.8869 .52976 L
F
.85714 .55952 m
.85714 .58929 L
.8869 .58929 L
.8869 .55952 L
F
.85714 .58929 m
.85714 .61905 L
.8869 .61905 L
.8869 .58929 L
F
.355 .645 .645 r
.85714 .61905 m
.85714 .64881 L
.8869 .64881 L
.8869 .61905 L
F
.85714 .64881 m
.85714 .67857 L
.8869 .67857 L
.8869 .64881 L
F
.85714 .67857 m
.85714 .70833 L
.8869 .70833 L
.8869 .67857 L
F
.85714 .70833 m
.85714 .7381 L
.8869 .7381 L
.8869 .70833 L
F
.226 .774 .774 r
.85714 .7381 m
.85714 .76786 L
.8869 .76786 L
.8869 .7381 L
F
.85714 .76786 m
.85714 .79762 L
.8869 .79762 L
.8869 .76786 L
F
.85714 .79762 m
.85714 .82738 L
.8869 .82738 L
.8869 .79762 L
F
.85714 .82738 m
.85714 .85714 L
.8869 .85714 L
.8869 .82738 L
F
.097 .903 .903 r
.85714 .85714 m
.85714 .8869 L
.8869 .8869 L
.8869 .85714 L
F
.85714 .8869 m
.85714 .91667 L
.8869 .91667 L
.8869 .8869 L
F
.85714 .91667 m
.85714 .94643 L
.8869 .94643 L
.8869 .91667 L
F
.85714 .94643 m
.85714 .97619 L
.8869 .97619 L
.8869 .94643 L
F
1 0 0 r
.8869 .02381 m
.8869 .05357 L
.91667 .05357 L
.91667 .02381 L
F
.968 .032 .032 r
.8869 .05357 m
.8869 .08333 L
.91667 .08333 L
.91667 .05357 L
F
1 0 0 r
.8869 .08333 m
.8869 .1131 L
.91667 .1131 L
.91667 .08333 L
F
.968 .032 .032 r
.8869 .1131 m
.8869 .14286 L
.91667 .14286 L
.91667 .1131 L
F
.871 .129 .129 r
.8869 .14286 m
.8869 .17262 L
.91667 .17262 L
.91667 .14286 L
F
.839 .161 .161 r
.8869 .17262 m
.8869 .20238 L
.91667 .20238 L
.91667 .17262 L
F
.871 .129 .129 r
.8869 .20238 m
.8869 .23214 L
.91667 .23214 L
.91667 .20238 L
F
.839 .161 .161 r
.8869 .23214 m
.8869 .2619 L
.91667 .2619 L
.91667 .23214 L
F
.742 .258 .258 r
.8869 .2619 m
.8869 .29167 L
.91667 .29167 L
.91667 .2619 L
F
.71 .29 .29 r
.8869 .29167 m
.8869 .32143 L
.91667 .32143 L
.91667 .29167 L
F
.742 .258 .258 r
.8869 .32143 m
.8869 .35119 L
.91667 .35119 L
.91667 .32143 L
F
.71 .29 .29 r
.8869 .35119 m
.8869 .38095 L
.91667 .38095 L
.91667 .35119 L
F
.613 .387 .387 r
.8869 .38095 m
.8869 .41071 L
.91667 .41071 L
.91667 .38095 L
F
.581 .419 .419 r
.8869 .41071 m
.8869 .44048 L
.91667 .44048 L
.91667 .41071 L
F
.613 .387 .387 r
.8869 .44048 m
.8869 .47024 L
.91667 .47024 L
.91667 .44048 L
F
.581 .419 .419 r
.8869 .47024 m
.8869 .5 L
.91667 .5 L
.91667 .47024 L
F
.484 .516 .516 r
.8869 .5 m
.8869 .52976 L
.91667 .52976 L
.91667 .5 L
F
.452 .548 .548 r
.8869 .52976 m
.8869 .55952 L
.91667 .55952 L
.91667 .52976 L
F
.484 .516 .516 r
.8869 .55952 m
.8869 .58929 L
.91667 .58929 L
.91667 .55952 L
F
.452 .548 .548 r
.8869 .58929 m
.8869 .61905 L
.91667 .61905 L
.91667 .58929 L
F
.355 .645 .645 r
.8869 .61905 m
.8869 .64881 L
.91667 .64881 L
.91667 .61905 L
F
.323 .677 .677 r
.8869 .64881 m
.8869 .67857 L
.91667 .67857 L
.91667 .64881 L
F
.355 .645 .645 r
.8869 .67857 m
.8869 .70833 L
.91667 .70833 L
.91667 .67857 L
F
.323 .677 .677 r
.8869 .70833 m
.8869 .7381 L
.91667 .7381 L
.91667 .70833 L
F
.226 .774 .774 r
.8869 .7381 m
.8869 .76786 L
.91667 .76786 L
.91667 .7381 L
F
.194 .806 .806 r
.8869 .76786 m
.8869 .79762 L
.91667 .79762 L
.91667 .76786 L
F
.226 .774 .774 r
.8869 .79762 m
.8869 .82738 L
.91667 .82738 L
.91667 .79762 L
F
.194 .806 .806 r
.8869 .82738 m
.8869 .85714 L
.91667 .85714 L
.91667 .82738 L
F
.097 .903 .903 r
.8869 .85714 m
.8869 .8869 L
.91667 .8869 L
.91667 .85714 L
F
.065 .935 .935 r
.8869 .8869 m
.8869 .91667 L
.91667 .91667 L
.91667 .8869 L
F
.097 .903 .903 r
.8869 .91667 m
.8869 .94643 L
.91667 .94643 L
.91667 .91667 L
F
.065 .935 .935 r
.8869 .94643 m
.8869 .97619 L
.91667 .97619 L
.91667 .94643 L
F
1 0 0 r
.91667 .02381 m
.91667 .05357 L
.94643 .05357 L
.94643 .02381 L
F
.91667 .05357 m
.91667 .08333 L
.94643 .08333 L
.94643 .05357 L
F
.935 .065 .065 r
.91667 .08333 m
.91667 .1131 L
.94643 .1131 L
.94643 .08333 L
F
.91667 .1131 m
.91667 .14286 L
.94643 .14286 L
.94643 .1131 L
F
.871 .129 .129 r
.91667 .14286 m
.91667 .17262 L
.94643 .17262 L
.94643 .14286 L
F
.91667 .17262 m
.91667 .20238 L
.94643 .20238 L
.94643 .17262 L
F
.806 .194 .194 r
.91667 .20238 m
.91667 .23214 L
.94643 .23214 L
.94643 .20238 L
F
.91667 .23214 m
.91667 .2619 L
.94643 .2619 L
.94643 .23214 L
F
.742 .258 .258 r
.91667 .2619 m
.91667 .29167 L
.94643 .29167 L
.94643 .2619 L
F
.91667 .29167 m
.91667 .32143 L
.94643 .32143 L
.94643 .29167 L
F
.677 .323 .323 r
.91667 .32143 m
.91667 .35119 L
.94643 .35119 L
.94643 .32143 L
F
.91667 .35119 m
.91667 .38095 L
.94643 .38095 L
.94643 .35119 L
F
.613 .387 .387 r
.91667 .38095 m
.91667 .41071 L
.94643 .41071 L
.94643 .38095 L
F
.91667 .41071 m
.91667 .44048 L
.94643 .44048 L
.94643 .41071 L
F
.548 .452 .452 r
.91667 .44048 m
.91667 .47024 L
.94643 .47024 L
.94643 .44048 L
F
.91667 .47024 m
.91667 .5 L
.94643 .5 L
.94643 .47024 L
F
.484 .516 .516 r
.91667 .5 m
.91667 .52976 L
.94643 .52976 L
.94643 .5 L
F
.91667 .52976 m
.91667 .55952 L
.94643 .55952 L
.94643 .52976 L
F
.419 .581 .581 r
.91667 .55952 m
.91667 .58929 L
.94643 .58929 L
.94643 .55952 L
F
.91667 .58929 m
.91667 .61905 L
.94643 .61905 L
.94643 .58929 L
F
.355 .645 .645 r
.91667 .61905 m
.91667 .64881 L
.94643 .64881 L
.94643 .61905 L
F
.91667 .64881 m
.91667 .67857 L
.94643 .67857 L
.94643 .64881 L
F
.29 .71 .71 r
.91667 .67857 m
.91667 .70833 L
.94643 .70833 L
.94643 .67857 L
F
.91667 .70833 m
.91667 .7381 L
.94643 .7381 L
.94643 .70833 L
F
.226 .774 .774 r
.91667 .7381 m
.91667 .76786 L
.94643 .76786 L
.94643 .7381 L
F
.91667 .76786 m
.91667 .79762 L
.94643 .79762 L
.94643 .76786 L
F
.161 .839 .839 r
.91667 .79762 m
.91667 .82738 L
.94643 .82738 L
.94643 .79762 L
F
.91667 .82738 m
.91667 .85714 L
.94643 .85714 L
.94643 .82738 L
F
.097 .903 .903 r
.91667 .85714 m
.91667 .8869 L
.94643 .8869 L
.94643 .85714 L
F
.91667 .8869 m
.91667 .91667 L
.94643 .91667 L
.94643 .8869 L
F
.032 .968 .968 r
.91667 .91667 m
.91667 .94643 L
.94643 .94643 L
.94643 .91667 L
F
.91667 .94643 m
.91667 .97619 L
.94643 .97619 L
.94643 .94643 L
F
1 0 0 r
.94643 .02381 m
.94643 .05357 L
.97619 .05357 L
.97619 .02381 L
F
.968 .032 .032 r
.94643 .05357 m
.94643 .08333 L
.97619 .08333 L
.97619 .05357 L
F
.935 .065 .065 r
.94643 .08333 m
.94643 .1131 L
.97619 .1131 L
.97619 .08333 L
F
.903 .097 .097 r
.94643 .1131 m
.94643 .14286 L
.97619 .14286 L
.97619 .1131 L
F
.871 .129 .129 r
.94643 .14286 m
.94643 .17262 L
.97619 .17262 L
.97619 .14286 L
F
.839 .161 .161 r
.94643 .17262 m
.94643 .20238 L
.97619 .20238 L
.97619 .17262 L
F
.806 .194 .194 r
.94643 .20238 m
.94643 .23214 L
.97619 .23214 L
.97619 .20238 L
F
.774 .226 .226 r
.94643 .23214 m
.94643 .2619 L
.97619 .2619 L
.97619 .23214 L
F
.742 .258 .258 r
.94643 .2619 m
.94643 .29167 L
.97619 .29167 L
.97619 .2619 L
F
.71 .29 .29 r
.94643 .29167 m
.94643 .32143 L
.97619 .32143 L
.97619 .29167 L
F
.677 .323 .323 r
.94643 .32143 m
.94643 .35119 L
.97619 .35119 L
.97619 .32143 L
F
.645 .355 .355 r
.94643 .35119 m
.94643 .38095 L
.97619 .38095 L
.97619 .35119 L
F
.613 .387 .387 r
.94643 .38095 m
.94643 .41071 L
.97619 .41071 L
.97619 .38095 L
F
.581 .419 .419 r
.94643 .41071 m
.94643 .44048 L
.97619 .44048 L
.97619 .41071 L
F
.548 .452 .452 r
.94643 .44048 m
.94643 .47024 L
.97619 .47024 L
.97619 .44048 L
F
.516 .484 .484 r
.94643 .47024 m
.94643 .5 L
.97619 .5 L
.97619 .47024 L
F
.484 .516 .516 r
.94643 .5 m
.94643 .52976 L
.97619 .52976 L
.97619 .5 L
F
.452 .548 .548 r
.94643 .52976 m
.94643 .55952 L
.97619 .55952 L
.97619 .52976 L
F
.419 .581 .581 r
.94643 .55952 m
.94643 .58929 L
.97619 .58929 L
.97619 .55952 L
F
.387 .613 .613 r
.94643 .58929 m
.94643 .61905 L
.97619 .61905 L
.97619 .58929 L
F
.355 .645 .645 r
.94643 .61905 m
.94643 .64881 L
.97619 .64881 L
.97619 .61905 L
F
.323 .677 .677 r
.94643 .64881 m
.94643 .67857 L
.97619 .67857 L
.97619 .64881 L
F
.29 .71 .71 r
.94643 .67857 m
.94643 .70833 L
.97619 .70833 L
.97619 .67857 L
F
.258 .742 .742 r
.94643 .70833 m
.94643 .7381 L
.97619 .7381 L
.97619 .70833 L
F
.226 .774 .774 r
.94643 .7381 m
.94643 .76786 L
.97619 .76786 L
.97619 .7381 L
F
.194 .806 .806 r
.94643 .76786 m
.94643 .79762 L
.97619 .79762 L
.97619 .76786 L
F
.161 .839 .839 r
.94643 .79762 m
.94643 .82738 L
.97619 .82738 L
.97619 .79762 L
F
.129 .871 .871 r
.94643 .82738 m
.94643 .85714 L
.97619 .85714 L
.97619 .82738 L
F
.097 .903 .903 r
.94643 .85714 m
.94643 .8869 L
.97619 .8869 L
.97619 .85714 L
F
.065 .935 .935 r
.94643 .8869 m
.94643 .91667 L
.97619 .91667 L
.97619 .8869 L
F
.032 .968 .968 r
.94643 .91667 m
.94643 .94643 L
.97619 .94643 L
.97619 .91667 L
F
0 1 1 r
.94643 .94643 m
.94643 .97619 L
.97619 .97619 L
.97619 .94643 L
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3AcJTQ
0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ
0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@001P3AcJWo0?l001<0o`00203AcJT000H0dLfYo`3o
000C0?l000P0dLfY00060=7=ZOl0o`004`3o00080=7=Z@001P3AcJWo0?l001<0o`00203AcJT000H0
dLfYo`3o000C0?l000P0dLfY00060=7=ZOl0o`004`3o00080=7=Z@001P3AcJWo0?l001<0o`00203A
cJT000H0dLfYo`3o000C0?l000P0dLfY00060=7=ZOl0o`004`3o00080=7=Z@001P3AcJT90?l000P0
m`P82@3o00090?L820P0o`002@3g20P80?l000T0m`P8203o00090?L820P0o`002@3g20P80?l000T0
m`P8203o00090?L820T0o`00203g20P90?l000P0m`P82@3o00080?L820T0o`00203g20P90?l000P0
m`P82@3o00090?L820P0o`002@3g20P80?l000T0m`P8203AcJT000H0dLfY2@3o00080?L820T0o`00
2@3g20P80?l000T0m`P8203o00090?L820P0o`002@3g20P80?l000T0m`P8203o00090?L820P0o`00
2@3g20P90?l000P0m`P82@3o00080?L820T0o`00203g20P90?l000P0m`P82@3o00080?L820T0o`00
2@3g20P80?l000T0m`P8203o00090?L820P0dLfY00060=7=Z@T0o`00203g20P90?l000T0m`P8203o
00090?L820P0o`002@3g20P80?l000T0m`P8203o00090?L820P0o`002@3g20P80?l000T0m`P82@3o
00080?L820T0o`00203g20P90?l000P0m`P82@3o00080?L820T0o`00203g20P90?l000T0m`P8203o
00090?L820P0o`002@3g20P80=7=Z@001P3AcJT90?l000P0m`P82@3o00090?L820P0o`002@3g20P8
0?l000T0m`P8203o00090?L820P0o`002@3g20P80?l000T0m`P8203o00090?L820T0o`00203g20P9
0?l000P0m`P82@3o00080?L820T0o`00203g20P90?l000P0m`P82@3o00090?L820P0o`002@3g20P8
0?l000T0m`P8203AcJT000H0dLfY2@3o00080?L820T0o`002@3g20P80?l000T0m`P8203o00090?L8
20P0o`002@3g20P80?l000T0m`P8203o00090?L820P0o`002@3g20P90?l000P0m`P82@3o00080?L8
20T0o`00203g20P90?l000P0m`P82@3o00080?L820T0o`002@3g20P80?l000T0m`P8203o00090?L8
20P0dLfY00060=7=Z@T0o`00203g20P90?l000T0m`P8203o00090?L820P0o`002@3g20P80?l000T0
m`P8203o00090?L820P0o`002@3g20P80?l000T0m`P82@3o00080?L820T0o`00203g20P90?l000P0
m`P82@3o00080?L820T0o`00203g20P90?l000T0m`P8203o00090?L820P0o`002@3g20P80=7=Z@00
1P3AcJT90?l000P0m`P82@3o00090?L820P0o`002@3g20P80?l000T0m`P8203o00090?L820P0o`00
2@3g20P80?l000T0m`P8203o00090?L820T0o`00203g20P90?l000P0m`P82@3o00080?L820T0o`00
203g20P90?l000P0m`P82@3o00090?L820P0o`002@3g20P80?l000T0m`P8203AcJT000H0dLfY2@3o
00080?L820T0o`002@3g20P80?l000T0m`P8203o00090?L820P0o`002@3g20P80?l000T0m`P8203o
00090?L820P0o`002@3g20P90?l000P0m`P82@3o00080?L820T0o`00203g20P90?l000P0m`P82@3o
00080?L820T0o`002@3g20P80?l000T0m`P8203o00090?L820P0dLfY00060=7=ZA40o`004P3_410A
0?l00140ka0@4@3o000A0>l@4140o`004@3_410A0?l00140ka0@4@3o000A0>l@4140o`004P3_410A
0?l00140ka0@203AcJT000H0dLfY4@3o000B0>l@4140o`004@3_410A0?l00140ka0@4@3o000A0>l@
4140o`004@3_410A0?l00140ka0@4@3o000B0>l@4140o`004@3_41080=7=Z@001P3AcJTA0?l00180
ka0@4@3o000A0>l@4140o`004@3_410A0?l00140ka0@4@3o000A0>l@4140o`004@3_410A0?l00180
ka0@4@3o000A0>l@40P0dLfY00060=7=ZA40o`004P3_410A0?l00140ka0@4@3o000A0>l@4140o`00
4@3_410A0?l00140ka0@4@3o000A0>l@4140o`004P3_410A0?l00140ka0@203AcJT000H0dLfY4@3o
000B0>l@4140o`004@3_410A0?l00140ka0@4@3o000A0>l@4140o`004@3_410A0?l00140ka0@4@3o
000B0>l@4140o`004@3_41080=7=Z@001P3AcJTA0?l00180ka0@4@3o000A0>l@4140o`004@3_410A
0?l00140ka0@4@3o000A0>l@4140o`004@3_410A0?l00180ka0@4@3o000A0>l@40P0dLfY00060=7=
ZA40o`004P3_410A0?l00140ka0@4@3o000A0>l@4140o`004@3_410A0?l00140ka0@4@3o000A0>l@
4140o`004P3_410A0?l00140ka0@203AcJT000H0dLfY4@3o000B0>l@4140o`004@3_410A0?l00140
ka0@4@3o000A0>l@4140o`004@3_410A0?l00140ka0@4@3o000B0>l@4140o`004@3_41080=7=Z@00
1P3AcJTA0?l00180ka0@4@3o000A0>l@4140o`004@3_410A0?l00140ka0@4@3o000A0>l@4140o`00
4@3_410A0?l00180ka0@4@3o000A0>l@40P0dLfY00060=7=Z@T0o`00203g20P90>l@40T0iaPH203o
00090?L820P0ka0@2@3W61P80?l000T0m`P8203_41090>LH60P0o`002@3g20P80>l@40T0iaPH2@3o
00080?L820T0ka0@203W61P90?l000P0m`P82@3_41080>LH60T0o`00203g20P90>l@40T0iaPH203o
00090?L820P0ka0@2@3W61P80=7=Z@001P3AcJT90?l000P0m`P82@3_41090>LH60P0o`002@3g20P8
0>l@40T0iaPH203o00090?L820P0ka0@2@3W61P80?l000T0m`P8203_41090>LH60T0o`00203g20P9
0>l@40P0iaPH2@3o00080?L820T0ka0@203W61P90?l000P0m`P82@3_41090>LH60P0o`002@3g20P8
0>l@40T0iaPH203AcJT000H0dLfY2@3o00080?L820T0ka0@2@3W61P80?l000T0m`P8203_41090>LH
60P0o`002@3g20P80>l@40T0iaPH203o00090?L820P0ka0@2@3W61P90?l000P0m`P82@3_41080>LH
60T0o`00203g20P90>l@40P0iaPH2@3o00080?L820T0ka0@2@3W61P80?l000T0m`P8203_41090>LH
60P0dLfY00060=7=Z@T0o`00203g20P90>l@40T0iaPH203o00090?L820P0ka0@2@3W61P80?l000T0
m`P8203_41090>LH60P0o`002@3g20P80>l@40T0iaPH2@3o00080?L820T0ka0@203W61P90?l000P0
m`P82@3_41080>LH60T0o`00203g20P90>l@40T0iaPH203o00090?L820P0ka0@2@3W61P80=7=Z@00
1P3AcJT90?l000P0m`P82@3_41090>LH60P0o`002@3g20P80>l@40T0iaPH203o00090?L820P0ka0@
2@3W61P80?l000T0m`P8203_41090>LH60T0o`00203g20P90>l@40P0iaPH2@3o00080?L820T0ka0@
203W61P90?l000P0m`P82@3_41090>LH60P0o`002@3g20P80>l@40T0iaPH203AcJT000H0dLfY2@3o
00080?L820T0ka0@2@3W61P80?l000T0m`P8203_41090>LH60P0o`002@3g20P80>l@40T0iaPH203o
00090?L820P0ka0@2@3W61P90?l000P0m`P82@3_41080>LH60T0o`00203g20P90>l@40P0iaPH2@3o
00080?L820T0ka0@2@3W61P80?l000T0m`P8203_41090>LH60P0dLfY00060=7=Z@T0o`00203g20P9
0>l@40T0iaPH203o00090?L820P0ka0@2@3W61P80?l000T0m`P8203_41090>LH60P0o`002@3g20P8
0>l@40T0iaPH2@3o00080?L820T0ka0@203W61P90?l000P0m`P82@3_41080>LH60T0o`00203g20P9
0>l@40T0iaPH203o00090?L820P0ka0@2@3W61P80=7=Z@001P3AcJT90?l000P0m`P82@3_41090>LH
60P0o`002@3g20P80>l@40T0iaPH203o00090?L820P0ka0@2@3W61P80?l000T0m`P8203_41090>LH
60T0o`00203g20P90>l@40P0iaPH2@3o00080?L820T0ka0@203W61P90?l000P0m`P82@3_41090>LH
60P0o`002@3g20P80>l@40T0iaPH203AcJT000H0dLfY8`3o000R0=hQ8B80o`008P3N8B4R0?l00280
gR4Q8`3o000R0=hQ8@P0dLfY00060=7=ZB<0o`008P3N8B4R0?l00280gR4Q8P3o000R0=hQ8B<0o`00
8P3N8B480=7=Z@001P3AcJTS0?l00280gR4Q8P3o000R0=hQ8B80o`008P3N8B4S0?l00280gR4Q203A
cJT000H0dLfY8`3o000R0=hQ8B80o`008P3N8B4R0?l00280gR4Q8`3o000R0=hQ8@P0dLfY00060=7=
ZB<0o`008P3N8B4R0?l00280gR4Q8P3o000R0=hQ8B<0o`008P3N8B480=7=Z@001P3AcJTS0?l00280
gR4Q8P3o000R0=hQ8B80o`008P3N8B4S0?l00280gR4Q203AcJT000H0dLfY8`3o000R0=hQ8B80o`00
8P3N8B4R0?l00280gR4Q8`3o000R0=hQ8@P0dLfY00060=7=ZB<0o`008P3N8B4R0?l00280gR4Q8P3o
000R0=hQ8B<0o`008P3N8B480=7=Z@001P3AcJTS0?l00280gR4Q8P3o000R0=hQ8B80o`008P3N8B4S
0?l00280gR4Q203AcJT000H0dLfY2@3o00080?L820T0o`002@3g20P80=hQ8@T0eRTY203N8B490=HY
:@P0o`002@3g20P80?l000T0m`P8203N8B490=HY:@P0gR4Q2@3F:BT90?l000P0m`P82@3o00080?L8
20T0gR4Q203F:BT90=hQ8@P0eRTY2@3o00080?L820T0o`002@3g20P80=hQ8@T0eRTY203N8B490=HY
:@P0dLfY00060=7=Z@T0o`00203g20P90?l000T0m`P8203N8B490=HY:@P0gR4Q2@3F:BT80?l000T0
m`P8203o00090?L820P0gR4Q2@3F:BT80=hQ8@T0eRTY2@3o00080?L820T0o`00203g20P90=hQ8@P0
eRTY2@3N8B480=HY:@T0o`00203g20P90?l000T0m`P8203N8B490=HY:@P0gR4Q2@3F:BT80=7=Z@00
1P3AcJT90?l000P0m`P82@3o00090?L820P0gR4Q2@3F:BT80=hQ8@T0eRTY203o00090?L820P0o`00
2@3g20P80=hQ8@T0eRTY203N8B490=HY:@T0o`00203g20P90?l000P0m`P82@3N8B480=HY:@T0gR4Q
203F:BT90?l000P0m`P82@3o00090?L820P0gR4Q2@3F:BT80=hQ8@T0eRTY203AcJT000H0dLfY2@3o
00080?L820T0o`002@3g20P80=hQ8@T0eRTY203N8B490=HY:@P0o`002@3g20P80?l000T0m`P8203N
8B490=HY:@P0gR4Q2@3F:BT90?l000P0m`P82@3o00080?L820T0gR4Q203F:BT90=hQ8@P0eRTY2@3o
00080?L820T0o`002@3g20P80=hQ8@T0eRTY203N8B490=HY:@P0dLfY00060=7=Z@T0o`00203g20P9
0?l000T0m`P8203N8B490=HY:@P0gR4Q2@3F:BT80?l000T0m`P8203o00090?L820P0gR4Q2@3F:BT8
0=hQ8@T0eRTY2@3o00080?L820T0o`00203g20P90=hQ8@P0eRTY2@3N8B480=HY:@T0o`00203g20P9
0?l000T0m`P8203N8B490=HY:@P0gR4Q2@3F:BT80=7=Z@001P3AcJT90?l000P0m`P82@3o00090?L8
20P0gR4Q2@3F:BT80=hQ8@T0eRTY203o00090?L820P0o`002@3g20P80=hQ8@T0eRTY203N8B490=HY
:@T0o`00203g20P90?l000P0m`P82@3N8B480=HY:@T0gR4Q203F:BT90?l000P0m`P82@3o00090?L8
20P0gR4Q2@3F:BT80=hQ8@T0eRTY203AcJT000H0dLfY2@3o00080?L820T0o`002@3g20P80=hQ8@T0
eRTY203N8B490=HY:@P0o`002@3g20P80?l000T0m`P8203N8B490=HY:@P0gR4Q2@3F:BT90?l000P0
m`P82@3o00080?L820T0gR4Q203F:BT90=hQ8@P0eRTY2@3o00080?L820T0o`002@3g20P80=hQ8@T0
eRTY203N8B490=HY:@P0dLfY00060=7=Z@T0o`00203g20P90?l000T0m`P8203N8B490=HY:@P0gR4Q
2@3F:BT80?l000T0m`P8203o00090?L820P0gR4Q2@3F:BT80=hQ8@T0eRTY2@3o00080?L820T0o`00
203g20P90=hQ8@P0eRTY2@3N8B480=HY:@T0o`00203g20P90?l000T0m`P8203N8B490=HY:@P0gR4Q
2@3F:BT80=7=Z@001P3AcJT90?l000P0m`P82@3o00090?L820P0gR4Q2@3F:BT80=hQ8@T0eRTY203o
00090?L820P0o`002@3g20P80=hQ8@T0eRTY203N8B490=HY:@T0o`00203g20P90?l000P0m`P82@3N
8B480=HY:@T0gR4Q203F:BT90?l000P0m`P82@3o00090?L820P0gR4Q2@3F:BT80=hQ8@T0eRTY203A
cJT000H0dLfY4@3o000B0>l@4140gR4Q4@3><C4A0?l00140ka0@4@3N8B4A0<ha<A40o`004@3_410A
0=hQ8A40cS4a4@3o000B0>l@4140gR4Q4@3><C480=7=Z@001P3AcJTA0?l00180ka0@4@3N8B4A0<ha
<A40o`004@3_410A0=hQ8A40cS4a4@3o000A0>l@4140gR4Q4@3><C4A0?l00180ka0@4@3N8B4A0<ha
<@P0dLfY00060=7=ZA40o`004P3_410A0=hQ8A40cS4a4@3o000A0>l@4140gR4Q4@3><C4A0?l00140
ka0@4@3N8B4A0<ha<A40o`004P3_410A0=hQ8A40cS4a203AcJT000H0dLfY4@3o000B0>l@4140gR4Q
4@3><C4A0?l00140ka0@4@3N8B4A0<ha<A40o`004@3_410A0=hQ8A40cS4a4@3o000B0>l@4140gR4Q
4@3><C480=7=Z@001P3AcJTA0?l00180ka0@4@3N8B4A0<ha<A40o`004@3_410A0=hQ8A40cS4a4@3o
000A0>l@4140gR4Q4@3><C4A0?l00180ka0@4@3N8B4A0<ha<@P0dLfY00060=7=ZA40o`004P3_410A
0=hQ8A40cS4a4@3o000A0>l@4140gR4Q4@3><C4A0?l00140ka0@4@3N8B4A0<ha<A40o`004P3_410A
0=hQ8A40cS4a203AcJT000H0dLfY4@3o000B0>l@4140gR4Q4@3><C4A0?l00140ka0@4@3N8B4A0<ha
<A40o`004@3_410A0=hQ8A40cS4a4@3o000B0>l@4140gR4Q4@3><C480=7=Z@001P3AcJTA0?l00180
ka0@4@3N8B4A0<ha<A40o`004@3_410A0=hQ8A40cS4a4@3o000A0>l@4140gR4Q4@3><C4A0?l00180
ka0@4@3N8B4A0<ha<@P0dLfY00060=7=Z@T0o`00203g20P90>l@40T0iaPH203N8B490=HY:@P0cS4a
2@36>CT80?l000T0m`P8203_41090>LH60P0gR4Q2@3F:BT80<ha<@T0aSTi2@3o00080?L820T0ka0@
203W61P90=hQ8@P0eRTY2@3><C480<Hi>@T0o`00203g20P90>l@40T0iaPH203N8B490=HY:@P0cS4a
2@36>CT80=7=Z@001P3AcJT90?l000P0m`P82@3_41090>LH60P0gR4Q2@3F:BT80<ha<@T0aSTi203o
00090?L820P0ka0@2@3W61P80=hQ8@T0eRTY203><C490<Hi>@T0o`00203g20P90>l@40P0iaPH2@3N
8B480=HY:@T0cS4a2036>CT90?l000P0m`P82@3_41090>LH60P0gR4Q2@3F:BT80<ha<@T0aSTi203A
cJT000H0dLfY2@3o00080?L820T0ka0@2@3W61P80=hQ8@T0eRTY203><C490<Hi>@P0o`002@3g20P8
0>l@40T0iaPH203N8B490=HY:@P0cS4a2@36>CT90?l000P0m`P82@3_41080>LH60T0gR4Q203F:BT9
0<ha<@P0aSTi2@3o00080?L820T0ka0@2@3W61P80=hQ8@T0eRTY203><C490<Hi>@P0dLfY00060=7=
Z@T0o`00203g20P90>l@40T0iaPH203N8B490=HY:@P0cS4a2@36>CT80?l000T0m`P8203_41090>LH
60P0gR4Q2@3F:BT80<ha<@T0aSTi2@3o00080?L820T0ka0@203W61P90=hQ8@P0eRTY2@3><C480<Hi
>@T0o`00203g20P90>l@40T0iaPH203N8B490=HY:@P0cS4a2@36>CT80=7=Z@001P3AcJT90?l000P0
m`P82@3_41090>LH60P0gR4Q2@3F:BT80<ha<@T0aSTi203o00090?L820P0ka0@2@3W61P80=hQ8@T0
eRTY203><C490<Hi>@T0o`00203g20P90>l@40P0iaPH2@3N8B480=HY:@T0cS4a2036>CT90?l000P0
m`P82@3_41090>LH60P0gR4Q2@3F:BT80<ha<@T0aSTi203AcJT000H0dLfY2@3o00080?L820T0ka0@
2@3W61P80=hQ8@T0eRTY203><C490<Hi>@P0o`002@3g20P80>l@40T0iaPH203N8B490=HY:@P0cS4a
2@36>CT90?l000P0m`P82@3_41080>LH60T0gR4Q203F:BT90<ha<@P0aSTi2@3o00080?L820T0ka0@
2@3W61P80=hQ8@T0eRTY203><C490<Hi>@P0dLfY00060=7=Z@T0o`00203g20P90>l@40T0iaPH203N
8B490=HY:@P0cS4a2@36>CT80?l000T0m`P8203_41090>LH60P0gR4Q2@3F:BT80<ha<@T0aSTi2@3o
00080?L820T0ka0@203W61P90=hQ8@P0eRTY2@3><C480<Hi>@T0o`00203g20P90>l@40T0iaPH203N
8B490=HY:@P0cS4a2@36>CT80=7=Z@001P3AcJT90?l000P0m`P82@3_41090>LH60P0gR4Q2@3F:BT8
0<ha<@T0aSTi203o00090?L820P0ka0@2@3W61P80=hQ8@T0eRTY203><C490<Hi>@T0o`00203g20P9
0>l@40P0iaPH2@3N8B480=HY:@T0cS4a2036>CT90?l000P0m`P82@3_41090>LH60P0gR4Q2@3F:BT8
0<ha<@T0aSTi203AcJT000H0dLfY2@3o00080?L820T0ka0@2@3W61P80=hQ8@T0eRTY203><C490<Hi
>@P0o`002@3g20P80>l@40T0iaPH203N8B490=HY:@P0cS4a2@36>CT90?l000P0m`P82@3_41080>LH
60T0gR4Q203F:BT90<ha<@P0aSTi2@3o00080?L820T0ka0@2@3W61P80=hQ8@T0eRTY203><C490<Hi
>@P0dLfY00060=7=ZDD0o`00A02m@T940?l004D0_D92203AcJT000H0dLfYA@3o00140;e2@T@0o`00
A@2m@T880=7=Z@001P3AcJU50?l004@0_D92A03o00150;e2@PP0dLfY00060=7=ZDD0o`00A02m@T94
0?l004D0_D92203AcJT000H0dLfYA@3o00140;e2@T@0o`00A@2m@T880=7=Z@001P3AcJU50?l004@0
_D92A03o00150;e2@PP0dLfY00060=7=ZDD0o`00A02m@T940?l004D0_D92203AcJT000H0dLfYA@3o
00140;e2@T@0o`00A@2m@T880=7=Z@001P3AcJT90?l000P0m`P82@3o00090?L820P0o`002@3g20P8
0?l000T0m`P8202m@T890;E:BPP0_D922@2eBTX80;e2@PT0]DY:202m@T890;E:BPT0o`00203g20P9
0?l000P0m`P82@3o00080?L820T0o`00203g20P90;e2@PP0]DY:2@2m@T890;E:BPP0_D922@2eBTX8
0;e2@PT0]DY:203AcJT000H0dLfY2@3o00080?L820T0o`002@3g20P80?l000T0m`P8203o00090?L8
20P0_D922@2eBTX80;e2@PT0]DY:202m@T890;E:BPP0_D922@2eBTX90?l000P0m`P82@3o00080?L8
20T0o`00203g20P90?l000P0m`P82@2m@T880;E:BPT0_D922@2eBTX80;e2@PT0]DY:202m@T890;E:
BPP0dLfY00060=7=Z@T0o`00203g20P90?l000T0m`P8203o00090?L820P0o`002@3g20P80;e2@PT0
]DY:202m@T890;E:BPP0_D922@2eBTX80;e2@PT0]DY:2@3o00080?L820T0o`00203g20P90?l000P0
m`P82@3o00080?L820T0_D92202eBTX90;e2@PT0]DY:202m@T890;E:BPP0_D922@2eBTX80=7=Z@00
1P3AcJT90?l000P0m`P82@3o00090?L820P0o`002@3g20P80?l000T0m`P8202m@T890;E:BPP0_D92
2@2eBTX80;e2@PT0]DY:202m@T890;E:BPT0o`00203g20P90?l000P0m`P82@3o00080?L820T0o`00
203g20P90;e2@PP0]DY:2@2m@T890;E:BPP0_D922@2eBTX80;e2@PT0]DY:203AcJT000H0dLfY2@3o
00080?L820T0o`002@3g20P80?l000T0m`P8203o00090?L820P0_D922@2eBTX80;e2@PT0]DY:202m
@T890;E:BPP0_D922@2eBTX90?l000P0m`P82@3o00080?L820T0o`00203g20P90?l000P0m`P82@2m
@T880;E:BPT0_D922@2eBTX80;e2@PT0]DY:202m@T890;E:BPP0dLfY00060=7=Z@T0o`00203g20P9
0?l000T0m`P8203o00090?L820P0o`002@3g20P80;e2@PT0]DY:202m@T890;E:BPP0_D922@2eBTX8
0;e2@PT0]DY:2@3o00080?L820T0o`00203g20P90?l000P0m`P82@3o00080?L820T0_D92202eBTX9
0;e2@PT0]DY:202m@T890;E:BPP0_D922@2eBTX80=7=Z@001P3AcJT90?l000P0m`P82@3o00090?L8
20P0o`002@3g20P80?l000T0m`P8202m@T890;E:BPP0_D922@2eBTX80;e2@PT0]DY:202m@T890;E:
BPT0o`00203g20P90?l000P0m`P82@3o00080?L820T0o`00203g20P90;e2@PP0]DY:2@2m@T890;E:
BPP0_D922@2eBTX80;e2@PT0]DY:203AcJT000H0dLfY2@3o00080?L820T0o`002@3g20P80?l000T0
m`P8203o00090?L820P0_D922@2eBTX80;e2@PT0]DY:202m@T890;E:BPP0_D922@2eBTX90?l000P0
m`P82@3o00080?L820T0o`00203g20P90?l000P0m`P82@2m@T880;E:BPT0_D922@2eBTX80;e2@PT0
]DY:202m@T890;E:BPP0dLfY00060=7=Z@T0o`00203g20P90?l000T0m`P8203o00090?L820P0o`00
2@3g20P80;e2@PT0]DY:202m@T890;E:BPP0_D922@2eBTX80;e2@PT0]DY:2@3o00080?L820T0o`00
203g20P90?l000P0m`P82@3o00080?L820T0_D92202eBTX90;e2@PT0]DY:202m@T890;E:BPP0_D92
2@2eBTX80=7=Z@001P3AcJTA0?l00180ka0@4@3o000A0>l@4140_D924@2]DU8A0;e2@Q40[E9B4@3o
000A0>l@4140o`004@3_410A0;e2@Q80[E9B4@2m@T8A0:eBDPP0dLfY00060=7=ZA40o`004P3_410A
0?l00140ka0@4@2m@T8A0:eBDQ40_D924@2]DU8A0?l00140ka0@4@3o000A0>l@4140_D924P2]DU8A
0;e2@Q40[E9B203AcJT000H0dLfY4@3o000B0>l@4140o`004@3_410A0;e2@Q40[E9B4@2m@T8A0:eB
DQ40o`004@3_410A0?l00140ka0@4@2m@T8B0:eBDQ40_D924@2]DU880=7=Z@001P3AcJTA0?l00180
ka0@4@3o000A0>l@4140_D924@2]DU8A0;e2@Q40[E9B4@3o000A0>l@4140o`004@3_410A0;e2@Q80
[E9B4@2m@T8A0:eBDPP0dLfY00060=7=ZA40o`004P3_410A0?l00140ka0@4@2m@T8A0:eBDQ40_D92
4@2]DU8A0?l00140ka0@4@3o000A0>l@4140_D924P2]DU8A0;e2@Q40[E9B203AcJT000H0dLfY4@3o
000B0>l@4140o`004@3_410A0;e2@Q40[E9B4@2m@T8A0:eBDQ40o`004@3_410A0?l00140ka0@4@2m
@T8B0:eBDQ40_D924@2]DU880=7=Z@001P3AcJTA0?l00180ka0@4@3o000A0>l@4140_D924@2]DU8A
0;e2@Q40[E9B4@3o000A0>l@4140o`004@3_410A0;e2@Q80[E9B4@2m@T8A0:eBDPP0dLfY00060=7=
ZA40o`004P3_410A0?l00140ka0@4@2m@T8A0:eBDQ40_D924@2]DU8A0?l00140ka0@4@3o000A0>l@
4140_D924P2]DU8A0;e2@Q40[E9B203AcJT000H0dLfY2@3o00080?L820T0ka0@2@3W61P80?l000T0
m`P8203_41090>LH60P0_D922@2eBTX80:eBDPT0YEYJ202m@T890;E:BPP0[E9B2@2UFUX90?l000P0
m`P82@3_41080>LH60T0o`00203g20P90>l@40P0iaPH2@2m@T880;E:BPT0[E9B2@2UFUX80;e2@PT0
]DY:202]DU890:EJFPP0dLfY00060=7=Z@T0o`00203g20P90>l@40T0iaPH203o00090?L820P0ka0@
2@3W61P80;e2@PT0]DY:202]DU890:EJFPP0_D922@2eBTX80:eBDPT0YEYJ2@3o00080?L820T0ka0@
203W61P90?l000P0m`P82@3_41080>LH60T0_D92202eBTX90:eBDPT0YEYJ202m@T890;E:BPP0[E9B
2@2UFUX80=7=Z@001P3AcJT90?l000P0m`P82@3_41090>LH60P0o`002@3g20P80>l@40T0iaPH202m
@T890;E:BPP0[E9B2@2UFUX80;e2@PT0]DY:202]DU890:EJFPT0o`00203g20P90>l@40P0iaPH2@3o
00080?L820T0ka0@203W61P90;e2@PP0]DY:2@2]DU890:EJFPP0_D922@2eBTX80:eBDPT0YEYJ203A
cJT000H0dLfY2@3o00080?L820T0ka0@2@3W61P80?l000T0m`P8203_41090>LH60P0_D922@2eBTX8
0:eBDPT0YEYJ202m@T890;E:BPP0[E9B2@2UFUX90?l000P0m`P82@3_41080>LH60T0o`00203g20P9
0>l@40P0iaPH2@2m@T880;E:BPT0[E9B2@2UFUX80;e2@PT0]DY:202]DU890:EJFPP0dLfY00060=7=
Z@T0o`00203g20P90>l@40T0iaPH203o00090?L820P0ka0@2@3W61P80;e2@PT0]DY:202]DU890:EJ
FPP0_D922@2eBTX80:eBDPT0YEYJ2@3o00080?L820T0ka0@203W61P90?l000P0m`P82@3_41080>LH
60T0_D92202eBTX90:eBDPT0YEYJ202m@T890;E:BPP0[E9B2@2UFUX80=7=Z@001P3AcJT90?l000P0
m`P82@3_41090>LH60P0o`002@3g20P80>l@40T0iaPH202m@T890;E:BPP0[E9B2@2UFUX80;e2@PT0
]DY:202]DU890:EJFPT0o`00203g20P90>l@40P0iaPH2@3o00080?L820T0ka0@203W61P90;e2@PP0
]DY:2@2]DU890:EJFPP0_D922@2eBTX80:eBDPT0YEYJ203AcJT000H0dLfY2@3o00080?L820T0ka0@
2@3W61P80?l000T0m`P8203_41090>LH60P0_D922@2eBTX80:eBDPT0YEYJ202m@T890;E:BPP0[E9B
2@2UFUX90?l000P0m`P82@3_41080>LH60T0o`00203g20P90>l@40P0iaPH2@2m@T880;E:BPT0[E9B
2@2UFUX80;e2@PT0]DY:202]DU890:EJFPP0dLfY00060=7=Z@T0o`00203g20P90>l@40T0iaPH203o
00090?L820P0ka0@2@3W61P80;e2@PT0]DY:202]DU890:EJFPP0_D922@2eBTX80:eBDPT0YEYJ2@3o
00080?L820T0ka0@203W61P90?l000P0m`P82@3_41080>LH60T0_D92202eBTX90:eBDPT0YEYJ202m
@T890;E:BPP0[E9B2@2UFUX80=7=Z@001P3AcJT90?l000P0m`P82@3_41090>LH60P0o`002@3g20P8
0>l@40T0iaPH202m@T890;E:BPP0[E9B2@2UFUX80;e2@PT0]DY:202]DU890:EJFPT0o`00203g20P9
0>l@40P0iaPH2@3o00080?L820T0ka0@203W61P90;e2@PP0]DY:2@2]DU890:EJFPP0_D922@2eBTX8
0:eBDPT0YEYJ203AcJT000H0dLfY8`3o000R0=hQ8B80_D928P2LHf<R0?l00280gR4Q8`2m@T8R09aS
H`P0dLfY00060=7=ZB<0o`008P3N8B4R0;e2@R80W6=S8P3o000R0=hQ8B<0_D928P2LHf<80=7=Z@00
1P3AcJTS0?l00280gR4Q8P2m@T8R09aSHb80o`008P3N8B4S0;e2@R80W6=S203AcJT000H0dLfY8`3o
000R0=hQ8B80_D928P2LHf<R0?l00280gR4Q8`2m@T8R09aSH`P0dLfY00060=7=ZB<0o`008P3N8B4R
0;e2@R80W6=S8P3o000R0=hQ8B<0_D928P2LHf<80=7=Z@001P3AcJTS0?l00280gR4Q8P2m@T8R09aS
Hb80o`008P3N8B4S0;e2@R80W6=S203AcJT000H0dLfY8`3o000R0=hQ8B80_D928P2LHf<R0?l00280
gR4Q8`2m@T8R09aSH`P0dLfY00060=7=ZB<0o`008P3N8B4R0;e2@R80W6=S8P3o000R0=hQ8B<0_D92
8P2LHf<80=7=Z@001P3AcJT90?l000P0m`P82@3o00090?L820P0gR4Q2@3F:BT80=hQ8@T0eRTY202m
@T890;E:BPP0_D922@2eBTX809aSH`T0U6][202LHf<909A[J`T0o`00203g20P90?l000P0m`P82@3N
8B480=HY:@T0gR4Q203F:BT90;e2@PP0]DY:2@2m@T890;E:BPP0W6=S2@2DJf/809aSH`T0U6][203A
cJT000H0dLfY2@3o00080?L820T0o`002@3g20P80=hQ8@T0eRTY203N8B490=HY:@P0_D922@2eBTX8
0;e2@PT0]DY:202LHf<909A[J`P0W6=S2@2DJf/90?l000P0m`P82@3o00080?L820T0gR4Q203F:BT9
0=hQ8@P0eRTY2@2m@T880;E:BPT0_D922@2eBTX809aSH`T0U6][202LHf<909A[J`P0dLfY00060=7=
Z@T0o`00203g20P90?l000T0m`P8203N8B490=HY:@P0gR4Q2@3F:BT80;e2@PT0]DY:202m@T890;E:
BPP0W6=S2@2DJf/809aSH`T0U6][2@3o00080?L820T0o`00203g20P90=hQ8@P0eRTY2@3N8B480=HY
:@T0_D92202eBTX90;e2@PT0]DY:202LHf<909A[J`P0W6=S2@2DJf/80=7=Z@001P3AcJT90?l000P0
m`P82@3o00090?L820P0gR4Q2@3F:BT80=hQ8@T0eRTY202m@T890;E:BPP0_D922@2eBTX809aSH`T0
U6][202LHf<909A[J`T0o`00203g20P90?l000P0m`P82@3N8B480=HY:@T0gR4Q203F:BT90;e2@PP0
]DY:2@2m@T890;E:BPP0W6=S2@2DJf/809aSH`T0U6][203AcJT000H0dLfY2@3o00080?L820T0o`00
2@3g20P80=hQ8@T0eRTY203N8B490=HY:@P0_D922@2eBTX80;e2@PT0]DY:202LHf<909A[J`P0W6=S
2@2DJf/90?l000P0m`P82@3o00080?L820T0gR4Q203F:BT90=hQ8@P0eRTY2@2m@T880;E:BPT0_D92
2@2eBTX809aSH`T0U6][202LHf<909A[J`P0dLfY00060=7=Z@T0o`00203g20P90?l000T0m`P8203N
8B490=HY:@P0gR4Q2@3F:BT80;e2@PT0]DY:202m@T890;E:BPP0W6=S2@2DJf/809aSH`T0U6][2@3o
00080?L820T0o`00203g20P90=hQ8@P0eRTY2@3N8B480=HY:@T0_D92202eBTX90;e2@PT0]DY:202L
Hf<909A[J`P0W6=S2@2DJf/80=7=Z@001P3AcJT90?l000P0m`P82@3o00090?L820P0gR4Q2@3F:BT8
0=hQ8@T0eRTY202m@T890;E:BPP0_D922@2eBTX809aSH`T0U6][202LHf<909A[J`T0o`00203g20P9
0?l000P0m`P82@3N8B480=HY:@T0gR4Q203F:BT90;e2@PP0]DY:2@2m@T890;E:BPP0W6=S2@2DJf/8
09aSH`T0U6][203AcJT000H0dLfY2@3o00080?L820T0o`002@3g20P80=hQ8@T0eRTY203N8B490=HY
:@P0_D922@2eBTX80;e2@PT0]DY:202LHf<909A[J`P0W6=S2@2DJf/90?l000P0m`P82@3o00080?L8
20T0gR4Q203F:BT90=hQ8@P0eRTY2@2m@T880;E:BPT0_D922@2eBTX809aSH`T0U6][202LHf<909A[
J`P0dLfY00060=7=Z@T0o`00203g20P90?l000T0m`P8203N8B490=HY:@P0gR4Q2@3F:BT80;e2@PT0
]DY:202m@T890;E:BPP0W6=S2@2DJf/809aSH`T0U6][2@3o00080?L820T0o`00203g20P90=hQ8@P0
eRTY2@3N8B480=HY:@T0_D92202eBTX90;e2@PT0]DY:202LHf<909A[J`P0W6=S2@2DJf/80=7=Z@00
1P3AcJTA0?l00180ka0@4@3N8B4A0<ha<A40_D924@2]DU8A09aSHa40S7=c4@3o000A0>l@4140gR4Q
4@3><C4A0;e2@Q80[E9B4@2LHf<A08acL`P0dLfY00060=7=ZA40o`004P3_410A0=hQ8A40cS4a4@2m
@T8A0:eBDQ40W6=S4@2<Lg<A0?l00140ka0@4@3N8B4A0<ha<A40_D924P2]DU8A09aSHa40S7=c203A
cJT000H0dLfY4@3o000B0>l@4140gR4Q4@3><C4A0;e2@Q40[E9B4@2LHf<A08acLa40o`004@3_410A
0=hQ8A40cS4a4@2m@T8B0:eBDQ40W6=S4@2<Lg<80=7=Z@001P3AcJTA0?l00180ka0@4@3N8B4A0<ha
<A40_D924@2]DU8A09aSHa40S7=c4@3o000A0>l@4140gR4Q4@3><C4A0;e2@Q80[E9B4@2LHf<A08ac
L`P0dLfY00060=7=ZA40o`004P3_410A0=hQ8A40cS4a4@2m@T8A0:eBDQ40W6=S4@2<Lg<A0?l00140
ka0@4@3N8B4A0<ha<A40_D924P2]DU8A09aSHa40S7=c203AcJT000H0dLfY4@3o000B0>l@4140gR4Q
4@3><C4A0;e2@Q40[E9B4@2LHf<A08acLa40o`004@3_410A0=hQ8A40cS4a4@2m@T8B0:eBDQ40W6=S
4@2<Lg<80=7=Z@001P3AcJTA0?l00180ka0@4@3N8B4A0<ha<A40_D924@2]DU8A09aSHa40S7=c4@3o
000A0>l@4140gR4Q4@3><C4A0;e2@Q80[E9B4@2LHf<A08acL`P0dLfY00060=7=ZA40o`004P3_410A
0=hQ8A40cS4a4@2m@T8A0:eBDQ40W6=S4@2<Lg<A0?l00140ka0@4@3N8B4A0<ha<A40_D924P2]DU8A
09aSHa40S7=c203AcJT000H0dLfY2@3o00080?L820T0ka0@2@3W61P80=hQ8@T0eRTY203><C490<Hi
>@P0_D922@2eBTX80:eBDPT0YEYJ202LHf<909A[J`P0S7=c2@24Ng/90?l000P0m`P82@3_41080>LH
60T0gR4Q203F:BT90<ha<@P0aSTi2@2m@T880;E:BPT0[E9B2@2UFUX809aSH`T0U6][202<Lg<908Ak
N`P0dLfY00060=7=Z@T0o`00203g20P90>l@40T0iaPH203N8B490=HY:@P0cS4a2@36>CT80;e2@PT0
]DY:202]DU890:EJFPP0W6=S2@2DJf/808acL`T0Q7]k2@3o00080?L820T0ka0@203W61P90=hQ8@P0
eRTY2@3><C480<Hi>@T0_D92202eBTX90:eBDPT0YEYJ202LHf<909A[J`P0S7=c2@24Ng/80=7=Z@00
1P3AcJT90?l000P0m`P82@3_41090>LH60P0gR4Q2@3F:BT80<ha<@T0aSTi202m@T890;E:BPP0[E9B
2@2UFUX809aSH`T0U6][202<Lg<908AkN`T0o`00203g20P90>l@40P0iaPH2@3N8B480=HY:@T0cS4a
2036>CT90;e2@PP0]DY:2@2]DU890:EJFPP0W6=S2@2DJf/808acL`T0Q7]k203AcJT000H0dLfY2@3o
00080?L820T0ka0@2@3W61P80=hQ8@T0eRTY203><C490<Hi>@P0_D922@2eBTX80:eBDPT0YEYJ202L
Hf<909A[J`P0S7=c2@24Ng/90?l000P0m`P82@3_41080>LH60T0gR4Q203F:BT90<ha<@P0aSTi2@2m
@T880;E:BPT0[E9B2@2UFUX809aSH`T0U6][202<Lg<908AkN`P0dLfY00060=7=Z@T0o`00203g20P9
0>l@40T0iaPH203N8B490=HY:@P0cS4a2@36>CT80;e2@PT0]DY:202]DU890:EJFPP0W6=S2@2DJf/8
08acL`T0Q7]k2@3o00080?L820T0ka0@203W61P90=hQ8@P0eRTY2@3><C480<Hi>@T0_D92202eBTX9
0:eBDPT0YEYJ202LHf<909A[J`P0S7=c2@24Ng/80=7=Z@001P3AcJT90?l000P0m`P82@3_41090>LH
60P0gR4Q2@3F:BT80<ha<@T0aSTi202m@T890;E:BPP0[E9B2@2UFUX809aSH`T0U6][202<Lg<908Ak
N`T0o`00203g20P90>l@40P0iaPH2@3N8B480=HY:@T0cS4a2036>CT90;e2@PP0]DY:2@2]DU890:EJ
FPP0W6=S2@2DJf/808acL`T0Q7]k203AcJT000H0dLfY2@3o00080?L820T0ka0@2@3W61P80=hQ8@T0
eRTY203><C490<Hi>@P0_D922@2eBTX80:eBDPT0YEYJ202LHf<909A[J`P0S7=c2@24Ng/90?l000P0
m`P82@3_41080>LH60T0gR4Q203F:BT90<ha<@P0aSTi2@2m@T880;E:BPT0[E9B2@2UFUX809aSH`T0
U6][202<Lg<908AkN`P0dLfY00060=7=Z@T0o`00203g20P90>l@40T0iaPH203N8B490=HY:@P0cS4a
2@36>CT80;e2@PT0]DY:202]DU890:EJFPP0W6=S2@2DJf/808acL`T0Q7]k2@3o00080?L820T0ka0@
203W61P90=hQ8@P0eRTY2@3><C480<Hi>@T0_D92202eBTX90:eBDPT0YEYJ202LHf<909A[J`P0S7=c
2@24Ng/80=7=Z@001P3AcJT90?l000P0m`P82@3_41090>LH60P0gR4Q2@3F:BT80<ha<@T0aSTi202m
@T890;E:BPP0[E9B2@2UFUX809aSH`T0U6][202<Lg<908AkN`T0o`00203g20P90>l@40P0iaPH2@3N
8B480=HY:@T0cS4a2036>CT90;e2@PP0]DY:2@2]DU890:EJFPP0W6=S2@2DJf/808acL`T0Q7]k203A
cJT000H0dLfYR@3o002907^4Q0P0dLfY00060=7=ZHT0o`00R@1kQ8@80=7=Z@001P3AcJV90?l008T0
NhB4203AcJT000H0dLfYR@3o002907^4Q0P0dLfY00060=7=ZHT0o`00R@1kQ8@80=7=Z@001P3AcJV9
0?l008T0NhB4203AcJT000H0dLfYR@3o002907^4Q0P0dLfY00060=7=ZHT0o`00R@1kQ8@80=7=Z@00
1P3AcJV90?l008T0NhB4203AcJT000H0dLfY2@3o00080?L820T0o`002@3g20P80?l000T0m`P8203o
00090?L820P0o`002@3g20P80?l000T0m`P8203o00090?L820P0o`002@3g20P907^4Q0P0Lhb<2@1k
Q8@807><S0T0NhB4201cS8`907^4Q0P0Lhb<2@1kQ8@807><S0T0NhB42@1cS8`807^4Q0T0Lhb<201k
Q8@907><S0P0dLfY00060=7=Z@T0o`00203g20P90?l000T0m`P8203o00090?L820P0o`002@3g20P8
0?l000T0m`P8203o00090?L820P0o`002@3g20P80?l000T0m`P82@1kQ8@807><S0T0NhB4201cS8`9
07^4Q0P0Lhb<2@1kQ8@807><S0T0NhB4201cS8`907^4Q0T0Lhb<201kQ8@907><S0P0NhB42@1cS8`8
0=7=Z@001P3AcJT90?l000P0m`P82@3o00090?L820P0o`002@3g20P80?l000T0m`P8203o00090?L8
20P0o`002@3g20P80?l000T0m`P8203o00090?L820T0NhB4201cS8`907^4Q0P0Lhb<2@1kQ8@807><
S0T0NhB4201cS8`907^4Q0P0Lhb<2@1kQ8@907><S0P0NhB42@1cS8`807^4Q0T0Lhb<203AcJT000H0
dLfY2@3o00080?L820T0o`002@3g20P80?l000T0m`P8203o00090?L820P0o`002@3g20P80?l000T0
m`P8203o00090?L820P0o`002@3g20P907^4Q0P0Lhb<2@1kQ8@807><S0T0NhB4201cS8`907^4Q0P0
Lhb<2@1kQ8@807><S0T0NhB42@1cS8`807^4Q0T0Lhb<201kQ8@907><S0P0dLfY00060=7=Z@T0o`00
203g20P90?l000T0m`P8203o00090?L820P0o`002@3g20P80?l000T0m`P8203o00090?L820P0o`00
2@3g20P80?l000T0m`P82@1kQ8@807><S0T0NhB4201cS8`907^4Q0P0Lhb<2@1kQ8@807><S0T0NhB4
201cS8`907^4Q0T0Lhb<201kQ8@907><S0P0NhB42@1cS8`80=7=Z@001P3AcJT90?l000P0m`P82@3o
00090?L820P0o`002@3g20P80?l000T0m`P8203o00090?L820P0o`002@3g20P80?l000T0m`P8203o
00090?L820T0NhB4201cS8`907^4Q0P0Lhb<2@1kQ8@807><S0T0NhB4201cS8`907^4Q0P0Lhb<2@1k
Q8@907><S0P0NhB42@1cS8`807^4Q0T0Lhb<203AcJT000H0dLfY2@3o00080?L820T0o`002@3g20P8
0?l000T0m`P8203o00090?L820P0o`002@3g20P80?l000T0m`P8203o00090?L820P0o`002@3g20P9
07^4Q0P0Lhb<2@1kQ8@807><S0T0NhB4201cS8`907^4Q0P0Lhb<2@1kQ8@807><S0T0NhB42@1cS8`8
07^4Q0T0Lhb<201kQ8@907><S0P0dLfY00060=7=Z@T0o`00203g20P90?l000T0m`P8203o00090?L8
20P0o`002@3g20P80?l000T0m`P8203o00090?L820P0o`002@3g20P80?l000T0m`P82@1kQ8@807><
S0T0NhB4201cS8`907^4Q0P0Lhb<2@1kQ8@807><S0T0NhB4201cS8`907^4Q0T0Lhb<201kQ8@907><
S0P0NhB42@1cS8`80=7=Z@001P3AcJTA0?l00180ka0@4@3o000A0>l@4140o`004@3_410A0?l00140
ka0@4@1kQ8@A06^DU140NhB44@1[U9@A07^4Q180JiBD4@1kQ8@A06^DU0P0dLfY00060=7=ZA40o`00
4P3_410A0?l00140ka0@4@3o000A0>l@4140o`004@3_410A07^4Q140JiBD4@1kQ8@A06^DU140NhB4
4P1[U9@A07^4Q140JiBD203AcJT000H0dLfY4@3o000B0>l@4140o`004@3_410A0?l00140ka0@4@3o
000A0>l@4140NhB44@1[U9@A07^4Q140JiBD4@1kQ8@B06^DU140NhB44@1[U9@80=7=Z@001P3AcJTA
0?l00180ka0@4@3o000A0>l@4140o`004@3_410A0?l00140ka0@4@1kQ8@A06^DU140NhB44@1[U9@A
07^4Q180JiBD4@1kQ8@A06^DU0P0dLfY00060=7=ZA40o`004P3_410A0?l00140ka0@4@3o000A0>l@
4140o`004@3_410A07^4Q140JiBD4@1kQ8@A06^DU140NhB44P1[U9@A07^4Q140JiBD203AcJT000H0
dLfY4@3o000B0>l@4140o`004@3_410A0?l00140ka0@4@3o000A0>l@4140NhB44@1[U9@A07^4Q140
JiBD4@1kQ8@B06^DU140NhB44@1[U9@80=7=Z@001P3AcJTA0?l00180ka0@4@3o000A0>l@4140o`00
4@3_410A0?l00140ka0@4@1kQ8@A06^DU140NhB44@1[U9@A07^4Q180JiBD4@1kQ8@A06^DU0P0dLfY
00060=7=ZA40o`004P3_410A0?l00140ka0@4@3o000A0>l@4140o`004@3_410A07^4Q140JiBD4@1k
Q8@A06^DU140NhB44P1[U9@A07^4Q140JiBD203AcJT000H0dLfY4@3o000B0>l@4140o`004@3_410A
0?l00140ka0@4@3o000A0>l@4140NhB44@1[U9@A07^4Q140JiBD4@1kQ8@B06^DU140NhB44@1[U9@8
0=7=Z@001P3AcJT90?l000P0m`P82@3_41090>LH60P0o`002@3g20P80>l@40T0iaPH203o00090?L8
20P0ka0@2@3W61P80?l000T0m`P8203_41090>LH60T0NhB4201cS8`906^DU0P0HibL2@1kQ8@807><
S0T0JiBD201SW9`907^4Q0P0Lhb<2@1[U9@906>LW0P0NhB42@1cS8`806^DU0T0HibL203AcJT000H0
dLfY2@3o00080?L820T0ka0@2@3W61P80?l000T0m`P8203_41090>LH60P0o`002@3g20P80>l@40T0
iaPH203o00090?L820P0ka0@2@3W61P907^4Q0P0Lhb<2@1[U9@806>LW0T0NhB4201cS8`906^DU0P0
HibL2@1kQ8@807><S0T0JiBD2@1SW9`807^4Q0T0Lhb<201[U9@906>LW0P0dLfY00060=7=Z@T0o`00
203g20P90>l@40T0iaPH203o00090?L820P0ka0@2@3W61P80?l000T0m`P8203_41090>LH60P0o`00
2@3g20P80>l@40T0iaPH2@1kQ8@807><S0T0JiBD201SW9`907^4Q0P0Lhb<2@1[U9@806>LW0T0NhB4
201cS8`906^DU0T0HibL201kQ8@907><S0P0JiBD2@1SW9`80=7=Z@001P3AcJT90?l000P0m`P82@3_
41090>LH60P0o`002@3g20P80>l@40T0iaPH203o00090?L820P0ka0@2@3W61P80?l000T0m`P8203_
41090>LH60T0NhB4201cS8`906^DU0P0HibL2@1kQ8@807><S0T0JiBD201SW9`907^4Q0P0Lhb<2@1[
U9@906>LW0P0NhB42@1cS8`806^DU0T0HibL203AcJT000H0dLfY2@3o00080?L820T0ka0@2@3W61P8
0?l000T0m`P8203_41090>LH60P0o`002@3g20P80>l@40T0iaPH203o00090?L820P0ka0@2@3W61P9
07^4Q0P0Lhb<2@1[U9@806>LW0T0NhB4201cS8`906^DU0P0HibL2@1kQ8@807><S0T0JiBD2@1SW9`8
07^4Q0T0Lhb<201[U9@906>LW0P0dLfY00060=7=Z@T0o`00203g20P90>l@40T0iaPH203o00090?L8
20P0ka0@2@3W61P80?l000T0m`P8203_41090>LH60P0o`002@3g20P80>l@40T0iaPH2@1kQ8@807><
S0T0JiBD201SW9`907^4Q0P0Lhb<2@1[U9@806>LW0T0NhB4201cS8`906^DU0T0HibL201kQ8@907><
S0P0JiBD2@1SW9`80=7=Z@001P3AcJT90?l000P0m`P82@3_41090>LH60P0o`002@3g20P80>l@40T0
iaPH203o00090?L820P0ka0@2@3W61P80?l000T0m`P8203_41090>LH60T0NhB4201cS8`906^DU0P0
HibL2@1kQ8@807><S0T0JiBD201SW9`907^4Q0P0Lhb<2@1[U9@906>LW0P0NhB42@1cS8`806^DU0T0
HibL203AcJT000H0dLfY2@3o00080?L820T0ka0@2@3W61P80?l000T0m`P8203_41090>LH60P0o`00
2@3g20P80>l@40T0iaPH203o00090?L820P0ka0@2@3W61P907^4Q0P0Lhb<2@1[U9@806>LW0T0NhB4
201cS8`906^DU0P0HibL2@1kQ8@807><S0T0JiBD2@1SW9`807^4Q0T0Lhb<201[U9@906>LW0P0dLfY
00060=7=ZB<0o`008P3N8B4R0?l00280gR4Q8P1kQ8@R05ZUYB<0NhB48P1JYJD80=7=Z@001P3AcJTS
0?l00280gR4Q8P3o000R0=hQ8B80NhB48P1JYJDS07^4Q280FZFU203AcJT000H0dLfY8`3o000R0=hQ
8B80o`008P3N8B4R07^4Q280FZFU8`1kQ8@R05ZUY@P0dLfY00060=7=ZB<0o`008P3N8B4R0?l00280
gR4Q8P1kQ8@R05ZUYB<0NhB48P1JYJD80=7=Z@001P3AcJTS0?l00280gR4Q8P3o000R0=hQ8B80NhB4
8P1JYJDS07^4Q280FZFU203AcJT000H0dLfY8`3o000R0=hQ8B80o`008P3N8B4R07^4Q280FZFU8`1k
Q8@R05ZUY@P0dLfY00060=7=ZB<0o`008P3N8B4R0?l00280gR4Q8P1kQ8@R05ZUYB<0NhB48P1JYJD8
0=7=Z@001P3AcJTS0?l00280gR4Q8P3o000R0=hQ8B80NhB48P1JYJDS07^4Q280FZFU203AcJT000H0
dLfY8`3o000R0=hQ8B80o`008P3N8B4R07^4Q280FZFU8`1kQ8@R05ZUY@P0dLfY00060=7=Z@T0o`00
203g20P90?l000T0m`P8203N8B490=HY:@P0gR4Q2@3F:BT80?l000T0m`P8203o00090?L820P0gR4Q
2@3F:BT80=hQ8@T0eRTY2@1kQ8@807><S0T0NhB4201cS8`905ZUY@P0DZf]2@1JYJD805:][@T0NhB4
201cS8`907^4Q0T0Lhb<201JYJD905:][@P0FZFU2@1B[Jd80=7=Z@001P3AcJT90?l000P0m`P82@3o
00090?L820P0gR4Q2@3F:BT80=hQ8@T0eRTY203o00090?L820P0o`002@3g20P80=hQ8@T0eRTY203N
8B490=HY:@T0NhB4201cS8`907^4Q0P0Lhb<2@1JYJD805:][@T0FZFU201B[Jd907^4Q0P0Lhb<2@1k
Q8@907><S0P0FZFU2@1B[Jd805ZUY@T0DZf]203AcJT000H0dLfY2@3o00080?L820T0o`002@3g20P8
0=hQ8@T0eRTY203N8B490=HY:@P0o`002@3g20P80?l000T0m`P8203N8B490=HY:@P0gR4Q2@3F:BT9
07^4Q0P0Lhb<2@1kQ8@807><S0T0FZFU201B[Jd905ZUY@P0DZf]2@1kQ8@807><S0T0NhB42@1cS8`8
05ZUY@T0DZf]201JYJD905:][@P0dLfY00060=7=Z@T0o`00203g20P90?l000T0m`P8203N8B490=HY
:@P0gR4Q2@3F:BT80?l000T0m`P8203o00090?L820P0gR4Q2@3F:BT80=hQ8@T0eRTY2@1kQ8@807><
S0T0NhB4201cS8`905ZUY@P0DZf]2@1JYJD805:][@T0NhB4201cS8`907^4Q0T0Lhb<201JYJD905:]
[@P0FZFU2@1B[Jd80=7=Z@001P3AcJT90?l000P0m`P82@3o00090?L820P0gR4Q2@3F:BT80=hQ8@T0
eRTY203o00090?L820P0o`002@3g20P80=hQ8@T0eRTY203N8B490=HY:@T0NhB4201cS8`907^4Q0P0
Lhb<2@1JYJD805:][@T0FZFU201B[Jd907^4Q0P0Lhb<2@1kQ8@907><S0P0FZFU2@1B[Jd805ZUY@T0
DZf]203AcJT000H0dLfY2@3o00080?L820T0o`002@3g20P80=hQ8@T0eRTY203N8B490=HY:@P0o`00
2@3g20P80?l000T0m`P8203N8B490=HY:@P0gR4Q2@3F:BT907^4Q0P0Lhb<2@1kQ8@807><S0T0FZFU
201B[Jd905ZUY@P0DZf]2@1kQ8@807><S0T0NhB42@1cS8`805ZUY@T0DZf]201JYJD905:][@P0dLfY
00060=7=Z@T0o`00203g20P90?l000T0m`P8203N8B490=HY:@P0gR4Q2@3F:BT80?l000T0m`P8203o
00090?L820P0gR4Q2@3F:BT80=hQ8@T0eRTY2@1kQ8@807><S0T0NhB4201cS8`905ZUY@P0DZf]2@1J
YJD805:][@T0NhB4201cS8`907^4Q0T0Lhb<201JYJD905:][@P0FZFU2@1B[Jd80=7=Z@001P3AcJT9
0?l000P0m`P82@3o00090?L820P0gR4Q2@3F:BT80=hQ8@T0eRTY203o00090?L820P0o`002@3g20P8
0=hQ8@T0eRTY203N8B490=HY:@T0NhB4201cS8`907^4Q0P0Lhb<2@1JYJD805:][@T0FZFU201B[Jd9
07^4Q0P0Lhb<2@1kQ8@907><S0P0FZFU2@1B[Jd805ZUY@T0DZf]203AcJT000H0dLfY4@3o000B0>l@
4140gR4Q4@3><C4A0?l00140ka0@4@3N8B4A0<ha<A40NhB44@1[U9@A05ZUYA40B[Fe4@1kQ8@B06^D
U140FZFU4@1:]KD80=7=Z@001P3AcJTA0?l00180ka0@4@3N8B4A0<ha<A40o`004@3_410A0=hQ8A40
cS4a4@1kQ8@A06^DU140FZFU4@1:]KDA07^4Q180JiBD4@1JYJDA04Ze]@P0dLfY00060=7=ZA40o`00
4P3_410A0=hQ8A40cS4a4@3o000A0>l@4140gR4Q4@3><C4A07^4Q140JiBD4@1JYJDA04Ze]A40NhB4
4P1[U9@A05ZUYA40B[Fe203AcJT000H0dLfY4@3o000B0>l@4140gR4Q4@3><C4A0?l00140ka0@4@3N
8B4A0<ha<A40NhB44@1[U9@A05ZUYA40B[Fe4@1kQ8@B06^DU140FZFU4@1:]KD80=7=Z@001P3AcJTA
0?l00180ka0@4@3N8B4A0<ha<A40o`004@3_410A0=hQ8A40cS4a4@1kQ8@A06^DU140FZFU4@1:]KDA
07^4Q180JiBD4@1JYJDA04Ze]@P0dLfY00060=7=ZA40o`004P3_410A0=hQ8A40cS4a4@3o000A0>l@
4140gR4Q4@3><C4A07^4Q140JiBD4@1JYJDA04Ze]A40NhB44P1[U9@A05ZUYA40B[Fe203AcJT000H0
dLfY4@3o000B0>l@4140gR4Q4@3><C4A0?l00140ka0@4@3N8B4A0<ha<A40NhB44@1[U9@A05ZUYA40
B[Fe4@1kQ8@B06^DU140FZFU4@1:]KD80=7=Z@001P3AcJTA0?l00180ka0@4@3N8B4A0<ha<A40o`00
4@3_410A0=hQ8A40cS4a4@1kQ8@A06^DU140FZFU4@1:]KDA07^4Q180JiBD4@1JYJDA04Ze]@P0dLfY
00060=7=ZA40o`004P3_410A0=hQ8A40cS4a4@3o000A0>l@4140gR4Q4@3><C4A07^4Q140JiBD4@1J
YJDA04Ze]A40NhB44P1[U9@A05ZUYA40B[Fe203AcJT000H0dLfY2@3o00080?L820T0ka0@2@3W61P8
0=hQ8@T0eRTY203><C490<Hi>@P0o`002@3g20P80>l@40T0iaPH203N8B490=HY:@P0cS4a2@36>CT9
07^4Q0P0Lhb<2@1[U9@806>LW0T0FZFU201B[Jd904Ze]@P0@[fm2@1kQ8@807><S0T0JiBD2@1SW9`8
05ZUY@T0DZf]201:]KD904:m_@P0dLfY00060=7=Z@T0o`00203g20P90>l@40T0iaPH203N8B490=HY
:@P0cS4a2@36>CT80?l000T0m`P8203_41090>LH60P0gR4Q2@3F:BT80<ha<@T0aSTi2@1kQ8@807><
S0T0JiBD201SW9`905ZUY@P0DZf]2@1:]KD804:m_@T0NhB4201cS8`906^DU0T0HibL201JYJD905:]
[@P0B[Fe2@12_Kd80=7=Z@001P3AcJT90?l000P0m`P82@3_41090>LH60P0gR4Q2@3F:BT80<ha<@T0
aSTi203o00090?L820P0ka0@2@3W61P80=hQ8@T0eRTY203><C490<Hi>@T0NhB4201cS8`906^DU0P0
HibL2@1JYJD805:][@T0B[Fe2012_Kd907^4Q0P0Lhb<2@1[U9@906>LW0P0FZFU2@1B[Jd804Ze]@T0
@[fm203AcJT000H0dLfY2@3o00080?L820T0ka0@2@3W61P80=hQ8@T0eRTY203><C490<Hi>@P0o`00
2@3g20P80>l@40T0iaPH203N8B490=HY:@P0cS4a2@36>CT907^4Q0P0Lhb<2@1[U9@806>LW0T0FZFU
201B[Jd904Ze]@P0@[fm2@1kQ8@807><S0T0JiBD2@1SW9`805ZUY@T0DZf]201:]KD904:m_@P0dLfY
00060=7=Z@T0o`00203g20P90>l@40T0iaPH203N8B490=HY:@P0cS4a2@36>CT80?l000T0m`P8203_
41090>LH60P0gR4Q2@3F:BT80<ha<@T0aSTi2@1kQ8@807><S0T0JiBD201SW9`905ZUY@P0DZf]2@1:
]KD804:m_@T0NhB4201cS8`906^DU0T0HibL201JYJD905:][@P0B[Fe2@12_Kd80=7=Z@001P3AcJT9
0?l000P0m`P82@3_41090>LH60P0gR4Q2@3F:BT80<ha<@T0aSTi203o00090?L820P0ka0@2@3W61P8
0=hQ8@T0eRTY203><C490<Hi>@T0NhB4201cS8`906^DU0P0HibL2@1JYJD805:][@T0B[Fe2012_Kd9
07^4Q0P0Lhb<2@1[U9@906>LW0P0FZFU2@1B[Jd804Ze]@T0@[fm203AcJT000H0dLfY2@3o00080?L8
20T0ka0@2@3W61P80=hQ8@T0eRTY203><C490<Hi>@P0o`002@3g20P80>l@40T0iaPH203N8B490=HY
:@P0cS4a2@36>CT907^4Q0P0Lhb<2@1[U9@806>LW0T0FZFU201B[Jd904Ze]@P0@[fm2@1kQ8@807><
S0T0JiBD2@1SW9`805ZUY@T0DZf]201:]KD904:m_@P0dLfY00060=7=Z@T0o`00203g20P90>l@40T0
iaPH203N8B490=HY:@P0cS4a2@36>CT80?l000T0m`P8203_41090>LH60P0gR4Q2@3F:BT80<ha<@T0
aSTi2@1kQ8@807><S0T0JiBD201SW9`905ZUY@P0DZf]2@1:]KD804:m_@T0NhB4201cS8`906^DU0T0
HibL201JYJD905:][@P0B[Fe2@12_Kd80=7=Z@001P3AcJU50?l004@0_D92A01kQ8A503W6aPP0dLfY
00060=7=ZDD0o`00A02m@T9407^4Q4D0>LK6203AcJT000H0dLfYA@3o00140;e2@T@0NhB4A@0ia/H8
0=7=Z@001P3AcJU50?l004@0_D92A01kQ8A503W6aPP0dLfY00060=7=ZDD0o`00A02m@T9407^4Q4D0
>LK6203AcJT000H0dLfYA@3o00140;e2@T@0NhB4A@0ia/H80=7=Z@001P3AcJU50?l004@0_D92A01k
Q8A503W6aPP0dLfY00060=7=ZDD0o`00A02m@T9407^4Q4D0>LK6203AcJT000H0dLfYA@3o00140;e2
@T@0NhB4A@0ia/H80=7=Z@001P3AcJT90?l000P0m`P82@3o00090?L820P0o`002@3g20P80?l000T0
m`P8202m@T890;E:BPP0_D922@2eBTX80;e2@PT0]DY:202m@T890;E:BPT0NhB4201cS8`907^4Q0P0
Lhb<2@1kQ8@807><S0T0NhB4201cS8`903W6aPP0<Lk>2@0ia/H9037>cPP0>LK62@0ac/h803W6aPT0
<Lk>203AcJT000H0dLfY2@3o00080?L820T0o`002@3g20P80?l000T0m`P8203o00090?L820P0_D92
2@2eBTX80;e2@PT0]DY:202m@T890;E:BPP0_D922@2eBTX907^4Q0P0Lhb<2@1kQ8@807><S0T0NhB4
201cS8`907^4Q0P0Lhb<2@0ia/H8037>cPT0>LK62@0ac/h803W6aPT0<Lk>200ia/H9037>cPP0dLfY
00060=7=Z@T0o`00203g20P90?l000T0m`P8203o00090?L820P0o`002@3g20P80;e2@PT0]DY:202m
@T890;E:BPP0_D922@2eBTX80;e2@PT0]DY:2@1kQ8@807><S0T0NhB4201cS8`907^4Q0P0Lhb<2@1k
Q8@807><S0T0>LK6200ac/h903W6aPT0<Lk>200ia/H9037>cPP0>LK62@0ac/h80=7=Z@001P3AcJT9
0?l000P0m`P82@3o00090?L820P0o`002@3g20P80?l000T0m`P8202m@T890;E:BPP0_D922@2eBTX8
0;e2@PT0]DY:202m@T890;E:BPT0NhB4201cS8`907^4Q0P0Lhb<2@1kQ8@807><S0T0NhB4201cS8`9
03W6aPP0<Lk>2@0ia/H9037>cPP0>LK62@0ac/h803W6aPT0<Lk>203AcJT000H0dLfY2@3o00080?L8
20T0o`002@3g20P80?l000T0m`P8203o00090?L820P0_D922@2eBTX80;e2@PT0]DY:202m@T890;E:
BPP0_D922@2eBTX907^4Q0P0Lhb<2@1kQ8@807><S0T0NhB4201cS8`907^4Q0P0Lhb<2@0ia/H8037>
cPT0>LK62@0ac/h803W6aPT0<Lk>200ia/H9037>cPP0dLfY00060=7=Z@T0o`00203g20P90?l000T0
m`P8203o00090?L820P0o`002@3g20P80;e2@PT0]DY:202m@T890;E:BPP0_D922@2eBTX80;e2@PT0
]DY:2@1kQ8@807><S0T0NhB4201cS8`907^4Q0P0Lhb<2@1kQ8@807><S0T0>LK6200ac/h903W6aPT0
<Lk>200ia/H9037>cPP0>LK62@0ac/h80=7=Z@001P3AcJT90?l000P0m`P82@3o00090?L820P0o`00
2@3g20P80?l000T0m`P8202m@T890;E:BPP0_D922@2eBTX80;e2@PT0]DY:202m@T890;E:BPT0NhB4
201cS8`907^4Q0P0Lhb<2@1kQ8@807><S0T0NhB4201cS8`903W6aPP0<Lk>2@0ia/H9037>cPP0>LK6
2@0ac/h803W6aPT0<Lk>203AcJT000H0dLfY2@3o00080?L820T0o`002@3g20P80?l000T0m`P8203o
00090?L820P0_D922@2eBTX80;e2@PT0]DY:202m@T890;E:BPP0_D922@2eBTX907^4Q0P0Lhb<2@1k
Q8@807><S0T0NhB4201cS8`907^4Q0P0Lhb<2@0ia/H8037>cPT0>LK62@0ac/h803W6aPT0<Lk>200i
a/H9037>cPP0dLfY00060=7=ZA40o`004P3_410A0?l00140ka0@4@2m@T8A0:eBDQ40_D924@2]DU8A
07^4Q140JiBD4@1kQ8@A06^DU140>LK64P0Ye]HA03W6aQ40:MKF203AcJT000H0dLfY4@3o000B0>l@
4140o`004@3_410A0;e2@Q40[E9B4@2m@T8A0:eBDQ40NhB44@1[U9@A07^4Q140JiBD4@0ia/HB02WF
eQ40>LK64@0Ye]H80=7=Z@001P3AcJTA0?l00180ka0@4@3o000A0>l@4140_D924@2]DU8A0;e2@Q40
[E9B4@1kQ8@A06^DU140NhB44@1[U9@A03W6aQ80:MKF4@0ia/HA02WFePP0dLfY00060=7=ZA40o`00
4P3_410A0?l00140ka0@4@2m@T8A0:eBDQ40_D924@2]DU8A07^4Q140JiBD4@1kQ8@A06^DU140>LK6
4P0Ye]HA03W6aQ40:MKF203AcJT000H0dLfY4@3o000B0>l@4140o`004@3_410A0;e2@Q40[E9B4@2m
@T8A0:eBDQ40NhB44@1[U9@A07^4Q140JiBD4@0ia/HB02WFeQ40>LK64@0Ye]H80=7=Z@001P3AcJTA
0?l00180ka0@4@3o000A0>l@4140_D924@2]DU8A0;e2@Q40[E9B4@1kQ8@A06^DU140NhB44@1[U9@A
03W6aQ80:MKF4@0ia/HA02WFePP0dLfY00060=7=ZA40o`004P3_410A0?l00140ka0@4@2m@T8A0:eB
DQ40_D924@2]DU8A07^4Q140JiBD4@1kQ8@A06^DU140>LK64P0Ye]HA03W6aQ40:MKF203AcJT000H0
dLfY4@3o000B0>l@4140o`004@3_410A0;e2@Q40[E9B4@2m@T8A0:eBDQ40NhB44@1[U9@A07^4Q140
JiBD4@0ia/HB02WFeQ40>LK64@0Ye]H80=7=Z@001P3AcJTA0?l00180ka0@4@3o000A0>l@4140_D92
4@2]DU8A0;e2@Q40[E9B4@1kQ8@A06^DU140NhB44@1[U9@A03W6aQ80:MKF4@0ia/HA02WFePP0dLfY
00060=7=Z@T0o`00203g20P90>l@40T0iaPH203o00090?L820P0ka0@2@3W61P80;e2@PT0]DY:202]
DU890:EJFPP0_D922@2eBTX80:eBDPT0YEYJ2@1kQ8@807><S0T0JiBD201SW9`907^4Q0P0Lhb<2@1[
U9@806>LW0T0>LK6200ac/h902WFePT08MkN200ia/H9037>cPP0:MKF2@0Qg]h80=7=Z@001P3AcJT9
0?l000P0m`P82@3_41090>LH60P0o`002@3g20P80>l@40T0iaPH202m@T890;E:BPP0[E9B2@2UFUX8
0;e2@PT0]DY:202]DU890:EJFPT0NhB4201cS8`906^DU0P0HibL2@1kQ8@807><S0T0JiBD201SW9`9
03W6aPP0<Lk>2@0Ye]H9027NgPP0>LK62@0ac/h802WFePT08MkN203AcJT000H0dLfY2@3o00080?L8
20T0ka0@2@3W61P80?l000T0m`P8203_41090>LH60P0_D922@2eBTX80:eBDPT0YEYJ202m@T890;E:
BPP0[E9B2@2UFUX907^4Q0P0Lhb<2@1[U9@806>LW0T0NhB4201cS8`906^DU0P0HibL2@0ia/H8037>
cPT0:MKF2@0Qg]h803W6aPT0<Lk>200Ye]H9027NgPP0dLfY00060=7=Z@T0o`00203g20P90>l@40T0
iaPH203o00090?L820P0ka0@2@3W61P80;e2@PT0]DY:202]DU890:EJFPP0_D922@2eBTX80:eBDPT0
YEYJ2@1kQ8@807><S0T0JiBD201SW9`907^4Q0P0Lhb<2@1[U9@806>LW0T0>LK6200ac/h902WFePT0
8MkN200ia/H9037>cPP0:MKF2@0Qg]h80=7=Z@001P3AcJT90?l000P0m`P82@3_41090>LH60P0o`00
2@3g20P80>l@40T0iaPH202m@T890;E:BPP0[E9B2@2UFUX80;e2@PT0]DY:202]DU890:EJFPT0NhB4
201cS8`906^DU0P0HibL2@1kQ8@807><S0T0JiBD201SW9`903W6aPP0<Lk>2@0Ye]H9027NgPP0>LK6
2@0ac/h802WFePT08MkN203AcJT000H0dLfY2@3o00080?L820T0ka0@2@3W61P80?l000T0m`P8203_
41090>LH60P0_D922@2eBTX80:eBDPT0YEYJ202m@T890;E:BPP0[E9B2@2UFUX907^4Q0P0Lhb<2@1[
U9@806>LW0T0NhB4201cS8`906^DU0P0HibL2@0ia/H8037>cPT0:MKF2@0Qg]h803W6aPT0<Lk>200Y
e]H9027NgPP0dLfY00060=7=Z@T0o`00203g20P90>l@40T0iaPH203o00090?L820P0ka0@2@3W61P8
0;e2@PT0]DY:202]DU890:EJFPP0_D922@2eBTX80:eBDPT0YEYJ2@1kQ8@807><S0T0JiBD201SW9`9
07^4Q0P0Lhb<2@1[U9@806>LW0T0>LK6200ac/h902WFePT08MkN200ia/H9037>cPP0:MKF2@0Qg]h8
0=7=Z@001P3AcJT90?l000P0m`P82@3_41090>LH60P0o`002@3g20P80>l@40T0iaPH202m@T890;E:
BPP0[E9B2@2UFUX80;e2@PT0]DY:202]DU890:EJFPT0NhB4201cS8`906^DU0P0HibL2@1kQ8@807><
S0T0JiBD201SW9`903W6aPP0<Lk>2@0Ye]H9027NgPP0>LK62@0ac/h802WFePT08MkN203AcJT000H0
dLfY8`3o000R0=hQ8B80_D928P2LHf<R07^4Q280FZFU8`0ia/HR01SWi`P0dLfY00060=7=ZB<0o`00
8P3N8B4R0;e2@R80W6=S8P1kQ8@R05ZUYB<0>LK68P0HinL80=7=Z@001P3AcJTS0?l00280gR4Q8P2m
@T8R09aSHb80NhB48P1JYJDS03W6aR806>OW203AcJT000H0dLfY8`3o000R0=hQ8B80_D928P2LHf<R
07^4Q280FZFU8`0ia/HR01SWi`P0dLfY00060=7=ZB<0o`008P3N8B4R0;e2@R80W6=S8P1kQ8@R05ZU
YB<0>LK68P0HinL80=7=Z@001P3AcJTS0?l00280gR4Q8P2m@T8R09aSHb80NhB48P1JYJDS03W6aR80
6>OW203AcJT000H0dLfY8`3o000R0=hQ8B80_D928P2LHf<R07^4Q280FZFU8`0ia/HR01SWi`P0dLfY
00060=7=ZB<0o`008P3N8B4R0;e2@R80W6=S8P1kQ8@R05ZUYB<0>LK68P0HinL80=7=Z@001P3AcJTS
0?l00280gR4Q8P2m@T8R09aSHb80NhB48P1JYJDS03W6aR806>OW203AcJT000H0dLfY2@3o00080?L8
20T0o`002@3g20P80=hQ8@T0eRTY203N8B490=HY:@P0_D922@2eBTX80;e2@PT0]DY:202LHf<909A[
J`P0W6=S2@2DJf/907^4Q0P0Lhb<2@1kQ8@807><S0T0FZFU201B[Jd905ZUY@P0DZf]2@0ia/H8037>
cPT0>LK62@0ac/h801SWi`T04>o_200HinL9013_k`P0dLfY00060=7=Z@T0o`00203g20P90?l000T0
m`P8203N8B490=HY:@P0gR4Q2@3F:BT80;e2@PT0]DY:202m@T890;E:BPP0W6=S2@2DJf/809aSH`T0
U6][2@1kQ8@807><S0T0NhB4201cS8`905ZUY@P0DZf]2@1JYJD805:][@T0>LK6200ac/h903W6aPT0
<Lk>200HinL9013_k`P06>OW2@0@knl80=7=Z@001P3AcJT90?l000P0m`P82@3o00090?L820P0gR4Q
2@3F:BT80=hQ8@T0eRTY202m@T890;E:BPP0_D922@2eBTX809aSH`T0U6][202LHf<909A[J`T0NhB4
201cS8`907^4Q0P0Lhb<2@1JYJD805:][@T0FZFU201B[Jd903W6aPP0<Lk>2@0ia/H9037>cPP06>OW
2@0@knl801SWi`T04>o_203AcJT000H0dLfY2@3o00080?L820T0o`002@3g20P80=hQ8@T0eRTY203N
8B490=HY:@P0_D922@2eBTX80;e2@PT0]DY:202LHf<909A[J`P0W6=S2@2DJf/907^4Q0P0Lhb<2@1k
Q8@807><S0T0FZFU201B[Jd905ZUY@P0DZf]2@0ia/H8037>cPT0>LK62@0ac/h801SWi`T04>o_200H
inL9013_k`P0dLfY00060=7=Z@T0o`00203g20P90?l000T0m`P8203N8B490=HY:@P0gR4Q2@3F:BT8
0;e2@PT0]DY:202m@T890;E:BPP0W6=S2@2DJf/809aSH`T0U6][2@1kQ8@807><S0T0NhB4201cS8`9
05ZUY@P0DZf]2@1JYJD805:][@T0>LK6200ac/h903W6aPT0<Lk>200HinL9013_k`P06>OW2@0@knl8
0=7=Z@001P3AcJT90?l000P0m`P82@3o00090?L820P0gR4Q2@3F:BT80=hQ8@T0eRTY202m@T890;E:
BPP0_D922@2eBTX809aSH`T0U6][202LHf<909A[J`T0NhB4201cS8`907^4Q0P0Lhb<2@1JYJD805:]
[@T0FZFU201B[Jd903W6aPP0<Lk>2@0ia/H9037>cPP06>OW2@0@knl801SWi`T04>o_203AcJT000H0
dLfY2@3o00080?L820T0o`002@3g20P80=hQ8@T0eRTY203N8B490=HY:@P0_D922@2eBTX80;e2@PT0
]DY:202LHf<909A[J`P0W6=S2@2DJf/907^4Q0P0Lhb<2@1kQ8@807><S0T0FZFU201B[Jd905ZUY@P0
DZf]2@0ia/H8037>cPT0>LK62@0ac/h801SWi`T04>o_200HinL9013_k`P0dLfY00060=7=Z@T0o`00
203g20P90?l000T0m`P8203N8B490=HY:@P0gR4Q2@3F:BT80;e2@PT0]DY:202m@T890;E:BPP0W6=S
2@2DJf/809aSH`T0U6][2@1kQ8@807><S0T0NhB4201cS8`905ZUY@P0DZf]2@1JYJD805:][@T0>LK6
200ac/h903W6aPT0<Lk>200HinL9013_k`P06>OW2@0@knl80=7=Z@001P3AcJT90?l000P0m`P82@3o
00090?L820P0gR4Q2@3F:BT80=hQ8@T0eRTY202m@T890;E:BPP0_D922@2eBTX809aSH`T0U6][202L
Hf<909A[J`T0NhB4201cS8`907^4Q0P0Lhb<2@1JYJD805:][@T0FZFU201B[Jd903W6aPP0<Lk>2@0i
a/H9037>cPP06>OW2@0@knl801SWi`T04>o_203AcJT000H0dLfY4@3o000B0>l@4140gR4Q4@3><C4A
0;e2@Q40[E9B4@2LHf<A08acLa40NhB44@1[U9@A05ZUYA40B[Fe4@0ia/HB02WFeQ406>OW4@08moL8
0=7=Z@001P3AcJTA0?l00180ka0@4@3N8B4A0<ha<A40_D924@2]DU8A09aSHa40S7=c4@1kQ8@A06^D
U140FZFU4@1:]KDA03W6aQ80:MKF4@0HinLA00Sgm`P0dLfY00060=7=ZA40o`004P3_410A0=hQ8A40
cS4a4@2m@T8A0:eBDQ40W6=S4@2<Lg<A07^4Q140JiBD4@1JYJDA04Ze]A40>LK64P0Ye]HA01SWia40
2?Og203AcJT000H0dLfY4@3o000B0>l@4140gR4Q4@3><C4A0;e2@Q40[E9B4@2LHf<A08acLa40NhB4
4@1[U9@A05ZUYA40B[Fe4@0ia/HB02WFeQ406>OW4@08moL80=7=Z@001P3AcJTA0?l00180ka0@4@3N
8B4A0<ha<A40_D924@2]DU8A09aSHa40S7=c4@1kQ8@A06^DU140FZFU4@1:]KDA03W6aQ80:MKF4@0H
inLA00Sgm`P0dLfY00060=7=ZA40o`004P3_410A0=hQ8A40cS4a4@2m@T8A0:eBDQ40W6=S4@2<Lg<A
07^4Q140JiBD4@1JYJDA04Ze]A40>LK64P0Ye]HA01SWia402?Og203AcJT000H0dLfY4@3o000B0>l@
4140gR4Q4@3><C4A0;e2@Q40[E9B4@2LHf<A08acLa40NhB44@1[U9@A05ZUYA40B[Fe4@0ia/HB02WF
eQ406>OW4@08moL80=7=Z@001P3AcJTA0?l00180ka0@4@3N8B4A0<ha<A40_D924@2]DU8A09aSHa40
S7=c4@1kQ8@A06^DU140FZFU4@1:]KDA03W6aQ80:MKF4@0HinLA00Sgm`P0dLfY00060=7=Z@T0o`00
203g20P90>l@40T0iaPH203N8B490=HY:@P0cS4a2@36>CT80;e2@PT0]DY:202]DU890:EJFPP0W6=S
2@2DJf/808acL`T0Q7]k2@1kQ8@807><S0T0JiBD201SW9`905ZUY@P0DZf]2@1:]KD804:m_@T0>LK6
200ac/h902WFePT08MkN200HinL9013_k`P02?Og2@00ool80=7=Z@001P3AcJT90?l000P0m`P82@3_
41090>LH60P0gR4Q2@3F:BT80<ha<@T0aSTi202m@T890;E:BPP0[E9B2@2UFUX809aSH`T0U6][202<
Lg<908AkN`T0NhB4201cS8`906^DU0P0HibL2@1JYJD805:][@T0B[Fe2012_Kd903W6aPP0<Lk>2@0Y
e]H9027NgPP06>OW2@0@knl800Sgm`T00?oo203AcJT000H0dLfY2@3o00080?L820T0ka0@2@3W61P8
0=hQ8@T0eRTY203><C490<Hi>@P0_D922@2eBTX80:eBDPT0YEYJ202LHf<909A[J`P0S7=c2@24Ng/9
07^4Q0P0Lhb<2@1[U9@806>LW0T0FZFU201B[Jd904Ze]@P0@[fm2@0ia/H8037>cPT0:MKF2@0Qg]h8
01SWi`T04>o_2008moL9003oo`P0dLfY00060=7=Z@T0o`00203g20P90>l@40T0iaPH203N8B490=HY
:@P0cS4a2@36>CT80;e2@PT0]DY:202]DU890:EJFPP0W6=S2@2DJf/808acL`T0Q7]k2@1kQ8@807><
S0T0JiBD201SW9`905ZUY@P0DZf]2@1:]KD804:m_@T0>LK6200ac/h902WFePT08MkN200HinL9013_
k`P02?Og2@00ool80=7=Z@001P3AcJT90?l000P0m`P82@3_41090>LH60P0gR4Q2@3F:BT80<ha<@T0
aSTi202m@T890;E:BPP0[E9B2@2UFUX809aSH`T0U6][202<Lg<908AkN`T0NhB4201cS8`906^DU0P0
HibL2@1JYJD805:][@T0B[Fe2012_Kd903W6aPP0<Lk>2@0Ye]H9027NgPP06>OW2@0@knl800Sgm`T0
0?oo203AcJT000H0dLfY2@3o00080?L820T0ka0@2@3W61P80=hQ8@T0eRTY203><C490<Hi>@P0_D92
2@2eBTX80:eBDPT0YEYJ202LHf<909A[J`P0S7=c2@24Ng/907^4Q0P0Lhb<2@1[U9@806>LW0T0FZFU
201B[Jd904Ze]@P0@[fm2@0ia/H8037>cPT0:MKF2@0Qg]h801SWi`T04>o_2008moL9003oo`P0dLfY
00060=7=Z@T0o`00203g20P90>l@40T0iaPH203N8B490=HY:@P0cS4a2@36>CT80;e2@PT0]DY:202]
DU890:EJFPP0W6=S2@2DJf/808acL`T0Q7]k2@1kQ8@807><S0T0JiBD201SW9`905ZUY@P0DZf]2@1:
]KD804:m_@T0>LK6200ac/h902WFePT08MkN200HinL9013_k`P02?Og2@00ool80=7=Z@001P3AcJT9
0?l000P0m`P82@3_41090>LH60P0gR4Q2@3F:BT80<ha<@T0aSTi202m@T890;E:BPP0[E9B2@2UFUX8
09aSH`T0U6][202<Lg<908AkN`T0NhB4201cS8`906^DU0P0HibL2@1JYJD805:][@T0B[Fe2012_Kd9
03W6aPP0<Lk>2@0Ye]H9027NgPP06>OW2@0@knl800Sgm`T00?oo203AcJT000H0dLfY2@3o00080?L8
20T0ka0@2@3W61P80=hQ8@T0eRTY203><C490<Hi>@P0_D922@2eBTX80:eBDPT0YEYJ202LHf<909A[
J`P0S7=c2@24Ng/907^4Q0P0Lhb<2@1[U9@806>LW0T0FZFU201B[Jd904Ze]@P0@[fm2@0ia/H8037>
cPT0:MKF2@0Qg]h801SWi`T04>o_2008moL9003oo`P0dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY
003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.80017, -1.80017, 0.117074, \
0.117074}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0801 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0610827 1.09311 0 1.09311 [
[ 0 0 0 0 ]
[ 1 1.0801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.0801 L
0 1.0801 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.55219 .65501 m .56503 .66152 L .5562 .67134 L p .694 .677 .829 r
F P
0 g
s
.5562 .67134 m .54339 .66488 L .55219 .65501 L p .694 .677 .829 r
F P
0 g
s
.55577 1.04826 m .54339 .66488 L .5562 .67134 L p .823 .511 .462 r
F P
0 g
s
.5562 .67134 m .57128 1.05498 L .55577 1.04826 L p .823 .511 .462 r
F P
0 g
s
.58207 1.04477 m .57128 1.05498 L .5562 .67134 L p .295 .107 .446 r
F P
0 g
s
.5562 .67134 m .56503 .66152 L .58207 1.04477 L p .295 .107 .446 r
F P
0 g
s
.53928 .64846 m .55219 .65501 L .54339 .66488 L p .694 .677 .829 r
F P
0 g
s
.54339 .66488 m .53051 .65838 L .53928 .64846 L p .694 .677 .829 r
F P
0 g
s
.54017 1.0415 m .53051 .65838 L .54339 .66488 L p .823 .511 .462 r
F P
0 g
s
.54339 .66488 m .55577 1.04826 L .54017 1.0415 L p .823 .511 .462 r
F P
0 g
s
.56652 1.03799 m .55577 1.04826 L .54339 .66488 L p .288 .099 .441 r
F P
0 g
s
.54339 .66488 m .55219 .65501 L .56652 1.03799 L p .288 .099 .441 r
F P
0 g
s
.56652 1.03799 m .55577 1.04826 L .54339 .66488 L p .288 .099 .441 r
F P
0 g
s
.54339 .66488 m .55219 .65501 L .56652 1.03799 L p .288 .099 .441 r
F P
0 g
s
.56105 .64506 m .57392 .65162 L .56503 .66152 L p .694 .677 .829 r
F P
0 g
s
.56503 .66152 m .55219 .65501 L .56105 .64506 L p .694 .677 .829 r
F P
0 g
s
.56652 1.03799 m .55219 .65501 L .56503 .66152 L p .824 .51 .458 r
F P
0 g
s
.56503 .66152 m .58207 1.04477 L .56652 1.03799 L p .824 .51 .458 r
F P
0 g
s
.59295 1.03446 m .58207 1.04477 L .56503 .66152 L p .295 .107 .446 r
F P
0 g
s
.56503 .66152 m .57392 .65162 L .59295 1.03446 L p .295 .107 .446 r
F P
0 g
s
.56652 1.03799 m .55219 .65501 L .56503 .66152 L p .824 .51 .458 r
F P
0 g
s
.56503 .66152 m .58207 1.04477 L .56652 1.03799 L p .824 .51 .458 r
F P
0 g
s
.52632 .64189 m .53928 .64846 L .53051 .65838 L p .694 .677 .829 r
F P
0 g
s
.53051 .65838 m .51757 .65186 L .52632 .64189 L p .694 .677 .829 r
F P
0 g
s
.52447 1.0347 m .51757 .65186 L .53051 .65838 L p .823 .511 .462 r
F P
0 g
s
.53051 .65838 m .54017 1.0415 L .52447 1.0347 L p .823 .511 .462 r
F P
0 g
s
.55088 1.03117 m .54017 1.0415 L .53051 .65838 L p .28 .091 .436 r
F P
0 g
s
.53051 .65838 m .53928 .64846 L .55088 1.03117 L p .28 .091 .436 r
F P
0 g
s
.55088 1.03117 m .54017 1.0415 L .53051 .65838 L p .28 .091 .436 r
F P
0 g
s
.53051 .65838 m .53928 .64846 L .55088 1.03117 L p .28 .091 .436 r
F P
0 g
s
.54812 .63847 m .56105 .64506 L .55219 .65501 L p .694 .677 .829 r
F P
0 g
s
.55219 .65501 m .53928 .64846 L .54812 .63847 L p .694 .677 .829 r
F P
0 g
s
.55042 1.01627 m .53928 .64846 L .55219 .65501 L p .824 .51 .458 r
F P
0 g
s
.55219 .65501 m .56596 1.02308 L .55042 1.01627 L p .824 .51 .458 r
F P
0 g
s
.57672 1.01272 m .56596 1.02308 L .55219 .65501 L p .288 .099 .441 r
F P
0 g
s
.55219 .65501 m .56105 .64506 L .57672 1.01272 L p .288 .099 .441 r
F P
0 g
s
.55088 1.03117 m .53928 .64846 L .55219 .65501 L p .824 .51 .458 r
F P
0 g
s
.55219 .65501 m .56652 1.03799 L .55088 1.03117 L p .824 .51 .458 r
F P
0 g
s
.57736 1.02762 m .56652 1.03799 L .55219 .65501 L p .288 .099 .441 r
F P
0 g
s
.55219 .65501 m .56105 .64506 L .57736 1.02762 L p .288 .099 .441 r
F P
0 g
s
.51329 .63528 m .52632 .64189 L .51757 .65186 L p .694 .677 .829 r
F P
0 g
s
.51757 .65186 m .50457 .6453 L .51329 .63528 L p .694 .677 .829 r
F P
0 g
s
.50869 1.02786 m .50457 .6453 L .51757 .65186 L p .823 .511 .462 r
F P
0 g
s
.51757 .65186 m .52447 1.0347 L .50869 1.02786 L p .823 .511 .462 r
F P
0 g
s
.53514 1.02431 m .52447 1.0347 L .51757 .65186 L p .272 .082 .43 r
F P
0 g
s
.51757 .65186 m .52632 .64189 L .53514 1.02431 L p .272 .082 .43 r
F P
0 g
s
.53514 1.02431 m .52447 1.0347 L .51757 .65186 L p .272 .082 .43 r
F P
0 g
s
.51757 .65186 m .52632 .64189 L .53514 1.02431 L p .272 .082 .43 r
F P
0 g
s
.56998 .63504 m .58287 .64165 L .57392 .65162 L p .694 .677 .829 r
F P
0 g
s
.57392 .65162 m .56105 .64506 L .56998 .63504 L p .694 .677 .829 r
F P
0 g
s
.57736 1.02762 m .56105 .64506 L .57392 .65162 L p .825 .508 .454 r
F P
0 g
s
.57392 .65162 m .59295 1.03446 L .57736 1.02762 L p .825 .508 .454 r
F P
0 g
s
.60392 1.02406 m .59295 1.03446 L .57392 .65162 L p .295 .107 .446 r
F P
0 g
s
.57392 .65162 m .58287 .64165 L .60392 1.02406 L p .295 .107 .446 r
F P
0 g
s
.57736 1.02762 m .56105 .64506 L .57392 .65162 L p .825 .508 .454 r
F P
0 g
s
.57392 .65162 m .59295 1.03446 L .57736 1.02762 L p .825 .508 .454 r
F P
0 g
s
.53513 .63184 m .54812 .63847 L .53928 .64846 L p .694 .677 .829 r
F P
0 g
s
.53928 .64846 m .52632 .64189 L .53513 .63184 L p .694 .677 .829 r
F P
0 g
s
.53514 1.02431 m .52632 .64189 L .53928 .64846 L p .824 .51 .458 r
F P
0 g
s
.53928 .64846 m .55088 1.03117 L .53514 1.02431 L p .824 .51 .458 r
F P
0 g
s
.56596 1.02308 m .55042 1.01627 L .56115 1.00584 L p .682 .709 .868 r
F P
0 g
s
.56168 1.02074 m .55088 1.03117 L .53928 .64846 L p .28 .091 .436 r
F P
0 g
s
.53928 .64846 m .54812 .63847 L .56168 1.02074 L p .28 .091 .436 r
F P
0 g
s
.53514 1.02431 m .52632 .64189 L .53928 .64846 L p .824 .51 .458 r
F P
0 g
s
.53928 .64846 m .55088 1.03117 L .53514 1.02431 L p .824 .51 .458 r
F P
0 g
s
.56115 1.00584 m .55042 1.01627 L .53928 .64846 L p .28 .091 .436 r
F P
0 g
s
.53928 .64846 m .54812 .63847 L .56115 1.00584 L p .28 .091 .436 r
F P
0 g
s
.50019 .62864 m .51329 .63528 L .50457 .6453 L p .694 .677 .829 r
F P
0 g
s
.50457 .6453 m .4915 .63871 L .50019 .62864 L p .694 .677 .829 r
F P
0 g
s
.4928 1.02098 m .4915 .63871 L .50457 .6453 L p .823 .511 .462 r
F P
0 g
s
.50457 .6453 m .50869 1.02786 L .4928 1.02098 L p .823 .511 .462 r
F P
0 g
s
.51931 1.0174 m .50869 1.02786 L .50457 .6453 L p .264 .074 .424 r
F P
0 g
s
.50457 .6453 m .51329 .63528 L .51931 1.0174 L p .264 .074 .424 r
F P
0 g
s
.51931 1.0174 m .50869 1.02786 L .50457 .6453 L p .264 .074 .424 r
F P
0 g
s
.50457 .6453 m .51329 .63528 L .51931 1.0174 L p .264 .074 .424 r
F P
0 g
s
.55703 .6284 m .56998 .63504 L .56105 .64506 L p .694 .677 .829 r
F P
0 g
s
.56105 .64506 m .54812 .63847 L .55703 .6284 L p .694 .677 .829 r
F P
0 g
s
.56115 1.00584 m .57672 1.01272 L .56596 1.02308 L p .682 .709 .868 r
F P
0 g
s
.56168 1.02074 m .54812 .63847 L .56105 .64506 L p .825 .508 .454 r
F P
0 g
s
.56105 .64506 m .57736 1.02762 L .56168 1.02074 L p .825 .508 .454 r
F P
0 g
s
.5883 1.01715 m .57736 1.02762 L .56105 .64506 L p .288 .099 .441 r
F P
0 g
s
.56105 .64506 m .56998 .63504 L .5883 1.01715 L p .288 .099 .441 r
F P
0 g
s
.56115 1.00584 m .54812 .63847 L .56105 .64506 L p .825 .508 .454 r
F P
0 g
s
.56105 .64506 m .57672 1.01272 L .56115 1.00584 L p .825 .508 .454 r
F P
0 g
s
.5883 1.01715 m .57736 1.02762 L .56105 .64506 L p .288 .099 .441 r
F P
0 g
s
.56105 .64506 m .56998 .63504 L .5883 1.01715 L p .288 .099 .441 r
F P
0 g
s
.52207 .62519 m .53513 .63184 L .52632 .64189 L p .694 .677 .829 r
F P
0 g
s
.52632 .64189 m .51329 .63528 L .52207 .62519 L p .694 .677 .829 r
F P
0 g
s
.51908 1.00251 m .51329 .63528 L .52632 .64189 L p .824 .51 .458 r
F P
0 g
s
.52632 .64189 m .5348 1.00941 L .51908 1.00251 L p .824 .51 .458 r
F P
0 g
s
.54549 .99892 m .5348 1.00941 L .52632 .64189 L p .272 .082 .43 r
F P
0 g
s
.52632 .64189 m .53513 .63184 L .54549 .99892 L p .272 .082 .43 r
F P
0 g
s
.51931 1.0174 m .51329 .63528 L .52632 .64189 L p .824 .51 .458 r
F P
0 g
s
.52632 .64189 m .53514 1.02431 L .51931 1.0174 L p .824 .51 .458 r
F P
0 g
s
.54591 1.01381 m .53514 1.02431 L .52632 .64189 L p .272 .082 .43 r
F P
0 g
s
.52632 .64189 m .53513 .63184 L .54591 1.01381 L p .272 .082 .43 r
F P
0 g
s
.57898 .62495 m .5919 .63161 L .58287 .64165 L p .694 .677 .829 r
F P
0 g
s
.58287 .64165 m .56998 .63504 L .57898 .62495 L p .694 .677 .829 r
F P
0 g
s
.5883 1.01715 m .56998 .63504 L .58287 .64165 L p .825 .507 .451 r
F P
0 g
s
.58287 .64165 m .60392 1.02406 L .5883 1.01715 L p .825 .507 .451 r
F P
0 g
s
.615 1.01356 m .60392 1.02406 L .58287 .64165 L p .295 .107 .446 r
F P
0 g
s
.58287 .64165 m .5919 .63161 L .615 1.01356 L p .295 .107 .446 r
F P
0 g
s
.5883 1.01715 m .56998 .63504 L .58287 .64165 L p .825 .507 .451 r
F P
0 g
s
.58287 .64165 m .60392 1.02406 L .5883 1.01715 L p .825 .507 .451 r
F P
0 g
s
.48703 .62197 m .50019 .62864 L .4915 .63871 L p .694 .677 .829 r
F P
0 g
s
.4915 .63871 m .47837 .63208 L .48703 .62197 L p .694 .677 .829 r
F P
0 g
s
.47683 1.01406 m .47837 .63208 L .4915 .63871 L p .823 .511 .462 r
F P
0 g
s
.4915 .63871 m .4928 1.02098 L .47683 1.01406 L p .823 .511 .462 r
F P
0 g
s
.50339 1.01046 m .4928 1.02098 L .4915 .63871 L p .256 .065 .418 r
F P
0 g
s
.4915 .63871 m .50019 .62864 L .50339 1.01046 L p .256 .065 .418 r
F P
0 g
s
.50339 1.01046 m .4928 1.02098 L .4915 .63871 L p .256 .065 .418 r
F P
0 g
s
.4915 .63871 m .50019 .62864 L .50339 1.01046 L p .256 .065 .418 r
F P
0 g
s
.54401 .62173 m .55703 .6284 L .54812 .63847 L p .694 .677 .829 r
F P
0 g
s
.54812 .63847 m .53513 .63184 L .54401 .62173 L p .694 .677 .829 r
F P
0 g
s
.54507 .98423 m .53513 .63184 L .54812 .63847 L p .825 .508 .454 r
F P
0 g
s
.54812 .63847 m .56063 .99115 L .54507 .98423 L p .825 .508 .454 r
F P
0 g
s
.57138 .98064 m .56063 .99115 L .54812 .63847 L p .28 .091 .436 r
F P
0 g
s
.54812 .63847 m .55703 .6284 L .57138 .98064 L p .28 .091 .436 r
F P
0 g
s
.54591 1.01381 m .53513 .63184 L .54812 .63847 L p .825 .508 .454 r
F P
0 g
s
.54812 .63847 m .56168 1.02074 L .54591 1.01381 L p .825 .508 .454 r
F P
0 g
s
.57258 1.01021 m .56168 1.02074 L .54812 .63847 L p .28 .091 .436 r
F P
0 g
s
.54812 .63847 m .55703 .6284 L .57258 1.01021 L p .28 .091 .436 r
F P
0 g
s
.50895 .6185 m .52207 .62519 L .51329 .63528 L p .694 .677 .829 r
F P
0 g
s
.51329 .63528 m .50019 .62864 L .50895 .6185 L p .694 .677 .829 r
F P
0 g
s
.50339 1.01046 m .50019 .62864 L .51329 .63528 L p .824 .51 .458 r
F P
0 g
s
.51329 .63528 m .51931 1.0174 L .50339 1.01046 L p .824 .51 .458 r
F P
0 g
s
.5348 1.00941 m .51908 1.00251 L .52973 .99196 L p .682 .709 .868 r
F P
0 g
s
.53004 1.00685 m .51931 1.0174 L .51329 .63528 L p .264 .074 .424 r
F P
0 g
s
.51329 .63528 m .52207 .62519 L .53004 1.00685 L p .264 .074 .424 r
F P
0 g
s
.50339 1.01046 m .50019 .62864 L .51329 .63528 L p .824 .51 .458 r
F P
0 g
s
.51329 .63528 m .51931 1.0174 L .50339 1.01046 L p .824 .51 .458 r
F P
0 g
s
.52973 .99196 m .51908 1.00251 L .51329 .63528 L p .264 .074 .424 r
F P
0 g
s
.51329 .63528 m .52207 .62519 L .52973 .99196 L p .264 .074 .424 r
F P
0 g
s
.566 .61826 m .57898 .62495 L .56998 .63504 L p .694 .677 .829 r
F P
0 g
s
.56998 .63504 m .55703 .6284 L .566 .61826 L p .694 .677 .829 r
F P
0 g
s
.57197 .99532 m .55703 .6284 L .56998 .63504 L p .825 .507 .451 r
F P
0 g
s
.56998 .63504 m .58758 1.00226 L .57197 .99532 L p .825 .507 .451 r
F P
0 g
s
.59854 .99171 m .58758 1.00226 L .56998 .63504 L p .288 .099 .441 r
F P
0 g
s
.56998 .63504 m .57898 .62495 L .59854 .99171 L p .288 .099 .441 r
F P
0 g
s
.57258 1.01021 m .55703 .6284 L .56998 .63504 L p .825 .507 .451 r
F P
0 g
s
.56998 .63504 m .5883 1.01715 L .57258 1.01021 L p .825 .507 .451 r
F P
0 g
s
.59934 1.0066 m .5883 1.01715 L .56998 .63504 L p .288 .099 .441 r
F P
0 g
s
.56998 .63504 m .57898 .62495 L .59934 1.0066 L p .288 .099 .441 r
F P
0 g
s
.47381 .61526 m .48703 .62197 L .47837 .63208 L p .694 .677 .829 r
F P
0 g
s
.47837 .63208 m .46517 .62543 L .47381 .61526 L p .694 .677 .829 r
F P
0 g
s
.46076 1.0071 m .46517 .62543 L .47837 .63208 L p .823 .511 .462 r
F P
0 g
s
.47837 .63208 m .47683 1.01406 L .46076 1.0071 L p .823 .511 .462 r
F P
0 g
s
.48738 1.00348 m .47683 1.01406 L .47837 .63208 L p .248 .056 .412 r
F P
0 g
s
.47837 .63208 m .48703 .62197 L .48738 1.00348 L p .248 .056 .412 r
F P
0 g
s
.48738 1.00348 m .47683 1.01406 L .47837 .63208 L p .248 .056 .412 r
F P
0 g
s
.47837 .63208 m .48703 .62197 L .48738 1.00348 L p .248 .056 .412 r
F P
0 g
s
.53092 .61502 m .54401 .62173 L .53513 .63184 L p .694 .677 .829 r
F P
0 g
s
.53513 .63184 m .52207 .62519 L .53092 .61502 L p .694 .677 .829 r
F P
0 g
s
.52942 .97728 m .52207 .62519 L .53513 .63184 L p .825 .508 .454 r
F P
0 g
s
.53513 .63184 m .54507 .98423 L .52942 .97728 L p .825 .508 .454 r
F P
0 g
s
.55578 .97366 m .54507 .98423 L .53513 .63184 L p .272 .082 .43 r
F P
0 g
s
.53513 .63184 m .54401 .62173 L .55578 .97366 L p .272 .082 .43 r
F P
0 g
s
.52973 .99196 m .52207 .62519 L .53513 .63184 L p .825 .508 .454 r
F P
0 g
s
.53513 .63184 m .54549 .99892 L .52973 .99196 L p .825 .508 .454 r
F P
0 g
s
.55578 .97366 m .54507 .98423 L .53513 .63184 L p .272 .082 .43 r
F P
0 g
s
.53513 .63184 m .54401 .62173 L .55578 .97366 L p .272 .082 .43 r
F P
0 g
s
.58804 .61478 m .60099 .62149 L .5919 .63161 L p .694 .677 .829 r
F P
0 g
s
.5919 .63161 m .57898 .62495 L .58804 .61478 L p .694 .677 .829 r
F P
0 g
s
.59934 1.0066 m .57898 .62495 L .5919 .63161 L p .826 .506 .447 r
F P
0 g
s
.5919 .63161 m .615 1.01356 L .59934 1.0066 L p .826 .506 .447 r
F P
0 g
s
.62618 1.00297 m .615 1.01356 L .5919 .63161 L p .295 .107 .446 r
F P
0 g
s
.5919 .63161 m .60099 .62149 L .62618 1.00297 L p .295 .107 .446 r
F P
0 g
s
.59934 1.0066 m .57898 .62495 L .5919 .63161 L p .826 .506 .447 r
F P
0 g
s
.5919 .63161 m .615 1.01356 L .59934 1.0066 L p .826 .506 .447 r
F P
0 g
s
.49576 .61177 m .50895 .6185 L .50019 .62864 L p .694 .677 .829 r
F P
0 g
s
.50019 .62864 m .48703 .62197 L .49576 .61177 L p .694 .677 .829 r
F P
0 g
s
.48736 .98859 m .48703 .62197 L .50019 .62864 L p .824 .51 .458 r
F P
0 g
s
.50019 .62864 m .50327 .99557 L .48736 .98859 L p .824 .51 .458 r
F P
0 g
s
.51388 .98496 m .50327 .99557 L .50019 .62864 L p .256 .065 .418 r
F P
0 g
s
.50019 .62864 m .50895 .6185 L .51388 .98496 L p .256 .065 .418 r
F P
0 g
s
.48738 1.00348 m .48703 .62197 L .50019 .62864 L p .824 .51 .458 r
F P
0 g
s
.50019 .62864 m .50339 1.01046 L .48738 1.00348 L p .824 .51 .458 r
F P
0 g
s
.51408 .99984 m .50339 1.01046 L .50019 .62864 L p .256 .065 .418 r
F P
0 g
s
.50019 .62864 m .50895 .6185 L .51408 .99984 L p .256 .065 .418 r
F P
0 g
s
.55295 .61153 m .566 .61826 L .55703 .6284 L p .694 .677 .829 r
F P
0 g
s
.55703 .6284 m .54401 .62173 L .55295 .61153 L p .694 .677 .829 r
F P
0 g
s
.55578 .97366 m .54401 .62173 L .55703 .6284 L p .825 .507 .451 r
F P
0 g
s
.55703 .6284 m .57138 .98064 L .55578 .97366 L p .825 .507 .451 r
F P
0 g
s
.58222 .97003 m .57138 .98064 L .55703 .6284 L p .28 .091 .436 r
F P
0 g
s
.55703 .6284 m .566 .61826 L .58222 .97003 L p .28 .091 .436 r
F P
0 g
s
.55578 .97366 m .54401 .62173 L .55703 .6284 L p .825 .507 .451 r
F P
0 g
s
.55703 .6284 m .57138 .98064 L .55578 .97366 L p .825 .507 .451 r
F P
0 g
s
.5829 .98471 m .57197 .99532 L .55703 .6284 L p .28 .091 .436 r
F P
0 g
s
.55703 .6284 m .566 .61826 L .5829 .98471 L p .28 .091 .436 r
F P
0 g
s
.46052 .60852 m .47381 .61526 L .46517 .62543 L p .694 .677 .829 r
F P
0 g
s
.46517 .62543 m .45191 .61874 L .46052 .60852 L p .694 .677 .829 r
F P
0 g
s
.44459 1.0001 m .45191 .61874 L .46517 .62543 L p .823 .511 .462 r
F P
0 g
s
.46517 .62543 m .46076 1.0071 L .44459 1.0001 L p .823 .511 .462 r
F P
0 g
s
.47126 .99645 m .46076 1.0071 L .46517 .62543 L p .239 .047 .406 r
F P
0 g
s
.46517 .62543 m .47381 .61526 L .47126 .99645 L p .239 .047 .406 r
F P
0 g
s
.47126 .99645 m .46076 1.0071 L .46517 .62543 L p .239 .047 .406 r
F P
0 g
s
.46517 .62543 m .47381 .61526 L .47126 .99645 L p .239 .047 .406 r
F P
0 g
s
.51777 .60828 m .53092 .61502 L .52207 .62519 L p .694 .677 .829 r
F P
0 g
s
.52207 .62519 m .50895 .6185 L .51777 .60828 L p .694 .677 .829 r
F P
0 g
s
.51408 .99984 m .50895 .6185 L .52207 .62519 L p .825 .508 .454 r
F P
0 g
s
.52207 .62519 m .53004 1.00685 L .51408 .99984 L p .825 .508 .454 r
F P
0 g
s
.54507 .98423 m .52942 .97728 L .54009 .96664 L p .683 .708 .867 r
F P
0 g
s
.52973 .99196 m .54549 .99892 L .5348 1.00941 L p .682 .709 .868 r
F P
0 g
s
.54086 .9962 m .53004 1.00685 L .52207 .62519 L p .264 .074 .424 r
F P
0 g
s
.52207 .62519 m .53092 .61502 L .54086 .9962 L p .264 .074 .424 r
F P
0 g
s
.51408 .99984 m .50895 .6185 L .52207 .62519 L p .825 .508 .454 r
F P
0 g
s
.52207 .62519 m .53004 1.00685 L .51408 .99984 L p .825 .508 .454 r
F P
0 g
s
.54009 .96664 m .52942 .97728 L .52207 .62519 L p .264 .074 .424 r
F P
0 g
s
.52207 .62519 m .53092 .61502 L .54009 .96664 L p .264 .074 .424 r
F P
0 g
s
.57503 .60804 m .58804 .61478 L .57898 .62495 L p .694 .677 .829 r
F P
0 g
s
.57898 .62495 m .566 .61826 L .57503 .60804 L p .694 .677 .829 r
F P
0 g
s
.5829 .98471 m .59854 .99171 L .58758 1.00226 L p .682 .709 .868 r
F P
0 g
s
.58758 1.00226 m .57197 .99532 L .5829 .98471 L p .682 .709 .868 r
F P
0 g
s
.58358 .99959 m .566 .61826 L .57898 .62495 L p .826 .506 .447 r
F P
0 g
s
.57898 .62495 m .59934 1.0066 L .58358 .99959 L p .826 .506 .447 r
F P
0 g
s
.61048 .99594 m .59934 1.0066 L .57898 .62495 L p .288 .099 .441 r
F P
0 g
s
.57898 .62495 m .58804 .61478 L .61048 .99594 L p .288 .099 .441 r
F P
0 g
s
.5829 .98471 m .566 .61826 L .57898 .62495 L p .826 .506 .447 r
F P
0 g
s
.57898 .62495 m .59854 .99171 L .5829 .98471 L p .826 .506 .447 r
F P
0 g
s
.61048 .99594 m .59934 1.0066 L .57898 .62495 L p .288 .099 .441 r
F P
0 g
s
.57898 .62495 m .58804 .61478 L .61048 .99594 L p .288 .099 .441 r
F P
0 g
s
.48251 .60502 m .49576 .61177 L .48703 .62197 L p .694 .677 .829 r
F P
0 g
s
.48703 .62197 m .47381 .61526 L .48251 .60502 L p .694 .677 .829 r
F P
0 g
s
.47126 .99645 m .47381 .61526 L .48703 .62197 L p .824 .51 .458 r
F P
0 g
s
.48703 .62197 m .48738 1.00348 L .47126 .99645 L p .824 .51 .458 r
F P
0 g
s
.50327 .99557 m .48736 .98859 L .49793 .97792 L p .682 .709 .868 r
F P
0 g
s
.49802 .99279 m .48738 1.00348 L .48703 .62197 L p .248 .056 .412 r
F P
0 g
s
.48703 .62197 m .49576 .61177 L .49802 .99279 L p .248 .056 .412 r
F P
0 g
s
.47126 .99645 m .47381 .61526 L .48703 .62197 L p .824 .51 .458 r
F P
0 g
s
.48703 .62197 m .48738 1.00348 L .47126 .99645 L p .824 .51 .458 r
F P
0 g
s
.49793 .97792 m .48736 .98859 L .48703 .62197 L p .248 .056 .412 r
F P
0 g
s
.48703 .62197 m .49576 .61177 L .49793 .97792 L p .248 .056 .412 r
F P
0 g
s
.53984 .60478 m .55295 .61153 L .54401 .62173 L p .694 .677 .829 r
F P
0 g
s
.54401 .62173 m .53092 .61502 L .53984 .60478 L p .694 .677 .829 r
F P
0 g
s
.53971 .95217 m .53092 .61502 L .54401 .62173 L p .825 .507 .451 r
F P
0 g
s
.54401 .62173 m .5553 .95918 L .53971 .95217 L p .825 .507 .451 r
F P
0 g
s
.56602 .94852 m .5553 .95918 L .54401 .62173 L p .272 .082 .43 r
F P
0 g
s
.54401 .62173 m .55295 .61153 L .56602 .94852 L p .272 .082 .43 r
F P
0 g
s
.54009 .96664 m .53092 .61502 L .54401 .62173 L p .825 .507 .451 r
F P
0 g
s
.54401 .62173 m .55578 .97366 L .54009 .96664 L p .825 .507 .451 r
F P
0 g
s
.56658 .96299 m .55578 .97366 L .54401 .62173 L p .272 .082 .43 r
F P
0 g
s
.54401 .62173 m .55295 .61153 L .56658 .96299 L p .272 .082 .43 r
F P
0 g
s
.59718 .60453 m .61015 .61129 L .60099 .62149 L p .694 .677 .829 r
F P
0 g
s
.60099 .62149 m .58804 .61478 L .59718 .60453 L p .694 .677 .829 r
F P
0 g
s
.61048 .99594 m .58804 .61478 L .60099 .62149 L p .827 .504 .443 r
F P
0 g
s
.60099 .62149 m .62618 1.00297 L .61048 .99594 L p .827 .504 .443 r
F P
0 g
s
.63746 .99228 m .62618 1.00297 L .60099 .62149 L p .295 .107 .446 r
F P
0 g
s
.60099 .62149 m .61015 .61129 L .63746 .99228 L p .295 .107 .446 r
F P
0 g
s
.61048 .99594 m .58804 .61478 L .60099 .62149 L p .827 .504 .443 r
F P
0 g
s
.60099 .62149 m .62618 1.00297 L .61048 .99594 L p .827 .504 .443 r
F P
0 g
s
.44717 .60175 m .46052 .60852 L .45191 .61874 L p .694 .677 .829 r
F P
0 g
s
.45191 .61874 m .43859 .61202 L .44717 .60175 L p .694 .677 .829 r
F P
0 g
s
.42832 .99305 m .43859 .61202 L .45191 .61874 L p .823 .511 .462 r
F P
0 g
s
.45191 .61874 m .44459 1.0001 L .42832 .99305 L p .823 .511 .462 r
F P
0 g
s
.45505 .98938 m .44459 1.0001 L .45191 .61874 L p .23 .037 .399 r
F P
0 g
s
.45191 .61874 m .46052 .60852 L .45505 .98938 L p .23 .037 .399 r
F P
0 g
s
.45505 .98938 m .44459 1.0001 L .45191 .61874 L p .23 .037 .399 r
F P
0 g
s
.45191 .61874 m .46052 .60852 L .45505 .98938 L p .23 .037 .399 r
F P
0 g
s
.50456 .60151 m .51777 .60828 L .50895 .6185 L p .694 .677 .829 r
F P
0 g
s
.50895 .6185 m .49576 .61177 L .50456 .60151 L p .694 .677 .829 r
F P
0 g
s
.49793 .97792 m .51388 .98496 L .50327 .99557 L p .682 .709 .868 r
F P
0 g
s
.49802 .99279 m .49576 .61177 L .50895 .6185 L p .825 .508 .454 r
F P
0 g
s
.50895 .6185 m .51408 .99984 L .49802 .99279 L p .825 .508 .454 r
F P
0 g
s
.52486 .98913 m .51408 .99984 L .50895 .6185 L p .256 .065 .418 r
F P
0 g
s
.50895 .6185 m .51777 .60828 L .52486 .98913 L p .256 .065 .418 r
F P
0 g
s
.49793 .97792 m .49576 .61177 L .50895 .6185 L p .825 .508 .454 r
F P
0 g
s
.50895 .6185 m .51388 .98496 L .49793 .97792 L p .825 .508 .454 r
F P
0 g
s
.52486 .98913 m .51408 .99984 L .50895 .6185 L p .256 .065 .418 r
F P
0 g
s
.50895 .6185 m .51777 .60828 L .52486 .98913 L p .256 .065 .418 r
F P
0 g
s
.56196 .60126 m .57503 .60804 L .566 .61826 L p .694 .677 .829 r
F P
0 g
s
.566 .61826 m .55295 .61153 L .56196 .60126 L p .694 .677 .829 r
F P
0 g
s
.55578 .97366 m .57138 .98064 L .56063 .99115 L p .683 .708 .867 r
F P
0 g
s
.56658 .96299 m .58222 .97003 L .57138 .98064 L p .683 .708 .867 r
F P
0 g
s
.57138 .98064 m .55578 .97366 L .56658 .96299 L p .683 .708 .867 r
F P
0 g
s
.56773 .99254 m .55295 .61153 L .566 .61826 L p .826 .506 .447 r
F P
0 g
s
.566 .61826 m .58358 .99959 L .56773 .99254 L p .826 .506 .447 r
F P
0 g
s
.59468 .98887 m .58358 .99959 L .566 .61826 L p .28 .091 .436 r
F P
0 g
s
.566 .61826 m .57503 .60804 L .59468 .98887 L p .28 .091 .436 r
F P
0 g
s
.56658 .96299 m .55295 .61153 L .566 .61826 L p .826 .506 .447 r
F P
0 g
s
.566 .61826 m .58222 .97003 L .56658 .96299 L p .826 .506 .447 r
F P
0 g
s
.59468 .98887 m .58358 .99959 L .566 .61826 L p .28 .091 .436 r
F P
0 g
s
.566 .61826 m .57503 .60804 L .59468 .98887 L p .28 .091 .436 r
F P
0 g
s
.4692 .59823 m .48251 .60502 L .47381 .61526 L p .694 .677 .829 r
F P
0 g
s
.47381 .61526 m .46052 .60852 L .4692 .59823 L p .694 .677 .829 r
F P
0 g
s
.45527 .97451 m .46052 .60852 L .47381 .61526 L p .824 .51 .458 r
F P
0 g
s
.47381 .61526 m .47136 .98157 L .45527 .97451 L p .824 .51 .458 r
F P
0 g
s
.48189 .97083 m .47136 .98157 L .47381 .61526 L p .239 .047 .406 r
F P
0 g
s
.47381 .61526 m .48251 .60502 L .48189 .97083 L p .239 .047 .406 r
F P
0 g
s
.45505 .98938 m .46052 .60852 L .47381 .61526 L p .824 .51 .458 r
F P
0 g
s
.47381 .61526 m .47126 .99645 L .45505 .98938 L p .824 .51 .458 r
F P
0 g
s
.48186 .9857 m .47126 .99645 L .47381 .61526 L p .239 .047 .406 r
F P
0 g
s
.47381 .61526 m .48251 .60502 L .48186 .9857 L p .239 .047 .406 r
F P
0 g
s
.52666 .59798 m .53984 .60478 L .53092 .61502 L p .694 .677 .829 r
F P
0 g
s
.53092 .61502 m .51777 .60828 L .52666 .59798 L p .694 .677 .829 r
F P
0 g
s
.52486 .98913 m .51777 .60828 L .53092 .61502 L p .825 .507 .451 r
F P
0 g
s
.53092 .61502 m .54086 .9962 L .52486 .98913 L p .825 .507 .451 r
F P
0 g
s
.56063 .99115 m .54507 .98423 L .55578 .97366 L p .683 .708 .867 r
F P
0 g
s
.5553 .95918 m .53971 .95217 L .5504 .94145 L p .683 .706 .865 r
F P
0 g
s
.54009 .96664 m .55578 .97366 L .54507 .98423 L p .683 .708 .867 r
F P
0 g
s
.55178 .98545 m .54086 .9962 L .53092 .61502 L p .264 .074 .424 r
F P
0 g
s
.53092 .61502 m .53984 .60478 L .55178 .98545 L p .264 .074 .424 r
F P
0 g
s
.52486 .98913 m .51777 .60828 L .53092 .61502 L p .825 .507 .451 r
F P
0 g
s
.53092 .61502 m .54086 .9962 L .52486 .98913 L p .825 .507 .451 r
F P
0 g
s
.5504 .94145 m .53971 .95217 L .53092 .61502 L p .264 .074 .424 r
F P
0 g
s
.53092 .61502 m .53984 .60478 L .5504 .94145 L p .264 .074 .424 r
F P
0 g
s
.58414 .59774 m .59718 .60453 L .58804 .61478 L p .694 .677 .829 r
F P
0 g
s
.58804 .61478 m .57503 .60804 L .58414 .59774 L p .694 .677 .829 r
F P
0 g
s
.59392 .974 m .57503 .60804 L .58804 .61478 L p .827 .504 .443 r
F P
0 g
s
.58804 .61478 m .6096 .98106 L .59392 .974 L p .827 .504 .443 r
F P
0 g
s
.62076 .97032 m .6096 .98106 L .58804 .61478 L p .288 .099 .441 r
F P
0 g
s
.58804 .61478 m .59718 .60453 L .62076 .97032 L p .288 .099 .441 r
F P
0 g
s
.59468 .98887 m .57503 .60804 L .58804 .61478 L p .827 .504 .443 r
F P
0 g
s
.58804 .61478 m .61048 .99594 L .59468 .98887 L p .827 .504 .443 r
F P
0 g
s
.62172 .98519 m .61048 .99594 L .58804 .61478 L p .288 .099 .441 r
F P
0 g
s
.58804 .61478 m .59718 .60453 L .62172 .98519 L p .288 .099 .441 r
F P
0 g
s
.43375 .59495 m .44717 .60175 L .43859 .61202 L p .694 .677 .829 r
F P
0 g
s
.43859 .61202 m .4252 .60526 L .43375 .59495 L p .694 .677 .829 r
F P
0 g
s
.41196 .98596 m .4252 .60526 L .43859 .61202 L p .823 .511 .462 r
F P
0 g
s
.43859 .61202 m .42832 .99305 L .41196 .98596 L p .823 .511 .462 r
F P
0 g
s
.43874 .98227 m .42832 .99305 L .43859 .61202 L p .22 .027 .392 r
F P
0 g
s
.43859 .61202 m .44717 .60175 L .43874 .98227 L p .22 .027 .392 r
F P
0 g
s
.43874 .98227 m .42832 .99305 L .43859 .61202 L p .22 .027 .392 r
F P
0 g
s
.43859 .61202 m .44717 .60175 L .43874 .98227 L p .22 .027 .392 r
F P
0 g
s
.49128 .5947 m .50456 .60151 L .49576 .61177 L p .694 .677 .829 r
F P
0 g
s
.49576 .61177 m .48251 .60502 L .49128 .5947 L p .694 .677 .829 r
F P
0 g
s
.48191 .95617 m .48251 .60502 L .49576 .61177 L p .825 .508 .454 r
F P
0 g
s
.49576 .61177 m .49784 .96325 L .48191 .95617 L p .825 .508 .454 r
F P
0 g
s
.50843 .95248 m .49784 .96325 L .49576 .61177 L p .248 .056 .412 r
F P
0 g
s
.49576 .61177 m .50456 .60151 L .50843 .95248 L p .248 .056 .412 r
F P
0 g
s
.48186 .9857 m .48251 .60502 L .49576 .61177 L p .825 .508 .454 r
F P
0 g
s
.49576 .61177 m .49802 .99279 L .48186 .9857 L p .825 .508 .454 r
F P
0 g
s
.50876 .98201 m .49802 .99279 L .49576 .61177 L p .248 .056 .412 r
F P
0 g
s
.49576 .61177 m .50456 .60151 L .50876 .98201 L p .248 .056 .412 r
F P
0 g
s
.54882 .59445 m .56196 .60126 L .55295 .61153 L p .694 .677 .829 r
F P
0 g
s
.55295 .61153 m .53984 .60478 L .54882 .59445 L p .694 .677 .829 r
F P
0 g
s
.5504 .94145 m .56602 .94852 L .5553 .95918 L p .683 .706 .865 r
F P
0 g
s
.55178 .98545 m .53984 .60478 L .55295 .61153 L p .826 .506 .447 r
F P
0 g
s
.55295 .61153 m .56773 .99254 L .55178 .98545 L p .826 .506 .447 r
F P
0 g
s
.57879 .98176 m .56773 .99254 L .55295 .61153 L p .272 .082 .43 r
F P
0 g
s
.55295 .61153 m .56196 .60126 L .57879 .98176 L p .272 .082 .43 r
F P
0 g
s
.5504 .94145 m .53984 .60478 L .55295 .61153 L p .826 .506 .447 r
F P
0 g
s
.55295 .61153 m .56602 .94852 L .5504 .94145 L p .826 .506 .447 r
F P
0 g
s
.57879 .98176 m .56773 .99254 L .55295 .61153 L p .272 .082 .43 r
F P
0 g
s
.55295 .61153 m .56196 .60126 L .57879 .98176 L p .272 .082 .43 r
F P
0 g
s
.60638 .59421 m .61937 .60102 L .61015 .61129 L p .694 .677 .829 r
F P
0 g
s
.61015 .61129 m .59718 .60453 L .60638 .59421 L p .694 .677 .829 r
F P
0 g
s
.62172 .98519 m .59718 .60453 L .61015 .61129 L p .828 .503 .439 r
F P
0 g
s
.61015 .61129 m .63746 .99228 L .62172 .98519 L p .828 .503 .439 r
F P
0 g
s
.64884 .9815 m .63746 .99228 L .61015 .61129 L p .295 .107 .446 r
F P
0 g
s
.61015 .61129 m .61937 .60102 L .64884 .9815 L p .295 .107 .446 r
F P
0 g
s
.62172 .98519 m .59718 .60453 L .61015 .61129 L p .828 .503 .439 r
F P
0 g
s
.61015 .61129 m .63746 .99228 L .62172 .98519 L p .828 .503 .439 r
F P
0 g
s
.45581 .59141 m .4692 .59823 L .46052 .60852 L p .694 .677 .829 r
F P
0 g
s
.46052 .60852 m .44717 .60175 L .45581 .59141 L p .694 .677 .829 r
F P
0 g
s
.43874 .98227 m .44717 .60175 L .46052 .60852 L p .824 .51 .458 r
F P
0 g
s
.46052 .60852 m .45505 .98938 L .43874 .98227 L p .824 .51 .458 r
F P
0 g
s
.47136 .98157 m .45527 .97451 L .46575 .9637 L p .682 .709 .868 r
F P
0 g
s
.46561 .97857 m .45505 .98938 L .46052 .60852 L p .23 .037 .399 r
F P
0 g
s
.46052 .60852 m .4692 .59823 L .46561 .97857 L p .23 .037 .399 r
F P
0 g
s
.43874 .98227 m .44717 .60175 L .46052 .60852 L p .824 .51 .458 r
F P
0 g
s
.46052 .60852 m .45505 .98938 L .43874 .98227 L p .824 .51 .458 r
F P
0 g
s
.46575 .9637 m .45527 .97451 L .46052 .60852 L p .23 .037 .399 r
F P
0 g
s
.46052 .60852 m .4692 .59823 L .46575 .9637 L p .23 .037 .399 r
F P
0 g
s
.51342 .59116 m .52666 .59798 L .51777 .60828 L p .694 .677 .829 r
F P
0 g
s
.51777 .60828 m .50456 .60151 L .51342 .59116 L p .694 .677 .829 r
F P
0 g
s
.5086 .96714 m .50456 .60151 L .51777 .60828 L p .825 .507 .451 r
F P
0 g
s
.51777 .60828 m .52458 .97425 L .5086 .96714 L p .825 .507 .451 r
F P
0 g
s
.53539 .96345 m .52458 .97425 L .51777 .60828 L p .256 .065 .418 r
F P
0 g
s
.51777 .60828 m .52666 .59798 L .53539 .96345 L p .256 .065 .418 r
F P
0 g
s
.50876 .98201 m .50456 .60151 L .51777 .60828 L p .825 .507 .451 r
F P
0 g
s
.51777 .60828 m .52486 .98913 L .50876 .98201 L p .825 .507 .451 r
F P
0 g
s
.53574 .97831 m .52486 .98913 L .51777 .60828 L p .256 .065 .418 r
F P
0 g
s
.51777 .60828 m .52666 .59798 L .53574 .97831 L p .256 .065 .418 r
F P
0 g
s
.57104 .59091 m .58414 .59774 L .57503 .60804 L p .694 .677 .829 r
F P
0 g
s
.57503 .60804 m .56196 .60126 L .57104 .59091 L p .694 .677 .829 r
F P
0 g
s
.57879 .98176 m .56196 .60126 L .57503 .60804 L p .827 .504 .443 r
F P
0 g
s
.57503 .60804 m .59468 .98887 L .57879 .98176 L p .827 .504 .443 r
F P
0 g
s
.6096 .98106 m .59392 .974 L .60504 .96319 L p .682 .709 .868 r
F P
0 g
s
.60589 .97805 m .59468 .98887 L .57503 .60804 L p .28 .091 .436 r
F P
0 g
s
.57503 .60804 m .58414 .59774 L .60589 .97805 L p .28 .091 .436 r
F P
0 g
s
.57879 .98176 m .56196 .60126 L .57503 .60804 L p .827 .504 .443 r
F P
0 g
s
.57503 .60804 m .59468 .98887 L .57879 .98176 L p .827 .504 .443 r
F P
0 g
s
.60504 .96319 m .59392 .974 L .57503 .60804 L p .28 .091 .436 r
F P
0 g
s
.57503 .60804 m .58414 .59774 L .60504 .96319 L p .28 .091 .436 r
F P
0 g
s
.42026 .58811 m .43375 .59495 L .4252 .60526 L p .694 .677 .829 r
F P
0 g
s
.4252 .60526 m .41174 .59847 L .42026 .58811 L p .694 .677 .829 r
F P
0 g
s
.3955 .97883 m .41174 .59847 L .4252 .60526 L p .823 .511 .462 r
F P
0 g
s
.4252 .60526 m .41196 .98596 L .3955 .97883 L p .823 .511 .462 r
F P
0 g
s
.42234 .97512 m .41196 .98596 L .4252 .60526 L p .211 .017 .385 r
F P
0 g
s
.4252 .60526 m .43375 .59495 L .42234 .97512 L p .211 .017 .385 r
F P
0 g
s
.42234 .97512 m .41196 .98596 L .4252 .60526 L p .211 .017 .385 r
F P
0 g
s
.4252 .60526 m .43375 .59495 L .42234 .97512 L p .211 .017 .385 r
F P
0 g
s
.47794 .58786 m .49128 .5947 L .48251 .60502 L p .694 .677 .829 r
F P
0 g
s
.48251 .60502 m .4692 .59823 L .47794 .58786 L p .694 .677 .829 r
F P
0 g
s
.46589 .94904 m .4692 .59823 L .48251 .60502 L p .825 .508 .454 r
F P
0 g
s
.48251 .60502 m .48191 .95617 L .46589 .94904 L p .825 .508 .454 r
F P
0 g
s
.49246 .94534 m .48191 .95617 L .48251 .60502 L p .239 .047 .406 r
F P
0 g
s
.48251 .60502 m .49128 .5947 L .49246 .94534 L p .239 .047 .406 r
F P
0 g
s
.46575 .9637 m .4692 .59823 L .48251 .60502 L p .825 .508 .454 r
F P
0 g
s
.48251 .60502 m .48189 .97083 L .46575 .9637 L p .825 .508 .454 r
F P
0 g
s
.49246 .94534 m .48191 .95617 L .48251 .60502 L p .239 .047 .406 r
F P
0 g
s
.48251 .60502 m .49128 .5947 L .49246 .94534 L p .239 .047 .406 r
F P
0 g
s
.53562 .58761 m .54882 .59445 L .53984 .60478 L p .694 .677 .829 r
F P
0 g
s
.53984 .60478 m .52666 .59798 L .53562 .58761 L p .694 .677 .829 r
F P
0 g
s
.53435 .92008 m .52666 .59798 L .53984 .60478 L p .826 .506 .447 r
F P
0 g
s
.53984 .60478 m .54996 .92719 L .53435 .92008 L p .826 .506 .447 r
F P
0 g
s
.56067 .91638 m .54996 .92719 L .53984 .60478 L p .264 .074 .424 r
F P
0 g
s
.53984 .60478 m .54882 .59445 L .56067 .91638 L p .264 .074 .424 r
F P
0 g
s
.53574 .97831 m .52666 .59798 L .53984 .60478 L p .826 .506 .447 r
F P
0 g
s
.53984 .60478 m .55178 .98545 L .53574 .97831 L p .826 .506 .447 r
F P
0 g
s
.56281 .9746 m .55178 .98545 L .53984 .60478 L p .264 .074 .424 r
F P
0 g
s
.53984 .60478 m .54882 .59445 L .56281 .9746 L p .264 .074 .424 r
F P
0 g
s
.59332 .58736 m .60638 .59421 L .59718 .60453 L p .694 .677 .829 r
F P
0 g
s
.59718 .60453 m .58414 .59774 L .59332 .58736 L p .694 .677 .829 r
F P
0 g
s
.60504 .96319 m .62076 .97032 L .6096 .98106 L p .682 .709 .868 r
F P
0 g
s
.60589 .97805 m .58414 .59774 L .59718 .60453 L p .828 .503 .439 r
F P
0 g
s
.59718 .60453 m .62172 .98519 L .60589 .97805 L p .828 .503 .439 r
F P
0 g
s
.63307 .97434 m .62172 .98519 L .59718 .60453 L p .288 .099 .441 r
F P
0 g
s
.59718 .60453 m .60638 .59421 L .63307 .97434 L p .288 .099 .441 r
F P
0 g
s
.60504 .96319 m .58414 .59774 L .59718 .60453 L p .828 .503 .439 r
F P
0 g
s
.59718 .60453 m .62076 .97032 L .60504 .96319 L p .828 .503 .439 r
F P
0 g
s
.63307 .97434 m .62172 .98519 L .59718 .60453 L p .288 .099 .441 r
F P
0 g
s
.59718 .60453 m .60638 .59421 L .63307 .97434 L p .288 .099 .441 r
F P
0 g
s
.44237 .58455 m .45581 .59141 L .44717 .60175 L p .694 .677 .829 r
F P
0 g
s
.44717 .60175 m .43375 .59495 L .44237 .58455 L p .694 .677 .829 r
F P
0 g
s
.42278 .96025 m .43375 .59495 L .44717 .60175 L p .824 .51 .458 r
F P
0 g
s
.44717 .60175 m .43907 .9674 L .42278 .96025 L p .824 .51 .458 r
F P
0 g
s
.44952 .95653 m .43907 .9674 L .44717 .60175 L p .22 .027 .392 r
F P
0 g
s
.44717 .60175 m .45581 .59141 L .44952 .95653 L p .22 .027 .392 r
F P
0 g
s
.42234 .97512 m .43375 .59495 L .44717 .60175 L p .824 .51 .458 r
F P
0 g
s
.44717 .60175 m .43874 .98227 L .42234 .97512 L p .824 .51 .458 r
F P
0 g
s
.44926 .97139 m .43874 .98227 L .44717 .60175 L p .22 .027 .392 r
F P
0 g
s
.44717 .60175 m .45581 .59141 L .44926 .97139 L p .22 .027 .392 r
F P
0 g
s
.50012 .5843 m .51342 .59116 L .50456 .60151 L p .694 .677 .829 r
F P
0 g
s
.50456 .60151 m .49128 .5947 L .50012 .5843 L p .694 .677 .829 r
F P
0 g
s
.49246 .94534 m .49128 .5947 L .50456 .60151 L p .825 .507 .451 r
F P
0 g
s
.50456 .60151 m .50843 .95248 L .49246 .94534 L p .825 .507 .451 r
F P
0 g
s
.51912 .94162 m .50843 .95248 L .50456 .60151 L p .248 .056 .412 r
F P
0 g
s
.50456 .60151 m .51342 .59116 L .51912 .94162 L p .248 .056 .412 r
F P
0 g
s
.49246 .94534 m .49128 .5947 L .50456 .60151 L p .825 .507 .451 r
F P
0 g
s
.50456 .60151 m .50843 .95248 L .49246 .94534 L p .825 .507 .451 r
F P
0 g
s
.51936 .95627 m .5086 .96714 L .50456 .60151 L p .248 .056 .412 r
F P
0 g
s
.50456 .60151 m .51342 .59116 L .51936 .95627 L p .248 .056 .412 r
F P
0 g
s
.55788 .58405 m .57104 .59091 L .56196 .60126 L p .694 .677 .829 r
F P
0 g
s
.56196 .60126 m .54882 .59445 L .55788 .58405 L p .694 .677 .829 r
F P
0 g
s
.56226 .95974 m .54882 .59445 L .56196 .60126 L p .827 .504 .443 r
F P
0 g
s
.56196 .60126 m .57814 .96689 L .56226 .95974 L p .827 .504 .443 r
F P
0 g
s
.58922 .95601 m .57814 .96689 L .56196 .60126 L p .272 .082 .43 r
F P
0 g
s
.56196 .60126 m .57104 .59091 L .58922 .95601 L p .272 .082 .43 r
F P
0 g
s
.56281 .9746 m .54882 .59445 L .56196 .60126 L p .827 .504 .443 r
F P
0 g
s
.56196 .60126 m .57879 .98176 L .56281 .9746 L p .827 .504 .443 r
F P
0 g
s
.58996 .97087 m .57879 .98176 L .56196 .60126 L p .272 .082 .43 r
F P
0 g
s
.56196 .60126 m .57104 .59091 L .58996 .97087 L p .272 .082 .43 r
F P
0 g
s
.61565 .58381 m .62867 .59067 L .61937 .60102 L p .694 .677 .829 r
F P
0 g
s
.61937 .60102 m .60638 .59421 L .61565 .58381 L p .694 .677 .829 r
F P
0 g
s
.63307 .97434 m .60638 .59421 L .61937 .60102 L p .828 .501 .435 r
F P
0 g
s
.61937 .60102 m .64884 .9815 L .63307 .97434 L p .828 .501 .435 r
F P
0 g
s
.66033 .97061 m .64884 .9815 L .61937 .60102 L p .295 .107 .446 r
F P
0 g
s
.61937 .60102 m .62867 .59067 L .66033 .97061 L p .295 .107 .446 r
F P
0 g
s
.63307 .97434 m .60638 .59421 L .61937 .60102 L p .828 .501 .435 r
F P
0 g
s
.61937 .60102 m .64884 .9815 L .63307 .97434 L p .828 .501 .435 r
F P
0 g
s
.40671 .58123 m .42026 .58811 L .41174 .59847 L p .694 .677 .829 r
F P
0 g
s
.41174 .59847 m .39822 .59165 L .40671 .58123 L p .694 .677 .829 r
F P
0 g
s
.37893 .97165 m .39822 .59165 L .41174 .59847 L p .823 .511 .462 r
F P
0 g
s
.41174 .59847 m .3955 .97883 L .37893 .97165 L p .823 .511 .462 r
F P
0 g
s
.40583 .96792 m .3955 .97883 L .41174 .59847 L p .201 .006 .378 r
F P
0 g
s
.41174 .59847 m .42026 .58811 L .40583 .96792 L p .201 .006 .378 r
F P
0 g
s
.40583 .96792 m .3955 .97883 L .41174 .59847 L p .201 .006 .378 r
F P
0 g
s
.41174 .59847 m .42026 .58811 L .40583 .96792 L p .201 .006 .378 r
F P
0 g
s
.46453 .58098 m .47794 .58786 L .4692 .59823 L p .694 .677 .829 r
F P
0 g
s
.4692 .59823 m .45581 .59141 L .46453 .58098 L p .694 .677 .829 r
F P
0 g
s
.44926 .97139 m .45581 .59141 L .4692 .59823 L p .825 .508 .454 r
F P
0 g
s
.4692 .59823 m .46561 .97857 L .44926 .97139 L p .825 .508 .454 r
F P
0 g
s
.48191 .95617 m .46589 .94904 L .4764 .93815 L p .683 .708 .867 r
F P
0 g
s
.46575 .9637 m .48189 .97083 L .47136 .98157 L p .682 .709 .868 r
F P
0 g
s
.47627 .96766 m .46561 .97857 L .4692 .59823 L p .23 .037 .399 r
F P
0 g
s
.4692 .59823 m .47794 .58786 L .47627 .96766 L p .23 .037 .399 r
F P
0 g
s
.44926 .97139 m .45581 .59141 L .4692 .59823 L p .825 .508 .454 r
F P
0 g
s
.4692 .59823 m .46561 .97857 L .44926 .97139 L p .825 .508 .454 r
F P
0 g
s
.4764 .93815 m .46589 .94904 L .4692 .59823 L p .23 .037 .399 r
F P
0 g
s
.4692 .59823 m .47794 .58786 L .4764 .93815 L p .23 .037 .399 r
F P
0 g
s
.52235 .58074 m .53562 .58761 L .52666 .59798 L p .694 .677 .829 r
F P
0 g
s
.52666 .59798 m .51342 .59116 L .52235 .58074 L p .694 .677 .829 r
F P
0 g
s
.51865 .91293 m .51342 .59116 L .52666 .59798 L p .826 .506 .447 r
F P
0 g
s
.52666 .59798 m .53435 .92008 L .51865 .91293 L p .826 .506 .447 r
F P
0 g
s
.54502 .90921 m .53435 .92008 L .52666 .59798 L p .256 .065 .418 r
F P
0 g
s
.52666 .59798 m .53562 .58761 L .54502 .90921 L p .256 .065 .418 r
F P
0 g
s
.51936 .95627 m .51342 .59116 L .52666 .59798 L p .826 .506 .447 r
F P
0 g
s
.52666 .59798 m .53539 .96345 L .51936 .95627 L p .826 .506 .447 r
F P
0 g
s
.54502 .90921 m .53435 .92008 L .52666 .59798 L p .256 .065 .418 r
F P
0 g
s
.52666 .59798 m .53562 .58761 L .54502 .90921 L p .256 .065 .418 r
F P
0 g
s
.58019 .58049 m .59332 .58736 L .58414 .59774 L p .694 .677 .829 r
F P
0 g
s
.58414 .59774 m .57104 .59091 L .58019 .58049 L p .694 .677 .829 r
F P
0 g
s
.58849 .94136 m .57104 .59091 L .58414 .59774 L p .828 .503 .439 r
F P
0 g
s
.58414 .59774 m .6042 .94853 L .58849 .94136 L p .828 .503 .439 r
F P
0 g
s
.61534 .93763 m .6042 .94853 L .58414 .59774 L p .28 .091 .436 r
F P
0 g
s
.58414 .59774 m .59332 .58736 L .61534 .93763 L p .28 .091 .436 r
F P
0 g
s
.58996 .97087 m .57104 .59091 L .58414 .59774 L p .828 .503 .439 r
F P
0 g
s
.58414 .59774 m .60589 .97805 L .58996 .97087 L p .828 .503 .439 r
F P
0 g
s
.61719 .96714 m .60589 .97805 L .58414 .59774 L p .28 .091 .436 r
F P
0 g
s
.58414 .59774 m .59332 .58736 L .61719 .96714 L p .28 .091 .436 r
F P
0 g
s
.42885 .57766 m .44237 .58455 L .43375 .59495 L p .694 .677 .829 r
F P
0 g
s
.43375 .59495 m .42026 .58811 L .42885 .57766 L p .694 .677 .829 r
F P
0 g
s
.40583 .96792 m .42026 .58811 L .43375 .59495 L p .824 .51 .458 r
F P
0 g
s
.43375 .59495 m .42234 .97512 L .40583 .96792 L p .824 .51 .458 r
F P
0 g
s
.43907 .9674 m .42278 .96025 L .43318 .94932 L p .682 .709 .868 r
F P
0 g
s
.43281 .96417 m .42234 .97512 L .43375 .59495 L p .211 .017 .385 r
F P
0 g
s
.43375 .59495 m .44237 .58455 L .43281 .96417 L p .211 .017 .385 r
F P
0 g
s
.40583 .96792 m .42026 .58811 L .43375 .59495 L p .824 .51 .458 r
F P
0 g
s
.43375 .59495 m .42234 .97512 L .40583 .96792 L p .824 .51 .458 r
F P
0 g
s
.43318 .94932 m .42278 .96025 L .43375 .59495 L p .211 .017 .385 r
F P
0 g
s
.43375 .59495 m .44237 .58455 L .43318 .94932 L p .211 .017 .385 r
F P
0 g
s
.48674 .57741 m .50012 .5843 L .49128 .5947 L p .694 .677 .829 r
F P
0 g
s
.49128 .5947 m .47794 .58786 L .48674 .57741 L p .694 .677 .829 r
F P
0 g
s
.47646 .92371 m .47794 .58786 L .49128 .5947 L p .825 .507 .451 r
F P
0 g
s
.49128 .5947 m .49242 .93089 L .47646 .92371 L p .825 .507 .451 r
F P
0 g
s
.50299 .91997 m .49242 .93089 L .49128 .5947 L p .239 .047 .406 r
F P
0 g
s
.49128 .5947 m .50012 .5843 L .50299 .91997 L p .239 .047 .406 r
F P
0 g
s
.4764 .93815 m .47794 .58786 L .49128 .5947 L p .825 .507 .451 r
F P
0 g
s
.49128 .5947 m .49246 .94534 L .4764 .93815 L p .825 .507 .451 r
F P
0 g
s
.50311 .93441 m .49246 .94534 L .49128 .5947 L p .239 .047 .406 r
F P
0 g
s
.49128 .5947 m .50012 .5843 L .50311 .93441 L p .239 .047 .406 r
F P
0 g
s
.54465 .57716 m .55788 .58405 L .54882 .59445 L p .694 .677 .829 r
F P
0 g
s
.54882 .59445 m .53562 .58761 L .54465 .57716 L p .694 .677 .829 r
F P
0 g
s
.54502 .90921 m .53562 .58761 L .54882 .59445 L p .827 .504 .443 r
F P
0 g
s
.54882 .59445 m .56067 .91638 L .54502 .90921 L p .827 .504 .443 r
F P
0 g
s
.57147 .90547 m .56067 .91638 L .54882 .59445 L p .264 .074 .424 r
F P
0 g
s
.54882 .59445 m .55788 .58405 L .57147 .90547 L p .264 .074 .424 r
F P
0 g
s
.54502 .90921 m .53562 .58761 L .54882 .59445 L p .827 .504 .443 r
F P
0 g
s
.54882 .59445 m .56067 .91638 L .54502 .90921 L p .827 .504 .443 r
F P
0 g
s
.5733 .9488 m .56226 .95974 L .54882 .59445 L p .264 .074 .424 r
F P
0 g
s
.54882 .59445 m .55788 .58405 L .5733 .9488 L p .264 .074 .424 r
F P
0 g
s
.60256 .57691 m .61565 .58381 L .60638 .59421 L p .694 .677 .829 r
F P
0 g
s
.60638 .59421 m .59332 .58736 L .60256 .57691 L p .694 .677 .829 r
F P
0 g
s
.61626 .95228 m .59332 .58736 L .60638 .59421 L p .828 .501 .435 r
F P
0 g
s
.60638 .59421 m .63202 .95948 L .61626 .95228 L p .828 .501 .435 r
F P
0 g
s
.64339 .94854 m .63202 .95948 L .60638 .59421 L p .288 .099 .441 r
F P
0 g
s
.60638 .59421 m .61565 .58381 L .64339 .94854 L p .288 .099 .441 r
F P
0 g
s
.61719 .96714 m .59332 .58736 L .60638 .59421 L p .828 .501 .435 r
F P
0 g
s
.60638 .59421 m .63307 .97434 L .61719 .96714 L p .828 .501 .435 r
F P
0 g
s
.64452 .96339 m .63307 .97434 L .60638 .59421 L p .288 .099 .441 r
F P
0 g
s
.60638 .59421 m .61565 .58381 L .64452 .96339 L p .288 .099 .441 r
F P
0 g
s
.39309 .57432 m .40671 .58123 L .39822 .59165 L p .694 .677 .829 r
F P
0 g
s
.39822 .59165 m .38463 .5848 L .39309 .57432 L p .694 .677 .829 r
F P
0 g
s
.36227 .96443 m .38463 .5848 L .39822 .59165 L p .823 .511 .462 r
F P
0 g
s
.39822 .59165 m .37893 .97165 L .36227 .96443 L p .823 .511 .462 r
F P
0 g
s
.38922 .96068 m .37893 .97165 L .39822 .59165 L p .19 0 .37 r
F P
0 g
s
.39822 .59165 m .40671 .58123 L .38922 .96068 L p .19 0 .37 r
F P
0 g
s
.38922 .96068 m .37893 .97165 L .39822 .59165 L p .19 0 .37 r
F P
0 g
s
.39822 .59165 m .40671 .58123 L .38922 .96068 L p .19 0 .37 r
F P
0 g
s
.45105 .57407 m .46453 .58098 L .45581 .59141 L p .694 .677 .829 r
F P
0 g
s
.45581 .59141 m .44237 .58455 L .45105 .57407 L p .694 .677 .829 r
F P
0 g
s
.43318 .94932 m .44952 .95653 L .43907 .9674 L p .682 .709 .868 r
F P
0 g
s
.43281 .96417 m .44237 .58455 L .45581 .59141 L p .825 .508 .454 r
F P
0 g
s
.45581 .59141 m .44926 .97139 L .43281 .96417 L p .825 .508 .454 r
F P
0 g
s
.45987 .96041 m .44926 .97139 L .45581 .59141 L p .22 .027 .392 r
F P
0 g
s
.45581 .59141 m .46453 .58098 L .45987 .96041 L p .22 .027 .392 r
F P
0 g
s
.43318 .94932 m .44237 .58455 L .45581 .59141 L p .825 .508 .454 r
F P
0 g
s
.45581 .59141 m .44952 .95653 L .43318 .94932 L p .825 .508 .454 r
F P
0 g
s
.45987 .96041 m .44926 .97139 L .45581 .59141 L p .22 .027 .392 r
F P
0 g
s
.45581 .59141 m .46453 .58098 L .45987 .96041 L p .22 .027 .392 r
F P
0 g
s
.50902 .57383 m .52235 .58074 L .51342 .59116 L p .694 .677 .829 r
F P
0 g
s
.51342 .59116 m .50012 .5843 L .50902 .57383 L p .694 .677 .829 r
F P
0 g
s
.50287 .90573 m .50012 .5843 L .51342 .59116 L p .826 .506 .447 r
F P
0 g
s
.51342 .59116 m .51865 .91293 L .50287 .90573 L p .826 .506 .447 r
F P
0 g
s
.52929 .90199 m .51865 .91293 L .51342 .59116 L p .248 .056 .412 r
F P
0 g
s
.51342 .59116 m .52235 .58074 L .52929 .90199 L p .248 .056 .412 r
F P
0 g
s
.50311 .93441 m .50012 .5843 L .51342 .59116 L p .826 .506 .447 r
F P
0 g
s
.51342 .59116 m .51912 .94162 L .50311 .93441 L p .826 .506 .447 r
F P
0 g
s
.52929 .90199 m .51865 .91293 L .51342 .59116 L p .248 .056 .412 r
F P
0 g
s
.51342 .59116 m .52235 .58074 L .52929 .90199 L p .248 .056 .412 r
F P
0 g
s
.567 .57358 m .58019 .58049 L .57104 .59091 L p .694 .677 .829 r
F P
0 g
s
.57104 .59091 m .55788 .58405 L .567 .57358 L p .694 .677 .829 r
F P
0 g
s
.57268 .93415 m .55788 .58405 L .57104 .59091 L p .828 .503 .439 r
F P
0 g
s
.57104 .59091 m .58849 .94136 L .57268 .93415 L p .828 .503 .439 r
F P
0 g
s
.59959 .9304 m .58849 .94136 L .57104 .59091 L p .272 .082 .43 r
F P
0 g
s
.57104 .59091 m .58019 .58049 L .59959 .9304 L p .272 .082 .43 r
F P
0 g
s
.5733 .9488 m .55788 .58405 L .57104 .59091 L p .828 .503 .439 r
F P
0 g
s
.57104 .59091 m .58922 .95601 L .5733 .9488 L p .828 .503 .439 r
F P
0 g
s
.59959 .9304 m .58849 .94136 L .57104 .59091 L p .272 .082 .43 r
F P
0 g
s
.57104 .59091 m .58019 .58049 L .59959 .9304 L p .272 .082 .43 r
F P
0 g
s
.62499 .57333 m .63804 .58024 L .62867 .59067 L p .694 .677 .829 r
F P
0 g
s
.62867 .59067 m .61565 .58381 L .62499 .57333 L p .694 .677 .829 r
F P
0 g
s
.64452 .96339 m .61565 .58381 L .62867 .59067 L p .829 .499 .43 r
F P
0 g
s
.62867 .59067 m .66033 .97061 L .64452 .96339 L p .829 .499 .43 r
F P
0 g
s
.67192 .95963 m .66033 .97061 L .62867 .59067 L p .295 .107 .446 r
F P
0 g
s
.62867 .59067 m .63804 .58024 L .67192 .95963 L p .295 .107 .446 r
F P
0 g
s
.64452 .96339 m .61565 .58381 L .62867 .59067 L p .829 .499 .43 r
F P
0 g
s
.62867 .59067 m .66033 .97061 L .64452 .96339 L p .829 .499 .43 r
F P
0 g
s
.41526 .57073 m .42885 .57766 L .42026 .58811 L p .694 .677 .829 r
F P
0 g
s
.42026 .58811 m .40671 .58123 L .41526 .57073 L p .694 .677 .829 r
F P
0 g
s
.38991 .94582 m .40671 .58123 L .42026 .58811 L p .824 .51 .458 r
F P
0 g
s
.42026 .58811 m .40639 .95306 L .38991 .94582 L p .824 .51 .458 r
F P
0 g
s
.41675 .94206 m .40639 .95306 L .42026 .58811 L p .201 .006 .378 r
F P
0 g
s
.42026 .58811 m .42885 .57766 L .41675 .94206 L p .201 .006 .378 r
F P
0 g
s
.38922 .96068 m .40671 .58123 L .42026 .58811 L p .824 .51 .458 r
F P
0 g
s
.42026 .58811 m .40583 .96792 L .38922 .96068 L p .824 .51 .458 r
F P
0 g
s
.41626 .95691 m .40583 .96792 L .42026 .58811 L p .201 .006 .378 r
F P
0 g
s
.42026 .58811 m .42885 .57766 L .41626 .95691 L p .201 .006 .378 r
F P
0 g
s
.4733 .57048 m .48674 .57741 L .47794 .58786 L p .694 .677 .829 r
F P
0 g
s
.47794 .58786 m .46453 .58098 L .4733 .57048 L p .694 .677 .829 r
F P
0 g
s
.45987 .96041 m .46453 .58098 L .47794 .58786 L p .825 .507 .451 r
F P
0 g
s
.47794 .58786 m .47627 .96766 L .45987 .96041 L p .825 .507 .451 r
F P
0 g
s
.49784 .96325 m .48191 .95617 L .49246 .94534 L p .683 .708 .867 r
F P
0 g
s
.49242 .93089 m .47646 .92371 L .48699 .91273 L p .683 .706 .865 r
F P
0 g
s
.4764 .93815 m .49246 .94534 L .48191 .95617 L p .683 .708 .867 r
F P
0 g
s
.48703 .95664 m .47627 .96766 L .47794 .58786 L p .23 .037 .399 r
F P
0 g
s
.47794 .58786 m .48674 .57741 L .48703 .95664 L p .23 .037 .399 r
F P
0 g
s
.45987 .96041 m .46453 .58098 L .47794 .58786 L p .825 .507 .451 r
F P
0 g
s
.47794 .58786 m .47627 .96766 L .45987 .96041 L p .825 .507 .451 r
F P
0 g
s
.48699 .91273 m .47646 .92371 L .47794 .58786 L p .23 .037 .399 r
F P
0 g
s
.47794 .58786 m .48674 .57741 L .48699 .91273 L p .23 .037 .399 r
F P
0 g
s
.53135 .57023 m .54465 .57716 L .53562 .58761 L p .694 .677 .829 r
F P
0 g
s
.53562 .58761 m .52235 .58074 L .53135 .57023 L p .694 .677 .829 r
F P
0 g
s
.52898 .88795 m .52235 .58074 L .53562 .58761 L p .827 .504 .443 r
F P
0 g
s
.53562 .58761 m .54461 .89516 L .52898 .88795 L p .827 .504 .443 r
F P
0 g
s
.5553 .8842 m .54461 .89516 L .53562 .58761 L p .256 .065 .418 r
F P
0 g
s
.53562 .58761 m .54465 .57716 L .5553 .8842 L p .256 .065 .418 r
F P
0 g
s
.52929 .90199 m .52235 .58074 L .53562 .58761 L p .827 .504 .443 r
F P
0 g
s
.53562 .58761 m .54502 .90921 L .52929 .90199 L p .827 .504 .443 r
F P
0 g
s
.55579 .89824 m .54502 .90921 L .53562 .58761 L p .256 .065 .418 r
F P
0 g
s
.53562 .58761 m .54465 .57716 L .55579 .89824 L p .256 .065 .418 r
F P
0 g
s
.58941 .56998 m .60256 .57691 L .59332 .58736 L p .694 .677 .829 r
F P
0 g
s
.59332 .58736 m .58019 .58049 L .58941 .56998 L p .694 .677 .829 r
F P
0 g
s
.59959 .9304 m .58019 .58049 L .59332 .58736 L p .828 .501 .435 r
F P
0 g
s
.59332 .58736 m .61534 .93763 L .59959 .9304 L p .828 .501 .435 r
F P
0 g
s
.62658 .92664 m .61534 .93763 L .59332 .58736 L p .28 .091 .436 r
F P
0 g
s
.59332 .58736 m .60256 .57691 L .62658 .92664 L p .28 .091 .436 r
F P
0 g
s
.59959 .9304 m .58019 .58049 L .59332 .58736 L p .828 .501 .435 r
F P
0 g
s
.59332 .58736 m .61534 .93763 L .59959 .9304 L p .828 .501 .435 r
F P
0 g
s
.62759 .94127 m .61626 .95228 L .59332 .58736 L p .28 .091 .436 r
F P
0 g
s
.59332 .58736 m .60256 .57691 L .62759 .94127 L p .28 .091 .436 r
F P
0 g
s
.3794 .56738 m .39309 .57432 L .38463 .5848 L p .694 .677 .829 r
F P
0 g
s
.38463 .5848 m .37097 .57791 L .3794 .56738 L p .694 .677 .829 r
F P
0 g
s
.34551 .95717 m .37097 .57791 L .38463 .5848 L p .823 .511 .462 r
F P
0 g
s
.38463 .5848 m .36227 .96443 L .34551 .95717 L p .823 .511 .462 r
F P
0 g
s
.37251 .95339 m .36227 .96443 L .38463 .5848 L p .18 0 .362 r
F P
0 g
s
.38463 .5848 m .39309 .57432 L .37251 .95339 L p .18 0 .362 r
F P
0 g
s
.37251 .95339 m .36227 .96443 L .38463 .5848 L p .18 0 .362 r
F P
0 g
s
.38463 .5848 m .39309 .57432 L .37251 .95339 L p .18 0 .362 r
F P
0 g
s
.4375 .56713 m .45105 .57407 L .44237 .58455 L p .694 .677 .829 r
F P
0 g
s
.44237 .58455 m .42885 .57766 L .4375 .56713 L p .694 .677 .829 r
F P
0 g
s
.41724 .92742 m .42885 .57766 L .44237 .58455 L p .825 .508 .454 r
F P
0 g
s
.44237 .58455 m .43355 .93467 L .41724 .92742 L p .825 .508 .454 r
F P
0 g
s
.44398 .92365 m .43355 .93467 L .44237 .58455 L p .211 .017 .385 r
F P
0 g
s
.44237 .58455 m .45105 .57407 L .44398 .92365 L p .211 .017 .385 r
F P
0 g
s
.41626 .95691 m .42885 .57766 L .44237 .58455 L p .825 .508 .454 r
F P
0 g
s
.44237 .58455 m .43281 .96417 L .41626 .95691 L p .825 .508 .454 r
F P
0 g
s
.44338 .95313 m .43281 .96417 L .44237 .58455 L p .211 .017 .385 r
F P
0 g
s
.44237 .58455 m .45105 .57407 L .44338 .95313 L p .211 .017 .385 r
F P
0 g
s
.49561 .56688 m .50902 .57383 L .50012 .5843 L p .694 .677 .829 r
F P
0 g
s
.50012 .5843 m .48674 .57741 L .49561 .56688 L p .694 .677 .829 r
F P
0 g
s
.48698 .8985 m .48674 .57741 L .50012 .5843 L p .826 .506 .447 r
F P
0 g
s
.50012 .5843 m .50287 .90573 L .48698 .8985 L p .826 .506 .447 r
F P
0 g
s
.51346 .89473 m .50287 .90573 L .50012 .5843 L p .239 .047 .406 r
F P
0 g
s
.50012 .5843 m .50902 .57383 L .51346 .89473 L p .239 .047 .406 r
F P
0 g
s
.48699 .91273 m .48674 .57741 L .50012 .5843 L p .826 .506 .447 r
F P
0 g
s
.50012 .5843 m .50299 .91997 L .48699 .91273 L p .826 .506 .447 r
F P
0 g
s
.51346 .89473 m .50287 .90573 L .50012 .5843 L p .239 .047 .406 r
F P
0 g
s
.50012 .5843 m .50902 .57383 L .51346 .89473 L p .239 .047 .406 r
F P
0 g
s
.55374 .56663 m .567 .57358 L .55788 .58405 L p .694 .677 .829 r
F P
0 g
s
.55788 .58405 m .54465 .57716 L .55374 .56663 L p .694 .677 .829 r
F P
0 g
s
.55579 .89824 m .54465 .57716 L .55788 .58405 L p .828 .503 .439 r
F P
0 g
s
.55788 .58405 m .57147 .90547 L .55579 .89824 L p .828 .503 .439 r
F P
0 g
s
.58237 .89447 m .57147 .90547 L .55788 .58405 L p .264 .074 .424 r
F P
0 g
s
.55788 .58405 m .567 .57358 L .58237 .89447 L p .264 .074 .424 r
F P
0 g
s
.55579 .89824 m .54465 .57716 L .55788 .58405 L p .828 .503 .439 r
F P
0 g
s
.55788 .58405 m .57147 .90547 L .55579 .89824 L p .828 .503 .439 r
F P
0 g
s
.58375 .92312 m .57268 .93415 L .55788 .58405 L p .264 .074 .424 r
F P
0 g
s
.55788 .58405 m .567 .57358 L .58375 .92312 L p .264 .074 .424 r
F P
0 g
s
.61188 .56638 m .62499 .57333 L .61565 .58381 L p .694 .677 .829 r
F P
0 g
s
.61565 .58381 m .60256 .57691 L .61188 .56638 L p .694 .677 .829 r
F P
0 g
s
.62759 .94127 m .64339 .94854 L .63202 .95948 L p .682 .709 .868 r
F P
0 g
s
.63202 .95948 m .61626 .95228 L .62759 .94127 L p .682 .709 .868 r
F P
0 g
s
.62861 .95612 m .60256 .57691 L .61565 .58381 L p .829 .499 .43 r
F P
0 g
s
.61565 .58381 m .64452 .96339 L .62861 .95612 L p .829 .499 .43 r
F P
0 g
s
.65607 .95234 m .64452 .96339 L .61565 .58381 L p .288 .099 .441 r
F P
0 g
s
.61565 .58381 m .62499 .57333 L .65607 .95234 L p .288 .099 .441 r
F P
0 g
s
.62759 .94127 m .60256 .57691 L .61565 .58381 L p .829 .499 .43 r
F P
0 g
s
.61565 .58381 m .64339 .94854 L .62759 .94127 L p .829 .499 .43 r
F P
0 g
s
.65607 .95234 m .64452 .96339 L .61565 .58381 L p .288 .099 .441 r
F P
0 g
s
.61565 .58381 m .62499 .57333 L .65607 .95234 L p .288 .099 .441 r
F P
0 g
s
.40161 .56377 m .41526 .57073 L .40671 .58123 L p .694 .677 .829 r
F P
0 g
s
.40671 .58123 m .39309 .57432 L .40161 .56377 L p .694 .677 .829 r
F P
0 g
s
.37251 .95339 m .39309 .57432 L .40671 .58123 L p .824 .51 .458 r
F P
0 g
s
.40671 .58123 m .38922 .96068 L .37251 .95339 L p .824 .51 .458 r
F P
0 g
s
.40639 .95306 m .38991 .94582 L .40022 .93476 L p .682 .709 .868 r
F P
0 g
s
.39961 .9496 m .38922 .96068 L .40671 .58123 L p .19 0 .37 r
F P
0 g
s
.40671 .58123 m .41526 .57073 L .39961 .9496 L p .19 0 .37 r
F P
0 g
s
.37251 .95339 m .39309 .57432 L .40671 .58123 L p .824 .51 .458 r
F P
0 g
s
.40671 .58123 m .38922 .96068 L .37251 .95339 L p .824 .51 .458 r
F P
0 g
s
.40022 .93476 m .38991 .94582 L .40671 .58123 L p .19 0 .37 r
F P
0 g
s
.40671 .58123 m .41526 .57073 L .40022 .93476 L p .19 0 .37 r
F P
0 g
s
.45979 .56352 m .4733 .57048 L .46453 .58098 L p .694 .677 .829 r
F P
0 g
s
.46453 .58098 m .45105 .57407 L .45979 .56352 L p .694 .677 .829 r
F P
0 g
s
.44368 .93828 m .45105 .57407 L .46453 .58098 L p .825 .507 .451 r
F P
0 g
s
.46453 .58098 m .46006 .94556 L .44368 .93828 L p .825 .507 .451 r
F P
0 g
s
.47069 .93449 m .46006 .94556 L .46453 .58098 L p .22 .027 .392 r
F P
0 g
s
.46453 .58098 m .4733 .57048 L .47069 .93449 L p .22 .027 .392 r
F P
0 g
s
.44338 .95313 m .45105 .57407 L .46453 .58098 L p .825 .507 .451 r
F P
0 g
s
.46453 .58098 m .45987 .96041 L .44338 .95313 L p .825 .507 .451 r
F P
0 g
s
.47059 .94933 m .45987 .96041 L .46453 .58098 L p .22 .027 .392 r
F P
0 g
s
.46453 .58098 m .4733 .57048 L .47059 .94933 L p .22 .027 .392 r
F P
0 g
s
.51799 .56327 m .53135 .57023 L .52235 .58074 L p .694 .677 .829 r
F P
0 g
s
.52235 .58074 m .50902 .57383 L .51799 .56327 L p .694 .677 .829 r
F P
0 g
s
.51346 .89473 m .50902 .57383 L .52235 .58074 L p .827 .504 .443 r
F P
0 g
s
.52235 .58074 m .52929 .90199 L .51346 .89473 L p .827 .504 .443 r
F P
0 g
s
.54461 .89516 m .52898 .88795 L .53964 .87693 L p .685 .704 .862 r
F P
0 g
s
.54001 .89095 m .52929 .90199 L .52235 .58074 L p .248 .056 .412 r
F P
0 g
s
.52235 .58074 m .53135 .57023 L .54001 .89095 L p .248 .056 .412 r
F P
0 g
s
.51346 .89473 m .50902 .57383 L .52235 .58074 L p .827 .504 .443 r
F P
0 g
s
.52235 .58074 m .52929 .90199 L .51346 .89473 L p .827 .504 .443 r
F P
0 g
s
.53964 .87693 m .52898 .88795 L .52235 .58074 L p .248 .056 .412 r
F P
0 g
s
.52235 .58074 m .53135 .57023 L .53964 .87693 L p .248 .056 .412 r
F P
0 g
s
.57619 .56302 m .58941 .56998 L .58019 .58049 L p .694 .677 .829 r
F P
0 g
s
.58019 .58049 m .567 .57358 L .57619 .56302 L p .694 .677 .829 r
F P
0 g
s
.58306 .9087 m .567 .57358 L .58019 .58049 L p .828 .501 .435 r
F P
0 g
s
.58019 .58049 m .59879 .91596 L .58306 .9087 L p .828 .501 .435 r
F P
0 g
s
.60991 .90491 m .59879 .91596 L .58019 .58049 L p .272 .082 .43 r
F P
0 g
s
.58019 .58049 m .58941 .56998 L .60991 .90491 L p .272 .082 .43 r
F P
0 g
s
.58375 .92312 m .567 .57358 L .58019 .58049 L p .828 .501 .435 r
F P
0 g
s
.58019 .58049 m .59959 .9304 L .58375 .92312 L p .828 .501 .435 r
F P
0 g
s
.61079 .91934 m .59959 .9304 L .58019 .58049 L p .272 .082 .43 r
F P
0 g
s
.58019 .58049 m .58941 .56998 L .61079 .91934 L p .272 .082 .43 r
F P
0 g
s
.6344 .56277 m .64748 .56973 L .63804 .58024 L p .694 .677 .829 r
F P
0 g
s
.63804 .58024 m .62499 .57333 L .6344 .56277 L p .694 .677 .829 r
F P
0 g
s
.65607 .95234 m .62499 .57333 L .63804 .58024 L p .83 .498 .426 r
F P
0 g
s
.63804 .58024 m .67192 .95963 L .65607 .95234 L p .83 .498 .426 r
F P
0 g
s
.68363 .94854 m .67192 .95963 L .63804 .58024 L p .295 .107 .446 r
F P
0 g
s
.63804 .58024 m .64748 .56973 L .68363 .94854 L p .295 .107 .446 r
F P
0 g
s
.65607 .95234 m .62499 .57333 L .63804 .58024 L p .83 .498 .426 r
F P
0 g
s
.63804 .58024 m .67192 .95963 L .65607 .95234 L p .83 .498 .426 r
F P
0 g
s
.36564 .5604 m .3794 .56738 L .37097 .57791 L p .694 .677 .829 r
F P
0 g
s
.37097 .57791 m .35724 .57098 L .36564 .5604 L p .694 .677 .829 r
F P
0 g
s
.32864 .94986 m .35724 .57098 L .37097 .57791 L p .823 .511 .462 r
F P
0 g
s
.37097 .57791 m .34551 .95717 L .32864 .94986 L p .823 .511 .462 r
F P
0 g
s
.3557 .94606 m .34551 .95717 L .37097 .57791 L p .169 0 .354 r
F P
0 g
s
.37097 .57791 m .3794 .56738 L .3557 .94606 L p .169 0 .354 r
F P
0 g
s
.3557 .94606 m .34551 .95717 L .37097 .57791 L p .169 0 .354 r
F P
0 g
s
.37097 .57791 m .3794 .56738 L .3557 .94606 L p .169 0 .354 r
F P
0 g
s
.42389 .56015 m .4375 .56713 L .42885 .57766 L p .694 .677 .829 r
F P
0 g
s
.42885 .57766 m .41526 .57073 L .42389 .56015 L p .694 .677 .829 r
F P
0 g
s
.40082 .92013 m .41526 .57073 L .42885 .57766 L p .825 .508 .454 r
F P
0 g
s
.42885 .57766 m .41724 .92742 L .40082 .92013 L p .825 .508 .454 r
F P
0 g
s
.42762 .91633 m .41724 .92742 L .42885 .57766 L p .201 .006 .378 r
F P
0 g
s
.42885 .57766 m .4375 .56713 L .42762 .91633 L p .201 .006 .378 r
F P
0 g
s
.40022 .93476 m .41526 .57073 L .42885 .57766 L p .825 .508 .454 r
F P
0 g
s
.42885 .57766 m .41675 .94206 L .40022 .93476 L p .825 .508 .454 r
F P
0 g
s
.42762 .91633 m .41724 .92742 L .42885 .57766 L p .201 .006 .378 r
F P
0 g
s
.42885 .57766 m .4375 .56713 L .42762 .91633 L p .201 .006 .378 r
F P
0 g
s
.48215 .5599 m .49561 .56688 L .48674 .57741 L p .694 .677 .829 r
F P
0 g
s
.48674 .57741 m .4733 .57048 L .48215 .5599 L p .694 .677 .829 r
F P
0 g
s
.47059 .94933 m .4733 .57048 L .48674 .57741 L p .826 .506 .447 r
F P
0 g
s
.48674 .57741 m .48703 .95664 L .47059 .94933 L p .826 .506 .447 r
F P
0 g
s
.50287 .90573 m .48698 .8985 L .49753 .88743 L p .684 .705 .863 r
F P
0 g
s
.49246 .94534 m .50843 .95248 L .49784 .96325 L p .683 .708 .867 r
F P
0 g
s
.48699 .91273 m .50299 .91997 L .49242 .93089 L p .683 .706 .865 r
F P
0 g
s
.50843 .95248 m .49246 .94534 L .50311 .93441 L p .683 .708 .867 r
F P
0 g
s
.49788 .94553 m .48703 .95664 L .48674 .57741 L p .23 .037 .399 r
F P
0 g
s
.48674 .57741 m .49561 .56688 L .49788 .94553 L p .23 .037 .399 r
F P
0 g
s
.47059 .94933 m .4733 .57048 L .48674 .57741 L p .826 .506 .447 r
F P
0 g
s
.48674 .57741 m .48703 .95664 L .47059 .94933 L p .826 .506 .447 r
F P
0 g
s
.49753 .88743 m .48698 .8985 L .48674 .57741 L p .23 .037 .399 r
F P
0 g
s
.48674 .57741 m .49561 .56688 L .49753 .88743 L p .23 .037 .399 r
F P
0 g
s
.54042 .55965 m .55374 .56663 L .54465 .57716 L p .694 .677 .829 r
F P
0 g
s
.54465 .57716 m .53135 .57023 L .54042 .55965 L p .694 .677 .829 r
F P
0 g
s
.53964 .87693 m .5553 .8842 L .54461 .89516 L p .685 .704 .862 r
F P
0 g
s
.54001 .89095 m .53135 .57023 L .54465 .57716 L p .828 .503 .439 r
F P
0 g
s
.54465 .57716 m .55579 .89824 L .54001 .89095 L p .828 .503 .439 r
F P
0 g
s
.56665 .88717 m .55579 .89824 L .54465 .57716 L p .256 .065 .418 r
F P
0 g
s
.54465 .57716 m .55374 .56663 L .56665 .88717 L p .256 .065 .418 r
F P
0 g
s
.53964 .87693 m .53135 .57023 L .54465 .57716 L p .828 .503 .439 r
F P
0 g
s
.54465 .57716 m .5553 .8842 L .53964 .87693 L p .828 .503 .439 r
F P
0 g
s
.56665 .88717 m .55579 .89824 L .54465 .57716 L p .256 .065 .418 r
F P
0 g
s
.54465 .57716 m .55374 .56663 L .56665 .88717 L p .256 .065 .418 r
F P
0 g
s
.5987 .5594 m .61188 .56638 L .60256 .57691 L p .694 .677 .829 r
F P
0 g
s
.60256 .57691 m .58941 .56998 L .5987 .5594 L p .694 .677 .829 r
F P
0 g
s
.59959 .9304 m .61534 .93763 L .6042 .94853 L p .683 .708 .867 r
F P
0 g
s
.61079 .91934 m .62658 .92664 L .61534 .93763 L p .683 .708 .867 r
F P
0 g
s
.61534 .93763 m .59959 .9304 L .61079 .91934 L p .683 .708 .867 r
F P
0 g
s
.6126 .94881 m .58941 .56998 L .60256 .57691 L p .829 .499 .43 r
F P
0 g
s
.60256 .57691 m .62861 .95612 L .6126 .94881 L p .829 .499 .43 r
F P
0 g
s
.64012 .945 m .62861 .95612 L .60256 .57691 L p .28 .091 .436 r
F P
0 g
s
.60256 .57691 m .61188 .56638 L .64012 .945 L p .28 .091 .436 r
F P
0 g
s
.61079 .91934 m .58941 .56998 L .60256 .57691 L p .829 .499 .43 r
F P
0 g
s
.60256 .57691 m .62658 .92664 L .61079 .91934 L p .829 .499 .43 r
F P
0 g
s
.64012 .945 m .62861 .95612 L .60256 .57691 L p .28 .091 .436 r
F P
0 g
s
.60256 .57691 m .61188 .56638 L .64012 .945 L p .28 .091 .436 r
F P
0 g
s
.38789 .55678 m .40161 .56377 L .39309 .57432 L p .694 .677 .829 r
F P
0 g
s
.39309 .57432 m .3794 .56738 L .38789 .55678 L p .694 .677 .829 r
F P
0 g
s
.35663 .93122 m .3794 .56738 L .39309 .57432 L p .824 .51 .458 r
F P
0 g
s
.39309 .57432 m .37332 .93854 L .35663 .93122 L p .824 .51 .458 r
F P
0 g
s
.38359 .92741 m .37332 .93854 L .39309 .57432 L p .18 0 .362 r
F P
0 g
s
.39309 .57432 m .40161 .56377 L .38359 .92741 L p .18 0 .362 r
F P
0 g
s
.3557 .94606 m .3794 .56738 L .39309 .57432 L p .824 .51 .458 r
F P
0 g
s
.39309 .57432 m .37251 .95339 L .3557 .94606 L p .824 .51 .458 r
F P
0 g
s
.38285 .94224 m .37251 .95339 L .39309 .57432 L p .18 0 .362 r
F P
0 g
s
.39309 .57432 m .40161 .56377 L .38285 .94224 L p .18 0 .362 r
F P
0 g
s
.44622 .55652 m .45979 .56352 L .45105 .57407 L p .694 .677 .829 r
F P
0 g
s
.45105 .57407 m .4375 .56713 L .44622 .55652 L p .694 .677 .829 r
F P
0 g
s
.42762 .91633 m .4375 .56713 L .45105 .57407 L p .825 .507 .451 r
F P
0 g
s
.45105 .57407 m .44398 .92365 L .42762 .91633 L p .825 .507 .451 r
F P
0 g
s
.4545 .91252 m .44398 .92365 L .45105 .57407 L p .211 .017 .385 r
F P
0 g
s
.45105 .57407 m .45979 .56352 L .4545 .91252 L p .211 .017 .385 r
F P
0 g
s
.42762 .91633 m .4375 .56713 L .45105 .57407 L p .825 .507 .451 r
F P
0 g
s
.45105 .57407 m .44398 .92365 L .42762 .91633 L p .825 .507 .451 r
F P
0 g
s
.45427 .92714 m .44368 .93828 L .45105 .57407 L p .211 .017 .385 r
F P
0 g
s
.45105 .57407 m .45979 .56352 L .45427 .92714 L p .211 .017 .385 r
F P
0 g
s
.50456 .55627 m .51799 .56327 L .50902 .57383 L p .694 .677 .829 r
F P
0 g
s
.50902 .57383 m .49561 .56688 L .50456 .55627 L p .694 .677 .829 r
F P
0 g
s
.49745 .87341 m .49561 .56688 L .50902 .57383 L p .827 .504 .443 r
F P
0 g
s
.50902 .57383 m .51326 .8807 L .49745 .87341 L p .827 .504 .443 r
F P
0 g
s
.52388 .86962 m .51326 .8807 L .50902 .57383 L p .239 .047 .406 r
F P
0 g
s
.50902 .57383 m .51799 .56327 L .52388 .86962 L p .239 .047 .406 r
F P
0 g
s
.49753 .88743 m .49561 .56688 L .50902 .57383 L p .827 .504 .443 r
F P
0 g
s
.50902 .57383 m .51346 .89473 L .49753 .88743 L p .827 .504 .443 r
F P
0 g
s
.52415 .88363 m .51346 .89473 L .50902 .57383 L p .239 .047 .406 r
F P
0 g
s
.50902 .57383 m .51799 .56327 L .52415 .88363 L p .239 .047 .406 r
F P
0 g
s
.5629 .55602 m .57619 .56302 L .567 .57358 L p .694 .677 .829 r
F P
0 g
s
.567 .57358 m .55374 .56663 L .5629 .55602 L p .694 .677 .829 r
F P
0 g
s
.56665 .88717 m .55374 .56663 L .567 .57358 L p .828 .501 .435 r
F P
0 g
s
.567 .57358 m .58237 .89447 L .56665 .88717 L p .828 .501 .435 r
F P
0 g
s
.59338 .88337 m .58237 .89447 L .567 .57358 L p .264 .074 .424 r
F P
0 g
s
.567 .57358 m .57619 .56302 L .59338 .88337 L p .264 .074 .424 r
F P
0 g
s
.56665 .88717 m .55374 .56663 L .567 .57358 L p .828 .501 .435 r
F P
0 g
s
.567 .57358 m .58237 .89447 L .56665 .88717 L p .828 .501 .435 r
F P
0 g
s
.59414 .89758 m .58306 .9087 L .567 .57358 L p .264 .074 .424 r
F P
0 g
s
.567 .57358 m .57619 .56302 L .59414 .89758 L p .264 .074 .424 r
F P
0 g
s
.62126 .55577 m .6344 .56277 L .62499 .57333 L p .694 .677 .829 r
F P
0 g
s
.62499 .57333 m .61188 .56638 L .62126 .55577 L p .694 .677 .829 r
F P
0 g
s
.63902 .93016 m .61188 .56638 L .62499 .57333 L p .83 .498 .426 r
F P
0 g
s
.62499 .57333 m .65486 .93749 L .63902 .93016 L p .83 .498 .426 r
F P
0 g
s
.66643 .92635 m .65486 .93749 L .62499 .57333 L p .288 .099 .441 r
F P
0 g
s
.62499 .57333 m .6344 .56277 L .66643 .92635 L p .288 .099 .441 r
F P
0 g
s
.64012 .945 m .61188 .56638 L .62499 .57333 L p .83 .498 .426 r
F P
0 g
s
.62499 .57333 m .65607 .95234 L .64012 .945 L p .83 .498 .426 r
F P
0 g
s
.66774 .94118 m .65607 .95234 L .62499 .57333 L p .288 .099 .441 r
F P
0 g
s
.62499 .57333 m .6344 .56277 L .66774 .94118 L p .288 .099 .441 r
F P
0 g
s
.35181 .55339 m .36564 .5604 L .35724 .57098 L p .694 .677 .829 r
F P
0 g
s
.35724 .57098 m .34344 .56402 L .35181 .55339 L p .694 .677 .829 r
F P
0 g
s
.31167 .94251 m .34344 .56402 L .35724 .57098 L p .823 .511 .462 r
F P
0 g
s
.35724 .57098 m .32864 .94986 L .31167 .94251 L p .823 .511 .462 r
F P
0 g
s
.33879 .93868 m .32864 .94986 L .35724 .57098 L p .157 0 .346 r
F P
0 g
s
.35724 .57098 m .36564 .5604 L .33879 .93868 L p .157 0 .346 r
F P
0 g
s
.33879 .93868 m .32864 .94986 L .35724 .57098 L p .157 0 .346 r
F P
0 g
s
.35724 .57098 m .36564 .5604 L .33879 .93868 L p .157 0 .346 r
F P
0 g
s
.4102 .55314 m .42389 .56015 L .41526 .57073 L p .694 .677 .829 r
F P
0 g
s
.41526 .57073 m .40161 .56377 L .4102 .55314 L p .694 .677 .829 r
F P
0 g
s
.38285 .94224 m .40161 .56377 L .41526 .57073 L p .825 .508 .454 r
F P
0 g
s
.41526 .57073 m .39961 .9496 L .38285 .94224 L p .825 .508 .454 r
F P
0 g
s
.41724 .92742 m .40082 .92013 L .41116 .90897 L p .683 .708 .867 r
F P
0 g
s
.40022 .93476 m .41675 .94206 L .40639 .95306 L p .682 .709 .868 r
F P
0 g
s
.41009 .93842 m .39961 .9496 L .41526 .57073 L p .19 0 .37 r
F P
0 g
s
.41526 .57073 m .42389 .56015 L .41009 .93842 L p .19 0 .37 r
F P
0 g
s
.38285 .94224 m .40161 .56377 L .41526 .57073 L p .825 .508 .454 r
F P
0 g
s
.41526 .57073 m .39961 .9496 L .38285 .94224 L p .825 .508 .454 r
F P
0 g
s
.41116 .90897 m .40082 .92013 L .41526 .57073 L p .19 0 .37 r
F P
0 g
s
.41526 .57073 m .42389 .56015 L .41116 .90897 L p .19 0 .37 r
F P
0 g
s
.46861 .55288 m .48215 .5599 L .4733 .57048 L p .694 .677 .829 r
F P
0 g
s
.4733 .57048 m .45979 .56352 L .46861 .55288 L p .694 .677 .829 r
F P
0 g
s
.45427 .92714 m .47069 .93449 L .46006 .94556 L p .682 .709 .868 r
F P
0 g
s
.46006 .94556 m .44368 .93828 L .45427 .92714 L p .682 .709 .868 r
F P
0 g
s
.45405 .94198 m .45979 .56352 L .4733 .57048 L p .826 .506 .447 r
F P
0 g
s
.4733 .57048 m .47059 .94933 L .45405 .94198 L p .826 .506 .447 r
F P
0 g
s
.4814 .93815 m .47059 .94933 L .4733 .57048 L p .22 .027 .392 r
F P
0 g
s
.4733 .57048 m .48215 .5599 L .4814 .93815 L p .22 .027 .392 r
F P
0 g
s
.45427 .92714 m .45979 .56352 L .4733 .57048 L p .826 .506 .447 r
F P
0 g
s
.4733 .57048 m .47069 .93449 L .45427 .92714 L p .826 .506 .447 r
F P
0 g
s
.4814 .93815 m .47059 .94933 L .4733 .57048 L p .22 .027 .392 r
F P
0 g
s
.4733 .57048 m .48215 .5599 L .4814 .93815 L p .22 .027 .392 r
F P
0 g
s
.52702 .55263 m .54042 .55965 L .53135 .57023 L p .694 .677 .829 r
F P
0 g
s
.53135 .57023 m .51799 .56327 L .52702 .55263 L p .694 .677 .829 r
F P
0 g
s
.52361 .85579 m .51799 .56327 L .53135 .57023 L p .828 .503 .439 r
F P
0 g
s
.53135 .57023 m .53926 .8631 L .52361 .85579 L p .828 .503 .439 r
F P
0 g
s
.54993 .85199 m .53926 .8631 L .53135 .57023 L p .248 .056 .412 r
F P
0 g
s
.53135 .57023 m .54042 .55965 L .54993 .85199 L p .248 .056 .412 r
F P
0 g
s
.52415 .88363 m .51799 .56327 L .53135 .57023 L p .828 .503 .439 r
F P
0 g
s
.53135 .57023 m .54001 .89095 L .52415 .88363 L p .828 .503 .439 r
F P
0 g
s
.55084 .87982 m .54001 .89095 L .53135 .57023 L p .248 .056 .412 r
F P
0 g
s
.53135 .57023 m .54042 .55965 L .55084 .87982 L p .248 .056 .412 r
F P
0 g
s
.58545 .55238 m .5987 .5594 L .58941 .56998 L p .694 .677 .829 r
F P
0 g
s
.58941 .56998 m .57619 .56302 L .58545 .55238 L p .694 .677 .829 r
F P
0 g
s
.6042 .94853 m .58849 .94136 L .59959 .9304 L p .683 .708 .867 r
F P
0 g
s
.59414 .89758 m .60991 .90491 L .59879 .91596 L p .683 .706 .865 r
F P
0 g
s
.59879 .91596 m .58306 .9087 L .59414 .89758 L p .683 .706 .865 r
F P
0 g
s
.58375 .92312 m .59959 .9304 L .58849 .94136 L p .683 .708 .867 r
F P
0 g
s
.59649 .94145 m .57619 .56302 L .58941 .56998 L p .829 .499 .43 r
F P
0 g
s
.58941 .56998 m .6126 .94881 L .59649 .94145 L p .829 .499 .43 r
F P
0 g
s
.62408 .93762 m .6126 .94881 L .58941 .56998 L p .272 .082 .43 r
F P
0 g
s
.58941 .56998 m .5987 .5594 L .62408 .93762 L p .272 .082 .43 r
F P
0 g
s
.59414 .89758 m .57619 .56302 L .58941 .56998 L p .829 .499 .43 r
F P
0 g
s
.58941 .56998 m .60991 .90491 L .59414 .89758 L p .829 .499 .43 r
F P
0 g
s
.62408 .93762 m .6126 .94881 L .58941 .56998 L p .272 .082 .43 r
F P
0 g
s
.58941 .56998 m .5987 .5594 L .62408 .93762 L p .272 .082 .43 r
F P
0 g
s
.64389 .55212 m .65699 .55914 L .64748 .56973 L p .694 .677 .829 r
F P
0 g
s
.64748 .56973 m .6344 .56277 L .64389 .55212 L p .694 .677 .829 r
F P
0 g
s
.66774 .94118 m .6344 .56277 L .64748 .56973 L p .831 .496 .421 r
F P
0 g
s
.64748 .56973 m .68363 .94854 L .66774 .94118 L p .831 .496 .421 r
F P
0 g
s
.69544 .93735 m .68363 .94854 L .64748 .56973 L p .295 .107 .446 r
F P
0 g
s
.64748 .56973 m .65699 .55914 L .69544 .93735 L p .295 .107 .446 r
F P
0 g
s
.66774 .94118 m .6344 .56277 L .64748 .56973 L p .831 .496 .421 r
F P
0 g
s
.64748 .56973 m .68363 .94854 L .66774 .94118 L p .831 .496 .421 r
F P
0 g
s
.3741 .54974 m .38789 .55678 L .3794 .56738 L p .694 .677 .829 r
F P
0 g
s
.3794 .56738 m .36564 .5604 L .3741 .54974 L p .694 .677 .829 r
F P
0 g
s
.33879 .93868 m .36564 .5604 L .3794 .56738 L p .824 .51 .458 r
F P
0 g
s
.3794 .56738 m .3557 .94606 L .33879 .93868 L p .824 .51 .458 r
F P
0 g
s
.37332 .93854 m .35663 .93122 L .36685 .92002 L p .682 .709 .868 r
F P
0 g
s
.36599 .93484 m .3557 .94606 L .3794 .56738 L p .169 0 .354 r
F P
0 g
s
.3794 .56738 m .38789 .55678 L .36599 .93484 L p .169 0 .354 r
F P
0 g
s
.33879 .93868 m .36564 .5604 L .3794 .56738 L p .824 .51 .458 r
F P
0 g
s
.3794 .56738 m .3557 .94606 L .33879 .93868 L p .824 .51 .458 r
F P
0 g
s
.36685 .92002 m .35663 .93122 L .3794 .56738 L p .169 0 .354 r
F P
0 g
s
.3794 .56738 m .38789 .55678 L .36685 .92002 L p .169 0 .354 r
F P
0 g
s
.43257 .54949 m .44622 .55652 L .4375 .56713 L p .694 .677 .829 r
F P
0 g
s
.4375 .56713 m .42389 .56015 L .43257 .54949 L p .694 .677 .829 r
F P
0 g
s
.41169 .89456 m .42389 .56015 L .4375 .56713 L p .825 .507 .451 r
F P
0 g
s
.4375 .56713 m .42803 .90191 L .41169 .89456 L p .825 .507 .451 r
F P
0 g
s
.43843 .89073 m .42803 .90191 L .4375 .56713 L p .201 .006 .378 r
F P
0 g
s
.4375 .56713 m .44622 .55652 L .43843 .89073 L p .201 .006 .378 r
F P
0 g
s
.41116 .90897 m .42389 .56015 L .4375 .56713 L p .825 .507 .451 r
F P
0 g
s
.4375 .56713 m .42762 .91633 L .41116 .90897 L p .825 .507 .451 r
F P
0 g
s
.43809 .90514 m .42762 .91633 L .4375 .56713 L p .201 .006 .378 r
F P
0 g
s
.4375 .56713 m .44622 .55652 L .43809 .90514 L p .201 .006 .378 r
F P
0 g
s
.49106 .54924 m .50456 .55627 L .49561 .56688 L p .694 .677 .829 r
F P
0 g
s
.49561 .56688 m .48215 .5599 L .49106 .54924 L p .694 .677 .829 r
F P
0 g
s
.4814 .93815 m .48215 .5599 L .49561 .56688 L p .827 .504 .443 r
F P
0 g
s
.49561 .56688 m .49788 .94553 L .4814 .93815 L p .827 .504 .443 r
F P
0 g
s
.51865 .91293 m .50287 .90573 L .51346 .89473 L p .684 .705 .863 r
F P
0 g
s
.51326 .8807 m .49745 .87341 L .50802 .86226 L p .685 .704 .862 r
F P
0 g
s
.49753 .88743 m .51346 .89473 L .50287 .90573 L p .684 .705 .863 r
F P
0 g
s
.50311 .93441 m .51912 .94162 L .50843 .95248 L p .683 .708 .867 r
F P
0 g
s
.50884 .93431 m .49788 .94553 L .49561 .56688 L p .23 .037 .399 r
F P
0 g
s
.49561 .56688 m .50456 .55627 L .50884 .93431 L p .23 .037 .399 r
F P
0 g
s
.4814 .93815 m .48215 .5599 L .49561 .56688 L p .827 .504 .443 r
F P
0 g
s
.49561 .56688 m .49788 .94553 L .4814 .93815 L p .827 .504 .443 r
F P
0 g
s
.50802 .86226 m .49745 .87341 L .49561 .56688 L p .23 .037 .399 r
F P
0 g
s
.49561 .56688 m .50456 .55627 L .50802 .86226 L p .23 .037 .399 r
F P
0 g
s
.54955 .54898 m .5629 .55602 L .55374 .56663 L p .694 .677 .829 r
F P
0 g
s
.55374 .56663 m .54042 .55965 L .54955 .54898 L p .694 .677 .829 r
F P
0 g
s
.55038 .86581 m .54042 .55965 L .55374 .56663 L p .828 .501 .435 r
F P
0 g
s
.55374 .56663 m .56609 .87315 L .55038 .86581 L p .828 .501 .435 r
F P
0 g
s
.57697 .86199 m .56609 .87315 L .55374 .56663 L p .256 .065 .418 r
F P
0 g
s
.55374 .56663 m .5629 .55602 L .57697 .86199 L p .256 .065 .418 r
F P
0 g
s
.55084 .87982 m .54042 .55965 L .55374 .56663 L p .828 .501 .435 r
F P
0 g
s
.55374 .56663 m .56665 .88717 L .55084 .87982 L p .828 .501 .435 r
F P
0 g
s
.57762 .876 m .56665 .88717 L .55374 .56663 L p .256 .065 .418 r
F P
0 g
s
.55374 .56663 m .5629 .55602 L .57762 .876 L p .256 .065 .418 r
F P
0 g
s
.60806 .54873 m .62126 .55577 L .61188 .56638 L p .694 .677 .829 r
F P
0 g
s
.61188 .56638 m .5987 .5594 L .60806 .54873 L p .694 .677 .829 r
F P
0 g
s
.62408 .93762 m .5987 .5594 L .61188 .56638 L p .83 .498 .426 r
F P
0 g
s
.61188 .56638 m .64012 .945 L .62408 .93762 L p .83 .498 .426 r
F P
0 g
s
.65486 .93749 m .63902 .93016 L .65055 .91895 L p .682 .709 .868 r
F P
0 g
s
.65175 .93377 m .64012 .945 L .61188 .56638 L p .28 .091 .436 r
F P
0 g
s
.61188 .56638 m .62126 .55577 L .65175 .93377 L p .28 .091 .436 r
F P
0 g
s
.62408 .93762 m .5987 .5594 L .61188 .56638 L p .83 .498 .426 r
F P
0 g
s
.61188 .56638 m .64012 .945 L .62408 .93762 L p .83 .498 .426 r
F P
0 g
s
.65055 .91895 m .63902 .93016 L .61188 .56638 L p .28 .091 .436 r
F P
0 g
s
.61188 .56638 m .62126 .55577 L .65055 .91895 L p .28 .091 .436 r
F P
0 g
s
.33791 .54634 m .35181 .55339 L .34344 .56402 L p .694 .677 .829 r
F P
0 g
s
.34344 .56402 m .32957 .55703 L .33791 .54634 L p .694 .677 .829 r
F P
0 g
s
.29459 .93511 m .32957 .55703 L .34344 .56402 L p .823 .511 .462 r
F P
0 g
s
.34344 .56402 m .31167 .94251 L .29459 .93511 L p .823 .511 .462 r
F P
0 g
s
.32177 .93126 m .31167 .94251 L .34344 .56402 L p .145 0 .337 r
F P
0 g
s
.34344 .56402 m .35181 .55339 L .32177 .93126 L p .145 0 .337 r
F P
0 g
s
.32177 .93126 m .31167 .94251 L .34344 .56402 L p .145 0 .337 r
F P
0 g
s
.34344 .56402 m .35181 .55339 L .32177 .93126 L p .145 0 .337 r
F P
0 g
s
.39645 .54609 m .4102 .55314 L .40161 .56377 L p .694 .677 .829 r
F P
0 g
s
.40161 .56377 m .38789 .55678 L .39645 .54609 L p .694 .677 .829 r
F P
0 g
s
.36685 .92002 m .38359 .92741 L .37332 .93854 L p .682 .709 .868 r
F P
0 g
s
.36599 .93484 m .38789 .55678 L .40161 .56377 L p .825 .508 .454 r
F P
0 g
s
.40161 .56377 m .38285 .94224 L .36599 .93484 L p .825 .508 .454 r
F P
0 g
s
.39328 .93099 m .38285 .94224 L .40161 .56377 L p .18 0 .362 r
F P
0 g
s
.40161 .56377 m .4102 .55314 L .39328 .93099 L p .18 0 .362 r
F P
0 g
s
.36685 .92002 m .38789 .55678 L .40161 .56377 L p .825 .508 .454 r
F P
0 g
s
.40161 .56377 m .38359 .92741 L .36685 .92002 L p .825 .508 .454 r
F P
0 g
s
.39328 .93099 m .38285 .94224 L .40161 .56377 L p .18 0 .362 r
F P
0 g
s
.40161 .56377 m .4102 .55314 L .39328 .93099 L p .18 0 .362 r
F P
0 g
s
.455 .54583 m .46861 .55288 L .45979 .56352 L p .694 .677 .829 r
F P
0 g
s
.45979 .56352 m .44622 .55652 L .455 .54583 L p .694 .677 .829 r
F P
0 g
s
.42762 .91633 m .44398 .92365 L .43355 .93467 L p .683 .708 .867 r
F P
0 g
s
.43809 .90514 m .4545 .91252 L .44398 .92365 L p .683 .708 .867 r
F P
0 g
s
.44398 .92365 m .42762 .91633 L .43809 .90514 L p .683 .708 .867 r
F P
0 g
s
.43741 .93458 m .44622 .55652 L .45979 .56352 L p .826 .506 .447 r
F P
0 g
s
.45979 .56352 m .45405 .94198 L .43741 .93458 L p .826 .506 .447 r
F P
0 g
s
.46482 .93072 m .45405 .94198 L .45979 .56352 L p .211 .017 .385 r
F P
0 g
s
.45979 .56352 m .46861 .55288 L .46482 .93072 L p .211 .017 .385 r
F P
0 g
s
.43809 .90514 m .44622 .55652 L .45979 .56352 L p .826 .506 .447 r
F P
0 g
s
.45979 .56352 m .4545 .91252 L .43809 .90514 L p .826 .506 .447 r
F P
0 g
s
.46482 .93072 m .45405 .94198 L .45979 .56352 L p .211 .017 .385 r
F P
0 g
s
.45979 .56352 m .46861 .55288 L .46482 .93072 L p .211 .017 .385 r
F P
0 g
s
.51356 .54558 m .52702 .55263 L .51799 .56327 L p .694 .677 .829 r
F P
0 g
s
.51799 .56327 m .50456 .55627 L .51356 .54558 L p .694 .677 .829 r
F P
0 g
s
.50787 .84845 m .50456 .55627 L .51799 .56327 L p .828 .503 .439 r
F P
0 g
s
.51799 .56327 m .52361 .85579 L .50787 .84845 L p .828 .503 .439 r
F P
0 g
s
.53424 .84462 m .52361 .85579 L .51799 .56327 L p .239 .047 .406 r
F P
0 g
s
.51799 .56327 m .52702 .55263 L .53424 .84462 L p .239 .047 .406 r
F P
0 g
s
.50802 .86226 m .50456 .55627 L .51799 .56327 L p .828 .503 .439 r
F P
0 g
s
.51799 .56327 m .52388 .86962 L .50802 .86226 L p .828 .503 .439 r
F P
0 g
s
.53424 .84462 m .52361 .85579 L .51799 .56327 L p .239 .047 .406 r
F P
0 g
s
.51799 .56327 m .52702 .55263 L .53424 .84462 L p .239 .047 .406 r
F P
0 g
s
.57214 .54532 m .58545 .55238 L .57619 .56302 L p .694 .677 .829 r
F P
0 g
s
.57619 .56302 m .5629 .55602 L .57214 .54532 L p .694 .677 .829 r
F P
0 g
s
.56665 .88717 m .58237 .89447 L .57147 .90547 L p .684 .705 .863 r
F P
0 g
s
.57762 .876 m .59338 .88337 L .58237 .89447 L p .684 .705 .863 r
F P
0 g
s
.58237 .89447 m .56665 .88717 L .57762 .876 L p .684 .705 .863 r
F P
0 g
s
.58849 .94136 m .57268 .93415 L .58375 .92312 L p .683 .708 .867 r
F P
0 g
s
.58029 .93404 m .5629 .55602 L .57619 .56302 L p .829 .499 .43 r
F P
0 g
s
.57619 .56302 m .59649 .94145 L .58029 .93404 L p .829 .499 .43 r
F P
0 g
s
.60793 .93019 m .59649 .94145 L .57619 .56302 L p .264 .074 .424 r
F P
0 g
s
.57619 .56302 m .58545 .55238 L .60793 .93019 L p .264 .074 .424 r
F P
0 g
s
.57762 .876 m .5629 .55602 L .57619 .56302 L p .829 .499 .43 r
F P
0 g
s
.57619 .56302 m .59338 .88337 L .57762 .876 L p .829 .499 .43 r
F P
0 g
s
.60793 .93019 m .59649 .94145 L .57619 .56302 L p .264 .074 .424 r
F P
0 g
s
.57619 .56302 m .58545 .55238 L .60793 .93019 L p .264 .074 .424 r
F P
0 g
s
.63072 .54507 m .64389 .55212 L .6344 .56277 L p .694 .677 .829 r
F P
0 g
s
.6344 .56277 m .62126 .55577 L .63072 .54507 L p .694 .677 .829 r
F P
0 g
s
.65055 .91895 m .66643 .92635 L .65486 .93749 L p .682 .709 .868 r
F P
0 g
s
.65175 .93377 m .62126 .55577 L .6344 .56277 L p .831 .496 .421 r
F P
0 g
s
.6344 .56277 m .66774 .94118 L .65175 .93377 L p .831 .496 .421 r
F P
0 g
s
.67951 .92992 m .66774 .94118 L .6344 .56277 L p .288 .099 .441 r
F P
0 g
s
.6344 .56277 m .64389 .55212 L .67951 .92992 L p .288 .099 .441 r
F P
0 g
s
.65055 .91895 m .62126 .55577 L .6344 .56277 L p .831 .496 .421 r
F P
0 g
s
.6344 .56277 m .66643 .92635 L .65055 .91895 L p .831 .496 .421 r
F P
0 g
s
.67951 .92992 m .66774 .94118 L .6344 .56277 L p .288 .099 .441 r
F P
0 g
s
.6344 .56277 m .64389 .55212 L .67951 .92992 L p .288 .099 .441 r
F P
0 g
s
.36024 .54268 m .3741 .54974 L .36564 .5604 L p .694 .677 .829 r
F P
0 g
s
.36564 .5604 m .35181 .55339 L .36024 .54268 L p .694 .677 .829 r
F P
0 g
s
.32295 .91644 m .35181 .55339 L .36564 .5604 L p .824 .51 .458 r
F P
0 g
s
.36564 .5604 m .33984 .92385 L .32295 .91644 L p .824 .51 .458 r
F P
0 g
s
.35001 .91258 m .33984 .92385 L .36564 .5604 L p .157 0 .346 r
F P
0 g
s
.36564 .5604 m .3741 .54974 L .35001 .91258 L p .157 0 .346 r
F P
0 g
s
.32177 .93126 m .35181 .55339 L .36564 .5604 L p .824 .51 .458 r
F P
0 g
s
.36564 .5604 m .33879 .93868 L .32177 .93126 L p .824 .51 .458 r
F P
0 g
s
.34903 .9274 m .33879 .93868 L .36564 .5604 L p .157 0 .346 r
F P
0 g
s
.36564 .5604 m .3741 .54974 L .34903 .9274 L p .157 0 .346 r
F P
0 g
s
.41886 .54242 m .43257 .54949 L .42389 .56015 L p .694 .677 .829 r
F P
0 g
s
.42389 .56015 m .4102 .55314 L .41886 .54242 L p .694 .677 .829 r
F P
0 g
s
.39328 .93099 m .4102 .55314 L .42389 .56015 L p .825 .507 .451 r
F P
0 g
s
.42389 .56015 m .41009 .93842 L .39328 .93099 L p .825 .507 .451 r
F P
0 g
s
.43355 .93467 m .41724 .92742 L .42762 .91633 L p .683 .708 .867 r
F P
0 g
s
.42803 .90191 m .41169 .89456 L .42205 .88331 L p .683 .706 .865 r
F P
0 g
s
.41116 .90897 m .42762 .91633 L .41724 .92742 L p .683 .708 .867 r
F P
0 g
s
.42066 .92713 m .41009 .93842 L .42389 .56015 L p .19 0 .37 r
F P
0 g
s
.42389 .56015 m .43257 .54949 L .42066 .92713 L p .19 0 .37 r
F P
0 g
s
.39328 .93099 m .4102 .55314 L .42389 .56015 L p .825 .507 .451 r
F P
0 g
s
.42389 .56015 m .41009 .93842 L .39328 .93099 L p .825 .507 .451 r
F P
0 g
s
.42205 .88331 m .41169 .89456 L .42389 .56015 L p .19 0 .37 r
F P
0 g
s
.42389 .56015 m .43257 .54949 L .42205 .88331 L p .19 0 .37 r
F P
0 g
s
.47749 .54217 m .49106 .54924 L .48215 .5599 L p .694 .677 .829 r
F P
0 g
s
.48215 .5599 m .46861 .55288 L .47749 .54217 L p .694 .677 .829 r
F P
0 g
s
.46497 .9159 m .46861 .55288 L .48215 .5599 L p .827 .504 .443 r
F P
0 g
s
.48215 .5599 m .48143 .92332 L .46497 .9159 L p .827 .504 .443 r
F P
0 g
s
.49227 .91204 m .48143 .92332 L .48215 .5599 L p .22 .027 .392 r
F P
0 g
s
.48215 .5599 m .49106 .54924 L .49227 .91204 L p .22 .027 .392 r
F P
0 g
s
.46482 .93072 m .46861 .55288 L .48215 .5599 L p .827 .504 .443 r
F P
0 g
s
.48215 .5599 m .4814 .93815 L .46482 .93072 L p .827 .504 .443 r
F P
0 g
s
.49231 .92686 m .4814 .93815 L .48215 .5599 L p .22 .027 .392 r
F P
0 g
s
.48215 .5599 m .49106 .54924 L .49231 .92686 L p .22 .027 .392 r
F P
0 g
s
.53613 .54191 m .54955 .54898 L .54042 .55965 L p .694 .677 .829 r
F P
0 g
s
.54042 .55965 m .52702 .55263 L .53613 .54191 L p .694 .677 .829 r
F P
0 g
s
.53424 .84462 m .52702 .55263 L .54042 .55965 L p .828 .501 .435 r
F P
0 g
s
.54042 .55965 m .54993 .85199 L .53424 .84462 L p .828 .501 .435 r
F P
0 g
s
.5607 .84079 m .54993 .85199 L .54042 .55965 L p .248 .056 .412 r
F P
0 g
s
.54042 .55965 m .54955 .54898 L .5607 .84079 L p .248 .056 .412 r
F P
0 g
s
.53424 .84462 m .52702 .55263 L .54042 .55965 L p .828 .501 .435 r
F P
0 g
s
.54042 .55965 m .54993 .85199 L .53424 .84462 L p .828 .501 .435 r
F P
0 g
s
.56123 .85459 m .55038 .86581 L .54042 .55965 L p .248 .056 .412 r
F P
0 g
s
.54042 .55965 m .54955 .54898 L .56123 .85459 L p .248 .056 .412 r
F P
0 g
s
.59478 .54166 m .60806 .54873 L .5987 .5594 L p .694 .677 .829 r
F P
0 g
s
.5987 .5594 m .58545 .55238 L .59478 .54166 L p .694 .677 .829 r
F P
0 g
s
.60705 .91537 m .58545 .55238 L .5987 .5594 L p .83 .498 .426 r
F P
0 g
s
.5987 .5594 m .62308 .92279 L .60705 .91537 L p .83 .498 .426 r
F P
0 g
s
.63458 .91151 m .62308 .92279 L .5987 .5594 L p .272 .082 .43 r
F P
0 g
s
.5987 .5594 m .60806 .54873 L .63458 .91151 L p .272 .082 .43 r
F P
0 g
s
.60793 .93019 m .58545 .55238 L .5987 .5594 L p .83 .498 .426 r
F P
0 g
s
.5987 .5594 m .62408 .93762 L .60793 .93019 L p .83 .498 .426 r
F P
0 g
s
.63566 .92632 m .62408 .93762 L .5987 .5594 L p .272 .082 .43 r
F P
0 g
s
.5987 .5594 m .60806 .54873 L .63566 .92632 L p .272 .082 .43 r
F P
0 g
s
.65344 .5414 m .66657 .54848 L .65699 .55914 L p .694 .677 .829 r
F P
0 g
s
.65699 .55914 m .64389 .55212 L .65344 .5414 L p .694 .677 .829 r
F P
0 g
s
.67951 .92992 m .64389 .55212 L .65699 .55914 L p .831 .494 .417 r
F P
0 g
s
.65699 .55914 m .69544 .93735 L .67951 .92992 L p .831 .494 .417 r
F P
0 g
s
.70736 .92605 m .69544 .93735 L .65699 .55914 L p .295 .107 .446 r
F P
0 g
s
.65699 .55914 m .66657 .54848 L .70736 .92605 L p .295 .107 .446 r
F P
0 g
s
.67951 .92992 m .64389 .55212 L .65699 .55914 L p .831 .494 .417 r
F P
0 g
s
.65699 .55914 m .69544 .93735 L .67951 .92992 L p .831 .494 .417 r
F P
0 g
s
.32394 .53926 m .33791 .54634 L .32957 .55703 L p .694 .677 .829 r
F P
0 g
s
.32957 .55703 m .31564 .55 L .32394 .53926 L p .694 .677 .829 r
F P
0 g
s
.27741 .92767 m .31564 .55 L .32957 .55703 L p .823 .511 .462 r
F P
0 g
s
.32957 .55703 m .29459 .93511 L .27741 .92767 L p .823 .511 .462 r
F P
0 g
s
.30464 .92379 m .29459 .93511 L .32957 .55703 L p .133 0 .328 r
F P
0 g
s
.32957 .55703 m .33791 .54634 L .30464 .92379 L p .133 0 .328 r
F P
0 g
s
.30464 .92379 m .29459 .93511 L .32957 .55703 L p .133 0 .328 r
F P
0 g
s
.32957 .55703 m .33791 .54634 L .30464 .92379 L p .133 0 .328 r
F P
0 g
s
.38263 .539 m .39645 .54609 L .38789 .55678 L p .694 .677 .829 r
F P
0 g
s
.38789 .55678 m .3741 .54974 L .38263 .539 L p .694 .677 .829 r
F P
0 g
s
.35098 .89798 m .3741 .54974 L .38789 .55678 L p .825 .508 .454 r
F P
0 g
s
.38789 .55678 m .3677 .9054 L .35098 .89798 L p .825 .508 .454 r
F P
0 g
s
.37794 .89411 m .3677 .9054 L .38789 .55678 L p .169 0 .354 r
F P
0 g
s
.38789 .55678 m .39645 .54609 L .37794 .89411 L p .169 0 .354 r
F P
0 g
s
.34903 .9274 m .3741 .54974 L .38789 .55678 L p .825 .508 .454 r
F P
0 g
s
.38789 .55678 m .36599 .93484 L .34903 .9274 L p .825 .508 .454 r
F P
0 g
s
.37638 .92352 m .36599 .93484 L .38789 .55678 L p .169 0 .354 r
F P
0 g
s
.38789 .55678 m .39645 .54609 L .37638 .92352 L p .169 0 .354 r
F P
0 g
s
.44133 .53875 m .455 .54583 L .44622 .55652 L p .694 .677 .829 r
F P
0 g
s
.44622 .55652 m .43257 .54949 L .44133 .53875 L p .694 .677 .829 r
F P
0 g
s
.42205 .88331 m .43843 .89073 L .42803 .90191 L p .683 .706 .865 r
F P
0 g
s
.42066 .92713 m .43257 .54949 L .44622 .55652 L p .826 .506 .447 r
F P
0 g
s
.44622 .55652 m .43741 .93458 L .42066 .92713 L p .826 .506 .447 r
F P
0 g
s
.44813 .92325 m .43741 .93458 L .44622 .55652 L p .201 .006 .378 r
F P
0 g
s
.44622 .55652 m .455 .54583 L .44813 .92325 L p .201 .006 .378 r
F P
0 g
s
.42205 .88331 m .43257 .54949 L .44622 .55652 L p .826 .506 .447 r
F P
0 g
s
.44622 .55652 m .43843 .89073 L .42205 .88331 L p .826 .506 .447 r
F P
0 g
s
.44813 .92325 m .43741 .93458 L .44622 .55652 L p .201 .006 .378 r
F P
0 g
s
.44622 .55652 m .455 .54583 L .44813 .92325 L p .201 .006 .378 r
F P
0 g
s
.50004 .53849 m .51356 .54558 L .50456 .55627 L p .694 .677 .829 r
F P
0 g
s
.50456 .55627 m .49106 .54924 L .50004 .53849 L p .694 .677 .829 r
F P
0 g
s
.49231 .92686 m .49106 .54924 L .50456 .55627 L p .828 .503 .439 r
F P
0 g
s
.50456 .55627 m .50884 .93431 L .49231 .92686 L p .828 .503 .439 r
F P
0 g
s
.53435 .92008 m .51865 .91293 L .52929 .90199 L p .684 .705 .863 r
F P
0 g
s
.52361 .85579 m .50787 .84845 L .51846 .83721 L p .685 .702 .86 r
F P
0 g
s
.51346 .89473 m .52929 .90199 L .51865 .91293 L p .684 .705 .863 r
F P
0 g
s
.50802 .86226 m .52388 .86962 L .51326 .8807 L p .685 .704 .862 r
F P
0 g
s
.52929 .90199 m .51346 .89473 L .52415 .88363 L p .684 .705 .863 r
F P
0 g
s
.5199 .92298 m .50884 .93431 L .50456 .55627 L p .23 .037 .399 r
F P
0 g
s
.50456 .55627 m .51356 .54558 L .5199 .92298 L p .23 .037 .399 r
F P
0 g
s
.49231 .92686 m .49106 .54924 L .50456 .55627 L p .828 .503 .439 r
F P
0 g
s
.50456 .55627 m .50884 .93431 L .49231 .92686 L p .828 .503 .439 r
F P
0 g
s
.51846 .83721 m .50787 .84845 L .50456 .55627 L p .23 .037 .399 r
F P
0 g
s
.50456 .55627 m .51356 .54558 L .51846 .83721 L p .23 .037 .399 r
F P
0 g
s
.55876 .53824 m .57214 .54532 L .5629 .55602 L p .694 .677 .829 r
F P
0 g
s
.5629 .55602 m .54955 .54898 L .55876 .53824 L p .694 .677 .829 r
F P
0 g
s
.55579 .89824 m .57147 .90547 L .56067 .91638 L p .684 .705 .863 r
F P
0 g
s
.57147 .90547 m .55579 .89824 L .56665 .88717 L p .684 .705 .863 r
F P
0 g
s
.56123 .85459 m .57697 .86199 L .56609 .87315 L p .685 .704 .862 r
F P
0 g
s
.56609 .87315 m .55038 .86581 L .56123 .85459 L p .685 .704 .862 r
F P
0 g
s
.55084 .87982 m .56665 .88717 L .55579 .89824 L p .684 .705 .863 r
F P
0 g
s
.56398 .92659 m .54955 .54898 L .5629 .55602 L p .829 .499 .43 r
F P
0 g
s
.5629 .55602 m .58029 .93404 L .56398 .92659 L p .829 .499 .43 r
F P
0 g
s
.59168 .92271 m .58029 .93404 L .5629 .55602 L p .256 .065 .418 r
F P
0 g
s
.5629 .55602 m .57214 .54532 L .59168 .92271 L p .256 .065 .418 r
F P
0 g
s
.56123 .85459 m .54955 .54898 L .5629 .55602 L p .829 .499 .43 r
F P
0 g
s
.5629 .55602 m .57697 .86199 L .56123 .85459 L p .829 .499 .43 r
F P
0 g
s
.59168 .92271 m .58029 .93404 L .5629 .55602 L p .256 .065 .418 r
F P
0 g
s
.5629 .55602 m .57214 .54532 L .59168 .92271 L p .256 .065 .418 r
F P
0 g
s
.61749 .53798 m .63072 .54507 L .62126 .55577 L p .694 .677 .829 r
F P
0 g
s
.62126 .55577 m .60806 .54873 L .61749 .53798 L p .694 .677 .829 r
F P
0 g
s
.63351 .8969 m .60806 .54873 L .62126 .55577 L p .831 .496 .421 r
F P
0 g
s
.62126 .55577 m .64938 .90434 L .63351 .8969 L p .831 .496 .421 r
F P
0 g
s
.66093 .89303 m .64938 .90434 L .62126 .55577 L p .28 .091 .436 r
F P
0 g
s
.62126 .55577 m .63072 .54507 L .66093 .89303 L p .28 .091 .436 r
F P
0 g
s
.63566 .92632 m .60806 .54873 L .62126 .55577 L p .831 .496 .421 r
F P
0 g
s
.62126 .55577 m .65175 .93377 L .63566 .92632 L p .831 .496 .421 r
F P
0 g
s
.66348 .92244 m .65175 .93377 L .62126 .55577 L p .28 .091 .436 r
F P
0 g
s
.62126 .55577 m .63072 .54507 L .66348 .92244 L p .28 .091 .436 r
F P
0 g
s
.34631 .53558 m .36024 .54268 L .35181 .55339 L p .694 .677 .829 r
F P
0 g
s
.35181 .55339 m .33791 .54634 L .34631 .53558 L p .694 .677 .829 r
F P
0 g
s
.30464 .92379 m .33791 .54634 L .35181 .55339 L p .824 .51 .458 r
F P
0 g
s
.35181 .55339 m .32177 .93126 L .30464 .92379 L p .824 .51 .458 r
F P
0 g
s
.33984 .92385 m .32295 .91644 L .33307 .9051 L p .682 .709 .868 r
F P
0 g
s
.33196 .91991 m .32177 .93126 L .35181 .55339 L p .145 0 .337 r
F P
0 g
s
.35181 .55339 m .36024 .54268 L .33196 .91991 L p .145 0 .337 r
F P
0 g
s
.30464 .92379 m .33791 .54634 L .35181 .55339 L p .824 .51 .458 r
F P
0 g
s
.35181 .55339 m .32177 .93126 L .30464 .92379 L p .824 .51 .458 r
F P
0 g
s
.33307 .9051 m .32295 .91644 L .35181 .55339 L p .145 0 .337 r
F P
0 g
s
.35181 .55339 m .36024 .54268 L .33307 .9051 L p .145 0 .337 r
F P
0 g
s
.40508 .53532 m .41886 .54242 L .4102 .55314 L p .694 .677 .829 r
F P
0 g
s
.4102 .55314 m .39645 .54609 L .40508 .53532 L p .694 .677 .829 r
F P
0 g
s
.37717 .90871 m .39645 .54609 L .4102 .55314 L p .825 .507 .451 r
F P
0 g
s
.4102 .55314 m .39395 .91617 L .37717 .90871 L p .825 .507 .451 r
F P
0 g
s
.40441 .90483 m .39395 .91617 L .4102 .55314 L p .18 0 .362 r
F P
0 g
s
.4102 .55314 m .41886 .54242 L .40441 .90483 L p .18 0 .362 r
F P
0 g
s
.37638 .92352 m .39645 .54609 L .4102 .55314 L p .825 .507 .451 r
F P
0 g
s
.4102 .55314 m .39328 .93099 L .37638 .92352 L p .825 .507 .451 r
F P
0 g
s
.40382 .91964 m .39328 .93099 L .4102 .55314 L p .18 0 .362 r
F P
0 g
s
.4102 .55314 m .41886 .54242 L .40382 .91964 L p .18 0 .362 r
F P
0 g
s
.46385 .53506 m .47749 .54217 L .46861 .55288 L p .694 .677 .829 r
F P
0 g
s
.46861 .55288 m .455 .54583 L .46385 .53506 L p .694 .677 .829 r
F P
0 g
s
.44813 .92325 m .455 .54583 L .46861 .55288 L p .827 .504 .443 r
F P
0 g
s
.46861 .55288 m .46482 .93072 L .44813 .92325 L p .827 .504 .443 r
F P
0 g
s
.48143 .92332 m .46497 .9159 L .47576 .90456 L p .682 .709 .868 r
F P
0 g
s
.47569 .91937 m .46482 .93072 L .46861 .55288 L p .211 .017 .385 r
F P
0 g
s
.46861 .55288 m .47749 .54217 L .47569 .91937 L p .211 .017 .385 r
F P
0 g
s
.44813 .92325 m .455 .54583 L .46861 .55288 L p .827 .504 .443 r
F P
0 g
s
.46861 .55288 m .46482 .93072 L .44813 .92325 L p .827 .504 .443 r
F P
0 g
s
.47576 .90456 m .46497 .9159 L .46861 .55288 L p .211 .017 .385 r
F P
0 g
s
.46861 .55288 m .47749 .54217 L .47576 .90456 L p .211 .017 .385 r
F P
0 g
s
.52264 .53481 m .53613 .54191 L .52702 .55263 L p .694 .677 .829 r
F P
0 g
s
.52702 .55263 m .51356 .54558 L .52264 .53481 L p .694 .677 .829 r
F P
0 g
s
.51823 .82361 m .51356 .54558 L .52702 .55263 L p .828 .501 .435 r
F P
0 g
s
.52702 .55263 m .53391 .83101 L .51823 .82361 L p .828 .501 .435 r
F P
0 g
s
.54456 .81975 m .53391 .83101 L .52702 .55263 L p .239 .047 .406 r
F P
0 g
s
.52702 .55263 m .53613 .54191 L .54456 .81975 L p .239 .047 .406 r
F P
0 g
s
.51846 .83721 m .51356 .54558 L .52702 .55263 L p .828 .501 .435 r
F P
0 g
s
.52702 .55263 m .53424 .84462 L .51846 .83721 L p .828 .501 .435 r
F P
0 g
s
.54497 .83335 m .53424 .84462 L .52702 .55263 L p .239 .047 .406 r
F P
0 g
s
.52702 .55263 m .53613 .54191 L .54497 .83335 L p .239 .047 .406 r
F P
0 g
s
.58144 .53455 m .59478 .54166 L .58545 .55238 L p .694 .677 .829 r
F P
0 g
s
.58545 .55238 m .57214 .54532 L .58144 .53455 L p .694 .677 .829 r
F P
0 g
s
.59168 .92271 m .57214 .54532 L .58545 .55238 L p .83 .498 .426 r
F P
0 g
s
.58545 .55238 m .60793 .93019 L .59168 .92271 L p .83 .498 .426 r
F P
0 g
s
.62308 .92279 m .60705 .91537 L .61851 .90402 L p .682 .709 .868 r
F P
0 g
s
.61948 .91882 m .60793 .93019 L .58545 .55238 L p .264 .074 .424 r
F P
0 g
s
.58545 .55238 m .59478 .54166 L .61948 .91882 L p .264 .074 .424 r
F P
0 g
s
.59168 .92271 m .57214 .54532 L .58545 .55238 L p .83 .498 .426 r
F P
0 g
s
.58545 .55238 m .60793 .93019 L .59168 .92271 L p .83 .498 .426 r
F P
0 g
s
.61851 .90402 m .60705 .91537 L .58545 .55238 L p .264 .074 .424 r
F P
0 g
s
.58545 .55238 m .59478 .54166 L .61851 .90402 L p .264 .074 .424 r
F P
0 g
s
.64025 .53429 m .65344 .5414 L .64389 .55212 L p .694 .677 .829 r
F P
0 g
s
.64389 .55212 m .63072 .54507 L .64025 .53429 L p .694 .677 .829 r
F P
0 g
s
.6622 .90763 m .63072 .54507 L .64389 .55212 L p .831 .494 .417 r
F P
0 g
s
.64389 .55212 m .67811 .9151 L .6622 .90763 L p .831 .494 .417 r
F P
0 g
s
.68991 .90375 m .67811 .9151 L .64389 .55212 L p .288 .099 .441 r
F P
0 g
s
.64389 .55212 m .65344 .5414 L .68991 .90375 L p .288 .099 .441 r
F P
0 g
s
.66348 .92244 m .63072 .54507 L .64389 .55212 L p .831 .494 .417 r
F P
0 g
s
.64389 .55212 m .67951 .92992 L .66348 .92244 L p .831 .494 .417 r
F P
0 g
s
.6914 .91855 m .67951 .92992 L .64389 .55212 L p .288 .099 .441 r
F P
0 g
s
.64389 .55212 m .65344 .5414 L .6914 .91855 L p .288 .099 .441 r
F P
0 g
s
.3099 .53214 m .32394 .53926 L .31564 .55 L p .694 .677 .829 r
F P
0 g
s
.31564 .55 m .30163 .54293 L .3099 .53214 L p .694 .677 .829 r
F P
0 g
s
.26012 .92018 m .30163 .54293 L .31564 .55 L p .823 .511 .462 r
F P
0 g
s
.31564 .55 m .27741 .92767 L .26012 .92018 L p .823 .511 .462 r
F P
0 g
s
.28741 .91628 m .27741 .92767 L .31564 .55 L p .121 0 .318 r
F P
0 g
s
.31564 .55 m .32394 .53926 L .28741 .91628 L p .121 0 .318 r
F P
0 g
s
.28741 .91628 m .27741 .92767 L .31564 .55 L p .121 0 .318 r
F P
0 g
s
.31564 .55 m .32394 .53926 L .28741 .91628 L p .121 0 .318 r
F P
0 g
s
.36874 .53188 m .38263 .539 L .3741 .54974 L p .694 .677 .829 r
F P
0 g
s
.3741 .54974 m .36024 .54268 L .36874 .53188 L p .694 .677 .829 r
F P
0 g
s
.33417 .8905 m .36024 .54268 L .3741 .54974 L p .825 .508 .454 r
F P
0 g
s
.3741 .54974 m .35098 .89798 L .33417 .8905 L p .825 .508 .454 r
F P
0 g
s
.36118 .88661 m .35098 .89798 L .3741 .54974 L p .157 0 .346 r
F P
0 g
s
.3741 .54974 m .38263 .539 L .36118 .88661 L p .157 0 .346 r
F P
0 g
s
.33307 .9051 m .36024 .54268 L .3741 .54974 L p .825 .508 .454 r
F P
0 g
s
.3741 .54974 m .35001 .91258 L .33307 .9051 L p .825 .508 .454 r
F P
0 g
s
.36118 .88661 m .35098 .89798 L .3741 .54974 L p .157 0 .346 r
F P
0 g
s
.3741 .54974 m .38263 .539 L .36118 .88661 L p .157 0 .346 r
F P
0 g
s
.42758 .53162 m .44133 .53875 L .43257 .54949 L p .694 .677 .829 r
F P
0 g
s
.43257 .54949 m .41886 .54242 L .42758 .53162 L p .694 .677 .829 r
F P
0 g
s
.40613 .86166 m .41886 .54242 L .43257 .54949 L p .826 .506 .447 r
F P
0 g
s
.43257 .54949 m .42249 .86912 L .40613 .86166 L p .826 .506 .447 r
F P
0 g
s
.43288 .85778 m .42249 .86912 L .43257 .54949 L p .19 0 .37 r
F P
0 g
s
.43257 .54949 m .44133 .53875 L .43288 .85778 L p .19 0 .37 r
F P
0 g
s
.40382 .91964 m .41886 .54242 L .43257 .54949 L p .826 .506 .447 r
F P
0 g
s
.43257 .54949 m .42066 .92713 L .40382 .91964 L p .826 .506 .447 r
F P
0 g
s
.43134 .91574 m .42066 .92713 L .43257 .54949 L p .19 0 .37 r
F P
0 g
s
.43257 .54949 m .44133 .53875 L .43134 .91574 L p .19 0 .37 r
F P
0 g
s
.48644 .53137 m .50004 .53849 L .49106 .54924 L p .694 .677 .829 r
F P
0 g
s
.49106 .54924 m .47749 .54217 L .48644 .53137 L p .694 .677 .829 r
F P
0 g
s
.47576 .90456 m .49227 .91204 L .48143 .92332 L p .682 .709 .868 r
F P
0 g
s
.47569 .91937 m .47749 .54217 L .49106 .54924 L p .828 .503 .439 r
F P
0 g
s
.49106 .54924 m .49231 .92686 L .47569 .91937 L p .828 .503 .439 r
F P
0 g
s
.50333 .91547 m .49231 .92686 L .49106 .54924 L p .22 .027 .392 r
F P
0 g
s
.49106 .54924 m .50004 .53849 L .50333 .91547 L p .22 .027 .392 r
F P
0 g
s
.47576 .90456 m .47749 .54217 L .49106 .54924 L p .828 .503 .439 r
F P
0 g
s
.49106 .54924 m .49227 .91204 L .47576 .90456 L p .828 .503 .439 r
F P
0 g
s
.50333 .91547 m .49231 .92686 L .49106 .54924 L p .22 .027 .392 r
F P
0 g
s
.49106 .54924 m .50004 .53849 L .50333 .91547 L p .22 .027 .392 r
F P
0 g
s
.54531 .53111 m .55876 .53824 L .54955 .54898 L p .694 .677 .829 r
F P
0 g
s
.54955 .54898 m .53613 .54191 L .54531 .53111 L p .694 .677 .829 r
F P
0 g
s
.54502 .90921 m .56067 .91638 L .54996 .92719 L p .684 .705 .863 r
F P
0 g
s
.54996 .92719 m .53435 .92008 L .54502 .90921 L p .684 .705 .863 r
F P
0 g
s
.53424 .84462 m .54993 .85199 L .53926 .8631 L p .685 .702 .86 r
F P
0 g
s
.56067 .91638 m .54502 .90921 L .55579 .89824 L p .684 .705 .863 r
F P
0 g
s
.54497 .83335 m .5607 .84079 L .54993 .85199 L p .685 .702 .86 r
F P
0 g
s
.54993 .85199 m .53424 .84462 L .54497 .83335 L p .685 .702 .86 r
F P
0 g
s
.55579 .89824 m .54001 .89095 L .55084 .87982 L p .684 .705 .863 r
F P
0 g
s
.54757 .9191 m .53613 .54191 L .54955 .54898 L p .829 .499 .43 r
F P
0 g
s
.54955 .54898 m .56398 .92659 L .54757 .9191 L p .829 .499 .43 r
F P
0 g
s
.57534 .91519 m .56398 .92659 L .54955 .54898 L p .248 .056 .412 r
F P
0 g
s
.54955 .54898 m .55876 .53824 L .57534 .91519 L p .248 .056 .412 r
F P
0 g
s
.54497 .83335 m .53613 .54191 L .54955 .54898 L p .829 .499 .43 r
F P
0 g
s
.54955 .54898 m .5607 .84079 L .54497 .83335 L p .829 .499 .43 r
F P
0 g
s
.57534 .91519 m .56398 .92659 L .54955 .54898 L p .248 .056 .412 r
F P
0 g
s
.54955 .54898 m .55876 .53824 L .57534 .91519 L p .248 .056 .412 r
F P
0 g
s
.60419 .53085 m .61749 .53798 L .60806 .54873 L p .694 .677 .829 r
F P
0 g
s
.60806 .54873 m .59478 .54166 L .60419 .53085 L p .694 .677 .829 r
F P
0 g
s
.61755 .88942 m .59478 .54166 L .60806 .54873 L p .831 .496 .421 r
F P
0 g
s
.60806 .54873 m .63351 .8969 L .61755 .88942 L p .831 .496 .421 r
F P
0 g
s
.64503 .88553 m .63351 .8969 L .60806 .54873 L p .272 .082 .43 r
F P
0 g
s
.60806 .54873 m .61749 .53798 L .64503 .88553 L p .272 .082 .43 r
F P
0 g
s
.61851 .90402 m .59478 .54166 L .60806 .54873 L p .831 .496 .421 r
F P
0 g
s
.60806 .54873 m .63458 .91151 L .61851 .90402 L p .831 .496 .421 r
F P
0 g
s
.64503 .88553 m .63351 .8969 L .60806 .54873 L p .272 .082 .43 r
F P
0 g
s
.60806 .54873 m .61749 .53798 L .64503 .88553 L p .272 .082 .43 r
F P
0 g
s
.66308 .5306 m .67623 .53772 L .66657 .54848 L p .694 .677 .829 r
F P
0 g
s
.66657 .54848 m .65344 .5414 L .66308 .5306 L p .694 .677 .829 r
F P
0 g
s
.6914 .91855 m .65344 .5414 L .66657 .54848 L p .832 .492 .412 r
F P
0 g
s
.66657 .54848 m .70736 .92605 L .6914 .91855 L p .832 .492 .412 r
F P
0 g
s
.7194 .91465 m .70736 .92605 L .66657 .54848 L p .295 .107 .446 r
F P
0 g
s
.66657 .54848 m .67623 .53772 L .7194 .91465 L p .295 .107 .446 r
F P
0 g
s
.6914 .91855 m .65344 .5414 L .66657 .54848 L p .832 .492 .412 r
F P
0 g
s
.66657 .54848 m .70736 .92605 L .6914 .91855 L p .832 .492 .412 r
F P
0 g
s
.33231 .52844 m .34631 .53558 L .33791 .54634 L p .694 .677 .829 r
F P
0 g
s
.33791 .54634 m .32394 .53926 L .33231 .52844 L p .694 .677 .829 r
F P
0 g
s
.28885 .90147 m .32394 .53926 L .33791 .54634 L p .824 .51 .458 r
F P
0 g
s
.33791 .54634 m .30595 .90898 L .28885 .90147 L p .824 .51 .458 r
F P
0 g
s
.31603 .89757 m .30595 .90898 L .33791 .54634 L p .133 0 .328 r
F P
0 g
s
.33791 .54634 m .34631 .53558 L .31603 .89757 L p .133 0 .328 r
F P
0 g
s
.28741 .91628 m .32394 .53926 L .33791 .54634 L p .824 .51 .458 r
F P
0 g
s
.33791 .54634 m .30464 .92379 L .28741 .91628 L p .824 .51 .458 r
F P
0 g
s
.31479 .91237 m .30464 .92379 L .33791 .54634 L p .133 0 .328 r
F P
0 g
s
.33791 .54634 m .34631 .53558 L .31479 .91237 L p .133 0 .328 r
F P
0 g
s
.39122 .52818 m .40508 .53532 L .39645 .54609 L p .694 .677 .829 r
F P
0 g
s
.39645 .54609 m .38263 .539 L .39122 .52818 L p .694 .677 .829 r
F P
0 g
s
.36118 .88661 m .38263 .539 L .39645 .54609 L p .825 .507 .451 r
F P
0 g
s
.39645 .54609 m .37794 .89411 L .36118 .88661 L p .825 .507 .451 r
F P
0 g
s
.38828 .88271 m .37794 .89411 L .39645 .54609 L p .169 0 .354 r
F P
0 g
s
.39645 .54609 m .40508 .53532 L .38828 .88271 L p .169 0 .354 r
F P
0 g
s
.36118 .88661 m .38263 .539 L .39645 .54609 L p .825 .507 .451 r
F P
0 g
s
.39645 .54609 m .37794 .89411 L .36118 .88661 L p .825 .507 .451 r
F P
0 g
s
.38758 .8973 m .37717 .90871 L .39645 .54609 L p .169 0 .354 r
F P
0 g
s
.39645 .54609 m .40508 .53532 L .38758 .8973 L p .169 0 .354 r
F P
0 g
s
.45015 .52792 m .46385 .53506 L .455 .54583 L p .694 .677 .829 r
F P
0 g
s
.455 .54583 m .44133 .53875 L .45015 .52792 L p .694 .677 .829 r
F P
0 g
s
.43173 .90093 m .44133 .53875 L .455 .54583 L p .827 .504 .443 r
F P
0 g
s
.455 .54583 m .4484 .90844 L .43173 .90093 L p .827 .504 .443 r
F P
0 g
s
.45915 .89703 m .4484 .90844 L .455 .54583 L p .201 .006 .378 r
F P
0 g
s
.455 .54583 m .46385 .53506 L .45915 .89703 L p .201 .006 .378 r
F P
0 g
s
.43134 .91574 m .44133 .53875 L .455 .54583 L p .827 .504 .443 r
F P
0 g
s
.455 .54583 m .44813 .92325 L .43134 .91574 L p .827 .504 .443 r
F P
0 g
s
.45896 .91182 m .44813 .92325 L .455 .54583 L p .201 .006 .378 r
F P
0 g
s
.455 .54583 m .46385 .53506 L .45896 .91182 L p .201 .006 .378 r
F P
0 g
s
.50909 .52766 m .52264 .53481 L .51356 .54558 L p .694 .677 .829 r
F P
0 g
s
.51356 .54558 m .50004 .53849 L .50909 .52766 L p .694 .677 .829 r
F P
0 g
s
.50333 .91547 m .50004 .53849 L .51356 .54558 L p .828 .501 .435 r
F P
0 g
s
.51356 .54558 m .5199 .92298 L .50333 .91547 L p .828 .501 .435 r
F P
0 g
s
.53926 .8631 m .52361 .85579 L .53424 .84462 L p .685 .702 .86 r
F P
0 g
s
.53391 .83101 m .51823 .82361 L .52885 .81228 L p .686 .701 .859 r
F P
0 g
s
.52929 .90199 m .54502 .90921 L .53435 .92008 L p .684 .705 .863 r
F P
0 g
s
.51846 .83721 m .53424 .84462 L .52361 .85579 L p .685 .702 .86 r
F P
0 g
s
.52415 .88363 m .54001 .89095 L .52929 .90199 L p .684 .705 .863 r
F P
0 g
s
.53107 .91155 m .5199 .92298 L .51356 .54558 L p .23 .037 .399 r
F P
0 g
s
.51356 .54558 m .52264 .53481 L .53107 .91155 L p .23 .037 .399 r
F P
0 g
s
.50333 .91547 m .50004 .53849 L .51356 .54558 L p .828 .501 .435 r
F P
0 g
s
.51356 .54558 m .5199 .92298 L .50333 .91547 L p .828 .501 .435 r
F P
0 g
s
.52885 .81228 m .51823 .82361 L .51356 .54558 L p .23 .037 .399 r
F P
0 g
s
.51356 .54558 m .52264 .53481 L .52885 .81228 L p .23 .037 .399 r
F P
0 g
s
.56803 .52741 m .58144 .53455 L .57214 .54532 L p .694 .677 .829 r
F P
0 g
s
.57214 .54532 m .55876 .53824 L .56803 .52741 L p .694 .677 .829 r
F P
0 g
s
.57469 .90039 m .55876 .53824 L .57214 .54532 L p .83 .498 .426 r
F P
0 g
s
.57214 .54532 m .59092 .9079 L .57469 .90039 L p .83 .498 .426 r
F P
0 g
s
.60234 .89648 m .59092 .9079 L .57214 .54532 L p .256 .065 .418 r
F P
0 g
s
.57214 .54532 m .58144 .53455 L .60234 .89648 L p .256 .065 .418 r
F P
0 g
s
.57534 .91519 m .55876 .53824 L .57214 .54532 L p .83 .498 .426 r
F P
0 g
s
.57214 .54532 m .59168 .92271 L .57534 .91519 L p .83 .498 .426 r
F P
0 g
s
.60319 .91128 m .59168 .92271 L .57214 .54532 L p .256 .065 .418 r
F P
0 g
s
.57214 .54532 m .58144 .53455 L .60319 .91128 L p .256 .065 .418 r
F P
0 g
s
.62699 .52715 m .64025 .53429 L .63072 .54507 L p .694 .677 .829 r
F P
0 g
s
.63072 .54507 m .61749 .53798 L .62699 .52715 L p .694 .677 .829 r
F P
0 g
s
.64503 .88553 m .61749 .53798 L .63072 .54507 L p .831 .494 .417 r
F P
0 g
s
.63072 .54507 m .66093 .89303 L .64503 .88553 L p .831 .494 .417 r
F P
0 g
s
.67259 .88162 m .66093 .89303 L .63072 .54507 L p .28 .091 .436 r
F P
0 g
s
.63072 .54507 m .64025 .53429 L .67259 .88162 L p .28 .091 .436 r
F P
0 g
s
.64503 .88553 m .61749 .53798 L .63072 .54507 L p .831 .494 .417 r
F P
0 g
s
.63072 .54507 m .66093 .89303 L .64503 .88553 L p .831 .494 .417 r
F P
0 g
s
.67395 .89621 m .6622 .90763 L .63072 .54507 L p .28 .091 .436 r
F P
0 g
s
.63072 .54507 m .64025 .53429 L .67395 .89621 L p .28 .091 .436 r
F P
0 g
s
.29579 .52498 m .3099 .53214 L .30163 .54293 L p .694 .677 .829 r
F P
0 g
s
.30163 .54293 m .28755 .53583 L .29579 .52498 L p .694 .677 .829 r
F P
0 g
s
.24273 .91264 m .28755 .53583 L .30163 .54293 L p .823 .511 .462 r
F P
0 g
s
.30163 .54293 m .26012 .92018 L .24273 .91264 L p .823 .511 .462 r
F P
0 g
s
.27007 .90872 m .26012 .92018 L .30163 .54293 L p .108 0 .308 r
F P
0 g
s
.30163 .54293 m .3099 .53214 L .27007 .90872 L p .108 0 .308 r
F P
0 g
s
.27007 .90872 m .26012 .92018 L .30163 .54293 L p .108 0 .308 r
F P
0 g
s
.30163 .54293 m .3099 .53214 L .27007 .90872 L p .108 0 .308 r
F P
0 g
s
.35477 .52472 m .36874 .53188 L .36024 .54268 L p .694 .677 .829 r
F P
0 g
s
.36024 .54268 m .34631 .53558 L .35477 .52472 L p .694 .677 .829 r
F P
0 g
s
.31479 .91237 m .34631 .53558 L .36024 .54268 L p .825 .508 .454 r
F P
0 g
s
.36024 .54268 m .33196 .91991 L .31479 .91237 L p .825 .508 .454 r
F P
0 g
s
.35098 .89798 m .33417 .8905 L .34432 .87907 L p .683 .708 .867 r
F P
0 g
s
.33307 .9051 m .35001 .91258 L .33984 .92385 L p .682 .709 .868 r
F P
0 g
s
.34225 .90845 m .33196 .91991 L .36024 .54268 L p .145 0 .337 r
F P
0 g
s
.36024 .54268 m .36874 .53188 L .34225 .90845 L p .145 0 .337 r
F P
0 g
s
.31479 .91237 m .34631 .53558 L .36024 .54268 L p .825 .508 .454 r
F P
0 g
s
.36024 .54268 m .33196 .91991 L .31479 .91237 L p .825 .508 .454 r
F P
0 g
s
.34432 .87907 m .33417 .8905 L .36024 .54268 L p .145 0 .337 r
F P
0 g
s
.36024 .54268 m .36874 .53188 L .34432 .87907 L p .145 0 .337 r
F P
0 g
s
.41377 .52447 m .42758 .53162 L .41886 .54242 L p .694 .677 .829 r
F P
0 g
s
.41886 .54242 m .40508 .53532 L .41377 .52447 L p .694 .677 .829 r
F P
0 g
s
.38966 .85416 m .40508 .53532 L .41886 .54242 L p .826 .506 .447 r
F P
0 g
s
.41886 .54242 m .40613 .86166 L .38966 .85416 L p .826 .506 .447 r
F P
0 g
s
.41647 .85026 m .40613 .86166 L .41886 .54242 L p .18 0 .362 r
F P
0 g
s
.41886 .54242 m .42758 .53162 L .41647 .85026 L p .18 0 .362 r
F P
0 g
s
.38758 .8973 m .40508 .53532 L .41886 .54242 L p .826 .506 .447 r
F P
0 g
s
.41886 .54242 m .40441 .90483 L .38758 .8973 L p .826 .506 .447 r
F P
0 g
s
.41647 .85026 m .40613 .86166 L .41886 .54242 L p .18 0 .362 r
F P
0 g
s
.41886 .54242 m .42758 .53162 L .41647 .85026 L p .18 0 .362 r
F P
0 g
s
.47277 .52421 m .48644 .53137 L .47749 .54217 L p .694 .677 .829 r
F P
0 g
s
.47749 .54217 m .46385 .53506 L .47277 .52421 L p .694 .677 .829 r
F P
0 g
s
.45934 .88244 m .46385 .53506 L .47749 .54217 L p .828 .503 .439 r
F P
0 g
s
.47749 .54217 m .47583 .88996 L .45934 .88244 L p .828 .503 .439 r
F P
0 g
s
.48664 .87852 m .47583 .88996 L .47749 .54217 L p .211 .017 .385 r
F P
0 g
s
.47749 .54217 m .48644 .53137 L .48664 .87852 L p .211 .017 .385 r
F P
0 g
s
.45896 .91182 m .46385 .53506 L .47749 .54217 L p .828 .503 .439 r
F P
0 g
s
.47749 .54217 m .47569 .91937 L .45896 .91182 L p .828 .503 .439 r
F P
0 g
s
.48666 .9079 m .47569 .91937 L .47749 .54217 L p .211 .017 .385 r
F P
0 g
s
.47749 .54217 m .48644 .53137 L .48666 .9079 L p .211 .017 .385 r
F P
0 g
s
.53179 .52395 m .54531 .53111 L .53613 .54191 L p .694 .677 .829 r
F P
0 g
s
.53613 .54191 m .52264 .53481 L .53179 .52395 L p .694 .677 .829 r
F P
0 g
s
.52885 .81228 m .54456 .81975 L .53391 .83101 L p .686 .701 .859 r
F P
0 g
s
.53107 .91155 m .52264 .53481 L .53613 .54191 L p .829 .499 .43 r
F P
0 g
s
.53613 .54191 m .54757 .9191 L .53107 .91155 L p .829 .499 .43 r
F P
0 g
s
.55889 .90763 m .54757 .9191 L .53613 .54191 L p .239 .047 .406 r
F P
0 g
s
.53613 .54191 m .54531 .53111 L .55889 .90763 L p .239 .047 .406 r
F P
0 g
s
.52885 .81228 m .52264 .53481 L .53613 .54191 L p .829 .499 .43 r
F P
0 g
s
.53613 .54191 m .54456 .81975 L .52885 .81228 L p .829 .499 .43 r
F P
0 g
s
.55889 .90763 m .54757 .9191 L .53613 .54191 L p .239 .047 .406 r
F P
0 g
s
.53613 .54191 m .54531 .53111 L .55889 .90763 L p .239 .047 .406 r
F P
0 g
s
.59082 .52369 m .60419 .53085 L .59478 .54166 L p .694 .677 .829 r
F P
0 g
s
.59478 .54166 m .58144 .53455 L .59082 .52369 L p .694 .677 .829 r
F P
0 g
s
.60319 .91128 m .58144 .53455 L .59478 .54166 L p .831 .496 .421 r
F P
0 g
s
.59478 .54166 m .61948 .91882 L .60319 .91128 L p .831 .496 .421 r
F P
0 g
s
.63351 .8969 m .61755 .88942 L .62903 .87798 L p .683 .708 .867 r
F P
0 g
s
.61851 .90402 m .63458 .91151 L .62308 .92279 L p .682 .709 .868 r
F P
0 g
s
.63113 .90735 m .61948 .91882 L .59478 .54166 L p .264 .074 .424 r
F P
0 g
s
.59478 .54166 m .60419 .53085 L .63113 .90735 L p .264 .074 .424 r
F P
0 g
s
.60319 .91128 m .58144 .53455 L .59478 .54166 L p .831 .496 .421 r
F P
0 g
s
.59478 .54166 m .61948 .91882 L .60319 .91128 L p .831 .496 .421 r
F P
0 g
s
.62903 .87798 m .61755 .88942 L .59478 .54166 L p .264 .074 .424 r
F P
0 g
s
.59478 .54166 m .60419 .53085 L .62903 .87798 L p .264 .074 .424 r
F P
0 g
s
.64986 .52343 m .66308 .5306 L .65344 .5414 L p .694 .677 .829 r
F P
0 g
s
.65344 .5414 m .64025 .53429 L .64986 .52343 L p .694 .677 .829 r
F P
0 g
s
.67395 .89621 m .68991 .90375 L .67811 .9151 L p .682 .709 .868 r
F P
0 g
s
.67811 .9151 m .6622 .90763 L .67395 .89621 L p .682 .709 .868 r
F P
0 g
s
.67533 .91101 m .64025 .53429 L .65344 .5414 L p .832 .492 .412 r
F P
0 g
s
.65344 .5414 m .6914 .91855 L .67533 .91101 L p .832 .492 .412 r
F P
0 g
s
.70339 .90708 m .6914 .91855 L .65344 .5414 L p .288 .099 .441 r
F P
0 g
s
.65344 .5414 m .66308 .5306 L .70339 .90708 L p .288 .099 .441 r
F P
0 g
s
.67395 .89621 m .64025 .53429 L .65344 .5414 L p .832 .492 .412 r
F P
0 g
s
.65344 .5414 m .68991 .90375 L .67395 .89621 L p .832 .492 .412 r
F P
0 g
s
.70339 .90708 m .6914 .91855 L .65344 .5414 L p .288 .099 .441 r
F P
0 g
s
.65344 .5414 m .66308 .5306 L .70339 .90708 L p .288 .099 .441 r
F P
0 g
s
.31824 .52126 m .33231 .52844 L .32394 .53926 L p .694 .677 .829 r
F P
0 g
s
.32394 .53926 m .3099 .53214 L .31824 .52126 L p .694 .677 .829 r
F P
0 g
s
.27007 .90872 m .3099 .53214 L .32394 .53926 L p .824 .51 .458 r
F P
0 g
s
.32394 .53926 m .28741 .91628 L .27007 .90872 L p .824 .51 .458 r
F P
0 g
s
.30595 .90898 m .28885 .90147 L .29887 .88999 L p .682 .709 .868 r
F P
0 g
s
.29751 .90478 m .28741 .91628 L .32394 .53926 L p .121 0 .318 r
F P
0 g
s
.32394 .53926 m .33231 .52844 L .29751 .90478 L p .121 0 .318 r
F P
0 g
s
.27007 .90872 m .3099 .53214 L .32394 .53926 L p .824 .51 .458 r
F P
0 g
s
.32394 .53926 m .28741 .91628 L .27007 .90872 L p .824 .51 .458 r
F P
0 g
s
.29887 .88999 m .28885 .90147 L .32394 .53926 L p .121 0 .318 r
F P
0 g
s
.32394 .53926 m .33231 .52844 L .29887 .88999 L p .121 0 .318 r
F P
0 g
s
.3773 .521 m .39122 .52818 L .38263 .539 L p .694 .677 .829 r
F P
0 g
s
.38263 .539 m .36874 .53188 L .3773 .521 L p .694 .677 .829 r
F P
0 g
s
.34533 .8647 m .36874 .53188 L .38263 .539 L p .825 .507 .451 r
F P
0 g
s
.38263 .539 m .36207 .87223 L .34533 .8647 L p .825 .507 .451 r
F P
0 g
s
.3723 .86078 m .36207 .87223 L .38263 .539 L p .157 0 .346 r
F P
0 g
s
.38263 .539 m .39122 .52818 L .3723 .86078 L p .157 0 .346 r
F P
0 g
s
.34432 .87907 m .36874 .53188 L .38263 .539 L p .825 .507 .451 r
F P
0 g
s
.38263 .539 m .36118 .88661 L .34432 .87907 L p .825 .507 .451 r
F P
0 g
s
.37148 .87514 m .36118 .88661 L .38263 .539 L p .157 0 .346 r
F P
0 g
s
.38263 .539 m .39122 .52818 L .37148 .87514 L p .157 0 .346 r
F P
0 g
s
.43637 .52074 m .45015 .52792 L .44133 .53875 L p .694 .677 .829 r
F P
0 g
s
.44133 .53875 m .42758 .53162 L .43637 .52074 L p .694 .677 .829 r
F P
0 g
s
.41647 .85026 m .42758 .53162 L .44133 .53875 L p .827 .504 .443 r
F P
0 g
s
.44133 .53875 m .43288 .85778 L .41647 .85026 L p .827 .504 .443 r
F P
0 g
s
.44336 .84634 m .43288 .85778 L .44133 .53875 L p .19 0 .37 r
F P
0 g
s
.44133 .53875 m .45015 .52792 L .44336 .84634 L p .19 0 .37 r
F P
0 g
s
.41647 .85026 m .42758 .53162 L .44133 .53875 L p .827 .504 .443 r
F P
0 g
s
.44133 .53875 m .43288 .85778 L .41647 .85026 L p .827 .504 .443 r
F P
0 g
s
.44244 .88945 m .43173 .90093 L .44133 .53875 L p .19 0 .37 r
F P
0 g
s
.44133 .53875 m .45015 .52792 L .44244 .88945 L p .19 0 .37 r
F P
0 g
s
.49546 .52048 m .50909 .52766 L .50004 .53849 L p .694 .677 .829 r
F P
0 g
s
.50004 .53849 m .48644 .53137 L .49546 .52048 L p .694 .677 .829 r
F P
0 g
s
.48665 .89311 m .48644 .53137 L .50004 .53849 L p .828 .501 .435 r
F P
0 g
s
.50004 .53849 m .5032 .90066 L .48665 .89311 L p .828 .501 .435 r
F P
0 g
s
.51424 .88917 m .5032 .90066 L .50004 .53849 L p .22 .027 .392 r
F P
0 g
s
.50004 .53849 m .50909 .52766 L .51424 .88917 L p .22 .027 .392 r
F P
0 g
s
.48666 .9079 m .48644 .53137 L .50004 .53849 L p .828 .501 .435 r
F P
0 g
s
.50004 .53849 m .50333 .91547 L .48666 .9079 L p .828 .501 .435 r
F P
0 g
s
.51445 .90396 m .50333 .91547 L .50004 .53849 L p .22 .027 .392 r
F P
0 g
s
.50004 .53849 m .50909 .52766 L .51445 .90396 L p .22 .027 .392 r
F P
0 g
s
.55456 .52023 m .56803 .52741 L .55876 .53824 L p .694 .677 .829 r
F P
0 g
s
.55876 .53824 m .54531 .53111 L .55456 .52023 L p .694 .677 .829 r
F P
0 g
s
.55889 .90763 m .54531 .53111 L .55876 .53824 L p .83 .498 .426 r
F P
0 g
s
.55876 .53824 m .57534 .91519 L .55889 .90763 L p .83 .498 .426 r
F P
0 g
s
.59092 .9079 m .57469 .90039 L .58606 .8889 L p .682 .709 .868 r
F P
0 g
s
.5868 .90369 m .57534 .91519 L .55876 .53824 L p .248 .056 .412 r
F P
0 g
s
.55876 .53824 m .56803 .52741 L .5868 .90369 L p .248 .056 .412 r
F P
0 g
s
.55889 .90763 m .54531 .53111 L .55876 .53824 L p .83 .498 .426 r
F P
0 g
s
.55876 .53824 m .57534 .91519 L .55889 .90763 L p .83 .498 .426 r
F P
0 g
s
.58606 .8889 m .57469 .90039 L .55876 .53824 L p .248 .056 .412 r
F P
0 g
s
.55876 .53824 m .56803 .52741 L .58606 .8889 L p .248 .056 .412 r
F P
0 g
s
.61366 .51997 m .62699 .52715 L .61749 .53798 L p .694 .677 .829 r
F P
0 g
s
.61749 .53798 m .60419 .53085 L .61366 .51997 L p .694 .677 .829 r
F P
0 g
s
.628 .86361 m .60419 .53085 L .61749 .53798 L p .831 .494 .417 r
F P
0 g
s
.61749 .53798 m .64389 .87115 L .628 .86361 L p .831 .494 .417 r
F P
0 g
s
.65543 .85968 m .64389 .87115 L .61749 .53798 L p .272 .082 .43 r
F P
0 g
s
.61749 .53798 m .62699 .52715 L .65543 .85968 L p .272 .082 .43 r
F P
0 g
s
.62903 .87798 m .60419 .53085 L .61749 .53798 L p .831 .494 .417 r
F P
0 g
s
.61749 .53798 m .64503 .88553 L .62903 .87798 L p .831 .494 .417 r
F P
0 g
s
.65665 .87405 m .64503 .88553 L .61749 .53798 L p .272 .082 .43 r
F P
0 g
s
.61749 .53798 m .62699 .52715 L .65665 .87405 L p .272 .082 .43 r
F P
0 g
s
.67278 .51971 m .68596 .52689 L .67623 .53772 L p .694 .677 .829 r
F P
0 g
s
.67623 .53772 m .66308 .5306 L .67278 .51971 L p .694 .677 .829 r
F P
0 g
s
.70339 .90708 m .66308 .5306 L .67623 .53772 L p .833 .49 .407 r
F P
0 g
s
.67623 .53772 m .7194 .91465 L .70339 .90708 L p .833 .49 .407 r
F P
0 g
s
.73155 .90314 m .7194 .91465 L .67623 .53772 L p .295 .107 .446 r
F P
0 g
s
.67623 .53772 m .68596 .52689 L .73155 .90314 L p .295 .107 .446 r
F P
0 g
s
.70339 .90708 m .66308 .5306 L .67623 .53772 L p .833 .49 .407 r
F P
0 g
s
.67623 .53772 m .7194 .91465 L .70339 .90708 L p .833 .49 .407 r
F P
0 g
s
.28161 .51779 m .29579 .52498 L .28755 .53583 L p .694 .677 .829 r
F P
0 g
s
.28755 .53583 m .2734 .52869 L .28161 .51779 L p .694 .677 .829 r
F P
0 g
s
.22522 .90506 m .2734 .52869 L .28755 .53583 L p .823 .511 .462 r
F P
0 g
s
.28755 .53583 m .24273 .91264 L .22522 .90506 L p .823 .511 .462 r
F P
0 g
s
.25263 .90111 m .24273 .91264 L .28755 .53583 L p .094 0 .298 r
F P
0 g
s
.28755 .53583 m .29579 .52498 L .25263 .90111 L p .094 0 .298 r
F P
0 g
s
.25263 .90111 m .24273 .91264 L .28755 .53583 L p .094 0 .298 r
F P
0 g
s
.28755 .53583 m .29579 .52498 L .25263 .90111 L p .094 0 .298 r
F P
0 g
s
.34074 .51753 m .35477 .52472 L .34631 .53558 L p .694 .677 .829 r
F P
0 g
s
.34631 .53558 m .33231 .52844 L .34074 .51753 L p .694 .677 .829 r
F P
0 g
s
.29887 .88999 m .31603 .89757 L .30595 .90898 L p .682 .709 .868 r
F P
0 g
s
.29751 .90478 m .33231 .52844 L .34631 .53558 L p .825 .508 .454 r
F P
0 g
s
.34631 .53558 m .31479 .91237 L .29751 .90478 L p .825 .508 .454 r
F P
0 g
s
.32503 .90084 m .31479 .91237 L .34631 .53558 L p .133 0 .328 r
F P
0 g
s
.34631 .53558 m .35477 .52472 L .32503 .90084 L p .133 0 .328 r
F P
0 g
s
.29887 .88999 m .33231 .52844 L .34631 .53558 L p .825 .508 .454 r
F P
0 g
s
.34631 .53558 m .31603 .89757 L .29887 .88999 L p .825 .508 .454 r
F P
0 g
s
.32503 .90084 m .31479 .91237 L .34631 .53558 L p .133 0 .328 r
F P
0 g
s
.34631 .53558 m .35477 .52472 L .32503 .90084 L p .133 0 .328 r
F P
0 g
s
.39988 .51727 m .41377 .52447 L .40508 .53532 L p .694 .677 .829 r
F P
0 g
s
.40508 .53532 m .39122 .52818 L .39988 .51727 L p .694 .677 .829 r
F P
0 g
s
.3731 .84661 m .39122 .52818 L .40508 .53532 L p .826 .506 .447 r
F P
0 g
s
.40508 .53532 m .38966 .85416 L .3731 .84661 L p .826 .506 .447 r
F P
0 g
s
.39996 .84269 m .38966 .85416 L .40508 .53532 L p .169 0 .354 r
F P
0 g
s
.40508 .53532 m .41377 .52447 L .39996 .84269 L p .169 0 .354 r
F P
0 g
s
.37148 .87514 m .39122 .52818 L .40508 .53532 L p .826 .506 .447 r
F P
0 g
s
.40508 .53532 m .38828 .88271 L .37148 .87514 L p .826 .506 .447 r
F P
0 g
s
.39996 .84269 m .38966 .85416 L .40508 .53532 L p .169 0 .354 r
F P
0 g
s
.40508 .53532 m .41377 .52447 L .39996 .84269 L p .169 0 .354 r
F P
0 g
s
.45904 .51701 m .47277 .52421 L .46385 .53506 L p .694 .677 .829 r
F P
0 g
s
.46385 .53506 m .45015 .52792 L .45904 .51701 L p .694 .677 .829 r
F P
0 g
s
.44275 .87487 m .45015 .52792 L .46385 .53506 L p .828 .503 .439 r
F P
0 g
s
.46385 .53506 m .45934 .88244 L .44275 .87487 L p .828 .503 .439 r
F P
0 g
s
.47011 .87093 m .45934 .88244 L .46385 .53506 L p .201 .006 .378 r
F P
0 g
s
.46385 .53506 m .47277 .52421 L .47011 .87093 L p .201 .006 .378 r
F P
0 g
s
.44244 .88945 m .45015 .52792 L .46385 .53506 L p .828 .503 .439 r
F P
0 g
s
.46385 .53506 m .45915 .89703 L .44244 .88945 L p .828 .503 .439 r
F P
0 g
s
.47011 .87093 m .45934 .88244 L .46385 .53506 L p .201 .006 .378 r
F P
0 g
s
.46385 .53506 m .47277 .52421 L .47011 .87093 L p .201 .006 .378 r
F P
0 g
s
.5182 .51675 m .53179 .52395 L .52264 .53481 L p .694 .677 .829 r
F P
0 g
s
.52264 .53481 m .50909 .52766 L .5182 .51675 L p .694 .677 .829 r
F P
0 g
s
.51285 .79138 m .50909 .52766 L .52264 .53481 L p .829 .499 .43 r
F P
0 g
s
.52264 .53481 m .52855 .79889 L .51285 .79138 L p .829 .499 .43 r
F P
0 g
s
.53918 .78748 m .52855 .79889 L .52264 .53481 L p .23 .037 .399 r
F P
0 g
s
.52264 .53481 m .53179 .52395 L .53918 .78748 L p .23 .037 .399 r
F P
0 g
s
.51445 .90396 m .50909 .52766 L .52264 .53481 L p .829 .499 .43 r
F P
0 g
s
.52264 .53481 m .53107 .91155 L .51445 .90396 L p .829 .499 .43 r
F P
0 g
s
.54234 .90001 m .53107 .91155 L .52264 .53481 L p .23 .037 .399 r
F P
0 g
s
.52264 .53481 m .53179 .52395 L .54234 .90001 L p .23 .037 .399 r
F P
0 g
s
.57738 .51649 m .59082 .52369 L .58144 .53455 L p .694 .677 .829 r
F P
0 g
s
.58144 .53455 m .56803 .52741 L .57738 .51649 L p .694 .677 .829 r
F P
0 g
s
.58606 .8889 m .60234 .89648 L .59092 .9079 L p .682 .709 .868 r
F P
0 g
s
.5868 .90369 m .56803 .52741 L .58144 .53455 L p .831 .496 .421 r
F P
0 g
s
.58144 .53455 m .60319 .91128 L .5868 .90369 L p .831 .496 .421 r
F P
0 g
s
.6148 .89974 m .60319 .91128 L .58144 .53455 L p .256 .065 .418 r
F P
0 g
s
.58144 .53455 m .59082 .52369 L .6148 .89974 L p .256 .065 .418 r
F P
0 g
s
.58606 .8889 m .56803 .52741 L .58144 .53455 L p .831 .496 .421 r
F P
0 g
s
.58144 .53455 m .60234 .89648 L .58606 .8889 L p .831 .496 .421 r
F P
0 g
s
.6148 .89974 m .60319 .91128 L .58144 .53455 L p .256 .065 .418 r
F P
0 g
s
.58144 .53455 m .59082 .52369 L .6148 .89974 L p .256 .065 .418 r
F P
0 g
s
.63657 .51623 m .64986 .52343 L .64025 .53429 L p .694 .677 .829 r
F P
0 g
s
.64025 .53429 m .62699 .52715 L .63657 .51623 L p .694 .677 .829 r
F P
0 g
s
.64503 .88553 m .66093 .89303 L .64938 .90434 L p .683 .708 .867 r
F P
0 g
s
.65665 .87405 m .67259 .88162 L .66093 .89303 L p .683 .708 .867 r
F P
0 g
s
.66093 .89303 m .64503 .88553 L .65665 .87405 L p .683 .708 .867 r
F P
0 g
s
.65917 .90341 m .62699 .52715 L .64025 .53429 L p .832 .492 .412 r
F P
0 g
s
.64025 .53429 m .67533 .91101 L .65917 .90341 L p .832 .492 .412 r
F P
0 g
s
.68729 .89946 m .67533 .91101 L .64025 .53429 L p .28 .091 .436 r
F P
0 g
s
.64025 .53429 m .64986 .52343 L .68729 .89946 L p .28 .091 .436 r
F P
0 g
s
.65665 .87405 m .62699 .52715 L .64025 .53429 L p .832 .492 .412 r
F P
0 g
s
.64025 .53429 m .67259 .88162 L .65665 .87405 L p .832 .492 .412 r
F P
0 g
s
.68729 .89946 m .67533 .91101 L .64025 .53429 L p .28 .091 .436 r
F P
0 g
s
.64025 .53429 m .64986 .52343 L .68729 .89946 L p .28 .091 .436 r
F P
0 g
s
.30409 .51405 m .31824 .52126 L .3099 .53214 L p .694 .677 .829 r
F P
0 g
s
.3099 .53214 m .29579 .52498 L .30409 .51405 L p .694 .677 .829 r
F P
0 g
s
.25432 .88633 m .29579 .52498 L .3099 .53214 L p .824 .51 .458 r
F P
0 g
s
.3099 .53214 m .27164 .89392 L .25432 .88633 L p .824 .51 .458 r
F P
0 g
s
.28162 .88237 m .27164 .89392 L .3099 .53214 L p .108 0 .308 r
F P
0 g
s
.3099 .53214 m .31824 .52126 L .28162 .88237 L p .108 0 .308 r
F P
0 g
s
.25263 .90111 m .29579 .52498 L .3099 .53214 L p .824 .51 .458 r
F P
0 g
s
.3099 .53214 m .27007 .90872 L .25263 .90111 L p .824 .51 .458 r
F P
0 g
s
.28012 .89715 m .27007 .90872 L .3099 .53214 L p .108 0 .308 r
F P
0 g
s
.3099 .53214 m .31824 .52126 L .28012 .89715 L p .108 0 .308 r
F P
0 g
s
.3633 .51379 m .3773 .521 L .36874 .53188 L p .694 .677 .829 r
F P
0 g
s
.36874 .53188 m .35477 .52472 L .3633 .51379 L p .694 .677 .829 r
F P
0 g
s
.32503 .90084 m .35477 .52472 L .36874 .53188 L p .825 .507 .451 r
F P
0 g
s
.36874 .53188 m .34225 .90845 L .32503 .90084 L p .825 .507 .451 r
F P
0 g
s
.3677 .9054 m .35098 .89798 L .36118 .88661 L p .683 .708 .867 r
F P
0 g
s
.36207 .87223 m .34533 .8647 L .35551 .85317 L p .683 .706 .865 r
F P
0 g
s
.34432 .87907 m .36118 .88661 L .35098 .89798 L p .683 .708 .867 r
F P
0 g
s
.35264 .89688 m .34225 .90845 L .36874 .53188 L p .145 0 .337 r
F P
0 g
s
.36874 .53188 m .3773 .521 L .35264 .89688 L p .145 0 .337 r
F P
0 g
s
.32503 .90084 m .35477 .52472 L .36874 .53188 L p .825 .507 .451 r
F P
0 g
s
.36874 .53188 m .34225 .90845 L .32503 .90084 L p .825 .507 .451 r
F P
0 g
s
.35551 .85317 m .34533 .8647 L .36874 .53188 L p .145 0 .337 r
F P
0 g
s
.36874 .53188 m .3773 .521 L .35551 .85317 L p .145 0 .337 r
F P
0 g
s
.42253 .51353 m .43637 .52074 L .42758 .53162 L p .694 .677 .829 r
F P
0 g
s
.42758 .53162 m .41377 .52447 L .42253 .51353 L p .694 .677 .829 r
F P
0 g
s
.40057 .82873 m .41377 .52447 L .42758 .53162 L p .827 .504 .443 r
F P
0 g
s
.42758 .53162 m .41696 .83629 L .40057 .82873 L p .827 .504 .443 r
F P
0 g
s
.42732 .8248 m .41696 .83629 L .42758 .53162 L p .18 0 .362 r
F P
0 g
s
.42758 .53162 m .43637 .52074 L .42732 .8248 L p .18 0 .362 r
F P
0 g
s
.39996 .84269 m .41377 .52447 L .42758 .53162 L p .827 .504 .443 r
F P
0 g
s
.42758 .53162 m .41647 .85026 L .39996 .84269 L p .827 .504 .443 r
F P
0 g
s
.4269 .83875 m .41647 .85026 L .42758 .53162 L p .18 0 .362 r
F P
0 g
s
.42758 .53162 m .43637 .52074 L .4269 .83875 L p .18 0 .362 r
F P
0 g
s
.48176 .51327 m .49546 .52048 L .48644 .53137 L p .694 .677 .829 r
F P
0 g
s
.48644 .53137 m .47277 .52421 L .48176 .51327 L p .694 .677 .829 r
F P
0 g
s
.47011 .87093 m .47277 .52421 L .48644 .53137 L p .828 .501 .435 r
F P
0 g
s
.48644 .53137 m .48664 .87852 L .47011 .87093 L p .828 .501 .435 r
F P
0 g
s
.49756 .86698 m .48664 .87852 L .48644 .53137 L p .211 .017 .385 r
F P
0 g
s
.48644 .53137 m .49546 .52048 L .49756 .86698 L p .211 .017 .385 r
F P
0 g
s
.47011 .87093 m .47277 .52421 L .48644 .53137 L p .828 .501 .435 r
F P
0 g
s
.48644 .53137 m .48664 .87852 L .47011 .87093 L p .828 .501 .435 r
F P
0 g
s
.49765 .88154 m .48665 .89311 L .48644 .53137 L p .211 .017 .385 r
F P
0 g
s
.48644 .53137 m .49546 .52048 L .49765 .88154 L p .211 .017 .385 r
F P
0 g
s
.54101 .51301 m .55456 .52023 L .54531 .53111 L p .694 .677 .829 r
F P
0 g
s
.54531 .53111 m .53179 .52395 L .54101 .51301 L p .694 .677 .829 r
F P
0 g
s
.54192 .88523 m .53179 .52395 L .54531 .53111 L p .83 .498 .426 r
F P
0 g
s
.54531 .53111 m .55835 .89283 L .54192 .88523 L p .83 .498 .426 r
F P
0 g
s
.56969 .88127 m .55835 .89283 L .54531 .53111 L p .239 .047 .406 r
F P
0 g
s
.54531 .53111 m .55456 .52023 L .56969 .88127 L p .239 .047 .406 r
F P
0 g
s
.54234 .90001 m .53179 .52395 L .54531 .53111 L p .83 .498 .426 r
F P
0 g
s
.54531 .53111 m .55889 .90763 L .54234 .90001 L p .83 .498 .426 r
F P
0 g
s
.57031 .89605 m .55889 .90763 L .54531 .53111 L p .239 .047 .406 r
F P
0 g
s
.54531 .53111 m .55456 .52023 L .57031 .89605 L p .239 .047 .406 r
F P
0 g
s
.60027 .51275 m .61366 .51997 L .60419 .53085 L p .694 .677 .829 r
F P
0 g
s
.60419 .53085 m .59082 .52369 L .60027 .51275 L p .694 .677 .829 r
F P
0 g
s
.6148 .89974 m .59082 .52369 L .60419 .53085 L p .831 .494 .417 r
F P
0 g
s
.60419 .53085 m .63113 .90735 L .6148 .89974 L p .831 .494 .417 r
F P
0 g
s
.64938 .90434 m .63351 .8969 L .64503 .88553 L p .683 .708 .867 r
F P
0 g
s
.64389 .87115 m .628 .86361 L .6395 .85207 L p .683 .706 .865 r
F P
0 g
s
.62903 .87798 m .64503 .88553 L .63351 .8969 L p .683 .708 .867 r
F P
0 g
s
.6429 .89577 m .63113 .90735 L .60419 .53085 L p .264 .074 .424 r
F P
0 g
s
.60419 .53085 m .61366 .51997 L .6429 .89577 L p .264 .074 .424 r
F P
0 g
s
.6148 .89974 m .59082 .52369 L .60419 .53085 L p .831 .494 .417 r
F P
0 g
s
.60419 .53085 m .63113 .90735 L .6148 .89974 L p .831 .494 .417 r
F P
0 g
s
.6395 .85207 m .628 .86361 L .60419 .53085 L p .264 .074 .424 r
F P
0 g
s
.60419 .53085 m .61366 .51997 L .6395 .85207 L p .264 .074 .424 r
F P
0 g
s
.65954 .51249 m .67278 .51971 L .66308 .5306 L p .694 .677 .829 r
F P
0 g
s
.66308 .5306 m .64986 .52343 L .65954 .51249 L p .694 .677 .829 r
F P
0 g
s
.68582 .88468 m .64986 .52343 L .66308 .5306 L p .833 .49 .407 r
F P
0 g
s
.66308 .5306 m .70181 .89229 L .68582 .88468 L p .833 .49 .407 r
F P
0 g
s
.71382 .88072 m .70181 .89229 L .66308 .5306 L p .288 .099 .441 r
F P
0 g
s
.66308 .5306 m .67278 .51971 L .71382 .88072 L p .288 .099 .441 r
F P
0 g
s
.68729 .89946 m .64986 .52343 L .66308 .5306 L p .833 .49 .407 r
F P
0 g
s
.66308 .5306 m .70339 .90708 L .68729 .89946 L p .833 .49 .407 r
F P
0 g
s
.7155 .8955 m .70339 .90708 L .66308 .5306 L p .288 .099 .441 r
F P
0 g
s
.66308 .5306 m .67278 .51971 L .7155 .8955 L p .288 .099 .441 r
F P
0 g
s
.26735 .51056 m .28161 .51779 L .2734 .52869 L p .694 .677 .829 r
F P
0 g
s
.2734 .52869 m .25918 .52152 L .26735 .51056 L p .694 .677 .829 r
F P
0 g
s
.20761 .89743 m .25918 .52152 L .2734 .52869 L p .823 .511 .462 r
F P
0 g
s
.2734 .52869 m .22522 .90506 L .20761 .89743 L p .823 .511 .462 r
F P
0 g
s
.23507 .89346 m .22522 .90506 L .2734 .52869 L p .08 0 .287 r
F P
0 g
s
.2734 .52869 m .28161 .51779 L .23507 .89346 L p .08 0 .287 r
F P
0 g
s
.23507 .89346 m .22522 .90506 L .2734 .52869 L p .08 0 .287 r
F P
0 g
s
.2734 .52869 m .28161 .51779 L .23507 .89346 L p .08 0 .287 r
F P
0 g
s
.32663 .5103 m .34074 .51753 L .33231 .52844 L p .694 .677 .829 r
F P
0 g
s
.33231 .52844 m .31824 .52126 L .32663 .5103 L p .694 .677 .829 r
F P
0 g
s
.28309 .8678 m .31824 .52126 L .33231 .52844 L p .825 .508 .454 r
F P
0 g
s
.33231 .52844 m .30022 .87542 L .28309 .8678 L p .825 .508 .454 r
F P
0 g
s
.31028 .86384 m .30022 .87542 L .33231 .52844 L p .121 0 .318 r
F P
0 g
s
.33231 .52844 m .34074 .51753 L .31028 .86384 L p .121 0 .318 r
F P
0 g
s
.28012 .89715 m .31824 .52126 L .33231 .52844 L p .825 .508 .454 r
F P
0 g
s
.33231 .52844 m .29751 .90478 L .28012 .89715 L p .825 .508 .454 r
F P
0 g
s
.3077 .89318 m .29751 .90478 L .33231 .52844 L p .121 0 .318 r
F P
0 g
s
.33231 .52844 m .34074 .51753 L .3077 .89318 L p .121 0 .318 r
F P
0 g
s
.38593 .51004 m .39988 .51727 L .39122 .52818 L p .694 .677 .829 r
F P
0 g
s
.39122 .52818 m .3773 .521 L .38593 .51004 L p .694 .677 .829 r
F P
0 g
s
.35644 .83902 m .3773 .521 L .39122 .52818 L p .826 .506 .447 r
F P
0 g
s
.39122 .52818 m .3731 .84661 L .35644 .83902 L p .826 .506 .447 r
F P
0 g
s
.38335 .83507 m .3731 .84661 L .39122 .52818 L p .157 0 .346 r
F P
0 g
s
.39122 .52818 m .39988 .51727 L .38335 .83507 L p .157 0 .346 r
F P
0 g
s
.35551 .85317 m .3773 .521 L .39122 .52818 L p .826 .506 .447 r
F P
0 g
s
.39122 .52818 m .3723 .86078 L .35551 .85317 L p .826 .506 .447 r
F P
0 g
s
.38335 .83507 m .3731 .84661 L .39122 .52818 L p .157 0 .346 r
F P
0 g
s
.39122 .52818 m .39988 .51727 L .38335 .83507 L p .157 0 .346 r
F P
0 g
s
.44523 .50978 m .45904 .51701 L .45015 .52792 L p .694 .677 .829 r
F P
0 g
s
.45015 .52792 m .43637 .52074 L .44523 .50978 L p .694 .677 .829 r
F P
0 g
s
.4269 .83875 m .43637 .52074 L .45015 .52792 L p .828 .503 .439 r
F P
0 g
s
.45015 .52792 m .44336 .84634 L .4269 .83875 L p .828 .503 .439 r
F P
0 g
s
.45393 .8348 m .44336 .84634 L .45015 .52792 L p .19 0 .37 r
F P
0 g
s
.45015 .52792 m .45904 .51701 L .45393 .8348 L p .19 0 .37 r
F P
0 g
s
.4269 .83875 m .43637 .52074 L .45015 .52792 L p .828 .503 .439 r
F P
0 g
s
.45015 .52792 m .44336 .84634 L .4269 .83875 L p .828 .503 .439 r
F P
0 g
s
.45347 .86329 m .44275 .87487 L .45015 .52792 L p .19 0 .37 r
F P
0 g
s
.45015 .52792 m .45904 .51701 L .45347 .86329 L p .19 0 .37 r
F P
0 g
s
.50455 .50952 m .5182 .51675 L .50909 .52766 L p .694 .677 .829 r
F P
0 g
s
.50909 .52766 m .49546 .52048 L .50455 .50952 L p .694 .677 .829 r
F P
0 g
s
.49706 .78384 m .49546 .52048 L .50909 .52766 L p .829 .499 .43 r
F P
0 g
s
.50909 .52766 m .51285 .79138 L .49706 .78384 L p .829 .499 .43 r
F P
0 g
s
.52344 .77991 m .51285 .79138 L .50909 .52766 L p .22 .027 .392 r
F P
0 g
s
.50909 .52766 m .5182 .51675 L .52344 .77991 L p .22 .027 .392 r
F P
0 g
s
.49765 .88154 m .49546 .52048 L .50909 .52766 L p .829 .499 .43 r
F P
0 g
s
.50909 .52766 m .51424 .88917 L .49765 .88154 L p .829 .499 .43 r
F P
0 g
s
.52344 .77991 m .51285 .79138 L .50909 .52766 L p .22 .027 .392 r
F P
0 g
s
.50909 .52766 m .5182 .51675 L .52344 .77991 L p .22 .027 .392 r
F P
0 g
s
.56388 .50926 m .57738 .51649 L .56803 .52741 L p .694 .677 .829 r
F P
0 g
s
.56803 .52741 m .55456 .52023 L .56388 .50926 L p .694 .677 .829 r
F P
0 g
s
.56908 .8667 m .55456 .52023 L .56803 .52741 L p .831 .496 .421 r
F P
0 g
s
.56803 .52741 m .58534 .87432 L .56908 .8667 L p .831 .496 .421 r
F P
0 g
s
.59673 .86274 m .58534 .87432 L .56803 .52741 L p .248 .056 .412 r
F P
0 g
s
.56803 .52741 m .57738 .51649 L .59673 .86274 L p .248 .056 .412 r
F P
0 g
s
.57031 .89605 m .55456 .52023 L .56803 .52741 L p .831 .496 .421 r
F P
0 g
s
.56803 .52741 m .5868 .90369 L .57031 .89605 L p .831 .496 .421 r
F P
0 g
s
.59837 .89207 m .5868 .90369 L .56803 .52741 L p .248 .056 .412 r
F P
0 g
s
.56803 .52741 m .57738 .51649 L .59837 .89207 L p .248 .056 .412 r
F P
0 g
s
.62321 .50899 m .63657 .51623 L .62699 .52715 L p .694 .677 .829 r
F P
0 g
s
.62699 .52715 m .61366 .51997 L .62321 .50899 L p .694 .677 .829 r
F P
0 g
s
.6395 .85207 m .65543 .85968 L .64389 .87115 L p .683 .706 .865 r
F P
0 g
s
.6429 .89577 m .61366 .51997 L .62699 .52715 L p .832 .492 .412 r
F P
0 g
s
.62699 .52715 m .65917 .90341 L .6429 .89577 L p .832 .492 .412 r
F P
0 g
s
.67108 .8918 m .65917 .90341 L .62699 .52715 L p .272 .082 .43 r
F P
0 g
s
.62699 .52715 m .63657 .51623 L .67108 .8918 L p .272 .082 .43 r
F P
0 g
s
.6395 .85207 m .61366 .51997 L .62699 .52715 L p .832 .492 .412 r
F P
0 g
s
.62699 .52715 m .65543 .85968 L .6395 .85207 L p .832 .492 .412 r
F P
0 g
s
.67108 .8918 m .65917 .90341 L .62699 .52715 L p .272 .082 .43 r
F P
0 g
s
.62699 .52715 m .63657 .51623 L .67108 .8918 L p .272 .082 .43 r
F P
0 g
s
.68256 .50873 m .69577 .51597 L .68596 .52689 L p .694 .677 .829 r
F P
0 g
s
.68596 .52689 m .67278 .51971 L .68256 .50873 L p .694 .677 .829 r
F P
0 g
s
.7155 .8955 m .67278 .51971 L .68596 .52689 L p .833 .488 .402 r
F P
0 g
s
.68596 .52689 m .73155 .90314 L .7155 .8955 L p .833 .488 .402 r
F P
0 g
s
.74381 .89152 m .73155 .90314 L .68596 .52689 L p .295 .107 .446 r
F P
0 g
s
.68596 .52689 m .69577 .51597 L .74381 .89152 L p .295 .107 .446 r
F P
0 g
s
.7155 .8955 m .67278 .51971 L .68596 .52689 L p .833 .488 .402 r
F P
0 g
s
.68596 .52689 m .73155 .90314 L .7155 .8955 L p .833 .488 .402 r
F P
0 g
s
.28987 .5068 m .30409 .51405 L .29579 .52498 L p .694 .677 .829 r
F P
0 g
s
.29579 .52498 m .28161 .51779 L .28987 .5068 L p .694 .677 .829 r
F P
0 g
s
.23507 .89346 m .28161 .51779 L .29579 .52498 L p .824 .51 .458 r
F P
0 g
s
.29579 .52498 m .25263 .90111 L .23507 .89346 L p .824 .51 .458 r
F P
0 g
s
.27164 .89392 m .25432 .88633 L .26425 .8747 L p .682 .709 .868 r
F P
0 g
s
.26262 .88947 m .25263 .90111 L .29579 .52498 L p .094 0 .298 r
F P
0 g
s
.29579 .52498 m .30409 .51405 L .26262 .88947 L p .094 0 .298 r
F P
0 g
s
.23507 .89346 m .28161 .51779 L .29579 .52498 L p .824 .51 .458 r
F P
0 g
s
.29579 .52498 m .25263 .90111 L .23507 .89346 L p .824 .51 .458 r
F P
0 g
s
.26425 .8747 m .25432 .88633 L .29579 .52498 L p .094 0 .298 r
F P
0 g
s
.29579 .52498 m .30409 .51405 L .26425 .8747 L p .094 0 .298 r
F P
0 g
s
.34924 .50654 m .3633 .51379 L .35477 .52472 L p .694 .677 .829 r
F P
0 g
s
.35477 .52472 m .34074 .51753 L .34924 .50654 L p .694 .677 .829 r
F P
0 g
s
.309 .8784 m .34074 .51753 L .35477 .52472 L p .825 .507 .451 r
F P
0 g
s
.35477 .52472 m .3262 .88605 L .309 .8784 L p .825 .507 .451 r
F P
0 g
s
.33647 .87442 m .3262 .88605 L .35477 .52472 L p .133 0 .328 r
F P
0 g
s
.35477 .52472 m .3633 .51379 L .33647 .87442 L p .133 0 .328 r
F P
0 g
s
.3077 .89318 m .34074 .51753 L .35477 .52472 L p .825 .507 .451 r
F P
0 g
s
.35477 .52472 m .32503 .90084 L .3077 .89318 L p .825 .507 .451 r
F P
0 g
s
.33537 .88919 m .32503 .90084 L .35477 .52472 L p .133 0 .328 r
F P
0 g
s
.35477 .52472 m .3633 .51379 L .33537 .88919 L p .133 0 .328 r
F P
0 g
s
.40861 .50628 m .42253 .51353 L .41377 .52447 L p .694 .677 .829 r
F P
0 g
s
.41377 .52447 m .39988 .51727 L .40861 .50628 L p .694 .677 .829 r
F P
0 g
s
.38335 .83507 m .39988 .51727 L .41377 .52447 L p .827 .504 .443 r
F P
0 g
s
.41377 .52447 m .39996 .84269 L .38335 .83507 L p .827 .504 .443 r
F P
0 g
s
.41696 .83629 m .40057 .82873 L .41089 .81717 L p .685 .704 .862 r
F P
0 g
s
.41035 .83111 m .39996 .84269 L .41377 .52447 L p .169 0 .354 r
F P
0 g
s
.41377 .52447 m .42253 .51353 L .41035 .83111 L p .169 0 .354 r
F P
0 g
s
.38335 .83507 m .39988 .51727 L .41377 .52447 L p .827 .504 .443 r
F P
0 g
s
.41377 .52447 m .39996 .84269 L .38335 .83507 L p .827 .504 .443 r
F P
0 g
s
.41089 .81717 m .40057 .82873 L .41377 .52447 L p .169 0 .354 r
F P
0 g
s
.41377 .52447 m .42253 .51353 L .41089 .81717 L p .169 0 .354 r
F P
0 g
s
.468 .50602 m .48176 .51327 L .47277 .52421 L p .694 .677 .829 r
F P
0 g
s
.47277 .52421 m .45904 .51701 L .468 .50602 L p .694 .677 .829 r
F P
0 g
s
.45371 .84894 m .45904 .51701 L .47277 .52421 L p .828 .501 .435 r
F P
0 g
s
.47277 .52421 m .47022 .85657 L .45371 .84894 L p .828 .501 .435 r
F P
0 g
s
.48102 .84497 m .47022 .85657 L .47277 .52421 L p .201 .006 .378 r
F P
0 g
s
.47277 .52421 m .48176 .51327 L .48102 .84497 L p .201 .006 .378 r
F P
0 g
s
.45347 .86329 m .45904 .51701 L .47277 .52421 L p .828 .501 .435 r
F P
0 g
s
.47277 .52421 m .47011 .87093 L .45347 .86329 L p .828 .501 .435 r
F P
0 g
s
.48098 .85931 m .47011 .87093 L .47277 .52421 L p .201 .006 .378 r
F P
0 g
s
.47277 .52421 m .48176 .51327 L .48098 .85931 L p .201 .006 .378 r
F P
0 g
s
.5274 .50575 m .54101 .51301 L .53179 .52395 L p .694 .677 .829 r
F P
0 g
s
.53179 .52395 m .5182 .51675 L .5274 .50575 L p .694 .677 .829 r
F P
0 g
s
.52344 .77991 m .5182 .51675 L .53179 .52395 L p .83 .498 .426 r
F P
0 g
s
.53179 .52395 m .53918 .78748 L .52344 .77991 L p .83 .498 .426 r
F P
0 g
s
.54991 .77597 m .53918 .78748 L .53179 .52395 L p .23 .037 .399 r
F P
0 g
s
.53179 .52395 m .54101 .51301 L .54991 .77597 L p .23 .037 .399 r
F P
0 g
s
.52344 .77991 m .5182 .51675 L .53179 .52395 L p .83 .498 .426 r
F P
0 g
s
.53179 .52395 m .53918 .78748 L .52344 .77991 L p .83 .498 .426 r
F P
0 g
s
.55322 .87359 m .54192 .88523 L .53179 .52395 L p .23 .037 .399 r
F P
0 g
s
.53179 .52395 m .54101 .51301 L .55322 .87359 L p .23 .037 .399 r
F P
0 g
s
.5868 .50549 m .60027 .51275 L .59082 .52369 L p .694 .677 .829 r
F P
0 g
s
.59082 .52369 m .57738 .51649 L .5868 .50549 L p .694 .677 .829 r
F P
0 g
s
.59755 .8773 m .57738 .51649 L .59082 .52369 L p .831 .494 .417 r
F P
0 g
s
.59082 .52369 m .61386 .88495 L .59755 .8773 L p .831 .494 .417 r
F P
0 g
s
.6255 .87331 m .61386 .88495 L .59082 .52369 L p .256 .065 .418 r
F P
0 g
s
.59082 .52369 m .60027 .51275 L .6255 .87331 L p .256 .065 .418 r
F P
0 g
s
.59837 .89207 m .57738 .51649 L .59082 .52369 L p .831 .494 .417 r
F P
0 g
s
.59082 .52369 m .6148 .89974 L .59837 .89207 L p .831 .494 .417 r
F P
0 g
s
.62653 .88808 m .6148 .89974 L .59082 .52369 L p .256 .065 .418 r
F P
0 g
s
.59082 .52369 m .60027 .51275 L .62653 .88808 L p .256 .065 .418 r
F P
0 g
s
.64622 .50523 m .65954 .51249 L .64986 .52343 L p .694 .677 .829 r
F P
0 g
s
.64986 .52343 m .63657 .51623 L .64622 .50523 L p .694 .677 .829 r
F P
0 g
s
.67108 .8918 m .63657 .51623 L .64986 .52343 L p .833 .49 .407 r
F P
0 g
s
.64986 .52343 m .68729 .89946 L .67108 .8918 L p .833 .49 .407 r
F P
0 g
s
.70181 .89229 m .68582 .88468 L .69779 .87304 L p .682 .709 .868 r
F P
0 g
s
.69936 .88781 m .68729 .89946 L .64986 .52343 L p .28 .091 .436 r
F P
0 g
s
.64986 .52343 m .65954 .51249 L .69936 .88781 L p .28 .091 .436 r
F P
0 g
s
.67108 .8918 m .63657 .51623 L .64986 .52343 L p .833 .49 .407 r
F P
0 g
s
.64986 .52343 m .68729 .89946 L .67108 .8918 L p .833 .49 .407 r
F P
0 g
s
.69779 .87304 m .68582 .88468 L .64986 .52343 L p .28 .091 .436 r
F P
0 g
s
.64986 .52343 m .65954 .51249 L .69779 .87304 L p .28 .091 .436 r
F P
0 g
s
.25302 .50329 m .26735 .51056 L .25918 .52152 L p .694 .677 .829 r
F P
0 g
s
.25918 .52152 m .24489 .51431 L .25302 .50329 L p .694 .677 .829 r
F P
0 g
s
.18989 .88975 m .24489 .51431 L .25918 .52152 L p .823 .511 .462 r
F P
0 g
s
.25918 .52152 m .20761 .89743 L .18989 .88975 L p .823 .511 .462 r
F P
0 g
s
.2174 .88575 m .20761 .89743 L .25918 .52152 L p .066 0 .276 r
F P
0 g
s
.25918 .52152 m .26735 .51056 L .2174 .88575 L p .066 0 .276 r
F P
0 g
s
.2174 .88575 m .20761 .89743 L .25918 .52152 L p .066 0 .276 r
F P
0 g
s
.25918 .52152 m .26735 .51056 L .2174 .88575 L p .066 0 .276 r
F P
0 g
s
.31246 .50303 m .32663 .5103 L .31824 .52126 L p .694 .677 .829 r
F P
0 g
s
.31824 .52126 m .30409 .51405 L .31246 .50303 L p .694 .677 .829 r
F P
0 g
s
.26586 .86014 m .30409 .51405 L .31824 .52126 L p .825 .508 .454 r
F P
0 g
s
.31824 .52126 m .28309 .8678 L .26586 .86014 L p .825 .508 .454 r
F P
0 g
s
.2931 .85616 m .28309 .8678 L .31824 .52126 L p .108 0 .308 r
F P
0 g
s
.31824 .52126 m .32663 .5103 L .2931 .85616 L p .108 0 .308 r
F P
0 g
s
.26425 .8747 m .30409 .51405 L .31824 .52126 L p .825 .508 .454 r
F P
0 g
s
.31824 .52126 m .28162 .88237 L .26425 .8747 L p .825 .508 .454 r
F P
0 g
s
.2931 .85616 m .28309 .8678 L .31824 .52126 L p .108 0 .308 r
F P
0 g
s
.31824 .52126 m .32663 .5103 L .2931 .85616 L p .108 0 .308 r
F P
0 g
s
.3719 .50277 m .38593 .51004 L .3773 .521 L p .694 .677 .829 r
F P
0 g
s
.3773 .521 m .3633 .51379 L .3719 .50277 L p .694 .677 .829 r
F P
0 g
s
.33537 .88919 m .3633 .51379 L .3773 .521 L p .826 .506 .447 r
F P
0 g
s
.3773 .521 m .35264 .89688 L .33537 .88919 L p .826 .506 .447 r
F P
0 g
s
.3731 .84661 m .35644 .83902 L .36664 .82741 L p .684 .705 .863 r
F P
0 g
s
.36118 .88661 m .37794 .89411 L .3677 .9054 L p .683 .708 .867 r
F P
0 g
s
.35551 .85317 m .3723 .86078 L .36207 .87223 L p .683 .706 .865 r
F P
0 g
s
.37794 .89411 m .36118 .88661 L .37148 .87514 L p .683 .708 .867 r
F P
0 g
s
.36313 .88519 m .35264 .89688 L .3773 .521 L p .145 0 .337 r
F P
0 g
s
.3773 .521 m .38593 .51004 L .36313 .88519 L p .145 0 .337 r
F P
0 g
s
.33537 .88919 m .3633 .51379 L .3773 .521 L p .826 .506 .447 r
F P
0 g
s
.3773 .521 m .35264 .89688 L .33537 .88919 L p .826 .506 .447 r
F P
0 g
s
.36664 .82741 m .35644 .83902 L .3773 .521 L p .145 0 .337 r
F P
0 g
s
.3773 .521 m .38593 .51004 L .36664 .82741 L p .145 0 .337 r
F P
0 g
s
.43136 .50251 m .44523 .50978 L .43637 .52074 L p .694 .677 .829 r
F P
0 g
s
.43637 .52074 m .42253 .51353 L .43136 .50251 L p .694 .677 .829 r
F P
0 g
s
.41089 .81717 m .42732 .8248 L .41696 .83629 L p .685 .704 .862 r
F P
0 g
s
.41035 .83111 m .42253 .51353 L .43637 .52074 L p .828 .503 .439 r
F P
0 g
s
.43637 .52074 m .4269 .83875 L .41035 .83111 L p .828 .503 .439 r
F P
0 g
s
.43744 .82713 m .4269 .83875 L .43637 .52074 L p .18 0 .362 r
F P
0 g
s
.43637 .52074 m .44523 .50978 L .43744 .82713 L p .18 0 .362 r
F P
0 g
s
.41089 .81717 m .42253 .51353 L .43637 .52074 L p .828 .503 .439 r
F P
0 g
s
.43637 .52074 m .42732 .8248 L .41089 .81717 L p .828 .503 .439 r
F P
0 g
s
.43744 .82713 m .4269 .83875 L .43637 .52074 L p .18 0 .362 r
F P
0 g
s
.43637 .52074 m .44523 .50978 L .43744 .82713 L p .18 0 .362 r
F P
0 g
s
.49082 .50225 m .50455 .50952 L .49546 .52048 L p .694 .677 .829 r
F P
0 g
s
.49546 .52048 m .48176 .51327 L .49082 .50225 L p .694 .677 .829 r
F P
0 g
s
.48117 .77625 m .48176 .51327 L .49546 .52048 L p .829 .499 .43 r
F P
0 g
s
.49546 .52048 m .49706 .78384 L .48117 .77625 L p .829 .499 .43 r
F P
0 g
s
.50761 .7723 m .49706 .78384 L .49546 .52048 L p .211 .017 .385 r
F P
0 g
s
.49546 .52048 m .50455 .50952 L .50761 .7723 L p .211 .017 .385 r
F P
0 g
s
.48098 .85931 m .48176 .51327 L .49546 .52048 L p .829 .499 .43 r
F P
0 g
s
.49546 .52048 m .49756 .86698 L .48098 .85931 L p .829 .499 .43 r
F P
0 g
s
.50761 .7723 m .49706 .78384 L .49546 .52048 L p .211 .017 .385 r
F P
0 g
s
.49546 .52048 m .50455 .50952 L .50761 .7723 L p .211 .017 .385 r
F P
0 g
s
.5503 .50198 m .56388 .50926 L .55456 .52023 L p .694 .677 .829 r
F P
0 g
s
.55456 .52023 m .54101 .51301 L .5503 .50198 L p .694 .677 .829 r
F P
0 g
s
.55272 .85904 m .54101 .51301 L .55456 .52023 L p .831 .496 .421 r
F P
0 g
s
.55456 .52023 m .56908 .8667 L .55272 .85904 L p .831 .496 .421 r
F P
0 g
s
.58044 .85505 m .56908 .8667 L .55456 .52023 L p .239 .047 .406 r
F P
0 g
s
.55456 .52023 m .56388 .50926 L .58044 .85505 L p .239 .047 .406 r
F P
0 g
s
.55322 .87359 m .54101 .51301 L .55456 .52023 L p .831 .496 .421 r
F P
0 g
s
.55456 .52023 m .56969 .88127 L .55322 .87359 L p .831 .496 .421 r
F P
0 g
s
.58044 .85505 m .56908 .8667 L .55456 .52023 L p .239 .047 .406 r
F P
0 g
s
.55456 .52023 m .56388 .50926 L .58044 .85505 L p .239 .047 .406 r
F P
0 g
s
.60979 .50172 m .62321 .50899 L .61366 .51997 L p .694 .677 .829 r
F P
0 g
s
.61366 .51997 m .60027 .51275 L .60979 .50172 L p .694 .677 .829 r
F P
0 g
s
.62249 .83028 m .60027 .51275 L .61366 .51997 L p .832 .492 .412 r
F P
0 g
s
.61366 .51997 m .6384 .83792 L .62249 .83028 L p .832 .492 .412 r
F P
0 g
s
.64992 .8263 m .6384 .83792 L .61366 .51997 L p .264 .074 .424 r
F P
0 g
s
.61366 .51997 m .62321 .50899 L .64992 .8263 L p .264 .074 .424 r
F P
0 g
s
.62653 .88808 m .60027 .51275 L .61366 .51997 L p .832 .492 .412 r
F P
0 g
s
.61366 .51997 m .6429 .89577 L .62653 .88808 L p .832 .492 .412 r
F P
0 g
s
.65478 .88408 m .6429 .89577 L .61366 .51997 L p .264 .074 .424 r
F P
0 g
s
.61366 .51997 m .62321 .50899 L .65478 .88408 L p .264 .074 .424 r
F P
0 g
s
.66929 .50146 m .68256 .50873 L .67278 .51971 L p .694 .677 .829 r
F P
0 g
s
.67278 .51971 m .65954 .51249 L .66929 .50146 L p .694 .677 .829 r
F P
0 g
s
.69779 .87304 m .71382 .88072 L .70181 .89229 L p .682 .709 .868 r
F P
0 g
s
.69936 .88781 m .65954 .51249 L .67278 .51971 L p .833 .488 .402 r
F P
0 g
s
.67278 .51971 m .7155 .8955 L .69936 .88781 L p .833 .488 .402 r
F P
0 g
s
.72773 .8838 m .7155 .8955 L .67278 .51971 L p .288 .099 .441 r
F P
0 g
s
.67278 .51971 m .68256 .50873 L .72773 .8838 L p .288 .099 .441 r
F P
0 g
s
.69779 .87304 m .65954 .51249 L .67278 .51971 L p .833 .488 .402 r
F P
0 g
s
.67278 .51971 m .71382 .88072 L .69779 .87304 L p .833 .488 .402 r
F P
0 g
s
.72773 .8838 m .7155 .8955 L .67278 .51971 L p .288 .099 .441 r
F P
0 g
s
.67278 .51971 m .68256 .50873 L .72773 .8838 L p .288 .099 .441 r
F P
0 g
s
.27558 .49952 m .28987 .5068 L .28161 .51779 L p .694 .677 .829 r
F P
0 g
s
.28161 .51779 m .26735 .51056 L .27558 .49952 L p .694 .677 .829 r
F P
0 g
s
.21937 .87099 m .26735 .51056 L .28161 .51779 L p .824 .51 .458 r
F P
0 g
s
.28161 .51779 m .2369 .87868 L .21937 .87099 L p .824 .51 .458 r
F P
0 g
s
.24678 .86698 m .2369 .87868 L .28161 .51779 L p .08 0 .287 r
F P
0 g
s
.28161 .51779 m .28987 .5068 L .24678 .86698 L p .08 0 .287 r
F P
0 g
s
.2174 .88575 m .26735 .51056 L .28161 .51779 L p .824 .51 .458 r
F P
0 g
s
.28161 .51779 m .23507 .89346 L .2174 .88575 L p .824 .51 .458 r
F P
0 g
s
.24501 .88174 m .23507 .89346 L .28161 .51779 L p .08 0 .287 r
F P
0 g
s
.28161 .51779 m .28987 .5068 L .24501 .88174 L p .08 0 .287 r
F P
0 g
s
.3351 .49925 m .34924 .50654 L .34074 .51753 L p .694 .677 .829 r
F P
0 g
s
.34074 .51753 m .32663 .5103 L .3351 .49925 L p .694 .677 .829 r
F P
0 g
s
.2931 .85616 m .32663 .5103 L .34074 .51753 L p .825 .507 .451 r
F P
0 g
s
.34074 .51753 m .31028 .86384 L .2931 .85616 L p .825 .507 .451 r
F P
0 g
s
.32043 .85216 m .31028 .86384 L .34074 .51753 L p .121 0 .318 r
F P
0 g
s
.34074 .51753 m .34924 .50654 L .32043 .85216 L p .121 0 .318 r
F P
0 g
s
.2931 .85616 m .32663 .5103 L .34074 .51753 L p .825 .507 .451 r
F P
0 g
s
.34074 .51753 m .31028 .86384 L .2931 .85616 L p .825 .507 .451 r
F P
0 g
s
.31922 .8667 m .309 .8784 L .34074 .51753 L p .121 0 .318 r
F P
0 g
s
.34074 .51753 m .34924 .50654 L .31922 .8667 L p .121 0 .318 r
F P
0 g
s
.39462 .49899 m .40861 .50628 L .39988 .51727 L p .694 .677 .829 r
F P
0 g
s
.39988 .51727 m .38593 .51004 L .39462 .49899 L p .694 .677 .829 r
F P
0 g
s
.36749 .81348 m .38593 .51004 L .39988 .51727 L p .827 .504 .443 r
F P
0 g
s
.39988 .51727 m .38408 .82113 L .36749 .81348 L p .827 .504 .443 r
F P
0 g
s
.39435 .8095 m .38408 .82113 L .39988 .51727 L p .157 0 .346 r
F P
0 g
s
.39988 .51727 m .40861 .50628 L .39435 .8095 L p .157 0 .346 r
F P
0 g
s
.36664 .82741 m .38593 .51004 L .39988 .51727 L p .827 .504 .443 r
F P
0 g
s
.39988 .51727 m .38335 .83507 L .36664 .82741 L p .827 .504 .443 r
F P
0 g
s
.3937 .82342 m .38335 .83507 L .39988 .51727 L p .157 0 .346 r
F P
0 g
s
.39988 .51727 m .40861 .50628 L .3937 .82342 L p .157 0 .346 r
F P
0 g
s
.45416 .49873 m .468 .50602 L .45904 .51701 L p .694 .677 .829 r
F P
0 g
s
.45904 .51701 m .44523 .50978 L .45416 .49873 L p .694 .677 .829 r
F P
0 g
s
.43744 .82713 m .44523 .50978 L .45904 .51701 L p .828 .501 .435 r
F P
0 g
s
.45904 .51701 m .45393 .8348 L .43744 .82713 L p .828 .501 .435 r
F P
0 g
s
.46461 .82314 m .45393 .8348 L .45904 .51701 L p .19 0 .37 r
F P
0 g
s
.45904 .51701 m .468 .50602 L .46461 .82314 L p .19 0 .37 r
F P
0 g
s
.43744 .82713 m .44523 .50978 L .45904 .51701 L p .828 .501 .435 r
F P
0 g
s
.45904 .51701 m .45393 .8348 L .43744 .82713 L p .828 .501 .435 r
F P
0 g
s
.46446 .83727 m .45371 .84894 L .45904 .51701 L p .19 0 .37 r
F P
0 g
s
.45904 .51701 m .468 .50602 L .46446 .83727 L p .19 0 .37 r
F P
0 g
s
.51371 .49846 m .5274 .50575 L .5182 .51675 L p .694 .677 .829 r
F P
0 g
s
.5182 .51675 m .50455 .50952 L .51371 .49846 L p .694 .677 .829 r
F P
0 g
s
.50746 .75913 m .50455 .50952 L .5182 .51675 L p .83 .498 .426 r
F P
0 g
s
.5182 .51675 m .52318 .76673 L .50746 .75913 L p .83 .498 .426 r
F P
0 g
s
.5338 .75518 m .52318 .76673 L .5182 .51675 L p .22 .027 .392 r
F P
0 g
s
.5182 .51675 m .5274 .50575 L .5338 .75518 L p .22 .027 .392 r
F P
0 g
s
.50761 .7723 m .50455 .50952 L .5182 .51675 L p .83 .498 .426 r
F P
0 g
s
.5182 .51675 m .52344 .77991 L .50761 .7723 L p .83 .498 .426 r
F P
0 g
s
.53413 .76833 m .52344 .77991 L .5182 .51675 L p .22 .027 .392 r
F P
0 g
s
.5182 .51675 m .5274 .50575 L .53413 .76833 L p .22 .027 .392 r
F P
0 g
s
.57327 .4982 m .5868 .50549 L .57738 .51649 L p .694 .677 .829 r
F P
0 g
s
.57738 .51649 m .56388 .50926 L .57327 .4982 L p .694 .677 .829 r
F P
0 g
s
.58044 .85505 m .56388 .50926 L .57738 .51649 L p .831 .494 .417 r
F P
0 g
s
.57738 .51649 m .59673 .86274 L .58044 .85505 L p .831 .494 .417 r
F P
0 g
s
.60824 .85105 m .59673 .86274 L .57738 .51649 L p .248 .056 .412 r
F P
0 g
s
.57738 .51649 m .5868 .50549 L .60824 .85105 L p .248 .056 .412 r
F P
0 g
s
.58044 .85505 m .56388 .50926 L .57738 .51649 L p .831 .494 .417 r
F P
0 g
s
.57738 .51649 m .59673 .86274 L .58044 .85505 L p .831 .494 .417 r
F P
0 g
s
.60914 .86559 m .59755 .8773 L .57738 .51649 L p .248 .056 .412 r
F P
0 g
s
.57738 .51649 m .5868 .50549 L .60914 .86559 L p .248 .056 .412 r
F P
0 g
s
.63284 .49794 m .64622 .50523 L .63657 .51623 L p .694 .677 .829 r
F P
0 g
s
.63657 .51623 m .62321 .50899 L .63284 .49794 L p .694 .677 .829 r
F P
0 g
s
.65354 .86932 m .62321 .50899 L .63657 .51623 L p .833 .49 .407 r
F P
0 g
s
.63657 .51623 m .66973 .87702 L .65354 .86932 L p .833 .49 .407 r
F P
0 g
s
.68166 .86531 m .66973 .87702 L .63657 .51623 L p .272 .082 .43 r
F P
0 g
s
.63657 .51623 m .64622 .50523 L .68166 .86531 L p .272 .082 .43 r
F P
0 g
s
.65478 .88408 m .62321 .50899 L .63657 .51623 L p .833 .49 .407 r
F P
0 g
s
.63657 .51623 m .67108 .8918 L .65478 .88408 L p .833 .49 .407 r
F P
0 g
s
.68312 .88007 m .67108 .8918 L .63657 .51623 L p .272 .082 .43 r
F P
0 g
s
.63657 .51623 m .64622 .50523 L .68312 .88007 L p .272 .082 .43 r
F P
0 g
s
.69242 .49767 m .70565 .50497 L .69577 .51597 L p .694 .677 .829 r
F P
0 g
s
.69577 .51597 m .68256 .50873 L .69242 .49767 L p .694 .677 .829 r
F P
0 g
s
.72773 .8838 m .68256 .50873 L .69577 .51597 L p .834 .486 .397 r
F P
0 g
s
.69577 .51597 m .74381 .89152 L .72773 .8838 L p .834 .486 .397 r
F P
0 g
s
.75619 .87979 m .74381 .89152 L .69577 .51597 L p .295 .107 .446 r
F P
0 g
s
.69577 .51597 m .70565 .50497 L .75619 .87979 L p .295 .107 .446 r
F P
0 g
s
.72773 .8838 m .68256 .50873 L .69577 .51597 L p .834 .486 .397 r
F P
0 g
s
.69577 .51597 m .74381 .89152 L .72773 .8838 L p .834 .486 .397 r
F P
0 g
s
.23862 .49599 m .25302 .50329 L .24489 .51431 L p .694 .677 .829 r
F P
0 g
s
.24489 .51431 m .23052 .50706 L .23862 .49599 L p .694 .677 .829 r
F P
0 g
s
.17205 .88202 m .23052 .50706 L .24489 .51431 L p .823 .511 .462 r
F P
0 g
s
.24489 .51431 m .18989 .88975 L .17205 .88202 L p .823 .511 .462 r
F P
0 g
s
.19963 .878 m .18989 .88975 L .24489 .51431 L p .051 0 .265 r
F P
0 g
s
.24489 .51431 m .25302 .50329 L .19963 .878 L p .051 0 .265 r
F P
0 g
s
.19963 .878 m .18989 .88975 L .24489 .51431 L p .051 0 .265 r
F P
0 g
s
.24489 .51431 m .25302 .50329 L .19963 .878 L p .051 0 .265 r
F P
0 g
s
.29821 .49573 m .31246 .50303 L .30409 .51405 L p .694 .677 .829 r
F P
0 g
s
.30409 .51405 m .28987 .5068 L .29821 .49573 L p .694 .677 .829 r
F P
0 g
s
.24501 .88174 m .28987 .5068 L .30409 .51405 L p .825 .508 .454 r
F P
0 g
s
.30409 .51405 m .26262 .88947 L .24501 .88174 L p .825 .508 .454 r
F P
0 g
s
.28309 .8678 m .26586 .86014 L .27582 .84843 L p .683 .708 .867 r
F P
0 g
s
.26425 .8747 m .28162 .88237 L .27164 .89392 L p .682 .709 .868 r
F P
0 g
s
.27271 .87772 m .26262 .88947 L .30409 .51405 L p .094 0 .298 r
F P
0 g
s
.30409 .51405 m .31246 .50303 L .27271 .87772 L p .094 0 .298 r
F P
0 g
s
.24501 .88174 m .28987 .5068 L .30409 .51405 L p .825 .508 .454 r
F P
0 g
s
.30409 .51405 m .26262 .88947 L .24501 .88174 L p .825 .508 .454 r
F P
0 g
s
.27582 .84843 m .26586 .86014 L .30409 .51405 L p .094 0 .298 r
F P
0 g
s
.30409 .51405 m .31246 .50303 L .27582 .84843 L p .094 0 .298 r
F P
0 g
s
.3578 .49546 m .3719 .50277 L .3633 .51379 L p .694 .677 .829 r
F P
0 g
s
.3633 .51379 m .34924 .50654 L .3578 .49546 L p .694 .677 .829 r
F P
0 g
s
.31922 .8667 m .33647 .87442 L .3262 .88605 L p .682 .709 .868 r
F P
0 g
s
.3262 .88605 m .309 .8784 L .31922 .8667 L p .682 .709 .868 r
F P
0 g
s
.31799 .88146 m .34924 .50654 L .3633 .51379 L p .826 .506 .447 r
F P
0 g
s
.3633 .51379 m .33537 .88919 L .31799 .88146 L p .826 .506 .447 r
F P
0 g
s
.34581 .87744 m .33537 .88919 L .3633 .51379 L p .133 0 .328 r
F P
0 g
s
.3633 .51379 m .3719 .50277 L .34581 .87744 L p .133 0 .328 r
F P
0 g
s
.31922 .8667 m .34924 .50654 L .3633 .51379 L p .826 .506 .447 r
F P
0 g
s
.3633 .51379 m .33647 .87442 L .31922 .8667 L p .826 .506 .447 r
F P
0 g
s
.34581 .87744 m .33537 .88919 L .3633 .51379 L p .133 0 .328 r
F P
0 g
s
.3633 .51379 m .3719 .50277 L .34581 .87744 L p .133 0 .328 r
F P
0 g
s
.41741 .4952 m .43136 .50251 L .42253 .51353 L p .694 .677 .829 r
F P
0 g
s
.42253 .51353 m .40861 .50628 L .41741 .4952 L p .694 .677 .829 r
F P
0 g
s
.395 .79577 m .40861 .50628 L .42253 .51353 L p .828 .503 .439 r
F P
0 g
s
.42253 .51353 m .41141 .80343 L .395 .79577 L p .828 .503 .439 r
F P
0 g
s
.42176 .79178 m .41141 .80343 L .42253 .51353 L p .169 0 .354 r
F P
0 g
s
.42253 .51353 m .43136 .50251 L .42176 .79178 L p .169 0 .354 r
F P
0 g
s
.3937 .82342 m .40861 .50628 L .42253 .51353 L p .828 .503 .439 r
F P
0 g
s
.42253 .51353 m .41035 .83111 L .3937 .82342 L p .828 .503 .439 r
F P
0 g
s
.42084 .81942 m .41035 .83111 L .42253 .51353 L p .169 0 .354 r
F P
0 g
s
.42253 .51353 m .43136 .50251 L .42084 .81942 L p .169 0 .354 r
F P
0 g
s
.47703 .49494 m .49082 .50225 L .48176 .51327 L p .694 .677 .829 r
F P
0 g
s
.48176 .51327 m .468 .50602 L .47703 .49494 L p .694 .677 .829 r
F P
0 g
s
.46519 .76861 m .468 .50602 L .48176 .51327 L p .829 .499 .43 r
F P
0 g
s
.48176 .51327 m .48117 .77625 L .46519 .76861 L p .829 .499 .43 r
F P
0 g
s
.49169 .76464 m .48117 .77625 L .48176 .51327 L p .201 .006 .378 r
F P
0 g
s
.48176 .51327 m .49082 .50225 L .49169 .76464 L p .201 .006 .378 r
F P
0 g
s
.46446 .83727 m .468 .50602 L .48176 .51327 L p .829 .499 .43 r
F P
0 g
s
.48176 .51327 m .48102 .84497 L .46446 .83727 L p .829 .499 .43 r
F P
0 g
s
.49169 .76464 m .48117 .77625 L .48176 .51327 L p .201 .006 .378 r
F P
0 g
s
.48176 .51327 m .49082 .50225 L .49169 .76464 L p .201 .006 .378 r
F P
0 g
s
.53666 .49467 m .5503 .50198 L .54101 .51301 L p .694 .677 .829 r
F P
0 g
s
.54101 .51301 m .5274 .50575 L .53666 .49467 L p .694 .677 .829 r
F P
0 g
s
.53413 .76833 m .5274 .50575 L .54101 .51301 L p .831 .496 .421 r
F P
0 g
s
.54101 .51301 m .54991 .77597 L .53413 .76833 L p .831 .496 .421 r
F P
0 g
s
.56074 .76436 m .54991 .77597 L .54101 .51301 L p .23 .037 .399 r
F P
0 g
s
.54101 .51301 m .5503 .50198 L .56074 .76436 L p .23 .037 .399 r
F P
0 g
s
.53413 .76833 m .5274 .50575 L .54101 .51301 L p .831 .496 .421 r
F P
0 g
s
.54101 .51301 m .54991 .77597 L .53413 .76833 L p .831 .496 .421 r
F P
0 g
s
.56404 .84731 m .55272 .85904 L .54101 .51301 L p .23 .037 .399 r
F P
0 g
s
.54101 .51301 m .5503 .50198 L .56404 .84731 L p .23 .037 .399 r
F P
0 g
s
.5963 .49441 m .60979 .50172 L .60027 .51275 L p .694 .677 .829 r
F P
0 g
s
.60027 .51275 m .5868 .50549 L .5963 .49441 L p .694 .677 .829 r
F P
0 g
s
.60648 .82259 m .5868 .50549 L .60027 .51275 L p .832 .492 .412 r
F P
0 g
s
.60027 .51275 m .62249 .83028 L .60648 .82259 L p .832 .492 .412 r
F P
0 g
s
.63396 .81858 m .62249 .83028 L .60027 .51275 L p .256 .065 .418 r
F P
0 g
s
.60027 .51275 m .60979 .50172 L .63396 .81858 L p .256 .065 .418 r
F P
0 g
s
.60914 .86559 m .5868 .50549 L .60027 .51275 L p .832 .492 .412 r
F P
0 g
s
.60027 .51275 m .6255 .87331 L .60914 .86559 L p .832 .492 .412 r
F P
0 g
s
.63396 .81858 m .62249 .83028 L .60027 .51275 L p .256 .065 .418 r
F P
0 g
s
.60027 .51275 m .60979 .50172 L .63396 .81858 L p .256 .065 .418 r
F P
0 g
s
.65595 .49414 m .66929 .50146 L .65954 .51249 L p .694 .677 .829 r
F P
0 g
s
.65954 .51249 m .64622 .50523 L .65595 .49414 L p .694 .677 .829 r
F P
0 g
s
.68023 .85077 m .64622 .50523 L .65954 .51249 L p .833 .488 .402 r
F P
0 g
s
.65954 .51249 m .69625 .85848 L .68023 .85077 L p .833 .488 .402 r
F P
0 g
s
.70825 .84675 m .69625 .85848 L .65954 .51249 L p .28 .091 .436 r
F P
0 g
s
.65954 .51249 m .66929 .50146 L .70825 .84675 L p .28 .091 .436 r
F P
0 g
s
.68312 .88007 m .64622 .50523 L .65954 .51249 L p .833 .488 .402 r
F P
0 g
s
.65954 .51249 m .69936 .88781 L .68312 .88007 L p .833 .488 .402 r
F P
0 g
s
.71155 .87604 m .69936 .88781 L .65954 .51249 L p .28 .091 .436 r
F P
0 g
s
.65954 .51249 m .66929 .50146 L .71155 .87604 L p .28 .091 .436 r
F P
0 g
s
.26122 .49219 m .27558 .49952 L .26735 .51056 L p .694 .677 .829 r
F P
0 g
s
.26735 .51056 m .25302 .50329 L .26122 .49219 L p .694 .677 .829 r
F P
0 g
s
.19963 .878 m .25302 .50329 L .26735 .51056 L p .824 .51 .458 r
F P
0 g
s
.26735 .51056 m .2174 .88575 L .19963 .878 L p .824 .51 .458 r
F P
0 g
s
.2369 .87868 m .21937 .87099 L .22919 .85922 L p .682 .709 .868 r
F P
0 g
s
.22729 .87396 m .2174 .88575 L .26735 .51056 L p .066 0 .276 r
F P
0 g
s
.26735 .51056 m .27558 .49952 L .22729 .87396 L p .066 0 .276 r
F P
0 g
s
.19963 .878 m .25302 .50329 L .26735 .51056 L p .824 .51 .458 r
F P
0 g
s
.26735 .51056 m .2174 .88575 L .19963 .878 L p .824 .51 .458 r
F P
0 g
s
.22919 .85922 m .21937 .87099 L .26735 .51056 L p .066 0 .276 r
F P
0 g
s
.26735 .51056 m .27558 .49952 L .22919 .85922 L p .066 0 .276 r
F P
0 g
s
.32089 .49193 m .3351 .49925 L .32663 .5103 L p .694 .677 .829 r
F P
0 g
s
.32663 .5103 m .31246 .50303 L .32089 .49193 L p .694 .677 .829 r
F P
0 g
s
.27734 .8341 m .31246 .50303 L .32663 .5103 L p .825 .507 .451 r
F P
0 g
s
.32663 .5103 m .29449 .84182 L .27734 .8341 L p .825 .507 .451 r
F P
0 g
s
.30453 .83008 m .29449 .84182 L .32663 .5103 L p .108 0 .308 r
F P
0 g
s
.32663 .5103 m .3351 .49925 L .30453 .83008 L p .108 0 .308 r
F P
0 g
s
.27582 .84843 m .31246 .50303 L .32663 .5103 L p .825 .507 .451 r
F P
0 g
s
.32663 .5103 m .2931 .85616 L .27582 .84843 L p .825 .507 .451 r
F P
0 g
s
.3032 .8444 m .2931 .85616 L .32663 .5103 L p .108 0 .308 r
F P
0 g
s
.32663 .5103 m .3351 .49925 L .3032 .8444 L p .108 0 .308 r
F P
0 g
s
.38057 .49166 m .39462 .49899 L .38593 .51004 L p .694 .677 .829 r
F P
0 g
s
.38593 .51004 m .3719 .50277 L .38057 .49166 L p .694 .677 .829 r
F P
0 g
s
.34581 .87744 m .3719 .50277 L .38593 .51004 L p .827 .504 .443 r
F P
0 g
s
.38593 .51004 m .36313 .88519 L .34581 .87744 L p .827 .504 .443 r
F P
0 g
s
.38966 .85416 m .3731 .84661 L .38335 .83507 L p .684 .705 .863 r
F P
0 g
s
.38408 .82113 m .36749 .81348 L .37772 .80177 L p .685 .704 .862 r
F P
0 g
s
.36664 .82741 m .38335 .83507 L .3731 .84661 L p .684 .705 .863 r
F P
0 g
s
.37148 .87514 m .38828 .88271 L .37794 .89411 L p .683 .708 .867 r
F P
0 g
s
.37372 .8734 m .36313 .88519 L .38593 .51004 L p .145 0 .337 r
F P
0 g
s
.38593 .51004 m .39462 .49899 L .37372 .8734 L p .145 0 .337 r
F P
0 g
s
.34581 .87744 m .3719 .50277 L .38593 .51004 L p .827 .504 .443 r
F P
0 g
s
.38593 .51004 m .36313 .88519 L .34581 .87744 L p .827 .504 .443 r
F P
0 g
s
.37772 .80177 m .36749 .81348 L .38593 .51004 L p .145 0 .337 r
F P
0 g
s
.38593 .51004 m .39462 .49899 L .37772 .80177 L p .145 0 .337 r
F P
0 g
s
.44025 .4914 m .45416 .49873 L .44523 .50978 L p .694 .677 .829 r
F P
0 g
s
.44523 .50978 m .43136 .50251 L .44025 .4914 L p .694 .677 .829 r
F P
0 g
s
.4213 .8055 m .43136 .50251 L .44523 .50978 L p .828 .501 .435 r
F P
0 g
s
.44523 .50978 m .43778 .8132 L .4213 .8055 L p .828 .501 .435 r
F P
0 g
s
.44833 .8015 m .43778 .8132 L .44523 .50978 L p .18 0 .362 r
F P
0 g
s
.44523 .50978 m .45416 .49873 L .44833 .8015 L p .18 0 .362 r
F P
0 g
s
.42084 .81942 m .43136 .50251 L .44523 .50978 L p .828 .501 .435 r
F P
0 g
s
.44523 .50978 m .43744 .82713 L .42084 .81942 L p .828 .501 .435 r
F P
0 g
s
.44807 .81541 m .43744 .82713 L .44523 .50978 L p .18 0 .362 r
F P
0 g
s
.44523 .50978 m .45416 .49873 L .44807 .81541 L p .18 0 .362 r
F P
0 g
s
.49995 .49113 m .51371 .49846 L .50455 .50952 L p .694 .677 .829 r
F P
0 g
s
.50455 .50952 m .49082 .50225 L .49995 .49113 L p .694 .677 .829 r
F P
0 g
s
.49169 .76464 m .49082 .50225 L .50455 .50952 L p .83 .498 .426 r
F P
0 g
s
.50455 .50952 m .50761 .7723 L .49169 .76464 L p .83 .498 .426 r
F P
0 g
s
.52318 .76673 m .50746 .75913 L .51803 .74751 L p .687 .699 .856 r
F P
0 g
s
.51826 .76065 m .50761 .7723 L .50455 .50952 L p .211 .017 .385 r
F P
0 g
s
.50455 .50952 m .51371 .49846 L .51826 .76065 L p .211 .017 .385 r
F P
0 g
s
.49169 .76464 m .49082 .50225 L .50455 .50952 L p .83 .498 .426 r
F P
0 g
s
.50455 .50952 m .50761 .7723 L .49169 .76464 L p .83 .498 .426 r
F P
0 g
s
.51803 .74751 m .50746 .75913 L .50455 .50952 L p .211 .017 .385 r
F P
0 g
s
.50455 .50952 m .51371 .49846 L .51803 .74751 L p .211 .017 .385 r
F P
0 g
s
.55967 .49087 m .57327 .4982 L .56388 .50926 L p .694 .677 .829 r
F P
0 g
s
.56388 .50926 m .5503 .50198 L .55967 .49087 L p .694 .677 .829 r
F P
0 g
s
.56347 .83298 m .5503 .50198 L .56388 .50926 L p .831 .494 .417 r
F P
0 g
s
.56388 .50926 m .57975 .84071 L .56347 .83298 L p .831 .494 .417 r
F P
0 g
s
.59113 .82896 m .57975 .84071 L .56388 .50926 L p .239 .047 .406 r
F P
0 g
s
.56388 .50926 m .57327 .4982 L .59113 .82896 L p .239 .047 .406 r
F P
0 g
s
.56404 .84731 m .5503 .50198 L .56388 .50926 L p .831 .494 .417 r
F P
0 g
s
.56388 .50926 m .58044 .85505 L .56404 .84731 L p .831 .494 .417 r
F P
0 g
s
.5919 .84328 m .58044 .85505 L .56388 .50926 L p .239 .047 .406 r
F P
0 g
s
.56388 .50926 m .57327 .4982 L .5919 .84328 L p .239 .047 .406 r
F P
0 g
s
.61939 .49061 m .63284 .49794 L .62321 .50899 L p .694 .677 .829 r
F P
0 g
s
.62321 .50899 m .60979 .50172 L .61939 .49061 L p .694 .677 .829 r
F P
0 g
s
.63396 .81858 m .60979 .50172 L .62321 .50899 L p .833 .49 .407 r
F P
0 g
s
.62321 .50899 m .64992 .8263 L .63396 .81858 L p .833 .49 .407 r
F P
0 g
s
.66154 .81457 m .64992 .8263 L .62321 .50899 L p .264 .074 .424 r
F P
0 g
s
.62321 .50899 m .63284 .49794 L .66154 .81457 L p .264 .074 .424 r
F P
0 g
s
.63396 .81858 m .60979 .50172 L .62321 .50899 L p .833 .49 .407 r
F P
0 g
s
.62321 .50899 m .64992 .8263 L .63396 .81858 L p .833 .49 .407 r
F P
0 g
s
.66543 .85753 m .65354 .86932 L .62321 .50899 L p .264 .074 .424 r
F P
0 g
s
.62321 .50899 m .63284 .49794 L .66543 .85753 L p .264 .074 .424 r
F P
0 g
s
.67912 .49034 m .69242 .49767 L .68256 .50873 L p .694 .677 .829 r
F P
0 g
s
.68256 .50873 m .66929 .50146 L .67912 .49034 L p .694 .677 .829 r
F P
0 g
s
.70989 .86129 m .66929 .50146 L .68256 .50873 L p .834 .486 .397 r
F P
0 g
s
.68256 .50873 m .72595 .86904 L .70989 .86129 L p .834 .486 .397 r
F P
0 g
s
.7382 .85725 m .72595 .86904 L .68256 .50873 L p .288 .099 .441 r
F P
0 g
s
.68256 .50873 m .69242 .49767 L .7382 .85725 L p .288 .099 .441 r
F P
0 g
s
.71155 .87604 m .66929 .50146 L .68256 .50873 L p .834 .486 .397 r
F P
0 g
s
.68256 .50873 m .72773 .8838 L .71155 .87604 L p .834 .486 .397 r
F P
0 g
s
.74008 .872 m .72773 .8838 L .68256 .50873 L p .288 .099 .441 r
F P
0 g
s
.68256 .50873 m .69242 .49767 L .74008 .872 L p .288 .099 .441 r
F P
0 g
s
.22414 .48865 m .23862 .49599 L .23052 .50706 L p .694 .677 .829 r
F P
0 g
s
.23052 .50706 m .21608 .49978 L .22414 .48865 L p .694 .677 .829 r
F P
0 g
s
.1541 .87424 m .21608 .49978 L .23052 .50706 L p .823 .511 .462 r
F P
0 g
s
.23052 .50706 m .17205 .88202 L .1541 .87424 L p .823 .511 .462 r
F P
0 g
s
.18174 .8702 m .17205 .88202 L .23052 .50706 L p .036 0 .253 r
F P
0 g
s
.23052 .50706 m .23862 .49599 L .18174 .8702 L p .036 0 .253 r
F P
0 g
s
.18174 .8702 m .17205 .88202 L .23052 .50706 L p .036 0 .253 r
F P
0 g
s
.23052 .50706 m .23862 .49599 L .18174 .8702 L p .036 0 .253 r
F P
0 g
s
.28388 .48838 m .29821 .49573 L .28987 .5068 L p .694 .677 .829 r
F P
0 g
s
.28987 .5068 m .27558 .49952 L .28388 .48838 L p .694 .677 .829 r
F P
0 g
s
.22919 .85922 m .24678 .86698 L .2369 .87868 L p .682 .709 .868 r
F P
0 g
s
.22729 .87396 m .27558 .49952 L .28987 .5068 L p .825 .508 .454 r
F P
0 g
s
.28987 .5068 m .24501 .88174 L .22729 .87396 L p .825 .508 .454 r
F P
0 g
s
.25505 .86992 m .24501 .88174 L .28987 .5068 L p .08 0 .287 r
F P
0 g
s
.28987 .5068 m .29821 .49573 L .25505 .86992 L p .08 0 .287 r
F P
0 g
s
.22919 .85922 m .27558 .49952 L .28987 .5068 L p .825 .508 .454 r
F P
0 g
s
.28987 .5068 m .24678 .86698 L .22919 .85922 L p .825 .508 .454 r
F P
0 g
s
.25505 .86992 m .24501 .88174 L .28987 .5068 L p .08 0 .287 r
F P
0 g
s
.28987 .5068 m .29821 .49573 L .25505 .86992 L p .08 0 .287 r
F P
0 g
s
.34363 .48812 m .3578 .49546 L .34924 .50654 L p .694 .677 .829 r
F P
0 g
s
.34924 .50654 m .3351 .49925 L .34363 .48812 L p .694 .677 .829 r
F P
0 g
s
.2931 .85616 m .31028 .86384 L .30022 .87542 L p .683 .708 .867 r
F P
0 g
s
.3032 .8444 m .32043 .85216 L .31028 .86384 L p .683 .708 .867 r
F P
0 g
s
.31028 .86384 m .2931 .85616 L .3032 .8444 L p .683 .708 .867 r
F P
0 g
s
.3005 .87368 m .3351 .49925 L .34924 .50654 L p .826 .506 .447 r
F P
0 g
s
.34924 .50654 m .31799 .88146 L .3005 .87368 L p .826 .506 .447 r
F P
0 g
s
.32837 .86963 m .31799 .88146 L .34924 .50654 L p .121 0 .318 r
F P
0 g
s
.34924 .50654 m .3578 .49546 L .32837 .86963 L p .121 0 .318 r
F P
0 g
s
.3032 .8444 m .3351 .49925 L .34924 .50654 L p .826 .506 .447 r
F P
0 g
s
.34924 .50654 m .32043 .85216 L .3032 .8444 L p .826 .506 .447 r
F P
0 g
s
.32837 .86963 m .31799 .88146 L .34924 .50654 L p .121 0 .318 r
F P
0 g
s
.34924 .50654 m .3578 .49546 L .32837 .86963 L p .121 0 .318 r
F P
0 g
s
.40339 .48785 m .41741 .4952 L .40861 .50628 L p .694 .677 .829 r
F P
0 g
s
.40861 .50628 m .39462 .49899 L .40339 .48785 L p .694 .677 .829 r
F P
0 g
s
.37848 .78806 m .39462 .49899 L .40861 .50628 L p .828 .503 .439 r
F P
0 g
s
.40861 .50628 m .395 .79577 L .37848 .78806 L p .828 .503 .439 r
F P
0 g
s
.4053 .78405 m .395 .79577 L .40861 .50628 L p .157 0 .346 r
F P
0 g
s
.40861 .50628 m .41741 .4952 L .4053 .78405 L p .157 0 .346 r
F P
0 g
s
.37772 .80177 m .39462 .49899 L .40861 .50628 L p .828 .503 .439 r
F P
0 g
s
.40861 .50628 m .39435 .8095 L .37772 .80177 L p .828 .503 .439 r
F P
0 g
s
.4053 .78405 m .395 .79577 L .40861 .50628 L p .157 0 .346 r
F P
0 g
s
.40861 .50628 m .41741 .4952 L .4053 .78405 L p .157 0 .346 r
F P
0 g
s
.46316 .48759 m .47703 .49494 L .468 .50602 L p .694 .677 .829 r
F P
0 g
s
.468 .50602 m .45416 .49873 L .46316 .48759 L p .694 .677 .829 r
F P
0 g
s
.44912 .76093 m .45416 .49873 L .468 .50602 L p .829 .499 .43 r
F P
0 g
s
.468 .50602 m .46519 .76861 L .44912 .76093 L p .829 .499 .43 r
F P
0 g
s
.47566 .75693 m .46519 .76861 L .468 .50602 L p .19 0 .37 r
F P
0 g
s
.468 .50602 m .47703 .49494 L .47566 .75693 L p .19 0 .37 r
F P
0 g
s
.44807 .81541 m .45416 .49873 L .468 .50602 L p .829 .499 .43 r
F P
0 g
s
.468 .50602 m .46461 .82314 L .44807 .81541 L p .829 .499 .43 r
F P
0 g
s
.47566 .75693 m .46519 .76861 L .468 .50602 L p .19 0 .37 r
F P
0 g
s
.468 .50602 m .47703 .49494 L .47566 .75693 L p .19 0 .37 r
F P
0 g
s
.52294 .48732 m .53666 .49467 L .5274 .50575 L p .694 .677 .829 r
F P
0 g
s
.5274 .50575 m .51371 .49846 L .52294 .48732 L p .694 .677 .829 r
F P
0 g
s
.51803 .74751 m .5338 .75518 L .52318 .76673 L p .687 .699 .856 r
F P
0 g
s
.51826 .76065 m .51371 .49846 L .5274 .50575 L p .831 .496 .421 r
F P
0 g
s
.5274 .50575 m .53413 .76833 L .51826 .76065 L p .831 .496 .421 r
F P
0 g
s
.54492 .75665 m .53413 .76833 L .5274 .50575 L p .22 .027 .392 r
F P
0 g
s
.5274 .50575 m .53666 .49467 L .54492 .75665 L p .22 .027 .392 r
F P
0 g
s
.51803 .74751 m .51371 .49846 L .5274 .50575 L p .831 .496 .421 r
F P
0 g
s
.5274 .50575 m .5338 .75518 L .51803 .74751 L p .831 .496 .421 r
F P
0 g
s
.54492 .75665 m .53413 .76833 L .5274 .50575 L p .22 .027 .392 r
F P
0 g
s
.5274 .50575 m .53666 .49467 L .54492 .75665 L p .22 .027 .392 r
F P
0 g
s
.58274 .48706 m .5963 .49441 L .5868 .50549 L p .694 .677 .829 r
F P
0 g
s
.5868 .50549 m .57327 .4982 L .58274 .48706 L p .694 .677 .829 r
F P
0 g
s
.59037 .81485 m .57327 .4982 L .5868 .50549 L p .832 .492 .412 r
F P
0 g
s
.5868 .50549 m .60648 .82259 L .59037 .81485 L p .832 .492 .412 r
F P
0 g
s
.61791 .81082 m .60648 .82259 L .5868 .50549 L p .248 .056 .412 r
F P
0 g
s
.5868 .50549 m .5963 .49441 L .61791 .81082 L p .248 .056 .412 r
F P
0 g
s
.5919 .84328 m .57327 .4982 L .5868 .50549 L p .832 .492 .412 r
F P
0 g
s
.5868 .50549 m .60824 .85105 L .5919 .84328 L p .832 .492 .412 r
F P
0 g
s
.61791 .81082 m .60648 .82259 L .5868 .50549 L p .248 .056 .412 r
F P
0 g
s
.5868 .50549 m .5963 .49441 L .61791 .81082 L p .248 .056 .412 r
F P
0 g
s
.64254 .48679 m .65595 .49414 L .64622 .50523 L p .694 .677 .829 r
F P
0 g
s
.64622 .50523 m .63284 .49794 L .64254 .48679 L p .694 .677 .829 r
F P
0 g
s
.66412 .843 m .63284 .49794 L .64622 .50523 L p .833 .488 .402 r
F P
0 g
s
.64622 .50523 m .68023 .85077 L .66412 .843 L p .833 .488 .402 r
F P
0 g
s
.69219 .83896 m .68023 .85077 L .64622 .50523 L p .272 .082 .43 r
F P
0 g
s
.64622 .50523 m .65595 .49414 L .69219 .83896 L p .272 .082 .43 r
F P
0 g
s
.66543 .85753 m .63284 .49794 L .64622 .50523 L p .833 .488 .402 r
F P
0 g
s
.64622 .50523 m .68166 .86531 L .66543 .85753 L p .833 .488 .402 r
F P
0 g
s
.69219 .83896 m .68023 .85077 L .64622 .50523 L p .272 .082 .43 r
F P
0 g
s
.64622 .50523 m .65595 .49414 L .69219 .83896 L p .272 .082 .43 r
F P
0 g
s
.70236 .48653 m .71561 .49388 L .70565 .50497 L p .694 .677 .829 r
F P
0 g
s
.70565 .50497 m .69242 .49767 L .70236 .48653 L p .694 .677 .829 r
F P
0 g
s
.74008 .872 m .69242 .49767 L .70565 .50497 L p .835 .484 .391 r
F P
0 g
s
.70565 .50497 m .75619 .87979 L .74008 .872 L p .835 .484 .391 r
F P
0 g
s
.76869 .86794 m .75619 .87979 L .70565 .50497 L p .295 .107 .446 r
F P
0 g
s
.70565 .50497 m .71561 .49388 L .76869 .86794 L p .295 .107 .446 r
F P
0 g
s
.74008 .872 m .69242 .49767 L .70565 .50497 L p .835 .484 .391 r
F P
0 g
s
.70565 .50497 m .75619 .87979 L .74008 .872 L p .835 .484 .391 r
F P
0 g
s
.24678 .48483 m .26122 .49219 L .25302 .50329 L p .694 .677 .829 r
F P
0 g
s
.25302 .50329 m .23862 .49599 L .24678 .48483 L p .694 .677 .829 r
F P
0 g
s
.18398 .85545 m .23862 .49599 L .25302 .50329 L p .824 .51 .458 r
F P
0 g
s
.25302 .50329 m .20173 .86324 L .18398 .85545 L p .824 .51 .458 r
F P
0 g
s
.2115 .8514 m .20173 .86324 L .25302 .50329 L p .051 0 .265 r
F P
0 g
s
.25302 .50329 m .26122 .49219 L .2115 .8514 L p .051 0 .265 r
F P
0 g
s
.18174 .8702 m .23862 .49599 L .25302 .50329 L p .824 .51 .458 r
F P
0 g
s
.25302 .50329 m .19963 .878 L .18174 .8702 L p .824 .51 .458 r
F P
0 g
s
.20946 .86614 m .19963 .878 L .25302 .50329 L p .051 0 .265 r
F P
0 g
s
.25302 .50329 m .26122 .49219 L .20946 .86614 L p .051 0 .265 r
F P
0 g
s
.3066 .48457 m .32089 .49193 L .31246 .50303 L p .694 .677 .829 r
F P
0 g
s
.31246 .50303 m .29821 .49573 L .3066 .48457 L p .694 .677 .829 r
F P
0 g
s
.25505 .86992 m .29821 .49573 L .31246 .50303 L p .825 .507 .451 r
F P
0 g
s
.31246 .50303 m .27271 .87772 L .25505 .86992 L p .825 .507 .451 r
F P
0 g
s
.29449 .84182 m .27734 .8341 L .28732 .82229 L p .683 .706 .865 r
F P
0 g
s
.27582 .84843 m .2931 .85616 L .28309 .8678 L p .683 .708 .867 r
F P
0 g
s
.28289 .86585 m .27271 .87772 L .31246 .50303 L p .094 0 .298 r
F P
0 g
s
.31246 .50303 m .32089 .49193 L .28289 .86585 L p .094 0 .298 r
F P
0 g
s
.25505 .86992 m .29821 .49573 L .31246 .50303 L p .825 .507 .451 r
F P
0 g
s
.31246 .50303 m .27271 .87772 L .25505 .86992 L p .825 .507 .451 r
F P
0 g
s
.28732 .82229 m .27734 .8341 L .31246 .50303 L p .094 0 .298 r
F P
0 g
s
.31246 .50303 m .32089 .49193 L .28732 .82229 L p .094 0 .298 r
F P
0 g
s
.36643 .4843 m .38057 .49166 L .3719 .50277 L p .694 .677 .829 r
F P
0 g
s
.3719 .50277 m .3578 .49546 L .36643 .4843 L p .694 .677 .829 r
F P
0 g
s
.32953 .85489 m .3578 .49546 L .3719 .50277 L p .827 .504 .443 r
F P
0 g
s
.3719 .50277 m .34683 .86269 L .32953 .85489 L p .827 .504 .443 r
F P
0 g
s
.3573 .85084 m .34683 .86269 L .3719 .50277 L p .133 0 .328 r
F P
0 g
s
.3719 .50277 m .38057 .49166 L .3573 .85084 L p .133 0 .328 r
F P
0 g
s
.32837 .86963 m .3578 .49546 L .3719 .50277 L p .827 .504 .443 r
F P
0 g
s
.3719 .50277 m .34581 .87744 L .32837 .86963 L p .827 .504 .443 r
F P
0 g
s
.35635 .86557 m .34581 .87744 L .3719 .50277 L p .133 0 .328 r
F P
0 g
s
.3719 .50277 m .38057 .49166 L .35635 .86557 L p .133 0 .328 r
F P
0 g
s
.42627 .48403 m .44025 .4914 L .43136 .50251 L p .694 .677 .829 r
F P
0 g
s
.43136 .50251 m .41741 .4952 L .42627 .48403 L p .694 .677 .829 r
F P
0 g
s
.4053 .78405 m .41741 .4952 L .43136 .50251 L p .828 .501 .435 r
F P
0 g
s
.43136 .50251 m .42176 .79178 L .4053 .78405 L p .828 .501 .435 r
F P
0 g
s
.43219 .78002 m .42176 .79178 L .43136 .50251 L p .169 0 .354 r
F P
0 g
s
.43136 .50251 m .44025 .4914 L .43219 .78002 L p .169 0 .354 r
F P
0 g
s
.4053 .78405 m .41741 .4952 L .43136 .50251 L p .828 .501 .435 r
F P
0 g
s
.43136 .50251 m .42176 .79178 L .4053 .78405 L p .828 .501 .435 r
F P
0 g
s
.43181 .79373 m .4213 .8055 L .43136 .50251 L p .169 0 .354 r
F P
0 g
s
.43136 .50251 m .44025 .4914 L .43181 .79373 L p .169 0 .354 r
F P
0 g
s
.48613 .48377 m .49995 .49113 L .49082 .50225 L p .694 .677 .829 r
F P
0 g
s
.49082 .50225 m .47703 .49494 L .48613 .48377 L p .694 .677 .829 r
F P
0 g
s
.47573 .74379 m .47703 .49494 L .49082 .50225 L p .83 .498 .426 r
F P
0 g
s
.49082 .50225 m .49164 .75148 L .47573 .74379 L p .83 .498 .426 r
F P
0 g
s
.50218 .73979 m .49164 .75148 L .49082 .50225 L p .201 .006 .378 r
F P
0 g
s
.49082 .50225 m .49995 .49113 L .50218 .73979 L p .201 .006 .378 r
F P
0 g
s
.47566 .75693 m .47703 .49494 L .49082 .50225 L p .83 .498 .426 r
F P
0 g
s
.49082 .50225 m .49169 .76464 L .47566 .75693 L p .83 .498 .426 r
F P
0 g
s
.5023 .75292 m .49169 .76464 L .49082 .50225 L p .201 .006 .378 r
F P
0 g
s
.49082 .50225 m .49995 .49113 L .5023 .75292 L p .201 .006 .378 r
F P
0 g
s
.54599 .4835 m .55967 .49087 L .5503 .50198 L p .694 .677 .829 r
F P
0 g
s
.5503 .50198 m .53666 .49467 L .54599 .4835 L p .694 .677 .829 r
F P
0 g
s
.54492 .75665 m .53666 .49467 L .5503 .50198 L p .831 .494 .417 r
F P
0 g
s
.5503 .50198 m .56074 .76436 L .54492 .75665 L p .831 .494 .417 r
F P
0 g
s
.57166 .75264 m .56074 .76436 L .5503 .50198 L p .23 .037 .399 r
F P
0 g
s
.5503 .50198 m .55967 .49087 L .57166 .75264 L p .23 .037 .399 r
F P
0 g
s
.54492 .75665 m .53666 .49467 L .5503 .50198 L p .831 .494 .417 r
F P
0 g
s
.5503 .50198 m .56074 .76436 L .54492 .75665 L p .831 .494 .417 r
F P
0 g
s
.5748 .82116 m .56347 .83298 L .5503 .50198 L p .23 .037 .399 r
F P
0 g
s
.5503 .50198 m .55967 .49087 L .5748 .82116 L p .23 .037 .399 r
F P
0 g
s
.60587 .48324 m .61939 .49061 L .60979 .50172 L p .694 .677 .829 r
F P
0 g
s
.60979 .50172 m .5963 .49441 L .60587 .48324 L p .694 .677 .829 r
F P
0 g
s
.61696 .79692 m .5963 .49441 L .60979 .50172 L p .833 .49 .407 r
F P
0 g
s
.60979 .50172 m .6329 .80467 L .61696 .79692 L p .833 .49 .407 r
F P
0 g
s
.6444 .79288 m .6329 .80467 L .60979 .50172 L p .256 .065 .418 r
F P
0 g
s
.60979 .50172 m .61939 .49061 L .6444 .79288 L p .256 .065 .418 r
F P
0 g
s
.61791 .81082 m .5963 .49441 L .60979 .50172 L p .833 .49 .407 r
F P
0 g
s
.60979 .50172 m .63396 .81858 L .61791 .81082 L p .833 .49 .407 r
F P
0 g
s
.64555 .80678 m .63396 .81858 L .60979 .50172 L p .256 .065 .418 r
F P
0 g
s
.60979 .50172 m .61939 .49061 L .64555 .80678 L p .256 .065 .418 r
F P
0 g
s
.66575 .48297 m .67912 .49034 L .66929 .50146 L p .694 .677 .829 r
F P
0 g
s
.66929 .50146 m .65595 .49414 L .66575 .48297 L p .694 .677 .829 r
F P
0 g
s
.69219 .83896 m .65595 .49414 L .66929 .50146 L p .834 .486 .397 r
F P
0 g
s
.66929 .50146 m .70825 .84675 L .69219 .83896 L p .834 .486 .397 r
F P
0 g
s
.72035 .8349 m .70825 .84675 L .66929 .50146 L p .28 .091 .436 r
F P
0 g
s
.66929 .50146 m .67912 .49034 L .72035 .8349 L p .28 .091 .436 r
F P
0 g
s
.69219 .83896 m .65595 .49414 L .66929 .50146 L p .834 .486 .397 r
F P
0 g
s
.66929 .50146 m .70825 .84675 L .69219 .83896 L p .834 .486 .397 r
F P
0 g
s
.72209 .84942 m .70989 .86129 L .66929 .50146 L p .28 .091 .436 r
F P
0 g
s
.66929 .50146 m .67912 .49034 L .72209 .84942 L p .28 .091 .436 r
F P
0 g
s
.20959 .48127 m .22414 .48865 L .21608 .49978 L p .694 .677 .829 r
F P
0 g
s
.21608 .49978 m .20156 .49246 L .20959 .48127 L p .694 .677 .829 r
F P
0 g
s
.13604 .86642 m .20156 .49246 L .21608 .49978 L p .823 .511 .462 r
F P
0 g
s
.21608 .49978 m .1541 .87424 L .13604 .86642 L p .823 .511 .462 r
F P
0 g
s
.16373 .86235 m .1541 .87424 L .21608 .49978 L p .02 0 .24 r
F P
0 g
s
.21608 .49978 m .22414 .48865 L .16373 .86235 L p .02 0 .24 r
F P
0 g
s
.16373 .86235 m .1541 .87424 L .21608 .49978 L p .02 0 .24 r
F P
0 g
s
.21608 .49978 m .22414 .48865 L .16373 .86235 L p .02 0 .24 r
F P
0 g
s
.26948 .481 m .28388 .48838 L .27558 .49952 L p .694 .677 .829 r
F P
0 g
s
.27558 .49952 m .26122 .49219 L .26948 .481 L p .694 .677 .829 r
F P
0 g
s
.21351 .83688 m .26122 .49219 L .27558 .49952 L p .825 .508 .454 r
F P
0 g
s
.27558 .49952 m .23107 .84468 L .21351 .83688 L p .825 .508 .454 r
F P
0 g
s
.24092 .83282 m .23107 .84468 L .27558 .49952 L p .066 0 .276 r
F P
0 g
s
.27558 .49952 m .28388 .48838 L .24092 .83282 L p .066 0 .276 r
F P
0 g
s
.20946 .86614 m .26122 .49219 L .27558 .49952 L p .825 .508 .454 r
F P
0 g
s
.27558 .49952 m .22729 .87396 L .20946 .86614 L p .825 .508 .454 r
F P
0 g
s
.23727 .86206 m .22729 .87396 L .27558 .49952 L p .066 0 .276 r
F P
0 g
s
.27558 .49952 m .28388 .48838 L .23727 .86206 L p .066 0 .276 r
F P
0 g
s
.32938 .48074 m .34363 .48812 L .3351 .49925 L p .694 .677 .829 r
F P
0 g
s
.3351 .49925 m .32089 .49193 L .32938 .48074 L p .694 .677 .829 r
F P
0 g
s
.28732 .82229 m .30453 .83008 L .29449 .84182 L p .683 .706 .865 r
F P
0 g
s
.28289 .86585 m .32089 .49193 L .3351 .49925 L p .826 .506 .447 r
F P
0 g
s
.30022 .87542 m .28309 .8678 L .2931 .85616 L p .683 .708 .867 r
F P
0 g
s
.3351 .49925 m .3005 .87368 L .28289 .86585 L p .826 .506 .447 r
F P
0 g
s
.31083 .86178 m .3005 .87368 L .3351 .49925 L p .108 0 .308 r
F P
0 g
s
.3351 .49925 m .34363 .48812 L .31083 .86178 L p .108 0 .308 r
F P
0 g
s
.28732 .82229 m .32089 .49193 L .3351 .49925 L p .826 .506 .447 r
F P
0 g
s
.3351 .49925 m .30453 .83008 L .28732 .82229 L p .826 .506 .447 r
F P
0 g
s
.31083 .86178 m .3005 .87368 L .3351 .49925 L p .108 0 .308 r
F P
0 g
s
.3351 .49925 m .34363 .48812 L .31083 .86178 L p .108 0 .308 r
F P
0 g
s
.3893 .48047 m .40339 .48785 L .39462 .49899 L p .694 .677 .829 r
F P
0 g
s
.39462 .49899 m .38057 .49166 L .3893 .48047 L p .694 .677 .829 r
F P
0 g
s
.35635 .86557 m .38057 .49166 L .39462 .49899 L p .828 .503 .439 r
F P
0 g
s
.39462 .49899 m .37372 .8734 L .35635 .86557 L p .828 .503 .439 r
F P
0 g
s
.395 .79577 m .37848 .78806 L .38874 .77627 L p .685 .702 .86 r
F P
0 g
s
.38335 .83507 m .39996 .84269 L .38966 .85416 L p .684 .705 .863 r
F P
0 g
s
.37772 .80177 m .39435 .8095 L .38408 .82113 L p .685 .704 .862 r
F P
0 g
s
.39996 .84269 m .38335 .83507 L .3937 .82342 L p .684 .705 .863 r
F P
0 g
s
.38441 .8615 m .37372 .8734 L .39462 .49899 L p .145 0 .337 r
F P
0 g
s
.39462 .49899 m .40339 .48785 L .38441 .8615 L p .145 0 .337 r
F P
0 g
s
.35635 .86557 m .38057 .49166 L .39462 .49899 L p .828 .503 .439 r
F P
0 g
s
.39462 .49899 m .37372 .8734 L .35635 .86557 L p .828 .503 .439 r
F P
0 g
s
.38874 .77627 m .37848 .78806 L .39462 .49899 L p .145 0 .337 r
F P
0 g
s
.39462 .49899 m .40339 .48785 L .38874 .77627 L p .145 0 .337 r
F P
0 g
s
.44922 .4802 m .46316 .48759 L .45416 .49873 L p .694 .677 .829 r
F P
0 g
s
.45416 .49873 m .44025 .4914 L .44922 .4802 L p .694 .677 .829 r
F P
0 g
s
.43294 .7532 m .44025 .4914 L .45416 .49873 L p .829 .499 .43 r
F P
0 g
s
.45416 .49873 m .44912 .76093 L .43294 .7532 L p .829 .499 .43 r
F P
0 g
s
.45955 .74918 m .44912 .76093 L .45416 .49873 L p .18 0 .362 r
F P
0 g
s
.45416 .49873 m .46316 .48759 L .45955 .74918 L p .18 0 .362 r
F P
0 g
s
.43181 .79373 m .44025 .4914 L .45416 .49873 L p .829 .499 .43 r
F P
0 g
s
.45416 .49873 m .44833 .8015 L .43181 .79373 L p .829 .499 .43 r
F P
0 g
s
.45955 .74918 m .44912 .76093 L .45416 .49873 L p .18 0 .362 r
F P
0 g
s
.45416 .49873 m .46316 .48759 L .45955 .74918 L p .18 0 .362 r
F P
0 g
s
.50916 .47994 m .52294 .48732 L .51371 .49846 L p .694 .677 .829 r
F P
0 g
s
.51371 .49846 m .49995 .49113 L .50916 .47994 L p .694 .677 .829 r
F P
0 g
s
.50206 .72684 m .49995 .49113 L .51371 .49846 L p .831 .496 .421 r
F P
0 g
s
.51371 .49846 m .51781 .73454 L .50206 .72684 L p .831 .496 .421 r
F P
0 g
s
.52841 .72284 m .51781 .73454 L .51371 .49846 L p .211 .017 .385 r
F P
0 g
s
.51371 .49846 m .52294 .48732 L .52841 .72284 L p .211 .017 .385 r
F P
0 g
s
.5023 .75292 m .49995 .49113 L .51371 .49846 L p .831 .496 .421 r
F P
0 g
s
.51371 .49846 m .51826 .76065 L .5023 .75292 L p .831 .496 .421 r
F P
0 g
s
.52901 .7489 m .51826 .76065 L .51371 .49846 L p .211 .017 .385 r
F P
0 g
s
.51371 .49846 m .52294 .48732 L .52901 .7489 L p .211 .017 .385 r
F P
0 g
s
.5691 .47967 m .58274 .48706 L .57327 .4982 L p .694 .677 .829 r
F P
0 g
s
.57327 .4982 m .55967 .49087 L .5691 .47967 L p .694 .677 .829 r
F P
0 g
s
.57416 .80706 m .55967 .49087 L .57327 .4982 L p .832 .492 .412 r
F P
0 g
s
.57327 .4982 m .59037 .81485 L .57416 .80706 L p .832 .492 .412 r
F P
0 g
s
.60176 .80301 m .59037 .81485 L .57327 .4982 L p .239 .047 .406 r
F P
0 g
s
.57327 .4982 m .58274 .48706 L .60176 .80301 L p .239 .047 .406 r
F P
0 g
s
.5748 .82116 m .55967 .49087 L .57327 .4982 L p .832 .492 .412 r
F P
0 g
s
.57327 .4982 m .59113 .82896 L .5748 .82116 L p .832 .492 .412 r
F P
0 g
s
.60176 .80301 m .59037 .81485 L .57327 .4982 L p .239 .047 .406 r
F P
0 g
s
.57327 .4982 m .58274 .48706 L .60176 .80301 L p .239 .047 .406 r
F P
0 g
s
.62906 .4794 m .64254 .48679 L .63284 .49794 L p .694 .677 .829 r
F P
0 g
s
.63284 .49794 m .61939 .49061 L .62906 .4794 L p .694 .677 .829 r
F P
0 g
s
.64555 .80678 m .61939 .49061 L .63284 .49794 L p .833 .488 .402 r
F P
0 g
s
.63284 .49794 m .66154 .81457 L .64555 .80678 L p .833 .488 .402 r
F P
0 g
s
.67327 .80273 m .66154 .81457 L .63284 .49794 L p .264 .074 .424 r
F P
0 g
s
.63284 .49794 m .64254 .48679 L .67327 .80273 L p .264 .074 .424 r
F P
0 g
s
.64555 .80678 m .61939 .49061 L .63284 .49794 L p .833 .488 .402 r
F P
0 g
s
.63284 .49794 m .66154 .81457 L .64555 .80678 L p .833 .488 .402 r
F P
0 g
s
.67603 .83112 m .66412 .843 L .63284 .49794 L p .264 .074 .424 r
F P
0 g
s
.63284 .49794 m .64254 .48679 L .67603 .83112 L p .264 .074 .424 r
F P
0 g
s
.68903 .47914 m .70236 .48653 L .69242 .49767 L p .694 .677 .829 r
F P
0 g
s
.69242 .49767 m .67912 .49034 L .68903 .47914 L p .694 .677 .829 r
F P
0 g
s
.72209 .84942 m .7382 .85725 L .72595 .86904 L p .682 .709 .868 r
F P
0 g
s
.72595 .86904 m .70989 .86129 L .72209 .84942 L p .682 .709 .868 r
F P
0 g
s
.72386 .86416 m .67912 .49034 L .69242 .49767 L p .835 .484 .391 r
F P
0 g
s
.69242 .49767 m .74008 .872 L .72386 .86416 L p .835 .484 .391 r
F P
0 g
s
.75254 .86008 m .74008 .872 L .69242 .49767 L p .288 .099 .441 r
F P
0 g
s
.69242 .49767 m .70236 .48653 L .75254 .86008 L p .288 .099 .441 r
F P
0 g
s
.72209 .84942 m .67912 .49034 L .69242 .49767 L p .835 .484 .391 r
F P
0 g
s
.69242 .49767 m .7382 .85725 L .72209 .84942 L p .835 .484 .391 r
F P
0 g
s
.75254 .86008 m .74008 .872 L .69242 .49767 L p .288 .099 .441 r
F P
0 g
s
.69242 .49767 m .70236 .48653 L .75254 .86008 L p .288 .099 .441 r
F P
0 g
s
.23227 .47743 m .24678 .48483 L .23862 .49599 L p .694 .677 .829 r
F P
0 g
s
.23862 .49599 m .22414 .48865 L .23227 .47743 L p .694 .677 .829 r
F P
0 g
s
.16373 .86235 m .22414 .48865 L .23862 .49599 L p .824 .51 .458 r
F P
0 g
s
.23862 .49599 m .18174 .8702 L .16373 .86235 L p .824 .51 .458 r
F P
0 g
s
.20173 .86324 m .18398 .85545 L .19369 .84354 L p .682 .709 .868 r
F P
0 g
s
.19151 .85826 m .18174 .8702 L .23862 .49599 L p .036 0 .253 r
F P
0 g
s
.23862 .49599 m .24678 .48483 L .19151 .85826 L p .036 0 .253 r
F P
0 g
s
.16373 .86235 m .22414 .48865 L .23862 .49599 L p .824 .51 .458 r
F P
0 g
s
.23862 .49599 m .18174 .8702 L .16373 .86235 L p .824 .51 .458 r
F P
0 g
s
.19369 .84354 m .18398 .85545 L .23862 .49599 L p .036 0 .253 r
F P
0 g
s
.23862 .49599 m .24678 .48483 L .19369 .84354 L p .036 0 .253 r
F P
0 g
s
.29224 .47717 m .3066 .48457 L .29821 .49573 L p .694 .677 .829 r
F P
0 g
s
.29821 .49573 m .28388 .48838 L .29224 .47717 L p .694 .677 .829 r
F P
0 g
s
.23911 .84733 m .28388 .48838 L .29821 .49573 L p .825 .507 .451 r
F P
0 g
s
.29821 .49573 m .25675 .85517 L .23911 .84733 L p .825 .507 .451 r
F P
0 g
s
.26681 .84325 m .25675 .85517 L .29821 .49573 L p .08 0 .287 r
F P
0 g
s
.29821 .49573 m .3066 .48457 L .26681 .84325 L p .08 0 .287 r
F P
0 g
s
.23727 .86206 m .28388 .48838 L .29821 .49573 L p .825 .507 .451 r
F P
0 g
s
.29821 .49573 m .25505 .86992 L .23727 .86206 L p .825 .507 .451 r
F P
0 g
s
.26518 .85798 m .25505 .86992 L .29821 .49573 L p .08 0 .287 r
F P
0 g
s
.29821 .49573 m .3066 .48457 L .26518 .85798 L p .08 0 .287 r
F P
0 g
s
.35223 .4769 m .36643 .4843 L .3578 .49546 L p .694 .677 .829 r
F P
0 g
s
.3578 .49546 m .34363 .48812 L .35223 .4769 L p .694 .677 .829 r
F P
0 g
s
.31083 .86178 m .34363 .48812 L .3578 .49546 L p .827 .504 .443 r
F P
0 g
s
.3578 .49546 m .32837 .86963 L .31083 .86178 L p .827 .504 .443 r
F P
0 g
s
.34683 .86269 m .32953 .85489 L .33995 .84297 L p .682 .709 .868 r
F P
0 g
s
.33886 .85769 m .32837 .86963 L .3578 .49546 L p .121 0 .318 r
F P
0 g
s
.3578 .49546 m .36643 .4843 L .33886 .85769 L p .121 0 .318 r
F P
0 g
s
.31083 .86178 m .34363 .48812 L .3578 .49546 L p .827 .504 .443 r
F P
0 g
s
.3578 .49546 m .32837 .86963 L .31083 .86178 L p .827 .504 .443 r
F P
0 g
s
.33995 .84297 m .32953 .85489 L .3578 .49546 L p .121 0 .318 r
F P
0 g
s
.3578 .49546 m .36643 .4843 L .33995 .84297 L p .121 0 .318 r
F P
0 g
s
.41222 .47663 m .42627 .48403 L .41741 .4952 L p .694 .677 .829 r
F P
0 g
s
.41741 .4952 m .40339 .48785 L .41222 .47663 L p .694 .677 .829 r
F P
0 g
s
.38942 .76277 m .40339 .48785 L .41741 .4952 L p .828 .501 .435 r
F P
0 g
s
.41741 .4952 m .40586 .77053 L .38942 .76277 L p .828 .501 .435 r
F P
0 g
s
.41619 .75873 m .40586 .77053 L .41741 .4952 L p .157 0 .346 r
F P
0 g
s
.41741 .4952 m .42627 .48403 L .41619 .75873 L p .157 0 .346 r
F P
0 g
s
.38874 .77627 m .40339 .48785 L .41741 .4952 L p .828 .501 .435 r
F P
0 g
s
.41741 .4952 m .4053 .78405 L .38874 .77627 L p .828 .501 .435 r
F P
0 g
s
.41569 .77222 m .4053 .78405 L .41741 .4952 L p .157 0 .346 r
F P
0 g
s
.41741 .4952 m .42627 .48403 L .41569 .77222 L p .157 0 .346 r
F P
0 g
s
.47223 .47636 m .48613 .48377 L .47703 .49494 L p .694 .677 .829 r
F P
0 g
s
.47703 .49494 m .46316 .48759 L .47223 .47636 L p .694 .677 .829 r
F P
0 g
s
.45955 .74918 m .46316 .48759 L .47703 .49494 L p .83 .498 .426 r
F P
0 g
s
.47703 .49494 m .47566 .75693 L .45955 .74918 L p .83 .498 .426 r
F P
0 g
s
.49164 .75148 m .47573 .74379 L .48623 .73203 L p .687 .699 .856 r
F P
0 g
s
.48623 .74515 m .47566 .75693 L .47703 .49494 L p .19 0 .37 r
F P
0 g
s
.47703 .49494 m .48613 .48377 L .48623 .74515 L p .19 0 .37 r
F P
0 g
s
.45955 .74918 m .46316 .48759 L .47703 .49494 L p .83 .498 .426 r
F P
0 g
s
.47703 .49494 m .47566 .75693 L .45955 .74918 L p .83 .498 .426 r
F P
0 g
s
.48623 .73203 m .47573 .74379 L .47703 .49494 L p .19 0 .37 r
F P
0 g
s
.47703 .49494 m .48613 .48377 L .48623 .73203 L p .19 0 .37 r
F P
0 g
s
.53225 .4761 m .54599 .4835 L .53666 .49467 L p .694 .677 .829 r
F P
0 g
s
.53666 .49467 m .52294 .48732 L .53225 .4761 L p .694 .677 .829 r
F P
0 g
s
.52871 .73578 m .52294 .48732 L .53666 .49467 L p .831 .494 .417 r
F P
0 g
s
.53666 .49467 m .54451 .74352 L .52871 .73578 L p .831 .494 .417 r
F P
0 g
s
.55532 .73175 m .54451 .74352 L .53666 .49467 L p .22 .027 .392 r
F P
0 g
s
.53666 .49467 m .54599 .4835 L .55532 .73175 L p .22 .027 .392 r
F P
0 g
s
.52901 .7489 m .52294 .48732 L .53666 .49467 L p .831 .494 .417 r
F P
0 g
s
.53666 .49467 m .54492 .75665 L .52901 .7489 L p .831 .494 .417 r
F P
0 g
s
.55581 .74487 m .54492 .75665 L .53666 .49467 L p .22 .027 .392 r
F P
0 g
s
.53666 .49467 m .54599 .4835 L .55581 .74487 L p .22 .027 .392 r
F P
0 g
s
.59228 .47583 m .60587 .48324 L .5963 .49441 L p .694 .677 .829 r
F P
0 g
s
.5963 .49441 m .58274 .48706 L .59228 .47583 L p .694 .677 .829 r
F P
0 g
s
.60176 .80301 m .58274 .48706 L .5963 .49441 L p .833 .49 .407 r
F P
0 g
s
.5963 .49441 m .61791 .81082 L .60176 .80301 L p .833 .49 .407 r
F P
0 g
s
.6329 .80467 m .61696 .79692 L .62842 .78506 L p .685 .704 .862 r
F P
0 g
s
.62946 .79894 m .61791 .81082 L .5963 .49441 L p .248 .056 .412 r
F P
0 g
s
.5963 .49441 m .60587 .48324 L .62946 .79894 L p .248 .056 .412 r
F P
0 g
s
.60176 .80301 m .58274 .48706 L .5963 .49441 L p .833 .49 .407 r
F P
0 g
s
.5963 .49441 m .61791 .81082 L .60176 .80301 L p .833 .49 .407 r
F P
0 g
s
.62842 .78506 m .61696 .79692 L .5963 .49441 L p .248 .056 .412 r
F P
0 g
s
.5963 .49441 m .60587 .48324 L .62842 .78506 L p .248 .056 .412 r
F P
0 g
s
.65232 .47556 m .66575 .48297 L .65595 .49414 L p .694 .677 .829 r
F P
0 g
s
.65595 .49414 m .64254 .48679 L .65232 .47556 L p .694 .677 .829 r
F P
0 g
s
.67464 .81682 m .64254 .48679 L .65595 .49414 L p .834 .486 .397 r
F P
0 g
s
.65595 .49414 m .69069 .82465 L .67464 .81682 L p .834 .486 .397 r
F P
0 g
s
.70266 .81275 m .69069 .82465 L .65595 .49414 L p .272 .082 .43 r
F P
0 g
s
.65595 .49414 m .66575 .48297 L .70266 .81275 L p .272 .082 .43 r
F P
0 g
s
.67603 .83112 m .64254 .48679 L .65595 .49414 L p .834 .486 .397 r
F P
0 g
s
.65595 .49414 m .69219 .83896 L .67603 .83112 L p .834 .486 .397 r
F P
0 g
s
.70426 .82704 m .69219 .83896 L .65595 .49414 L p .272 .082 .43 r
F P
0 g
s
.65595 .49414 m .66575 .48297 L .70426 .82704 L p .272 .082 .43 r
F P
0 g
s
.71237 .47529 m .72565 .4827 L .71561 .49388 L p .694 .677 .829 r
F P
0 g
s
.71561 .49388 m .70236 .48653 L .71237 .47529 L p .694 .677 .829 r
F P
0 g
s
.75254 .86008 m .70236 .48653 L .71561 .49388 L p .835 .482 .386 r
F P
0 g
s
.71561 .49388 m .76869 .86794 L .75254 .86008 L p .835 .482 .386 r
F P
0 g
s
.78132 .85598 m .76869 .86794 L .71561 .49388 L p .295 .107 .446 r
F P
0 g
s
.71561 .49388 m .72565 .4827 L .78132 .85598 L p .295 .107 .446 r
F P
0 g
s
.75254 .86008 m .70236 .48653 L .71561 .49388 L p .835 .482 .386 r
F P
0 g
s
.71561 .49388 m .76869 .86794 L .75254 .86008 L p .835 .482 .386 r
F P
0 g
s
.19496 .47385 m .20959 .48127 L .20156 .49246 L p .694 .677 .829 r
F P
0 g
s
.20156 .49246 m .18697 .4851 L .19496 .47385 L p .694 .677 .829 r
F P
0 g
s
.11786 .85854 m .18697 .4851 L .20156 .49246 L p .823 .511 .462 r
F P
0 g
s
.20156 .49246 m .13604 .86642 L .11786 .85854 L p .823 .511 .462 r
F P
0 g
s
.14561 .85445 m .13604 .86642 L .20156 .49246 L p .004 0 .228 r
F P
0 g
s
.20156 .49246 m .20959 .48127 L .14561 .85445 L p .004 0 .228 r
F P
0 g
s
.14561 .85445 m .13604 .86642 L .20156 .49246 L p .004 0 .228 r
F P
0 g
s
.20156 .49246 m .20959 .48127 L .14561 .85445 L p .004 0 .228 r
F P
0 g
s
.25501 .47358 m .26948 .481 L .26122 .49219 L p .694 .677 .829 r
F P
0 g
s
.26122 .49219 m .24678 .48483 L .25501 .47358 L p .694 .677 .829 r
F P
0 g
s
.19584 .82903 m .24678 .48483 L .26122 .49219 L p .825 .508 .454 r
F P
0 g
s
.26122 .49219 m .21351 .83688 L .19584 .82903 L p .825 .508 .454 r
F P
0 g
s
.22331 .82494 m .21351 .83688 L .26122 .49219 L p .051 0 .265 r
F P
0 g
s
.26122 .49219 m .26948 .481 L .22331 .82494 L p .051 0 .265 r
F P
0 g
s
.19369 .84354 m .24678 .48483 L .26122 .49219 L p .825 .508 .454 r
F P
0 g
s
.26122 .49219 m .2115 .8514 L .19369 .84354 L p .825 .508 .454 r
F P
0 g
s
.22331 .82494 m .21351 .83688 L .26122 .49219 L p .051 0 .265 r
F P
0 g
s
.26122 .49219 m .26948 .481 L .22331 .82494 L p .051 0 .265 r
F P
0 g
s
.31506 .47332 m .32938 .48074 L .32089 .49193 L p .694 .677 .829 r
F P
0 g
s
.32089 .49193 m .3066 .48457 L .31506 .47332 L p .694 .677 .829 r
F P
0 g
s
.27157 .80036 m .3066 .48457 L .32089 .49193 L p .826 .506 .447 r
F P
0 g
s
.32089 .49193 m .28875 .80819 L .27157 .80036 L p .826 .506 .447 r
F P
0 g
s
.29877 .79628 m .28875 .80819 L .32089 .49193 L p .094 0 .298 r
F P
0 g
s
.32089 .49193 m .32938 .48074 L .29877 .79628 L p .094 0 .298 r
F P
0 g
s
.26518 .85798 m .3066 .48457 L .32089 .49193 L p .826 .506 .447 r
F P
0 g
s
.32089 .49193 m .28289 .86585 L .26518 .85798 L p .826 .506 .447 r
F P
0 g
s
.29318 .85388 m .28289 .86585 L .32089 .49193 L p .094 0 .298 r
F P
0 g
s
.32089 .49193 m .32938 .48074 L .29318 .85388 L p .094 0 .298 r
F P
0 g
s
.37513 .47305 m .3893 .48047 L .38057 .49166 L p .694 .677 .829 r
F P
0 g
s
.38057 .49166 m .36643 .4843 L .37513 .47305 L p .694 .677 .829 r
F P
0 g
s
.33995 .84297 m .3573 .85084 L .34683 .86269 L p .682 .709 .868 r
F P
0 g
s
.33886 .85769 m .36643 .4843 L .38057 .49166 L p .828 .503 .439 r
F P
0 g
s
.38057 .49166 m .35635 .86557 L .33886 .85769 L p .828 .503 .439 r
F P
0 g
s
.36699 .85359 m .35635 .86557 L .38057 .49166 L p .133 0 .328 r
F P
0 g
s
.38057 .49166 m .3893 .48047 L .36699 .85359 L p .133 0 .328 r
F P
0 g
s
.33995 .84297 m .36643 .4843 L .38057 .49166 L p .828 .503 .439 r
F P
0 g
s
.38057 .49166 m .3573 .85084 L .33995 .84297 L p .828 .503 .439 r
F P
0 g
s
.36699 .85359 m .35635 .86557 L .38057 .49166 L p .133 0 .328 r
F P
0 g
s
.38057 .49166 m .3893 .48047 L .36699 .85359 L p .133 0 .328 r
F P
0 g
s
.43521 .47278 m .44922 .4802 L .44025 .4914 L p .694 .677 .829 r
F P
0 g
s
.44025 .4914 m .42627 .48403 L .43521 .47278 L p .694 .677 .829 r
F P
0 g
s
.41668 .74543 m .42627 .48403 L .44025 .4914 L p .829 .499 .43 r
F P
0 g
s
.44025 .4914 m .43294 .7532 L .41668 .74543 L p .829 .499 .43 r
F P
0 g
s
.44333 .74138 m .43294 .7532 L .44025 .4914 L p .169 0 .354 r
F P
0 g
s
.44025 .4914 m .44922 .4802 L .44333 .74138 L p .169 0 .354 r
F P
0 g
s
.41569 .77222 m .42627 .48403 L .44025 .4914 L p .829 .499 .43 r
F P
0 g
s
.44025 .4914 m .43219 .78002 L .41569 .77222 L p .829 .499 .43 r
F P
0 g
s
.44333 .74138 m .43294 .7532 L .44025 .4914 L p .169 0 .354 r
F P
0 g
s
.44025 .4914 m .44922 .4802 L .44333 .74138 L p .169 0 .354 r
F P
0 g
s
.4953 .47251 m .50916 .47994 L .49995 .49113 L p .694 .677 .829 r
F P
0 g
s
.49995 .49113 m .48613 .48377 L .4953 .47251 L p .694 .677 .829 r
F P
0 g
s
.48622 .7191 m .48613 .48377 L .49995 .49113 L p .831 .496 .421 r
F P
0 g
s
.49995 .49113 m .50206 .72684 L .48622 .7191 L p .831 .496 .421 r
F P
0 g
s
.51262 .71507 m .50206 .72684 L .49995 .49113 L p .201 .006 .378 r
F P
0 g
s
.49995 .49113 m .50916 .47994 L .51262 .71507 L p .201 .006 .378 r
F P
0 g
s
.48623 .73203 m .48613 .48377 L .49995 .49113 L p .831 .496 .421 r
F P
0 g
s
.49995 .49113 m .50218 .73979 L .48623 .73203 L p .831 .496 .421 r
F P
0 g
s
.51262 .71507 m .50206 .72684 L .49995 .49113 L p .201 .006 .378 r
F P
0 g
s
.49995 .49113 m .50916 .47994 L .51262 .71507 L p .201 .006 .378 r
F P
0 g
s
.5554 .47224 m .5691 .47967 L .55967 .49087 L p .694 .677 .829 r
F P
0 g
s
.55967 .49087 m .54599 .4835 L .5554 .47224 L p .694 .677 .829 r
F P
0 g
s
.55581 .74487 m .54599 .4835 L .55967 .49087 L p .832 .492 .412 r
F P
0 g
s
.55967 .49087 m .57166 .75264 L .55581 .74487 L p .832 .492 .412 r
F P
0 g
s
.58269 .74082 m .57166 .75264 L .55967 .49087 L p .23 .037 .399 r
F P
0 g
s
.55967 .49087 m .5691 .47967 L .58269 .74082 L p .23 .037 .399 r
F P
0 g
s
.55581 .74487 m .54599 .4835 L .55967 .49087 L p .832 .492 .412 r
F P
0 g
s
.55967 .49087 m .57166 .75264 L .55581 .74487 L p .832 .492 .412 r
F P
0 g
s
.58552 .79515 m .57416 .80706 L .55967 .49087 L p .23 .037 .399 r
F P
0 g
s
.55967 .49087 m .5691 .47967 L .58552 .79515 L p .23 .037 .399 r
F P
0 g
s
.61551 .47198 m .62906 .4794 L .61939 .49061 L p .694 .677 .829 r
F P
0 g
s
.61939 .49061 m .60587 .48324 L .61551 .47198 L p .694 .677 .829 r
F P
0 g
s
.62842 .78506 m .6444 .79288 L .6329 .80467 L p .685 .704 .862 r
F P
0 g
s
.62946 .79894 m .60587 .48324 L .61939 .49061 L p .833 .488 .402 r
F P
0 g
s
.61939 .49061 m .64555 .80678 L .62946 .79894 L p .833 .488 .402 r
F P
0 g
s
.65724 .79487 m .64555 .80678 L .61939 .49061 L p .256 .065 .418 r
F P
0 g
s
.61939 .49061 m .62906 .4794 L .65724 .79487 L p .256 .065 .418 r
F P
0 g
s
.62842 .78506 m .60587 .48324 L .61939 .49061 L p .833 .488 .402 r
F P
0 g
s
.61939 .49061 m .6444 .79288 L .62842 .78506 L p .833 .488 .402 r
F P
0 g
s
.65724 .79487 m .64555 .80678 L .61939 .49061 L p .256 .065 .418 r
F P
0 g
s
.61939 .49061 m .62906 .4794 L .65724 .79487 L p .256 .065 .418 r
F P
0 g
s
.67564 .47171 m .68903 .47914 L .67912 .49034 L p .694 .677 .829 r
F P
0 g
s
.67912 .49034 m .66575 .48297 L .67564 .47171 L p .694 .677 .829 r
F P
0 g
s
.69219 .83896 m .70825 .84675 L .69625 .85848 L p .683 .708 .867 r
F P
0 g
s
.70426 .82704 m .72035 .8349 L .70825 .84675 L p .683 .708 .867 r
F P
0 g
s
.70825 .84675 m .69219 .83896 L .70426 .82704 L p .683 .708 .867 r
F P
0 g
s
.70753 .85627 m .66575 .48297 L .67912 .49034 L p .835 .484 .391 r
F P
0 g
s
.67912 .49034 m .72386 .86416 L .70753 .85627 L p .835 .484 .391 r
F P
0 g
s
.73628 .85216 m .72386 .86416 L .67912 .49034 L p .28 .091 .436 r
F P
0 g
s
.67912 .49034 m .68903 .47914 L .73628 .85216 L p .28 .091 .436 r
F P
0 g
s
.70426 .82704 m .66575 .48297 L .67912 .49034 L p .835 .484 .391 r
F P
0 g
s
.67912 .49034 m .72035 .8349 L .70426 .82704 L p .835 .484 .391 r
F P
0 g
s
.73628 .85216 m .72386 .86416 L .67912 .49034 L p .28 .091 .436 r
F P
0 g
s
.67912 .49034 m .68903 .47914 L .73628 .85216 L p .28 .091 .436 r
F P
0 g
s
.21768 .46999 m .23227 .47743 L .22414 .48865 L p .694 .677 .829 r
F P
0 g
s
.22414 .48865 m .20959 .48127 L .21768 .46999 L p .694 .677 .829 r
F P
0 g
s
.14814 .83973 m .20959 .48127 L .22414 .48865 L p .824 .51 .458 r
F P
0 g
s
.22414 .48865 m .16611 .84762 L .14814 .83973 L p .824 .51 .458 r
F P
0 g
s
.17577 .83562 m .16611 .84762 L .22414 .48865 L p .02 0 .24 r
F P
0 g
s
.22414 .48865 m .23227 .47743 L .17577 .83562 L p .02 0 .24 r
F P
0 g
s
.14561 .85445 m .20959 .48127 L .22414 .48865 L p .824 .51 .458 r
F P
0 g
s
.22414 .48865 m .16373 .86235 L .14561 .85445 L p .824 .51 .458 r
F P
0 g
s
.17345 .85033 m .16373 .86235 L .22414 .48865 L p .02 0 .24 r
F P
0 g
s
.22414 .48865 m .23227 .47743 L .17345 .85033 L p .02 0 .24 r
F P
0 g
s
.27781 .46973 m .29224 .47717 L .28388 .48838 L p .694 .677 .829 r
F P
0 g
s
.28388 .48838 m .26948 .481 L .27781 .46973 L p .694 .677 .829 r
F P
0 g
s
.22331 .82494 m .26948 .481 L .28388 .48838 L p .825 .507 .451 r
F P
0 g
s
.28388 .48838 m .24092 .83282 L .22331 .82494 L p .825 .507 .451 r
F P
0 g
s
.25087 .82084 m .24092 .83282 L .28388 .48838 L p .066 0 .276 r
F P
0 g
s
.28388 .48838 m .29224 .47717 L .25087 .82084 L p .066 0 .276 r
F P
0 g
s
.22331 .82494 m .26948 .481 L .28388 .48838 L p .825 .507 .451 r
F P
0 g
s
.28388 .48838 m .24092 .83282 L .22331 .82494 L p .825 .507 .451 r
F P
0 g
s
.24912 .83533 m .23911 .84733 L .28388 .48838 L p .066 0 .276 r
F P
0 g
s
.28388 .48838 m .29224 .47717 L .24912 .83533 L p .066 0 .276 r
F P
0 g
s
.33795 .46946 m .35223 .4769 L .34363 .48812 L p .694 .677 .829 r
F P
0 g
s
.34363 .48812 m .32938 .48074 L .33795 .46946 L p .694 .677 .829 r
F P
0 g
s
.29461 .83916 m .32938 .48074 L .34363 .48812 L p .827 .504 .443 r
F P
0 g
s
.34363 .48812 m .31213 .84705 L .29461 .83916 L p .827 .504 .443 r
F P
0 g
s
.32249 .83505 m .31213 .84705 L .34363 .48812 L p .108 0 .308 r
F P
0 g
s
.34363 .48812 m .35223 .4769 L .32249 .83505 L p .108 0 .308 r
F P
0 g
s
.29318 .85388 m .32938 .48074 L .34363 .48812 L p .827 .504 .443 r
F P
0 g
s
.34363 .48812 m .31083 .86178 L .29318 .85388 L p .827 .504 .443 r
F P
0 g
s
.32127 .84976 m .31083 .86178 L .34363 .48812 L p .108 0 .308 r
F P
0 g
s
.34363 .48812 m .35223 .4769 L .32127 .84976 L p .108 0 .308 r
F P
0 g
s
.3981 .46919 m .41222 .47663 L .40339 .48785 L p .694 .677 .829 r
F P
0 g
s
.40339 .48785 m .3893 .48047 L .3981 .46919 L p .694 .677 .829 r
F P
0 g
s
.36699 .85359 m .3893 .48047 L .40339 .48785 L p .828 .501 .435 r
F P
0 g
s
.40339 .48785 m .38441 .8615 L .36699 .85359 L p .828 .501 .435 r
F P
0 g
s
.41141 .80343 m .395 .79577 L .4053 .78405 L p .685 .702 .86 r
F P
0 g
s
.40586 .77053 m .38942 .76277 L .3997 .75089 L p .686 .701 .859 r
F P
0 g
s
.40613 .86166 m .38966 .85416 L .39996 .84269 L p .684 .705 .863 r
F P
0 g
s
.38874 .77627 m .4053 .78405 L .395 .79577 L p .685 .702 .86 r
F P
0 g
s
.3937 .82342 m .41035 .83111 L .39996 .84269 L p .684 .705 .863 r
F P
0 g
s
.3952 .84947 m .38441 .8615 L .40339 .48785 L p .145 0 .337 r
F P
0 g
s
.40339 .48785 m .41222 .47663 L .3952 .84947 L p .145 0 .337 r
F P
0 g
s
.36699 .85359 m .3893 .48047 L .40339 .48785 L p .828 .501 .435 r
F P
0 g
s
.40339 .48785 m .38441 .8615 L .36699 .85359 L p .828 .501 .435 r
F P
0 g
s
.3997 .75089 m .38942 .76277 L .40339 .48785 L p .145 0 .337 r
F P
0 g
s
.40339 .48785 m .41222 .47663 L .3997 .75089 L p .145 0 .337 r
F P
0 g
s
.45826 .46892 m .47223 .47636 L .46316 .48759 L p .694 .677 .829 r
F P
0 g
s
.46316 .48759 m .44922 .4802 L .45826 .46892 L p .694 .677 .829 r
F P
0 g
s
.44363 .72827 m .44922 .4802 L .46316 .48759 L p .83 .498 .426 r
F P
0 g
s
.46316 .48759 m .45973 .73606 L .44363 .72827 L p .83 .498 .426 r
F P
0 g
s
.47018 .72423 m .45973 .73606 L .46316 .48759 L p .18 0 .362 r
F P
0 g
s
.46316 .48759 m .47223 .47636 L .47018 .72423 L p .18 0 .362 r
F P
0 g
s
.44333 .74138 m .44922 .4802 L .46316 .48759 L p .83 .498 .426 r
F P
0 g
s
.46316 .48759 m .45955 .74918 L .44333 .74138 L p .83 .498 .426 r
F P
0 g
s
.47008 .73732 m .45955 .74918 L .46316 .48759 L p .18 0 .362 r
F P
0 g
s
.46316 .48759 m .47223 .47636 L .47008 .73732 L p .18 0 .362 r
F P
0 g
s
.51843 .46865 m .53225 .4761 L .52294 .48732 L p .694 .677 .829 r
F P
0 g
s
.52294 .48732 m .50916 .47994 L .51843 .46865 L p .694 .677 .829 r
F P
0 g
s
.51262 .71507 m .50916 .47994 L .52294 .48732 L p .831 .494 .417 r
F P
0 g
s
.52294 .48732 m .52841 .72284 L .51262 .71507 L p .831 .494 .417 r
F P
0 g
s
.5391 .71103 m .52841 .72284 L .52294 .48732 L p .211 .017 .385 r
F P
0 g
s
.52294 .48732 m .53225 .4761 L .5391 .71103 L p .211 .017 .385 r
F P
0 g
s
.51262 .71507 m .50916 .47994 L .52294 .48732 L p .831 .494 .417 r
F P
0 g
s
.52294 .48732 m .52841 .72284 L .51262 .71507 L p .831 .494 .417 r
F P
0 g
s
.53948 .72394 m .52871 .73578 L .52294 .48732 L p .211 .017 .385 r
F P
0 g
s
.52294 .48732 m .53225 .4761 L .53948 .72394 L p .211 .017 .385 r
F P
0 g
s
.57862 .46838 m .59228 .47583 L .58274 .48706 L p .694 .677 .829 r
F P
0 g
s
.58274 .48706 m .5691 .47967 L .57862 .46838 L p .694 .677 .829 r
F P
0 g
s
.58479 .78127 m .5691 .47967 L .58274 .48706 L p .833 .49 .407 r
F P
0 g
s
.58274 .48706 m .60093 .78912 L .58479 .78127 L p .833 .49 .407 r
F P
0 g
s
.61235 .77719 m .60093 .78912 L .58274 .48706 L p .239 .047 .406 r
F P
0 g
s
.58274 .48706 m .59228 .47583 L .61235 .77719 L p .239 .047 .406 r
F P
0 g
s
.58552 .79515 m .5691 .47967 L .58274 .48706 L p .833 .49 .407 r
F P
0 g
s
.58274 .48706 m .60176 .80301 L .58552 .79515 L p .833 .49 .407 r
F P
0 g
s
.61327 .79106 m .60176 .80301 L .58274 .48706 L p .239 .047 .406 r
F P
0 g
s
.58274 .48706 m .59228 .47583 L .61327 .79106 L p .239 .047 .406 r
F P
0 g
s
.63881 .46811 m .65232 .47556 L .64254 .48679 L p .694 .677 .829 r
F P
0 g
s
.64254 .48679 m .62906 .4794 L .63881 .46811 L p .694 .677 .829 r
F P
0 g
s
.65724 .79487 m .62906 .4794 L .64254 .48679 L p .834 .486 .397 r
F P
0 g
s
.64254 .48679 m .67327 .80273 L .65724 .79487 L p .834 .486 .397 r
F P
0 g
s
.68512 .79077 m .67327 .80273 L .64254 .48679 L p .264 .074 .424 r
F P
0 g
s
.64254 .48679 m .65232 .47556 L .68512 .79077 L p .264 .074 .424 r
F P
0 g
s
.65724 .79487 m .62906 .4794 L .64254 .48679 L p .834 .486 .397 r
F P
0 g
s
.64254 .48679 m .67327 .80273 L .65724 .79487 L p .834 .486 .397 r
F P
0 g
s
.68658 .80485 m .67464 .81682 L .64254 .48679 L p .264 .074 .424 r
F P
0 g
s
.64254 .48679 m .65232 .47556 L .68658 .80485 L p .264 .074 .424 r
F P
0 g
s
.69902 .46785 m .71237 .47529 L .70236 .48653 L p .694 .677 .829 r
F P
0 g
s
.70236 .48653 m .68903 .47914 L .69902 .46785 L p .694 .677 .829 r
F P
0 g
s
.73442 .83745 m .68903 .47914 L .70236 .48653 L p .835 .482 .386 r
F P
0 g
s
.70236 .48653 m .75056 .84535 L .73442 .83745 L p .835 .482 .386 r
F P
0 g
s
.76304 .83333 m .75056 .84535 L .70236 .48653 L p .288 .099 .441 r
F P
0 g
s
.70236 .48653 m .71237 .47529 L .76304 .83333 L p .288 .099 .441 r
F P
0 g
s
.73628 .85216 m .68903 .47914 L .70236 .48653 L p .835 .482 .386 r
F P
0 g
s
.70236 .48653 m .75254 .86008 L .73628 .85216 L p .835 .482 .386 r
F P
0 g
s
.76512 .84804 m .75254 .86008 L .70236 .48653 L p .288 .099 .441 r
F P
0 g
s
.70236 .48653 m .71237 .47529 L .76512 .84804 L p .288 .099 .441 r
F P
0 g
s
.18026 .4664 m .19496 .47385 L .18697 .4851 L p .694 .677 .829 r
F P
0 g
s
.18697 .4851 m .17231 .4777 L .18026 .4664 L p .694 .677 .829 r
F P
0 g
s
.09957 .85062 m .17231 .4777 L .18697 .4851 L p .823 .511 .462 r
F P
0 g
s
.18697 .4851 m .11786 .85854 L .09957 .85062 L p .823 .511 .462 r
F P
0 g
s
.12738 .84649 m .11786 .85854 L .18697 .4851 L p 0 0 .214 r
F P
0 g
s
.18697 .4851 m .19496 .47385 L .12738 .84649 L p 0 0 .214 r
F P
0 g
s
.12738 .84649 m .11786 .85854 L .18697 .4851 L p 0 0 .214 r
F P
0 g
s
.18697 .4851 m .19496 .47385 L .12738 .84649 L p 0 0 .214 r
F P
0 g
s
.24046 .46613 m .25501 .47358 L .24678 .48483 L p .694 .677 .829 r
F P
0 g
s
.24678 .48483 m .23227 .47743 L .24046 .46613 L p .694 .677 .829 r
F P
0 g
s
.17345 .85033 m .23227 .47743 L .24678 .48483 L p .825 .508 .454 r
F P
0 g
s
.24678 .48483 m .19151 .85826 L .17345 .85033 L p .825 .508 .454 r
F P
0 g
s
.21351 .83688 m .19584 .82903 L .20559 .81701 L p .683 .708 .867 r
F P
0 g
s
.19369 .84354 m .2115 .8514 L .20173 .86324 L p .682 .709 .868 r
F P
0 g
s
.20139 .84621 m .19151 .85826 L .24678 .48483 L p .036 0 .253 r
F P
0 g
s
.24678 .48483 m .25501 .47358 L .20139 .84621 L p .036 0 .253 r
F P
0 g
s
.17345 .85033 m .23227 .47743 L .24678 .48483 L p .825 .508 .454 r
F P
0 g
s
.24678 .48483 m .19151 .85826 L .17345 .85033 L p .825 .508 .454 r
F P
0 g
s
.20559 .81701 m .19584 .82903 L .24678 .48483 L p .036 0 .253 r
F P
0 g
s
.24678 .48483 m .25501 .47358 L .20559 .81701 L p .036 0 .253 r
F P
0 g
s
.30067 .46586 m .31506 .47332 L .3066 .48457 L p .694 .677 .829 r
F P
0 g
s
.3066 .48457 m .29224 .47717 L .30067 .46586 L p .694 .677 .829 r
F P
0 g
s
.25428 .79248 m .29224 .47717 L .3066 .48457 L p .826 .506 .447 r
F P
0 g
s
.3066 .48457 m .27157 .80036 L .25428 .79248 L p .826 .506 .447 r
F P
0 g
s
.28153 .78838 m .27157 .80036 L .3066 .48457 L p .08 0 .287 r
F P
0 g
s
.3066 .48457 m .31506 .47332 L .28153 .78838 L p .08 0 .287 r
F P
0 g
s
.24912 .83533 m .29224 .47717 L .3066 .48457 L p .826 .506 .447 r
F P
0 g
s
.3066 .48457 m .26681 .84325 L .24912 .83533 L p .826 .506 .447 r
F P
0 g
s
.28153 .78838 m .27157 .80036 L .3066 .48457 L p .08 0 .287 r
F P
0 g
s
.3066 .48457 m .31506 .47332 L .28153 .78838 L p .08 0 .287 r
F P
0 g
s
.36089 .46559 m .37513 .47305 L .36643 .4843 L p .694 .677 .829 r
F P
0 g
s
.36643 .4843 m .35223 .4769 L .36089 .46559 L p .694 .677 .829 r
F P
0 g
s
.32369 .82055 m .35223 .4769 L .36643 .4843 L p .828 .503 .439 r
F P
0 g
s
.36643 .4843 m .34102 .82846 L .32369 .82055 L p .828 .503 .439 r
F P
0 g
s
.35146 .81644 m .34102 .82846 L .36643 .4843 L p .121 0 .318 r
F P
0 g
s
.36643 .4843 m .37513 .47305 L .35146 .81644 L p .121 0 .318 r
F P
0 g
s
.32127 .84976 m .35223 .4769 L .36643 .4843 L p .828 .503 .439 r
F P
0 g
s
.36643 .4843 m .33886 .85769 L .32127 .84976 L p .828 .503 .439 r
F P
0 g
s
.34945 .84563 m .33886 .85769 L .36643 .4843 L p .121 0 .318 r
F P
0 g
s
.36643 .4843 m .37513 .47305 L .34945 .84563 L p .121 0 .318 r
F P
0 g
s
.42113 .46532 m .43521 .47278 L .42627 .48403 L p .694 .677 .829 r
F P
0 g
s
.42627 .48403 m .41222 .47663 L .42113 .46532 L p .694 .677 .829 r
F P
0 g
s
.40031 .73761 m .41222 .47663 L .42627 .48403 L p .829 .499 .43 r
F P
0 g
s
.42627 .48403 m .41668 .74543 L .40031 .73761 L p .829 .499 .43 r
F P
0 g
s
.42702 .73354 m .41668 .74543 L .42627 .48403 L p .157 0 .346 r
F P
0 g
s
.42627 .48403 m .43521 .47278 L .42702 .73354 L p .157 0 .346 r
F P
0 g
s
.3997 .75089 m .41222 .47663 L .42627 .48403 L p .829 .499 .43 r
F P
0 g
s
.42627 .48403 m .41619 .75873 L .3997 .75089 L p .829 .499 .43 r
F P
0 g
s
.42702 .73354 m .41668 .74543 L .42627 .48403 L p .157 0 .346 r
F P
0 g
s
.42627 .48403 m .43521 .47278 L .42702 .73354 L p .157 0 .346 r
F P
0 g
s
.48137 .46505 m .4953 .47251 L .48613 .48377 L p .694 .677 .829 r
F P
0 g
s
.48613 .48377 m .47223 .47636 L .48137 .46505 L p .694 .677 .829 r
F P
0 g
s
.47008 .73732 m .47223 .47636 L .48613 .48377 L p .831 .496 .421 r
F P
0 g
s
.48613 .48377 m .48623 .74515 L .47008 .73732 L p .831 .496 .421 r
F P
0 g
s
.50206 .72684 m .48622 .7191 L .49674 .70726 L p .687 .698 .854 r
F P
0 g
s
.48623 .73203 m .50218 .73979 L .49164 .75148 L p .687 .699 .856 r
F P
0 g
s
.4969 .73325 m .48623 .74515 L .48613 .48377 L p .19 0 .37 r
F P
0 g
s
.48613 .48377 m .4953 .47251 L .4969 .73325 L p .19 0 .37 r
F P
0 g
s
.47008 .73732 m .47223 .47636 L .48613 .48377 L p .831 .496 .421 r
F P
0 g
s
.48613 .48377 m .48623 .74515 L .47008 .73732 L p .831 .496 .421 r
F P
0 g
s
.49674 .70726 m .48622 .7191 L .48613 .48377 L p .19 0 .37 r
F P
0 g
s
.48613 .48377 m .4953 .47251 L .49674 .70726 L p .19 0 .37 r
F P
0 g
s
.54163 .46478 m .5554 .47224 L .54599 .4835 L p .694 .677 .829 r
F P
0 g
s
.54599 .4835 m .53225 .4761 L .54163 .46478 L p .694 .677 .829 r
F P
0 g
s
.53948 .72394 m .55532 .73175 L .54451 .74352 L p .687 .699 .856 r
F P
0 g
s
.54451 .74352 m .52871 .73578 L .53948 .72394 L p .687 .699 .856 r
F P
0 g
s
.53986 .73704 m .53225 .4761 L .54599 .4835 L p .832 .492 .412 r
F P
0 g
s
.54599 .4835 m .55581 .74487 L .53986 .73704 L p .832 .492 .412 r
F P
0 g
s
.56679 .73297 m .55581 .74487 L .54599 .4835 L p .22 .027 .392 r
F P
0 g
s
.54599 .4835 m .5554 .47224 L .56679 .73297 L p .22 .027 .392 r
F P
0 g
s
.53948 .72394 m .53225 .4761 L .54599 .4835 L p .832 .492 .412 r
F P
0 g
s
.54599 .4835 m .55532 .73175 L .53948 .72394 L p .832 .492 .412 r
F P
0 g
s
.56679 .73297 m .55581 .74487 L .54599 .4835 L p .22 .027 .392 r
F P
0 g
s
.54599 .4835 m .5554 .47224 L .56679 .73297 L p .22 .027 .392 r
F P
0 g
s
.60189 .46451 m .61551 .47198 L .60587 .48324 L p .694 .677 .829 r
F P
0 g
s
.60587 .48324 m .59228 .47583 L .60189 .46451 L p .694 .677 .829 r
F P
0 g
s
.61144 .76352 m .59228 .47583 L .60587 .48324 L p .833 .488 .402 r
F P
0 g
s
.60587 .48324 m .6274 .77138 L .61144 .76352 L p .833 .488 .402 r
F P
0 g
s
.63888 .75943 m .6274 .77138 L .60587 .48324 L p .248 .056 .412 r
F P
0 g
s
.60587 .48324 m .61551 .47198 L .63888 .75943 L p .248 .056 .412 r
F P
0 g
s
.61327 .79106 m .59228 .47583 L .60587 .48324 L p .833 .488 .402 r
F P
0 g
s
.60587 .48324 m .62946 .79894 L .61327 .79106 L p .833 .488 .402 r
F P
0 g
s
.64111 .78695 m .62946 .79894 L .60587 .48324 L p .248 .056 .412 r
F P
0 g
s
.60587 .48324 m .61551 .47198 L .64111 .78695 L p .248 .056 .412 r
F P
0 g
s
.66217 .46424 m .67564 .47171 L .66575 .48297 L p .694 .677 .829 r
F P
0 g
s
.66575 .48297 m .65232 .47556 L .66217 .46424 L p .694 .677 .829 r
F P
0 g
s
.69625 .85848 m .68023 .85077 L .69219 .83896 L p .683 .708 .867 r
F P
0 g
s
.68658 .80485 m .70266 .81275 L .69069 .82465 L p .683 .706 .865 r
F P
0 g
s
.69069 .82465 m .67464 .81682 L .68658 .80485 L p .683 .706 .865 r
F P
0 g
s
.67603 .83112 m .69219 .83896 L .68023 .85077 L p .683 .708 .867 r
F P
0 g
s
.6911 .84833 m .65232 .47556 L .66575 .48297 L p .835 .484 .391 r
F P
0 g
s
.66575 .48297 m .70753 .85627 L .6911 .84833 L p .835 .484 .391 r
F P
0 g
s
.71992 .8442 m .70753 .85627 L .66575 .48297 L p .272 .082 .43 r
F P
0 g
s
.66575 .48297 m .67564 .47171 L .71992 .8442 L p .272 .082 .43 r
F P
0 g
s
.68658 .80485 m .65232 .47556 L .66575 .48297 L p .835 .484 .391 r
F P
0 g
s
.66575 .48297 m .70266 .81275 L .68658 .80485 L p .835 .484 .391 r
F P
0 g
s
.71992 .8442 m .70753 .85627 L .66575 .48297 L p .272 .082 .43 r
F P
0 g
s
.66575 .48297 m .67564 .47171 L .71992 .8442 L p .272 .082 .43 r
F P
0 g
s
.72246 .46397 m .73577 .47144 L .72565 .4827 L p .694 .677 .829 r
F P
0 g
s
.72565 .4827 m .71237 .47529 L .72246 .46397 L p .694 .677 .829 r
F P
0 g
s
.76512 .84804 m .71237 .47529 L .72565 .4827 L p .836 .479 .38 r
F P
0 g
s
.72565 .4827 m .78132 .85598 L .76512 .84804 L p .836 .479 .38 r
F P
0 g
s
.79406 .84391 m .78132 .85598 L .72565 .4827 L p .295 .107 .446 r
F P
0 g
s
.72565 .4827 m .73577 .47144 L .79406 .84391 L p .295 .107 .446 r
F P
0 g
s
.76512 .84804 m .71237 .47529 L .72565 .4827 L p .836 .479 .38 r
F P
0 g
s
.72565 .4827 m .78132 .85598 L .76512 .84804 L p .836 .479 .38 r
F P
0 g
s
.20302 .46252 m .21768 .46999 L .20959 .48127 L p .694 .677 .829 r
F P
0 g
s
.20959 .48127 m .19496 .47385 L .20302 .46252 L p .694 .677 .829 r
F P
0 g
s
.12738 .84649 m .19496 .47385 L .20959 .48127 L p .824 .51 .458 r
F P
0 g
s
.20959 .48127 m .14561 .85445 L .12738 .84649 L p .824 .51 .458 r
F P
0 g
s
.16611 .84762 m .14814 .83973 L .15774 .82766 L p .682 .709 .868 r
F P
0 g
s
.15528 .84236 m .14561 .85445 L .20959 .48127 L p .004 0 .228 r
F P
0 g
s
.20959 .48127 m .21768 .46999 L .15528 .84236 L p .004 0 .228 r
F P
0 g
s
.12738 .84649 m .19496 .47385 L .20959 .48127 L p .824 .51 .458 r
F P
0 g
s
.20959 .48127 m .14561 .85445 L .12738 .84649 L p .824 .51 .458 r
F P
0 g
s
.15774 .82766 m .14814 .83973 L .20959 .48127 L p .004 0 .228 r
F P
0 g
s
.20959 .48127 m .21768 .46999 L .15774 .82766 L p .004 0 .228 r
F P
0 g
s
.2633 .46225 m .27781 .46973 L .26948 .481 L p .694 .677 .829 r
F P
0 g
s
.26948 .481 m .25501 .47358 L .2633 .46225 L p .694 .677 .829 r
F P
0 g
s
.20764 .80274 m .25501 .47358 L .26948 .481 L p .825 .507 .451 r
F P
0 g
s
.26948 .481 m .22523 .81065 L .20764 .80274 L p .825 .507 .451 r
F P
0 g
s
.23506 .79862 m .22523 .81065 L .26948 .481 L p .051 0 .265 r
F P
0 g
s
.26948 .481 m .27781 .46973 L .23506 .79862 L p .051 0 .265 r
F P
0 g
s
.20559 .81701 m .25501 .47358 L .26948 .481 L p .825 .507 .451 r
F P
0 g
s
.26948 .481 m .22331 .82494 L .20559 .81701 L p .825 .507 .451 r
F P
0 g
s
.2332 .81289 m .22331 .82494 L .26948 .481 L p .051 0 .265 r
F P
0 g
s
.26948 .481 m .27781 .46973 L .2332 .81289 L p .051 0 .265 r
F P
0 g
s
.32359 .46198 m .33795 .46946 L .32938 .48074 L p .694 .677 .829 r
F P
0 g
s
.32938 .48074 m .31506 .47332 L .32359 .46198 L p .694 .677 .829 r
F P
0 g
s
.28153 .78838 m .31506 .47332 L .32938 .48074 L p .827 .504 .443 r
F P
0 g
s
.32938 .48074 m .29877 .79628 L .28153 .78838 L p .827 .504 .443 r
F P
0 g
s
.30887 .78427 m .29877 .79628 L .32938 .48074 L p .094 0 .298 r
F P
0 g
s
.32938 .48074 m .33795 .46946 L .30887 .78427 L p .094 0 .298 r
F P
0 g
s
.28153 .78838 m .31506 .47332 L .32938 .48074 L p .827 .504 .443 r
F P
0 g
s
.32938 .48074 m .29877 .79628 L .28153 .78838 L p .827 .504 .443 r
F P
0 g
s
.30492 .82708 m .29461 .83916 L .32938 .48074 L p .094 0 .298 r
F P
0 g
s
.32938 .48074 m .33795 .46946 L .30492 .82708 L p .094 0 .298 r
F P
0 g
s
.3839 .46171 m .3981 .46919 L .3893 .48047 L p .694 .677 .829 r
F P
0 g
s
.3893 .48047 m .37513 .47305 L .3839 .46171 L p .694 .677 .829 r
F P
0 g
s
.35047 .83093 m .37513 .47305 L .3893 .48047 L p .828 .501 .435 r
F P
0 g
s
.3893 .48047 m .36787 .83887 L .35047 .83093 L p .828 .501 .435 r
F P
0 g
s
.37853 .82679 m .36787 .83887 L .3893 .48047 L p .133 0 .328 r
F P
0 g
s
.3893 .48047 m .3981 .46919 L .37853 .82679 L p .133 0 .328 r
F P
0 g
s
.34945 .84563 m .37513 .47305 L .3893 .48047 L p .828 .501 .435 r
F P
0 g
s
.3893 .48047 m .36699 .85359 L .34945 .84563 L p .828 .501 .435 r
F P
0 g
s
.37773 .84149 m .36699 .85359 L .3893 .48047 L p .133 0 .328 r
F P
0 g
s
.3893 .48047 m .3981 .46919 L .37773 .84149 L p .133 0 .328 r
F P
0 g
s
.44422 .46144 m .45826 .46892 L .44922 .4802 L p .694 .677 .829 r
F P
0 g
s
.44922 .4802 m .43521 .47278 L .44422 .46144 L p .694 .677 .829 r
F P
0 g
s
.42702 .73354 m .43521 .47278 L .44922 .4802 L p .83 .498 .426 r
F P
0 g
s
.44922 .4802 m .44333 .74138 L .42702 .73354 L p .83 .498 .426 r
F P
0 g
s
.45973 .73606 m .44363 .72827 L .45404 .71637 L p .687 .699 .856 r
F P
0 g
s
.45382 .72945 m .44333 .74138 L .44922 .4802 L p .169 0 .354 r
F P
0 g
s
.44922 .4802 m .45826 .46892 L .45382 .72945 L p .169 0 .354 r
F P
0 g
s
.42702 .73354 m .43521 .47278 L .44922 .4802 L p .83 .498 .426 r
F P
0 g
s
.44922 .4802 m .44333 .74138 L .42702 .73354 L p .83 .498 .426 r
F P
0 g
s
.45404 .71637 m .44363 .72827 L .44922 .4802 L p .169 0 .354 r
F P
0 g
s
.44922 .4802 m .45826 .46892 L .45404 .71637 L p .169 0 .354 r
F P
0 g
s
.50454 .46117 m .51843 .46865 L .50916 .47994 L p .694 .677 .829 r
F P
0 g
s
.50916 .47994 m .4953 .47251 L .50454 .46117 L p .694 .677 .829 r
F P
0 g
s
.49666 .69453 m .4953 .47251 L .50916 .47994 L p .831 .494 .417 r
F P
0 g
s
.50916 .47994 m .51243 .70232 L .49666 .69453 L p .831 .494 .417 r
F P
0 g
s
.52301 .69047 m .51243 .70232 L .50916 .47994 L p .201 .006 .378 r
F P
0 g
s
.50916 .47994 m .51843 .46865 L .52301 .69047 L p .201 .006 .378 r
F P
0 g
s
.49674 .70726 m .4953 .47251 L .50916 .47994 L p .831 .494 .417 r
F P
0 g
s
.50916 .47994 m .51262 .71507 L .49674 .70726 L p .831 .494 .417 r
F P
0 g
s
.52327 .70319 m .51262 .71507 L .50916 .47994 L p .201 .006 .378 r
F P
0 g
s
.50916 .47994 m .51843 .46865 L .52327 .70319 L p .201 .006 .378 r
F P
0 g
s
.56488 .4609 m .57862 .46838 L .5691 .47967 L p .694 .677 .829 r
F P
0 g
s
.5691 .47967 m .5554 .47224 L .56488 .4609 L p .694 .677 .829 r
F P
0 g
s
.56679 .73297 m .5554 .47224 L .5691 .47967 L p .833 .49 .407 r
F P
0 g
s
.5691 .47967 m .58269 .74082 L .56679 .73297 L p .833 .49 .407 r
F P
0 g
s
.59382 .72889 m .58269 .74082 L .5691 .47967 L p .23 .037 .399 r
F P
0 g
s
.5691 .47967 m .57862 .46838 L .59382 .72889 L p .23 .037 .399 r
F P
0 g
s
.56679 .73297 m .5554 .47224 L .5691 .47967 L p .833 .49 .407 r
F P
0 g
s
.5691 .47967 m .58269 .74082 L .56679 .73297 L p .833 .49 .407 r
F P
0 g
s
.59617 .76927 m .58479 .78127 L .5691 .47967 L p .23 .037 .399 r
F P
0 g
s
.5691 .47967 m .57862 .46838 L .59617 .76927 L p .23 .037 .399 r
F P
0 g
s
.62523 .46063 m .63881 .46811 L .62906 .4794 L p .694 .677 .829 r
F P
0 g
s
.62906 .4794 m .61551 .47198 L .62523 .46063 L p .694 .677 .829 r
F P
0 g
s
.63999 .77309 m .61551 .47198 L .62906 .4794 L p .834 .486 .397 r
F P
0 g
s
.62906 .4794 m .656 .78099 L .63999 .77309 L p .834 .486 .397 r
F P
0 g
s
.66772 .76898 m .656 .78099 L .62906 .4794 L p .256 .065 .418 r
F P
0 g
s
.62906 .4794 m .63881 .46811 L .66772 .76898 L p .256 .065 .418 r
F P
0 g
s
.64111 .78695 m .61551 .47198 L .62906 .4794 L p .834 .486 .397 r
F P
0 g
s
.62906 .4794 m .65724 .79487 L .64111 .78695 L p .834 .486 .397 r
F P
0 g
s
.66905 .78284 m .65724 .79487 L .62906 .4794 L p .256 .065 .418 r
F P
0 g
s
.62906 .4794 m .63881 .46811 L .66905 .78284 L p .256 .065 .418 r
F P
0 g
s
.68559 .46036 m .69902 .46785 L .68903 .47914 L p .694 .677 .829 r
F P
0 g
s
.68903 .47914 m .67564 .47171 L .68559 .46036 L p .694 .677 .829 r
F P
0 g
s
.71992 .8442 m .67564 .47171 L .68903 .47914 L p .835 .482 .386 r
F P
0 g
s
.68903 .47914 m .73628 .85216 L .71992 .8442 L p .835 .482 .386 r
F P
0 g
s
.75056 .84535 m .73442 .83745 L .74686 .82535 L p .682 .709 .868 r
F P
0 g
s
.74883 .84005 m .73628 .85216 L .68903 .47914 L p .28 .091 .436 r
F P
0 g
s
.68903 .47914 m .69902 .46785 L .74883 .84005 L p .28 .091 .436 r
F P
0 g
s
.71992 .8442 m .67564 .47171 L .68903 .47914 L p .835 .482 .386 r
F P
0 g
s
.68903 .47914 m .73628 .85216 L .71992 .8442 L p .835 .482 .386 r
F P
0 g
s
.74686 .82535 m .73442 .83745 L .68903 .47914 L p .28 .091 .436 r
F P
0 g
s
.68903 .47914 m .69902 .46785 L .74686 .82535 L p .28 .091 .436 r
F P
0 g
s
.16548 .4589 m .18026 .4664 L .17231 .4777 L p .694 .677 .829 r
F P
0 g
s
.17231 .4777 m .15757 .47026 L .16548 .4589 L p .694 .677 .829 r
F P
0 g
s
.08116 .84264 m .15757 .47026 L .17231 .4777 L p .823 .511 .462 r
F P
0 g
s
.17231 .4777 m .09957 .85062 L .08116 .84264 L p .823 .511 .462 r
F P
0 g
s
.10903 .83849 m .09957 .85062 L .17231 .4777 L p 0 0 .2 r
F P
0 g
s
.17231 .4777 m .18026 .4664 L .10903 .83849 L p 0 0 .2 r
F P
0 g
s
.10903 .83849 m .09957 .85062 L .17231 .4777 L p 0 0 .2 r
F P
0 g
s
.17231 .4777 m .18026 .4664 L .10903 .83849 L p 0 0 .2 r
F P
0 g
s
.22584 .45863 m .24046 .46613 L .23227 .47743 L p .694 .677 .829 r
F P
0 g
s
.23227 .47743 m .21768 .46999 L .22584 .45863 L p .694 .677 .829 r
F P
0 g
s
.15774 .82766 m .17577 .83562 L .16611 .84762 L p .682 .709 .868 r
F P
0 g
s
.15528 .84236 m .21768 .46999 L .23227 .47743 L p .825 .508 .454 r
F P
0 g
s
.23227 .47743 m .17345 .85033 L .15528 .84236 L p .825 .508 .454 r
F P
0 g
s
.18327 .8382 m .17345 .85033 L .23227 .47743 L p .02 0 .24 r
F P
0 g
s
.23227 .47743 m .24046 .46613 L .18327 .8382 L p .02 0 .24 r
F P
0 g
s
.15774 .82766 m .21768 .46999 L .23227 .47743 L p .825 .508 .454 r
F P
0 g
s
.23227 .47743 m .17577 .83562 L .15774 .82766 L p .825 .508 .454 r
F P
0 g
s
.18327 .8382 m .17345 .85033 L .23227 .47743 L p .02 0 .24 r
F P
0 g
s
.23227 .47743 m .24046 .46613 L .18327 .8382 L p .02 0 .24 r
F P
0 g
s
.2862 .45836 m .30067 .46586 L .29224 .47717 L p .694 .677 .829 r
F P
0 g
s
.29224 .47717 m .27781 .46973 L .2862 .45836 L p .694 .677 .829 r
F P
0 g
s
.23689 .78456 m .27781 .46973 L .29224 .47717 L p .826 .506 .447 r
F P
0 g
s
.29224 .47717 m .25428 .79248 L .23689 .78456 L p .826 .506 .447 r
F P
0 g
s
.2642 .78043 m .25428 .79248 L .29224 .47717 L p .066 0 .276 r
F P
0 g
s
.29224 .47717 m .30067 .46586 L .2642 .78043 L p .066 0 .276 r
F P
0 g
s
.2332 .81289 m .27781 .46973 L .29224 .47717 L p .826 .506 .447 r
F P
0 g
s
.29224 .47717 m .25087 .82084 L .2332 .81289 L p .826 .506 .447 r
F P
0 g
s
.2642 .78043 m .25428 .79248 L .29224 .47717 L p .066 0 .276 r
F P
0 g
s
.29224 .47717 m .30067 .46586 L .2642 .78043 L p .066 0 .276 r
F P
0 g
s
.34658 .45809 m .36089 .46559 L .35223 .4769 L p .694 .677 .829 r
F P
0 g
s
.35223 .4769 m .33795 .46946 L .34658 .45809 L p .694 .677 .829 r
F P
0 g
s
.30626 .8126 m .33795 .46946 L .35223 .4769 L p .828 .503 .439 r
F P
0 g
s
.35223 .4769 m .32369 .82055 L .30626 .8126 L p .828 .503 .439 r
F P
0 g
s
.33409 .80846 m .32369 .82055 L .35223 .4769 L p .108 0 .308 r
F P
0 g
s
.35223 .4769 m .36089 .46559 L .33409 .80846 L p .108 0 .308 r
F P
0 g
s
.30492 .82708 m .33795 .46946 L .35223 .4769 L p .828 .503 .439 r
F P
0 g
s
.35223 .4769 m .32249 .83505 L .30492 .82708 L p .828 .503 .439 r
F P
0 g
s
.33409 .80846 m .32369 .82055 L .35223 .4769 L p .108 0 .308 r
F P
0 g
s
.35223 .4769 m .36089 .46559 L .33409 .80846 L p .108 0 .308 r
F P
0 g
s
.40697 .45782 m .42113 .46532 L .41222 .47663 L p .694 .677 .829 r
F P
0 g
s
.41222 .47663 m .3981 .46919 L .40697 .45782 L p .694 .677 .829 r
F P
0 g
s
.37773 .84149 m .3981 .46919 L .41222 .47663 L p .829 .499 .43 r
F P
0 g
s
.41222 .47663 m .3952 .84947 L .37773 .84149 L p .829 .499 .43 r
F P
0 g
s
.41668 .74543 m .40031 .73761 L .41061 .72564 L p .686 .7 .857 r
F P
0 g
s
.4053 .78405 m .42176 .79178 L .41141 .80343 L p .685 .702 .86 r
F P
0 g
s
.3997 .75089 m .41619 .75873 L .40586 .77053 L p .686 .701 .859 r
F P
0 g
s
.39996 .84269 m .41647 .85026 L .40613 .86166 L p .684 .705 .863 r
F P
0 g
s
.42176 .79178 m .4053 .78405 L .41569 .77222 L p .685 .702 .86 r
F P
0 g
s
.4061 .83734 m .3952 .84947 L .41222 .47663 L p .145 0 .337 r
F P
0 g
s
.41222 .47663 m .42113 .46532 L .4061 .83734 L p .145 0 .337 r
F P
0 g
s
.37773 .84149 m .3981 .46919 L .41222 .47663 L p .829 .499 .43 r
F P
0 g
s
.41222 .47663 m .3952 .84947 L .37773 .84149 L p .829 .499 .43 r
F P
0 g
s
.41061 .72564 m .40031 .73761 L .41222 .47663 L p .145 0 .337 r
F P
0 g
s
.41222 .47663 m .42113 .46532 L .41061 .72564 L p .145 0 .337 r
F P
0 g
s
.46737 .45755 m .48137 .46505 L .47223 .47636 L p .694 .677 .829 r
F P
0 g
s
.47223 .47636 m .45826 .46892 L .46737 .45755 L p .694 .677 .829 r
F P
0 g
s
.45404 .71637 m .47018 .72423 L .45973 .73606 L p .687 .699 .856 r
F P
0 g
s
.45382 .72945 m .45826 .46892 L .47223 .47636 L p .831 .496 .421 r
F P
0 g
s
.47223 .47636 m .47008 .73732 L .45382 .72945 L p .831 .496 .421 r
F P
0 g
s
.4807 .72536 m .47008 .73732 L .47223 .47636 L p .18 0 .362 r
F P
0 g
s
.47223 .47636 m .48137 .46505 L .4807 .72536 L p .18 0 .362 r
F P
0 g
s
.45404 .71637 m .45826 .46892 L .47223 .47636 L p .831 .496 .421 r
F P
0 g
s
.47223 .47636 m .47018 .72423 L .45404 .71637 L p .831 .496 .421 r
F P
0 g
s
.4807 .72536 m .47008 .73732 L .47223 .47636 L p .18 0 .362 r
F P
0 g
s
.47223 .47636 m .48137 .46505 L .4807 .72536 L p .18 0 .362 r
F P
0 g
s
.52778 .45728 m .54163 .46478 L .53225 .4761 L p .694 .677 .829 r
F P
0 g
s
.53225 .4761 m .51843 .46865 L .52778 .45728 L p .694 .677 .829 r
F P
0 g
s
.51262 .71507 m .52841 .72284 L .51781 .73454 L p .687 .698 .854 r
F P
0 g
s
.52327 .70319 m .5391 .71103 L .52841 .72284 L p .687 .698 .854 r
F P
0 g
s
.52841 .72284 m .51262 .71507 L .52327 .70319 L p .687 .698 .854 r
F P
0 g
s
.52381 .72917 m .51843 .46865 L .53225 .4761 L p .832 .492 .412 r
F P
0 g
s
.53225 .4761 m .53986 .73704 L .52381 .72917 L p .832 .492 .412 r
F P
0 g
s
.5508 .72507 m .53986 .73704 L .53225 .4761 L p .211 .017 .385 r
F P
0 g
s
.53225 .4761 m .54163 .46478 L .5508 .72507 L p .211 .017 .385 r
F P
0 g
s
.52327 .70319 m .51843 .46865 L .53225 .4761 L p .832 .492 .412 r
F P
0 g
s
.53225 .4761 m .5391 .71103 L .52327 .70319 L p .832 .492 .412 r
F P
0 g
s
.5508 .72507 m .53986 .73704 L .53225 .4761 L p .211 .017 .385 r
F P
0 g
s
.53225 .4761 m .54163 .46478 L .5508 .72507 L p .211 .017 .385 r
F P
0 g
s
.5882 .45701 m .60189 .46451 L .59228 .47583 L p .694 .677 .829 r
F P
0 g
s
.59228 .47583 m .57862 .46838 L .5882 .45701 L p .694 .677 .829 r
F P
0 g
s
.59538 .75561 m .57862 .46838 L .59228 .47583 L p .833 .488 .402 r
F P
0 g
s
.59228 .47583 m .61144 .76352 L .59538 .75561 L p .833 .488 .402 r
F P
0 g
s
.62287 .7515 m .61144 .76352 L .59228 .47583 L p .239 .047 .406 r
F P
0 g
s
.59228 .47583 m .60189 .46451 L .62287 .7515 L p .239 .047 .406 r
F P
0 g
s
.59617 .76927 m .57862 .46838 L .59228 .47583 L p .833 .488 .402 r
F P
0 g
s
.59228 .47583 m .61235 .77719 L .59617 .76927 L p .833 .488 .402 r
F P
0 g
s
.62287 .7515 m .61144 .76352 L .59228 .47583 L p .239 .047 .406 r
F P
0 g
s
.59228 .47583 m .60189 .46451 L .62287 .7515 L p .239 .047 .406 r
F P
0 g
s
.64864 .45673 m .66217 .46424 L .65232 .47556 L p .694 .677 .829 r
F P
0 g
s
.65232 .47556 m .63881 .46811 L .64864 .45673 L p .694 .677 .829 r
F P
0 g
s
.65724 .79487 m .67327 .80273 L .66154 .81457 L p .684 .705 .863 r
F P
0 g
s
.66905 .78284 m .68512 .79077 L .67327 .80273 L p .684 .705 .863 r
F P
0 g
s
.67327 .80273 m .65724 .79487 L .66905 .78284 L p .684 .705 .863 r
F P
0 g
s
.68023 .85077 m .66412 .843 L .67603 .83112 L p .683 .708 .867 r
F P
0 g
s
.67457 .84034 m .63881 .46811 L .65232 .47556 L p .835 .484 .391 r
F P
0 g
s
.65232 .47556 m .6911 .84833 L .67457 .84034 L p .835 .484 .391 r
F P
0 g
s
.70345 .83618 m .6911 .84833 L .65232 .47556 L p .264 .074 .424 r
F P
0 g
s
.65232 .47556 m .66217 .46424 L .70345 .83618 L p .264 .074 .424 r
F P
0 g
s
.66905 .78284 m .63881 .46811 L .65232 .47556 L p .835 .484 .391 r
F P
0 g
s
.65232 .47556 m .68512 .79077 L .66905 .78284 L p .835 .484 .391 r
F P
0 g
s
.70345 .83618 m .6911 .84833 L .65232 .47556 L p .264 .074 .424 r
F P
0 g
s
.65232 .47556 m .66217 .46424 L .70345 .83618 L p .264 .074 .424 r
F P
0 g
s
.70908 .45646 m .72246 .46397 L .71237 .47529 L p .694 .677 .829 r
F P
0 g
s
.71237 .47529 m .69902 .46785 L .70908 .45646 L p .694 .677 .829 r
F P
0 g
s
.74686 .82535 m .76304 .83333 L .75056 .84535 L p .682 .709 .868 r
F P
0 g
s
.74883 .84005 m .69902 .46785 L .71237 .47529 L p .836 .479 .38 r
F P
0 g
s
.71237 .47529 m .76512 .84804 L .74883 .84005 L p .836 .479 .38 r
F P
0 g
s
.77783 .83589 m .76512 .84804 L .71237 .47529 L p .288 .099 .441 r
F P
0 g
s
.71237 .47529 m .72246 .46397 L .77783 .83589 L p .288 .099 .441 r
F P
0 g
s
.74686 .82535 m .69902 .46785 L .71237 .47529 L p .836 .479 .38 r
F P
0 g
s
.71237 .47529 m .76304 .83333 L .74686 .82535 L p .836 .479 .38 r
F P
0 g
s
.77783 .83589 m .76512 .84804 L .71237 .47529 L p .288 .099 .441 r
F P
0 g
s
.71237 .47529 m .72246 .46397 L .77783 .83589 L p .288 .099 .441 r
F P
0 g
s
.18828 .455 m .20302 .46252 L .19496 .47385 L p .694 .677 .829 r
F P
0 g
s
.19496 .47385 m .18026 .4664 L .18828 .455 L p .694 .677 .829 r
F P
0 g
s
.11184 .8238 m .18026 .4664 L .19496 .47385 L p .824 .51 .458 r
F P
0 g
s
.19496 .47385 m .13005 .83179 L .11184 .8238 L p .824 .51 .458 r
F P
0 g
s
.13959 .81964 m .13005 .83179 L .19496 .47385 L p 0 0 .214 r
F P
0 g
s
.19496 .47385 m .20302 .46252 L .13959 .81964 L p 0 0 .214 r
F P
0 g
s
.10903 .83849 m .18026 .4664 L .19496 .47385 L p .824 .51 .458 r
F P
0 g
s
.19496 .47385 m .12738 .84649 L .10903 .83849 L p .824 .51 .458 r
F P
0 g
s
.13699 .83433 m .12738 .84649 L .19496 .47385 L p 0 0 .214 r
F P
0 g
s
.19496 .47385 m .20302 .46252 L .13699 .83433 L p 0 0 .214 r
F P
0 g
s
.24872 .45473 m .2633 .46225 L .25501 .47358 L p .694 .677 .829 r
F P
0 g
s
.25501 .47358 m .24046 .46613 L .24872 .45473 L p .694 .677 .829 r
F P
0 g
s
.18327 .8382 m .24046 .46613 L .25501 .47358 L p .825 .507 .451 r
F P
0 g
s
.25501 .47358 m .20139 .84621 L .18327 .8382 L p .825 .507 .451 r
F P
0 g
s
.22523 .81065 m .20764 .80274 L .21742 .79063 L p .683 .706 .865 r
F P
0 g
s
.20559 .81701 m .22331 .82494 L .21351 .83688 L p .683 .708 .867 r
F P
0 g
s
.21136 .83404 m .20139 .84621 L .25501 .47358 L p .036 0 .253 r
F P
0 g
s
.25501 .47358 m .2633 .46225 L .21136 .83404 L p .036 0 .253 r
F P
0 g
s
.18327 .8382 m .24046 .46613 L .25501 .47358 L p .825 .507 .451 r
F P
0 g
s
.25501 .47358 m .20139 .84621 L .18327 .8382 L p .825 .507 .451 r
F P
0 g
s
.21742 .79063 m .20764 .80274 L .25501 .47358 L p .036 0 .253 r
F P
0 g
s
.25501 .47358 m .2633 .46225 L .21742 .79063 L p .036 0 .253 r
F P
0 g
s
.30917 .45446 m .32359 .46198 L .31506 .47332 L p .694 .677 .829 r
F P
0 g
s
.31506 .47332 m .30067 .46586 L .30917 .45446 L p .694 .677 .829 r
F P
0 g
s
.2658 .76658 m .30067 .46586 L .31506 .47332 L p .827 .504 .443 r
F P
0 g
s
.31506 .47332 m .28301 .77452 L .2658 .76658 L p .827 .504 .443 r
F P
0 g
s
.293 .76245 m .28301 .77452 L .31506 .47332 L p .08 0 .287 r
F P
0 g
s
.31506 .47332 m .32359 .46198 L .293 .76245 L p .08 0 .287 r
F P
0 g
s
.2642 .78043 m .30067 .46586 L .31506 .47332 L p .827 .504 .443 r
F P
0 g
s
.31506 .47332 m .28153 .78838 L .2642 .78043 L p .827 .504 .443 r
F P
0 g
s
.29159 .77629 m .28153 .78838 L .31506 .47332 L p .08 0 .287 r
F P
0 g
s
.31506 .47332 m .32359 .46198 L .29159 .77629 L p .08 0 .287 r
F P
0 g
s
.36963 .45419 m .3839 .46171 L .37513 .47305 L p .694 .677 .829 r
F P
0 g
s
.37513 .47305 m .36089 .46559 L .36963 .45419 L p .694 .677 .829 r
F P
0 g
s
.33409 .80846 m .36089 .46559 L .37513 .47305 L p .828 .501 .435 r
F P
0 g
s
.37513 .47305 m .35146 .81644 L .33409 .80846 L p .828 .501 .435 r
F P
0 g
s
.36201 .8043 m .35146 .81644 L .37513 .47305 L p .121 0 .318 r
F P
0 g
s
.37513 .47305 m .3839 .46171 L .36201 .8043 L p .121 0 .318 r
F P
0 g
s
.33409 .80846 m .36089 .46559 L .37513 .47305 L p .828 .501 .435 r
F P
0 g
s
.37513 .47305 m .35146 .81644 L .33409 .80846 L p .828 .501 .435 r
F P
0 g
s
.36108 .81877 m .35047 .83093 L .37513 .47305 L p .121 0 .318 r
F P
0 g
s
.37513 .47305 m .3839 .46171 L .36108 .81877 L p .121 0 .318 r
F P
0 g
s
.4301 .45392 m .44422 .46144 L .43521 .47278 L p .694 .677 .829 r
F P
0 g
s
.43521 .47278 m .42113 .46532 L .4301 .45392 L p .694 .677 .829 r
F P
0 g
s
.41114 .71257 m .42113 .46532 L .43521 .47278 L p .83 .498 .426 r
F P
0 g
s
.43521 .47278 m .42743 .72045 L .41114 .71257 L p .83 .498 .426 r
F P
0 g
s
.4378 .70847 m .42743 .72045 L .43521 .47278 L p .157 0 .346 r
F P
0 g
s
.43521 .47278 m .44422 .46144 L .4378 .70847 L p .157 0 .346 r
F P
0 g
s
.41061 .72564 m .42113 .46532 L .43521 .47278 L p .83 .498 .426 r
F P
0 g
s
.43521 .47278 m .42702 .73354 L .41061 .72564 L p .83 .498 .426 r
F P
0 g
s
.43746 .72154 m .42702 .73354 L .43521 .47278 L p .157 0 .346 r
F P
0 g
s
.43521 .47278 m .44422 .46144 L .43746 .72154 L p .157 0 .346 r
F P
0 g
s
.49058 .45365 m .50454 .46117 L .4953 .47251 L p .694 .677 .829 r
F P
0 g
s
.4953 .47251 m .48137 .46505 L .49058 .45365 L p .694 .677 .829 r
F P
0 g
s
.4807 .72536 m .48137 .46505 L .4953 .47251 L p .831 .494 .417 r
F P
0 g
s
.4953 .47251 m .4969 .73325 L .4807 .72536 L p .831 .494 .417 r
F P
0 g
s
.51781 .73454 m .50206 .72684 L .51262 .71507 L p .687 .698 .854 r
F P
0 g
s
.51243 .70232 m .49666 .69453 L .5072 .6826 L p .687 .696 .853 r
F P
0 g
s
.49674 .70726 m .51262 .71507 L .50206 .72684 L p .687 .698 .854 r
F P
0 g
s
.50767 .72125 m .4969 .73325 L .4953 .47251 L p .19 0 .37 r
F P
0 g
s
.4953 .47251 m .50454 .46117 L .50767 .72125 L p .19 0 .37 r
F P
0 g
s
.4807 .72536 m .48137 .46505 L .4953 .47251 L p .831 .494 .417 r
F P
0 g
s
.4953 .47251 m .4969 .73325 L .4807 .72536 L p .831 .494 .417 r
F P
0 g
s
.5072 .6826 m .49666 .69453 L .4953 .47251 L p .19 0 .37 r
F P
0 g
s
.4953 .47251 m .50454 .46117 L .5072 .6826 L p .19 0 .37 r
F P
0 g
s
.55108 .45337 m .56488 .4609 L .5554 .47224 L p .694 .677 .829 r
F P
0 g
s
.5554 .47224 m .54163 .46478 L .55108 .45337 L p .694 .677 .829 r
F P
0 g
s
.55034 .712 m .54163 .46478 L .5554 .47224 L p .833 .49 .407 r
F P
0 g
s
.5554 .47224 m .56622 .71988 L .55034 .712 L p .833 .49 .407 r
F P
0 g
s
.57723 .7079 m .56622 .71988 L .5554 .47224 L p .22 .027 .392 r
F P
0 g
s
.5554 .47224 m .56488 .4609 L .57723 .7079 L p .22 .027 .392 r
F P
0 g
s
.5508 .72507 m .54163 .46478 L .5554 .47224 L p .833 .49 .407 r
F P
0 g
s
.5554 .47224 m .56679 .73297 L .5508 .72507 L p .833 .49 .407 r
F P
0 g
s
.57788 .72097 m .56679 .73297 L .5554 .47224 L p .22 .027 .392 r
F P
0 g
s
.5554 .47224 m .56488 .4609 L .57788 .72097 L p .22 .027 .392 r
F P
0 g
s
.61158 .4531 m .62523 .46063 L .61551 .47198 L p .694 .677 .829 r
F P
0 g
s
.61551 .47198 m .60189 .46451 L .61158 .4531 L p .694 .677 .829 r
F P
0 g
s
.62287 .7515 m .60189 .46451 L .61551 .47198 L p .834 .486 .397 r
F P
0 g
s
.61551 .47198 m .63888 .75943 L .62287 .7515 L p .834 .486 .397 r
F P
0 g
s
.65046 .74737 m .63888 .75943 L .61551 .47198 L p .248 .056 .412 r
F P
0 g
s
.61551 .47198 m .62523 .46063 L .65046 .74737 L p .248 .056 .412 r
F P
0 g
s
.62287 .7515 m .60189 .46451 L .61551 .47198 L p .834 .486 .397 r
F P
0 g
s
.61551 .47198 m .63888 .75943 L .62287 .7515 L p .834 .486 .397 r
F P
0 g
s
.65166 .76101 m .63999 .77309 L .61551 .47198 L p .248 .056 .412 r
F P
0 g
s
.61551 .47198 m .62523 .46063 L .65166 .76101 L p .248 .056 .412 r
F P
0 g
s
.6721 .45283 m .68559 .46036 L .67564 .47171 L p .694 .677 .829 r
F P
0 g
s
.67564 .47171 m .66217 .46424 L .6721 .45283 L p .694 .677 .829 r
F P
0 g
s
.70182 .82149 m .66217 .46424 L .67564 .47171 L p .835 .482 .386 r
F P
0 g
s
.67564 .47171 m .71817 .82949 L .70182 .82149 L p .835 .482 .386 r
F P
0 g
s
.73057 .81732 m .71817 .82949 L .67564 .47171 L p .272 .082 .43 r
F P
0 g
s
.67564 .47171 m .68559 .46036 L .73057 .81732 L p .272 .082 .43 r
F P
0 g
s
.70345 .83618 m .66217 .46424 L .67564 .47171 L p .835 .482 .386 r
F P
0 g
s
.67564 .47171 m .71992 .8442 L .70345 .83618 L p .835 .482 .386 r
F P
0 g
s
.73242 .83201 m .71992 .8442 L .67564 .47171 L p .272 .082 .43 r
F P
0 g
s
.67564 .47171 m .68559 .46036 L .73242 .83201 L p .272 .082 .43 r
F P
0 g
s
.73263 .45256 m .74597 .46009 L .73577 .47144 L p .694 .677 .829 r
F P
0 g
s
.73577 .47144 m .72246 .46397 L .73263 .45256 L p .694 .677 .829 r
F P
0 g
s
.77783 .83589 m .72246 .46397 L .73577 .47144 L p .836 .477 .374 r
F P
0 g
s
.73577 .47144 m .79406 .84391 L .77783 .83589 L p .836 .477 .374 r
F P
0 g
s
.80693 .83171 m .79406 .84391 L .73577 .47144 L p .295 .107 .446 r
F P
0 g
s
.73577 .47144 m .74597 .46009 L .80693 .83171 L p .295 .107 .446 r
F P
0 g
s
.77783 .83589 m .72246 .46397 L .73577 .47144 L p .836 .477 .374 r
F P
0 g
s
.73577 .47144 m .79406 .84391 L .77783 .83589 L p .836 .477 .374 r
F P
0 g
s
.15062 .45137 m .16548 .4589 L .15757 .47026 L p .694 .677 .829 r
F P
0 g
s
.15757 .47026 m .14275 .46279 L .15062 .45137 L p .694 .677 .829 r
F P
0 g
s
.06263 .83462 m .14275 .46279 L .15757 .47026 L p .823 .511 .462 r
F P
0 g
s
.15757 .47026 m .08116 .84264 L .06263 .83462 L p .823 .511 .462 r
F P
0 g
s
.09056 .83044 m .08116 .84264 L .15757 .47026 L p 0 0 .186 r
F P
0 g
s
.15757 .47026 m .16548 .4589 L .09056 .83044 L p 0 0 .186 r
F P
0 g
s
.09056 .83044 m .08116 .84264 L .15757 .47026 L p 0 0 .186 r
F P
0 g
s
.15757 .47026 m .16548 .4589 L .09056 .83044 L p 0 0 .186 r
F P
0 g
s
.21114 .45109 m .22584 .45863 L .21768 .46999 L p .694 .677 .829 r
F P
0 g
s
.21768 .46999 m .20302 .46252 L .21114 .45109 L p .694 .677 .829 r
F P
0 g
s
.14216 .80517 m .20302 .46252 L .21768 .46999 L p .825 .508 .454 r
F P
0 g
s
.21768 .46999 m .16017 .81317 L .14216 .80517 L p .825 .508 .454 r
F P
0 g
s
.16981 .80101 m .16017 .81317 L .21768 .46999 L p .004 0 .228 r
F P
0 g
s
.21768 .46999 m .22584 .45863 L .16981 .80101 L p .004 0 .228 r
F P
0 g
s
.13699 .83433 m .20302 .46252 L .21768 .46999 L p .825 .508 .454 r
F P
0 g
s
.21768 .46999 m .15528 .84236 L .13699 .83433 L p .825 .508 .454 r
F P
0 g
s
.16504 .83015 m .15528 .84236 L .21768 .46999 L p .004 0 .228 r
F P
0 g
s
.21768 .46999 m .22584 .45863 L .16504 .83015 L p .004 0 .228 r
F P
0 g
s
.27166 .45082 m .2862 .45836 L .27781 .46973 L p .694 .677 .829 r
F P
0 g
s
.27781 .46973 m .2633 .46225 L .27166 .45082 L p .694 .677 .829 r
F P
0 g
s
.21938 .77658 m .2633 .46225 L .27781 .46973 L p .826 .506 .447 r
F P
0 g
s
.27781 .46973 m .23689 .78456 L .21938 .77658 L p .826 .506 .447 r
F P
0 g
s
.24675 .77243 m .23689 .78456 L .27781 .46973 L p .051 0 .265 r
F P
0 g
s
.27781 .46973 m .2862 .45836 L .24675 .77243 L p .051 0 .265 r
F P
0 g
s
.21742 .79063 m .2633 .46225 L .27781 .46973 L p .826 .506 .447 r
F P
0 g
s
.27781 .46973 m .23506 .79862 L .21742 .79063 L p .826 .506 .447 r
F P
0 g
s
.24675 .77243 m .23689 .78456 L .27781 .46973 L p .051 0 .265 r
F P
0 g
s
.27781 .46973 m .2862 .45836 L .24675 .77243 L p .051 0 .265 r
F P
0 g
s
.33219 .45055 m .34658 .45809 L .33795 .46946 L p .694 .677 .829 r
F P
0 g
s
.33795 .46946 m .32359 .46198 L .33219 .45055 L p .694 .677 .829 r
F P
0 g
s
.29159 .77629 m .32359 .46198 L .33795 .46946 L p .828 .503 .439 r
F P
0 g
s
.33795 .46946 m .30887 .78427 L .29159 .77629 L p .828 .503 .439 r
F P
0 g
s
.31908 .77214 m .30887 .78427 L .33795 .46946 L p .094 0 .298 r
F P
0 g
s
.33795 .46946 m .34658 .45809 L .31908 .77214 L p .094 0 .298 r
F P
0 g
s
.29159 .77629 m .32359 .46198 L .33795 .46946 L p .828 .503 .439 r
F P
0 g
s
.33795 .46946 m .30887 .78427 L .29159 .77629 L p .828 .503 .439 r
F P
0 g
s
.3166 .80043 m .30626 .8126 L .33795 .46946 L p .094 0 .298 r
F P
0 g
s
.33795 .46946 m .34658 .45809 L .3166 .80043 L p .094 0 .298 r
F P
0 g
s
.39274 .45028 m .40697 .45782 L .3981 .46919 L p .694 .677 .829 r
F P
0 g
s
.3981 .46919 m .3839 .46171 L .39274 .45028 L p .694 .677 .829 r
F P
0 g
s
.36108 .81877 m .37853 .82679 L .36787 .83887 L p .682 .709 .868 r
F P
0 g
s
.36787 .83887 m .35047 .83093 L .36108 .81877 L p .682 .709 .868 r
F P
0 g
s
.36015 .83346 m .3839 .46171 L .3981 .46919 L p .829 .499 .43 r
F P
0 g
s
.3981 .46919 m .37773 .84149 L .36015 .83346 L p .829 .499 .43 r
F P
0 g
s
.38858 .82927 m .37773 .84149 L .3981 .46919 L p .133 0 .328 r
F P
0 g
s
.3981 .46919 m .40697 .45782 L .38858 .82927 L p .133 0 .328 r
F P
0 g
s
.36108 .81877 m .3839 .46171 L .3981 .46919 L p .829 .499 .43 r
F P
0 g
s
.3981 .46919 m .37853 .82679 L .36108 .81877 L p .829 .499 .43 r
F P
0 g
s
.38858 .82927 m .37773 .84149 L .3981 .46919 L p .133 0 .328 r
F P
0 g
s
.3981 .46919 m .40697 .45782 L .38858 .82927 L p .133 0 .328 r
F P
0 g
s
.45329 .45001 m .46737 .45755 L .45826 .46892 L p .694 .677 .829 r
F P
0 g
s
.45826 .46892 m .44422 .46144 L .45329 .45001 L p .694 .677 .829 r
F P
0 g
s
.43814 .69559 m .44422 .46144 L .45826 .46892 L p .831 .496 .421 r
F P
0 g
s
.45826 .46892 m .45426 .70347 L .43814 .69559 L p .831 .496 .421 r
F P
0 g
s
.4647 .69149 m .45426 .70347 L .45826 .46892 L p .169 0 .354 r
F P
0 g
s
.45826 .46892 m .46737 .45755 L .4647 .69149 L p .169 0 .354 r
F P
0 g
s
.43746 .72154 m .44422 .46144 L .45826 .46892 L p .831 .496 .421 r
F P
0 g
s
.45826 .46892 m .45382 .72945 L .43746 .72154 L p .831 .496 .421 r
F P
0 g
s
.4644 .71742 m .45382 .72945 L .45826 .46892 L p .169 0 .354 r
F P
0 g
s
.45826 .46892 m .46737 .45755 L .4644 .71742 L p .169 0 .354 r
F P
0 g
s
.51386 .44973 m .52778 .45728 L .51843 .46865 L p .694 .677 .829 r
F P
0 g
s
.51843 .46865 m .50454 .46117 L .51386 .44973 L p .694 .677 .829 r
F P
0 g
s
.5072 .6826 m .52301 .69047 L .51243 .70232 L p .687 .696 .853 r
F P
0 g
s
.50767 .72125 m .50454 .46117 L .51843 .46865 L p .832 .492 .412 r
F P
0 g
s
.51843 .46865 m .52381 .72917 L .50767 .72125 L p .832 .492 .412 r
F P
0 g
s
.53472 .71713 m .52381 .72917 L .51843 .46865 L p .201 .006 .378 r
F P
0 g
s
.51843 .46865 m .52778 .45728 L .53472 .71713 L p .201 .006 .378 r
F P
0 g
s
.5072 .6826 m .50454 .46117 L .51843 .46865 L p .832 .492 .412 r
F P
0 g
s
.51843 .46865 m .52301 .69047 L .5072 .6826 L p .832 .492 .412 r
F P
0 g
s
.53472 .71713 m .52381 .72917 L .51843 .46865 L p .201 .006 .378 r
F P
0 g
s
.51843 .46865 m .52778 .45728 L .53472 .71713 L p .201 .006 .378 r
F P
0 g
s
.57444 .44946 m .5882 .45701 L .57862 .46838 L p .694 .677 .829 r
F P
0 g
s
.57862 .46838 m .56488 .4609 L .57444 .44946 L p .694 .677 .829 r
F P
0 g
s
.57788 .72097 m .56488 .4609 L .57862 .46838 L p .833 .488 .402 r
F P
0 g
s
.57862 .46838 m .59382 .72889 L .57788 .72097 L p .833 .488 .402 r
F P
0 g
s
.60504 .71684 m .59382 .72889 L .57862 .46838 L p .23 .037 .399 r
F P
0 g
s
.57862 .46838 m .5882 .45701 L .60504 .71684 L p .23 .037 .399 r
F P
0 g
s
.57788 .72097 m .56488 .4609 L .57862 .46838 L p .833 .488 .402 r
F P
0 g
s
.57862 .46838 m .59382 .72889 L .57788 .72097 L p .833 .488 .402 r
F P
0 g
s
.60677 .74352 m .59538 .75561 L .57862 .46838 L p .23 .037 .399 r
F P
0 g
s
.57862 .46838 m .5882 .45701 L .60677 .74352 L p .23 .037 .399 r
F P
0 g
s
.63503 .44919 m .64864 .45673 L .63881 .46811 L p .694 .677 .829 r
F P
0 g
s
.63881 .46811 m .62523 .46063 L .63503 .44919 L p .694 .677 .829 r
F P
0 g
s
.64555 .80678 m .66154 .81457 L .64992 .8263 L p .684 .705 .863 r
F P
0 g
s
.66154 .81457 m .64555 .80678 L .65724 .79487 L p .684 .705 .863 r
F P
0 g
s
.65166 .76101 m .66772 .76898 L .656 .78099 L p .685 .704 .862 r
F P
0 g
s
.656 .78099 m .63999 .77309 L .65166 .76101 L p .685 .704 .862 r
F P
0 g
s
.64111 .78695 m .65724 .79487 L .64555 .80678 L p .684 .705 .863 r
F P
0 g
s
.65793 .8323 m .62523 .46063 L .63881 .46811 L p .835 .484 .391 r
F P
0 g
s
.63881 .46811 m .67457 .84034 L .65793 .8323 L p .835 .484 .391 r
F P
0 g
s
.68688 .82811 m .67457 .84034 L .63881 .46811 L p .256 .065 .418 r
F P
0 g
s
.63881 .46811 m .64864 .45673 L .68688 .82811 L p .256 .065 .418 r
F P
0 g
s
.65166 .76101 m .62523 .46063 L .63881 .46811 L p .835 .484 .391 r
F P
0 g
s
.63881 .46811 m .66772 .76898 L .65166 .76101 L p .835 .484 .391 r
F P
0 g
s
.68688 .82811 m .67457 .84034 L .63881 .46811 L p .256 .065 .418 r
F P
0 g
s
.63881 .46811 m .64864 .45673 L .68688 .82811 L p .256 .065 .418 r
F P
0 g
s
.69563 .44892 m .70908 .45646 L .69902 .46785 L p .694 .677 .829 r
F P
0 g
s
.69902 .46785 m .68559 .46036 L .69563 .44892 L p .694 .677 .829 r
F P
0 g
s
.72875 .80286 m .68559 .46036 L .69902 .46785 L p .836 .479 .38 r
F P
0 g
s
.69902 .46785 m .74492 .81087 L .72875 .80286 L p .836 .479 .38 r
F P
0 g
s
.75738 .79868 m .74492 .81087 L .69902 .46785 L p .28 .091 .436 r
F P
0 g
s
.69902 .46785 m .70908 .45646 L .75738 .79868 L p .28 .091 .436 r
F P
0 g
s
.73242 .83201 m .68559 .46036 L .69902 .46785 L p .836 .479 .38 r
F P
0 g
s
.69902 .46785 m .74883 .84005 L .73242 .83201 L p .836 .479 .38 r
F P
0 g
s
.76149 .82782 m .74883 .84005 L .69902 .46785 L p .28 .091 .436 r
F P
0 g
s
.69902 .46785 m .70908 .45646 L .76149 .82782 L p .28 .091 .436 r
F P
0 g
s
.17346 .44745 m .18828 .455 L .18026 .4664 L p .694 .677 .829 r
F P
0 g
s
.18026 .4664 m .16548 .4589 L .17346 .44745 L p .694 .677 .829 r
F P
0 g
s
.09056 .83044 m .16548 .4589 L .18026 .4664 L p .824 .51 .458 r
F P
0 g
s
.18026 .4664 m .10903 .83849 L .09056 .83044 L p .824 .51 .458 r
F P
0 g
s
.13005 .83179 m .11184 .8238 L .12133 .81157 L p .682 .709 .868 r
F P
0 g
s
.11858 .82625 m .10903 .83849 L .18026 .4664 L p 0 0 .2 r
F P
0 g
s
.18026 .4664 m .18828 .455 L .11858 .82625 L p 0 0 .2 r
F P
0 g
s
.09056 .83044 m .16548 .4589 L .18026 .4664 L p .824 .51 .458 r
F P
0 g
s
.18026 .4664 m .10903 .83849 L .09056 .83044 L p .824 .51 .458 r
F P
0 g
s
.12133 .81157 m .11184 .8238 L .18026 .4664 L p 0 0 .2 r
F P
0 g
s
.18026 .4664 m .18828 .455 L .12133 .81157 L p 0 0 .2 r
F P
0 g
s
.23406 .44718 m .24872 .45473 L .24046 .46613 L p .694 .677 .829 r
F P
0 g
s
.24046 .46613 m .22584 .45863 L .23406 .44718 L p .694 .677 .829 r
F P
0 g
s
.16744 .81547 m .22584 .45863 L .24046 .46613 L p .825 .507 .451 r
F P
0 g
s
.24046 .46613 m .18553 .82351 L .16744 .81547 L p .825 .507 .451 r
F P
0 g
s
.19538 .81128 m .18553 .82351 L .24046 .46613 L p .02 0 .24 r
F P
0 g
s
.24046 .46613 m .24872 .45473 L .19538 .81128 L p .02 0 .24 r
F P
0 g
s
.16504 .83015 m .22584 .45863 L .24046 .46613 L p .825 .507 .451 r
F P
0 g
s
.24046 .46613 m .18327 .8382 L .16504 .83015 L p .825 .507 .451 r
F P
0 g
s
.19318 .82595 m .18327 .8382 L .24046 .46613 L p .02 0 .24 r
F P
0 g
s
.24046 .46613 m .24872 .45473 L .19318 .82595 L p .02 0 .24 r
F P
0 g
s
.29466 .4469 m .30917 .45446 L .30067 .46586 L p .694 .677 .829 r
F P
0 g
s
.30067 .46586 m .2862 .45836 L .29466 .4469 L p .694 .677 .829 r
F P
0 g
s
.24675 .77243 m .2862 .45836 L .30067 .46586 L p .827 .504 .443 r
F P
0 g
s
.30067 .46586 m .2642 .78043 L .24675 .77243 L p .827 .504 .443 r
F P
0 g
s
.28301 .77452 m .2658 .76658 L .27574 .75444 L p .685 .704 .862 r
F P
0 g
s
.2742 .76827 m .2642 .78043 L .30067 .46586 L p .066 0 .276 r
F P
0 g
s
.30067 .46586 m .30917 .45446 L .2742 .76827 L p .066 0 .276 r
F P
0 g
s
.24675 .77243 m .2862 .45836 L .30067 .46586 L p .827 .504 .443 r
F P
0 g
s
.30067 .46586 m .2642 .78043 L .24675 .77243 L p .827 .504 .443 r
F P
0 g
s
.27574 .75444 m .2658 .76658 L .30067 .46586 L p .066 0 .276 r
F P
0 g
s
.30067 .46586 m .30917 .45446 L .27574 .75444 L p .066 0 .276 r
F P
0 g
s
.35528 .44663 m .36963 .45419 L .36089 .46559 L p .694 .677 .829 r
F P
0 g
s
.36089 .46559 m .34658 .45809 L .35528 .44663 L p .694 .677 .829 r
F P
0 g
s
.31785 .78618 m .34658 .45809 L .36089 .46559 L p .828 .501 .435 r
F P
0 g
s
.36089 .46559 m .3352 .7942 L .31785 .78618 L p .828 .501 .435 r
F P
0 g
s
.34562 .78201 m .3352 .7942 L .36089 .46559 L p .108 0 .308 r
F P
0 g
s
.36089 .46559 m .36963 .45419 L .34562 .78201 L p .108 0 .308 r
F P
0 g
s
.3166 .80043 m .34658 .45809 L .36089 .46559 L p .828 .501 .435 r
F P
0 g
s
.36089 .46559 m .33409 .80846 L .3166 .80043 L p .828 .501 .435 r
F P
0 g
s
.34458 .79625 m .33409 .80846 L .36089 .46559 L p .108 0 .308 r
F P
0 g
s
.36089 .46559 m .36963 .45419 L .34458 .79625 L p .108 0 .308 r
F P
0 g
s
.41591 .44636 m .4301 .45392 L .42113 .46532 L p .694 .677 .829 r
F P
0 g
s
.42113 .46532 m .40697 .45782 L .41591 .44636 L p .694 .677 .829 r
F P
0 g
s
.38858 .82927 m .40697 .45782 L .42113 .46532 L p .83 .498 .426 r
F P
0 g
s
.42113 .46532 m .4061 .83734 L .38858 .82927 L p .83 .498 .426 r
F P
0 g
s
.43294 .7532 m .41668 .74543 L .42702 .73354 L p .686 .7 .857 r
F P
0 g
s
.42743 .72045 m .41114 .71257 L .42147 .70052 L p .687 .699 .856 r
F P
0 g
s
.41061 .72564 m .42702 .73354 L .41668 .74543 L p .686 .7 .857 r
F P
0 g
s
.41569 .77222 m .43219 .78002 L .42176 .79178 L p .685 .702 .86 r
F P
0 g
s
.4269 .83875 m .41035 .83111 L .42084 .81942 L p .684 .705 .863 r
F P
0 g
s
.41711 .82508 m .4061 .83734 L .42113 .46532 L p .145 0 .337 r
F P
0 g
s
.42113 .46532 m .4301 .45392 L .41711 .82508 L p .145 0 .337 r
F P
0 g
s
.38858 .82927 m .40697 .45782 L .42113 .46532 L p .83 .498 .426 r
F P
0 g
s
.42113 .46532 m .4061 .83734 L .38858 .82927 L p .83 .498 .426 r
F P
0 g
s
.42147 .70052 m .41114 .71257 L .42113 .46532 L p .145 0 .337 r
F P
0 g
s
.42113 .46532 m .4301 .45392 L .42147 .70052 L p .145 0 .337 r
F P
0 g
s
.47655 .44608 m .49058 .45365 L .48137 .46505 L p .694 .677 .829 r
F P
0 g
s
.48137 .46505 m .46737 .45755 L .47655 .44608 L p .694 .677 .829 r
F P
0 g
s
.46455 .70436 m .46737 .45755 L .48137 .46505 L p .831 .494 .417 r
F P
0 g
s
.48137 .46505 m .48073 .71229 L .46455 .70436 L p .831 .494 .417 r
F P
0 g
s
.49138 .70024 m .48073 .71229 L .48137 .46505 L p .18 0 .362 r
F P
0 g
s
.48137 .46505 m .49058 .45365 L .49138 .70024 L p .18 0 .362 r
F P
0 g
s
.4644 .71742 m .46737 .45755 L .48137 .46505 L p .831 .494 .417 r
F P
0 g
s
.48137 .46505 m .4807 .72536 L .4644 .71742 L p .831 .494 .417 r
F P
0 g
s
.49142 .71328 m .4807 .72536 L .48137 .46505 L p .18 0 .362 r
F P
0 g
s
.48137 .46505 m .49058 .45365 L .49142 .71328 L p .18 0 .362 r
F P
0 g
s
.5372 .44581 m .55108 .45337 L .54163 .46478 L p .694 .677 .829 r
F P
0 g
s
.54163 .46478 m .52778 .45728 L .5372 .44581 L p .694 .677 .829 r
F P
0 g
s
.53472 .71713 m .52778 .45728 L .54163 .46478 L p .833 .49 .407 r
F P
0 g
s
.54163 .46478 m .5508 .72507 L .53472 .71713 L p .833 .49 .407 r
F P
0 g
s
.56622 .71988 m .55034 .712 L .56131 .69995 L p .687 .699 .856 r
F P
0 g
s
.56185 .713 m .5508 .72507 L .54163 .46478 L p .211 .017 .385 r
F P
0 g
s
.54163 .46478 m .55108 .45337 L .56185 .713 L p .211 .017 .385 r
F P
0 g
s
.53472 .71713 m .52778 .45728 L .54163 .46478 L p .833 .49 .407 r
F P
0 g
s
.54163 .46478 m .5508 .72507 L .53472 .71713 L p .833 .49 .407 r
F P
0 g
s
.56131 .69995 m .55034 .712 L .54163 .46478 L p .211 .017 .385 r
F P
0 g
s
.54163 .46478 m .55108 .45337 L .56131 .69995 L p .211 .017 .385 r
F P
0 g
s
.59787 .44554 m .61158 .4531 L .60189 .46451 L p .694 .677 .829 r
F P
0 g
s
.60189 .46451 m .5882 .45701 L .59787 .44554 L p .694 .677 .829 r
F P
0 g
s
.6059 .73009 m .5882 .45701 L .60189 .46451 L p .834 .486 .397 r
F P
0 g
s
.60189 .46451 m .62189 .73805 L .6059 .73009 L p .834 .486 .397 r
F P
0 g
s
.63335 .72594 m .62189 .73805 L .60189 .46451 L p .239 .047 .406 r
F P
0 g
s
.60189 .46451 m .61158 .4531 L .63335 .72594 L p .239 .047 .406 r
F P
0 g
s
.60677 .74352 m .5882 .45701 L .60189 .46451 L p .834 .486 .397 r
F P
0 g
s
.60189 .46451 m .62287 .7515 L .60677 .74352 L p .834 .486 .397 r
F P
0 g
s
.63442 .73937 m .62287 .7515 L .60189 .46451 L p .239 .047 .406 r
F P
0 g
s
.60189 .46451 m .61158 .4531 L .63442 .73937 L p .239 .047 .406 r
F P
0 g
s
.65854 .44527 m .6721 .45283 L .66217 .46424 L p .694 .677 .829 r
F P
0 g
s
.66217 .46424 m .64864 .45673 L .65854 .44527 L p .694 .677 .829 r
F P
0 g
s
.68688 .82811 m .64864 .45673 L .66217 .46424 L p .835 .482 .386 r
F P
0 g
s
.66217 .46424 m .70345 .83618 L .68688 .82811 L p .835 .482 .386 r
F P
0 g
s
.71817 .82949 m .70182 .82149 L .71418 .80924 L p .682 .709 .868 r
F P
0 g
s
.71592 .82391 m .70345 .83618 L .66217 .46424 L p .264 .074 .424 r
F P
0 g
s
.66217 .46424 m .6721 .45283 L .71592 .82391 L p .264 .074 .424 r
F P
0 g
s
.68688 .82811 m .64864 .45673 L .66217 .46424 L p .835 .482 .386 r
F P
0 g
s
.66217 .46424 m .70345 .83618 L .68688 .82811 L p .835 .482 .386 r
F P
0 g
s
.71418 .80924 m .70182 .82149 L .66217 .46424 L p .264 .074 .424 r
F P
0 g
s
.66217 .46424 m .6721 .45283 L .71418 .80924 L p .264 .074 .424 r
F P
0 g
s
.71923 .44499 m .73263 .45256 L .72246 .46397 L p .694 .677 .829 r
F P
0 g
s
.72246 .46397 m .70908 .45646 L .71923 .44499 L p .694 .677 .829 r
F P
0 g
s
.75942 .81314 m .70908 .45646 L .72246 .46397 L p .836 .477 .374 r
F P
0 g
s
.72246 .46397 m .77564 .8212 L .75942 .81314 L p .836 .477 .374 r
F P
0 g
s
.78837 .80895 m .77564 .8212 L .72246 .46397 L p .288 .099 .441 r
F P
0 g
s
.72246 .46397 m .73263 .45256 L .78837 .80895 L p .288 .099 .441 r
F P
0 g
s
.76149 .82782 m .70908 .45646 L .72246 .46397 L p .836 .477 .374 r
F P
0 g
s
.72246 .46397 m .77783 .83589 L .76149 .82782 L p .836 .477 .374 r
F P
0 g
s
.79066 .82362 m .77783 .83589 L .72246 .46397 L p .288 .099 .441 r
F P
0 g
s
.72246 .46397 m .73263 .45256 L .79066 .82362 L p .288 .099 .441 r
F P
0 g
s
.13569 .44379 m .15062 .45137 L .14275 .46279 L p .694 .677 .829 r
F P
0 g
s
.14275 .46279 m .12785 .45527 L .13569 .44379 L p .694 .677 .829 r
F P
0 g
s
.04399 .82654 m .12785 .45527 L .14275 .46279 L p .823 .511 .462 r
F P
0 g
s
.14275 .46279 m .06263 .83462 L .04399 .82654 L p .823 .511 .462 r
F P
0 g
s
.07197 .82233 m .06263 .83462 L .14275 .46279 L p 0 0 .171 r
F P
0 g
s
.14275 .46279 m .15062 .45137 L .07197 .82233 L p 0 0 .171 r
F P
0 g
s
.07197 .82233 m .06263 .83462 L .14275 .46279 L p 0 0 .171 r
F P
0 g
s
.14275 .46279 m .15062 .45137 L .07197 .82233 L p 0 0 .171 r
F P
0 g
s
.19636 .44352 m .21114 .45109 L .20302 .46252 L p .694 .677 .829 r
F P
0 g
s
.20302 .46252 m .18828 .455 L .19636 .44352 L p .694 .677 .829 r
F P
0 g
s
.12404 .79712 m .18828 .455 L .20302 .46252 L p .825 .508 .454 r
F P
0 g
s
.20302 .46252 m .14216 .80517 L .12404 .79712 L p .825 .508 .454 r
F P
0 g
s
.15174 .79293 m .14216 .80517 L .20302 .46252 L p 0 0 .214 r
F P
0 g
s
.20302 .46252 m .21114 .45109 L .15174 .79293 L p 0 0 .214 r
F P
0 g
s
.12133 .81157 m .18828 .455 L .20302 .46252 L p .825 .508 .454 r
F P
0 g
s
.20302 .46252 m .13959 .81964 L .12133 .81157 L p .825 .508 .454 r
F P
0 g
s
.15174 .79293 m .14216 .80517 L .20302 .46252 L p 0 0 .214 r
F P
0 g
s
.20302 .46252 m .21114 .45109 L .15174 .79293 L p 0 0 .214 r
F P
0 g
s
.25704 .44325 m .27166 .45082 L .2633 .46225 L p .694 .677 .829 r
F P
0 g
s
.2633 .46225 m .24872 .45473 L .25704 .44325 L p .694 .677 .829 r
F P
0 g
s
.19318 .82595 m .24872 .45473 L .2633 .46225 L p .826 .506 .447 r
F P
0 g
s
.2633 .46225 m .21136 .83404 L .19318 .82595 L p .826 .506 .447 r
F P
0 g
s
.23689 .78456 m .21938 .77658 L .22919 .76438 L p .684 .705 .863 r
F P
0 g
s
.21742 .79063 m .23506 .79862 L .22523 .81065 L p .683 .706 .865 r
F P
0 g
s
.22142 .82175 m .21136 .83404 L .2633 .46225 L p .036 0 .253 r
F P
0 g
s
.2633 .46225 m .27166 .45082 L .22142 .82175 L p .036 0 .253 r
F P
0 g
s
.19318 .82595 m .24872 .45473 L .2633 .46225 L p .826 .506 .447 r
F P
0 g
s
.2633 .46225 m .21136 .83404 L .19318 .82595 L p .826 .506 .447 r
F P
0 g
s
.22919 .76438 m .21938 .77658 L .2633 .46225 L p .036 0 .253 r
F P
0 g
s
.2633 .46225 m .27166 .45082 L .22919 .76438 L p .036 0 .253 r
F P
0 g
s
.31773 .44297 m .33219 .45055 L .32359 .46198 L p .694 .677 .829 r
F P
0 g
s
.32359 .46198 m .30917 .45446 L .31773 .44297 L p .694 .677 .829 r
F P
0 g
s
.27574 .75444 m .293 .76245 L .28301 .77452 L p .685 .704 .862 r
F P
0 g
s
.2742 .76827 m .30917 .45446 L .32359 .46198 L p .828 .503 .439 r
F P
0 g
s
.32359 .46198 m .29159 .77629 L .2742 .76827 L p .828 .503 .439 r
F P
0 g
s
.30174 .76409 m .29159 .77629 L .32359 .46198 L p .08 0 .287 r
F P
0 g
s
.32359 .46198 m .33219 .45055 L .30174 .76409 L p .08 0 .287 r
F P
0 g
s
.27574 .75444 m .30917 .45446 L .32359 .46198 L p .828 .503 .439 r
F P
0 g
s
.32359 .46198 m .293 .76245 L .27574 .75444 L p .828 .503 .439 r
F P
0 g
s
.30174 .76409 m .29159 .77629 L .32359 .46198 L p .08 0 .287 r
F P
0 g
s
.32359 .46198 m .33219 .45055 L .30174 .76409 L p .08 0 .287 r
F P
0 g
s
.37843 .4427 m .39274 .45028 L .3839 .46171 L p .694 .677 .829 r
F P
0 g
s
.3839 .46171 m .36963 .45419 L .37843 .4427 L p .694 .677 .829 r
F P
0 g
s
.33409 .80846 m .35146 .81644 L .34102 .82846 L p .683 .708 .867 r
F P
0 g
s
.34458 .79625 m .36201 .8043 L .35146 .81644 L p .683 .708 .867 r
F P
0 g
s
.35146 .81644 m .33409 .80846 L .34458 .79625 L p .683 .708 .867 r
F P
0 g
s
.34245 .82537 m .36963 .45419 L .3839 .46171 L p .829 .499 .43 r
F P
0 g
s
.3839 .46171 m .36015 .83346 L .34245 .82537 L p .829 .499 .43 r
F P
0 g
s
.37094 .82116 m .36015 .83346 L .3839 .46171 L p .121 0 .318 r
F P
0 g
s
.3839 .46171 m .39274 .45028 L .37094 .82116 L p .121 0 .318 r
F P
0 g
s
.34458 .79625 m .36963 .45419 L .3839 .46171 L p .829 .499 .43 r
F P
0 g
s
.3839 .46171 m .36201 .8043 L .34458 .79625 L p .829 .499 .43 r
F P
0 g
s
.37094 .82116 m .36015 .83346 L .3839 .46171 L p .121 0 .318 r
F P
0 g
s
.3839 .46171 m .39274 .45028 L .37094 .82116 L p .121 0 .318 r
F P
0 g
s
.43914 .44243 m .45329 .45001 L .44422 .46144 L p .694 .677 .829 r
F P
0 g
s
.44422 .46144 m .4301 .45392 L .43914 .44243 L p .694 .677 .829 r
F P
0 g
s
.42192 .68766 m .4301 .45392 L .44422 .46144 L p .831 .496 .421 r
F P
0 g
s
.44422 .46144 m .43814 .69559 L .42192 .68766 L p .831 .496 .421 r
F P
0 g
s
.44853 .68353 m .43814 .69559 L .44422 .46144 L p .157 0 .346 r
F P
0 g
s
.44422 .46144 m .45329 .45001 L .44853 .68353 L p .157 0 .346 r
F P
0 g
s
.42147 .70052 m .4301 .45392 L .44422 .46144 L p .831 .496 .421 r
F P
0 g
s
.44422 .46144 m .4378 .70847 L .42147 .70052 L p .831 .496 .421 r
F P
0 g
s
.44853 .68353 m .43814 .69559 L .44422 .46144 L p .157 0 .346 r
F P
0 g
s
.44422 .46144 m .45329 .45001 L .44853 .68353 L p .157 0 .346 r
F P
0 g
s
.49987 .44215 m .51386 .44973 L .50454 .46117 L p .694 .677 .829 r
F P
0 g
s
.50454 .46117 m .49058 .45365 L .49987 .44215 L p .694 .677 .829 r
F P
0 g
s
.49126 .66218 m .49058 .45365 L .50454 .46117 L p .832 .492 .412 r
F P
0 g
s
.50454 .46117 m .50705 .67007 L .49126 .66218 L p .832 .492 .412 r
F P
0 g
s
.51761 .65807 m .50705 .67007 L .50454 .46117 L p .19 0 .37 r
F P
0 g
s
.50454 .46117 m .51386 .44973 L .51761 .65807 L p .19 0 .37 r
F P
0 g
s
.49142 .71328 m .49058 .45365 L .50454 .46117 L p .832 .492 .412 r
F P
0 g
s
.50454 .46117 m .50767 .72125 L .49142 .71328 L p .832 .492 .412 r
F P
0 g
s
.51853 .70914 m .50767 .72125 L .50454 .46117 L p .19 0 .37 r
F P
0 g
s
.50454 .46117 m .51386 .44973 L .51853 .70914 L p .19 0 .37 r
F P
0 g
s
.56061 .44188 m .57444 .44946 L .56488 .4609 L p .694 .677 .829 r
F P
0 g
s
.56488 .4609 m .55108 .45337 L .56061 .44188 L p .694 .677 .829 r
F P
0 g
s
.56131 .69995 m .57723 .7079 L .56622 .71988 L p .687 .699 .856 r
F P
0 g
s
.56185 .713 m .55108 .45337 L .56488 .4609 L p .833 .488 .402 r
F P
0 g
s
.56488 .4609 m .57788 .72097 L .56185 .713 L p .833 .488 .402 r
F P
0 g
s
.58907 .70885 m .57788 .72097 L .56488 .4609 L p .22 .027 .392 r
F P
0 g
s
.56488 .4609 m .57444 .44946 L .58907 .70885 L p .22 .027 .392 r
F P
0 g
s
.56131 .69995 m .55108 .45337 L .56488 .4609 L p .833 .488 .402 r
F P
0 g
s
.56488 .4609 m .57723 .7079 L .56131 .69995 L p .833 .488 .402 r
F P
0 g
s
.58907 .70885 m .57788 .72097 L .56488 .4609 L p .22 .027 .392 r
F P
0 g
s
.56488 .4609 m .57444 .44946 L .58907 .70885 L p .22 .027 .392 r
F P
0 g
s
.62135 .4416 m .63503 .44919 L .62523 .46063 L p .694 .677 .829 r
F P
0 g
s
.62523 .46063 m .61158 .4531 L .62135 .4416 L p .694 .677 .829 r
F P
0 g
s
.63396 .81858 m .64992 .8263 L .6384 .83792 L p .684 .705 .863 r
F P
0 g
s
.62287 .7515 m .63888 .75943 L .6274 .77138 L p .685 .702 .86 r
F P
0 g
s
.64992 .8263 m .63396 .81858 L .64555 .80678 L p .684 .705 .863 r
F P
0 g
s
.63442 .73937 m .65046 .74737 L .63888 .75943 L p .685 .702 .86 r
F P
0 g
s
.63888 .75943 m .62287 .7515 L .63442 .73937 L p .685 .702 .86 r
F P
0 g
s
.64555 .80678 m .62946 .79894 L .64111 .78695 L p .684 .705 .863 r
F P
0 g
s
.64119 .8242 m .61158 .4531 L .62523 .46063 L p .835 .484 .391 r
F P
0 g
s
.62523 .46063 m .65793 .8323 L .64119 .8242 L p .835 .484 .391 r
F P
0 g
s
.6702 .81999 m .65793 .8323 L .62523 .46063 L p .248 .056 .412 r
F P
0 g
s
.62523 .46063 m .63503 .44919 L .6702 .81999 L p .248 .056 .412 r
F P
0 g
s
.63442 .73937 m .61158 .4531 L .62523 .46063 L p .835 .484 .391 r
F P
0 g
s
.62523 .46063 m .65046 .74737 L .63442 .73937 L p .835 .484 .391 r
F P
0 g
s
.6702 .81999 m .65793 .8323 L .62523 .46063 L p .248 .056 .412 r
F P
0 g
s
.62523 .46063 m .63503 .44919 L .6702 .81999 L p .248 .056 .412 r
F P
0 g
s
.68211 .44133 m .69563 .44892 L .68559 .46036 L p .694 .677 .829 r
F P
0 g
s
.68559 .46036 m .6721 .45283 L .68211 .44133 L p .694 .677 .829 r
F P
0 g
s
.71248 .79479 m .6721 .45283 L .68559 .46036 L p .836 .479 .38 r
F P
0 g
s
.68559 .46036 m .72875 .80286 L .71248 .79479 L p .836 .479 .38 r
F P
0 g
s
.74117 .79059 m .72875 .80286 L .68559 .46036 L p .272 .082 .43 r
F P
0 g
s
.68559 .46036 m .69563 .44892 L .74117 .79059 L p .272 .082 .43 r
F P
0 g
s
.71418 .80924 m .6721 .45283 L .68559 .46036 L p .836 .479 .38 r
F P
0 g
s
.68559 .46036 m .73057 .81732 L .71418 .80924 L p .836 .479 .38 r
F P
0 g
s
.74117 .79059 m .72875 .80286 L .68559 .46036 L p .272 .082 .43 r
F P
0 g
s
.68559 .46036 m .69563 .44892 L .74117 .79059 L p .272 .082 .43 r
F P
0 g
s
.74289 .44106 m .75625 .44864 L .74597 .46009 L p .694 .677 .829 r
F P
0 g
s
.74597 .46009 m .73263 .45256 L .74289 .44106 L p .694 .677 .829 r
F P
0 g
s
.79066 .82362 m .73263 .45256 L .74597 .46009 L p .837 .474 .368 r
F P
0 g
s
.74597 .46009 m .80693 .83171 L .79066 .82362 L p .837 .474 .368 r
F P
0 g
s
.81993 .8194 m .80693 .83171 L .74597 .46009 L p .295 .107 .446 r
F P
0 g
s
.74597 .46009 m .75625 .44864 L .81993 .8194 L p .295 .107 .446 r
F P
0 g
s
.79066 .82362 m .73263 .45256 L .74597 .46009 L p .837 .474 .368 r
F P
0 g
s
.74597 .46009 m .80693 .83171 L .79066 .82362 L p .837 .474 .368 r
F P
0 g
s
.15857 .43985 m .17346 .44745 L .16548 .4589 L p .694 .677 .829 r
F P
0 g
s
.16548 .4589 m .15062 .45137 L .15857 .43985 L p .694 .677 .829 r
F P
0 g
s
.07508 .80767 m .15062 .45137 L .16548 .4589 L p .824 .51 .458 r
F P
0 g
s
.16548 .4589 m .09352 .81576 L .07508 .80767 L p .824 .51 .458 r
F P
0 g
s
.10295 .80345 m .09352 .81576 L .16548 .4589 L p 0 0 .186 r
F P
0 g
s
.16548 .4589 m .17346 .44745 L .10295 .80345 L p 0 0 .186 r
F P
0 g
s
.07197 .82233 m .15062 .45137 L .16548 .4589 L p .824 .51 .458 r
F P
0 g
s
.16548 .4589 m .09056 .83044 L .07197 .82233 L p .824 .51 .458 r
F P
0 g
s
.10005 .81811 m .09056 .83044 L .16548 .4589 L p 0 0 .186 r
F P
0 g
s
.16548 .4589 m .17346 .44745 L .10005 .81811 L p 0 0 .186 r
F P
0 g
s
.21932 .43958 m .23406 .44718 L .22584 .45863 L p .694 .677 .829 r
F P
0 g
s
.22584 .45863 m .21114 .45109 L .21932 .43958 L p .694 .677 .829 r
F P
0 g
s
.15174 .79293 m .21114 .45109 L .22584 .45863 L p .825 .507 .451 r
F P
0 g
s
.22584 .45863 m .16981 .80101 L .15174 .79293 L p .825 .507 .451 r
F P
0 g
s
.17954 .78872 m .16981 .80101 L .22584 .45863 L p .004 0 .228 r
F P
0 g
s
.22584 .45863 m .23406 .44718 L .17954 .78872 L p .004 0 .228 r
F P
0 g
s
.15174 .79293 m .21114 .45109 L .22584 .45863 L p .825 .507 .451 r
F P
0 g
s
.22584 .45863 m .16981 .80101 L .15174 .79293 L p .825 .507 .451 r
F P
0 g
s
.17723 .80316 m .16744 .81547 L .22584 .45863 L p .004 0 .228 r
F P
0 g
s
.22584 .45863 m .23406 .44718 L .17723 .80316 L p .004 0 .228 r
F P
0 g
s
.28008 .43931 m .29466 .4469 L .2862 .45836 L p .694 .677 .829 r
F P
0 g
s
.2862 .45836 m .27166 .45082 L .28008 .43931 L p .694 .677 .829 r
F P
0 g
s
.23106 .75056 m .27166 .45082 L .2862 .45836 L p .827 .504 .443 r
F P
0 g
s
.2862 .45836 m .24849 .7586 L .23106 .75056 L p .827 .504 .443 r
F P
0 g
s
.25838 .74638 m .24849 .7586 L .2862 .45836 L p .051 0 .265 r
F P
0 g
s
.2862 .45836 m .29466 .4469 L .25838 .74638 L p .051 0 .265 r
F P
0 g
s
.22919 .76438 m .27166 .45082 L .2862 .45836 L p .827 .504 .443 r
F P
0 g
s
.2862 .45836 m .24675 .77243 L .22919 .76438 L p .827 .504 .443 r
F P
0 g
s
.2567 .76019 m .24675 .77243 L .2862 .45836 L p .051 0 .265 r
F P
0 g
s
.2862 .45836 m .29466 .4469 L .2567 .76019 L p .051 0 .265 r
F P
0 g
s
.34086 .43903 m .35528 .44663 L .34658 .45809 L p .694 .677 .829 r
F P
0 g
s
.34658 .45809 m .33219 .45055 L .34086 .43903 L p .694 .677 .829 r
F P
0 g
s
.30174 .76409 m .33219 .45055 L .34658 .45809 L p .828 .501 .435 r
F P
0 g
s
.34658 .45809 m .31908 .77214 L .30174 .76409 L p .828 .501 .435 r
F P
0 g
s
.32938 .7599 m .31908 .77214 L .34658 .45809 L p .094 0 .298 r
F P
0 g
s
.34658 .45809 m .35528 .44663 L .32938 .7599 L p .094 0 .298 r
F P
0 g
s
.30174 .76409 m .33219 .45055 L .34658 .45809 L p .828 .501 .435 r
F P
0 g
s
.34658 .45809 m .31908 .77214 L .30174 .76409 L p .828 .501 .435 r
F P
0 g
s
.32822 .77391 m .31785 .78618 L .34658 .45809 L p .094 0 .298 r
F P
0 g
s
.34658 .45809 m .35528 .44663 L .32822 .77391 L p .094 0 .298 r
F P
0 g
s
.40164 .43876 m .41591 .44636 L .40697 .45782 L p .694 .677 .829 r
F P
0 g
s
.40697 .45782 m .39274 .45028 L .40164 .43876 L p .694 .677 .829 r
F P
0 g
s
.37181 .8065 m .39274 .45028 L .40697 .45782 L p .83 .498 .426 r
F P
0 g
s
.40697 .45782 m .38931 .8146 L .37181 .8065 L p .83 .498 .426 r
F P
0 g
s
.40018 .80228 m .38931 .8146 L .40697 .45782 L p .133 0 .328 r
F P
0 g
s
.40697 .45782 m .41591 .44636 L .40018 .80228 L p .133 0 .328 r
F P
0 g
s
.37094 .82116 m .39274 .45028 L .40697 .45782 L p .83 .498 .426 r
F P
0 g
s
.40697 .45782 m .38858 .82927 L .37094 .82116 L p .83 .498 .426 r
F P
0 g
s
.39953 .81694 m .38858 .82927 L .40697 .45782 L p .133 0 .328 r
F P
0 g
s
.40697 .45782 m .41591 .44636 L .39953 .81694 L p .133 0 .328 r
F P
0 g
s
.46244 .43848 m .47655 .44608 L .46737 .45755 L p .694 .677 .829 r
F P
0 g
s
.46737 .45755 m .45329 .45001 L .46244 .43848 L p .694 .677 .829 r
F P
0 g
s
.44853 .68353 m .45329 .45001 L .46737 .45755 L p .831 .494 .417 r
F P
0 g
s
.46737 .45755 m .4647 .69149 L .44853 .68353 L p .831 .494 .417 r
F P
0 g
s
.47523 .67939 m .4647 .69149 L .46737 .45755 L p .169 0 .354 r
F P
0 g
s
.46737 .45755 m .47655 .44608 L .47523 .67939 L p .169 0 .354 r
F P
0 g
s
.44853 .68353 m .45329 .45001 L .46737 .45755 L p .831 .494 .417 r
F P
0 g
s
.46737 .45755 m .4647 .69149 L .44853 .68353 L p .831 .494 .417 r
F P
0 g
s
.47515 .69224 m .46455 .70436 L .46737 .45755 L p .169 0 .354 r
F P
0 g
s
.46737 .45755 m .47655 .44608 L .47515 .69224 L p .169 0 .354 r
F P
0 g
s
.52325 .43821 m .5372 .44581 L .52778 .45728 L p .694 .677 .829 r
F P
0 g
s
.52778 .45728 m .51386 .44973 L .52325 .43821 L p .694 .677 .829 r
F P
0 g
s
.51829 .6961 m .51386 .44973 L .52778 .45728 L p .833 .49 .407 r
F P
0 g
s
.52778 .45728 m .53437 .70407 L .51829 .6961 L p .833 .49 .407 r
F P
0 g
s
.54529 .69195 m .53437 .70407 L .52778 .45728 L p .201 .006 .378 r
F P
0 g
s
.52778 .45728 m .5372 .44581 L .54529 .69195 L p .201 .006 .378 r
F P
0 g
s
.51853 .70914 m .51386 .44973 L .52778 .45728 L p .833 .49 .407 r
F P
0 g
s
.52778 .45728 m .53472 .71713 L .51853 .70914 L p .833 .49 .407 r
F P
0 g
s
.54572 .70498 m .53472 .71713 L .52778 .45728 L p .201 .006 .378 r
F P
0 g
s
.52778 .45728 m .5372 .44581 L .54572 .70498 L p .201 .006 .378 r
F P
0 g
s
.58407 .43793 m .59787 .44554 L .5882 .45701 L p .694 .677 .829 r
F P
0 g
s
.5882 .45701 m .57444 .44946 L .58407 .43793 L p .694 .677 .829 r
F P
0 g
s
.58907 .70885 m .57444 .44946 L .5882 .45701 L p .834 .486 .397 r
F P
0 g
s
.5882 .45701 m .60504 .71684 L .58907 .70885 L p .834 .486 .397 r
F P
0 g
s
.61638 .70469 m .60504 .71684 L .5882 .45701 L p .23 .037 .399 r
F P
0 g
s
.5882 .45701 m .59787 .44554 L .61638 .70469 L p .23 .037 .399 r
F P
0 g
s
.58907 .70885 m .57444 .44946 L .5882 .45701 L p .834 .486 .397 r
F P
0 g
s
.5882 .45701 m .60504 .71684 L .58907 .70885 L p .834 .486 .397 r
F P
0 g
s
.61732 .71791 m .6059 .73009 L .5882 .45701 L p .23 .037 .399 r
F P
0 g
s
.5882 .45701 m .59787 .44554 L .61732 .71791 L p .23 .037 .399 r
F P
0 g
s
.64491 .43766 m .65854 .44527 L .64864 .45673 L p .694 .677 .829 r
F P
0 g
s
.64864 .45673 m .63503 .44919 L .64491 .43766 L p .694 .677 .829 r
F P
0 g
s
.6688 .80533 m .63503 .44919 L .64864 .45673 L p .835 .482 .386 r
F P
0 g
s
.64864 .45673 m .68536 .81343 L .6688 .80533 L p .835 .482 .386 r
F P
0 g
s
.69769 .80111 m .68536 .81343 L .64864 .45673 L p .256 .065 .418 r
F P
0 g
s
.64864 .45673 m .65854 .44527 L .69769 .80111 L p .256 .065 .418 r
F P
0 g
s
.6702 .81999 m .63503 .44919 L .64864 .45673 L p .835 .482 .386 r
F P
0 g
s
.64864 .45673 m .68688 .82811 L .6702 .81999 L p .835 .482 .386 r
F P
0 g
s
.6993 .81576 m .68688 .82811 L .64864 .45673 L p .256 .065 .418 r
F P
0 g
s
.64864 .45673 m .65854 .44527 L .6993 .81576 L p .256 .065 .418 r
F P
0 g
s
.70575 .43739 m .71923 .44499 L .70908 .45646 L p .694 .677 .829 r
F P
0 g
s
.70908 .45646 m .69563 .44892 L .70575 .43739 L p .694 .677 .829 r
F P
0 g
s
.74117 .79059 m .69563 .44892 L .70908 .45646 L p .836 .477 .374 r
F P
0 g
s
.70908 .45646 m .75738 .79868 L .74117 .79059 L p .836 .477 .374 r
F P
0 g
s
.76996 .78638 m .75738 .79868 L .70908 .45646 L p .28 .091 .436 r
F P
0 g
s
.70908 .45646 m .71923 .44499 L .76996 .78638 L p .28 .091 .436 r
F P
0 g
s
.74117 .79059 m .69563 .44892 L .70908 .45646 L p .836 .477 .374 r
F P
0 g
s
.70908 .45646 m .75738 .79868 L .74117 .79059 L p .836 .477 .374 r
F P
0 g
s
.77211 .80081 m .75942 .81314 L .70908 .45646 L p .28 .091 .436 r
F P
0 g
s
.70908 .45646 m .71923 .44499 L .77211 .80081 L p .28 .091 .436 r
F P
0 g
s
.12068 .43618 m .13569 .44379 L .12785 .45527 L p .694 .677 .829 r
F P
0 g
s
.12785 .45527 m .11288 .44772 L .12068 .43618 L p .694 .677 .829 r
F P
0 g
s
.02522 .81841 m .11288 .44772 L .12785 .45527 L p .823 .511 .462 r
F P
0 g
s
.12785 .45527 m .04399 .82654 L .02522 .81841 L p .823 .511 .462 r
F P
0 g
s
.05326 .81417 m .04399 .82654 L .12785 .45527 L p 0 0 .156 r
F P
0 g
s
.12785 .45527 m .13569 .44379 L .05326 .81417 L p 0 0 .156 r
F P
0 g
s
.05326 .81417 m .04399 .82654 L .12785 .45527 L p 0 0 .156 r
F P
0 g
s
.12785 .45527 m .13569 .44379 L .05326 .81417 L p 0 0 .156 r
F P
0 g
s
.1815 .4359 m .19636 .44352 L .18828 .455 L p .694 .677 .829 r
F P
0 g
s
.18828 .455 m .17346 .44745 L .1815 .4359 L p .694 .677 .829 r
F P
0 g
s
.10005 .81811 m .17346 .44745 L .18828 .455 L p .825 .508 .454 r
F P
0 g
s
.18828 .455 m .11858 .82625 L .10005 .81811 L p .825 .508 .454 r
F P
0 g
s
.14216 .80517 m .12404 .79712 L .13357 .7848 L p .683 .708 .867 r
F P
0 g
s
.12133 .81157 m .13959 .81964 L .13005 .83179 L p .682 .709 .868 r
F P
0 g
s
.12822 .81388 m .11858 .82625 L .18828 .455 L p 0 0 .2 r
F P
0 g
s
.18828 .455 m .19636 .44352 L .12822 .81388 L p 0 0 .2 r
F P
0 g
s
.10005 .81811 m .17346 .44745 L .18828 .455 L p .825 .508 .454 r
F P
0 g
s
.18828 .455 m .11858 .82625 L .10005 .81811 L p .825 .508 .454 r
F P
0 g
s
.13357 .7848 m .12404 .79712 L .18828 .455 L p 0 0 .2 r
F P
0 g
s
.18828 .455 m .19636 .44352 L .13357 .7848 L p 0 0 .2 r
F P
0 g
s
.24234 .43563 m .25704 .44325 L .24872 .45473 L p .694 .677 .829 r
F P
0 g
s
.24872 .45473 m .23406 .44718 L .24234 .43563 L p .694 .677 .829 r
F P
0 g
s
.17723 .80316 m .19538 .81128 L .18553 .82351 L p .682 .709 .868 r
F P
0 g
s
.18553 .82351 m .16744 .81547 L .17723 .80316 L p .682 .709 .868 r
F P
0 g
s
.17489 .81782 m .23406 .44718 L .24872 .45473 L p .826 .506 .447 r
F P
0 g
s
.24872 .45473 m .19318 .82595 L .17489 .81782 L p .826 .506 .447 r
F P
0 g
s
.20319 .81359 m .19318 .82595 L .24872 .45473 L p .02 0 .24 r
F P
0 g
s
.24872 .45473 m .25704 .44325 L .20319 .81359 L p .02 0 .24 r
F P
0 g
s
.17723 .80316 m .23406 .44718 L .24872 .45473 L p .826 .506 .447 r
F P
0 g
s
.24872 .45473 m .19538 .81128 L .17723 .80316 L p .826 .506 .447 r
F P
0 g
s
.20319 .81359 m .19318 .82595 L .24872 .45473 L p .02 0 .24 r
F P
0 g
s
.24872 .45473 m .25704 .44325 L .20319 .81359 L p .02 0 .24 r
F P
0 g
s
.30319 .43535 m .31773 .44297 L .30917 .45446 L p .694 .677 .829 r
F P
0 g
s
.30917 .45446 m .29466 .4469 L .30319 .43535 L p .694 .677 .829 r
F P
0 g
s
.26002 .73277 m .29466 .4469 L .30917 .45446 L p .828 .503 .439 r
F P
0 g
s
.30917 .45446 m .27726 .74082 L .26002 .73277 L p .828 .503 .439 r
F P
0 g
s
.28723 .72858 m .27726 .74082 L .30917 .45446 L p .066 0 .276 r
F P
0 g
s
.30917 .45446 m .31773 .44297 L .28723 .72858 L p .066 0 .276 r
F P
0 g
s
.2567 .76019 m .29466 .4469 L .30917 .45446 L p .828 .503 .439 r
F P
0 g
s
.30917 .45446 m .2742 .76827 L .2567 .76019 L p .828 .503 .439 r
F P
0 g
s
.2843 .75599 m .2742 .76827 L .30917 .45446 L p .066 0 .276 r
F P
0 g
s
.30917 .45446 m .31773 .44297 L .2843 .75599 L p .066 0 .276 r
F P
0 g
s
.36405 .43508 m .37843 .4427 L .36963 .45419 L p .694 .677 .829 r
F P
0 g
s
.36963 .45419 m .35528 .44663 L .36405 .43508 L p .694 .677 .829 r
F P
0 g
s
.32822 .77391 m .34562 .78201 L .3352 .7942 L p .683 .706 .865 r
F P
0 g
s
.3352 .7942 m .31785 .78618 L .32822 .77391 L p .683 .706 .865 r
F P
0 g
s
.3166 .80043 m .33409 .80846 L .32369 .82055 L p .683 .708 .867 r
F P
0 g
s
.32464 .81723 m .35528 .44663 L .36963 .45419 L p .829 .499 .43 r
F P
0 g
s
.34102 .82846 m .32369 .82055 L .33409 .80846 L p .683 .708 .867 r
F P
0 g
s
.36963 .45419 m .34245 .82537 L .32464 .81723 L p .829 .499 .43 r
F P
0 g
s
.35319 .813 m .34245 .82537 L .36963 .45419 L p .108 0 .308 r
F P
0 g
s
.36963 .45419 m .37843 .4427 L .35319 .813 L p .108 0 .308 r
F P
0 g
s
.32822 .77391 m .35528 .44663 L .36963 .45419 L p .829 .499 .43 r
F P
0 g
s
.36963 .45419 m .34562 .78201 L .32822 .77391 L p .829 .499 .43 r
F P
0 g
s
.35319 .813 m .34245 .82537 L .36963 .45419 L p .108 0 .308 r
F P
0 g
s
.36963 .45419 m .37843 .4427 L .35319 .813 L p .108 0 .308 r
F P
0 g
s
.42492 .4348 m .43914 .44243 L .4301 .45392 L p .694 .677 .829 r
F P
0 g
s
.4301 .45392 m .41591 .44636 L .42492 .4348 L p .694 .677 .829 r
F P
0 g
s
.39953 .81694 m .41591 .44636 L .4301 .45392 L p .831 .496 .421 r
F P
0 g
s
.4301 .45392 m .41711 .82508 L .39953 .81694 L p .831 .496 .421 r
F P
0 g
s
.43814 .69559 m .42192 .68766 L .43227 .67553 L p .687 .698 .854 r
F P
0 g
s
.42702 .73354 m .44333 .74138 L .43294 .7532 L p .686 .7 .857 r
F P
0 g
s
.42147 .70052 m .4378 .70847 L .42743 .72045 L p .687 .699 .856 r
F P
0 g
s
.44333 .74138 m .42702 .73354 L .43746 .72154 L p .686 .7 .857 r
F P
0 g
s
.43778 .8132 m .4213 .8055 L .43181 .79373 L p .685 .704 .862 r
F P
0 g
s
.42084 .81942 m .43744 .82713 L .4269 .83875 L p .684 .705 .863 r
F P
0 g
s
.42822 .8127 m .41711 .82508 L .4301 .45392 L p .145 0 .337 r
F P
0 g
s
.4301 .45392 m .43914 .44243 L .42822 .8127 L p .145 0 .337 r
F P
0 g
s
.39953 .81694 m .41591 .44636 L .4301 .45392 L p .831 .496 .421 r
F P
0 g
s
.4301 .45392 m .41711 .82508 L .39953 .81694 L p .831 .496 .421 r
F P
0 g
s
.43227 .67553 m .42192 .68766 L .4301 .45392 L p .145 0 .337 r
F P
0 g
s
.4301 .45392 m .43914 .44243 L .43227 .67553 L p .145 0 .337 r
F P
0 g
s
.4858 .43453 m .49987 .44215 L .49058 .45365 L p .694 .677 .829 r
F P
0 g
s
.49058 .45365 m .47655 .44608 L .4858 .43453 L p .694 .677 .829 r
F P
0 g
s
.47537 .65423 m .47655 .44608 L .49058 .45365 L p .832 .492 .412 r
F P
0 g
s
.49058 .45365 m .49126 .66218 L .47537 .65423 L p .832 .492 .412 r
F P
0 g
s
.50178 .6501 m .49126 .66218 L .49058 .45365 L p .18 0 .362 r
F P
0 g
s
.49058 .45365 m .49987 .44215 L .50178 .6501 L p .18 0 .362 r
F P
0 g
s
.47515 .69224 m .47655 .44608 L .49058 .45365 L p .832 .492 .412 r
F P
0 g
s
.49058 .45365 m .49138 .70024 L .47515 .69224 L p .832 .492 .412 r
F P
0 g
s
.50178 .6501 m .49126 .66218 L .49058 .45365 L p .18 0 .362 r
F P
0 g
s
.49058 .45365 m .49987 .44215 L .50178 .6501 L p .18 0 .362 r
F P
0 g
s
.5467 .43425 m .56061 .44188 L .55108 .45337 L p .694 .677 .829 r
F P
0 g
s
.55108 .45337 m .5372 .44581 L .5467 .43425 L p .694 .677 .829 r
F P
0 g
s
.54487 .6791 m .5372 .44581 L .55108 .45337 L p .833 .488 .402 r
F P
0 g
s
.55108 .45337 m .56078 .68708 L .54487 .6791 L p .833 .488 .402 r
F P
0 g
s
.57176 .67495 m .56078 .68708 L .55108 .45337 L p .211 .017 .385 r
F P
0 g
s
.55108 .45337 m .56061 .44188 L .57176 .67495 L p .211 .017 .385 r
F P
0 g
s
.54572 .70498 m .5372 .44581 L .55108 .45337 L p .833 .488 .402 r
F P
0 g
s
.55108 .45337 m .56185 .713 L .54572 .70498 L p .833 .488 .402 r
F P
0 g
s
.573 .70081 m .56185 .713 L .55108 .45337 L p .211 .017 .385 r
F P
0 g
s
.55108 .45337 m .56061 .44188 L .573 .70081 L p .211 .017 .385 r
F P
0 g
s
.60761 .43398 m .62135 .4416 L .61158 .4531 L p .694 .677 .829 r
F P
0 g
s
.61158 .4531 m .59787 .44554 L .60761 .43398 L p .694 .677 .829 r
F P
0 g
s
.6274 .77138 m .61144 .76352 L .62287 .7515 L p .685 .702 .86 r
F P
0 g
s
.61732 .71791 m .63335 .72594 L .62189 .73805 L p .686 .701 .859 r
F P
0 g
s
.62189 .73805 m .6059 .73009 L .61732 .71791 L p .686 .701 .859 r
F P
0 g
s
.61791 .81082 m .63396 .81858 L .62249 .83028 L p .684 .705 .863 r
F P
0 g
s
.60677 .74352 m .62287 .7515 L .61144 .76352 L p .685 .702 .86 r
F P
0 g
s
.61327 .79106 m .62946 .79894 L .61791 .81082 L p .684 .705 .863 r
F P
0 g
s
.62433 .81606 m .59787 .44554 L .61158 .4531 L p .835 .484 .391 r
F P
0 g
s
.6384 .83792 m .62249 .83028 L .63396 .81858 L p .684 .705 .863 r
F P
0 g
s
.61158 .4531 m .64119 .8242 L .62433 .81606 L p .835 .484 .391 r
F P
0 g
s
.65341 .81182 m .64119 .8242 L .61158 .4531 L p .239 .047 .406 r
F P
0 g
s
.61158 .4531 m .62135 .4416 L .65341 .81182 L p .239 .047 .406 r
F P
0 g
s
.61732 .71791 m .59787 .44554 L .61158 .4531 L p .835 .484 .391 r
F P
0 g
s
.61158 .4531 m .63335 .72594 L .61732 .71791 L p .835 .484 .391 r
F P
0 g
s
.65341 .81182 m .64119 .8242 L .61158 .4531 L p .239 .047 .406 r
F P
0 g
s
.61158 .4531 m .62135 .4416 L .65341 .81182 L p .239 .047 .406 r
F P
0 g
s
.66852 .4337 m .68211 .44133 L .6721 .45283 L p .694 .677 .829 r
F P
0 g
s
.6721 .45283 m .65854 .44527 L .66852 .4337 L p .694 .677 .829 r
F P
0 g
s
.6993 .81576 m .65854 .44527 L .6721 .45283 L p .836 .479 .38 r
F P
0 g
s
.6721 .45283 m .71592 .82391 L .6993 .81576 L p .836 .479 .38 r
F P
0 g
s
.72875 .80286 m .71248 .79479 L .72486 .78245 L p .683 .708 .867 r
F P
0 g
s
.71418 .80924 m .73057 .81732 L .71817 .82949 L p .682 .709 .868 r
F P
0 g
s
.7285 .81152 m .71592 .82391 L .6721 .45283 L p .264 .074 .424 r
F P
0 g
s
.6721 .45283 m .68211 .44133 L .7285 .81152 L p .264 .074 .424 r
F P
0 g
s
.6993 .81576 m .65854 .44527 L .6721 .45283 L p .836 .479 .38 r
F P
0 g
s
.6721 .45283 m .71592 .82391 L .6993 .81576 L p .836 .479 .38 r
F P
0 g
s
.72486 .78245 m .71248 .79479 L .6721 .45283 L p .264 .074 .424 r
F P
0 g
s
.6721 .45283 m .68211 .44133 L .72486 .78245 L p .264 .074 .424 r
F P
0 g
s
.72945 .43343 m .74289 .44106 L .73263 .45256 L p .694 .677 .829 r
F P
0 g
s
.73263 .45256 m .71923 .44499 L .72945 .43343 L p .694 .677 .829 r
F P
0 g
s
.77211 .80081 m .78837 .80895 L .77564 .8212 L p .682 .709 .868 r
F P
0 g
s
.77564 .8212 m .75942 .81314 L .77211 .80081 L p .682 .709 .868 r
F P
0 g
s
.77429 .81547 m .71923 .44499 L .73263 .45256 L p .837 .474 .368 r
F P
0 g
s
.73263 .45256 m .79066 .82362 L .77429 .81547 L p .837 .474 .368 r
F P
0 g
s
.80362 .81122 m .79066 .82362 L .73263 .45256 L p .288 .099 .441 r
F P
0 g
s
.73263 .45256 m .74289 .44106 L .80362 .81122 L p .288 .099 .441 r
F P
0 g
s
.77211 .80081 m .71923 .44499 L .73263 .45256 L p .837 .474 .368 r
F P
0 g
s
.73263 .45256 m .78837 .80895 L .77211 .80081 L p .837 .474 .368 r
F P
0 g
s
.80362 .81122 m .79066 .82362 L .73263 .45256 L p .288 .099 .441 r
F P
0 g
s
.73263 .45256 m .74289 .44106 L .80362 .81122 L p .288 .099 .441 r
F P
0 g
s
.14359 .43222 m .15857 .43985 L .15062 .45137 L p .694 .677 .829 r
F P
0 g
s
.15062 .45137 m .13569 .44379 L .14359 .43222 L p .694 .677 .829 r
F P
0 g
s
.05326 .81417 m .13569 .44379 L .15062 .45137 L p .824 .51 .458 r
F P
0 g
s
.15062 .45137 m .07197 .82233 L .05326 .81417 L p .824 .51 .458 r
F P
0 g
s
.09352 .81576 m .07508 .80767 L .08445 .79528 L p .682 .709 .868 r
F P
0 g
s
.0814 .80993 m .07197 .82233 L .15062 .45137 L p 0 0 .171 r
F P
0 g
s
.15062 .45137 m .15857 .43985 L .0814 .80993 L p 0 0 .171 r
F P
0 g
s
.05326 .81417 m .13569 .44379 L .15062 .45137 L p .824 .51 .458 r
F P
0 g
s
.15062 .45137 m .07197 .82233 L .05326 .81417 L p .824 .51 .458 r
F P
0 g
s
.08445 .79528 m .07508 .80767 L .15062 .45137 L p 0 0 .171 r
F P
0 g
s
.15062 .45137 m .15857 .43985 L .08445 .79528 L p 0 0 .171 r
F P
0 g
s
.2045 .43194 m .21932 .43958 L .21114 .45109 L p .694 .677 .829 r
F P
0 g
s
.21114 .45109 m .19636 .44352 L .2045 .43194 L p .694 .677 .829 r
F P
0 g
s
.13618 .77058 m .19636 .44352 L .21114 .45109 L p .825 .507 .451 r
F P
0 g
s
.21114 .45109 m .15422 .77869 L .13618 .77058 L p .825 .507 .451 r
F P
0 g
s
.16383 .76635 m .15422 .77869 L .21114 .45109 L p 0 0 .214 r
F P
0 g
s
.21114 .45109 m .21932 .43958 L .16383 .76635 L p 0 0 .214 r
F P
0 g
s
.13357 .7848 m .19636 .44352 L .21114 .45109 L p .825 .507 .451 r
F P
0 g
s
.21114 .45109 m .15174 .79293 L .13357 .7848 L p .825 .507 .451 r
F P
0 g
s
.16142 .78056 m .15174 .79293 L .21114 .45109 L p 0 0 .214 r
F P
0 g
s
.21114 .45109 m .21932 .43958 L .16142 .78056 L p 0 0 .214 r
F P
0 g
s
.26543 .43167 m .28008 .43931 L .27166 .45082 L p .694 .677 .829 r
F P
0 g
s
.27166 .45082 m .25704 .44325 L .26543 .43167 L p .694 .677 .829 r
F P
0 g
s
.20319 .81359 m .25704 .44325 L .27166 .45082 L p .827 .504 .443 r
F P
0 g
s
.27166 .45082 m .22142 .82175 L .20319 .81359 L p .827 .504 .443 r
F P
0 g
s
.24849 .7586 m .23106 .75056 L .2409 .73827 L p .685 .704 .862 r
F P
0 g
s
.22919 .76438 m .24675 .77243 L .23689 .78456 L p .684 .705 .863 r
F P
0 g
s
.23159 .80934 m .22142 .82175 L .27166 .45082 L p .036 0 .253 r
F P
0 g
s
.27166 .45082 m .28008 .43931 L .23159 .80934 L p .036 0 .253 r
F P
0 g
s
.20319 .81359 m .25704 .44325 L .27166 .45082 L p .827 .504 .443 r
F P
0 g
s
.27166 .45082 m .22142 .82175 L .20319 .81359 L p .827 .504 .443 r
F P
0 g
s
.2409 .73827 m .23106 .75056 L .27166 .45082 L p .036 0 .253 r
F P
0 g
s
.27166 .45082 m .28008 .43931 L .2409 .73827 L p .036 0 .253 r
F P
0 g
s
.32636 .43139 m .34086 .43903 L .33219 .45055 L p .694 .677 .829 r
F P
0 g
s
.33219 .45055 m .31773 .44297 L .32636 .43139 L p .694 .677 .829 r
F P
0 g
s
.28578 .74218 m .31773 .44297 L .33219 .45055 L p .828 .501 .435 r
F P
0 g
s
.33219 .45055 m .30309 .75027 L .28578 .74218 L p .828 .501 .435 r
F P
0 g
s
.31327 .73798 m .30309 .75027 L .33219 .45055 L p .08 0 .287 r
F P
0 g
s
.33219 .45055 m .34086 .43903 L .31327 .73798 L p .08 0 .287 r
F P
0 g
s
.2843 .75599 m .31773 .44297 L .33219 .45055 L p .828 .501 .435 r
F P
0 g
s
.33219 .45055 m .30174 .76409 L .2843 .75599 L p .828 .501 .435 r
F P
0 g
s
.31199 .75177 m .30174 .76409 L .33219 .45055 L p .08 0 .287 r
F P
0 g
s
.33219 .45055 m .34086 .43903 L .31199 .75177 L p .08 0 .287 r
F P
0 g
s
.3873 .43112 m .40164 .43876 L .39274 .45028 L p .694 .677 .829 r
F P
0 g
s
.39274 .45028 m .37843 .4427 L .3873 .43112 L p .694 .677 .829 r
F P
0 g
s
.35319 .813 m .37843 .4427 L .39274 .45028 L p .83 .498 .426 r
F P
0 g
s
.39274 .45028 m .37094 .82116 L .35319 .813 L p .83 .498 .426 r
F P
0 g
s
.38931 .8146 m .37181 .8065 L .38263 .7941 L p .682 .709 .868 r
F P
0 g
s
.38185 .80874 m .37094 .82116 L .39274 .45028 L p .121 0 .318 r
F P
0 g
s
.39274 .45028 m .40164 .43876 L .38185 .80874 L p .121 0 .318 r
F P
0 g
s
.35319 .813 m .37843 .4427 L .39274 .45028 L p .83 .498 .426 r
F P
0 g
s
.39274 .45028 m .37094 .82116 L .35319 .813 L p .83 .498 .426 r
F P
0 g
s
.38263 .7941 m .37181 .8065 L .39274 .45028 L p .121 0 .318 r
F P
0 g
s
.39274 .45028 m .40164 .43876 L .38263 .7941 L p .121 0 .318 r
F P
0 g
s
.44826 .43084 m .46244 .43848 L .45329 .45001 L p .694 .677 .829 r
F P
0 g
s
.45329 .45001 m .43914 .44243 L .44826 .43084 L p .694 .677 .829 r
F P
0 g
s
.43264 .66287 m .43914 .44243 L .45329 .45001 L p .831 .494 .417 r
F P
0 g
s
.45329 .45001 m .44879 .67085 L .43264 .66287 L p .831 .494 .417 r
F P
0 g
s
.45921 .65871 m .44879 .67085 L .45329 .45001 L p .157 0 .346 r
F P
0 g
s
.45329 .45001 m .46244 .43848 L .45921 .65871 L p .157 0 .346 r
F P
0 g
s
.43227 .67553 m .43914 .44243 L .45329 .45001 L p .831 .494 .417 r
F P
0 g
s
.45329 .45001 m .44853 .68353 L .43227 .67553 L p .831 .494 .417 r
F P
0 g
s
.45902 .67136 m .44853 .68353 L .45329 .45001 L p .157 0 .346 r
F P
0 g
s
.45329 .45001 m .46244 .43848 L .45902 .67136 L p .157 0 .346 r
F P
0 g
s
.50923 .43057 m .52325 .43821 L .51386 .44973 L p .694 .677 .829 r
F P
0 g
s
.51386 .44973 m .49987 .44215 L .50923 .43057 L p .694 .677 .829 r
F P
0 g
s
.50178 .6501 m .49987 .44215 L .51386 .44973 L p .833 .49 .407 r
F P
0 g
s
.51386 .44973 m .51761 .65807 L .50178 .6501 L p .833 .49 .407 r
F P
0 g
s
.52826 .64595 m .51761 .65807 L .51386 .44973 L p .19 0 .37 r
F P
0 g
s
.51386 .44973 m .52325 .43821 L .52826 .64595 L p .19 0 .37 r
F P
0 g
s
.50178 .6501 m .49987 .44215 L .51386 .44973 L p .833 .49 .407 r
F P
0 g
s
.51386 .44973 m .51761 .65807 L .50178 .6501 L p .833 .49 .407 r
F P
0 g
s
.52918 .6839 m .51829 .6961 L .51386 .44973 L p .19 0 .37 r
F P
0 g
s
.51386 .44973 m .52325 .43821 L .52918 .6839 L p .19 0 .37 r
F P
0 g
s
.57021 .43029 m .58407 .43793 L .57444 .44946 L p .694 .677 .829 r
F P
0 g
s
.57444 .44946 m .56061 .44188 L .57021 .43029 L p .694 .677 .829 r
F P
0 g
s
.57238 .68779 m .56061 .44188 L .57444 .44946 L p .834 .486 .397 r
F P
0 g
s
.57444 .44946 m .58834 .69581 L .57238 .68779 L p .834 .486 .397 r
F P
0 g
s
.59955 .68361 m .58834 .69581 L .57444 .44946 L p .22 .027 .392 r
F P
0 g
s
.57444 .44946 m .58407 .43793 L .59955 .68361 L p .22 .027 .392 r
F P
0 g
s
.573 .70081 m .56061 .44188 L .57444 .44946 L p .834 .486 .397 r
F P
0 g
s
.57444 .44946 m .58907 .70885 L .573 .70081 L p .834 .486 .397 r
F P
0 g
s
.60036 .69662 m .58907 .70885 L .57444 .44946 L p .22 .027 .392 r
F P
0 g
s
.57444 .44946 m .58407 .43793 L .60036 .69662 L p .22 .027 .392 r
F P
0 g
s
.6312 .43001 m .64491 .43766 L .63503 .44919 L p .694 .677 .829 r
F P
0 g
s
.63503 .44919 m .62135 .4416 L .6312 .43001 L p .694 .677 .829 r
F P
0 g
s
.65341 .81182 m .62135 .4416 L .63503 .44919 L p .835 .482 .386 r
F P
0 g
s
.63503 .44919 m .6702 .81999 L .65341 .81182 L p .835 .482 .386 r
F P
0 g
s
.68536 .81343 m .6688 .80533 L .68109 .79292 L p .682 .709 .868 r
F P
0 g
s
.68258 .80756 m .6702 .81999 L .63503 .44919 L p .248 .056 .412 r
F P
0 g
s
.63503 .44919 m .64491 .43766 L .68258 .80756 L p .248 .056 .412 r
F P
0 g
s
.65341 .81182 m .62135 .4416 L .63503 .44919 L p .835 .482 .386 r
F P
0 g
s
.63503 .44919 m .6702 .81999 L .65341 .81182 L p .835 .482 .386 r
F P
0 g
s
.68109 .79292 m .6688 .80533 L .63503 .44919 L p .248 .056 .412 r
F P
0 g
s
.63503 .44919 m .64491 .43766 L .68109 .79292 L p .248 .056 .412 r
F P
0 g
s
.69221 .42974 m .70575 .43739 L .69563 .44892 L p .694 .677 .829 r
F P
0 g
s
.69563 .44892 m .68211 .44133 L .69221 .42974 L p .694 .677 .829 r
F P
0 g
s
.72308 .76823 m .68211 .44133 L .69563 .44892 L p .836 .477 .374 r
F P
0 g
s
.69563 .44892 m .73928 .77636 L .72308 .76823 L p .836 .477 .374 r
F P
0 g
s
.75172 .764 m .73928 .77636 L .69563 .44892 L p .272 .082 .43 r
F P
0 g
s
.69563 .44892 m .70575 .43739 L .75172 .764 L p .272 .082 .43 r
F P
0 g
s
.72486 .78245 m .68211 .44133 L .69563 .44892 L p .836 .477 .374 r
F P
0 g
s
.69563 .44892 m .74117 .79059 L .72486 .78245 L p .836 .477 .374 r
F P
0 g
s
.75372 .77821 m .74117 .79059 L .69563 .44892 L p .272 .082 .43 r
F P
0 g
s
.69563 .44892 m .70575 .43739 L .75372 .77821 L p .272 .082 .43 r
F P
0 g
s
.75322 .42946 m .76661 .43711 L .75625 .44864 L p .694 .677 .829 r
F P
0 g
s
.75625 .44864 m .74289 .44106 L .75322 .42946 L p .694 .677 .829 r
F P
0 g
s
.80362 .81122 m .74289 .44106 L .75625 .44864 L p .837 .472 .362 r
F P
0 g
s
.75625 .44864 m .81993 .8194 L .80362 .81122 L p .837 .472 .362 r
F P
0 g
s
.83305 .80697 m .81993 .8194 L .75625 .44864 L p .295 .107 .446 r
F P
0 g
s
.75625 .44864 m .76661 .43711 L .83305 .80697 L p .295 .107 .446 r
F P
0 g
s
.80362 .81122 m .74289 .44106 L .75625 .44864 L p .837 .472 .362 r
F P
0 g
s
.75625 .44864 m .81993 .8194 L .80362 .81122 L p .837 .472 .362 r
F P
0 g
s
.03443 .80596 m .02522 .81841 L .11288 .44772 L p 0 0 .14 r
F P
0 g
s
.11288 .44772 m .12068 .43618 L .03443 .80596 L p 0 0 .14 r
F P
0 g
s
.16657 .42825 m .1815 .4359 L .17346 .44745 L p .694 .677 .829 r
F P
0 g
s
.17346 .44745 m .15857 .43985 L .16657 .42825 L p .694 .677 .829 r
F P
0 g
s
.08445 .79528 m .10295 .80345 L .09352 .81576 L p .682 .709 .868 r
F P
0 g
s
.0814 .80993 m .15857 .43985 L .17346 .44745 L p .825 .508 .454 r
F P
0 g
s
.17346 .44745 m .10005 .81811 L .0814 .80993 L p .825 .508 .454 r
F P
0 g
s
.10963 .80567 m .10005 .81811 L .17346 .44745 L p 0 0 .186 r
F P
0 g
s
.17346 .44745 m .1815 .4359 L .10963 .80567 L p 0 0 .186 r
F P
0 g
s
.08445 .79528 m .15857 .43985 L .17346 .44745 L p .825 .508 .454 r
F P
0 g
s
.17346 .44745 m .10295 .80345 L .08445 .79528 L p .825 .508 .454 r
F P
0 g
s
.10963 .80567 m .10005 .81811 L .17346 .44745 L p 0 0 .186 r
F P
0 g
s
.17346 .44745 m .1815 .4359 L .10963 .80567 L p 0 0 .186 r
F P
0 g
s
.22757 .42797 m .24234 .43563 L .23406 .44718 L p .694 .677 .829 r
F P
0 g
s
.23406 .44718 m .21932 .43958 L .22757 .42797 L p .694 .677 .829 r
F P
0 g
s
.15174 .79293 m .16981 .80101 L .16017 .81317 L p .683 .708 .867 r
F P
0 g
s
.16017 .81317 m .14216 .80517 L .15174 .79293 L p .683 .708 .867 r
F P
0 g
s
.16142 .78056 m .17954 .78872 L .16981 .80101 L p .683 .708 .867 r
F P
0 g
s
.16981 .80101 m .15174 .79293 L .16142 .78056 L p .683 .708 .867 r
F P
0 g
s
.15648 .80963 m .21932 .43958 L .23406 .44718 L p .826 .506 .447 r
F P
0 g
s
.23406 .44718 m .17489 .81782 L .15648 .80963 L p .826 .506 .447 r
F P
0 g
s
.18484 .80537 m .17489 .81782 L .23406 .44718 L p .004 0 .228 r
F P
0 g
s
.23406 .44718 m .24234 .43563 L .18484 .80537 L p .004 0 .228 r
F P
0 g
s
.16142 .78056 m .21932 .43958 L .23406 .44718 L p .826 .506 .447 r
F P
0 g
s
.23406 .44718 m .17954 .78872 L .16142 .78056 L p .826 .506 .447 r
F P
0 g
s
.18484 .80537 m .17489 .81782 L .23406 .44718 L p .004 0 .228 r
F P
0 g
s
.23406 .44718 m .24234 .43563 L .18484 .80537 L p .004 0 .228 r
F P
0 g
s
.28857 .4277 m .30319 .43535 L .29466 .4469 L p .694 .677 .829 r
F P
0 g
s
.29466 .4469 m .28008 .43931 L .28857 .4277 L p .694 .677 .829 r
F P
0 g
s
.24268 .72468 m .28008 .43931 L .29466 .4469 L p .828 .503 .439 r
F P
0 g
s
.29466 .4469 m .26002 .73277 L .24268 .72468 L p .828 .503 .439 r
F P
0 g
s
.26994 .72046 m .26002 .73277 L .29466 .4469 L p .051 0 .265 r
F P
0 g
s
.29466 .4469 m .30319 .43535 L .26994 .72046 L p .051 0 .265 r
F P
0 g
s
.2409 .73827 m .28008 .43931 L .29466 .4469 L p .828 .503 .439 r
F P
0 g
s
.29466 .4469 m .25838 .74638 L .2409 .73827 L p .828 .503 .439 r
F P
0 g
s
.26994 .72046 m .26002 .73277 L .29466 .4469 L p .051 0 .265 r
F P
0 g
s
.29466 .4469 m .30319 .43535 L .26994 .72046 L p .051 0 .265 r
F P
0 g
s
.34959 .42742 m .36405 .43508 L .35528 .44663 L p .694 .677 .829 r
F P
0 g
s
.35528 .44663 m .34086 .43903 L .34959 .42742 L p .694 .677 .829 r
F P
0 g
s
.30174 .76409 m .31908 .77214 L .30887 .78427 L p .684 .705 .863 r
F P
0 g
s
.31199 .75177 m .32938 .7599 L .31908 .77214 L p .684 .705 .863 r
F P
0 g
s
.31908 .77214 m .30174 .76409 L .31199 .75177 L p .684 .705 .863 r
F P
0 g
s
.30671 .80904 m .34086 .43903 L .35528 .44663 L p .829 .499 .43 r
F P
0 g
s
.32369 .82055 m .30626 .8126 L .3166 .80043 L p .683 .708 .867 r
F P
0 g
s
.35528 .44663 m .32464 .81723 L .30671 .80904 L p .829 .499 .43 r
F P
0 g
s
.33533 .80478 m .32464 .81723 L .35528 .44663 L p .094 0 .298 r
F P
0 g
s
.35528 .44663 m .36405 .43508 L .33533 .80478 L p .094 0 .298 r
F P
0 g
s
.31199 .75177 m .34086 .43903 L .35528 .44663 L p .829 .499 .43 r
F P
0 g
s
.35528 .44663 m .32938 .7599 L .31199 .75177 L p .829 .499 .43 r
F P
0 g
s
.33533 .80478 m .32464 .81723 L .35528 .44663 L p .094 0 .298 r
F P
0 g
s
.35528 .44663 m .36405 .43508 L .33533 .80478 L p .094 0 .298 r
F P
0 g
s
.41062 .42714 m .42492 .4348 L .41591 .44636 L p .694 .677 .829 r
F P
0 g
s
.41591 .44636 m .40164 .43876 L .41062 .42714 L p .694 .677 .829 r
F P
0 g
s
.38263 .7941 m .40018 .80228 L .38931 .8146 L p .682 .709 .868 r
F P
0 g
s
.38185 .80874 m .40164 .43876 L .41591 .44636 L p .831 .496 .421 r
F P
0 g
s
.41591 .44636 m .39953 .81694 L .38185 .80874 L p .831 .496 .421 r
F P
0 g
s
.4106 .80448 m .39953 .81694 L .41591 .44636 L p .133 0 .328 r
F P
0 g
s
.41591 .44636 m .42492 .4348 L .4106 .80448 L p .133 0 .328 r
F P
0 g
s
.38263 .7941 m .40164 .43876 L .41591 .44636 L p .831 .496 .421 r
F P
0 g
s
.41591 .44636 m .40018 .80228 L .38263 .7941 L p .831 .496 .421 r
F P
0 g
s
.4106 .80448 m .39953 .81694 L .41591 .44636 L p .133 0 .328 r
F P
0 g
s
.41591 .44636 m .42492 .4348 L .4106 .80448 L p .133 0 .328 r
F P
0 g
s
.47167 .42687 m .4858 .43453 L .47655 .44608 L p .694 .677 .829 r
F P
0 g
s
.47655 .44608 m .46244 .43848 L .47167 .42687 L p .694 .677 .829 r
F P
0 g
s
.45939 .64624 m .46244 .43848 L .47655 .44608 L p .832 .492 .412 r
F P
0 g
s
.47655 .44608 m .47537 .65423 L .45939 .64624 L p .832 .492 .412 r
F P
0 g
s
.48585 .64208 m .47537 .65423 L .47655 .44608 L p .169 0 .354 r
F P
0 g
s
.47655 .44608 m .4858 .43453 L .48585 .64208 L p .169 0 .354 r
F P
0 g
s
.45902 .67136 m .46244 .43848 L .47655 .44608 L p .832 .492 .412 r
F P
0 g
s
.47655 .44608 m .47523 .67939 L .45902 .67136 L p .832 .492 .412 r
F P
0 g
s
.48585 .64208 m .47537 .65423 L .47655 .44608 L p .169 0 .354 r
F P
0 g
s
.47655 .44608 m .4858 .43453 L .48585 .64208 L p .169 0 .354 r
F P
0 g
s
.53272 .42659 m .5467 .43425 L .5372 .44581 L p .694 .677 .829 r
F P
0 g
s
.5372 .44581 m .52325 .43821 L .53272 .42659 L p .694 .677 .829 r
F P
0 g
s
.52887 .67107 m .52325 .43821 L .5372 .44581 L p .833 .488 .402 r
F P
0 g
s
.5372 .44581 m .54487 .6791 L .52887 .67107 L p .833 .488 .402 r
F P
0 g
s
.55582 .66689 m .54487 .6791 L .5372 .44581 L p .201 .006 .378 r
F P
0 g
s
.5372 .44581 m .5467 .43425 L .55582 .66689 L p .201 .006 .378 r
F P
0 g
s
.52918 .6839 m .52325 .43821 L .5372 .44581 L p .833 .488 .402 r
F P
0 g
s
.5372 .44581 m .54529 .69195 L .52918 .6839 L p .833 .488 .402 r
F P
0 g
s
.55582 .66689 m .54487 .6791 L .5372 .44581 L p .201 .006 .378 r
F P
0 g
s
.5372 .44581 m .5467 .43425 L .55582 .66689 L p .201 .006 .378 r
F P
0 g
s
.59379 .42631 m .60761 .43398 L .59787 .44554 L p .694 .677 .829 r
F P
0 g
s
.59787 .44554 m .58407 .43793 L .59379 .42631 L p .694 .677 .829 r
F P
0 g
s
.58907 .70885 m .60504 .71684 L .59382 .72889 L p .686 .7 .857 r
F P
0 g
s
.60036 .69662 m .61638 .70469 L .60504 .71684 L p .686 .7 .857 r
F P
0 g
s
.60504 .71684 m .58907 .70885 L .60036 .69662 L p .686 .7 .857 r
F P
0 g
s
.61144 .76352 m .59538 .75561 L .60677 .74352 L p .685 .702 .86 r
F P
0 g
s
.60176 .80301 m .61791 .81082 L .60648 .82259 L p .684 .705 .863 r
F P
0 g
s
.59617 .76927 m .61235 .77719 L .60093 .78912 L p .685 .704 .862 r
F P
0 g
s
.61791 .81082 m .60176 .80301 L .61327 .79106 L p .684 .705 .863 r
F P
0 g
s
.60737 .80786 m .58407 .43793 L .59787 .44554 L p .835 .484 .391 r
F P
0 g
s
.62249 .83028 m .60648 .82259 L .61791 .81082 L p .684 .705 .863 r
F P
0 g
s
.59787 .44554 m .62433 .81606 L .60737 .80786 L p .835 .484 .391 r
F P
0 g
s
.63651 .80359 m .62433 .81606 L .59787 .44554 L p .23 .037 .399 r
F P
0 g
s
.59787 .44554 m .60761 .43398 L .63651 .80359 L p .23 .037 .399 r
F P
0 g
s
.60036 .69662 m .58407 .43793 L .59787 .44554 L p .835 .484 .391 r
F P
0 g
s
.59787 .44554 m .61638 .70469 L .60036 .69662 L p .835 .484 .391 r
F P
0 g
s
.63651 .80359 m .62433 .81606 L .59787 .44554 L p .23 .037 .399 r
F P
0 g
s
.59787 .44554 m .60761 .43398 L .63651 .80359 L p .23 .037 .399 r
F P
0 g
s
.65486 .42604 m .66852 .4337 L .65854 .44527 L p .694 .677 .829 r
F P
0 g
s
.65854 .44527 m .64491 .43766 L .65486 .42604 L p .694 .677 .829 r
F P
0 g
s
.68109 .79292 m .69769 .80111 L .68536 .81343 L p .682 .709 .868 r
F P
0 g
s
.68258 .80756 m .64491 .43766 L .65854 .44527 L p .836 .479 .38 r
F P
0 g
s
.65854 .44527 m .6993 .81576 L .68258 .80756 L p .836 .479 .38 r
F P
0 g
s
.71185 .80329 m .6993 .81576 L .65854 .44527 L p .256 .065 .418 r
F P
0 g
s
.65854 .44527 m .66852 .4337 L .71185 .80329 L p .256 .065 .418 r
F P
0 g
s
.68109 .79292 m .64491 .43766 L .65854 .44527 L p .836 .479 .38 r
F P
0 g
s
.65854 .44527 m .69769 .80111 L .68109 .79292 L p .836 .479 .38 r
F P
0 g
s
.71185 .80329 m .6993 .81576 L .65854 .44527 L p .256 .065 .418 r
F P
0 g
s
.65854 .44527 m .66852 .4337 L .71185 .80329 L p .256 .065 .418 r
F P
0 g
s
.71595 .42576 m .72945 .43343 L .71923 .44499 L p .694 .677 .829 r
F P
0 g
s
.71923 .44499 m .70575 .43739 L .71595 .42576 L p .694 .677 .829 r
F P
0 g
s
.74117 .79059 m .75738 .79868 L .74492 .81087 L p .683 .708 .867 r
F P
0 g
s
.75372 .77821 m .76996 .78638 L .75738 .79868 L p .683 .708 .867 r
F P
0 g
s
.75738 .79868 m .74117 .79059 L .75372 .77821 L p .683 .708 .867 r
F P
0 g
s
.7578 .80726 m .70575 .43739 L .71923 .44499 L p .837 .474 .368 r
F P
0 g
s
.71923 .44499 m .77429 .81547 L .7578 .80726 L p .837 .474 .368 r
F P
0 g
s
.7872 .80299 m .77429 .81547 L .71923 .44499 L p .28 .091 .436 r
F P
0 g
s
.71923 .44499 m .72945 .43343 L .7872 .80299 L p .28 .091 .436 r
F P
0 g
s
.75372 .77821 m .70575 .43739 L .71923 .44499 L p .837 .474 .368 r
F P
0 g
s
.71923 .44499 m .76996 .78638 L .75372 .77821 L p .837 .474 .368 r
F P
0 g
s
.7872 .80299 m .77429 .81547 L .71923 .44499 L p .28 .091 .436 r
F P
0 g
s
.71923 .44499 m .72945 .43343 L .7872 .80299 L p .28 .091 .436 r
F P
0 g
s
.12854 .42455 m .14359 .43222 L .13569 .44379 L p .694 .677 .829 r
F P
0 g
s
.13569 .44379 m .12068 .43618 L .12854 .42455 L p .694 .677 .829 r
F P
0 g
s
.03784 .79133 m .12068 .43618 L .13569 .44379 L p .824 .51 .458 r
F P
0 g
s
.13569 .44379 m .05652 .79952 L .03784 .79133 L p .824 .51 .458 r
F P
0 g
s
.06583 .78706 m .05652 .79952 L .13569 .44379 L p 0 0 .156 r
F P
0 g
s
.13569 .44379 m .14359 .43222 L .06583 .78706 L p 0 0 .156 r
F P
0 g
s
.03443 .80596 m .12068 .43618 L .13569 .44379 L p .824 .51 .458 r
F P
0 g
s
.13569 .44379 m .05326 .81417 L .03443 .80596 L p .824 .51 .458 r
F P
0 g
s
.06263 .80169 m .05326 .81417 L .13569 .44379 L p 0 0 .156 r
F P
0 g
s
.13569 .44379 m .14359 .43222 L .06263 .80169 L p 0 0 .156 r
F P
0 g
s
.18961 .42427 m .2045 .43194 L .19636 .44352 L p .694 .677 .829 r
F P
0 g
s
.19636 .44352 m .1815 .4359 L .18961 .42427 L p .694 .677 .829 r
F P
0 g
s
.10963 .80567 m .1815 .4359 L .19636 .44352 L p .825 .507 .451 r
F P
0 g
s
.19636 .44352 m .12822 .81388 L .10963 .80567 L p .825 .507 .451 r
F P
0 g
s
.15422 .77869 m .13618 .77058 L .14574 .75816 L p .683 .706 .865 r
F P
0 g
s
.13357 .7848 m .15174 .79293 L .14216 .80517 L p .683 .708 .867 r
F P
0 g
s
.13796 .80139 m .12822 .81388 L .19636 .44352 L p 0 0 .2 r
F P
0 g
s
.19636 .44352 m .2045 .43194 L .13796 .80139 L p 0 0 .2 r
F P
0 g
s
.10963 .80567 m .1815 .4359 L .19636 .44352 L p .825 .507 .451 r
F P
0 g
s
.19636 .44352 m .12822 .81388 L .10963 .80567 L p .825 .507 .451 r
F P
0 g
s
.14574 .75816 m .13618 .77058 L .19636 .44352 L p 0 0 .2 r
F P
0 g
s
.19636 .44352 m .2045 .43194 L .14574 .75816 L p 0 0 .2 r
F P
0 g
s
.25069 .42399 m .26543 .43167 L .25704 .44325 L p .694 .677 .829 r
F P
0 g
s
.25704 .44325 m .24234 .43563 L .25069 .42399 L p .694 .677 .829 r
F P
0 g
s
.18712 .79073 m .24234 .43563 L .25704 .44325 L p .827 .504 .443 r
F P
0 g
s
.25704 .44325 m .20532 .79893 L .18712 .79073 L p .827 .504 .443 r
F P
0 g
s
.21536 .78647 m .20532 .79893 L .25704 .44325 L p .02 0 .24 r
F P
0 g
s
.25704 .44325 m .26543 .43167 L .21536 .78647 L p .02 0 .24 r
F P
0 g
s
.18484 .80537 m .24234 .43563 L .25704 .44325 L p .827 .504 .443 r
F P
0 g
s
.25704 .44325 m .20319 .81359 L .18484 .80537 L p .827 .504 .443 r
F P
0 g
s
.2133 .80109 m .20319 .81359 L .25704 .44325 L p .02 0 .24 r
F P
0 g
s
.25704 .44325 m .26543 .43167 L .2133 .80109 L p .02 0 .24 r
F P
0 g
s
.31178 .42371 m .32636 .43139 L .31773 .44297 L p .694 .677 .829 r
F P
0 g
s
.31773 .44297 m .30319 .43535 L .31178 .42371 L p .694 .677 .829 r
F P
0 g
s
.26994 .72046 m .30319 .43535 L .31773 .44297 L p .828 .501 .435 r
F P
0 g
s
.31773 .44297 m .28723 .72858 L .26994 .72046 L p .828 .501 .435 r
F P
0 g
s
.29729 .71624 m .28723 .72858 L .31773 .44297 L p .066 0 .276 r
F P
0 g
s
.31773 .44297 m .32636 .43139 L .29729 .71624 L p .066 0 .276 r
F P
0 g
s
.26994 .72046 m .30319 .43535 L .31773 .44297 L p .828 .501 .435 r
F P
0 g
s
.31773 .44297 m .28723 .72858 L .26994 .72046 L p .828 .501 .435 r
F P
0 g
s
.29591 .72981 m .28578 .74218 L .31773 .44297 L p .066 0 .276 r
F P
0 g
s
.31773 .44297 m .32636 .43139 L .29591 .72981 L p .066 0 .276 r
F P
0 g
s
.37289 .42344 m .3873 .43112 L .37843 .4427 L p .694 .677 .829 r
F P
0 g
s
.37843 .4427 m .36405 .43508 L .37289 .42344 L p .694 .677 .829 r
F P
0 g
s
.33647 .79014 m .36405 .43508 L .37843 .4427 L p .83 .498 .426 r
F P
0 g
s
.37843 .4427 m .35419 .79835 L .33647 .79014 L p .83 .498 .426 r
F P
0 g
s
.36497 .78587 m .35419 .79835 L .37843 .4427 L p .108 0 .308 r
F P
0 g
s
.37843 .4427 m .3873 .43112 L .36497 .78587 L p .108 0 .308 r
F P
0 g
s
.33533 .80478 m .36405 .43508 L .37843 .4427 L p .83 .498 .426 r
F P
0 g
s
.37843 .4427 m .35319 .813 L .33533 .80478 L p .83 .498 .426 r
F P
0 g
s
.36405 .8005 m .35319 .813 L .37843 .4427 L p .108 0 .308 r
F P
0 g
s
.37843 .4427 m .3873 .43112 L .36405 .8005 L p .108 0 .308 r
F P
0 g
s
.43401 .42316 m .44826 .43084 L .43914 .44243 L p .694 .677 .829 r
F P
0 g
s
.43914 .44243 m .42492 .4348 L .43401 .42316 L p .694 .677 .829 r
F P
0 g
s
.4106 .80448 m .42492 .4348 L .43914 .44243 L p .831 .494 .417 r
F P
0 g
s
.43914 .44243 m .42822 .8127 L .4106 .80448 L p .831 .494 .417 r
F P
0 g
s
.45426 .70347 m .43814 .69559 L .44853 .68353 L p .687 .698 .854 r
F P
0 g
s
.44879 .67085 m .43264 .66287 L .44301 .65065 L p .687 .696 .853 r
F P
0 g
s
.44912 .76093 m .43294 .7532 L .44333 .74138 L p .686 .7 .857 r
F P
0 g
s
.43227 .67553 m .44853 .68353 L .43814 .69559 L p .687 .698 .854 r
F P
0 g
s
.43746 .72154 m .45382 .72945 L .44333 .74138 L p .686 .7 .857 r
F P
0 g
s
.43181 .79373 m .44833 .8015 L .43778 .8132 L p .685 .704 .862 r
F P
0 g
s
.43944 .8002 m .42822 .8127 L .43914 .44243 L p .145 0 .337 r
F P
0 g
s
.43914 .44243 m .44826 .43084 L .43944 .8002 L p .145 0 .337 r
F P
0 g
s
.4106 .80448 m .42492 .4348 L .43914 .44243 L p .831 .494 .417 r
F P
0 g
s
.43914 .44243 m .42822 .8127 L .4106 .80448 L p .831 .494 .417 r
F P
0 g
s
.44301 .65065 m .43264 .66287 L .43914 .44243 L p .145 0 .337 r
F P
0 g
s
.43914 .44243 m .44826 .43084 L .44301 .65065 L p .145 0 .337 r
F P
0 g
s
.49513 .42288 m .50923 .43057 L .49987 .44215 L p .694 .677 .829 r
F P
0 g
s
.49987 .44215 m .4858 .43453 L .49513 .42288 L p .694 .677 .829 r
F P
0 g
s
.48585 .62979 m .4858 .43453 L .49987 .44215 L p .833 .49 .407 r
F P
0 g
s
.49987 .44215 m .50166 .63779 L .48585 .62979 L p .833 .49 .407 r
F P
0 g
s
.5122 .62563 m .50166 .63779 L .49987 .44215 L p .18 0 .362 r
F P
0 g
s
.49987 .44215 m .50923 .43057 L .5122 .62563 L p .18 0 .362 r
F P
0 g
s
.48585 .64208 m .4858 .43453 L .49987 .44215 L p .833 .49 .407 r
F P
0 g
s
.49987 .44215 m .50178 .6501 L .48585 .64208 L p .833 .49 .407 r
F P
0 g
s
.51239 .63791 m .50178 .6501 L .49987 .44215 L p .18 0 .362 r
F P
0 g
s
.49987 .44215 m .50923 .43057 L .51239 .63791 L p .18 0 .362 r
F P
0 g
s
.55627 .42261 m .57021 .43029 L .56061 .44188 L p .694 .677 .829 r
F P
0 g
s
.56061 .44188 m .5467 .43425 L .55627 .42261 L p .694 .677 .829 r
F P
0 g
s
.55582 .66689 m .5467 .43425 L .56061 .44188 L p .834 .486 .397 r
F P
0 g
s
.56061 .44188 m .57176 .67495 L .55582 .66689 L p .834 .486 .397 r
F P
0 g
s
.58285 .6627 m .57176 .67495 L .56061 .44188 L p .211 .017 .385 r
F P
0 g
s
.56061 .44188 m .57021 .43029 L .58285 .6627 L p .211 .017 .385 r
F P
0 g
s
.55582 .66689 m .5467 .43425 L .56061 .44188 L p .834 .486 .397 r
F P
0 g
s
.56061 .44188 m .57176 .67495 L .55582 .66689 L p .834 .486 .397 r
F P
0 g
s
.58355 .67551 m .57238 .68779 L .56061 .44188 L p .211 .017 .385 r
F P
0 g
s
.56061 .44188 m .57021 .43029 L .58355 .67551 L p .211 .017 .385 r
F P
0 g
s
.61742 .42233 m .6312 .43001 L .62135 .4416 L p .694 .677 .829 r
F P
0 g
s
.62135 .4416 m .60761 .43398 L .61742 .42233 L p .694 .677 .829 r
F P
0 g
s
.63536 .78896 m .60761 .43398 L .62135 .4416 L p .835 .482 .386 r
F P
0 g
s
.62135 .4416 m .65214 .79717 L .63536 .78896 L p .835 .482 .386 r
F P
0 g
s
.66438 .78468 m .65214 .79717 L .62135 .4416 L p .239 .047 .406 r
F P
0 g
s
.62135 .4416 m .6312 .43001 L .66438 .78468 L p .239 .047 .406 r
F P
0 g
s
.63651 .80359 m .60761 .43398 L .62135 .4416 L p .835 .482 .386 r
F P
0 g
s
.62135 .4416 m .65341 .81182 L .63651 .80359 L p .835 .482 .386 r
F P
0 g
s
.66575 .79931 m .65341 .81182 L .62135 .4416 L p .239 .047 .406 r
F P
0 g
s
.62135 .4416 m .6312 .43001 L .66575 .79931 L p .239 .047 .406 r
F P
0 g
s
.67859 .42205 m .69221 .42974 L .68211 .44133 L p .694 .677 .829 r
F P
0 g
s
.68211 .44133 m .66852 .4337 L .67859 .42205 L p .694 .677 .829 r
F P
0 g
s
.71185 .80329 m .66852 .4337 L .68211 .44133 L p .836 .477 .374 r
F P
0 g
s
.68211 .44133 m .7285 .81152 L .71185 .80329 L p .836 .477 .374 r
F P
0 g
s
.74492 .81087 m .72875 .80286 L .74117 .79059 L p .683 .708 .867 r
F P
0 g
s
.73928 .77636 m .72308 .76823 L .73548 .75579 L p .683 .706 .865 r
F P
0 g
s
.72486 .78245 m .74117 .79059 L .72875 .80286 L p .683 .708 .867 r
F P
0 g
s
.74122 .79901 m .7285 .81152 L .68211 .44133 L p .264 .074 .424 r
F P
0 g
s
.68211 .44133 m .69221 .42974 L .74122 .79901 L p .264 .074 .424 r
F P
0 g
s
.71185 .80329 m .66852 .4337 L .68211 .44133 L p .836 .477 .374 r
F P
0 g
s
.68211 .44133 m .7285 .81152 L .71185 .80329 L p .836 .477 .374 r
F P
0 g
s
.73548 .75579 m .72308 .76823 L .68211 .44133 L p .264 .074 .424 r
F P
0 g
s
.68211 .44133 m .69221 .42974 L .73548 .75579 L p .264 .074 .424 r
F P
0 g
s
.73976 .42177 m .75322 .42946 L .74289 .44106 L p .694 .677 .829 r
F P
0 g
s
.74289 .44106 m .72945 .43343 L .73976 .42177 L p .694 .677 .829 r
F P
0 g
s
.78492 .78836 m .72945 .43343 L .74289 .44106 L p .837 .472 .362 r
F P
0 g
s
.74289 .44106 m .80122 .79658 L .78492 .78836 L p .837 .472 .362 r
F P
0 g
s
.81419 .78409 m .80122 .79658 L .74289 .44106 L p .288 .099 .441 r
F P
0 g
s
.74289 .44106 m .75322 .42946 L .81419 .78409 L p .288 .099 .441 r
F P
0 g
s
.7872 .80299 m .72945 .43343 L .74289 .44106 L p .837 .472 .362 r
F P
0 g
s
.74289 .44106 m .80362 .81122 L .7872 .80299 L p .837 .472 .362 r
F P
0 g
s
.8167 .79871 m .80362 .81122 L .74289 .44106 L p .288 .099 .441 r
F P
0 g
s
.74289 .44106 m .75322 .42946 L .8167 .79871 L p .288 .099 .441 r
F P
0 g
s
.15156 .42055 m .16657 .42825 L .15857 .43985 L p .694 .677 .829 r
F P
0 g
s
.15857 .43985 m .14359 .43222 L .15156 .42055 L p .694 .677 .829 r
F P
0 g
s
.06899 .77265 m .14359 .43222 L .15857 .43985 L p .825 .508 .454 r
F P
0 g
s
.15857 .43985 m .08746 .78086 L .06899 .77265 L p .825 .508 .454 r
F P
0 g
s
.09687 .76838 m .08746 .78086 L .15857 .43985 L p 0 0 .171 r
F P
0 g
s
.15857 .43985 m .16657 .42825 L .09687 .76838 L p 0 0 .171 r
F P
0 g
s
.06263 .80169 m .14359 .43222 L .15857 .43985 L p .825 .508 .454 r
F P
0 g
s
.15857 .43985 m .0814 .80993 L .06263 .80169 L p .825 .508 .454 r
F P
0 g
s
.09092 .7974 m .0814 .80993 L .15857 .43985 L p 0 0 .171 r
F P
0 g
s
.15857 .43985 m .16657 .42825 L .09092 .7974 L p 0 0 .171 r
F P
0 g
s
.21271 .42028 m .22757 .42797 L .21932 .43958 L p .694 .677 .829 r
F P
0 g
s
.21932 .43958 m .2045 .43194 L .21271 .42028 L p .694 .677 .829 r
F P
0 g
s
.14574 .75816 m .16383 .76635 L .15422 .77869 L p .683 .706 .865 r
F P
0 g
s
.13796 .80139 m .2045 .43194 L .21932 .43958 L p .826 .506 .447 r
F P
0 g
s
.21932 .43958 m .15648 .80963 L .13796 .80139 L p .826 .506 .447 r
F P
0 g
s
.16638 .7971 m .15648 .80963 L .21932 .43958 L p 0 0 .214 r
F P
0 g
s
.21932 .43958 m .22757 .42797 L .16638 .7971 L p 0 0 .214 r
F P
0 g
s
.14574 .75816 m .2045 .43194 L .21932 .43958 L p .826 .506 .447 r
F P
0 g
s
.21932 .43958 m .16383 .76635 L .14574 .75816 L p .826 .506 .447 r
F P
0 g
s
.16638 .7971 m .15648 .80963 L .21932 .43958 L p 0 0 .214 r
F P
0 g
s
.21932 .43958 m .22757 .42797 L .16638 .7971 L p 0 0 .214 r
F P
0 g
s
.27388 .42 m .28857 .4277 L .28008 .43931 L p .694 .677 .829 r
F P
0 g
s
.28008 .43931 m .26543 .43167 L .27388 .42 L p .694 .677 .829 r
F P
0 g
s
.2133 .80109 m .26543 .43167 L .28008 .43931 L p .828 .503 .439 r
F P
0 g
s
.28008 .43931 m .23159 .80934 L .2133 .80109 L p .828 .503 .439 r
F P
0 g
s
.26002 .73277 m .24268 .72468 L .25255 .71229 L p .685 .702 .86 r
F P
0 g
s
.25428 .79248 m .23689 .78456 L .24675 .77243 L p .684 .705 .863 r
F P
0 g
s
.2409 .73827 m .25838 .74638 L .24849 .7586 L p .685 .704 .862 r
F P
0 g
s
.24185 .7968 m .23159 .80934 L .28008 .43931 L p .036 0 .253 r
F P
0 g
s
.28008 .43931 m .28857 .4277 L .24185 .7968 L p .036 0 .253 r
F P
0 g
s
.2133 .80109 m .26543 .43167 L .28008 .43931 L p .828 .503 .439 r
F P
0 g
s
.28008 .43931 m .23159 .80934 L .2133 .80109 L p .828 .503 .439 r
F P
0 g
s
.25255 .71229 m .24268 .72468 L .28008 .43931 L p .036 0 .253 r
F P
0 g
s
.28008 .43931 m .28857 .4277 L .25255 .71229 L p .036 0 .253 r
F P
0 g
s
.33506 .41972 m .34959 .42742 L .34086 .43903 L p .694 .677 .829 r
F P
0 g
s
.34086 .43903 m .32636 .43139 L .33506 .41972 L p .694 .677 .829 r
F P
0 g
s
.28153 .78838 m .29877 .79628 L .28875 .80819 L p .684 .705 .863 r
F P
0 g
s
.29159 .77629 m .30887 .78427 L .29877 .79628 L p .684 .705 .863 r
F P
0 g
s
.29877 .79628 m .28153 .78838 L .29159 .77629 L p .684 .705 .863 r
F P
0 g
s
.30887 .78427 m .29159 .77629 L .30174 .76409 L p .684 .705 .863 r
F P
0 g
s
.29591 .72981 m .31327 .73798 L .30309 .75027 L p .685 .704 .862 r
F P
0 g
s
.30309 .75027 m .28578 .74218 L .29591 .72981 L p .685 .704 .862 r
F P
0 g
s
.2843 .75599 m .30174 .76409 L .29159 .77629 L p .684 .705 .863 r
F P
0 g
s
.29159 .77629 m .2742 .76827 L .2843 .75599 L p .684 .705 .863 r
F P
0 g
s
.28866 .8008 m .32636 .43139 L .34086 .43903 L p .829 .499 .43 r
F P
0 g
s
.34086 .43903 m .30671 .80904 L .28866 .8008 L p .829 .499 .43 r
F P
0 g
s
.31735 .7965 m .30671 .80904 L .34086 .43903 L p .08 0 .287 r
F P
0 g
s
.34086 .43903 m .34959 .42742 L .31735 .7965 L p .08 0 .287 r
F P
0 g
s
.29591 .72981 m .32636 .43139 L .34086 .43903 L p .829 .499 .43 r
F P
0 g
s
.34086 .43903 m .31327 .73798 L .29591 .72981 L p .829 .499 .43 r
F P
0 g
s
.31735 .7965 m .30671 .80904 L .34086 .43903 L p .08 0 .287 r
F P
0 g
s
.34086 .43903 m .34959 .42742 L .31735 .7965 L p .08 0 .287 r
F P
0 g
s
.39625 .41944 m .41062 .42714 L .40164 .43876 L p .694 .677 .829 r
F P
0 g
s
.40164 .43876 m .3873 .43112 L .39625 .41944 L p .694 .677 .829 r
F P
0 g
s
.36587 .77146 m .3873 .43112 L .40164 .43876 L p .831 .496 .421 r
F P
0 g
s
.40164 .43876 m .3834 .77968 L .36587 .77146 L p .831 .496 .421 r
F P
0 g
s
.39426 .76719 m .3834 .77968 L .40164 .43876 L p .121 0 .318 r
F P
0 g
s
.40164 .43876 m .41062 .42714 L .39426 .76719 L p .121 0 .318 r
F P
0 g
s
.36405 .8005 m .3873 .43112 L .40164 .43876 L p .831 .496 .421 r
F P
0 g
s
.40164 .43876 m .38185 .80874 L .36405 .8005 L p .831 .496 .421 r
F P
0 g
s
.39286 .79621 m .38185 .80874 L .40164 .43876 L p .121 0 .318 r
F P
0 g
s
.40164 .43876 m .41062 .42714 L .39286 .79621 L p .121 0 .318 r
F P
0 g
s
.45745 .41916 m .47167 .42687 L .46244 .43848 L p .694 .677 .829 r
F P
0 g
s
.46244 .43848 m .44826 .43084 L .45745 .41916 L p .694 .677 .829 r
F P
0 g
s
.44331 .6382 m .44826 .43084 L .46244 .43848 L p .832 .492 .412 r
F P
0 g
s
.46244 .43848 m .45939 .64624 L .44331 .6382 L p .832 .492 .412 r
F P
0 g
s
.46983 .63402 m .45939 .64624 L .46244 .43848 L p .157 0 .346 r
F P
0 g
s
.46244 .43848 m .47167 .42687 L .46983 .63402 L p .157 0 .346 r
F P
0 g
s
.44301 .65065 m .44826 .43084 L .46244 .43848 L p .832 .492 .412 r
F P
0 g
s
.46244 .43848 m .45921 .65871 L .44301 .65065 L p .832 .492 .412 r
F P
0 g
s
.46983 .63402 m .45939 .64624 L .46244 .43848 L p .157 0 .346 r
F P
0 g
s
.46244 .43848 m .47167 .42687 L .46983 .63402 L p .157 0 .346 r
F P
0 g
s
.51867 .41889 m .53272 .42659 L .52325 .43821 L p .694 .677 .829 r
F P
0 g
s
.52325 .43821 m .50923 .43057 L .51867 .41889 L p .694 .677 .829 r
F P
0 g
s
.51239 .63791 m .50923 .43057 L .52325 .43821 L p .833 .488 .402 r
F P
0 g
s
.52325 .43821 m .52826 .64595 L .51239 .63791 L p .833 .488 .402 r
F P
0 g
s
.53902 .63373 m .52826 .64595 L .52325 .43821 L p .19 0 .37 r
F P
0 g
s
.52325 .43821 m .53272 .42659 L .53902 .63373 L p .19 0 .37 r
F P
0 g
s
.51239 .63791 m .50923 .43057 L .52325 .43821 L p .833 .488 .402 r
F P
0 g
s
.52325 .43821 m .52826 .64595 L .51239 .63791 L p .833 .488 .402 r
F P
0 g
s
.53978 .65879 m .52887 .67107 L .52325 .43821 L p .19 0 .37 r
F P
0 g
s
.52325 .43821 m .53272 .42659 L .53978 .65879 L p .19 0 .37 r
F P
0 g
s
.57989 .41861 m .59379 .42631 L .58407 .43793 L p .694 .677 .829 r
F P
0 g
s
.58407 .43793 m .57021 .43029 L .57989 .41861 L p .694 .677 .829 r
F P
0 g
s
.57788 .72097 m .59382 .72889 L .58269 .74082 L p .686 .7 .857 r
F P
0 g
s
.59382 .72889 m .57788 .72097 L .58907 .70885 L p .686 .7 .857 r
F P
0 g
s
.58355 .67551 m .59955 .68361 L .58834 .69581 L p .687 .699 .856 r
F P
0 g
s
.58834 .69581 m .57238 .68779 L .58355 .67551 L p .687 .699 .856 r
F P
0 g
s
.573 .70081 m .58907 .70885 L .57788 .72097 L p .686 .7 .857 r
F P
0 g
s
.60093 .78912 m .58479 .78127 L .59617 .76927 L p .685 .704 .862 r
F P
0 g
s
.58552 .79515 m .60176 .80301 L .59037 .81485 L p .684 .705 .863 r
F P
0 g
s
.5903 .7996 m .57021 .43029 L .58407 .43793 L p .835 .484 .391 r
F P
0 g
s
.60648 .82259 m .59037 .81485 L .60176 .80301 L p .684 .705 .863 r
F P
0 g
s
.58407 .43793 m .60737 .80786 L .5903 .7996 L p .835 .484 .391 r
F P
0 g
s
.6195 .79531 m .60737 .80786 L .58407 .43793 L p .22 .027 .392 r
F P
0 g
s
.58407 .43793 m .59379 .42631 L .6195 .79531 L p .22 .027 .392 r
F P
0 g
s
.58355 .67551 m .57021 .43029 L .58407 .43793 L p .835 .484 .391 r
F P
0 g
s
.58407 .43793 m .59955 .68361 L .58355 .67551 L p .835 .484 .391 r
F P
0 g
s
.6195 .79531 m .60737 .80786 L .58407 .43793 L p .22 .027 .392 r
F P
0 g
s
.58407 .43793 m .59379 .42631 L .6195 .79531 L p .22 .027 .392 r
F P
0 g
s
.64113 .41833 m .65486 .42604 L .64491 .43766 L p .694 .677 .829 r
F P
0 g
s
.64491 .43766 m .6312 .43001 L .64113 .41833 L p .694 .677 .829 r
F P
0 g
s
.66303 .77028 m .6312 .43001 L .64491 .43766 L p .836 .479 .38 r
F P
0 g
s
.64491 .43766 m .67962 .7785 L .66303 .77028 L p .836 .479 .38 r
F P
0 g
s
.69192 .766 m .67962 .7785 L .64491 .43766 L p .248 .056 .412 r
F P
0 g
s
.64491 .43766 m .65486 .42604 L .69192 .766 L p .248 .056 .412 r
F P
0 g
s
.66575 .79931 m .6312 .43001 L .64491 .43766 L p .836 .479 .38 r
F P
0 g
s
.64491 .43766 m .68258 .80756 L .66575 .79931 L p .836 .479 .38 r
F P
0 g
s
.69508 .79501 m .68258 .80756 L .64491 .43766 L p .248 .056 .412 r
F P
0 g
s
.64491 .43766 m .65486 .42604 L .69508 .79501 L p .248 .056 .412 r
F P
0 g
s
.70238 .41805 m .71595 .42576 L .70575 .43739 L p .694 .677 .829 r
F P
0 g
s
.70575 .43739 m .69221 .42974 L .70238 .41805 L p .694 .677 .829 r
F P
0 g
s
.73548 .75579 m .75172 .764 L .73928 .77636 L p .683 .706 .865 r
F P
0 g
s
.74122 .79901 m .69221 .42974 L .70575 .43739 L p .837 .474 .368 r
F P
0 g
s
.70575 .43739 m .7578 .80726 L .74122 .79901 L p .837 .474 .368 r
F P
0 g
s
.77068 .79471 m .7578 .80726 L .70575 .43739 L p .272 .082 .43 r
F P
0 g
s
.70575 .43739 m .71595 .42576 L .77068 .79471 L p .272 .082 .43 r
F P
0 g
s
.73548 .75579 m .69221 .42974 L .70575 .43739 L p .837 .474 .368 r
F P
0 g
s
.70575 .43739 m .75172 .764 L .73548 .75579 L p .837 .474 .368 r
F P
0 g
s
.77068 .79471 m .7578 .80726 L .70575 .43739 L p .272 .082 .43 r
F P
0 g
s
.70575 .43739 m .71595 .42576 L .77068 .79471 L p .272 .082 .43 r
F P
0 g
s
.76364 .41777 m .77705 .42548 L .76661 .43711 L p .694 .677 .829 r
F P
0 g
s
.76661 .43711 m .75322 .42946 L .76364 .41777 L p .694 .677 .829 r
F P
0 g
s
.8167 .79871 m .75322 .42946 L .76661 .43711 L p .838 .469 .355 r
F P
0 g
s
.76661 .43711 m .83305 .80697 L .8167 .79871 L p .838 .469 .355 r
F P
0 g
s
.8463 .79441 m .83305 .80697 L .76661 .43711 L p .295 .107 .446 r
F P
0 g
s
.76661 .43711 m .77705 .42548 L .8463 .79441 L p .295 .107 .446 r
F P
0 g
s
.8167 .79871 m .75322 .42946 L .76661 .43711 L p .838 .469 .355 r
F P
0 g
s
.76661 .43711 m .83305 .80697 L .8167 .79871 L p .838 .469 .355 r
F P
0 g
s
.04709 .77878 m .03784 .79133 L .12068 .43618 L p 0 0 .14 r
F P
0 g
s
.12068 .43618 m .12854 .42455 L .04709 .77878 L p 0 0 .14 r
F P
0 g
s
.17464 .41655 m .18961 .42427 L .1815 .4359 L p .694 .677 .829 r
F P
0 g
s
.1815 .4359 m .16657 .42825 L .17464 .41655 L p .694 .677 .829 r
F P
0 g
s
.09391 .78278 m .16657 .42825 L .1815 .4359 L p .825 .507 .451 r
F P
0 g
s
.1815 .4359 m .11247 .79103 L .09391 .78278 L p .825 .507 .451 r
F P
0 g
s
.12209 .77848 m .11247 .79103 L .1815 .4359 L p 0 0 .186 r
F P
0 g
s
.1815 .4359 m .18961 .42427 L .12209 .77848 L p 0 0 .186 r
F P
0 g
s
.09092 .7974 m .16657 .42825 L .1815 .4359 L p .825 .507 .451 r
F P
0 g
s
.1815 .4359 m .10963 .80567 L .09092 .7974 L p .825 .507 .451 r
F P
0 g
s
.11931 .7931 m .10963 .80567 L .1815 .4359 L p 0 0 .186 r
F P
0 g
s
.1815 .4359 m .18961 .42427 L .11931 .7931 L p 0 0 .186 r
F P
0 g
s
.23588 .41627 m .25069 .42399 L .24234 .43563 L p .694 .677 .829 r
F P
0 g
s
.24234 .43563 m .22757 .42797 L .23588 .41627 L p .694 .677 .829 r
F P
0 g
s
.16638 .7971 m .22757 .42797 L .24234 .43563 L p .827 .504 .443 r
F P
0 g
s
.24234 .43563 m .18484 .80537 L .16638 .7971 L p .827 .504 .443 r
F P
0 g
s
.20532 .79893 m .18712 .79073 L .19711 .77818 L p .682 .709 .868 r
F P
0 g
s
.1949 .7928 m .18484 .80537 L .24234 .43563 L p .004 0 .228 r
F P
0 g
s
.24234 .43563 m .25069 .42399 L .1949 .7928 L p .004 0 .228 r
F P
0 g
s
.16638 .7971 m .22757 .42797 L .24234 .43563 L p .827 .504 .443 r
F P
0 g
s
.24234 .43563 m .18484 .80537 L .16638 .7971 L p .827 .504 .443 r
F P
0 g
s
.19711 .77818 m .18712 .79073 L .24234 .43563 L p .004 0 .228 r
F P
0 g
s
.24234 .43563 m .25069 .42399 L .19711 .77818 L p .004 0 .228 r
F P
0 g
s
.29713 .41599 m .31178 .42371 L .30319 .43535 L p .694 .677 .829 r
F P
0 g
s
.30319 .43535 m .28857 .4277 L .29713 .41599 L p .694 .677 .829 r
F P
0 g
s
.25424 .69892 m .28857 .4277 L .30319 .43535 L p .828 .501 .435 r
F P
0 g
s
.30319 .43535 m .2715 .70708 L .25424 .69892 L p .828 .501 .435 r
F P
0 g
s
.28145 .69468 m .2715 .70708 L .30319 .43535 L p .051 0 .265 r
F P
0 g
s
.30319 .43535 m .31178 .42371 L .28145 .69468 L p .051 0 .265 r
F P
0 g
s
.25255 .71229 m .28857 .4277 L .30319 .43535 L p .828 .501 .435 r
F P
0 g
s
.30319 .43535 m .26994 .72046 L .25255 .71229 L p .828 .501 .435 r
F P
0 g
s
.27996 .70804 m .26994 .72046 L .30319 .43535 L p .051 0 .265 r
F P
0 g
s
.30319 .43535 m .31178 .42371 L .27996 .70804 L p .051 0 .265 r
F P
0 g
s
.3584 .41572 m .37289 .42344 L .36405 .43508 L p .694 .677 .829 r
F P
0 g
s
.36405 .43508 m .34959 .42742 L .3584 .41572 L p .694 .677 .829 r
F P
0 g
s
.31735 .7965 m .34959 .42742 L .36405 .43508 L p .83 .498 .426 r
F P
0 g
s
.36405 .43508 m .33533 .80478 L .31735 .7965 L p .83 .498 .426 r
F P
0 g
s
.35419 .79835 m .33647 .79014 L .34719 .77759 L p .682 .709 .868 r
F P
0 g
s
.34613 .7922 m .33533 .80478 L .36405 .43508 L p .094 0 .298 r
F P
0 g
s
.36405 .43508 m .37289 .42344 L .34613 .7922 L p .094 0 .298 r
F P
0 g
s
.31735 .7965 m .34959 .42742 L .36405 .43508 L p .83 .498 .426 r
F P
0 g
s
.36405 .43508 m .33533 .80478 L .31735 .7965 L p .83 .498 .426 r
F P
0 g
s
.34719 .77759 m .33647 .79014 L .36405 .43508 L p .094 0 .298 r
F P
0 g
s
.36405 .43508 m .37289 .42344 L .34719 .77759 L p .094 0 .298 r
F P
0 g
s
.41967 .41544 m .43401 .42316 L .42492 .4348 L p .694 .677 .829 r
F P
0 g
s
.42492 .4348 m .41062 .42714 L .41967 .41544 L p .694 .677 .829 r
F P
0 g
s
.39356 .78159 m .41062 .42714 L .42492 .4348 L p .831 .494 .417 r
F P
0 g
s
.42492 .4348 m .41116 .78985 L .39356 .78159 L p .831 .494 .417 r
F P
0 g
s
.42226 .77729 m .41116 .78985 L .42492 .4348 L p .133 0 .328 r
F P
0 g
s
.42492 .4348 m .43401 .42316 L .42226 .77729 L p .133 0 .328 r
F P
0 g
s
.39286 .79621 m .41062 .42714 L .42492 .4348 L p .831 .494 .417 r
F P
0 g
s
.42492 .4348 m .4106 .80448 L .39286 .79621 L p .831 .494 .417 r
F P
0 g
s
.42177 .7919 m .4106 .80448 L .42492 .4348 L p .133 0 .328 r
F P
0 g
s
.42492 .4348 m .43401 .42316 L .42177 .7919 L p .133 0 .328 r
F P
0 g
s
.48096 .41516 m .49513 .42288 L .4858 .43453 L p .694 .677 .829 r
F P
0 g
s
.4858 .43453 m .47167 .42687 L .48096 .41516 L p .694 .677 .829 r
F P
0 g
s
.46983 .63402 m .47167 .42687 L .4858 .43453 L p .833 .49 .407 r
F P
0 g
s
.4858 .43453 m .48585 .64208 L .46983 .63402 L p .833 .49 .407 r
F P
0 g
s
.50166 .63779 m .48585 .62979 L .49635 .61756 L p .688 .694 .85 r
F P
0 g
s
.49642 .62982 m .48585 .64208 L .4858 .43453 L p .169 0 .354 r
F P
0 g
s
.4858 .43453 m .49513 .42288 L .49642 .62982 L p .169 0 .354 r
F P
0 g
s
.46983 .63402 m .47167 .42687 L .4858 .43453 L p .833 .49 .407 r
F P
0 g
s
.4858 .43453 m .48585 .64208 L .46983 .63402 L p .833 .49 .407 r
F P
0 g
s
.49635 .61756 m .48585 .62979 L .4858 .43453 L p .169 0 .354 r
F P
0 g
s
.4858 .43453 m .49513 .42288 L .49635 .61756 L p .169 0 .354 r
F P
0 g
s
.54226 .41488 m .55627 .42261 L .5467 .43425 L p .694 .677 .829 r
F P
0 g
s
.5467 .43425 m .53272 .42659 L .54226 .41488 L p .694 .677 .829 r
F P
0 g
s
.53939 .64617 m .53272 .42659 L .5467 .43425 L p .834 .486 .397 r
F P
0 g
s
.5467 .43425 m .55532 .65425 L .53939 .64617 L p .834 .486 .397 r
F P
0 g
s
.56629 .64196 m .55532 .65425 L .5467 .43425 L p .201 .006 .378 r
F P
0 g
s
.5467 .43425 m .55627 .42261 L .56629 .64196 L p .201 .006 .378 r
F P
0 g
s
.53978 .65879 m .53272 .42659 L .5467 .43425 L p .834 .486 .397 r
F P
0 g
s
.5467 .43425 m .55582 .66689 L .53978 .65879 L p .834 .486 .397 r
F P
0 g
s
.56687 .65457 m .55582 .66689 L .5467 .43425 L p .201 .006 .378 r
F P
0 g
s
.5467 .43425 m .55627 .42261 L .56687 .65457 L p .201 .006 .378 r
F P
0 g
s
.60357 .4146 m .61742 .42233 L .60761 .43398 L p .694 .677 .829 r
F P
0 g
s
.60761 .43398 m .59379 .42631 L .60357 .4146 L p .694 .677 .829 r
F P
0 g
s
.6195 .79531 m .59379 .42631 L .60761 .43398 L p .835 .482 .386 r
F P
0 g
s
.60761 .43398 m .63651 .80359 L .6195 .79531 L p .835 .482 .386 r
F P
0 g
s
.65214 .79717 m .63536 .78896 L .64756 .77639 L p .682 .709 .868 r
F P
0 g
s
.64881 .791 m .63651 .80359 L .60761 .43398 L p .23 .037 .399 r
F P
0 g
s
.60761 .43398 m .61742 .42233 L .64881 .791 L p .23 .037 .399 r
F P
0 g
s
.6195 .79531 m .59379 .42631 L .60761 .43398 L p .835 .482 .386 r
F P
0 g
s
.60761 .43398 m .63651 .80359 L .6195 .79531 L p .835 .482 .386 r
F P
0 g
s
.64756 .77639 m .63536 .78896 L .60761 .43398 L p .23 .037 .399 r
F P
0 g
s
.60761 .43398 m .61742 .42233 L .64756 .77639 L p .23 .037 .399 r
F P
0 g
s
.6649 .41432 m .67859 .42205 L .66852 .4337 L p .694 .677 .829 r
F P
0 g
s
.66852 .4337 m .65486 .42604 L .6649 .41432 L p .694 .677 .829 r
F P
0 g
s
.69349 .78039 m .65486 .42604 L .66852 .4337 L p .836 .477 .374 r
F P
0 g
s
.66852 .4337 m .71013 .78866 L .69349 .78039 L p .836 .477 .374 r
F P
0 g
s
.7227 .77609 m .71013 .78866 L .66852 .4337 L p .256 .065 .418 r
F P
0 g
s
.66852 .4337 m .67859 .42205 L .7227 .77609 L p .256 .065 .418 r
F P
0 g
s
.69508 .79501 m .65486 .42604 L .66852 .4337 L p .836 .477 .374 r
F P
0 g
s
.66852 .4337 m .71185 .80329 L .69508 .79501 L p .836 .477 .374 r
F P
0 g
s
.72452 .7907 m .71185 .80329 L .66852 .4337 L p .256 .065 .418 r
F P
0 g
s
.66852 .4337 m .67859 .42205 L .72452 .7907 L p .256 .065 .418 r
F P
0 g
s
.72623 .41404 m .73976 .42177 L .72945 .43343 L p .694 .677 .829 r
F P
0 g
s
.72945 .43343 m .71595 .42576 L .72623 .41404 L p .694 .677 .829 r
F P
0 g
s
.77068 .79471 m .71595 .42576 L .72945 .43343 L p .837 .472 .362 r
F P
0 g
s
.72945 .43343 m .7872 .80299 L .77068 .79471 L p .837 .472 .362 r
F P
0 g
s
.79785 .77579 m .81419 .78409 L .80122 .79658 L p .682 .709 .868 r
F P
0 g
s
.80122 .79658 m .78492 .78836 L .79785 .77579 L p .682 .709 .868 r
F P
0 g
s
.80025 .7904 m .7872 .80299 L .72945 .43343 L p .28 .091 .436 r
F P
0 g
s
.72945 .43343 m .73976 .42177 L .80025 .7904 L p .28 .091 .436 r
F P
0 g
s
.77068 .79471 m .71595 .42576 L .72945 .43343 L p .837 .472 .362 r
F P
0 g
s
.72945 .43343 m .7872 .80299 L .77068 .79471 L p .837 .472 .362 r
F P
0 g
s
.79785 .77579 m .78492 .78836 L .72945 .43343 L p .28 .091 .436 r
F P
0 g
s
.72945 .43343 m .73976 .42177 L .79785 .77579 L p .28 .091 .436 r
F P
0 g
s
.13647 .41282 m .15156 .42055 L .14359 .43222 L p .694 .677 .829 r
F P
0 g
s
.14359 .43222 m .12854 .42455 L .13647 .41282 L p .694 .677 .829 r
F P
0 g
s
.0504 .76439 m .12854 .42455 L .14359 .43222 L p .825 .508 .454 r
F P
0 g
s
.14359 .43222 m .06899 .77265 L .0504 .76439 L p .825 .508 .454 r
F P
0 g
s
.07834 .76009 m .06899 .77265 L .14359 .43222 L p 0 0 .156 r
F P
0 g
s
.14359 .43222 m .15156 .42055 L .07834 .76009 L p 0 0 .156 r
F P
0 g
s
.04709 .77878 m .12854 .42455 L .14359 .43222 L p .825 .508 .454 r
F P
0 g
s
.14359 .43222 m .06583 .78706 L .04709 .77878 L p .825 .508 .454 r
F P
0 g
s
.07834 .76009 m .06899 .77265 L .14359 .43222 L p 0 0 .156 r
F P
0 g
s
.14359 .43222 m .15156 .42055 L .07834 .76009 L p 0 0 .156 r
F P
0 g
s
.19778 .41254 m .21271 .42028 L .2045 .43194 L p .694 .677 .829 r
F P
0 g
s
.2045 .43194 m .18961 .42427 L .19778 .41254 L p .694 .677 .829 r
F P
0 g
s
.1302 .73595 m .18961 .42427 L .2045 .43194 L p .826 .506 .447 r
F P
0 g
s
.2045 .43194 m .14826 .74418 L .1302 .73595 L p .826 .506 .447 r
F P
0 g
s
.15785 .73167 m .14826 .74418 L .2045 .43194 L p 0 0 .2 r
F P
0 g
s
.2045 .43194 m .21271 .42028 L .15785 .73167 L p 0 0 .2 r
F P
0 g
s
.11931 .7931 m .18961 .42427 L .2045 .43194 L p .826 .506 .447 r
F P
0 g
s
.2045 .43194 m .13796 .80139 L .11931 .7931 L p .826 .506 .447 r
F P
0 g
s
.14779 .78878 m .13796 .80139 L .2045 .43194 L p 0 0 .2 r
F P
0 g
s
.2045 .43194 m .21271 .42028 L .14779 .78878 L p 0 0 .2 r
F P
0 g
s
.25911 .41226 m .27388 .42 L .26543 .43167 L p .694 .677 .829 r
F P
0 g
s
.26543 .43167 m .25069 .42399 L .25911 .41226 L p .694 .677 .829 r
F P
0 g
s
.19711 .77818 m .21536 .78647 L .20532 .79893 L p .682 .709 .868 r
F P
0 g
s
.1949 .7928 m .25069 .42399 L .26543 .43167 L p .828 .503 .439 r
F P
0 g
s
.26543 .43167 m .2133 .80109 L .1949 .7928 L p .828 .503 .439 r
F P
0 g
s
.22351 .78848 m .2133 .80109 L .26543 .43167 L p .02 0 .24 r
F P
0 g
s
.26543 .43167 m .27388 .42 L .22351 .78848 L p .02 0 .24 r
F P
0 g
s
.19711 .77818 m .25069 .42399 L .26543 .43167 L p .828 .503 .439 r
F P
0 g
s
.26543 .43167 m .21536 .78647 L .19711 .77818 L p .828 .503 .439 r
F P
0 g
s
.22351 .78848 m .2133 .80109 L .26543 .43167 L p .02 0 .24 r
F P
0 g
s
.26543 .43167 m .27388 .42 L .22351 .78848 L p .02 0 .24 r
F P
0 g
s
.32045 .41198 m .33506 .41972 L .32636 .43139 L p .694 .677 .829 r
F P
0 g
s
.32636 .43139 m .31178 .42371 L .32045 .41198 L p .694 .677 .829 r
F P
0 g
s
.26994 .72046 m .28723 .72858 L .27726 .74082 L p .685 .702 .86 r
F P
0 g
s
.27726 .74082 m .26002 .73277 L .26994 .72046 L p .685 .702 .86 r
F P
0 g
s
.2642 .78043 m .28153 .78838 L .27157 .80036 L p .684 .705 .863 r
F P
0 g
s
.27996 .70804 m .29729 .71624 L .28723 .72858 L p .685 .702 .86 r
F P
0 g
s
.28723 .72858 m .26994 .72046 L .27996 .70804 L p .685 .702 .86 r
F P
0 g
s
.2567 .76019 m .2742 .76827 L .2642 .78043 L p .684 .705 .863 r
F P
0 g
s
.2705 .7925 m .31178 .42371 L .32636 .43139 L p .829 .499 .43 r
F P
0 g
s
.28875 .80819 m .27157 .80036 L .28153 .78838 L p .684 .705 .863 r
F P
0 g
s
.32636 .43139 m .28866 .8008 L .2705 .7925 L p .829 .499 .43 r
F P
0 g
s
.29925 .78818 m .28866 .8008 L .32636 .43139 L p .066 0 .276 r
F P
0 g
s
.32636 .43139 m .33506 .41972 L .29925 .78818 L p .066 0 .276 r
F P
0 g
s
.27996 .70804 m .31178 .42371 L .32636 .43139 L p .829 .499 .43 r
F P
0 g
s
.32636 .43139 m .29729 .71624 L .27996 .70804 L p .829 .499 .43 r
F P
0 g
s
.29925 .78818 m .28866 .8008 L .32636 .43139 L p .066 0 .276 r
F P
0 g
s
.32636 .43139 m .33506 .41972 L .29925 .78818 L p .066 0 .276 r
F P
0 g
s
.3818 .4117 m .39625 .41944 L .3873 .43112 L p .694 .677 .829 r
F P
0 g
s
.3873 .43112 m .37289 .42344 L .3818 .4117 L p .694 .677 .829 r
F P
0 g
s
.34823 .7632 m .37289 .42344 L .3873 .43112 L p .831 .496 .421 r
F P
0 g
s
.3873 .43112 m .36587 .77146 L .34823 .7632 L p .831 .496 .421 r
F P
0 g
s
.37668 .75889 m .36587 .77146 L .3873 .43112 L p .108 0 .308 r
F P
0 g
s
.3873 .43112 m .39625 .41944 L .37668 .75889 L p .108 0 .308 r
F P
0 g
s
.34719 .77759 m .37289 .42344 L .3873 .43112 L p .831 .496 .421 r
F P
0 g
s
.3873 .43112 m .36497 .78587 L .34719 .77759 L p .831 .496 .421 r
F P
0 g
s
.37668 .75889 m .36587 .77146 L .3873 .43112 L p .108 0 .308 r
F P
0 g
s
.3873 .43112 m .39625 .41944 L .37668 .75889 L p .108 0 .308 r
F P
0 g
s
.44316 .41142 m .45745 .41916 L .44826 .43084 L p .694 .677 .829 r
F P
0 g
s
.44826 .43084 m .43401 .42316 L .44316 .41142 L p .694 .677 .829 r
F P
0 g
s
.42177 .7919 m .43401 .42316 L .44826 .43084 L p .832 .492 .412 r
F P
0 g
s
.44826 .43084 m .43944 .8002 L .42177 .7919 L p .832 .492 .412 r
F P
0 g
s
.45939 .64624 m .44331 .6382 L .45371 .62591 L p .688 .695 .852 r
F P
0 g
s
.46519 .76861 m .44912 .76093 L .45955 .74918 L p .686 .7 .857 r
F P
0 g
s
.44853 .68353 m .4647 .69149 L .45426 .70347 L p .687 .698 .854 r
F P
0 g
s
.44301 .65065 m .45921 .65871 L .44879 .67085 L p .687 .696 .853 r
F P
0 g
s
.44333 .74138 m .45955 .74918 L .44912 .76093 L p .686 .7 .857 r
F P
0 g
s
.4647 .69149 m .44853 .68353 L .45902 .67136 L p .687 .698 .854 r
F P
0 g
s
.45078 .78758 m .43944 .8002 L .44826 .43084 L p .145 0 .337 r
F P
0 g
s
.44826 .43084 m .45745 .41916 L .45078 .78758 L p .145 0 .337 r
F P
0 g
s
.42177 .7919 m .43401 .42316 L .44826 .43084 L p .832 .492 .412 r
F P
0 g
s
.44826 .43084 m .43944 .8002 L .42177 .7919 L p .832 .492 .412 r
F P
0 g
s
.45371 .62591 m .44331 .6382 L .44826 .43084 L p .145 0 .337 r
F P
0 g
s
.44826 .43084 m .45745 .41916 L .45371 .62591 L p .145 0 .337 r
F P
0 g
s
.50454 .41114 m .51867 .41889 L .50923 .43057 L p .694 .677 .829 r
F P
0 g
s
.50923 .43057 m .49513 .42288 L .50454 .41114 L p .694 .677 .829 r
F P
0 g
s
.49635 .61756 m .5122 .62563 L .50166 .63779 L p .688 .694 .85 r
F P
0 g
s
.49642 .62982 m .49513 .42288 L .50923 .43057 L p .833 .488 .402 r
F P
0 g
s
.50923 .43057 m .51239 .63791 L .49642 .62982 L p .833 .488 .402 r
F P
0 g
s
.5231 .62561 m .51239 .63791 L .50923 .43057 L p .18 0 .362 r
F P
0 g
s
.50923 .43057 m .51867 .41889 L .5231 .62561 L p .18 0 .362 r
F P
0 g
s
.49635 .61756 m .49513 .42288 L .50923 .43057 L p .833 .488 .402 r
F P
0 g
s
.50923 .43057 m .5122 .62563 L .49635 .61756 L p .833 .488 .402 r
F P
0 g
s
.5231 .62561 m .51239 .63791 L .50923 .43057 L p .18 0 .362 r
F P
0 g
s
.50923 .43057 m .51867 .41889 L .5231 .62561 L p .18 0 .362 r
F P
0 g
s
.56592 .41086 m .57989 .41861 L .57021 .43029 L p .694 .677 .829 r
F P
0 g
s
.57021 .43029 m .55627 .42261 L .56592 .41086 L p .694 .677 .829 r
F P
0 g
s
.55581 .74487 m .57166 .75264 L .56074 .76436 L p .686 .7 .857 r
F P
0 g
s
.56679 .73297 m .58269 .74082 L .57166 .75264 L p .686 .7 .857 r
F P
0 g
s
.57166 .75264 m .55581 .74487 L .56679 .73297 L p .686 .7 .857 r
F P
0 g
s
.55582 .66689 m .57176 .67495 L .56078 .68708 L p .687 .698 .854 r
F P
0 g
s
.58269 .74082 m .56679 .73297 L .57788 .72097 L p .686 .7 .857 r
F P
0 g
s
.56687 .65457 m .58285 .6627 L .57176 .67495 L p .687 .698 .854 r
F P
0 g
s
.57176 .67495 m .55582 .66689 L .56687 .65457 L p .687 .698 .854 r
F P
0 g
s
.57788 .72097 m .56185 .713 L .573 .70081 L p .686 .7 .857 r
F P
0 g
s
.57311 .7913 m .55627 .42261 L .57021 .43029 L p .835 .484 .391 r
F P
0 g
s
.59037 .81485 m .57416 .80706 L .58552 .79515 L p .684 .705 .863 r
F P
0 g
s
.57021 .43029 m .5903 .7996 L .57311 .7913 L p .835 .484 .391 r
F P
0 g
s
.60238 .78697 m .5903 .7996 L .57021 .43029 L p .211 .017 .385 r
F P
0 g
s
.57021 .43029 m .57989 .41861 L .60238 .78697 L p .211 .017 .385 r
F P
0 g
s
.56687 .65457 m .55627 .42261 L .57021 .43029 L p .835 .484 .391 r
F P
0 g
s
.57021 .43029 m .58285 .6627 L .56687 .65457 L p .835 .484 .391 r
F P
0 g
s
.60238 .78697 m .5903 .7996 L .57021 .43029 L p .211 .017 .385 r
F P
0 g
s
.57021 .43029 m .57989 .41861 L .60238 .78697 L p .211 .017 .385 r
F P
0 g
s
.62732 .41058 m .64113 .41833 L .6312 .43001 L p .694 .677 .829 r
F P
0 g
s
.6312 .43001 m .61742 .42233 L .62732 .41058 L p .694 .677 .829 r
F P
0 g
s
.64634 .762 m .61742 .42233 L .6312 .43001 L p .836 .479 .38 r
F P
0 g
s
.6312 .43001 m .66303 .77028 L .64634 .762 L p .836 .479 .38 r
F P
0 g
s
.67529 .75769 m .66303 .77028 L .6312 .43001 L p .239 .047 .406 r
F P
0 g
s
.6312 .43001 m .64113 .41833 L .67529 .75769 L p .239 .047 .406 r
F P
0 g
s
.64756 .77639 m .61742 .42233 L .6312 .43001 L p .836 .479 .38 r
F P
0 g
s
.6312 .43001 m .66438 .78468 L .64756 .77639 L p .836 .479 .38 r
F P
0 g
s
.67529 .75769 m .66303 .77028 L .6312 .43001 L p .239 .047 .406 r
F P
0 g
s
.6312 .43001 m .64113 .41833 L .67529 .75769 L p .239 .047 .406 r
F P
0 g
s
.68873 .4103 m .70238 .41805 L .69221 .42974 L p .694 .677 .829 r
F P
0 g
s
.69221 .42974 m .67859 .42205 L .68873 .4103 L p .694 .677 .829 r
F P
0 g
s
.7174 .73357 m .67859 .42205 L .69221 .42974 L p .837 .474 .368 r
F P
0 g
s
.69221 .42974 m .73363 .74181 L .7174 .73357 L p .837 .474 .368 r
F P
0 g
s
.74604 .72928 m .73363 .74181 L .69221 .42974 L p .264 .074 .424 r
F P
0 g
s
.69221 .42974 m .70238 .41805 L .74604 .72928 L p .264 .074 .424 r
F P
0 g
s
.72452 .7907 m .67859 .42205 L .69221 .42974 L p .837 .474 .368 r
F P
0 g
s
.69221 .42974 m .74122 .79901 L .72452 .7907 L p .837 .474 .368 r
F P
0 g
s
.75406 .78637 m .74122 .79901 L .69221 .42974 L p .264 .074 .424 r
F P
0 g
s
.69221 .42974 m .70238 .41805 L .75406 .78637 L p .264 .074 .424 r
F P
0 g
s
.75015 .41002 m .76364 .41777 L .75322 .42946 L p .694 .677 .829 r
F P
0 g
s
.75322 .42946 m .73976 .42177 L .75015 .41002 L p .694 .677 .829 r
F P
0 g
s
.80025 .7904 m .73976 .42177 L .75322 .42946 L p .838 .469 .355 r
F P
0 g
s
.75322 .42946 m .8167 .79871 L .80025 .7904 L p .838 .469 .355 r
F P
0 g
s
.82992 .78607 m .8167 .79871 L .75322 .42946 L p .288 .099 .441 r
F P
0 g
s
.75322 .42946 m .76364 .41777 L .82992 .78607 L p .288 .099 .441 r
F P
0 g
s
.79785 .77579 m .73976 .42177 L .75322 .42946 L p .838 .469 .355 r
F P
0 g
s
.75322 .42946 m .81419 .78409 L .79785 .77579 L p .838 .469 .355 r
F P
0 g
s
.82992 .78607 m .8167 .79871 L .75322 .42946 L p .288 .099 .441 r
F P
0 g
s
.75322 .42946 m .76364 .41777 L .82992 .78607 L p .288 .099 .441 r
F P
0 g
s
.15959 .40879 m .17464 .41655 L .16657 .42825 L p .694 .677 .829 r
F P
0 g
s
.16657 .42825 m .15156 .42055 L .15959 .40879 L p .694 .677 .829 r
F P
0 g
s
.07834 .76009 m .15156 .42055 L .16657 .42825 L p .825 .507 .451 r
F P
0 g
s
.16657 .42825 m .09687 .76838 L .07834 .76009 L p .825 .507 .451 r
F P
0 g
s
.10637 .75578 m .09687 .76838 L .16657 .42825 L p 0 0 .171 r
F P
0 g
s
.16657 .42825 m .17464 .41655 L .10637 .75578 L p 0 0 .171 r
F P
0 g
s
.07834 .76009 m .15156 .42055 L .16657 .42825 L p .825 .507 .451 r
F P
0 g
s
.16657 .42825 m .09687 .76838 L .07834 .76009 L p .825 .507 .451 r
F P
0 g
s
.10347 .77015 m .09391 .78278 L .16657 .42825 L p 0 0 .171 r
F P
0 g
s
.16657 .42825 m .17464 .41655 L .10347 .77015 L p 0 0 .171 r
F P
0 g
s
.22099 .40851 m .23588 .41627 L .22757 .42797 L p .694 .677 .829 r
F P
0 g
s
.22757 .42797 m .21271 .42028 L .22099 .40851 L p .694 .677 .829 r
F P
0 g
s
.15036 .77417 m .21271 .42028 L .22757 .42797 L p .827 .504 .443 r
F P
0 g
s
.22757 .42797 m .1688 .78248 L .15036 .77417 L p .827 .504 .443 r
F P
0 g
s
.17873 .76985 m .1688 .78248 L .22757 .42797 L p 0 0 .214 r
F P
0 g
s
.22757 .42797 m .23588 .41627 L .17873 .76985 L p 0 0 .214 r
F P
0 g
s
.14779 .78878 m .21271 .42028 L .22757 .42797 L p .827 .504 .443 r
F P
0 g
s
.22757 .42797 m .16638 .7971 L .14779 .78878 L p .827 .504 .443 r
F P
0 g
s
.17637 .78445 m .16638 .7971 L .22757 .42797 L p 0 0 .214 r
F P
0 g
s
.22757 .42797 m .23588 .41627 L .17637 .78445 L p 0 0 .214 r
F P
0 g
s
.2824 .40823 m .29713 .41599 L .28857 .4277 L p .694 .677 .829 r
F P
0 g
s
.28857 .4277 m .27388 .42 L .2824 .40823 L p .694 .677 .829 r
F P
0 g
s
.22351 .78848 m .27388 .42 L .28857 .4277 L p .828 .501 .435 r
F P
0 g
s
.28857 .4277 m .24185 .7968 L .22351 .78848 L p .828 .501 .435 r
F P
0 g
s
.2715 .70708 m .25424 .69892 L .26414 .68645 L p .686 .701 .859 r
F P
0 g
s
.25255 .71229 m .26994 .72046 L .26002 .73277 L p .685 .702 .86 r
F P
0 g
s
.24675 .77243 m .2642 .78043 L .25428 .79248 L p .684 .705 .863 r
F P
0 g
s
.2642 .78043 m .24675 .77243 L .2567 .76019 L p .684 .705 .863 r
F P
0 g
s
.25222 .78414 m .24185 .7968 L .28857 .4277 L p .036 0 .253 r
F P
0 g
s
.28857 .4277 m .29713 .41599 L .25222 .78414 L p .036 0 .253 r
F P
0 g
s
.22351 .78848 m .27388 .42 L .28857 .4277 L p .828 .501 .435 r
F P
0 g
s
.28857 .4277 m .24185 .7968 L .22351 .78848 L p .828 .501 .435 r
F P
0 g
s
.26414 .68645 m .25424 .69892 L .28857 .4277 L p .036 0 .253 r
F P
0 g
s
.28857 .4277 m .29713 .41599 L .26414 .68645 L p .036 0 .253 r
F P
0 g
s
.34383 .40795 m .3584 .41572 L .34959 .42742 L p .694 .677 .829 r
F P
0 g
s
.34959 .42742 m .33506 .41972 L .34383 .40795 L p .694 .677 .829 r
F P
0 g
s
.30067 .77357 m .33506 .41972 L .34959 .42742 L p .83 .498 .426 r
F P
0 g
s
.34959 .42742 m .31862 .78188 L .30067 .77357 L p .83 .498 .426 r
F P
0 g
s
.32929 .76925 m .31862 .78188 L .34959 .42742 L p .08 0 .287 r
F P
0 g
s
.34959 .42742 m .3584 .41572 L .32929 .76925 L p .08 0 .287 r
F P
0 g
s
.29925 .78818 m .33506 .41972 L .34959 .42742 L p .83 .498 .426 r
F P
0 g
s
.34959 .42742 m .31735 .7965 L .29925 .78818 L p .83 .498 .426 r
F P
0 g
s
.32809 .78384 m .31735 .7965 L .34959 .42742 L p .08 0 .287 r
F P
0 g
s
.34959 .42742 m .3584 .41572 L .32809 .78384 L p .08 0 .287 r
F P
0 g
s
.40527 .40767 m .41967 .41544 L .41062 .42714 L p .694 .677 .829 r
F P
0 g
s
.41062 .42714 m .39625 .41944 L .40527 .40767 L p .694 .677 .829 r
F P
0 g
s
.37668 .75889 m .39625 .41944 L .41062 .42714 L p .831 .494 .417 r
F P
0 g
s
.41062 .42714 m .39426 .76719 L .37668 .75889 L p .831 .494 .417 r
F P
0 g
s
.40522 .75457 m .39426 .76719 L .41062 .42714 L p .121 0 .318 r
F P
0 g
s
.41062 .42714 m .41967 .41544 L .40522 .75457 L p .121 0 .318 r
F P
0 g
s
.37668 .75889 m .39625 .41944 L .41062 .42714 L p .831 .494 .417 r
F P
0 g
s
.41062 .42714 m .39426 .76719 L .37668 .75889 L p .831 .494 .417 r
F P
0 g
s
.4046 .76895 m .39356 .78159 L .41062 .42714 L p .121 0 .318 r
F P
0 g
s
.41062 .42714 m .41967 .41544 L .4046 .76895 L p .121 0 .318 r
F P
0 g
s
.46672 .40739 m .48096 .41516 L .47167 .42687 L p .694 .677 .829 r
F P
0 g
s
.47167 .42687 m .45745 .41916 L .46672 .40739 L p .694 .677 .829 r
F P
0 g
s
.45393 .61366 m .45745 .41916 L .47167 .42687 L p .833 .49 .407 r
F P
0 g
s
.47167 .42687 m .46994 .62175 L .45393 .61366 L p .833 .49 .407 r
F P
0 g
s
.48039 .60945 m .46994 .62175 L .47167 .42687 L p .157 0 .346 r
F P
0 g
s
.47167 .42687 m .48096 .41516 L .48039 .60945 L p .157 0 .346 r
F P
0 g
s
.45371 .62591 m .45745 .41916 L .47167 .42687 L p .833 .49 .407 r
F P
0 g
s
.47167 .42687 m .46983 .63402 L .45371 .62591 L p .833 .49 .407 r
F P
0 g
s
.48036 .62169 m .46983 .63402 L .47167 .42687 L p .157 0 .346 r
F P
0 g
s
.47167 .42687 m .48096 .41516 L .48036 .62169 L p .157 0 .346 r
F P
0 g
s
.52818 .40711 m .54226 .41488 L .53272 .42659 L p .694 .677 .829 r
F P
0 g
s
.53272 .42659 m .51867 .41889 L .52818 .40711 L p .694 .677 .829 r
F P
0 g
s
.5231 .62561 m .51867 .41889 L .53272 .42659 L p .834 .486 .397 r
F P
0 g
s
.53272 .42659 m .53902 .63373 L .5231 .62561 L p .834 .486 .397 r
F P
0 g
s
.54986 .62139 m .53902 .63373 L .53272 .42659 L p .19 0 .37 r
F P
0 g
s
.53272 .42659 m .54226 .41488 L .54986 .62139 L p .19 0 .37 r
F P
0 g
s
.5231 .62561 m .51867 .41889 L .53272 .42659 L p .834 .486 .397 r
F P
0 g
s
.53272 .42659 m .53902 .63373 L .5231 .62561 L p .834 .486 .397 r
F P
0 g
s
.55032 .6338 m .53939 .64617 L .53272 .42659 L p .19 0 .37 r
F P
0 g
s
.53272 .42659 m .54226 .41488 L .55032 .6338 L p .19 0 .37 r
F P
0 g
s
.58965 .40683 m .60357 .4146 L .59379 .42631 L p .694 .677 .829 r
F P
0 g
s
.59379 .42631 m .57989 .41861 L .58965 .40683 L p .694 .677 .829 r
F P
0 g
s
.60149 .77237 m .57989 .41861 L .59379 .42631 L p .835 .482 .386 r
F P
0 g
s
.59379 .42631 m .61848 .78069 L .60149 .77237 L p .835 .482 .386 r
F P
0 g
s
.63064 .76804 m .61848 .78069 L .59379 .42631 L p .22 .027 .392 r
F P
0 g
s
.59379 .42631 m .60357 .4146 L .63064 .76804 L p .22 .027 .392 r
F P
0 g
s
.60238 .78697 m .57989 .41861 L .59379 .42631 L p .835 .482 .386 r
F P
0 g
s
.59379 .42631 m .6195 .79531 L .60238 .78697 L p .835 .482 .386 r
F P
0 g
s
.63175 .78264 m .6195 .79531 L .59379 .42631 L p .22 .027 .392 r
F P
0 g
s
.59379 .42631 m .60357 .4146 L .63175 .78264 L p .22 .027 .392 r
F P
0 g
s
.65113 .40655 m .6649 .41432 L .65486 .42604 L p .694 .677 .829 r
F P
0 g
s
.65486 .42604 m .64113 .41833 L .65113 .40655 L p .694 .677 .829 r
F P
0 g
s
.67529 .75769 m .64113 .41833 L .65486 .42604 L p .836 .477 .374 r
F P
0 g
s
.65486 .42604 m .69192 .766 L .67529 .75769 L p .836 .477 .374 r
F P
0 g
s
.70434 .75337 m .69192 .766 L .65486 .42604 L p .248 .056 .412 r
F P
0 g
s
.65486 .42604 m .6649 .41432 L .70434 .75337 L p .248 .056 .412 r
F P
0 g
s
.67529 .75769 m .64113 .41833 L .65486 .42604 L p .836 .477 .374 r
F P
0 g
s
.65486 .42604 m .69192 .766 L .67529 .75769 L p .836 .477 .374 r
F P
0 g
s
.70602 .76774 m .69349 .78039 L .65486 .42604 L p .248 .056 .412 r
F P
0 g
s
.65486 .42604 m .6649 .41432 L .70602 .76774 L p .248 .056 .412 r
F P
0 g
s
.71263 .40627 m .72623 .41404 L .71595 .42576 L p .694 .677 .829 r
F P
0 g
s
.71595 .42576 m .70238 .41805 L .71263 .40627 L p .694 .677 .829 r
F P
0 g
s
.75201 .77177 m .70238 .41805 L .71595 .42576 L p .837 .472 .362 r
F P
0 g
s
.71595 .42576 m .76852 .78009 L .75201 .77177 L p .837 .472 .362 r
F P
0 g
s
.78141 .76744 m .76852 .78009 L .71595 .42576 L p .272 .082 .43 r
F P
0 g
s
.71595 .42576 m .72623 .41404 L .78141 .76744 L p .272 .082 .43 r
F P
0 g
s
.75406 .78637 m .70238 .41805 L .71595 .42576 L p .837 .472 .362 r
F P
0 g
s
.71595 .42576 m .77068 .79471 L .75406 .78637 L p .837 .472 .362 r
F P
0 g
s
.78369 .78203 m .77068 .79471 L .71595 .42576 L p .272 .082 .43 r
F P
0 g
s
.71595 .42576 m .72623 .41404 L .78369 .78203 L p .272 .082 .43 r
F P
0 g
s
.77414 .40599 m .78758 .41376 L .77705 .42548 L p .694 .677 .829 r
F P
0 g
s
.77705 .42548 m .76364 .41777 L .77414 .40599 L p .694 .677 .829 r
F P
0 g
s
.82992 .78607 m .76364 .41777 L .77705 .42548 L p .838 .466 .348 r
F P
0 g
s
.77705 .42548 m .8463 .79441 L .82992 .78607 L p .838 .466 .348 r
F P
0 g
s
.85969 .78173 m .8463 .79441 L .77705 .42548 L p .295 .107 .446 r
F P
0 g
s
.77705 .42548 m .78758 .41376 L .85969 .78173 L p .295 .107 .446 r
F P
0 g
s
.82992 .78607 m .76364 .41777 L .77705 .42548 L p .838 .466 .348 r
F P
0 g
s
.77705 .42548 m .8463 .79441 L .82992 .78607 L p .838 .466 .348 r
F P
0 g
s
.05969 .75175 m .0504 .76439 L .12854 .42455 L p 0 0 .14 r
F P
0 g
s
.12854 .42455 m .13647 .41282 L .05969 .75175 L p 0 0 .14 r
F P
0 g
s
.18277 .40476 m .19778 .41254 L .18961 .42427 L p .694 .677 .829 r
F P
0 g
s
.18961 .42427 m .17464 .41655 L .18277 .40476 L p .694 .677 .829 r
F P
0 g
s
.11202 .72767 m .17464 .41655 L .18961 .42427 L p .826 .506 .447 r
F P
0 g
s
.18961 .42427 m .1302 .73595 L .11202 .72767 L p .826 .506 .447 r
F P
0 g
s
.13973 .72336 m .1302 .73595 L .18961 .42427 L p 0 0 .186 r
F P
0 g
s
.18961 .42427 m .19778 .41254 L .13973 .72336 L p 0 0 .186 r
F P
0 g
s
.10347 .77015 m .17464 .41655 L .18961 .42427 L p .826 .506 .447 r
F P
0 g
s
.18961 .42427 m .12209 .77848 L .10347 .77015 L p .826 .506 .447 r
F P
0 g
s
.13973 .72336 m .1302 .73595 L .18961 .42427 L p 0 0 .186 r
F P
0 g
s
.18961 .42427 m .19778 .41254 L .13973 .72336 L p 0 0 .186 r
F P
0 g
s
.24426 .40448 m .25911 .41226 L .25069 .42399 L p .694 .677 .829 r
F P
0 g
s
.25069 .42399 m .23588 .41627 L .24426 .40448 L p .694 .677 .829 r
F P
0 g
s
.18105 .75548 m .23588 .41627 L .25069 .42399 L p .828 .503 .439 r
F P
0 g
s
.25069 .42399 m .19928 .76379 L .18105 .75548 L p .828 .503 .439 r
F P
0 g
s
.2093 .75115 m .19928 .76379 L .25069 .42399 L p .004 0 .228 r
F P
0 g
s
.25069 .42399 m .25911 .41226 L .2093 .75115 L p .004 0 .228 r
F P
0 g
s
.17637 .78445 m .23588 .41627 L .25069 .42399 L p .828 .503 .439 r
F P
0 g
s
.25069 .42399 m .1949 .7928 L .17637 .78445 L p .828 .503 .439 r
F P
0 g
s
.20505 .7801 m .1949 .7928 L .25069 .42399 L p .004 0 .228 r
F P
0 g
s
.25069 .42399 m .25911 .41226 L .20505 .7801 L p .004 0 .228 r
F P
0 g
s
.30576 .4042 m .32045 .41198 L .31178 .42371 L p .694 .677 .829 r
F P
0 g
s
.31178 .42371 m .29713 .41599 L .30576 .4042 L p .694 .677 .829 r
F P
0 g
s
.26414 .68645 m .28145 .69468 L .2715 .70708 L p .686 .701 .859 r
F P
0 g
s
.25222 .78414 m .29713 .41599 L .31178 .42371 L p .829 .499 .43 r
F P
0 g
s
.27157 .80036 m .25428 .79248 L .2642 .78043 L p .684 .705 .863 r
F P
0 g
s
.31178 .42371 m .2705 .7925 L .25222 .78414 L p .829 .499 .43 r
F P
0 g
s
.28103 .7798 m .2705 .7925 L .31178 .42371 L p .051 0 .265 r
F P
0 g
s
.31178 .42371 m .32045 .41198 L .28103 .7798 L p .051 0 .265 r
F P
0 g
s
.26414 .68645 m .29713 .41599 L .31178 .42371 L p .829 .499 .43 r
F P
0 g
s
.31178 .42371 m .28145 .69468 L .26414 .68645 L p .829 .499 .43 r
F P
0 g
s
.28103 .7798 m .2705 .7925 L .31178 .42371 L p .051 0 .265 r
F P
0 g
s
.31178 .42371 m .32045 .41198 L .28103 .7798 L p .051 0 .265 r
F P
0 g
s
.36727 .40392 m .3818 .4117 L .37289 .42344 L p .694 .677 .829 r
F P
0 g
s
.37289 .42344 m .3584 .41572 L .36727 .40392 L p .694 .677 .829 r
F P
0 g
s
.32809 .78384 m .3584 .41572 L .37289 .42344 L p .831 .496 .421 r
F P
0 g
s
.37289 .42344 m .34613 .7922 L .32809 .78384 L p .831 .496 .421 r
F P
0 g
s
.36587 .77146 m .34823 .7632 L .35898 .75054 L p .683 .708 .867 r
F P
0 g
s
.34719 .77759 m .36497 .78587 L .35419 .79835 L p .682 .709 .868 r
F P
0 g
s
.35703 .77949 m .34613 .7922 L .37289 .42344 L p .094 0 .298 r
F P
0 g
s
.37289 .42344 m .3818 .4117 L .35703 .77949 L p .094 0 .298 r
F P
0 g
s
.32809 .78384 m .3584 .41572 L .37289 .42344 L p .831 .496 .421 r
F P
0 g
s
.37289 .42344 m .34613 .7922 L .32809 .78384 L p .831 .496 .421 r
F P
0 g
s
.35898 .75054 m .34823 .7632 L .37289 .42344 L p .094 0 .298 r
F P
0 g
s
.37289 .42344 m .3818 .4117 L .35898 .75054 L p .094 0 .298 r
F P
0 g
s
.4288 .40364 m .44316 .41142 L .43401 .42316 L p .694 .677 .829 r
F P
0 g
s
.43401 .42316 m .41967 .41544 L .4288 .40364 L p .694 .677 .829 r
F P
0 g
s
.4046 .76895 m .42226 .77729 L .41116 .78985 L p .682 .709 .868 r
F P
0 g
s
.41116 .78985 m .39356 .78159 L .4046 .76895 L p .682 .709 .868 r
F P
0 g
s
.40398 .78354 m .41967 .41544 L .43401 .42316 L p .832 .492 .412 r
F P
0 g
s
.43401 .42316 m .42177 .7919 L .40398 .78354 L p .832 .492 .412 r
F P
0 g
s
.43305 .77919 m .42177 .7919 L .43401 .42316 L p .133 0 .328 r
F P
0 g
s
.43401 .42316 m .44316 .41142 L .43305 .77919 L p .133 0 .328 r
F P
0 g
s
.4046 .76895 m .41967 .41544 L .43401 .42316 L p .832 .492 .412 r
F P
0 g
s
.43401 .42316 m .42226 .77729 L .4046 .76895 L p .832 .492 .412 r
F P
0 g
s
.43305 .77919 m .42177 .7919 L .43401 .42316 L p .133 0 .328 r
F P
0 g
s
.43401 .42316 m .44316 .41142 L .43305 .77919 L p .133 0 .328 r
F P
0 g
s
.49033 .40336 m .50454 .41114 L .49513 .42288 L p .694 .677 .829 r
F P
0 g
s
.49513 .42288 m .48096 .41516 L .49033 .40336 L p .694 .677 .829 r
F P
0 g
s
.48043 .59738 m .48096 .41516 L .49513 .42288 L p .833 .488 .402 r
F P
0 g
s
.49513 .42288 m .49627 .60548 L .48043 .59738 L p .833 .488 .402 r
F P
0 g
s
.50679 .59317 m .49627 .60548 L .49513 .42288 L p .169 0 .354 r
F P
0 g
s
.49513 .42288 m .50454 .41114 L .50679 .59317 L p .169 0 .354 r
F P
0 g
s
.48036 .62169 m .48096 .41516 L .49513 .42288 L p .833 .488 .402 r
F P
0 g
s
.49513 .42288 m .49642 .62982 L .48036 .62169 L p .833 .488 .402 r
F P
0 g
s
.50709 .61745 m .49642 .62982 L .49513 .42288 L p .169 0 .354 r
F P
0 g
s
.49513 .42288 m .50454 .41114 L .50709 .61745 L p .169 0 .354 r
F P
0 g
s
.55188 .40307 m .56592 .41086 L .55627 .42261 L p .694 .677 .829 r
F P
0 g
s
.55627 .42261 m .54226 .41488 L .55188 .40307 L p .694 .677 .829 r
F P
0 g
s
.54492 .75665 m .56074 .76436 L .54991 .77597 L p .686 .7 .857 r
F P
0 g
s
.56074 .76436 m .54492 .75665 L .55581 .74487 L p .686 .7 .857 r
F P
0 g
s
.56078 .68708 m .54487 .6791 L .55582 .66689 L p .687 .698 .854 r
F P
0 g
s
.55032 .6338 m .56629 .64196 L .55532 .65425 L p .687 .696 .853 r
F P
0 g
s
.55532 .65425 m .53939 .64617 L .55032 .6338 L p .687 .696 .853 r
F P
0 g
s
.5508 .72507 m .56679 .73297 L .55581 .74487 L p .686 .7 .857 r
F P
0 g
s
.55581 .74487 m .53986 .73704 L .5508 .72507 L p .686 .7 .857 r
F P
0 g
s
.53978 .65879 m .55582 .66689 L .54487 .6791 L p .687 .698 .854 r
F P
0 g
s
.54572 .70498 m .56185 .713 L .5508 .72507 L p .686 .7 .857 r
F P
0 g
s
.55581 .78294 m .54226 .41488 L .55627 .42261 L p .835 .484 .391 r
F P
0 g
s
.55627 .42261 m .57311 .7913 L .55581 .78294 L p .835 .484 .391 r
F P
0 g
s
.58515 .77859 m .57311 .7913 L .55627 .42261 L p .201 .006 .378 r
F P
0 g
s
.55627 .42261 m .56592 .41086 L .58515 .77859 L p .201 .006 .378 r
F P
0 g
s
.55032 .6338 m .54226 .41488 L .55627 .42261 L p .835 .484 .391 r
F P
0 g
s
.55627 .42261 m .56629 .64196 L .55032 .6338 L p .835 .484 .391 r
F P
0 g
s
.58515 .77859 m .57311 .7913 L .55627 .42261 L p .201 .006 .378 r
F P
0 g
s
.55627 .42261 m .56592 .41086 L .58515 .77859 L p .201 .006 .378 r
F P
0 g
s
.61344 .40279 m .62732 .41058 L .61742 .42233 L p .694 .677 .829 r
F P
0 g
s
.61742 .42233 m .60357 .4146 L .61344 .40279 L p .694 .677 .829 r
F P
0 g
s
.63175 .78264 m .60357 .4146 L .61742 .42233 L p .836 .479 .38 r
F P
0 g
s
.61742 .42233 m .64881 .791 L .63175 .78264 L p .836 .479 .38 r
F P
0 g
s
.66303 .77028 m .64634 .762 L .65856 .74934 L p .683 .708 .867 r
F P
0 g
s
.64756 .77639 m .66438 .78468 L .65214 .79717 L p .682 .709 .868 r
F P
0 g
s
.66122 .77828 m .64881 .791 L .61742 .42233 L p .23 .037 .399 r
F P
0 g
s
.61742 .42233 m .62732 .41058 L .66122 .77828 L p .23 .037 .399 r
F P
0 g
s
.63175 .78264 m .60357 .4146 L .61742 .42233 L p .836 .479 .38 r
F P
0 g
s
.61742 .42233 m .64881 .791 L .63175 .78264 L p .836 .479 .38 r
F P
0 g
s
.65856 .74934 m .64634 .762 L .61742 .42233 L p .23 .037 .399 r
F P
0 g
s
.61742 .42233 m .62732 .41058 L .65856 .74934 L p .23 .037 .399 r
F P
0 g
s
.67501 .40251 m .68873 .4103 L .67859 .42205 L p .694 .677 .829 r
F P
0 g
s
.67859 .42205 m .6649 .41432 L .67501 .40251 L p .694 .677 .829 r
F P
0 g
s
.70107 .72527 m .6649 .41432 L .67859 .42205 L p .837 .474 .368 r
F P
0 g
s
.67859 .42205 m .7174 .73357 L .70107 .72527 L p .837 .474 .368 r
F P
0 g
s
.72978 .72096 m .7174 .73357 L .67859 .42205 L p .256 .065 .418 r
F P
0 g
s
.67859 .42205 m .68873 .4103 L .72978 .72096 L p .256 .065 .418 r
F P
0 g
s
.70602 .76774 m .6649 .41432 L .67859 .42205 L p .837 .474 .368 r
F P
0 g
s
.67859 .42205 m .7227 .77609 L .70602 .76774 L p .837 .474 .368 r
F P
0 g
s
.72978 .72096 m .7174 .73357 L .67859 .42205 L p .256 .065 .418 r
F P
0 g
s
.67859 .42205 m .68873 .4103 L .72978 .72096 L p .256 .065 .418 r
F P
0 g
s
.7366 .40223 m .75015 .41002 L .73976 .42177 L p .694 .677 .829 r
F P
0 g
s
.73976 .42177 m .72623 .41404 L .7366 .40223 L p .694 .677 .829 r
F P
0 g
s
.77917 .75307 m .72623 .41404 L .73976 .42177 L p .838 .469 .355 r
F P
0 g
s
.73976 .42177 m .79549 .7614 L .77917 .75307 L p .838 .469 .355 r
F P
0 g
s
.80845 .74873 m .79549 .7614 L .73976 .42177 L p .28 .091 .436 r
F P
0 g
s
.73976 .42177 m .75015 .41002 L .80845 .74873 L p .28 .091 .436 r
F P
0 g
s
.78369 .78203 m .72623 .41404 L .73976 .42177 L p .838 .469 .355 r
F P
0 g
s
.73976 .42177 m .80025 .7904 L .78369 .78203 L p .838 .469 .355 r
F P
0 g
s
.81343 .77768 m .80025 .7904 L .73976 .42177 L p .28 .091 .436 r
F P
0 g
s
.73976 .42177 m .75015 .41002 L .81343 .77768 L p .28 .091 .436 r
F P
0 g
s
.14445 .401 m .15959 .40879 L .15156 .42055 L p .694 .677 .829 r
F P
0 g
s
.15156 .42055 m .13647 .41282 L .14445 .401 L p .694 .677 .829 r
F P
0 g
s
.0629 .7376 m .13647 .41282 L .15156 .42055 L p .825 .507 .451 r
F P
0 g
s
.15156 .42055 m .08139 .74592 L .0629 .7376 L p .825 .507 .451 r
F P
0 g
s
.09078 .73326 m .08139 .74592 L .15156 .42055 L p 0 0 .156 r
F P
0 g
s
.15156 .42055 m .15959 .40879 L .09078 .73326 L p 0 0 .156 r
F P
0 g
s
.05969 .75175 m .13647 .41282 L .15156 .42055 L p .825 .507 .451 r
F P
0 g
s
.15156 .42055 m .07834 .76009 L .05969 .75175 L p .825 .507 .451 r
F P
0 g
s
.08778 .74741 m .07834 .76009 L .15156 .42055 L p 0 0 .156 r
F P
0 g
s
.15156 .42055 m .15959 .40879 L .08778 .74741 L p 0 0 .156 r
F P
0 g
s
.20602 .40071 m .22099 .40851 L .21271 .42028 L p .694 .677 .829 r
F P
0 g
s
.21271 .42028 m .19778 .41254 L .20602 .40071 L p .694 .677 .829 r
F P
0 g
s
.13973 .72336 m .19778 .41254 L .21271 .42028 L p .827 .504 .443 r
F P
0 g
s
.21271 .42028 m .15785 .73167 L .13973 .72336 L p .827 .504 .443 r
F P
0 g
s
.16753 .71903 m .15785 .73167 L .21271 .42028 L p 0 0 .2 r
F P
0 g
s
.21271 .42028 m .22099 .40851 L .16753 .71903 L p 0 0 .2 r
F P
0 g
s
.13973 .72336 m .19778 .41254 L .21271 .42028 L p .827 .504 .443 r
F P
0 g
s
.21271 .42028 m .15785 .73167 L .13973 .72336 L p .827 .504 .443 r
F P
0 g
s
.16023 .76146 m .15036 .77417 L .21271 .42028 L p 0 0 .2 r
F P
0 g
s
.21271 .42028 m .22099 .40851 L .16023 .76146 L p 0 0 .2 r
F P
0 g
s
.2676 .40043 m .2824 .40823 L .27388 .42 L p .694 .677 .829 r
F P
0 g
s
.27388 .42 m .25911 .41226 L .2676 .40043 L p .694 .677 .829 r
F P
0 g
s
.20719 .76551 m .25911 .41226 L .27388 .42 L p .828 .501 .435 r
F P
0 g
s
.27388 .42 m .22551 .77387 L .20719 .76551 L p .828 .501 .435 r
F P
0 g
s
.23575 .76116 m .22551 .77387 L .27388 .42 L p .02 0 .24 r
F P
0 g
s
.27388 .42 m .2824 .40823 L .23575 .76116 L p .02 0 .24 r
F P
0 g
s
.20505 .7801 m .25911 .41226 L .27388 .42 L p .828 .501 .435 r
F P
0 g
s
.27388 .42 m .22351 .78848 L .20505 .7801 L p .828 .501 .435 r
F P
0 g
s
.23382 .77574 m .22351 .78848 L .27388 .42 L p .02 0 .24 r
F P
0 g
s
.27388 .42 m .2824 .40823 L .23382 .77574 L p .02 0 .24 r
F P
0 g
s
.32918 .40015 m .34383 .40795 L .33506 .41972 L p .694 .677 .829 r
F P
0 g
s
.33506 .41972 m .32045 .41198 L .32918 .40015 L p .694 .677 .829 r
F P
0 g
s
.28103 .7798 m .32045 .41198 L .33506 .41972 L p .83 .498 .426 r
F P
0 g
s
.33506 .41972 m .29925 .78818 L .28103 .7798 L p .83 .498 .426 r
F P
0 g
s
.31862 .78188 m .30067 .77357 L .31128 .76086 L p .682 .709 .868 r
F P
0 g
s
.30994 .77543 m .29925 .78818 L .33506 .41972 L p .066 0 .276 r
F P
0 g
s
.33506 .41972 m .34383 .40795 L .30994 .77543 L p .066 0 .276 r
F P
0 g
s
.28103 .7798 m .32045 .41198 L .33506 .41972 L p .83 .498 .426 r
F P
0 g
s
.33506 .41972 m .29925 .78818 L .28103 .7798 L p .83 .498 .426 r
F P
0 g
s
.31128 .76086 m .30067 .77357 L .33506 .41972 L p .066 0 .276 r
F P
0 g
s
.33506 .41972 m .34383 .40795 L .31128 .76086 L p .066 0 .276 r
F P
0 g
s
.39078 .39987 m .40527 .40767 L .39625 .41944 L p .694 .677 .829 r
F P
0 g
s
.39625 .41944 m .3818 .4117 L .39078 .39987 L p .694 .677 .829 r
F P
0 g
s
.35994 .73639 m .3818 .4117 L .39625 .41944 L p .831 .494 .417 r
F P
0 g
s
.39625 .41944 m .37749 .74473 L .35994 .73639 L p .831 .494 .417 r
F P
0 g
s
.38832 .73206 m .37749 .74473 L .39625 .41944 L p .108 0 .308 r
F P
0 g
s
.39625 .41944 m .40527 .40767 L .38832 .73206 L p .108 0 .308 r
F P
0 g
s
.35898 .75054 m .3818 .4117 L .39625 .41944 L p .831 .494 .417 r
F P
0 g
s
.39625 .41944 m .37668 .75889 L .35898 .75054 L p .831 .494 .417 r
F P
0 g
s
.38759 .7462 m .37668 .75889 L .39625 .41944 L p .108 0 .308 r
F P
0 g
s
.39625 .41944 m .40527 .40767 L .38759 .7462 L p .108 0 .308 r
F P
0 g
s
.45239 .39959 m .46672 .40739 L .45745 .41916 L p .694 .677 .829 r
F P
0 g
s
.45745 .41916 m .44316 .41142 L .45239 .39959 L p .694 .677 .829 r
F P
0 g
s
.43305 .77919 m .44316 .41142 L .45745 .41916 L p .833 .49 .407 r
F P
0 g
s
.45745 .41916 m .45078 .78758 L .43305 .77919 L p .833 .49 .407 r
F P
0 g
s
.47537 .65423 m .45939 .64624 L .46983 .63402 L p .688 .695 .852 r
F P
0 g
s
.46994 .62175 m .45393 .61366 L .46435 .60128 L p .688 .694 .85 r
F P
0 g
s
.45371 .62591 m .46983 .63402 L .45939 .64624 L p .688 .695 .852 r
F P
0 g
s
.45955 .74918 m .47566 .75693 L .46519 .76861 L p .686 .7 .857 r
F P
0 g
s
.47566 .75693 m .45955 .74918 L .47008 .73732 L p .686 .7 .857 r
F P
0 g
s
.45902 .67136 m .47523 .67939 L .4647 .69149 L p .687 .698 .854 r
F P
0 g
s
.47008 .73732 m .45382 .72945 L .4644 .71742 L p .686 .7 .857 r
F P
0 g
s
.46223 .77483 m .45078 .78758 L .45745 .41916 L p .145 0 .337 r
F P
0 g
s
.45745 .41916 m .46672 .40739 L .46223 .77483 L p .145 0 .337 r
F P
0 g
s
.43305 .77919 m .44316 .41142 L .45745 .41916 L p .833 .49 .407 r
F P
0 g
s
.45745 .41916 m .45078 .78758 L .43305 .77919 L p .833 .49 .407 r
F P
0 g
s
.46435 .60128 m .45393 .61366 L .45745 .41916 L p .145 0 .337 r
F P
0 g
s
.45745 .41916 m .46672 .40739 L .46435 .60128 L p .145 0 .337 r
F P
0 g
s
.51402 .39931 m .52818 .40711 L .51867 .41889 L p .694 .677 .829 r
F P
0 g
s
.51867 .41889 m .50454 .41114 L .51402 .39931 L p .694 .677 .829 r
F P
0 g
s
.50694 .60522 m .50454 .41114 L .51867 .41889 L p .834 .486 .397 r
F P
0 g
s
.51867 .41889 m .52284 .61337 L .50694 .60522 L p .834 .486 .397 r
F P
0 g
s
.53357 .60099 m .52284 .61337 L .51867 .41889 L p .18 0 .362 r
F P
0 g
s
.51867 .41889 m .52818 .40711 L .53357 .60099 L p .18 0 .362 r
F P
0 g
s
.50709 .61745 m .50454 .41114 L .51867 .41889 L p .834 .486 .397 r
F P
0 g
s
.51867 .41889 m .5231 .62561 L .50709 .61745 L p .834 .486 .397 r
F P
0 g
s
.53391 .6132 m .5231 .62561 L .51867 .41889 L p .18 0 .362 r
F P
0 g
s
.51867 .41889 m .52818 .40711 L .53391 .6132 L p .18 0 .362 r
F P
0 g
s
.57565 .39902 m .58965 .40683 L .57989 .41861 L p .694 .677 .829 r
F P
0 g
s
.57989 .41861 m .56592 .41086 L .57565 .39902 L p .694 .677 .829 r
F P
0 g
s
.58515 .77859 m .56592 .41086 L .57989 .41861 L p .835 .482 .386 r
F P
0 g
s
.57989 .41861 m .60238 .78697 L .58515 .77859 L p .835 .482 .386 r
F P
0 g
s
.61848 .78069 m .60149 .77237 L .6136 .75964 L p .682 .709 .868 r
F P
0 g
s
.61459 .77422 m .60238 .78697 L .57989 .41861 L p .211 .017 .385 r
F P
0 g
s
.57989 .41861 m .58965 .40683 L .61459 .77422 L p .211 .017 .385 r
F P
0 g
s
.58515 .77859 m .56592 .41086 L .57989 .41861 L p .835 .482 .386 r
F P
0 g
s
.57989 .41861 m .60238 .78697 L .58515 .77859 L p .835 .482 .386 r
F P
0 g
s
.6136 .75964 m .60149 .77237 L .57989 .41861 L p .211 .017 .385 r
F P
0 g
s
.57989 .41861 m .58965 .40683 L .6136 .75964 L p .211 .017 .385 r
F P
0 g
s
.6373 .39874 m .65113 .40655 L .64113 .41833 L p .694 .677 .829 r
F P
0 g
s
.64113 .41833 m .62732 .41058 L .6373 .39874 L p .694 .677 .829 r
F P
0 g
s
.65725 .73519 m .62732 .41058 L .64113 .41833 L p .836 .477 .374 r
F P
0 g
s
.64113 .41833 m .67387 .74353 L .65725 .73519 L p .836 .477 .374 r
F P
0 g
s
.68615 .73085 m .67387 .74353 L .64113 .41833 L p .239 .047 .406 r
F P
0 g
s
.64113 .41833 m .65113 .40655 L .68615 .73085 L p .239 .047 .406 r
F P
0 g
s
.65856 .74934 m .62732 .41058 L .64113 .41833 L p .836 .477 .374 r
F P
0 g
s
.64113 .41833 m .67529 .75769 L .65856 .74934 L p .836 .477 .374 r
F P
0 g
s
.68767 .74499 m .67529 .75769 L .64113 .41833 L p .239 .047 .406 r
F P
0 g
s
.64113 .41833 m .65113 .40655 L .68767 .74499 L p .239 .047 .406 r
F P
0 g
s
.69896 .39846 m .71263 .40627 L .70238 .41805 L p .694 .677 .829 r
F P
0 g
s
.70238 .41805 m .68873 .4103 L .69896 .39846 L p .694 .677 .829 r
F P
0 g
s
.72978 .72096 m .68873 .4103 L .70238 .41805 L p .837 .472 .362 r
F P
0 g
s
.70238 .41805 m .74604 .72928 L .72978 .72096 L p .837 .472 .362 r
F P
0 g
s
.75858 .71662 m .74604 .72928 L .70238 .41805 L p .264 .074 .424 r
F P
0 g
s
.70238 .41805 m .71263 .40627 L .75858 .71662 L p .264 .074 .424 r
F P
0 g
s
.72978 .72096 m .68873 .4103 L .70238 .41805 L p .837 .472 .362 r
F P
0 g
s
.70238 .41805 m .74604 .72928 L .72978 .72096 L p .837 .472 .362 r
F P
0 g
s
.76486 .75904 m .75201 .77177 L .70238 .41805 L p .264 .074 .424 r
F P
0 g
s
.70238 .41805 m .71263 .40627 L .76486 .75904 L p .264 .074 .424 r
F P
0 g
s
.76063 .39818 m .77414 .40599 L .76364 .41777 L p .694 .677 .829 r
F P
0 g
s
.76364 .41777 m .75015 .41002 L .76063 .39818 L p .694 .677 .829 r
F P
0 g
s
.81092 .76309 m .75015 .41002 L .76364 .41777 L p .838 .466 .348 r
F P
0 g
s
.76364 .41777 m .82729 .77147 L .81092 .76309 L p .838 .466 .348 r
F P
0 g
s
.84052 .75873 m .82729 .77147 L .76364 .41777 L p .288 .099 .441 r
F P
0 g
s
.76364 .41777 m .77414 .40599 L .84052 .75873 L p .288 .099 .441 r
F P
0 g
s
.81343 .77768 m .75015 .41002 L .76364 .41777 L p .838 .466 .348 r
F P
0 g
s
.76364 .41777 m .82992 .78607 L .81343 .77768 L p .838 .466 .348 r
F P
0 g
s
.84327 .77331 m .82992 .78607 L .76364 .41777 L p .288 .099 .441 r
F P
0 g
s
.76364 .41777 m .77414 .40599 L .84327 .77331 L p .288 .099 .441 r
F P
0 g
s
.16768 .39694 m .18277 .40476 L .17464 .41655 L p .694 .677 .829 r
F P
0 g
s
.17464 .41655 m .15959 .40879 L .16768 .39694 L p .694 .677 .829 r
F P
0 g
s
.09373 .71933 m .15959 .40879 L .17464 .41655 L p .826 .506 .447 r
F P
0 g
s
.17464 .41655 m .11202 .72767 L .09373 .71933 L p .826 .506 .447 r
F P
0 g
s
.1215 .715 m .11202 .72767 L .17464 .41655 L p 0 0 .171 r
F P
0 g
s
.17464 .41655 m .18277 .40476 L .1215 .715 L p 0 0 .171 r
F P
0 g
s
.08778 .74741 m .15959 .40879 L .17464 .41655 L p .826 .506 .447 r
F P
0 g
s
.17464 .41655 m .10637 .75578 L .08778 .74741 L p .826 .506 .447 r
F P
0 g
s
.1215 .715 m .11202 .72767 L .17464 .41655 L p 0 0 .171 r
F P
0 g
s
.17464 .41655 m .18277 .40476 L .1215 .715 L p 0 0 .171 r
F P
0 g
s
.22933 .39666 m .24426 .40448 L .23588 .41627 L p .694 .677 .829 r
F P
0 g
s
.23588 .41627 m .22099 .40851 L .22933 .39666 L p .694 .677 .829 r
F P
0 g
s
.1627 .7471 m .22099 .40851 L .23588 .41627 L p .828 .503 .439 r
F P
0 g
s
.23588 .41627 m .18105 .75548 L .1627 .7471 L p .828 .503 .439 r
F P
0 g
s
.19101 .74275 m .18105 .75548 L .23588 .41627 L p 0 0 .214 r
F P
0 g
s
.23588 .41627 m .24426 .40448 L .19101 .74275 L p 0 0 .214 r
F P
0 g
s
.16023 .76146 m .22099 .40851 L .23588 .41627 L p .828 .503 .439 r
F P
0 g
s
.23588 .41627 m .17873 .76985 L .16023 .76146 L p .828 .503 .439 r
F P
0 g
s
.19101 .74275 m .18105 .75548 L .23588 .41627 L p 0 0 .214 r
F P
0 g
s
.23588 .41627 m .24426 .40448 L .19101 .74275 L p 0 0 .214 r
F P
0 g
s
.29099 .39638 m .30576 .4042 L .29713 .41599 L p .694 .677 .829 r
F P
0 g
s
.29713 .41599 m .2824 .40823 L .29099 .39638 L p .694 .677 .829 r
F P
0 g
s
.24845 .66504 m .2824 .40823 L .29713 .41599 L p .829 .499 .43 r
F P
0 g
s
.29713 .41599 m .26574 .6733 L .24845 .66504 L p .829 .499 .43 r
F P
0 g
s
.27567 .66074 m .26574 .6733 L .29713 .41599 L p .036 0 .253 r
F P
0 g
s
.29713 .41599 m .30576 .4042 L .27567 .66074 L p .036 0 .253 r
F P
0 g
s
.23382 .77574 m .2824 .40823 L .29713 .41599 L p .829 .499 .43 r
F P
0 g
s
.29713 .41599 m .25222 .78414 L .23382 .77574 L p .829 .499 .43 r
F P
0 g
s
.26269 .77136 m .25222 .78414 L .29713 .41599 L p .036 0 .253 r
F P
0 g
s
.29713 .41599 m .30576 .4042 L .26269 .77136 L p .036 0 .253 r
F P
0 g
s
.35267 .39609 m .36727 .40392 L .3584 .41572 L p .694 .677 .829 r
F P
0 g
s
.3584 .41572 m .34383 .40795 L .35267 .39609 L p .694 .677 .829 r
F P
0 g
s
.31128 .76086 m .32929 .76925 L .31862 .78188 L p .682 .709 .868 r
F P
0 g
s
.30994 .77543 m .34383 .40795 L .3584 .41572 L p .831 .496 .421 r
F P
0 g
s
.3584 .41572 m .32809 .78384 L .30994 .77543 L p .831 .496 .421 r
F P
0 g
s
.33894 .77106 m .32809 .78384 L .3584 .41572 L p .08 0 .287 r
F P
0 g
s
.3584 .41572 m .36727 .40392 L .33894 .77106 L p .08 0 .287 r
F P
0 g
s
.31128 .76086 m .34383 .40795 L .3584 .41572 L p .831 .496 .421 r
F P
0 g
s
.3584 .41572 m .32929 .76925 L .31128 .76086 L p .831 .496 .421 r
F P
0 g
s
.33894 .77106 m .32809 .78384 L .3584 .41572 L p .08 0 .287 r
F P
0 g
s
.3584 .41572 m .36727 .40392 L .33894 .77106 L p .08 0 .287 r
F P
0 g
s
.41436 .39581 m .4288 .40364 L .41967 .41544 L p .694 .677 .829 r
F P
0 g
s
.41967 .41544 m .40527 .40767 L .41436 .39581 L p .694 .677 .829 r
F P
0 g
s
.37668 .75889 m .39426 .76719 L .3834 .77968 L p .683 .708 .867 r
F P
0 g
s
.38759 .7462 m .40522 .75457 L .39426 .76719 L p .683 .708 .867 r
F P
0 g
s
.39426 .76719 m .37668 .75889 L .38759 .7462 L p .683 .708 .867 r
F P
0 g
s
.38607 .77513 m .40527 .40767 L .41967 .41544 L p .832 .492 .412 r
F P
0 g
s
.41967 .41544 m .40398 .78354 L .38607 .77513 L p .832 .492 .412 r
F P
0 g
s
.41521 .77075 m .40398 .78354 L .41967 .41544 L p .121 0 .318 r
F P
0 g
s
.41967 .41544 m .4288 .40364 L .41521 .77075 L p .121 0 .318 r
F P
0 g
s
.38759 .7462 m .40527 .40767 L .41967 .41544 L p .832 .492 .412 r
F P
0 g
s
.41967 .41544 m .40522 .75457 L .38759 .7462 L p .832 .492 .412 r
F P
0 g
s
.41521 .77075 m .40398 .78354 L .41967 .41544 L p .121 0 .318 r
F P
0 g
s
.41967 .41544 m .4288 .40364 L .41521 .77075 L p .121 0 .318 r
F P
0 g
s
.47606 .39553 m .49033 .40336 L .48096 .41516 L p .694 .677 .829 r
F P
0 g
s
.48096 .41516 m .46672 .40739 L .47606 .39553 L p .694 .677 .829 r
F P
0 g
s
.46449 .58924 m .46672 .40739 L .48096 .41516 L p .833 .488 .402 r
F P
0 g
s
.48096 .41516 m .48043 .59738 L .46449 .58924 L p .833 .488 .402 r
F P
0 g
s
.49091 .585 m .48043 .59738 L .48096 .41516 L p .157 0 .346 r
F P
0 g
s
.48096 .41516 m .49033 .40336 L .49091 .585 L p .157 0 .346 r
F P
0 g
s
.46435 .60128 m .46672 .40739 L .48096 .41516 L p .833 .488 .402 r
F P
0 g
s
.48096 .41516 m .48039 .60945 L .46435 .60128 L p .833 .488 .402 r
F P
0 g
s
.49091 .585 m .48043 .59738 L .48096 .41516 L p .157 0 .346 r
F P
0 g
s
.48096 .41516 m .49033 .40336 L .49091 .585 L p .157 0 .346 r
F P
0 g
s
.53777 .39525 m .55188 .40307 L .54226 .41488 L p .694 .677 .829 r
F P
0 g
s
.54226 .41488 m .52818 .40711 L .53777 .39525 L p .694 .677 .829 r
F P
0 g
s
.53413 .76833 m .54991 .77597 L .53918 .78748 L p .686 .7 .857 r
F P
0 g
s
.54991 .77597 m .53413 .76833 L .54492 .75665 L p .686 .7 .857 r
F P
0 g
s
.5231 .62561 m .53902 .63373 L .52826 .64595 L p .688 .695 .852 r
F P
0 g
s
.52901 .7489 m .54492 .75665 L .53413 .76833 L p .686 .7 .857 r
F P
0 g
s
.53391 .6132 m .54986 .62139 L .53902 .63373 L p .688 .695 .852 r
F P
0 g
s
.53902 .63373 m .5231 .62561 L .53391 .6132 L p .688 .695 .852 r
F P
0 g
s
.54487 .6791 m .52887 .67107 L .53978 .65879 L p .687 .698 .854 r
F P
0 g
s
.53472 .71713 m .5508 .72507 L .53986 .73704 L p .686 .7 .857 r
F P
0 g
s
.53986 .73704 m .52381 .72917 L .53472 .71713 L p .686 .7 .857 r
F P
0 g
s
.52918 .6839 m .54529 .69195 L .53437 .70407 L p .687 .699 .856 r
F P
0 g
s
.5508 .72507 m .53472 .71713 L .54572 .70498 L p .686 .7 .857 r
F P
0 g
s
.5384 .77452 m .52818 .40711 L .54226 .41488 L p .835 .484 .391 r
F P
0 g
s
.54226 .41488 m .55581 .78294 L .5384 .77452 L p .835 .484 .391 r
F P
0 g
s
.56781 .77014 m .55581 .78294 L .54226 .41488 L p .19 0 .37 r
F P
0 g
s
.54226 .41488 m .55188 .40307 L .56781 .77014 L p .19 0 .37 r
F P
0 g
s
.53391 .6132 m .52818 .40711 L .54226 .41488 L p .835 .484 .391 r
F P
0 g
s
.54226 .41488 m .54986 .62139 L .53391 .6132 L p .835 .484 .391 r
F P
0 g
s
.56781 .77014 m .55581 .78294 L .54226 .41488 L p .19 0 .37 r
F P
0 g
s
.54226 .41488 m .55188 .40307 L .56781 .77014 L p .19 0 .37 r
F P
0 g
s
.59949 .39496 m .61344 .40279 L .60357 .4146 L p .694 .677 .829 r
F P
0 g
s
.60357 .4146 m .58965 .40683 L .59949 .39496 L p .694 .677 .829 r
F P
0 g
s
.6136 .75964 m .63064 .76804 L .61848 .78069 L p .682 .709 .868 r
F P
0 g
s
.61459 .77422 m .58965 .40683 L .60357 .4146 L p .836 .479 .38 r
F P
0 g
s
.60357 .4146 m .63175 .78264 L .61459 .77422 L p .836 .479 .38 r
F P
0 g
s
.64413 .76984 m .63175 .78264 L .60357 .4146 L p .22 .027 .392 r
F P
0 g
s
.60357 .4146 m .61344 .40279 L .64413 .76984 L p .22 .027 .392 r
F P
0 g
s
.6136 .75964 m .58965 .40683 L .60357 .4146 L p .836 .479 .38 r
F P
0 g
s
.60357 .4146 m .63064 .76804 L .6136 .75964 L p .836 .479 .38 r
F P
0 g
s
.64413 .76984 m .63175 .78264 L .60357 .4146 L p .22 .027 .392 r
F P
0 g
s
.60357 .4146 m .61344 .40279 L .64413 .76984 L p .22 .027 .392 r
F P
0 g
s
.66122 .39468 m .67501 .40251 L .6649 .41432 L p .694 .677 .829 r
F P
0 g
s
.6649 .41432 m .65113 .40655 L .66122 .39468 L p .694 .677 .829 r
F P
0 g
s
.68464 .71692 m .65113 .40655 L .6649 .41432 L p .837 .474 .368 r
F P
0 g
s
.6649 .41432 m .70107 .72527 L .68464 .71692 L p .837 .474 .368 r
F P
0 g
s
.71342 .71258 m .70107 .72527 L .6649 .41432 L p .248 .056 .412 r
F P
0 g
s
.6649 .41432 m .67501 .40251 L .71342 .71258 L p .248 .056 .412 r
F P
0 g
s
.68767 .74499 m .65113 .40655 L .6649 .41432 L p .837 .474 .368 r
F P
0 g
s
.6649 .41432 m .70434 .75337 L .68767 .74499 L p .837 .474 .368 r
F P
0 g
s
.71342 .71258 m .70107 .72527 L .6649 .41432 L p .248 .056 .412 r
F P
0 g
s
.6649 .41432 m .67501 .40251 L .71342 .71258 L p .248 .056 .412 r
F P
0 g
s
.72297 .3944 m .7366 .40223 L .72623 .41404 L p .694 .677 .829 r
F P
0 g
s
.72623 .41404 m .71263 .40627 L .72297 .3944 L p .694 .677 .829 r
F P
0 g
s
.76274 .74468 m .71263 .40627 L .72623 .41404 L p .838 .469 .355 r
F P
0 g
s
.72623 .41404 m .77917 .75307 L .76274 .74468 L p .838 .469 .355 r
F P
0 g
s
.79208 .74032 m .77917 .75307 L .72623 .41404 L p .272 .082 .43 r
F P
0 g
s
.72623 .41404 m .7366 .40223 L .79208 .74032 L p .272 .082 .43 r
F P
0 g
s
.76486 .75904 m .71263 .40627 L .72623 .41404 L p .838 .469 .355 r
F P
0 g
s
.72623 .41404 m .78141 .76744 L .76486 .75904 L p .838 .469 .355 r
F P
0 g
s
.79208 .74032 m .77917 .75307 L .72623 .41404 L p .272 .082 .43 r
F P
0 g
s
.72623 .41404 m .7366 .40223 L .79208 .74032 L p .272 .082 .43 r
F P
0 g
s
.78473 .39411 m .79819 .40195 L .78758 .41376 L p .694 .677 .829 r
F P
0 g
s
.78758 .41376 m .77414 .40599 L .78473 .39411 L p .694 .677 .829 r
F P
0 g
s
.84327 .77331 m .77414 .40599 L .78758 .41376 L p .839 .463 .341 r
F P
0 g
s
.78758 .41376 m .85969 .78173 L .84327 .77331 L p .839 .463 .341 r
F P
0 g
s
.87321 .76892 m .85969 .78173 L .78758 .41376 L p .295 .107 .446 r
F P
0 g
s
.78758 .41376 m .79819 .40195 L .87321 .76892 L p .295 .107 .446 r
F P
0 g
s
.84327 .77331 m .77414 .40599 L .78758 .41376 L p .839 .463 .341 r
F P
0 g
s
.78758 .41376 m .85969 .78173 L .84327 .77331 L p .839 .463 .341 r
F P
0 g
s
.07222 .72486 m .0629 .7376 L .13647 .41282 L p 0 0 .14 r
F P
0 g
s
.13647 .41282 m .14445 .401 L .07222 .72486 L p 0 0 .14 r
F P
0 g
s
.19097 .39287 m .20602 .40071 L .19778 .41254 L p .694 .677 .829 r
F P
0 g
s
.19778 .41254 m .18277 .40476 L .19097 .39287 L p .694 .677 .829 r
F P
0 g
s
.12421 .70128 m .18277 .40476 L .19778 .41254 L p .827 .504 .443 r
F P
0 g
s
.19778 .41254 m .1423 .70963 L .12421 .70128 L p .827 .504 .443 r
F P
0 g
s
.15186 .69694 m .1423 .70963 L .19778 .41254 L p 0 0 .186 r
F P
0 g
s
.19778 .41254 m .20602 .40071 L .15186 .69694 L p 0 0 .186 r
F P
0 g
s
.1215 .715 m .18277 .40476 L .19778 .41254 L p .827 .504 .443 r
F P
0 g
s
.19778 .41254 m .13973 .72336 L .1215 .715 L p .827 .504 .443 r
F P
0 g
s
.14936 .71064 m .13973 .72336 L .19778 .41254 L p 0 0 .186 r
F P
0 g
s
.19778 .41254 m .20602 .40071 L .14936 .71064 L p 0 0 .186 r
F P
0 g
s
.25271 .39259 m .2676 .40043 L .25911 .41226 L p .694 .677 .829 r
F P
0 g
s
.25911 .41226 m .24426 .40448 L .25271 .39259 L p .694 .677 .829 r
F P
0 g
s
.19101 .74275 m .24426 .40448 L .25911 .41226 L p .828 .501 .435 r
F P
0 g
s
.25911 .41226 m .2093 .75115 L .19101 .74275 L p .828 .501 .435 r
F P
0 g
s
.21942 .73837 m .2093 .75115 L .25911 .41226 L p .004 0 .228 r
F P
0 g
s
.25911 .41226 m .2676 .40043 L .21942 .73837 L p .004 0 .228 r
F P
0 g
s
.19101 .74275 m .24426 .40448 L .25911 .41226 L p .828 .501 .435 r
F P
0 g
s
.25911 .41226 m .2093 .75115 L .19101 .74275 L p .828 .501 .435 r
F P
0 g
s
.21737 .75271 m .20719 .76551 L .25911 .41226 L p .004 0 .228 r
F P
0 g
s
.25911 .41226 m .2676 .40043 L .21737 .75271 L p .004 0 .228 r
F P
0 g
s
.31446 .39231 m .32918 .40015 L .32045 .41198 L p .694 .677 .829 r
F P
0 g
s
.32045 .41198 m .30576 .4042 L .31446 .39231 L p .694 .677 .829 r
F P
0 g
s
.2644 .75679 m .30576 .4042 L .32045 .41198 L p .83 .498 .426 r
F P
0 g
s
.32045 .41198 m .28259 .76521 L .2644 .75679 L p .83 .498 .426 r
F P
0 g
s
.29315 .75241 m .28259 .76521 L .32045 .41198 L p .051 0 .265 r
F P
0 g
s
.32045 .41198 m .32918 .40015 L .29315 .75241 L p .051 0 .265 r
F P
0 g
s
.26269 .77136 m .30576 .4042 L .32045 .41198 L p .83 .498 .426 r
F P
0 g
s
.32045 .41198 m .28103 .7798 L .26269 .77136 L p .83 .498 .426 r
F P
0 g
s
.29167 .76697 m .28103 .7798 L .32045 .41198 L p .051 0 .265 r
F P
0 g
s
.32045 .41198 m .32918 .40015 L .29167 .76697 L p .051 0 .265 r
F P
0 g
s
.37622 .39202 m .39078 .39987 L .3818 .4117 L p .694 .677 .829 r
F P
0 g
s
.3818 .4117 m .36727 .40392 L .37622 .39202 L p .694 .677 .829 r
F P
0 g
s
.33894 .77106 m .36727 .40392 L .3818 .4117 L p .831 .494 .417 r
F P
0 g
s
.3818 .4117 m .35703 .77949 L .33894 .77106 L p .831 .494 .417 r
F P
0 g
s
.37749 .74473 m .35994 .73639 L .37072 .72364 L p .683 .706 .865 r
F P
0 g
s
.35898 .75054 m .37668 .75889 L .36587 .77146 L p .683 .708 .867 r
F P
0 g
s
.36805 .76666 m .35703 .77949 L .3818 .4117 L p .094 0 .298 r
F P
0 g
s
.3818 .4117 m .39078 .39987 L .36805 .76666 L p .094 0 .298 r
F P
0 g
s
.33894 .77106 m .36727 .40392 L .3818 .4117 L p .831 .494 .417 r
F P
0 g
s
.3818 .4117 m .35703 .77949 L .33894 .77106 L p .831 .494 .417 r
F P
0 g
s
.37072 .72364 m .35994 .73639 L .3818 .4117 L p .094 0 .298 r
F P
0 g
s
.3818 .4117 m .39078 .39987 L .37072 .72364 L p .094 0 .298 r
F P
0 g
s
.438 .39174 m .45239 .39959 L .44316 .41142 L p .694 .677 .829 r
F P
0 g
s
.44316 .41142 m .4288 .40364 L .438 .39174 L p .694 .677 .829 r
F P
0 g
s
.41575 .75618 m .4288 .40364 L .44316 .41142 L p .833 .49 .407 r
F P
0 g
s
.44316 .41142 m .43346 .76461 L .41575 .75618 L p .833 .49 .407 r
F P
0 g
s
.44477 .7518 m .43346 .76461 L .44316 .41142 L p .133 0 .328 r
F P
0 g
s
.44316 .41142 m .45239 .39959 L .44477 .7518 L p .133 0 .328 r
F P
0 g
s
.41521 .77075 m .4288 .40364 L .44316 .41142 L p .833 .49 .407 r
F P
0 g
s
.44316 .41142 m .43305 .77919 L .41521 .77075 L p .833 .49 .407 r
F P
0 g
s
.44445 .76636 m .43305 .77919 L .44316 .41142 L p .133 0 .328 r
F P
0 g
s
.44316 .41142 m .45239 .39959 L .44445 .76636 L p .133 0 .328 r
F P
0 g
s
.49978 .39146 m .51402 .39931 L .50454 .41114 L p .694 .677 .829 r
F P
0 g
s
.50454 .41114 m .49033 .40336 L .49978 .39146 L p .694 .677 .829 r
F P
0 g
s
.49091 .585 m .49033 .40336 L .50454 .41114 L p .834 .486 .397 r
F P
0 g
s
.50454 .41114 m .50679 .59317 L .49091 .585 L p .834 .486 .397 r
F P
0 g
s
.51741 .58075 m .50679 .59317 L .50454 .41114 L p .169 0 .354 r
F P
0 g
s
.50454 .41114 m .51402 .39931 L .51741 .58075 L p .169 0 .354 r
F P
0 g
s
.49091 .585 m .49033 .40336 L .50454 .41114 L p .834 .486 .397 r
F P
0 g
s
.50454 .41114 m .50679 .59317 L .49091 .585 L p .834 .486 .397 r
F P
0 g
s
.51763 .59277 m .50694 .60522 L .50454 .41114 L p .169 0 .354 r
F P
0 g
s
.50454 .41114 m .51402 .39931 L .51763 .59277 L p .169 0 .354 r
F P
0 g
s
.56158 .39117 m .57565 .39902 L .56592 .41086 L p .694 .677 .829 r
F P
0 g
s
.56592 .41086 m .55188 .40307 L .56158 .39117 L p .694 .677 .829 r
F P
0 g
s
.56717 .75557 m .55188 .40307 L .56592 .41086 L p .835 .482 .386 r
F P
0 g
s
.56592 .41086 m .58439 .764 L .56717 .75557 L p .835 .482 .386 r
F P
0 g
s
.59645 .75119 m .58439 .764 L .56592 .41086 L p .201 .006 .378 r
F P
0 g
s
.56592 .41086 m .57565 .39902 L .59645 .75119 L p .201 .006 .378 r
F P
0 g
s
.56781 .77014 m .55188 .40307 L .56592 .41086 L p .835 .482 .386 r
F P
0 g
s
.56592 .41086 m .58515 .77859 L .56781 .77014 L p .835 .482 .386 r
F P
0 g
s
.59731 .76575 m .58515 .77859 L .56592 .41086 L p .201 .006 .378 r
F P
0 g
s
.56592 .41086 m .57565 .39902 L .59731 .76575 L p .201 .006 .378 r
F P
0 g
s
.62339 .39089 m .6373 .39874 L .62732 .41058 L p .694 .677 .829 r
F P
0 g
s
.62732 .41058 m .61344 .40279 L .62339 .39089 L p .694 .677 .829 r
F P
0 g
s
.64413 .76984 m .61344 .40279 L .62732 .41058 L p .836 .477 .374 r
F P
0 g
s
.62732 .41058 m .66122 .77828 L .64413 .76984 L p .836 .477 .374 r
F P
0 g
s
.67962 .7785 m .66303 .77028 L .67529 .75769 L p .683 .708 .867 r
F P
0 g
s
.67387 .74353 m .65725 .73519 L .66949 .72243 L p .683 .706 .865 r
F P
0 g
s
.65856 .74934 m .67529 .75769 L .66303 .77028 L p .683 .708 .867 r
F P
0 g
s
.67377 .76544 m .66122 .77828 L .62732 .41058 L p .23 .037 .399 r
F P
0 g
s
.62732 .41058 m .6373 .39874 L .67377 .76544 L p .23 .037 .399 r
F P
0 g
s
.64413 .76984 m .61344 .40279 L .62732 .41058 L p .836 .477 .374 r
F P
0 g
s
.62732 .41058 m .66122 .77828 L .64413 .76984 L p .836 .477 .374 r
F P
0 g
s
.66949 .72243 m .65725 .73519 L .62732 .41058 L p .23 .037 .399 r
F P
0 g
s
.62732 .41058 m .6373 .39874 L .66949 .72243 L p .23 .037 .399 r
F P
0 g
s
.68521 .39061 m .69896 .39846 L .68873 .4103 L p .694 .677 .829 r
F P
0 g
s
.68873 .4103 m .67501 .40251 L .68521 .39061 L p .694 .677 .829 r
F P
0 g
s
.71172 .69887 m .67501 .40251 L .68873 .4103 L p .837 .472 .362 r
F P
0 g
s
.68873 .4103 m .72797 .70723 L .71172 .69887 L p .837 .472 .362 r
F P
0 g
s
.74037 .69452 m .72797 .70723 L .68873 .4103 L p .256 .065 .418 r
F P
0 g
s
.68873 .4103 m .69896 .39846 L .74037 .69452 L p .256 .065 .418 r
F P
0 g
s
.71342 .71258 m .67501 .40251 L .68873 .4103 L p .837 .472 .362 r
F P
0 g
s
.68873 .4103 m .72978 .72096 L .71342 .71258 L p .837 .472 .362 r
F P
0 g
s
.74228 .70822 m .72978 .72096 L .68873 .4103 L p .256 .065 .418 r
F P
0 g
s
.68873 .4103 m .69896 .39846 L .74228 .70822 L p .256 .065 .418 r
F P
0 g
s
.74704 .39032 m .76063 .39818 L .75015 .41002 L p .694 .677 .829 r
F P
0 g
s
.75015 .41002 m .7366 .40223 L .74704 .39032 L p .694 .677 .829 r
F P
0 g
s
.79208 .74032 m .7366 .40223 L .75015 .41002 L p .838 .466 .348 r
F P
0 g
s
.75015 .41002 m .80845 .74873 L .79208 .74032 L p .838 .466 .348 r
F P
0 g
s
.82153 .73594 m .80845 .74873 L .75015 .41002 L p .28 .091 .436 r
F P
0 g
s
.75015 .41002 m .76063 .39818 L .82153 .73594 L p .28 .091 .436 r
F P
0 g
s
.79208 .74032 m .7366 .40223 L .75015 .41002 L p .838 .466 .348 r
F P
0 g
s
.75015 .41002 m .80845 .74873 L .79208 .74032 L p .838 .466 .348 r
F P
0 g
s
.82411 .75027 m .81092 .76309 L .75015 .41002 L p .28 .091 .436 r
F P
0 g
s
.75015 .41002 m .76063 .39818 L .82411 .75027 L p .28 .091 .436 r
F P
0 g
s
.15251 .38908 m .16768 .39694 L .15959 .40879 L p .694 .677 .829 r
F P
0 g
s
.15959 .40879 m .14445 .401 L .15251 .38908 L p .694 .677 .829 r
F P
0 g
s
.07532 .71095 m .14445 .401 L .15959 .40879 L p .826 .506 .447 r
F P
0 g
s
.15959 .40879 m .09373 .71933 L .07532 .71095 L p .826 .506 .447 r
F P
0 g
s
.10315 .70658 m .09373 .71933 L .15959 .40879 L p 0 0 .156 r
F P
0 g
s
.15959 .40879 m .16768 .39694 L .10315 .70658 L p 0 0 .156 r
F P
0 g
s
.07222 .72486 m .14445 .401 L .15959 .40879 L p .826 .506 .447 r
F P
0 g
s
.15959 .40879 m .09078 .73326 L .07222 .72486 L p .826 .506 .447 r
F P
0 g
s
.10315 .70658 m .09373 .71933 L .15959 .40879 L p 0 0 .156 r
F P
0 g
s
.15959 .40879 m .16768 .39694 L .10315 .70658 L p 0 0 .156 r
F P
0 g
s
.21432 .38879 m .22933 .39666 L .22099 .40851 L p .694 .677 .829 r
F P
0 g
s
.22099 .40851 m .20602 .40071 L .21432 .38879 L p .694 .677 .829 r
F P
0 g
s
.14936 .71064 m .20602 .40071 L .22099 .40851 L p .828 .503 .439 r
F P
0 g
s
.22099 .40851 m .16753 .71903 L .14936 .71064 L p .828 .503 .439 r
F P
0 g
s
.17731 .70628 m .16753 .71903 L .22099 .40851 L p 0 0 .2 r
F P
0 g
s
.22099 .40851 m .22933 .39666 L .17731 .70628 L p 0 0 .2 r
F P
0 g
s
.14936 .71064 m .20602 .40071 L .22099 .40851 L p .828 .503 .439 r
F P
0 g
s
.22099 .40851 m .16753 .71903 L .14936 .71064 L p .828 .503 .439 r
F P
0 g
s
.17261 .73429 m .1627 .7471 L .22099 .40851 L p 0 0 .2 r
F P
0 g
s
.22099 .40851 m .22933 .39666 L .17261 .73429 L p 0 0 .2 r
F P
0 g
s
.27615 .38851 m .29099 .39638 L .2824 .40823 L p .694 .677 .829 r
F P
0 g
s
.2824 .40823 m .2676 .40043 L .27615 .38851 L p .694 .677 .829 r
F P
0 g
s
.23106 .65673 m .2676 .40043 L .2824 .40823 L p .829 .499 .43 r
F P
0 g
s
.2824 .40823 m .24845 .66504 L .23106 .65673 L p .829 .499 .43 r
F P
0 g
s
.25833 .6524 m .24845 .66504 L .2824 .40823 L p .02 0 .24 r
F P
0 g
s
.2824 .40823 m .29099 .39638 L .25833 .6524 L p .02 0 .24 r
F P
0 g
s
.21737 .75271 m .2676 .40043 L .2824 .40823 L p .829 .499 .43 r
F P
0 g
s
.2824 .40823 m .23575 .76116 L .21737 .75271 L p .829 .499 .43 r
F P
0 g
s
.25833 .6524 m .24845 .66504 L .2824 .40823 L p .02 0 .24 r
F P
0 g
s
.2824 .40823 m .29099 .39638 L .25833 .6524 L p .02 0 .24 r
F P
0 g
s
.33799 .38823 m .35267 .39609 L .34383 .40795 L p .694 .677 .829 r
F P
0 g
s
.34383 .40795 m .32918 .40015 L .33799 .38823 L p .694 .677 .829 r
F P
0 g
s
.29462 .73807 m .32918 .40015 L .34383 .40795 L p .831 .496 .421 r
F P
0 g
s
.34383 .40795 m .31261 .7465 L .29462 .73807 L p .831 .496 .421 r
F P
0 g
s
.32325 .73368 m .31261 .7465 L .34383 .40795 L p .066 0 .276 r
F P
0 g
s
.34383 .40795 m .35267 .39609 L .32325 .73368 L p .066 0 .276 r
F P
0 g
s
.29167 .76697 m .32918 .40015 L .34383 .40795 L p .831 .496 .421 r
F P
0 g
s
.34383 .40795 m .30994 .77543 L .29167 .76697 L p .831 .496 .421 r
F P
0 g
s
.32074 .76256 m .30994 .77543 L .34383 .40795 L p .066 0 .276 r
F P
0 g
s
.34383 .40795 m .35267 .39609 L .32074 .76256 L p .066 0 .276 r
F P
0 g
s
.39984 .38794 m .41436 .39581 L .40527 .40767 L p .694 .677 .829 r
F P
0 g
s
.40527 .40767 m .39078 .39987 L .39984 .38794 L p .694 .677 .829 r
F P
0 g
s
.37072 .72364 m .38832 .73206 L .37749 .74473 L p .683 .706 .865 r
F P
0 g
s
.36805 .76666 m .39078 .39987 L .40527 .40767 L p .832 .492 .412 r
F P
0 g
s
.3834 .77968 m .36587 .77146 L .37668 .75889 L p .683 .708 .867 r
F P
0 g
s
.40527 .40767 m .38607 .77513 L .36805 .76666 L p .832 .492 .412 r
F P
0 g
s
.39725 .76225 m .38607 .77513 L .40527 .40767 L p .108 0 .308 r
F P
0 g
s
.40527 .40767 m .41436 .39581 L .39725 .76225 L p .108 0 .308 r
F P
0 g
s
.37072 .72364 m .39078 .39987 L .40527 .40767 L p .832 .492 .412 r
F P
0 g
s
.40527 .40767 m .38832 .73206 L .37072 .72364 L p .832 .492 .412 r
F P
0 g
s
.39725 .76225 m .38607 .77513 L .40527 .40767 L p .108 0 .308 r
F P
0 g
s
.40527 .40767 m .41436 .39581 L .39725 .76225 L p .108 0 .308 r
F P
0 g
s
.4617 .38766 m .47606 .39553 L .46672 .40739 L p .694 .677 .829 r
F P
0 g
s
.46672 .40739 m .45239 .39959 L .4617 .38766 L p .694 .677 .829 r
F P
0 g
s
.44445 .76636 m .45239 .39959 L .46672 .40739 L p .833 .488 .402 r
F P
0 g
s
.46672 .40739 m .46223 .77483 L .44445 .76636 L p .833 .488 .402 r
F P
0 g
s
.48043 .59738 m .46449 .58924 L .47494 .57678 L p .689 .693 .849 r
F P
0 g
s
.46983 .63402 m .48585 .64208 L .47537 .65423 L p .688 .695 .852 r
F P
0 g
s
.46435 .60128 m .48039 .60945 L .46994 .62175 L p .688 .694 .85 r
F P
0 g
s
.48117 .77625 m .46519 .76861 L .47566 .75693 L p .686 .7 .857 r
F P
0 g
s
.48585 .64208 m .46983 .63402 L .48036 .62169 L p .688 .695 .852 r
F P
0 g
s
.47008 .73732 m .48623 .74515 L .47566 .75693 L p .686 .7 .857 r
F P
0 g
s
.48623 .74515 m .47008 .73732 L .4807 .72536 L p .686 .7 .857 r
F P
0 g
s
.48073 .71229 m .46455 .70436 L .47515 .69224 L p .687 .699 .856 r
F P
0 g
s
.4644 .71742 m .4807 .72536 L .47008 .73732 L p .686 .7 .857 r
F P
0 g
s
.47379 .76195 m .46223 .77483 L .46672 .40739 L p .145 0 .337 r
F P
0 g
s
.46672 .40739 m .47606 .39553 L .47379 .76195 L p .145 0 .337 r
F P
0 g
s
.44445 .76636 m .45239 .39959 L .46672 .40739 L p .833 .488 .402 r
F P
0 g
s
.46672 .40739 m .46223 .77483 L .44445 .76636 L p .833 .488 .402 r
F P
0 g
s
.47494 .57678 m .46449 .58924 L .46672 .40739 L p .145 0 .337 r
F P
0 g
s
.46672 .40739 m .47606 .39553 L .47494 .57678 L p .145 0 .337 r
F P
0 g
s
.52357 .38737 m .53777 .39525 L .52818 .40711 L p .694 .677 .829 r
F P
0 g
s
.52818 .40711 m .51402 .39931 L .52357 .38737 L p .694 .677 .829 r
F P
0 g
s
.51239 .63791 m .52826 .64595 L .51761 .65807 L p .688 .695 .852 r
F P
0 g
s
.52826 .64595 m .51239 .63791 L .5231 .62561 L p .688 .695 .852 r
F P
0 g
s
.51763 .59277 m .53357 .60099 L .52284 .61337 L p .688 .694 .85 r
F P
0 g
s
.52284 .61337 m .50694 .60522 L .51763 .59277 L p .688 .694 .85 r
F P
0 g
s
.53413 .76833 m .51826 .76065 L .52901 .7489 L p .686 .7 .857 r
F P
0 g
s
.50709 .61745 m .5231 .62561 L .51239 .63791 L p .688 .695 .852 r
F P
0 g
s
.53437 .70407 m .51829 .6961 L .52918 .6839 L p .687 .699 .856 r
F P
0 g
s
.51853 .70914 m .53472 .71713 L .52381 .72917 L p .686 .7 .857 r
F P
0 g
s
.52381 .72917 m .50767 .72125 L .51853 .70914 L p .686 .7 .857 r
F P
0 g
s
.52087 .76605 m .51402 .39931 L .52818 .40711 L p .835 .484 .391 r
F P
0 g
s
.53918 .78748 m .52344 .77991 L .53413 .76833 L p .686 .7 .857 r
F P
0 g
s
.52818 .40711 m .5384 .77452 L .52087 .76605 L p .835 .484 .391 r
F P
0 g
s
.55035 .76164 m .5384 .77452 L .52818 .40711 L p .18 0 .362 r
F P
0 g
s
.52818 .40711 m .53777 .39525 L .55035 .76164 L p .18 0 .362 r
F P
0 g
s
.51763 .59277 m .51402 .39931 L .52818 .40711 L p .835 .484 .391 r
F P
0 g
s
.52818 .40711 m .53357 .60099 L .51763 .59277 L p .835 .484 .391 r
F P
0 g
s
.55035 .76164 m .5384 .77452 L .52818 .40711 L p .18 0 .362 r
F P
0 g
s
.52818 .40711 m .53777 .39525 L .55035 .76164 L p .18 0 .362 r
F P
0 g
s
.58546 .38709 m .59949 .39496 L .58965 .40683 L p .694 .677 .829 r
F P
0 g
s
.58965 .40683 m .57565 .39902 L .58546 .38709 L p .694 .677 .829 r
F P
0 g
s
.5956 .73685 m .57565 .39902 L .58965 .40683 L p .836 .479 .38 r
F P
0 g
s
.58965 .40683 m .61263 .74529 L .5956 .73685 L p .836 .479 .38 r
F P
0 g
s
.62476 .73246 m .61263 .74529 L .58965 .40683 L p .211 .017 .385 r
F P
0 g
s
.58965 .40683 m .59949 .39496 L .62476 .73246 L p .211 .017 .385 r
F P
0 g
s
.59731 .76575 m .57565 .39902 L .58965 .40683 L p .836 .479 .38 r
F P
0 g
s
.58965 .40683 m .61459 .77422 L .59731 .76575 L p .836 .479 .38 r
F P
0 g
s
.62692 .76133 m .61459 .77422 L .58965 .40683 L p .211 .017 .385 r
F P
0 g
s
.58965 .40683 m .59949 .39496 L .62692 .76133 L p .211 .017 .385 r
F P
0 g
s
.64736 .38681 m .66122 .39468 L .65113 .40655 L p .694 .677 .829 r
F P
0 g
s
.65113 .40655 m .6373 .39874 L .64736 .38681 L p .694 .677 .829 r
F P
0 g
s
.66811 .70852 m .6373 .39874 L .65113 .40655 L p .837 .474 .368 r
F P
0 g
s
.65113 .40655 m .68464 .71692 L .66811 .70852 L p .837 .474 .368 r
F P
0 g
s
.69694 .70415 m .68464 .71692 L .65113 .40655 L p .239 .047 .406 r
F P
0 g
s
.65113 .40655 m .66122 .39468 L .69694 .70415 L p .239 .047 .406 r
F P
0 g
s
.66949 .72243 m .6373 .39874 L .65113 .40655 L p .837 .474 .368 r
F P
0 g
s
.65113 .40655 m .68615 .73085 L .66949 .72243 L p .837 .474 .368 r
F P
0 g
s
.69694 .70415 m .68464 .71692 L .65113 .40655 L p .239 .047 .406 r
F P
0 g
s
.65113 .40655 m .66122 .39468 L .69694 .70415 L p .239 .047 .406 r
F P
0 g
s
.70927 .38652 m .72297 .3944 L .71263 .40627 L p .694 .677 .829 r
F P
0 g
s
.71263 .40627 m .69896 .39846 L .70927 .38652 L p .694 .677 .829 r
F P
0 g
s
.74228 .70822 m .69896 .39846 L .71263 .40627 L p .838 .469 .355 r
F P
0 g
s
.71263 .40627 m .75858 .71662 L .74228 .70822 L p .838 .469 .355 r
F P
0 g
s
.77125 .70384 m .75858 .71662 L .71263 .40627 L p .264 .074 .424 r
F P
0 g
s
.71263 .40627 m .72297 .3944 L .77125 .70384 L p .264 .074 .424 r
F P
0 g
s
.74228 .70822 m .69896 .39846 L .71263 .40627 L p .838 .469 .355 r
F P
0 g
s
.71263 .40627 m .75858 .71662 L .74228 .70822 L p .838 .469 .355 r
F P
0 g
s
.77562 .73185 m .76274 .74468 L .71263 .40627 L p .264 .074 .424 r
F P
0 g
s
.71263 .40627 m .72297 .3944 L .77562 .73185 L p .264 .074 .424 r
F P
0 g
s
.77119 .38624 m .78473 .39411 L .77414 .40599 L p .694 .677 .829 r
F P
0 g
s
.77414 .40599 m .76063 .39818 L .77119 .38624 L p .694 .677 .829 r
F P
0 g
s
.82411 .75027 m .84052 .75873 L .82729 .77147 L p .682 .709 .868 r
F P
0 g
s
.82674 .76483 m .76063 .39818 L .77414 .40599 L p .839 .463 .341 r
F P
0 g
s
.77414 .40599 m .84327 .77331 L .82674 .76483 L p .839 .463 .341 r
F P
0 g
s
.85675 .76041 m .84327 .77331 L .77414 .40599 L p .288 .099 .441 r
F P
0 g
s
.77414 .40599 m .78473 .39411 L .85675 .76041 L p .288 .099 .441 r
F P
0 g
s
.82411 .75027 m .76063 .39818 L .77414 .40599 L p .839 .463 .341 r
F P
0 g
s
.77414 .40599 m .84052 .75873 L .82411 .75027 L p .839 .463 .341 r
F P
0 g
s
.85675 .76041 m .84327 .77331 L .77414 .40599 L p .288 .099 .441 r
F P
0 g
s
.77414 .40599 m .78473 .39411 L .85675 .76041 L p .288 .099 .441 r
F P
0 g
s
.17584 .38499 m .19097 .39287 L .18277 .40476 L p .694 .677 .829 r
F P
0 g
s
.18277 .40476 m .16768 .39694 L .17584 .38499 L p .694 .677 .829 r
F P
0 g
s
.10315 .70658 m .16768 .39694 L .18277 .40476 L p .827 .504 .443 r
F P
0 g
s
.18277 .40476 m .1215 .715 L .10315 .70658 L p .827 .504 .443 r
F P
0 g
s
.1423 .70963 m .12421 .70128 L .13372 .68852 L p .685 .704 .862 r
F P
0 g
s
.13107 .7022 m .1215 .715 L .18277 .40476 L p 0 0 .171 r
F P
0 g
s
.18277 .40476 m .19097 .39287 L .13107 .7022 L p 0 0 .171 r
F P
0 g
s
.10315 .70658 m .16768 .39694 L .18277 .40476 L p .827 .504 .443 r
F P
0 g
s
.18277 .40476 m .1215 .715 L .10315 .70658 L p .827 .504 .443 r
F P
0 g
s
.13372 .68852 m .12421 .70128 L .18277 .40476 L p 0 0 .171 r
F P
0 g
s
.18277 .40476 m .19097 .39287 L .13372 .68852 L p 0 0 .171 r
F P
0 g
s
.23774 .3847 m .25271 .39259 L .24426 .40448 L p .694 .677 .829 r
F P
0 g
s
.24426 .40448 m .22933 .39666 L .23774 .3847 L p .694 .677 .829 r
F P
0 g
s
.17498 .72018 m .22933 .39666 L .24426 .40448 L p .828 .501 .435 r
F P
0 g
s
.24426 .40448 m .19324 .72861 L .17498 .72018 L p .828 .501 .435 r
F P
0 g
s
.20323 .71579 m .19324 .72861 L .24426 .40448 L p 0 0 .214 r
F P
0 g
s
.24426 .40448 m .25271 .39259 L .20323 .71579 L p 0 0 .214 r
F P
0 g
s
.17261 .73429 m .22933 .39666 L .24426 .40448 L p .828 .501 .435 r
F P
0 g
s
.24426 .40448 m .19101 .74275 L .17261 .73429 L p .828 .501 .435 r
F P
0 g
s
.20107 .72989 m .19101 .74275 L .24426 .40448 L p 0 0 .214 r
F P
0 g
s
.24426 .40448 m .25271 .39259 L .20107 .72989 L p 0 0 .214 r
F P
0 g
s
.29966 .38442 m .31446 .39231 L .30576 .4042 L p .694 .677 .829 r
F P
0 g
s
.30576 .4042 m .29099 .39638 L .29966 .38442 L p .694 .677 .829 r
F P
0 g
s
.25833 .6524 m .29099 .39638 L .30576 .4042 L p .83 .498 .426 r
F P
0 g
s
.30576 .4042 m .27567 .66074 L .25833 .6524 L p .83 .498 .426 r
F P
0 g
s
.28569 .64806 m .27567 .66074 L .30576 .4042 L p .036 0 .253 r
F P
0 g
s
.30576 .4042 m .31446 .39231 L .28569 .64806 L p .036 0 .253 r
F P
0 g
s
.25833 .6524 m .29099 .39638 L .30576 .4042 L p .83 .498 .426 r
F P
0 g
s
.30576 .4042 m .27567 .66074 L .25833 .6524 L p .83 .498 .426 r
F P
0 g
s
.27491 .7439 m .2644 .75679 L .30576 .4042 L p .036 0 .253 r
F P
0 g
s
.30576 .4042 m .31446 .39231 L .27491 .7439 L p .036 0 .253 r
F P
0 g
s
.36158 .38414 m .37622 .39202 L .36727 .40392 L p .694 .677 .829 r
F P
0 g
s
.36727 .40392 m .35267 .39609 L .36158 .38414 L p .694 .677 .829 r
F P
0 g
s
.322 .74801 m .35267 .39609 L .36727 .40392 L p .831 .494 .417 r
F P
0 g
s
.36727 .40392 m .34007 .75649 L .322 .74801 L p .831 .494 .417 r
F P
0 g
s
.35095 .7436 m .34007 .75649 L .36727 .40392 L p .08 0 .287 r
F P
0 g
s
.36727 .40392 m .37622 .39202 L .35095 .7436 L p .08 0 .287 r
F P
0 g
s
.32074 .76256 m .35267 .39609 L .36727 .40392 L p .831 .494 .417 r
F P
0 g
s
.36727 .40392 m .33894 .77106 L .32074 .76256 L p .831 .494 .417 r
F P
0 g
s
.34991 .75814 m .33894 .77106 L .36727 .40392 L p .08 0 .287 r
F P
0 g
s
.36727 .40392 m .37622 .39202 L .34991 .75814 L p .08 0 .287 r
F P
0 g
s
.42352 .38385 m .438 .39174 L .4288 .40364 L p .694 .677 .829 r
F P
0 g
s
.4288 .40364 m .41436 .39581 L .42352 .38385 L p .694 .677 .829 r
F P
0 g
s
.39725 .76225 m .41436 .39581 L .4288 .40364 L p .833 .49 .407 r
F P
0 g
s
.4288 .40364 m .41521 .77075 L .39725 .76225 L p .833 .49 .407 r
F P
0 g
s
.43346 .76461 m .41575 .75618 L .42701 .74329 L p .682 .709 .868 r
F P
0 g
s
.42656 .75783 m .41521 .77075 L .4288 .40364 L p .121 0 .318 r
F P
0 g
s
.4288 .40364 m .438 .39174 L .42656 .75783 L p .121 0 .318 r
F P
0 g
s
.39725 .76225 m .41436 .39581 L .4288 .40364 L p .833 .49 .407 r
F P
0 g
s
.4288 .40364 m .41521 .77075 L .39725 .76225 L p .833 .49 .407 r
F P
0 g
s
.42701 .74329 m .41575 .75618 L .4288 .40364 L p .121 0 .318 r
F P
0 g
s
.4288 .40364 m .438 .39174 L .42701 .74329 L p .121 0 .318 r
F P
0 g
s
.48547 .38357 m .49978 .39146 L .49033 .40336 L p .694 .677 .829 r
F P
0 g
s
.49033 .40336 m .47606 .39553 L .48547 .38357 L p .694 .677 .829 r
F P
0 g
s
.47501 .56493 m .47606 .39553 L .49033 .40336 L p .834 .486 .397 r
F P
0 g
s
.49033 .40336 m .49087 .57313 L .47501 .56493 L p .834 .486 .397 r
F P
0 g
s
.50138 .56067 m .49087 .57313 L .49033 .40336 L p .157 0 .346 r
F P
0 g
s
.49033 .40336 m .49978 .39146 L .50138 .56067 L p .157 0 .346 r
F P
0 g
s
.47494 .57678 m .47606 .39553 L .49033 .40336 L p .834 .486 .397 r
F P
0 g
s
.49033 .40336 m .49091 .585 L .47494 .57678 L p .834 .486 .397 r
F P
0 g
s
.50149 .5725 m .49091 .585 L .49033 .40336 L p .157 0 .346 r
F P
0 g
s
.49033 .40336 m .49978 .39146 L .50149 .5725 L p .157 0 .346 r
F P
0 g
s
.54743 .38328 m .56158 .39117 L .55188 .40307 L p .694 .677 .829 r
F P
0 g
s
.55188 .40307 m .53777 .39525 L .54743 .38328 L p .694 .677 .829 r
F P
0 g
s
.55035 .76164 m .53777 .39525 L .55188 .40307 L p .835 .482 .386 r
F P
0 g
s
.55188 .40307 m .56781 .77014 L .55035 .76164 L p .835 .482 .386 r
F P
0 g
s
.58439 .764 m .56717 .75557 L .57919 .74268 L p .682 .709 .868 r
F P
0 g
s
.57992 .75722 m .56781 .77014 L .55188 .40307 L p .19 0 .37 r
F P
0 g
s
.55188 .40307 m .56158 .39117 L .57992 .75722 L p .19 0 .37 r
F P
0 g
s
.55035 .76164 m .53777 .39525 L .55188 .40307 L p .835 .482 .386 r
F P
0 g
s
.55188 .40307 m .56781 .77014 L .55035 .76164 L p .835 .482 .386 r
F P
0 g
s
.57919 .74268 m .56717 .75557 L .55188 .40307 L p .19 0 .37 r
F P
0 g
s
.55188 .40307 m .56158 .39117 L .57919 .74268 L p .19 0 .37 r
F P
0 g
s
.60941 .383 m .62339 .39089 L .61344 .40279 L p .694 .677 .829 r
F P
0 g
s
.61344 .40279 m .59949 .39496 L .60941 .383 L p .694 .677 .829 r
F P
0 g
s
.62583 .74679 m .59949 .39496 L .61344 .40279 L p .836 .477 .374 r
F P
0 g
s
.61344 .40279 m .64291 .75527 L .62583 .74679 L p .836 .477 .374 r
F P
0 g
s
.65531 .74237 m .64291 .75527 L .61344 .40279 L p .22 .027 .392 r
F P
0 g
s
.61344 .40279 m .62339 .39089 L .65531 .74237 L p .22 .027 .392 r
F P
0 g
s
.62692 .76133 m .59949 .39496 L .61344 .40279 L p .836 .477 .374 r
F P
0 g
s
.61344 .40279 m .64413 .76984 L .62692 .76133 L p .836 .477 .374 r
F P
0 g
s
.65663 .75691 m .64413 .76984 L .61344 .40279 L p .22 .027 .392 r
F P
0 g
s
.61344 .40279 m .62339 .39089 L .65663 .75691 L p .22 .027 .392 r
F P
0 g
s
.67139 .38271 m .68521 .39061 L .67501 .40251 L p .694 .677 .829 r
F P
0 g
s
.67501 .40251 m .66122 .39468 L .67139 .38271 L p .694 .677 .829 r
F P
0 g
s
.69694 .70415 m .66122 .39468 L .67501 .40251 L p .837 .472 .362 r
F P
0 g
s
.67501 .40251 m .71342 .71258 L .69694 .70415 L p .837 .472 .362 r
F P
0 g
s
.72797 .70723 m .71172 .69887 L .72408 .68608 L p .685 .704 .862 r
F P
0 g
s
.72588 .69976 m .71342 .71258 L .67501 .40251 L p .248 .056 .412 r
F P
0 g
s
.67501 .40251 m .68521 .39061 L .72588 .69976 L p .248 .056 .412 r
F P
0 g
s
.69694 .70415 m .66122 .39468 L .67501 .40251 L p .837 .472 .362 r
F P
0 g
s
.67501 .40251 m .71342 .71258 L .69694 .70415 L p .837 .472 .362 r
F P
0 g
s
.72408 .68608 m .71172 .69887 L .67501 .40251 L p .248 .056 .412 r
F P
0 g
s
.67501 .40251 m .68521 .39061 L .72408 .68608 L p .248 .056 .412 r
F P
0 g
s
.73339 .38243 m .74704 .39032 L .7366 .40223 L p .694 .677 .829 r
F P
0 g
s
.7366 .40223 m .72297 .3944 L .73339 .38243 L p .694 .677 .829 r
F P
0 g
s
.77341 .71774 m .72297 .3944 L .7366 .40223 L p .838 .466 .348 r
F P
0 g
s
.7366 .40223 m .78977 .72619 L .77341 .71774 L p .838 .466 .348 r
F P
0 g
s
.8027 .71334 m .78977 .72619 L .7366 .40223 L p .272 .082 .43 r
F P
0 g
s
.7366 .40223 m .74704 .39032 L .8027 .71334 L p .272 .082 .43 r
F P
0 g
s
.77562 .73185 m .72297 .3944 L .7366 .40223 L p .838 .466 .348 r
F P
0 g
s
.7366 .40223 m .79208 .74032 L .77562 .73185 L p .838 .466 .348 r
F P
0 g
s
.80513 .72744 m .79208 .74032 L .7366 .40223 L p .272 .082 .43 r
F P
0 g
s
.7366 .40223 m .74704 .39032 L .80513 .72744 L p .272 .082 .43 r
F P
0 g
s
.7954 .38214 m .80889 .39004 L .79819 .40195 L p .694 .677 .829 r
F P
0 g
s
.79819 .40195 m .78473 .39411 L .7954 .38214 L p .694 .677 .829 r
F P
0 g
s
.85675 .76041 m .78473 .39411 L .79819 .40195 L p .839 .46 .334 r
F P
0 g
s
.79819 .40195 m .87321 .76892 L .85675 .76041 L p .839 .46 .334 r
F P
0 g
s
.88686 .75598 m .87321 .76892 L .79819 .40195 L p .295 .107 .446 r
F P
0 g
s
.79819 .40195 m .80889 .39004 L .88686 .75598 L p .295 .107 .446 r
F P
0 g
s
.85675 .76041 m .78473 .39411 L .79819 .40195 L p .839 .46 .334 r
F P
0 g
s
.79819 .40195 m .87321 .76892 L .85675 .76041 L p .839 .46 .334 r
F P
0 g
s
.08468 .69811 m .07532 .71095 L .14445 .401 L p 0 0 .14 r
F P
0 g
s
.14445 .401 m .15251 .38908 L .08468 .69811 L p 0 0 .14 r
F P
0 g
s
.19924 .38089 m .21432 .38879 L .20602 .40071 L p .694 .677 .829 r
F P
0 g
s
.20602 .40071 m .19097 .39287 L .19924 .38089 L p .694 .677 .829 r
F P
0 g
s
.13372 .68852 m .15186 .69694 L .1423 .70963 L p .685 .704 .862 r
F P
0 g
s
.13107 .7022 m .19097 .39287 L .20602 .40071 L p .828 .503 .439 r
F P
0 g
s
.20602 .40071 m .14936 .71064 L .13107 .7022 L p .828 .503 .439 r
F P
0 g
s
.15908 .69781 m .14936 .71064 L .20602 .40071 L p 0 0 .186 r
F P
0 g
s
.20602 .40071 m .21432 .38879 L .15908 .69781 L p 0 0 .186 r
F P
0 g
s
.13372 .68852 m .19097 .39287 L .20602 .40071 L p .828 .503 .439 r
F P
0 g
s
.20602 .40071 m .15186 .69694 L .13372 .68852 L p .828 .503 .439 r
F P
0 g
s
.15908 .69781 m .14936 .71064 L .20602 .40071 L p 0 0 .186 r
F P
0 g
s
.20602 .40071 m .21432 .38879 L .15908 .69781 L p 0 0 .186 r
F P
0 g
s
.26123 .3806 m .27615 .38851 L .2676 .40043 L p .694 .677 .829 r
F P
0 g
s
.2676 .40043 m .25271 .39259 L .26123 .3806 L p .694 .677 .829 r
F P
0 g
s
.21355 .64836 m .25271 .39259 L .2676 .40043 L p .829 .499 .43 r
F P
0 g
s
.2676 .40043 m .23106 .65673 L .21355 .64836 L p .829 .499 .43 r
F P
0 g
s
.24088 .64401 m .23106 .65673 L .2676 .40043 L p .004 0 .228 r
F P
0 g
s
.2676 .40043 m .27615 .38851 L .24088 .64401 L p .004 0 .228 r
F P
0 g
s
.20107 .72989 m .25271 .39259 L .2676 .40043 L p .829 .499 .43 r
F P
0 g
s
.2676 .40043 m .21942 .73837 L .20107 .72989 L p .829 .499 .43 r
F P
0 g
s
.24088 .64401 m .23106 .65673 L .2676 .40043 L p .004 0 .228 r
F P
0 g
s
.2676 .40043 m .27615 .38851 L .24088 .64401 L p .004 0 .228 r
F P
0 g
s
.32323 .38032 m .33799 .38823 L .32918 .40015 L p .694 .677 .829 r
F P
0 g
s
.32918 .40015 m .31446 .39231 L .32323 .38032 L p .694 .677 .829 r
F P
0 g
s
.27652 .72958 m .31446 .39231 L .32918 .40015 L p .831 .496 .421 r
F P
0 g
s
.32918 .40015 m .29462 .73807 L .27652 .72958 L p .831 .496 .421 r
F P
0 g
s
.30521 .72517 m .29462 .73807 L .32918 .40015 L p .051 0 .265 r
F P
0 g
s
.32918 .40015 m .33799 .38823 L .30521 .72517 L p .051 0 .265 r
F P
0 g
s
.27491 .7439 m .31446 .39231 L .32918 .40015 L p .831 .496 .421 r
F P
0 g
s
.32918 .40015 m .29315 .75241 L .27491 .7439 L p .831 .496 .421 r
F P
0 g
s
.30521 .72517 m .29462 .73807 L .32918 .40015 L p .051 0 .265 r
F P
0 g
s
.32918 .40015 m .33799 .38823 L .30521 .72517 L p .051 0 .265 r
F P
0 g
s
.38524 .38003 m .39984 .38794 L .39078 .39987 L p .694 .677 .829 r
F P
0 g
s
.39078 .39987 m .37622 .39202 L .38524 .38003 L p .694 .677 .829 r
F P
0 g
s
.35399 .70129 m .37622 .39202 L .39078 .39987 L p .832 .492 .412 r
F P
0 g
s
.39078 .39987 m .37158 .70974 L .35399 .70129 L p .832 .492 .412 r
F P
0 g
s
.38239 .69689 m .37158 .70974 L .39078 .39987 L p .094 0 .298 r
F P
0 g
s
.39078 .39987 m .39984 .38794 L .38239 .69689 L p .094 0 .298 r
F P
0 g
s
.34991 .75814 m .37622 .39202 L .39078 .39987 L p .832 .492 .412 r
F P
0 g
s
.39078 .39987 m .36805 .76666 L .34991 .75814 L p .832 .492 .412 r
F P
0 g
s
.37918 .7537 m .36805 .76666 L .39078 .39987 L p .094 0 .298 r
F P
0 g
s
.39078 .39987 m .39984 .38794 L .37918 .7537 L p .094 0 .298 r
F P
0 g
s
.44727 .37975 m .4617 .38766 L .45239 .39959 L p .694 .677 .829 r
F P
0 g
s
.45239 .39959 m .438 .39174 L .44727 .37975 L p .694 .677 .829 r
F P
0 g
s
.42701 .74329 m .44477 .7518 L .43346 .76461 L p .682 .709 .868 r
F P
0 g
s
.42656 .75783 m .438 .39174 L .45239 .39959 L p .833 .488 .402 r
F P
0 g
s
.45239 .39959 m .44445 .76636 L .42656 .75783 L p .833 .488 .402 r
F P
0 g
s
.45596 .75339 m .44445 .76636 L .45239 .39959 L p .133 0 .328 r
F P
0 g
s
.45239 .39959 m .4617 .38766 L .45596 .75339 L p .133 0 .328 r
F P
0 g
s
.42701 .74329 m .438 .39174 L .45239 .39959 L p .833 .488 .402 r
F P
0 g
s
.45239 .39959 m .44477 .7518 L .42701 .74329 L p .833 .488 .402 r
F P
0 g
s
.45596 .75339 m .44445 .76636 L .45239 .39959 L p .133 0 .328 r
F P
0 g
s
.45239 .39959 m .4617 .38766 L .45596 .75339 L p .133 0 .328 r
F P
0 g
s
.50931 .37946 m .52357 .38737 L .51402 .39931 L p .694 .677 .829 r
F P
0 g
s
.51402 .39931 m .49978 .39146 L .50931 .37946 L p .694 .677 .829 r
F P
0 g
s
.50178 .6501 m .51761 .65807 L .50705 .67007 L p .688 .695 .852 r
F P
0 g
s
.50705 .67007 m .49126 .66218 L .50178 .6501 L p .688 .695 .852 r
F P
0 g
s
.49091 .585 m .50679 .59317 L .49627 .60548 L p .689 .693 .849 r
F P
0 g
s
.51761 .65807 m .50178 .6501 L .51239 .63791 L p .688 .695 .852 r
F P
0 g
s
.50149 .5725 m .51741 .58075 L .50679 .59317 L p .689 .693 .849 r
F P
0 g
s
.50679 .59317 m .49091 .585 L .50149 .5725 L p .689 .693 .849 r
F P
0 g
s
.5023 .75292 m .51826 .76065 L .50761 .7723 L p .686 .7 .857 r
F P
0 g
s
.50761 .7723 m .49169 .76464 L .5023 .75292 L p .686 .7 .857 r
F P
0 g
s
.51239 .63791 m .49642 .62982 L .50709 .61745 L p .688 .695 .852 r
F P
0 g
s
.49142 .71328 m .50767 .72125 L .4969 .73325 L p .686 .7 .857 r
F P
0 g
s
.50323 .75752 m .49978 .39146 L .51402 .39931 L p .835 .484 .391 r
F P
0 g
s
.51402 .39931 m .52087 .76605 L .50323 .75752 L p .835 .484 .391 r
F P
0 g
s
.53277 .75308 m .52087 .76605 L .51402 .39931 L p .169 0 .354 r
F P
0 g
s
.51402 .39931 m .52357 .38737 L .53277 .75308 L p .169 0 .354 r
F P
0 g
s
.50149 .5725 m .49978 .39146 L .51402 .39931 L p .835 .484 .391 r
F P
0 g
s
.51402 .39931 m .51741 .58075 L .50149 .5725 L p .835 .484 .391 r
F P
0 g
s
.53277 .75308 m .52087 .76605 L .51402 .39931 L p .169 0 .354 r
F P
0 g
s
.51402 .39931 m .52357 .38737 L .53277 .75308 L p .169 0 .354 r
F P
0 g
s
.57136 .37918 m .58546 .38709 L .57565 .39902 L p .694 .677 .829 r
F P
0 g
s
.57565 .39902 m .56158 .39117 L .57136 .37918 L p .694 .677 .829 r
F P
0 g
s
.57847 .72836 m .56158 .39117 L .57565 .39902 L p .836 .479 .38 r
F P
0 g
s
.57565 .39902 m .5956 .73685 L .57847 .72836 L p .836 .479 .38 r
F P
0 g
s
.60769 .72394 m .5956 .73685 L .57565 .39902 L p .201 .006 .378 r
F P
0 g
s
.57565 .39902 m .58546 .38709 L .60769 .72394 L p .201 .006 .378 r
F P
0 g
s
.57919 .74268 m .56158 .39117 L .57565 .39902 L p .836 .479 .38 r
F P
0 g
s
.57565 .39902 m .59645 .75119 L .57919 .74268 L p .836 .479 .38 r
F P
0 g
s
.60769 .72394 m .5956 .73685 L .57565 .39902 L p .201 .006 .378 r
F P
0 g
s
.57565 .39902 m .58546 .38709 L .60769 .72394 L p .201 .006 .378 r
F P
0 g
s
.63342 .37889 m .64736 .38681 L .6373 .39874 L p .694 .677 .829 r
F P
0 g
s
.6373 .39874 m .62339 .39089 L .63342 .37889 L p .694 .677 .829 r
F P
0 g
s
.65663 .75691 m .62339 .39089 L .6373 .39874 L p .837 .474 .368 r
F P
0 g
s
.6373 .39874 m .67377 .76544 L .65663 .75691 L p .837 .474 .368 r
F P
0 g
s
.68464 .71692 m .66811 .70852 L .68037 .69566 L p .684 .705 .863 r
F P
0 g
s
.67529 .75769 m .69192 .766 L .67962 .7785 L p .683 .708 .867 r
F P
0 g
s
.66949 .72243 m .68615 .73085 L .67387 .74353 L p .683 .706 .865 r
F P
0 g
s
.69192 .766 m .67529 .75769 L .68767 .74499 L p .683 .708 .867 r
F P
0 g
s
.68644 .75247 m .67377 .76544 L .6373 .39874 L p .23 .037 .399 r
F P
0 g
s
.6373 .39874 m .64736 .38681 L .68644 .75247 L p .23 .037 .399 r
F P
0 g
s
.65663 .75691 m .62339 .39089 L .6373 .39874 L p .837 .474 .368 r
F P
0 g
s
.6373 .39874 m .67377 .76544 L .65663 .75691 L p .837 .474 .368 r
F P
0 g
s
.68037 .69566 m .66811 .70852 L .6373 .39874 L p .23 .037 .399 r
F P
0 g
s
.6373 .39874 m .64736 .38681 L .68037 .69566 L p .23 .037 .399 r
F P
0 g
s
.69549 .3786 m .70927 .38652 L .69896 .39846 L p .694 .677 .829 r
F P
0 g
s
.69896 .39846 m .68521 .39061 L .69549 .3786 L p .694 .677 .829 r
F P
0 g
s
.72408 .68608 m .74037 .69452 L .72797 .70723 L p .685 .704 .862 r
F P
0 g
s
.72588 .69976 m .68521 .39061 L .69896 .39846 L p .838 .469 .355 r
F P
0 g
s
.69896 .39846 m .74228 .70822 L .72588 .69976 L p .838 .469 .355 r
F P
0 g
s
.75491 .69536 m .74228 .70822 L .69896 .39846 L p .256 .065 .418 r
F P
0 g
s
.69896 .39846 m .70927 .38652 L .75491 .69536 L p .256 .065 .418 r
F P
0 g
s
.72408 .68608 m .68521 .39061 L .69896 .39846 L p .838 .469 .355 r
F P
0 g
s
.69896 .39846 m .74037 .69452 L .72408 .68608 L p .838 .469 .355 r
F P
0 g
s
.75491 .69536 m .74228 .70822 L .69896 .39846 L p .256 .065 .418 r
F P
0 g
s
.69896 .39846 m .70927 .38652 L .75491 .69536 L p .256 .065 .418 r
F P
0 g
s
.75758 .37832 m .77119 .38624 L .76063 .39818 L p .694 .677 .829 r
F P
0 g
s
.76063 .39818 m .74704 .39032 L .75758 .37832 L p .694 .677 .829 r
F P
0 g
s
.80513 .72744 m .82153 .73594 L .80845 .74873 L p .683 .708 .867 r
F P
0 g
s
.8101 .75629 m .74704 .39032 L .76063 .39818 L p .839 .463 .341 r
F P
0 g
s
.82729 .77147 m .81092 .76309 L .82411 .75027 L p .682 .709 .868 r
F P
0 g
s
.76063 .39818 m .82674 .76483 L .8101 .75629 L p .839 .463 .341 r
F P
0 g
s
.84018 .75185 m .82674 .76483 L .76063 .39818 L p .28 .091 .436 r
F P
0 g
s
.76063 .39818 m .77119 .38624 L .84018 .75185 L p .28 .091 .436 r
F P
0 g
s
.80513 .72744 m .74704 .39032 L .76063 .39818 L p .839 .463 .341 r
F P
0 g
s
.76063 .39818 m .82153 .73594 L .80513 .72744 L p .839 .463 .341 r
F P
0 g
s
.84018 .75185 m .82674 .76483 L .76063 .39818 L p .28 .091 .436 r
F P
0 g
s
.76063 .39818 m .77119 .38624 L .84018 .75185 L p .28 .091 .436 r
F P
0 g
s
.16063 .37706 m .17584 .38499 L .16768 .39694 L p .694 .677 .829 r
F P
0 g
s
.16768 .39694 m .15251 .38908 L .16063 .37706 L p .694 .677 .829 r
F P
0 g
s
.08768 .68444 m .15251 .38908 L .16768 .39694 L p .827 .504 .443 r
F P
0 g
s
.16768 .39694 m .106 .69289 L .08768 .68444 L p .827 .504 .443 r
F P
0 g
s
.11545 .68004 m .106 .69289 L .16768 .39694 L p 0 0 .156 r
F P
0 g
s
.16768 .39694 m .17584 .38499 L .11545 .68004 L p 0 0 .156 r
F P
0 g
s
.08468 .69811 m .15251 .38908 L .16768 .39694 L p .827 .504 .443 r
F P
0 g
s
.16768 .39694 m .10315 .70658 L .08468 .69811 L p .827 .504 .443 r
F P
0 g
s
.11266 .6937 m .10315 .70658 L .16768 .39694 L p 0 0 .156 r
F P
0 g
s
.16768 .39694 m .17584 .38499 L .11266 .6937 L p 0 0 .156 r
F P
0 g
s
.2227 .37678 m .23774 .3847 L .22933 .39666 L p .694 .677 .829 r
F P
0 g
s
.22933 .39666 m .21432 .38879 L .2227 .37678 L p .694 .677 .829 r
F P
0 g
s
.15908 .69781 m .21432 .38879 L .22933 .39666 L p .828 .501 .435 r
F P
0 g
s
.22933 .39666 m .17731 .70628 L .15908 .69781 L p .828 .501 .435 r
F P
0 g
s
.18719 .6934 m .17731 .70628 L .22933 .39666 L p 0 0 .2 r
F P
0 g
s
.22933 .39666 m .23774 .3847 L .18719 .6934 L p 0 0 .2 r
F P
0 g
s
.15908 .69781 m .21432 .38879 L .22933 .39666 L p .828 .501 .435 r
F P
0 g
s
.22933 .39666 m .17731 .70628 L .15908 .69781 L p .828 .501 .435 r
F P
0 g
s
.18491 .70727 m .17498 .72018 L .22933 .39666 L p 0 0 .2 r
F P
0 g
s
.22933 .39666 m .23774 .3847 L .18491 .70727 L p 0 0 .2 r
F P
0 g
s
.28477 .37649 m .29966 .38442 L .29099 .39638 L p .694 .677 .829 r
F P
0 g
s
.29099 .39638 m .27615 .38851 L .28477 .37649 L p .694 .677 .829 r
F P
0 g
s
.24266 .63113 m .27615 .38851 L .29099 .39638 L p .83 .498 .426 r
F P
0 g
s
.29099 .39638 m .25998 .6395 L .24266 .63113 L p .83 .498 .426 r
F P
0 g
s
.26988 .62677 m .25998 .6395 L .29099 .39638 L p .02 0 .24 r
F P
0 g
s
.29099 .39638 m .29966 .38442 L .26988 .62677 L p .02 0 .24 r
F P
0 g
s
.24088 .64401 m .27615 .38851 L .29099 .39638 L p .83 .498 .426 r
F P
0 g
s
.29099 .39638 m .25833 .6524 L .24088 .64401 L p .83 .498 .426 r
F P
0 g
s
.2683 .63964 m .25833 .6524 L .29099 .39638 L p .02 0 .24 r
F P
0 g
s
.29099 .39638 m .29966 .38442 L .2683 .63964 L p .02 0 .24 r
F P
0 g
s
.34686 .3762 m .36158 .38414 L .35267 .39609 L p .694 .677 .829 r
F P
0 g
s
.35267 .39609 m .33799 .38823 L .34686 .3762 L p .694 .677 .829 r
F P
0 g
s
.30521 .72517 m .33799 .38823 L .35267 .39609 L p .831 .494 .417 r
F P
0 g
s
.35267 .39609 m .32325 .73368 L .30521 .72517 L p .831 .494 .417 r
F P
0 g
s
.334 .72074 m .32325 .73368 L .35267 .39609 L p .066 0 .276 r
F P
0 g
s
.35267 .39609 m .36158 .38414 L .334 .72074 L p .066 0 .276 r
F P
0 g
s
.30521 .72517 m .33799 .38823 L .35267 .39609 L p .831 .494 .417 r
F P
0 g
s
.35267 .39609 m .32325 .73368 L .30521 .72517 L p .831 .494 .417 r
F P
0 g
s
.33283 .73504 m .322 .74801 L .35267 .39609 L p .066 0 .276 r
F P
0 g
s
.35267 .39609 m .36158 .38414 L .33283 .73504 L p .066 0 .276 r
F P
0 g
s
.40897 .37592 m .42352 .38385 L .41436 .39581 L p .694 .677 .829 r
F P
0 g
s
.41436 .39581 m .39984 .38794 L .40897 .37592 L p .694 .677 .829 r
F P
0 g
s
.38 .73917 m .39984 .38794 L .41436 .39581 L p .833 .49 .407 r
F P
0 g
s
.41436 .39581 m .39793 .7477 L .38 .73917 L p .833 .49 .407 r
F P
0 g
s
.40914 .73473 m .39793 .7477 L .41436 .39581 L p .108 0 .308 r
F P
0 g
s
.41436 .39581 m .42352 .38385 L .40914 .73473 L p .108 0 .308 r
F P
0 g
s
.37918 .7537 m .39984 .38794 L .41436 .39581 L p .833 .49 .407 r
F P
0 g
s
.41436 .39581 m .39725 .76225 L .37918 .7537 L p .833 .49 .407 r
F P
0 g
s
.40855 .74925 m .39725 .76225 L .41436 .39581 L p .108 0 .308 r
F P
0 g
s
.41436 .39581 m .42352 .38385 L .40855 .74925 L p .108 0 .308 r
F P
0 g
s
.47108 .37563 m .48547 .38357 L .47606 .39553 L p .694 .677 .829 r
F P
0 g
s
.47606 .39553 m .4617 .38766 L .47108 .37563 L p .694 .677 .829 r
F P
0 g
s
.45596 .75339 m .4617 .38766 L .47606 .39553 L p .834 .486 .397 r
F P
0 g
s
.47606 .39553 m .47379 .76195 L .45596 .75339 L p .834 .486 .397 r
F P
0 g
s
.49627 .60548 m .48043 .59738 L .49091 .585 L p .689 .693 .849 r
F P
0 g
s
.49087 .57313 m .47501 .56493 L .48547 .5524 L p .689 .692 .848 r
F P
0 g
s
.49126 .66218 m .47537 .65423 L .48585 .64208 L p .688 .695 .852 r
F P
0 g
s
.47494 .57678 m .49091 .585 L .48043 .59738 L p .689 .693 .849 r
F P
0 g
s
.47566 .75693 m .49169 .76464 L .48117 .77625 L p .686 .7 .857 r
F P
0 g
s
.48036 .62169 m .49642 .62982 L .48585 .64208 L p .688 .695 .852 r
F P
0 g
s
.4807 .72536 m .4969 .73325 L .48623 .74515 L p .686 .7 .857 r
F P
0 g
s
.47515 .69224 m .49138 .70024 L .48073 .71229 L p .687 .699 .856 r
F P
0 g
s
.4969 .73325 m .4807 .72536 L .49142 .71328 L p .686 .7 .857 r
F P
0 g
s
.48547 .74894 m .47379 .76195 L .47606 .39553 L p .145 0 .337 r
F P
0 g
s
.47606 .39553 m .48547 .38357 L .48547 .74894 L p .145 0 .337 r
F P
0 g
s
.45596 .75339 m .4617 .38766 L .47606 .39553 L p .834 .486 .397 r
F P
0 g
s
.47606 .39553 m .47379 .76195 L .45596 .75339 L p .834 .486 .397 r
F P
0 g
s
.48547 .5524 m .47501 .56493 L .47606 .39553 L p .145 0 .337 r
F P
0 g
s
.47606 .39553 m .48547 .38357 L .48547 .5524 L p .145 0 .337 r
F P
0 g
s
.53321 .37535 m .54743 .38328 L .53777 .39525 L p .694 .677 .829 r
F P
0 g
s
.53777 .39525 m .52357 .38737 L .53321 .37535 L p .694 .677 .829 r
F P
0 g
s
.5324 .73855 m .52357 .38737 L .53777 .39525 L p .835 .482 .386 r
F P
0 g
s
.53777 .39525 m .54985 .74709 L .5324 .73855 L p .835 .482 .386 r
F P
0 g
s
.56182 .73411 m .54985 .74709 L .53777 .39525 L p .18 0 .362 r
F P
0 g
s
.53777 .39525 m .54743 .38328 L .56182 .73411 L p .18 0 .362 r
F P
0 g
s
.53277 .75308 m .52357 .38737 L .53777 .39525 L p .835 .482 .386 r
F P
0 g
s
.53777 .39525 m .55035 .76164 L .53277 .75308 L p .835 .482 .386 r
F P
0 g
s
.56241 .74863 m .55035 .76164 L .53777 .39525 L p .18 0 .362 r
F P
0 g
s
.53777 .39525 m .54743 .38328 L .56241 .74863 L p .18 0 .362 r
F P
0 g
s
.59535 .37506 m .60941 .383 L .59949 .39496 L p .694 .677 .829 r
F P
0 g
s
.59949 .39496 m .58546 .38709 L .59535 .37506 L p .694 .677 .829 r
F P
0 g
s
.60769 .72394 m .58546 .38709 L .59949 .39496 L p .836 .477 .374 r
F P
0 g
s
.59949 .39496 m .62476 .73246 L .60769 .72394 L p .836 .477 .374 r
F P
0 g
s
.63701 .7195 m .62476 .73246 L .59949 .39496 L p .211 .017 .385 r
F P
0 g
s
.59949 .39496 m .60941 .383 L .63701 .7195 L p .211 .017 .385 r
F P
0 g
s
.60769 .72394 m .58546 .38709 L .59949 .39496 L p .836 .477 .374 r
F P
0 g
s
.59949 .39496 m .62476 .73246 L .60769 .72394 L p .836 .477 .374 r
F P
0 g
s
.63818 .7338 m .62583 .74679 L .59949 .39496 L p .211 .017 .385 r
F P
0 g
s
.59949 .39496 m .60941 .383 L .63818 .7338 L p .211 .017 .385 r
F P
0 g
s
.6575 .37477 m .67139 .38271 L .66122 .39468 L p .694 .677 .829 r
F P
0 g
s
.66122 .39468 m .64736 .38681 L .6575 .37477 L p .694 .677 .829 r
F P
0 g
s
.67891 .682 m .64736 .38681 L .66122 .39468 L p .837 .472 .362 r
F P
0 g
s
.66122 .39468 m .69536 .69046 L .67891 .682 L p .837 .472 .362 r
F P
0 g
s
.70768 .67759 m .69536 .69046 L .66122 .39468 L p .239 .047 .406 r
F P
0 g
s
.66122 .39468 m .67139 .38271 L .70768 .67759 L p .239 .047 .406 r
F P
0 g
s
.68037 .69566 m .64736 .38681 L .66122 .39468 L p .837 .472 .362 r
F P
0 g
s
.66122 .39468 m .69694 .70415 L .68037 .69566 L p .837 .472 .362 r
F P
0 g
s
.70937 .69125 m .69694 .70415 L .66122 .39468 L p .239 .047 .406 r
F P
0 g
s
.66122 .39468 m .67139 .38271 L .70937 .69125 L p .239 .047 .406 r
F P
0 g
s
.71966 .37449 m .73339 .38243 L .72297 .3944 L p .694 .677 .829 r
F P
0 g
s
.72297 .3944 m .70927 .38652 L .71966 .37449 L p .694 .677 .829 r
F P
0 g
s
.75491 .69536 m .70927 .38652 L .72297 .3944 L p .838 .466 .348 r
F P
0 g
s
.72297 .3944 m .77125 .70384 L .75491 .69536 L p .838 .466 .348 r
F P
0 g
s
.78403 .69094 m .77125 .70384 L .72297 .3944 L p .264 .074 .424 r
F P
0 g
s
.72297 .3944 m .73339 .38243 L .78403 .69094 L p .264 .074 .424 r
F P
0 g
s
.75491 .69536 m .70927 .38652 L .72297 .3944 L p .838 .466 .348 r
F P
0 g
s
.72297 .3944 m .77125 .70384 L .75491 .69536 L p .838 .466 .348 r
F P
0 g
s
.78631 .70481 m .77341 .71774 L .72297 .3944 L p .264 .074 .424 r
F P
0 g
s
.72297 .3944 m .73339 .38243 L .78631 .70481 L p .264 .074 .424 r
F P
0 g
s
.78183 .3742 m .7954 .38214 L .78473 .39411 L p .694 .677 .829 r
F P
0 g
s
.78473 .39411 m .77119 .38624 L .78183 .3742 L p .694 .677 .829 r
F P
0 g
s
.83744 .73732 m .77119 .38624 L .78473 .39411 L p .839 .46 .334 r
F P
0 g
s
.78473 .39411 m .85389 .74587 L .83744 .73732 L p .839 .46 .334 r
F P
0 g
s
.86738 .73287 m .85389 .74587 L .78473 .39411 L p .288 .099 .441 r
F P
0 g
s
.78473 .39411 m .7954 .38214 L .86738 .73287 L p .288 .099 .441 r
F P
0 g
s
.84018 .75185 m .77119 .38624 L .78473 .39411 L p .839 .46 .334 r
F P
0 g
s
.78473 .39411 m .85675 .76041 L .84018 .75185 L p .839 .46 .334 r
F P
0 g
s
.87036 .74739 m .85675 .76041 L .78473 .39411 L p .288 .099 .441 r
F P
0 g
s
.78473 .39411 m .7954 .38214 L .87036 .74739 L p .288 .099 .441 r
F P
0 g
s
.18407 .37294 m .19924 .38089 L .19097 .39287 L p .694 .677 .829 r
F P
0 g
s
.19097 .39287 m .17584 .38499 L .18407 .37294 L p .694 .677 .829 r
F P
0 g
s
.11821 .66658 m .17584 .38499 L .19097 .39287 L p .828 .503 .439 r
F P
0 g
s
.19097 .39287 m .13633 .67504 L .11821 .66658 L p .828 .503 .439 r
F P
0 g
s
.14587 .66218 m .13633 .67504 L .19097 .39287 L p 0 0 .171 r
F P
0 g
s
.19097 .39287 m .19924 .38089 L .14587 .66218 L p 0 0 .171 r
F P
0 g
s
.11266 .6937 m .17584 .38499 L .19097 .39287 L p .828 .503 .439 r
F P
0 g
s
.19097 .39287 m .13107 .7022 L .11266 .6937 L p .828 .503 .439 r
F P
0 g
s
.14073 .68928 m .13107 .7022 L .19097 .39287 L p 0 0 .171 r
F P
0 g
s
.19097 .39287 m .19924 .38089 L .14073 .68928 L p 0 0 .171 r
F P
0 g
s
.24622 .37265 m .26123 .3806 L .25271 .39259 L p .694 .677 .829 r
F P
0 g
s
.25271 .39259 m .23774 .3847 L .24622 .37265 L p .694 .677 .829 r
F P
0 g
s
.19594 .63995 m .23774 .3847 L .25271 .39259 L p .829 .499 .43 r
F P
0 g
s
.25271 .39259 m .21355 .64836 L .19594 .63995 L p .829 .499 .43 r
F P
0 g
s
.22332 .63557 m .21355 .64836 L .25271 .39259 L p 0 0 .214 r
F P
0 g
s
.25271 .39259 m .26123 .3806 L .22332 .63557 L p 0 0 .214 r
F P
0 g
s
.18491 .70727 m .23774 .3847 L .25271 .39259 L p .829 .499 .43 r
F P
0 g
s
.25271 .39259 m .20323 .71579 L .18491 .70727 L p .829 .499 .43 r
F P
0 g
s
.22332 .63557 m .21355 .64836 L .25271 .39259 L p 0 0 .214 r
F P
0 g
s
.25271 .39259 m .26123 .3806 L .22332 .63557 L p 0 0 .214 r
F P
0 g
s
.30839 .37237 m .32323 .38032 L .31446 .39231 L p .694 .677 .829 r
F P
0 g
s
.31446 .39231 m .29966 .38442 L .30839 .37237 L p .694 .677 .829 r
F P
0 g
s
.2683 .63964 m .29966 .38442 L .31446 .39231 L p .831 .496 .421 r
F P
0 g
s
.31446 .39231 m .28569 .64806 L .2683 .63964 L p .831 .496 .421 r
F P
0 g
s
.2958 .63526 m .28569 .64806 L .31446 .39231 L p .036 0 .253 r
F P
0 g
s
.31446 .39231 m .32323 .38032 L .2958 .63526 L p .036 0 .253 r
F P
0 g
s
.2683 .63964 m .29966 .38442 L .31446 .39231 L p .831 .496 .421 r
F P
0 g
s
.31446 .39231 m .28569 .64806 L .2683 .63964 L p .831 .496 .421 r
F P
0 g
s
.28705 .7166 m .27652 .72958 L .31446 .39231 L p .036 0 .253 r
F P
0 g
s
.31446 .39231 m .32323 .38032 L .28705 .7166 L p .036 0 .253 r
F P
0 g
s
.37057 .37208 m .38524 .38003 L .37622 .39202 L p .694 .677 .829 r
F P
0 g
s
.37622 .39202 m .36158 .38414 L .37057 .37208 L p .694 .677 .829 r
F P
0 g
s
.33629 .69278 m .36158 .38414 L .37622 .39202 L p .832 .492 .412 r
F P
0 g
s
.37622 .39202 m .35399 .70129 L .33629 .69278 L p .832 .492 .412 r
F P
0 g
s
.36475 .68836 m .35399 .70129 L .37622 .39202 L p .08 0 .287 r
F P
0 g
s
.37622 .39202 m .38524 .38003 L .36475 .68836 L p .08 0 .287 r
F P
0 g
s
.33283 .73504 m .36158 .38414 L .37622 .39202 L p .832 .492 .412 r
F P
0 g
s
.37622 .39202 m .35095 .7436 L .33283 .73504 L p .832 .492 .412 r
F P
0 g
s
.36475 .68836 m .35399 .70129 L .37622 .39202 L p .08 0 .287 r
F P
0 g
s
.37622 .39202 m .38524 .38003 L .36475 .68836 L p .08 0 .287 r
F P
0 g
s
.43276 .37179 m .44727 .37975 L .438 .39174 L p .694 .677 .829 r
F P
0 g
s
.438 .39174 m .42352 .38385 L .43276 .37179 L p .694 .677 .829 r
F P
0 g
s
.40973 .72043 m .42352 .38385 L .438 .39174 L p .833 .488 .402 r
F P
0 g
s
.438 .39174 m .42746 .72897 L .40973 .72043 L p .833 .488 .402 r
F P
0 g
s
.43875 .71598 m .42746 .72897 L .438 .39174 L p .121 0 .318 r
F P
0 g
s
.438 .39174 m .44727 .37975 L .43875 .71598 L p .121 0 .318 r
F P
0 g
s
.40855 .74925 m .42352 .38385 L .438 .39174 L p .833 .488 .402 r
F P
0 g
s
.438 .39174 m .42656 .75783 L .40855 .74925 L p .833 .488 .402 r
F P
0 g
s
.43802 .74478 m .42656 .75783 L .438 .39174 L p .121 0 .318 r
F P
0 g
s
.438 .39174 m .44727 .37975 L .43802 .74478 L p .121 0 .318 r
F P
0 g
s
.49496 .37151 m .50931 .37946 L .49978 .39146 L p .694 .677 .829 r
F P
0 g
s
.49978 .39146 m .48547 .38357 L .49496 .37151 L p .694 .677 .829 r
F P
0 g
s
.48547 .5524 m .50138 .56067 L .49087 .57313 L p .689 .692 .848 r
F P
0 g
s
.48585 .64208 m .50178 .6501 L .49126 .66218 L p .688 .695 .852 r
F P
0 g
s
.48547 .74894 m .48547 .38357 L .49978 .39146 L p .835 .484 .391 r
F P
0 g
s
.49978 .39146 m .50323 .75752 L .48547 .74894 L p .835 .484 .391 r
F P
0 g
s
.51508 .74447 m .50323 .75752 L .49978 .39146 L p .157 0 .346 r
F P
0 g
s
.49978 .39146 m .50931 .37946 L .51508 .74447 L p .157 0 .346 r
F P
0 g
s
.48547 .5524 m .48547 .38357 L .49978 .39146 L p .835 .484 .391 r
F P
0 g
s
.49978 .39146 m .50138 .56067 L .48547 .5524 L p .835 .484 .391 r
F P
0 g
s
.51508 .74447 m .50323 .75752 L .49978 .39146 L p .157 0 .346 r
F P
0 g
s
.49978 .39146 m .50931 .37946 L .51508 .74447 L p .157 0 .346 r
F P
0 g
s
.55718 .37122 m .57136 .37918 L .56158 .39117 L p .694 .677 .829 r
F P
0 g
s
.56158 .39117 m .54743 .38328 L .55718 .37122 L p .694 .677 .829 r
F P
0 g
s
.56241 .74863 m .54743 .38328 L .56158 .39117 L p .836 .479 .38 r
F P
0 g
s
.56158 .39117 m .57992 .75722 L .56241 .74863 L p .836 .479 .38 r
F P
0 g
s
.5956 .73685 m .57847 .72836 L .59052 .71536 L p .683 .708 .867 r
F P
0 g
s
.57919 .74268 m .59645 .75119 L .58439 .764 L p .682 .709 .868 r
F P
0 g
s
.59216 .74416 m .57992 .75722 L .56158 .39117 L p .19 0 .37 r
F P
0 g
s
.56158 .39117 m .57136 .37918 L .59216 .74416 L p .19 0 .37 r
F P
0 g
s
.56241 .74863 m .54743 .38328 L .56158 .39117 L p .836 .479 .38 r
F P
0 g
s
.56158 .39117 m .57992 .75722 L .56241 .74863 L p .836 .479 .38 r
F P
0 g
s
.59052 .71536 m .57847 .72836 L .56158 .39117 L p .19 0 .37 r
F P
0 g
s
.56158 .39117 m .57136 .37918 L .59052 .71536 L p .19 0 .37 r
F P
0 g
s
.6194 .37093 m .63342 .37889 L .62339 .39089 L p .694 .677 .829 r
F P
0 g
s
.62339 .39089 m .60941 .383 L .6194 .37093 L p .694 .677 .829 r
F P
0 g
s
.63818 .7338 m .65531 .74237 L .64291 .75527 L p .682 .709 .868 r
F P
0 g
s
.64291 .75527 m .62583 .74679 L .63818 .7338 L p .682 .709 .868 r
F P
0 g
s
.63937 .74832 m .60941 .383 L .62339 .39089 L p .837 .474 .368 r
F P
0 g
s
.62339 .39089 m .65663 .75691 L .63937 .74832 L p .837 .474 .368 r
F P
0 g
s
.66925 .74385 m .65663 .75691 L .62339 .39089 L p .22 .027 .392 r
F P
0 g
s
.62339 .39089 m .63342 .37889 L .66925 .74385 L p .22 .027 .392 r
F P
0 g
s
.63818 .7338 m .60941 .383 L .62339 .39089 L p .837 .474 .368 r
F P
0 g
s
.62339 .39089 m .65531 .74237 L .63818 .7338 L p .837 .474 .368 r
F P
0 g
s
.66925 .74385 m .65663 .75691 L .62339 .39089 L p .22 .027 .392 r
F P
0 g
s
.62339 .39089 m .63342 .37889 L .66925 .74385 L p .22 .027 .392 r
F P
0 g
s
.68164 .37064 m .69549 .3786 L .68521 .39061 L p .694 .677 .829 r
F P
0 g
s
.68521 .39061 m .67139 .38271 L .68164 .37064 L p .694 .677 .829 r
F P
0 g
s
.70603 .66413 m .67139 .38271 L .68521 .39061 L p .838 .469 .355 r
F P
0 g
s
.68521 .39061 m .72231 .67261 L .70603 .66413 L p .838 .469 .355 r
F P
0 g
s
.73468 .65973 m .72231 .67261 L .68521 .39061 L p .248 .056 .412 r
F P
0 g
s
.68521 .39061 m .69549 .3786 L .73468 .65973 L p .248 .056 .412 r
F P
0 g
s
.70937 .69125 m .67139 .38271 L .68521 .39061 L p .838 .469 .355 r
F P
0 g
s
.68521 .39061 m .72588 .69976 L .70937 .69125 L p .838 .469 .355 r
F P
0 g
s
.73846 .68682 m .72588 .69976 L .68521 .39061 L p .248 .056 .412 r
F P
0 g
s
.68521 .39061 m .69549 .3786 L .73846 .68682 L p .248 .056 .412 r
F P
0 g
s
.74389 .37036 m .75758 .37832 L .74704 .39032 L p .694 .677 .829 r
F P
0 g
s
.74704 .39032 m .73339 .38243 L .74389 .37036 L p .694 .677 .829 r
F P
0 g
s
.79208 .74032 m .80845 .74873 L .79549 .7614 L p .683 .708 .867 r
F P
0 g
s
.78631 .70481 m .8027 .71334 L .78977 .72619 L p .683 .706 .865 r
F P
0 g
s
.80845 .74873 m .79208 .74032 L .80513 .72744 L p .683 .708 .867 r
F P
0 g
s
.79335 .7477 m .73339 .38243 L .74704 .39032 L p .839 .463 .341 r
F P
0 g
s
.74704 .39032 m .8101 .75629 L .79335 .7477 L p .839 .463 .341 r
F P
0 g
s
.8235 .74323 m .8101 .75629 L .74704 .39032 L p .272 .082 .43 r
F P
0 g
s
.74704 .39032 m .75758 .37832 L .8235 .74323 L p .272 .082 .43 r
F P
0 g
s
.78631 .70481 m .73339 .38243 L .74704 .39032 L p .839 .463 .341 r
F P
0 g
s
.74704 .39032 m .8027 .71334 L .78631 .70481 L p .839 .463 .341 r
F P
0 g
s
.8235 .74323 m .8101 .75629 L .74704 .39032 L p .272 .082 .43 r
F P
0 g
s
.74704 .39032 m .75758 .37832 L .8235 .74323 L p .272 .082 .43 r
F P
0 g
s
.80616 .37007 m .81968 .37803 L .80889 .39004 L p .694 .677 .829 r
F P
0 g
s
.80889 .39004 m .7954 .38214 L .80616 .37007 L p .694 .677 .829 r
F P
0 g
s
.87036 .74739 m .7954 .38214 L .80889 .39004 L p .839 .457 .326 r
F P
0 g
s
.80889 .39004 m .88686 .75598 L .87036 .74739 L p .839 .457 .326 r
F P
0 g
s
.90065 .74292 m .88686 .75598 L .80889 .39004 L p .295 .107 .446 r
F P
0 g
s
.80889 .39004 m .81968 .37803 L .90065 .74292 L p .295 .107 .446 r
F P
0 g
s
.87036 .74739 m .7954 .38214 L .80889 .39004 L p .839 .457 .326 r
F P
0 g
s
.80889 .39004 m .88686 .75598 L .87036 .74739 L p .839 .457 .326 r
F P
0 g
s
.09707 .67151 m .08768 .68444 L .15251 .38908 L p 0 0 .14 r
F P
0 g
s
.15251 .38908 m .16063 .37706 L .09707 .67151 L p 0 0 .14 r
F P
0 g
s
.20757 .36881 m .2227 .37678 L .21432 .38879 L p .694 .677 .829 r
F P
0 g
s
.21432 .38879 m .19924 .38089 L .20757 .36881 L p .694 .677 .829 r
F P
0 g
s
.14332 .67563 m .19924 .38089 L .21432 .38879 L p .828 .501 .435 r
F P
0 g
s
.21432 .38879 m .16152 .68413 L .14332 .67563 L p .828 .501 .435 r
F P
0 g
s
.17128 .6712 m .16152 .68413 L .21432 .38879 L p 0 0 .186 r
F P
0 g
s
.21432 .38879 m .2227 .37678 L .17128 .6712 L p 0 0 .186 r
F P
0 g
s
.14073 .68928 m .19924 .38089 L .21432 .38879 L p .828 .501 .435 r
F P
0 g
s
.21432 .38879 m .15908 .69781 L .14073 .68928 L p .828 .501 .435 r
F P
0 g
s
.1689 .68484 m .15908 .69781 L .21432 .38879 L p 0 0 .186 r
F P
0 g
s
.21432 .38879 m .2227 .37678 L .1689 .68484 L p 0 0 .186 r
F P
0 g
s
.26981 .36852 m .28477 .37649 L .27615 .38851 L p .694 .677 .829 r
F P
0 g
s
.27615 .38851 m .26123 .3806 L .26981 .36852 L p .694 .677 .829 r
F P
0 g
s
.22332 .63557 m .26123 .3806 L .27615 .38851 L p .83 .498 .426 r
F P
0 g
s
.27615 .38851 m .24088 .64401 L .22332 .63557 L p .83 .498 .426 r
F P
0 g
s
.25998 .6395 m .24266 .63113 L .25251 .61832 L p .687 .699 .856 r
F P
0 g
s
.2508 .63117 m .24088 .64401 L .27615 .38851 L p .004 0 .228 r
F P
0 g
s
.27615 .38851 m .28477 .37649 L .2508 .63117 L p .004 0 .228 r
F P
0 g
s
.22332 .63557 m .26123 .3806 L .27615 .38851 L p .83 .498 .426 r
F P
0 g
s
.27615 .38851 m .24088 .64401 L .22332 .63557 L p .83 .498 .426 r
F P
0 g
s
.25251 .61832 m .24266 .63113 L .27615 .38851 L p .004 0 .228 r
F P
0 g
s
.27615 .38851 m .28477 .37649 L .25251 .61832 L p .004 0 .228 r
F P
0 g
s
.33207 .36823 m .34686 .3762 L .33799 .38823 L p .694 .677 .829 r
F P
0 g
s
.33799 .38823 m .32323 .38032 L .33207 .36823 L p .694 .677 .829 r
F P
0 g
s
.28857 .70253 m .32323 .38032 L .33799 .38823 L p .831 .494 .417 r
F P
0 g
s
.33799 .38823 m .30658 .71107 L .28857 .70253 L p .831 .494 .417 r
F P
0 g
s
.3172 .69807 m .30658 .71107 L .33799 .38823 L p .051 0 .265 r
F P
0 g
s
.33799 .38823 m .34686 .3762 L .3172 .69807 L p .051 0 .265 r
F P
0 g
s
.28705 .7166 m .32323 .38032 L .33799 .38823 L p .831 .494 .417 r
F P
0 g
s
.33799 .38823 m .30521 .72517 L .28705 .7166 L p .831 .494 .417 r
F P
0 g
s
.31591 .71214 m .30521 .72517 L .33799 .38823 L p .051 0 .265 r
F P
0 g
s
.33799 .38823 m .34686 .3762 L .31591 .71214 L p .051 0 .265 r
F P
0 g
s
.39434 .36794 m .40897 .37592 L .39984 .38794 L p .694 .677 .829 r
F P
0 g
s
.39984 .38794 m .38524 .38003 L .39434 .36794 L p .694 .677 .829 r
F P
0 g
s
.36475 .68836 m .38524 .38003 L .39984 .38794 L p .833 .49 .407 r
F P
0 g
s
.39984 .38794 m .38239 .69689 L .36475 .68836 L p .833 .49 .407 r
F P
0 g
s
.3933 .68392 m .38239 .69689 L .39984 .38794 L p .094 0 .298 r
F P
0 g
s
.39984 .38794 m .40897 .37592 L .3933 .68392 L p .094 0 .298 r
F P
0 g
s
.36475 .68836 m .38524 .38003 L .39984 .38794 L p .833 .49 .407 r
F P
0 g
s
.39984 .38794 m .38239 .69689 L .36475 .68836 L p .833 .49 .407 r
F P
0 g
s
.39115 .72611 m .38 .73917 L .39984 .38794 L p .094 0 .298 r
F P
0 g
s
.39984 .38794 m .40897 .37592 L .39115 .72611 L p .094 0 .298 r
F P
0 g
s
.45662 .36766 m .47108 .37563 L .4617 .38766 L p .694 .677 .829 r
F P
0 g
s
.4617 .38766 m .44727 .37975 L .45662 .36766 L p .694 .677 .829 r
F P
0 g
s
.43839 .73027 m .44727 .37975 L .4617 .38766 L p .834 .486 .397 r
F P
0 g
s
.4617 .38766 m .45619 .73886 L .43839 .73027 L p .834 .486 .397 r
F P
0 g
s
.46773 .7258 m .45619 .73886 L .4617 .38766 L p .133 0 .328 r
F P
0 g
s
.4617 .38766 m .47108 .37563 L .46773 .7258 L p .133 0 .328 r
F P
0 g
s
.43802 .74478 m .44727 .37975 L .4617 .38766 L p .834 .486 .397 r
F P
0 g
s
.4617 .38766 m .45596 .75339 L .43802 .74478 L p .834 .486 .397 r
F P
0 g
s
.46759 .7403 m .45596 .75339 L .4617 .38766 L p .133 0 .328 r
F P
0 g
s
.4617 .38766 m .47108 .37563 L .46759 .7403 L p .133 0 .328 r
F P
0 g
s
.51891 .36737 m .53321 .37535 L .52357 .38737 L p .694 .677 .829 r
F P
0 g
s
.52357 .38737 m .50931 .37946 L .51891 .36737 L p .694 .677 .829 r
F P
0 g
s
.51508 .74447 m .50931 .37946 L .52357 .38737 L p .835 .482 .386 r
F P
0 g
s
.52357 .38737 m .53277 .75308 L .51508 .74447 L p .835 .482 .386 r
F P
0 g
s
.54985 .74709 m .5324 .73855 L .54433 .72548 L p .682 .709 .868 r
F P
0 g
s
.54479 .73999 m .53277 .75308 L .52357 .38737 L p .169 0 .354 r
F P
0 g
s
.52357 .38737 m .53321 .37535 L .54479 .73999 L p .169 0 .354 r
F P
0 g
s
.51508 .74447 m .50931 .37946 L .52357 .38737 L p .835 .482 .386 r
F P
0 g
s
.52357 .38737 m .53277 .75308 L .51508 .74447 L p .835 .482 .386 r
F P
0 g
s
.54433 .72548 m .5324 .73855 L .52357 .38737 L p .169 0 .354 r
F P
0 g
s
.52357 .38737 m .53321 .37535 L .54433 .72548 L p .169 0 .354 r
F P
0 g
s
.58121 .36708 m .59535 .37506 L .58546 .38709 L p .694 .677 .829 r
F P
0 g
s
.58546 .38709 m .57136 .37918 L .58121 .36708 L p .694 .677 .829 r
F P
0 g
s
.58971 .70129 m .57136 .37918 L .58546 .38709 L p .836 .477 .374 r
F P
0 g
s
.58546 .38709 m .60676 .70985 L .58971 .70129 L p .836 .477 .374 r
F P
0 g
s
.61887 .69684 m .60676 .70985 L .58546 .38709 L p .201 .006 .378 r
F P
0 g
s
.58546 .38709 m .59535 .37506 L .61887 .69684 L p .201 .006 .378 r
F P
0 g
s
.59052 .71536 m .57136 .37918 L .58546 .38709 L p .836 .477 .374 r
F P
0 g
s
.58546 .38709 m .60769 .72394 L .59052 .71536 L p .836 .477 .374 r
F P
0 g
s
.6199 .7109 m .60769 .72394 L .58546 .38709 L p .201 .006 .378 r
F P
0 g
s
.58546 .38709 m .59535 .37506 L .6199 .7109 L p .201 .006 .378 r
F P
0 g
s
.64353 .36679 m .6575 .37477 L .64736 .38681 L p .694 .677 .829 r
F P
0 g
s
.64736 .38681 m .63342 .37889 L .64353 .36679 L p .694 .677 .829 r
F P
0 g
s
.66925 .74385 m .63342 .37889 L .64736 .38681 L p .837 .472 .362 r
F P
0 g
s
.64736 .38681 m .68644 .75247 L .66925 .74385 L p .837 .472 .362 r
F P
0 g
s
.70107 .72527 m .68464 .71692 L .69694 .70415 L p .684 .705 .863 r
F P
0 g
s
.69536 .69046 m .67891 .682 L .69119 .66904 L p .685 .704 .862 r
F P
0 g
s
.68037 .69566 m .69694 .70415 L .68464 .71692 L p .684 .705 .863 r
F P
0 g
s
.68767 .74499 m .70434 .75337 L .69192 .766 L p .683 .708 .867 r
F P
0 g
s
.69924 .73936 m .68644 .75247 L .64736 .38681 L p .23 .037 .399 r
F P
0 g
s
.64736 .38681 m .6575 .37477 L .69924 .73936 L p .23 .037 .399 r
F P
0 g
s
.66925 .74385 m .63342 .37889 L .64736 .38681 L p .837 .472 .362 r
F P
0 g
s
.64736 .38681 m .68644 .75247 L .66925 .74385 L p .837 .472 .362 r
F P
0 g
s
.69119 .66904 m .67891 .682 L .64736 .38681 L p .23 .037 .399 r
F P
0 g
s
.64736 .38681 m .6575 .37477 L .69119 .66904 L p .23 .037 .399 r
F P
0 g
s
.70586 .3665 m .71966 .37449 L .70927 .38652 L p .694 .677 .829 r
F P
0 g
s
.70927 .38652 m .69549 .3786 L .70586 .3665 L p .694 .677 .829 r
F P
0 g
s
.73656 .67317 m .69549 .3786 L .70927 .38652 L p .838 .466 .348 r
F P
0 g
s
.70927 .38652 m .75289 .68169 L .73656 .67317 L p .838 .466 .348 r
F P
0 g
s
.76553 .66873 m .75289 .68169 L .70927 .38652 L p .256 .065 .418 r
F P
0 g
s
.70927 .38652 m .71966 .37449 L .76553 .66873 L p .256 .065 .418 r
F P
0 g
s
.73846 .68682 m .69549 .3786 L .70927 .38652 L p .838 .466 .348 r
F P
0 g
s
.70927 .38652 m .75491 .69536 L .73846 .68682 L p .838 .466 .348 r
F P
0 g
s
.76765 .68237 m .75491 .69536 L .70927 .38652 L p .256 .065 .418 r
F P
0 g
s
.70927 .38652 m .71966 .37449 L .76765 .68237 L p .256 .065 .418 r
F P
0 g
s
.7682 .36622 m .78183 .3742 L .77119 .38624 L p .694 .677 .829 r
F P
0 g
s
.77119 .38624 m .75758 .37832 L .7682 .36622 L p .694 .677 .829 r
F P
0 g
s
.8235 .74323 m .75758 .37832 L .77119 .38624 L p .839 .46 .334 r
F P
0 g
s
.77119 .38624 m .84018 .75185 L .8235 .74323 L p .839 .46 .334 r
F P
0 g
s
.8509 .72424 m .86738 .73287 L .85389 .74587 L p .682 .709 .868 r
F P
0 g
s
.85389 .74587 m .83744 .73732 L .8509 .72424 L p .682 .709 .868 r
F P
0 g
s
.85376 .73874 m .84018 .75185 L .77119 .38624 L p .28 .091 .436 r
F P
0 g
s
.77119 .38624 m .78183 .3742 L .85376 .73874 L p .28 .091 .436 r
F P
0 g
s
.8235 .74323 m .75758 .37832 L .77119 .38624 L p .839 .46 .334 r
F P
0 g
s
.77119 .38624 m .84018 .75185 L .8235 .74323 L p .839 .46 .334 r
F P
0 g
s
.8509 .72424 m .83744 .73732 L .77119 .38624 L p .28 .091 .436 r
F P
0 g
s
.77119 .38624 m .78183 .3742 L .8509 .72424 L p .28 .091 .436 r
F P
0 g
s
.16882 .36495 m .18407 .37294 L .17584 .38499 L p .694 .677 .829 r
F P
0 g
s
.17584 .38499 m .16063 .37706 L .16882 .36495 L p .694 .677 .829 r
F P
0 g
s
.09997 .65807 m .16063 .37706 L .17584 .38499 L p .828 .503 .439 r
F P
0 g
s
.17584 .38499 m .11821 .66658 L .09997 .65807 L p .828 .503 .439 r
F P
0 g
s
.12769 .65364 m .11821 .66658 L .17584 .38499 L p 0 0 .156 r
F P
0 g
s
.17584 .38499 m .18407 .37294 L .12769 .65364 L p 0 0 .156 r
F P
0 g
s
.09707 .67151 m .16063 .37706 L .17584 .38499 L p .828 .503 .439 r
F P
0 g
s
.17584 .38499 m .11545 .68004 L .09707 .67151 L p .828 .503 .439 r
F P
0 g
s
.12769 .65364 m .11821 .66658 L .17584 .38499 L p 0 0 .156 r
F P
0 g
s
.17584 .38499 m .18407 .37294 L .12769 .65364 L p 0 0 .156 r
F P
0 g
s
.23114 .36466 m .24622 .37265 L .23774 .3847 L p .694 .677 .829 r
F P
0 g
s
.23774 .3847 m .2227 .37678 L .23114 .36466 L p .694 .677 .829 r
F P
0 g
s
.17821 .63148 m .2227 .37678 L .23774 .3847 L p .829 .499 .43 r
F P
0 g
s
.23774 .3847 m .19594 .63995 L .17821 .63148 L p .829 .499 .43 r
F P
0 g
s
.20566 .62707 m .19594 .63995 L .23774 .3847 L p 0 0 .2 r
F P
0 g
s
.23774 .3847 m .24622 .37265 L .20566 .62707 L p 0 0 .2 r
F P
0 g
s
.1689 .68484 m .2227 .37678 L .23774 .3847 L p .829 .499 .43 r
F P
0 g
s
.23774 .3847 m .18719 .6934 L .1689 .68484 L p .829 .499 .43 r
F P
0 g
s
.20566 .62707 m .19594 .63995 L .23774 .3847 L p 0 0 .2 r
F P
0 g
s
.23774 .3847 m .24622 .37265 L .20566 .62707 L p 0 0 .2 r
F P
0 g
s
.29347 .36437 m .30839 .37237 L .29966 .38442 L p .694 .677 .829 r
F P
0 g
s
.29966 .38442 m .28477 .37649 L .29347 .36437 L p .694 .677 .829 r
F P
0 g
s
.25251 .61832 m .26988 .62677 L .25998 .6395 L p .687 .699 .856 r
F P
0 g
s
.2508 .63117 m .28477 .37649 L .29966 .38442 L p .831 .496 .421 r
F P
0 g
s
.29966 .38442 m .2683 .63964 L .2508 .63117 L p .831 .496 .421 r
F P
0 g
s
.27836 .62676 m .2683 .63964 L .29966 .38442 L p .02 0 .24 r
F P
0 g
s
.29966 .38442 m .30839 .37237 L .27836 .62676 L p .02 0 .24 r
F P
0 g
s
.25251 .61832 m .28477 .37649 L .29966 .38442 L p .831 .496 .421 r
F P
0 g
s
.29966 .38442 m .26988 .62677 L .25251 .61832 L p .831 .496 .421 r
F P
0 g
s
.27836 .62676 m .2683 .63964 L .29966 .38442 L p .02 0 .24 r
F P
0 g
s
.29966 .38442 m .30839 .37237 L .27836 .62676 L p .02 0 .24 r
F P
0 g
s
.35581 .36408 m .37057 .37208 L .36158 .38414 L p .694 .677 .829 r
F P
0 g
s
.36158 .38414 m .34686 .3762 L .35581 .36408 L p .694 .677 .829 r
F P
0 g
s
.31848 .68423 m .34686 .3762 L .36158 .38414 L p .832 .492 .412 r
F P
0 g
s
.36158 .38414 m .33629 .69278 L .31848 .68423 L p .832 .492 .412 r
F P
0 g
s
.347 .67977 m .33629 .69278 L .36158 .38414 L p .066 0 .276 r
F P
0 g
s
.36158 .38414 m .37057 .37208 L .347 .67977 L p .066 0 .276 r
F P
0 g
s
.31591 .71214 m .34686 .3762 L .36158 .38414 L p .832 .492 .412 r
F P
0 g
s
.36158 .38414 m .334 .72074 L .31591 .71214 L p .832 .492 .412 r
F P
0 g
s
.347 .67977 m .33629 .69278 L .36158 .38414 L p .066 0 .276 r
F P
0 g
s
.36158 .38414 m .37057 .37208 L .347 .67977 L p .066 0 .276 r
F P
0 g
s
.41817 .3638 m .43276 .37179 L .42352 .38385 L p .694 .677 .829 r
F P
0 g
s
.42352 .38385 m .40897 .37592 L .41817 .3638 L p .694 .677 .829 r
F P
0 g
s
.39188 .71183 m .40897 .37592 L .42352 .38385 L p .833 .488 .402 r
F P
0 g
s
.42352 .38385 m .40973 .72043 L .39188 .71183 L p .833 .488 .402 r
F P
0 g
s
.42096 .70735 m .40973 .72043 L .42352 .38385 L p .108 0 .308 r
F P
0 g
s
.42352 .38385 m .43276 .37179 L .42096 .70735 L p .108 0 .308 r
F P
0 g
s
.39115 .72611 m .40897 .37592 L .42352 .38385 L p .833 .488 .402 r
F P
0 g
s
.42352 .38385 m .40914 .73473 L .39115 .72611 L p .833 .488 .402 r
F P
0 g
s
.42096 .70735 m .40973 .72043 L .42352 .38385 L p .108 0 .308 r
F P
0 g
s
.42352 .38385 m .43276 .37179 L .42096 .70735 L p .108 0 .308 r
F P
0 g
s
.48054 .36351 m .49496 .37151 L .48547 .38357 L p .694 .677 .829 r
F P
0 g
s
.48547 .38357 m .47108 .37563 L .48054 .36351 L p .694 .677 .829 r
F P
0 g
s
.46958 .53245 m .47108 .37563 L .48547 .38357 L p .835 .484 .391 r
F P
0 g
s
.48547 .38357 m .48547 .54075 L .46958 .53245 L p .835 .484 .391 r
F P
0 g
s
.49595 .52814 m .48547 .54075 L .48547 .38357 L p .145 0 .337 r
F P
0 g
s
.48547 .38357 m .49496 .37151 L .49595 .52814 L p .145 0 .337 r
F P
0 g
s
.46759 .7403 m .47108 .37563 L .48547 .38357 L p .835 .484 .391 r
F P
0 g
s
.48547 .38357 m .48547 .74894 L .46759 .7403 L p .835 .484 .391 r
F P
0 g
s
.49727 .7358 m .48547 .74894 L .48547 .38357 L p .145 0 .337 r
F P
0 g
s
.48547 .38357 m .49496 .37151 L .49727 .7358 L p .145 0 .337 r
F P
0 g
s
.54292 .36322 m .55718 .37122 L .54743 .38328 L p .694 .677 .829 r
F P
0 g
s
.54743 .38328 m .53321 .37535 L .54292 .36322 L p .694 .677 .829 r
F P
0 g
s
.54433 .72548 m .56182 .73411 L .54985 .74709 L p .682 .709 .868 r
F P
0 g
s
.54479 .73999 m .53321 .37535 L .54743 .38328 L p .836 .479 .38 r
F P
0 g
s
.54743 .38328 m .56241 .74863 L .54479 .73999 L p .836 .479 .38 r
F P
0 g
s
.5746 .73549 m .56241 .74863 L .54743 .38328 L p .18 0 .362 r
F P
0 g
s
.54743 .38328 m .55718 .37122 L .5746 .73549 L p .18 0 .362 r
F P
0 g
s
.54433 .72548 m .53321 .37535 L .54743 .38328 L p .836 .479 .38 r
F P
0 g
s
.54743 .38328 m .56182 .73411 L .54433 .72548 L p .836 .479 .38 r
F P
0 g
s
.5746 .73549 m .56241 .74863 L .54743 .38328 L p .18 0 .362 r
F P
0 g
s
.54743 .38328 m .55718 .37122 L .5746 .73549 L p .18 0 .362 r
F P
0 g
s
.60531 .36293 m .6194 .37093 L .60941 .383 L p .694 .677 .829 r
F P
0 g
s
.60941 .383 m .59535 .37506 L .60531 .36293 L p .694 .677 .829 r
F P
0 g
s
.60769 .72394 m .62476 .73246 L .61263 .74529 L p .683 .708 .867 r
F P
0 g
s
.6199 .7109 m .63701 .7195 L .62476 .73246 L p .683 .708 .867 r
F P
0 g
s
.62476 .73246 m .60769 .72394 L .6199 .7109 L p .683 .708 .867 r
F P
0 g
s
.622 .73968 m .59535 .37506 L .60941 .383 L p .837 .474 .368 r
F P
0 g
s
.60941 .383 m .63937 .74832 L .622 .73968 L p .837 .474 .368 r
F P
0 g
s
.65195 .73517 m .63937 .74832 L .60941 .383 L p .211 .017 .385 r
F P
0 g
s
.60941 .383 m .6194 .37093 L .65195 .73517 L p .211 .017 .385 r
F P
0 g
s
.6199 .7109 m .59535 .37506 L .60941 .383 L p .837 .474 .368 r
F P
0 g
s
.60941 .383 m .63701 .7195 L .6199 .7109 L p .837 .474 .368 r
F P
0 g
s
.65195 .73517 m .63937 .74832 L .60941 .383 L p .211 .017 .385 r
F P
0 g
s
.60941 .383 m .6194 .37093 L .65195 .73517 L p .211 .017 .385 r
F P
0 g
s
.66772 .36264 m .68164 .37064 L .67139 .38271 L p .694 .677 .829 r
F P
0 g
s
.67139 .38271 m .6575 .37477 L .66772 .36264 L p .694 .677 .829 r
F P
0 g
s
.68965 .65561 m .6575 .37477 L .67139 .38271 L p .838 .469 .355 r
F P
0 g
s
.67139 .38271 m .70603 .66413 L .68965 .65561 L p .838 .469 .355 r
F P
0 g
s
.71837 .65117 m .70603 .66413 L .67139 .38271 L p .239 .047 .406 r
F P
0 g
s
.67139 .38271 m .68164 .37064 L .71837 .65117 L p .239 .047 .406 r
F P
0 g
s
.69119 .66904 m .6575 .37477 L .67139 .38271 L p .838 .469 .355 r
F P
0 g
s
.67139 .38271 m .70768 .67759 L .69119 .66904 L p .838 .469 .355 r
F P
0 g
s
.71837 .65117 m .70603 .66413 L .67139 .38271 L p .239 .047 .406 r
F P
0 g
s
.67139 .38271 m .68164 .37064 L .71837 .65117 L p .239 .047 .406 r
F P
0 g
s
.73014 .36235 m .74389 .37036 L .73339 .38243 L p .694 .677 .829 r
F P
0 g
s
.73339 .38243 m .71966 .37449 L .73014 .36235 L p .694 .677 .829 r
F P
0 g
s
.75491 .69536 m .77125 .70384 L .75858 .71662 L p .684 .705 .863 r
F P
0 g
s
.76765 .68237 m .78403 .69094 L .77125 .70384 L p .684 .705 .863 r
F P
0 g
s
.77125 .70384 m .75491 .69536 L .76765 .68237 L p .684 .705 .863 r
F P
0 g
s
.78977 .72619 m .77341 .71774 L .78631 .70481 L p .683 .706 .865 r
F P
0 g
s
.77562 .73185 m .79208 .74032 L .77917 .75307 L p .683 .708 .867 r
F P
0 g
s
.77917 .75307 m .76274 .74468 L .77562 .73185 L p .683 .708 .867 r
F P
0 g
s
.77649 .73905 m .71966 .37449 L .73339 .38243 L p .839 .463 .341 r
F P
0 g
s
.79549 .7614 m .77917 .75307 L .79208 .74032 L p .683 .708 .867 r
F P
0 g
s
.73339 .38243 m .79335 .7477 L .77649 .73905 L p .839 .463 .341 r
F P
0 g
s
.80671 .73455 m .79335 .7477 L .73339 .38243 L p .264 .074 .424 r
F P
0 g
s
.73339 .38243 m .74389 .37036 L .80671 .73455 L p .264 .074 .424 r
F P
0 g
s
.76765 .68237 m .71966 .37449 L .73339 .38243 L p .839 .463 .341 r
F P
0 g
s
.73339 .38243 m .78403 .69094 L .76765 .68237 L p .839 .463 .341 r
F P
0 g
s
.80671 .73455 m .79335 .7477 L .73339 .38243 L p .264 .074 .424 r
F P
0 g
s
.73339 .38243 m .74389 .37036 L .80671 .73455 L p .264 .074 .424 r
F P
0 g
s
.79257 .36206 m .80616 .37007 L .7954 .38214 L p .694 .677 .829 r
F P
0 g
s
.7954 .38214 m .78183 .3742 L .79257 .36206 L p .694 .677 .829 r
F P
0 g
s
.85376 .73874 m .78183 .3742 L .7954 .38214 L p .839 .457 .326 r
F P
0 g
s
.7954 .38214 m .87036 .74739 L .85376 .73874 L p .839 .457 .326 r
F P
0 g
s
.88412 .73423 m .87036 .74739 L .7954 .38214 L p .288 .099 .441 r
F P
0 g
s
.7954 .38214 m .80616 .37007 L .88412 .73423 L p .288 .099 .441 r
F P
0 g
s
.8509 .72424 m .78183 .3742 L .7954 .38214 L p .839 .457 .326 r
F P
0 g
s
.7954 .38214 m .86738 .73287 L .8509 .72424 L p .839 .457 .326 r
F P
0 g
s
.88412 .73423 m .87036 .74739 L .7954 .38214 L p .288 .099 .441 r
F P
0 g
s
.7954 .38214 m .80616 .37007 L .88412 .73423 L p .288 .099 .441 r
F P
0 g
s
.19236 .36079 m .20757 .36881 L .19924 .38089 L p .694 .677 .829 r
F P
0 g
s
.19924 .38089 m .18407 .37294 L .19236 .36079 L p .694 .677 .829 r
F P
0 g
s
.12769 .65364 m .18407 .37294 L .19924 .38089 L p .828 .501 .435 r
F P
0 g
s
.19924 .38089 m .14587 .66218 L .12769 .65364 L p .828 .501 .435 r
F P
0 g
s
.15551 .6492 m .14587 .66218 L .19924 .38089 L p 0 0 .171 r
F P
0 g
s
.19924 .38089 m .20757 .36881 L .15551 .6492 L p 0 0 .171 r
F P
0 g
s
.12769 .65364 m .18407 .37294 L .19924 .38089 L p .828 .501 .435 r
F P
0 g
s
.19924 .38089 m .14587 .66218 L .12769 .65364 L p .828 .501 .435 r
F P
0 g
s
.15302 .66261 m .14332 .67563 L .19924 .38089 L p 0 0 .171 r
F P
0 g
s
.19924 .38089 m .20757 .36881 L .15302 .66261 L p 0 0 .171 r
F P
0 g
s
.25477 .36051 m .26981 .36852 L .26123 .3806 L p .694 .677 .829 r
F P
0 g
s
.26123 .3806 m .24622 .37265 L .25477 .36051 L p .694 .677 .829 r
F P
0 g
s
.2077 .61423 m .24622 .37265 L .26123 .3806 L p .83 .498 .426 r
F P
0 g
s
.26123 .3806 m .22524 .6227 L .2077 .61423 L p .83 .498 .426 r
F P
0 g
s
.23504 .60982 m .22524 .6227 L .26123 .3806 L p 0 0 .214 r
F P
0 g
s
.26123 .3806 m .26981 .36852 L .23504 .60982 L p 0 0 .214 r
F P
0 g
s
.20566 .62707 m .24622 .37265 L .26123 .3806 L p .83 .498 .426 r
F P
0 g
s
.26123 .3806 m .22332 .63557 L .20566 .62707 L p .83 .498 .426 r
F P
0 g
s
.23319 .62265 m .22332 .63557 L .26123 .3806 L p 0 0 .214 r
F P
0 g
s
.26123 .3806 m .26981 .36852 L .23319 .62265 L p 0 0 .214 r
F P
0 g
s
.31719 .36022 m .33207 .36823 L .32323 .38032 L p .694 .677 .829 r
F P
0 g
s
.32323 .38032 m .30839 .37237 L .31719 .36022 L p .694 .677 .829 r
F P
0 g
s
.27836 .62676 m .30839 .37237 L .32323 .38032 L p .831 .494 .417 r
F P
0 g
s
.32323 .38032 m .2958 .63526 L .27836 .62676 L p .831 .494 .417 r
F P
0 g
s
.30601 .62234 m .2958 .63526 L .32323 .38032 L p .036 0 .253 r
F P
0 g
s
.32323 .38032 m .33207 .36823 L .30601 .62234 L p .036 0 .253 r
F P
0 g
s
.27836 .62676 m .30839 .37237 L .32323 .38032 L p .831 .494 .417 r
F P
0 g
s
.32323 .38032 m .2958 .63526 L .27836 .62676 L p .831 .494 .417 r
F P
0 g
s
.29913 .68944 m .28857 .70253 L .32323 .38032 L p .036 0 .253 r
F P
0 g
s
.32323 .38032 m .33207 .36823 L .29913 .68944 L p .036 0 .253 r
F P
0 g
s
.37963 .35993 m .39434 .36794 L .38524 .38003 L p .694 .677 .829 r
F P
0 g
s
.38524 .38003 m .37057 .37208 L .37963 .35993 L p .694 .677 .829 r
F P
0 g
s
.34804 .66614 m .37057 .37208 L .38524 .38003 L p .833 .49 .407 r
F P
0 g
s
.38524 .38003 m .36566 .67471 L .34804 .66614 L p .833 .49 .407 r
F P
0 g
s
.37644 .66168 m .36566 .67471 L .38524 .38003 L p .08 0 .287 r
F P
0 g
s
.38524 .38003 m .39434 .36794 L .37644 .66168 L p .08 0 .287 r
F P
0 g
s
.347 .67977 m .37057 .37208 L .38524 .38003 L p .833 .49 .407 r
F P
0 g
s
.38524 .38003 m .36475 .68836 L .347 .67977 L p .833 .49 .407 r
F P
0 g
s
.37561 .6753 m .36475 .68836 L .38524 .38003 L p .08 0 .287 r
F P
0 g
s
.38524 .38003 m .39434 .36794 L .37561 .6753 L p .08 0 .287 r
F P
0 g
s
.44207 .35964 m .45662 .36766 L .44727 .37975 L p .694 .677 .829 r
F P
0 g
s
.44727 .37975 m .43276 .37179 L .44207 .35964 L p .694 .677 .829 r
F P
0 g
s
.42096 .70735 m .43276 .37179 L .44727 .37975 L p .834 .486 .397 r
F P
0 g
s
.44727 .37975 m .43875 .71598 L .42096 .70735 L p .834 .486 .397 r
F P
0 g
s
.45015 .70286 m .43875 .71598 L .44727 .37975 L p .121 0 .318 r
F P
0 g
s
.44727 .37975 m .45662 .36766 L .45015 .70286 L p .121 0 .318 r
F P
0 g
s
.42096 .70735 m .43276 .37179 L .44727 .37975 L p .834 .486 .397 r
F P
0 g
s
.44727 .37975 m .43875 .71598 L .42096 .70735 L p .834 .486 .397 r
F P
0 g
s
.44987 .71712 m .43839 .73027 L .44727 .37975 L p .121 0 .318 r
F P
0 g
s
.44727 .37975 m .45662 .36766 L .44987 .71712 L p .121 0 .318 r
F P
0 g
s
.50453 .35935 m .51891 .36737 L .50931 .37946 L p .694 .677 .829 r
F P
0 g
s
.50931 .37946 m .49496 .37151 L .50453 .35935 L p .694 .677 .829 r
F P
0 g
s
.49718 .72131 m .49496 .37151 L .50931 .37946 L p .835 .482 .386 r
F P
0 g
s
.50931 .37946 m .51485 .72996 L .49718 .72131 L p .835 .482 .386 r
F P
0 g
s
.52672 .7168 m .51485 .72996 L .50931 .37946 L p .157 0 .346 r
F P
0 g
s
.50931 .37946 m .51891 .36737 L .52672 .7168 L p .157 0 .346 r
F P
0 g
s
.49727 .7358 m .49496 .37151 L .50931 .37946 L p .835 .482 .386 r
F P
0 g
s
.50931 .37946 m .51508 .74447 L .49727 .7358 L p .835 .482 .386 r
F P
0 g
s
.52705 .73129 m .51508 .74447 L .50931 .37946 L p .157 0 .346 r
F P
0 g
s
.50931 .37946 m .51891 .36737 L .52705 .73129 L p .157 0 .346 r
F P
0 g
s
.567 .35906 m .58121 .36708 L .57136 .37918 L p .694 .677 .829 r
F P
0 g
s
.57136 .37918 m .55718 .37122 L .567 .35906 L p .694 .677 .829 r
F P
0 g
s
.5746 .73549 m .55718 .37122 L .57136 .37918 L p .836 .477 .374 r
F P
0 g
s
.57136 .37918 m .59216 .74416 L .5746 .73549 L p .836 .477 .374 r
F P
0 g
s
.61263 .74529 m .5956 .73685 L .60769 .72394 L p .683 .708 .867 r
F P
0 g
s
.60676 .70985 m .58971 .70129 L .60178 .68819 L p .683 .706 .865 r
F P
0 g
s
.59052 .71536 m .60769 .72394 L .5956 .73685 L p .683 .708 .867 r
F P
0 g
s
.60452 .73097 m .59216 .74416 L .57136 .37918 L p .19 0 .37 r
F P
0 g
s
.57136 .37918 m .58121 .36708 L .60452 .73097 L p .19 0 .37 r
F P
0 g
s
.5746 .73549 m .55718 .37122 L .57136 .37918 L p .836 .477 .374 r
F P
0 g
s
.57136 .37918 m .59216 .74416 L .5746 .73549 L p .836 .477 .374 r
F P
0 g
s
.60178 .68819 m .58971 .70129 L .57136 .37918 L p .19 0 .37 r
F P
0 g
s
.57136 .37918 m .58121 .36708 L .60178 .68819 L p .19 0 .37 r
F P
0 g
s
.62948 .35877 m .64353 .36679 L .63342 .37889 L p .694 .677 .829 r
F P
0 g
s
.63342 .37889 m .6194 .37093 L .62948 .35877 L p .694 .677 .829 r
F P
0 g
s
.65066 .72068 m .6194 .37093 L .63342 .37889 L p .837 .472 .362 r
F P
0 g
s
.63342 .37889 m .66783 .72934 L .65066 .72068 L p .837 .472 .362 r
F P
0 g
s
.68048 .71618 m .66783 .72934 L .63342 .37889 L p .22 .027 .392 r
F P
0 g
s
.63342 .37889 m .64353 .36679 L .68048 .71618 L p .22 .027 .392 r
F P
0 g
s
.65195 .73517 m .6194 .37093 L .63342 .37889 L p .837 .472 .362 r
F P
0 g
s
.63342 .37889 m .66925 .74385 L .65195 .73517 L p .837 .472 .362 r
F P
0 g
s
.68201 .73066 m .66925 .74385 L .63342 .37889 L p .22 .027 .392 r
F P
0 g
s
.63342 .37889 m .64353 .36679 L .68201 .73066 L p .22 .027 .392 r
F P
0 g
s
.69198 .35848 m .70586 .3665 L .69549 .3786 L p .694 .677 .829 r
F P
0 g
s
.69549 .3786 m .68164 .37064 L .69198 .35848 L p .694 .677 .829 r
F P
0 g
s
.71837 .65117 m .68164 .37064 L .69549 .3786 L p .838 .466 .348 r
F P
0 g
s
.69549 .3786 m .73468 .65973 L .71837 .65117 L p .838 .466 .348 r
F P
0 g
s
.74718 .64672 m .73468 .65973 L .69549 .3786 L p .248 .056 .412 r
F P
0 g
s
.69549 .3786 m .70586 .3665 L .74718 .64672 L p .248 .056 .412 r
F P
0 g
s
.71837 .65117 m .68164 .37064 L .69549 .3786 L p .838 .466 .348 r
F P
0 g
s
.69549 .3786 m .73468 .65973 L .71837 .65117 L p .838 .466 .348 r
F P
0 g
s
.74916 .66013 m .73656 .67317 L .69549 .3786 L p .248 .056 .412 r
F P
0 g
s
.69549 .3786 m .70586 .3665 L .74916 .66013 L p .248 .056 .412 r
F P
0 g
s
.75449 .35819 m .7682 .36622 L .75758 .37832 L p .694 .677 .829 r
F P
0 g
s
.75758 .37832 m .74389 .37036 L .75449 .35819 L p .694 .677 .829 r
F P
0 g
s
.80421 .72006 m .74389 .37036 L .75758 .37832 L p .839 .46 .334 r
F P
0 g
s
.75758 .37832 m .82088 .72872 L .80421 .72006 L p .839 .46 .334 r
F P
0 g
s
.8343 .71555 m .82088 .72872 L .75758 .37832 L p .272 .082 .43 r
F P
0 g
s
.75758 .37832 m .7682 .36622 L .8343 .71555 L p .272 .082 .43 r
F P
0 g
s
.80671 .73455 m .74389 .37036 L .75758 .37832 L p .839 .46 .334 r
F P
0 g
s
.75758 .37832 m .8235 .74323 L .80671 .73455 L p .839 .46 .334 r
F P
0 g
s
.83704 .73003 m .8235 .74323 L .75758 .37832 L p .272 .082 .43 r
F P
0 g
s
.75758 .37832 m .7682 .36622 L .83704 .73003 L p .272 .082 .43 r
F P
0 g
s
.81701 .3579 m .83055 .36593 L .81968 .37803 L p .694 .677 .829 r
F P
0 g
s
.81968 .37803 m .80616 .37007 L .81701 .3579 L p .694 .677 .829 r
F P
0 g
s
.88412 .73423 m .80616 .37007 L .81968 .37803 L p .839 .453 .319 r
F P
0 g
s
.81968 .37803 m .90065 .74292 L .88412 .73423 L p .839 .453 .319 r
F P
0 g
s
.91459 .72971 m .90065 .74292 L .81968 .37803 L p .295 .107 .446 r
F P
0 g
s
.81968 .37803 m .83055 .36593 L .91459 .72971 L p .295 .107 .446 r
F P
0 g
s
.88412 .73423 m .80616 .37007 L .81968 .37803 L p .839 .453 .319 r
F P
0 g
s
.81968 .37803 m .90065 .74292 L .88412 .73423 L p .839 .453 .319 r
F P
0 g
s
.1094 .64505 m .09997 .65807 L .16063 .37706 L p 0 0 .14 r
F P
0 g
s
.16063 .37706 m .16882 .36495 L .1094 .64505 L p 0 0 .14 r
F P
0 g
s
.21597 .35663 m .23114 .36466 L .2227 .37678 L p .694 .677 .829 r
F P
0 g
s
.2227 .37678 m .20757 .36881 L .21597 .35663 L p .694 .677 .829 r
F P
0 g
s
.16038 .62296 m .20757 .36881 L .2227 .37678 L p .829 .499 .43 r
F P
0 g
s
.2227 .37678 m .17821 .63148 L .16038 .62296 L p .829 .499 .43 r
F P
0 g
s
.18788 .61852 m .17821 .63148 L .2227 .37678 L p 0 0 .186 r
F P
0 g
s
.2227 .37678 m .23114 .36466 L .18788 .61852 L p 0 0 .186 r
F P
0 g
s
.15302 .66261 m .20757 .36881 L .2227 .37678 L p .829 .499 .43 r
F P
0 g
s
.2227 .37678 m .17128 .6712 L .15302 .66261 L p .829 .499 .43 r
F P
0 g
s
.18788 .61852 m .17821 .63148 L .2227 .37678 L p 0 0 .186 r
F P
0 g
s
.2227 .37678 m .23114 .36466 L .18788 .61852 L p 0 0 .186 r
F P
0 g
s
.27847 .35634 m .29347 .36437 L .28477 .37649 L p .694 .677 .829 r
F P
0 g
s
.28477 .37649 m .26981 .36852 L .27847 .35634 L p .694 .677 .829 r
F P
0 g
s
.23686 .59717 m .26981 .36852 L .28477 .37649 L p .831 .496 .421 r
F P
0 g
s
.28477 .37649 m .2542 .60565 L .23686 .59717 L p .831 .496 .421 r
F P
0 g
s
.26408 .59276 m .2542 .60565 L .28477 .37649 L p .004 0 .228 r
F P
0 g
s
.28477 .37649 m .29347 .36437 L .26408 .59276 L p .004 0 .228 r
F P
0 g
s
.23319 .62265 m .26981 .36852 L .28477 .37649 L p .831 .496 .421 r
F P
0 g
s
.28477 .37649 m .2508 .63117 L .23319 .62265 L p .831 .496 .421 r
F P
0 g
s
.26081 .61821 m .2508 .63117 L .28477 .37649 L p .004 0 .228 r
F P
0 g
s
.28477 .37649 m .29347 .36437 L .26081 .61821 L p .004 0 .228 r
F P
0 g
s
.34098 .35605 m .35581 .36408 L .34686 .3762 L p .694 .677 .829 r
F P
0 g
s
.34686 .3762 m .33207 .36823 L .34098 .35605 L p .694 .677 .829 r
F P
0 g
s
.30055 .67561 m .33207 .36823 L .34686 .3762 L p .832 .492 .412 r
F P
0 g
s
.34686 .3762 m .31848 .68423 L .30055 .67561 L p .832 .492 .412 r
F P
0 g
s
.32913 .67113 m .31848 .68423 L .34686 .3762 L p .051 0 .265 r
F P
0 g
s
.34686 .3762 m .35581 .36408 L .32913 .67113 L p .051 0 .265 r
F P
0 g
s
.29913 .68944 m .33207 .36823 L .34686 .3762 L p .832 .492 .412 r
F P
0 g
s
.34686 .3762 m .3172 .69807 L .29913 .68944 L p .832 .492 .412 r
F P
0 g
s
.32913 .67113 m .31848 .68423 L .34686 .3762 L p .051 0 .265 r
F P
0 g
s
.34686 .3762 m .35581 .36408 L .32913 .67113 L p .051 0 .265 r
F P
0 g
s
.4035 .35576 m .41817 .3638 L .40897 .37592 L p .694 .677 .829 r
F P
0 g
s
.40897 .37592 m .39434 .36794 L .4035 .35576 L p .694 .677 .829 r
F P
0 g
s
.37561 .6753 m .39434 .36794 L .40897 .37592 L p .833 .488 .402 r
F P
0 g
s
.40897 .37592 m .3933 .68392 L .37561 .6753 L p .833 .488 .402 r
F P
0 g
s
.40432 .67082 m .3933 .68392 L .40897 .37592 L p .094 0 .298 r
F P
0 g
s
.40897 .37592 m .41817 .3638 L .40432 .67082 L p .094 0 .298 r
F P
0 g
s
.37561 .6753 m .39434 .36794 L .40897 .37592 L p .833 .488 .402 r
F P
0 g
s
.40897 .37592 m .3933 .68392 L .37561 .6753 L p .833 .488 .402 r
F P
0 g
s
.40306 .69866 m .39188 .71183 L .40897 .37592 L p .094 0 .298 r
F P
0 g
s
.40897 .37592 m .41817 .3638 L .40306 .69866 L p .094 0 .298 r
F P
0 g
s
.46604 .35547 m .48054 .36351 L .47108 .37563 L p .694 .677 .829 r
F P
0 g
s
.47108 .37563 m .45662 .36766 L .46604 .35547 L p .694 .677 .829 r
F P
0 g
s
.4536 .52411 m .45662 .36766 L .47108 .37563 L p .835 .484 .391 r
F P
0 g
s
.47108 .37563 m .46958 .53245 L .4536 .52411 L p .835 .484 .391 r
F P
0 g
s
.48002 .51977 m .46958 .53245 L .47108 .37563 L p .133 0 .328 r
F P
0 g
s
.47108 .37563 m .48054 .36351 L .48002 .51977 L p .133 0 .328 r
F P
0 g
s
.44987 .71712 m .45662 .36766 L .47108 .37563 L p .835 .484 .391 r
F P
0 g
s
.47108 .37563 m .46773 .7258 L .44987 .71712 L p .835 .484 .391 r
F P
0 g
s
.48002 .51977 m .46958 .53245 L .47108 .37563 L p .133 0 .328 r
F P
0 g
s
.47108 .37563 m .48054 .36351 L .48002 .51977 L p .133 0 .328 r
F P
0 g
s
.52859 .35518 m .54292 .36322 L .53321 .37535 L p .694 .677 .829 r
F P
0 g
s
.53321 .37535 m .51891 .36737 L .52859 .35518 L p .694 .677 .829 r
F P
0 g
s
.5264 .70255 m .51891 .36737 L .53321 .37535 L p .836 .479 .38 r
F P
0 g
s
.53321 .37535 m .54387 .71121 L .5264 .70255 L p .836 .479 .38 r
F P
0 g
s
.55582 .69804 m .54387 .71121 L .53321 .37535 L p .169 0 .354 r
F P
0 g
s
.53321 .37535 m .54292 .36322 L .55582 .69804 L p .169 0 .354 r
F P
0 g
s
.52705 .73129 m .51891 .36737 L .53321 .37535 L p .836 .479 .38 r
F P
0 g
s
.53321 .37535 m .54479 .73999 L .52705 .73129 L p .836 .479 .38 r
F P
0 g
s
.55693 .72676 m .54479 .73999 L .53321 .37535 L p .169 0 .354 r
F P
0 g
s
.53321 .37535 m .54292 .36322 L .55693 .72676 L p .169 0 .354 r
F P
0 g
s
.59115 .35489 m .60531 .36293 L .59535 .37506 L p .694 .677 .829 r
F P
0 g
s
.59535 .37506 m .58121 .36708 L .59115 .35489 L p .694 .677 .829 r
F P
0 g
s
.60178 .68819 m .61887 .69684 L .60676 .70985 L p .683 .706 .865 r
F P
0 g
s
.60452 .73097 m .58121 .36708 L .59535 .37506 L p .837 .474 .368 r
F P
0 g
s
.59535 .37506 m .622 .73968 L .60452 .73097 L p .837 .474 .368 r
F P
0 g
s
.63454 .72644 m .622 .73968 L .59535 .37506 L p .201 .006 .378 r
F P
0 g
s
.59535 .37506 m .60531 .36293 L .63454 .72644 L p .201 .006 .378 r
F P
0 g
s
.60178 .68819 m .58121 .36708 L .59535 .37506 L p .837 .474 .368 r
F P
0 g
s
.59535 .37506 m .61887 .69684 L .60178 .68819 L p .837 .474 .368 r
F P
0 g
s
.63454 .72644 m .622 .73968 L .59535 .37506 L p .201 .006 .378 r
F P
0 g
s
.59535 .37506 m .60531 .36293 L .63454 .72644 L p .201 .006 .378 r
F P
0 g
s
.65372 .3546 m .66772 .36264 L .6575 .37477 L p .694 .677 .829 r
F P
0 g
s
.6575 .37477 m .64353 .36679 L .65372 .3546 L p .694 .677 .829 r
F P
0 g
s
.68201 .73066 m .64353 .36679 L .6575 .37477 L p .838 .469 .355 r
F P
0 g
s
.6575 .37477 m .69924 .73936 L .68201 .73066 L p .838 .469 .355 r
F P
0 g
s
.7174 .73357 m .70107 .72527 L .71342 .71258 L p .684 .705 .863 r
F P
0 g
s
.70603 .66413 m .68965 .65561 L .70195 .64256 L p .685 .702 .86 r
F P
0 g
s
.69694 .70415 m .71342 .71258 L .70107 .72527 L p .684 .705 .863 r
F P
0 g
s
.69119 .66904 m .70768 .67759 L .69536 .69046 L p .685 .704 .862 r
F P
0 g
s
.71342 .71258 m .69694 .70415 L .70937 .69125 L p .684 .705 .863 r
F P
0 g
s
.71216 .72613 m .69924 .73936 L .6575 .37477 L p .23 .037 .399 r
F P
0 g
s
.6575 .37477 m .66772 .36264 L .71216 .72613 L p .23 .037 .399 r
F P
0 g
s
.68201 .73066 m .64353 .36679 L .6575 .37477 L p .838 .469 .355 r
F P
0 g
s
.6575 .37477 m .69924 .73936 L .68201 .73066 L p .838 .469 .355 r
F P
0 g
s
.70195 .64256 m .68965 .65561 L .6575 .37477 L p .23 .037 .399 r
F P
0 g
s
.6575 .37477 m .66772 .36264 L .70195 .64256 L p .23 .037 .399 r
F P
0 g
s
.71631 .3543 m .73014 .36235 L .71966 .37449 L p .694 .677 .829 r
F P
0 g
s
.71966 .37449 m .70586 .3665 L .71631 .3543 L p .694 .677 .829 r
F P
0 g
s
.74228 .70822 m .75858 .71662 L .74604 .72928 L p .684 .705 .863 r
F P
0 g
s
.75858 .71662 m .74228 .70822 L .75491 .69536 L p .684 .705 .863 r
F P
0 g
s
.74916 .66013 m .76553 .66873 L .75289 .68169 L p .685 .704 .862 r
F P
0 g
s
.75289 .68169 m .73656 .67317 L .74916 .66013 L p .685 .704 .862 r
F P
0 g
s
.73846 .68682 m .75491 .69536 L .74228 .70822 L p .684 .705 .863 r
F P
0 g
s
.75951 .73034 m .70586 .3665 L .71966 .37449 L p .839 .463 .341 r
F P
0 g
s
.71966 .37449 m .77649 .73905 L .75951 .73034 L p .839 .463 .341 r
F P
0 g
s
.78981 .72581 m .77649 .73905 L .71966 .37449 L p .256 .065 .418 r
F P
0 g
s
.71966 .37449 m .73014 .36235 L .78981 .72581 L p .256 .065 .418 r
F P
0 g
s
.74916 .66013 m .70586 .3665 L .71966 .37449 L p .839 .463 .341 r
F P
0 g
s
.71966 .37449 m .76553 .66873 L .74916 .66013 L p .839 .463 .341 r
F P
0 g
s
.78981 .72581 m .77649 .73905 L .71966 .37449 L p .256 .065 .418 r
F P
0 g
s
.71966 .37449 m .73014 .36235 L .78981 .72581 L p .256 .065 .418 r
F P
0 g
s
.7789 .35401 m .79257 .36206 L .78183 .3742 L p .694 .677 .829 r
F P
0 g
s
.78183 .3742 m .7682 .36622 L .7789 .35401 L p .694 .677 .829 r
F P
0 g
s
.8316 .70129 m .7682 .36622 L .78183 .3742 L p .839 .457 .326 r
F P
0 g
s
.78183 .3742 m .84808 .70996 L .8316 .70129 L p .839 .457 .326 r
F P
0 g
s
.86156 .69678 m .84808 .70996 L .78183 .3742 L p .28 .091 .436 r
F P
0 g
s
.78183 .3742 m .79257 .36206 L .86156 .69678 L p .28 .091 .436 r
F P
0 g
s
.83704 .73003 m .7682 .36622 L .78183 .3742 L p .839 .457 .326 r
F P
0 g
s
.78183 .3742 m .85376 .73874 L .83704 .73003 L p .839 .457 .326 r
F P
0 g
s
.86747 .72549 m .85376 .73874 L .78183 .3742 L p .28 .091 .436 r
F P
0 g
s
.78183 .3742 m .79257 .36206 L .86747 .72549 L p .28 .091 .436 r
F P
0 g
s
.17707 .35274 m .19236 .36079 L .18407 .37294 L p .694 .677 .829 r
F P
0 g
s
.18407 .37294 m .16882 .36495 L .17707 .35274 L p .694 .677 .829 r
F P
0 g
s
.1122 .63184 m .16882 .36495 L .18407 .37294 L p .828 .501 .435 r
F P
0 g
s
.18407 .37294 m .13035 .64041 L .1122 .63184 L p .828 .501 .435 r
F P
0 g
s
.13987 .62738 m .13035 .64041 L .18407 .37294 L p 0 0 .156 r
F P
0 g
s
.18407 .37294 m .19236 .36079 L .13987 .62738 L p 0 0 .156 r
F P
0 g
s
.1094 .64505 m .16882 .36495 L .18407 .37294 L p .828 .501 .435 r
F P
0 g
s
.18407 .37294 m .12769 .65364 L .1094 .64505 L p .828 .501 .435 r
F P
0 g
s
.13727 .64057 m .12769 .65364 L .18407 .37294 L p 0 0 .156 r
F P
0 g
s
.18407 .37294 m .19236 .36079 L .13727 .64057 L p 0 0 .156 r
F P
0 g
s
.23965 .35245 m .25477 .36051 L .24622 .37265 L p .694 .677 .829 r
F P
0 g
s
.24622 .37265 m .23114 .36466 L .23965 .35245 L p .694 .677 .829 r
F P
0 g
s
.18788 .61852 m .23114 .36466 L .24622 .37265 L p .83 .498 .426 r
F P
0 g
s
.24622 .37265 m .20566 .62707 L .18788 .61852 L p .83 .498 .426 r
F P
0 g
s
.22524 .6227 m .2077 .61423 L .21745 .60126 L p .687 .699 .856 r
F P
0 g
s
.21547 .61407 m .20566 .62707 L .24622 .37265 L p 0 0 .2 r
F P
0 g
s
.24622 .37265 m .25477 .36051 L .21547 .61407 L p 0 0 .2 r
F P
0 g
s
.18788 .61852 m .23114 .36466 L .24622 .37265 L p .83 .498 .426 r
F P
0 g
s
.24622 .37265 m .20566 .62707 L .18788 .61852 L p .83 .498 .426 r
F P
0 g
s
.21745 .60126 m .2077 .61423 L .24622 .37265 L p 0 0 .2 r
F P
0 g
s
.24622 .37265 m .25477 .36051 L .21745 .60126 L p 0 0 .2 r
F P
0 g
s
.30224 .35216 m .31719 .36022 L .30839 .37237 L p .694 .677 .829 r
F P
0 g
s
.30839 .37237 m .29347 .36437 L .30224 .35216 L p .694 .677 .829 r
F P
0 g
s
.26246 .60539 m .29347 .36437 L .30839 .37237 L p .831 .494 .417 r
F P
0 g
s
.30839 .37237 m .27988 .61392 L .26246 .60539 L p .831 .494 .417 r
F P
0 g
s
.28997 .60095 m .27988 .61392 L .30839 .37237 L p .02 0 .24 r
F P
0 g
s
.30839 .37237 m .31719 .36022 L .28997 .60095 L p .02 0 .24 r
F P
0 g
s
.26081 .61821 m .29347 .36437 L .30839 .37237 L p .831 .494 .417 r
F P
0 g
s
.30839 .37237 m .27836 .62676 L .26081 .61821 L p .831 .494 .417 r
F P
0 g
s
.28852 .61376 m .27836 .62676 L .30839 .37237 L p .02 0 .24 r
F P
0 g
s
.30839 .37237 m .31719 .36022 L .28852 .61376 L p .02 0 .24 r
F P
0 g
s
.36484 .35187 m .37963 .35993 L .37057 .37208 L p .694 .677 .829 r
F P
0 g
s
.37057 .37208 m .35581 .36408 L .36484 .35187 L p .694 .677 .829 r
F P
0 g
s
.32913 .67113 m .35581 .36408 L .37057 .37208 L p .833 .49 .407 r
F P
0 g
s
.37057 .37208 m .347 .67977 L .32913 .67113 L p .833 .49 .407 r
F P
0 g
s
.36566 .67471 m .34804 .66614 L .35877 .65303 L p .685 .704 .862 r
F P
0 g
s
.35781 .66663 m .347 .67977 L .37057 .37208 L p .066 0 .276 r
F P
0 g
s
.37057 .37208 m .37963 .35993 L .35781 .66663 L p .066 0 .276 r
F P
0 g
s
.32913 .67113 m .35581 .36408 L .37057 .37208 L p .833 .49 .407 r
F P
0 g
s
.37057 .37208 m .347 .67977 L .32913 .67113 L p .833 .49 .407 r
F P
0 g
s
.35877 .65303 m .34804 .66614 L .37057 .37208 L p .066 0 .276 r
F P
0 g
s
.37057 .37208 m .37963 .35993 L .35877 .65303 L p .066 0 .276 r
F P
0 g
s
.42745 .35157 m .44207 .35964 L .43276 .37179 L p .694 .677 .829 r
F P
0 g
s
.43276 .37179 m .41817 .3638 L .42745 .35157 L p .694 .677 .829 r
F P
0 g
s
.4037 .68463 m .41817 .3638 L .43276 .37179 L p .834 .486 .397 r
F P
0 g
s
.43276 .37179 m .42146 .6933 L .4037 .68463 L p .834 .486 .397 r
F P
0 g
s
.43272 .68012 m .42146 .6933 L .43276 .37179 L p .108 0 .308 r
F P
0 g
s
.43276 .37179 m .44207 .35964 L .43272 .68012 L p .108 0 .308 r
F P
0 g
s
.40306 .69866 m .41817 .3638 L .43276 .37179 L p .834 .486 .397 r
F P
0 g
s
.43276 .37179 m .42096 .70735 L .40306 .69866 L p .834 .486 .397 r
F P
0 g
s
.43231 .69414 m .42096 .70735 L .43276 .37179 L p .108 0 .308 r
F P
0 g
s
.43276 .37179 m .44207 .35964 L .43231 .69414 L p .108 0 .308 r
F P
0 g
s
.49008 .35128 m .50453 .35935 L .49496 .37151 L p .694 .677 .829 r
F P
0 g
s
.49496 .37151 m .48054 .36351 L .49008 .35128 L p .694 .677 .829 r
F P
0 g
s
.48002 .51977 m .48054 .36351 L .49496 .37151 L p .835 .482 .386 r
F P
0 g
s
.49496 .37151 m .49595 .52814 L .48002 .51977 L p .835 .482 .386 r
F P
0 g
s
.50653 .51541 m .49595 .52814 L .49496 .37151 L p .145 0 .337 r
F P
0 g
s
.49496 .37151 m .50453 .35935 L .50653 .51541 L p .145 0 .337 r
F P
0 g
s
.48002 .51977 m .48054 .36351 L .49496 .37151 L p .835 .482 .386 r
F P
0 g
s
.49496 .37151 m .49595 .52814 L .48002 .51977 L p .835 .482 .386 r
F P
0 g
s
.509 .70807 m .49718 .72131 L .49496 .37151 L p .145 0 .337 r
F P
0 g
s
.49496 .37151 m .50453 .35935 L .509 .70807 L p .145 0 .337 r
F P
0 g
s
.55271 .35099 m .567 .35906 L .55718 .37122 L p .694 .677 .829 r
F P
0 g
s
.55718 .37122 m .54292 .36322 L .55271 .35099 L p .694 .677 .829 r
F P
0 g
s
.55637 .71228 m .54292 .36322 L .55718 .37122 L p .836 .477 .374 r
F P
0 g
s
.55718 .37122 m .57391 .721 L .55637 .71228 L p .836 .477 .374 r
F P
0 g
s
.58612 .70775 m .57391 .721 L .55718 .37122 L p .18 0 .362 r
F P
0 g
s
.55718 .37122 m .567 .35906 L .58612 .70775 L p .18 0 .362 r
F P
0 g
s
.55693 .72676 m .54292 .36322 L .55718 .37122 L p .836 .477 .374 r
F P
0 g
s
.55718 .37122 m .5746 .73549 L .55693 .72676 L p .836 .477 .374 r
F P
0 g
s
.58691 .72221 m .5746 .73549 L .55718 .37122 L p .18 0 .362 r
F P
0 g
s
.55718 .37122 m .567 .35906 L .58691 .72221 L p .18 0 .362 r
F P
0 g
s
.61536 .3507 m .62948 .35877 L .6194 .37093 L p .694 .677 .829 r
F P
0 g
s
.6194 .37093 m .60531 .36293 L .61536 .3507 L p .694 .677 .829 r
F P
0 g
s
.63454 .72644 m .60531 .36293 L .6194 .37093 L p .837 .472 .362 r
F P
0 g
s
.6194 .37093 m .65195 .73517 L .63454 .72644 L p .837 .472 .362 r
F P
0 g
s
.66783 .72934 m .65066 .72068 L .66326 .70743 L p .682 .709 .868 r
F P
0 g
s
.66466 .72189 m .65195 .73517 L .6194 .37093 L p .211 .017 .385 r
F P
0 g
s
.6194 .37093 m .62948 .35877 L .66466 .72189 L p .211 .017 .385 r
F P
0 g
s
.63454 .72644 m .60531 .36293 L .6194 .37093 L p .837 .472 .362 r
F P
0 g
s
.6194 .37093 m .65195 .73517 L .63454 .72644 L p .837 .472 .362 r
F P
0 g
s
.66326 .70743 m .65066 .72068 L .6194 .37093 L p .211 .017 .385 r
F P
0 g
s
.6194 .37093 m .62948 .35877 L .66326 .70743 L p .211 .017 .385 r
F P
0 g
s
.67803 .35041 m .69198 .35848 L .68164 .37064 L p .694 .677 .829 r
F P
0 g
s
.68164 .37064 m .66772 .36264 L .67803 .35041 L p .694 .677 .829 r
F P
0 g
s
.70033 .62936 m .66772 .36264 L .68164 .37064 L p .838 .466 .348 r
F P
0 g
s
.68164 .37064 m .71664 .63795 L .70033 .62936 L p .838 .466 .348 r
F P
0 g
s
.72899 .62489 m .71664 .63795 L .68164 .37064 L p .239 .047 .406 r
F P
0 g
s
.68164 .37064 m .69198 .35848 L .72899 .62489 L p .239 .047 .406 r
F P
0 g
s
.70195 .64256 m .66772 .36264 L .68164 .37064 L p .838 .466 .348 r
F P
0 g
s
.68164 .37064 m .71837 .65117 L .70195 .64256 L p .838 .466 .348 r
F P
0 g
s
.73083 .63808 m .71837 .65117 L .68164 .37064 L p .239 .047 .406 r
F P
0 g
s
.68164 .37064 m .69198 .35848 L .73083 .63808 L p .239 .047 .406 r
F P
0 g
s
.7407 .35012 m .75449 .35819 L .74389 .37036 L p .694 .677 .829 r
F P
0 g
s
.74389 .37036 m .73014 .36235 L .7407 .35012 L p .694 .677 .829 r
F P
0 g
s
.78981 .72581 m .73014 .36235 L .74389 .37036 L p .839 .46 .334 r
F P
0 g
s
.74389 .37036 m .80671 .73455 L .78981 .72581 L p .839 .46 .334 r
F P
0 g
s
.81759 .7068 m .8343 .71555 L .82088 .72872 L p .682 .709 .868 r
F P
0 g
s
.82088 .72872 m .80421 .72006 L .81759 .7068 L p .682 .709 .868 r
F P
0 g
s
.82021 .72126 m .80671 .73455 L .74389 .37036 L p .264 .074 .424 r
F P
0 g
s
.74389 .37036 m .75449 .35819 L .82021 .72126 L p .264 .074 .424 r
F P
0 g
s
.78981 .72581 m .73014 .36235 L .74389 .37036 L p .839 .46 .334 r
F P
0 g
s
.74389 .37036 m .80671 .73455 L .78981 .72581 L p .839 .46 .334 r
F P
0 g
s
.81759 .7068 m .80421 .72006 L .74389 .37036 L p .264 .074 .424 r
F P
0 g
s
.74389 .37036 m .75449 .35819 L .81759 .7068 L p .264 .074 .424 r
F P
0 g
s
.80339 .34983 m .81701 .3579 L .80616 .37007 L p .694 .677 .829 r
F P
0 g
s
.80616 .37007 m .79257 .36206 L .80339 .34983 L p .694 .677 .829 r
F P
0 g
s
.86449 .71103 m .79257 .36206 L .80616 .37007 L p .839 .453 .319 r
F P
0 g
s
.80616 .37007 m .88102 .71974 L .86449 .71103 L p .839 .453 .319 r
F P
0 g
s
.89479 .70649 m .88102 .71974 L .80616 .37007 L p .288 .099 .441 r
F P
0 g
s
.80616 .37007 m .81701 .3579 L .89479 .70649 L p .288 .099 .441 r
F P
0 g
s
.86747 .72549 m .79257 .36206 L .80616 .37007 L p .839 .453 .319 r
F P
0 g
s
.80616 .37007 m .88412 .73423 L .86747 .72549 L p .839 .453 .319 r
F P
0 g
s
.89801 .72094 m .88412 .73423 L .80616 .37007 L p .288 .099 .441 r
F P
0 g
s
.80616 .37007 m .81701 .3579 L .89801 .72094 L p .288 .099 .441 r
F P
0 g
s
.20072 .34855 m .21597 .35663 L .20757 .36881 L p .694 .677 .829 r
F P
0 g
s
.20757 .36881 m .19236 .36079 L .20072 .34855 L p .694 .677 .829 r
F P
0 g
s
.14243 .61438 m .19236 .36079 L .20757 .36881 L p .829 .499 .43 r
F P
0 g
s
.20757 .36881 m .16038 .62296 L .14243 .61438 L p .829 .499 .43 r
F P
0 g
s
.16999 .60991 m .16038 .62296 L .20757 .36881 L p 0 0 .171 r
F P
0 g
s
.20757 .36881 m .21597 .35663 L .16999 .60991 L p 0 0 .171 r
F P
0 g
s
.13727 .64057 m .19236 .36079 L .20757 .36881 L p .829 .499 .43 r
F P
0 g
s
.20757 .36881 m .15551 .6492 L .13727 .64057 L p .829 .499 .43 r
F P
0 g
s
.16999 .60991 m .16038 .62296 L .20757 .36881 L p 0 0 .171 r
F P
0 g
s
.20757 .36881 m .21597 .35663 L .16999 .60991 L p 0 0 .171 r
F P
0 g
s
.26339 .34826 m .27847 .35634 L .26981 .36852 L p .694 .677 .829 r
F P
0 g
s
.26981 .36852 m .25477 .36051 L .26339 .34826 L p .694 .677 .829 r
F P
0 g
s
.21941 .58864 m .25477 .36051 L .26981 .36852 L p .831 .496 .421 r
F P
0 g
s
.26981 .36852 m .23686 .59717 L .21941 .58864 L p .831 .496 .421 r
F P
0 g
s
.24669 .5842 m .23686 .59717 L .26981 .36852 L p 0 0 .214 r
F P
0 g
s
.26981 .36852 m .27847 .35634 L .24669 .5842 L p 0 0 .214 r
F P
0 g
s
.21745 .60126 m .25477 .36051 L .26981 .36852 L p .831 .496 .421 r
F P
0 g
s
.26981 .36852 m .23504 .60982 L .21745 .60126 L p .831 .496 .421 r
F P
0 g
s
.24669 .5842 m .23686 .59717 L .26981 .36852 L p 0 0 .214 r
F P
0 g
s
.26981 .36852 m .27847 .35634 L .24669 .5842 L p 0 0 .214 r
F P
0 g
s
.32607 .34796 m .34098 .35605 L .33207 .36823 L p .694 .677 .829 r
F P
0 g
s
.33207 .36823 m .31719 .36022 L .32607 .34796 L p .694 .677 .829 r
F P
0 g
s
.28852 .61376 m .31719 .36022 L .33207 .36823 L p .832 .492 .412 r
F P
0 g
s
.33207 .36823 m .30601 .62234 L .28852 .61376 L p .832 .492 .412 r
F P
0 g
s
.31632 .60929 m .30601 .62234 L .33207 .36823 L p .036 0 .253 r
F P
0 g
s
.33207 .36823 m .34098 .35605 L .31632 .60929 L p .036 0 .253 r
F P
0 g
s
.28852 .61376 m .31719 .36022 L .33207 .36823 L p .832 .492 .412 r
F P
0 g
s
.33207 .36823 m .30601 .62234 L .28852 .61376 L p .832 .492 .412 r
F P
0 g
s
.31115 .66243 m .30055 .67561 L .33207 .36823 L p .036 0 .253 r
F P
0 g
s
.33207 .36823 m .34098 .35605 L .31115 .66243 L p .036 0 .253 r
F P
0 g
s
.38876 .34767 m .4035 .35576 L .39434 .36794 L p .694 .677 .829 r
F P
0 g
s
.39434 .36794 m .37963 .35993 L .38876 .34767 L p .694 .677 .829 r
F P
0 g
s
.35877 .65303 m .37644 .66168 L .36566 .67471 L p .685 .704 .862 r
F P
0 g
s
.35781 .66663 m .37963 .35993 L .39434 .36794 L p .833 .488 .402 r
F P
0 g
s
.39434 .36794 m .37561 .6753 L .35781 .66663 L p .833 .488 .402 r
F P
0 g
s
.38658 .66212 m .37561 .6753 L .39434 .36794 L p .08 0 .287 r
F P
0 g
s
.39434 .36794 m .4035 .35576 L .38658 .66212 L p .08 0 .287 r
F P
0 g
s
.35877 .65303 m .37963 .35993 L .39434 .36794 L p .833 .488 .402 r
F P
0 g
s
.39434 .36794 m .37644 .66168 L .35877 .65303 L p .833 .488 .402 r
F P
0 g
s
.38658 .66212 m .37561 .6753 L .39434 .36794 L p .08 0 .287 r
F P
0 g
s
.39434 .36794 m .4035 .35576 L .38658 .66212 L p .08 0 .287 r
F P
0 g
s
.45146 .34738 m .46604 .35547 L .45662 .36766 L p .694 .677 .829 r
F P
0 g
s
.45662 .36766 m .44207 .35964 L .45146 .34738 L p .694 .677 .829 r
F P
0 g
s
.43752 .51571 m .44207 .35964 L .45662 .36766 L p .835 .484 .391 r
F P
0 g
s
.45662 .36766 m .4536 .52411 L .43752 .51571 L p .835 .484 .391 r
F P
0 g
s
.464 .51135 m .4536 .52411 L .45662 .36766 L p .121 0 .318 r
F P
0 g
s
.45662 .36766 m .46604 .35547 L .464 .51135 L p .121 0 .318 r
F P
0 g
s
.43231 .69414 m .44207 .35964 L .45662 .36766 L p .835 .484 .391 r
F P
0 g
s
.45662 .36766 m .45015 .70286 L .43231 .69414 L p .835 .484 .391 r
F P
0 g
s
.464 .51135 m .4536 .52411 L .45662 .36766 L p .121 0 .318 r
F P
0 g
s
.45662 .36766 m .46604 .35547 L .464 .51135 L p .121 0 .318 r
F P
0 g
s
.51418 .34709 m .52859 .35518 L .51891 .36737 L p .694 .677 .829 r
F P
0 g
s
.51891 .36737 m .50453 .35935 L .51418 .34709 L p .694 .677 .829 r
F P
0 g
s
.50882 .69383 m .50453 .35935 L .51891 .36737 L p .836 .479 .38 r
F P
0 g
s
.51891 .36737 m .5264 .70255 L .50882 .69383 L p .836 .479 .38 r
F P
0 g
s
.5383 .68929 m .5264 .70255 L .51891 .36737 L p .157 0 .346 r
F P
0 g
s
.51891 .36737 m .52859 .35518 L .5383 .68929 L p .157 0 .346 r
F P
0 g
s
.509 .70807 m .50453 .35935 L .51891 .36737 L p .836 .479 .38 r
F P
0 g
s
.51891 .36737 m .52672 .7168 L .509 .70807 L p .836 .479 .38 r
F P
0 g
s
.5383 .68929 m .5264 .70255 L .51891 .36737 L p .157 0 .346 r
F P
0 g
s
.51891 .36737 m .52859 .35518 L .5383 .68929 L p .157 0 .346 r
F P
0 g
s
.57691 .3468 m .59115 .35489 L .58121 .36708 L p .694 .677 .829 r
F P
0 g
s
.58121 .36708 m .567 .35906 L .57691 .3468 L p .694 .677 .829 r
F P
0 g
s
.58381 .66569 m .567 .35906 L .58121 .36708 L p .837 .474 .368 r
F P
0 g
s
.58121 .36708 m .60089 .67437 L .58381 .66569 L p .837 .474 .368 r
F P
0 g
s
.61298 .66117 m .60089 .67437 L .58121 .36708 L p .19 0 .37 r
F P
0 g
s
.58121 .36708 m .59115 .35489 L .61298 .66117 L p .19 0 .37 r
F P
0 g
s
.58691 .72221 m .567 .35906 L .58121 .36708 L p .837 .474 .368 r
F P
0 g
s
.58121 .36708 m .60452 .73097 L .58691 .72221 L p .837 .474 .368 r
F P
0 g
s
.617 .71765 m .60452 .73097 L .58121 .36708 L p .19 0 .37 r
F P
0 g
s
.58121 .36708 m .59115 .35489 L .617 .71765 L p .19 0 .37 r
F P
0 g
s
.63965 .34651 m .65372 .3546 L .64353 .36679 L p .694 .677 .829 r
F P
0 g
s
.64353 .36679 m .62948 .35877 L .63965 .34651 L p .694 .677 .829 r
F P
0 g
s
.66326 .70743 m .68048 .71618 L .66783 .72934 L p .682 .709 .868 r
F P
0 g
s
.66466 .72189 m .62948 .35877 L .64353 .36679 L p .838 .469 .355 r
F P
0 g
s
.64353 .36679 m .68201 .73066 L .66466 .72189 L p .838 .469 .355 r
F P
0 g
s
.69489 .71733 m .68201 .73066 L .64353 .36679 L p .22 .027 .392 r
F P
0 g
s
.64353 .36679 m .65372 .3546 L .69489 .71733 L p .22 .027 .392 r
F P
0 g
s
.66326 .70743 m .62948 .35877 L .64353 .36679 L p .838 .469 .355 r
F P
0 g
s
.64353 .36679 m .68048 .71618 L .66326 .70743 L p .838 .469 .355 r
F P
0 g
s
.69489 .71733 m .68201 .73066 L .64353 .36679 L p .22 .027 .392 r
F P
0 g
s
.64353 .36679 m .65372 .3546 L .69489 .71733 L p .22 .027 .392 r
F P
0 g
s
.7024 .34621 m .71631 .3543 L .70586 .3665 L p .694 .677 .829 r
F P
0 g
s
.70586 .3665 m .69198 .35848 L .7024 .34621 L p .694 .677 .829 r
F P
0 g
s
.71837 .65117 m .73468 .65973 L .72231 .67261 L p .685 .702 .86 r
F P
0 g
s
.74604 .72928 m .72978 .72096 L .74228 .70822 L p .684 .705 .863 r
F P
0 g
s
.73083 .63808 m .74718 .64672 L .73468 .65973 L p .685 .702 .86 r
F P
0 g
s
.73468 .65973 m .71837 .65117 L .73083 .63808 L p .685 .702 .86 r
F P
0 g
s
.74228 .70822 m .72588 .69976 L .73846 .68682 L p .684 .705 .863 r
F P
0 g
s
.74243 .72158 m .69198 .35848 L .70586 .3665 L p .839 .463 .341 r
F P
0 g
s
.70586 .3665 m .75951 .73034 L .74243 .72158 L p .839 .463 .341 r
F P
0 g
s
.77279 .71701 m .75951 .73034 L .70586 .3665 L p .248 .056 .412 r
F P
0 g
s
.70586 .3665 m .71631 .3543 L .77279 .71701 L p .248 .056 .412 r
F P
0 g
s
.73083 .63808 m .69198 .35848 L .70586 .3665 L p .839 .463 .341 r
F P
0 g
s
.70586 .3665 m .74718 .64672 L .73083 .63808 L p .839 .463 .341 r
F P
0 g
s
.77279 .71701 m .75951 .73034 L .70586 .3665 L p .248 .056 .412 r
F P
0 g
s
.70586 .3665 m .71631 .3543 L .77279 .71701 L p .248 .056 .412 r
F P
0 g
s
.76517 .34592 m .7789 .35401 L .7682 .36622 L p .694 .677 .829 r
F P
0 g
s
.7682 .36622 m .75449 .35819 L .76517 .34592 L p .694 .677 .829 r
F P
0 g
s
.81502 .69257 m .75449 .35819 L .7682 .36622 L p .839 .457 .326 r
F P
0 g
s
.7682 .36622 m .8316 .70129 L .81502 .69257 L p .839 .457 .326 r
F P
0 g
s
.84504 .68802 m .8316 .70129 L .7682 .36622 L p .272 .082 .43 r
F P
0 g
s
.7682 .36622 m .7789 .35401 L .84504 .68802 L p .272 .082 .43 r
F P
0 g
s
.81759 .7068 m .75449 .35819 L .7682 .36622 L p .839 .457 .326 r
F P
0 g
s
.7682 .36622 m .8343 .71555 L .81759 .7068 L p .839 .457 .326 r
F P
0 g
s
.84504 .68802 m .8316 .70129 L .7682 .36622 L p .272 .082 .43 r
F P
0 g
s
.7682 .36622 m .7789 .35401 L .84504 .68802 L p .272 .082 .43 r
F P
0 g
s
.82794 .34563 m .84151 .35372 L .83055 .36593 L p .694 .677 .829 r
F P
0 g
s
.83055 .36593 m .81701 .3579 L .82794 .34563 L p .694 .677 .829 r
F P
0 g
s
.89801 .72094 m .81701 .3579 L .83055 .36593 L p .839 .45 .311 r
F P
0 g
s
.83055 .36593 m .91459 .72971 L .89801 .72094 L p .839 .45 .311 r
F P
0 g
s
.92866 .71638 m .91459 .72971 L .83055 .36593 L p .295 .107 .446 r
F P
0 g
s
.83055 .36593 m .84151 .35372 L .92866 .71638 L p .295 .107 .446 r
F P
0 g
s
.89801 .72094 m .81701 .3579 L .83055 .36593 L p .839 .45 .311 r
F P
0 g
s
.83055 .36593 m .91459 .72971 L .89801 .72094 L p .839 .45 .311 r
F P
0 g
s
.12167 .61872 m .1122 .63184 L .16882 .36495 L p 0 0 .14 r
F P
0 g
s
.16882 .36495 m .17707 .35274 L .12167 .61872 L p 0 0 .14 r
F P
0 g
s
.22444 .34435 m .23965 .35245 L .23114 .36466 L p .694 .677 .829 r
F P
0 g
s
.23114 .36466 m .21597 .35663 L .22444 .34435 L p .694 .677 .829 r
F P
0 g
s
.17231 .59712 m .21597 .35663 L .23114 .36466 L p .83 .498 .426 r
F P
0 g
s
.23114 .36466 m .19006 .6057 L .17231 .59712 L p .83 .498 .426 r
F P
0 g
s
.19976 .59265 m .19006 .6057 L .23114 .36466 L p 0 0 .186 r
F P
0 g
s
.23114 .36466 m .23965 .35245 L .19976 .59265 L p 0 0 .186 r
F P
0 g
s
.16999 .60991 m .21597 .35663 L .23114 .36466 L p .83 .498 .426 r
F P
0 g
s
.23114 .36466 m .18788 .61852 L .16999 .60991 L p .83 .498 .426 r
F P
0 g
s
.19763 .60544 m .18788 .61852 L .23114 .36466 L p 0 0 .186 r
F P
0 g
s
.23114 .36466 m .23965 .35245 L .19763 .60544 L p 0 0 .186 r
F P
0 g
s
.2872 .34405 m .30224 .35216 L .29347 .36437 L p .694 .677 .829 r
F P
0 g
s
.29347 .36437 m .27847 .35634 L .2872 .34405 L p .694 .677 .829 r
F P
0 g
s
.24669 .5842 m .27847 .35634 L .29347 .36437 L p .831 .494 .417 r
F P
0 g
s
.29347 .36437 m .26408 .59276 L .24669 .5842 L p .831 .494 .417 r
F P
0 g
s
.27406 .57974 m .26408 .59276 L .29347 .36437 L p .004 0 .228 r
F P
0 g
s
.29347 .36437 m .30224 .35216 L .27406 .57974 L p .004 0 .228 r
F P
0 g
s
.24669 .5842 m .27847 .35634 L .29347 .36437 L p .831 .494 .417 r
F P
0 g
s
.29347 .36437 m .26408 .59276 L .24669 .5842 L p .831 .494 .417 r
F P
0 g
s
.2725 .59234 m .26246 .60539 L .29347 .36437 L p .004 0 .228 r
F P
0 g
s
.29347 .36437 m .30224 .35216 L .2725 .59234 L p .004 0 .228 r
F P
0 g
s
.34997 .34376 m .36484 .35187 L .35581 .36408 L p .694 .677 .829 r
F P
0 g
s
.35581 .36408 m .34098 .35605 L .34997 .34376 L p .694 .677 .829 r
F P
0 g
s
.31247 .64884 m .34098 .35605 L .35581 .36408 L p .833 .49 .407 r
F P
0 g
s
.35581 .36408 m .33031 .65752 L .31247 .64884 L p .833 .49 .407 r
F P
0 g
s
.34099 .64433 m .33031 .65752 L .35581 .36408 L p .051 0 .265 r
F P
0 g
s
.35581 .36408 m .36484 .35187 L .34099 .64433 L p .051 0 .265 r
F P
0 g
s
.31115 .66243 m .34098 .35605 L .35581 .36408 L p .833 .49 .407 r
F P
0 g
s
.35581 .36408 m .32913 .67113 L .31115 .66243 L p .833 .49 .407 r
F P
0 g
s
.33989 .6579 m .32913 .67113 L .35581 .36408 L p .051 0 .265 r
F P
0 g
s
.35581 .36408 m .36484 .35187 L .33989 .6579 L p .051 0 .265 r
F P
0 g
s
.41275 .34347 m .42745 .35157 L .41817 .3638 L p .694 .677 .829 r
F P
0 g
s
.41817 .3638 m .4035 .35576 L .41275 .34347 L p .694 .677 .829 r
F P
0 g
s
.38658 .66212 m .4035 .35576 L .41817 .3638 L p .834 .486 .397 r
F P
0 g
s
.41817 .3638 m .40432 .67082 L .38658 .66212 L p .834 .486 .397 r
F P
0 g
s
.41545 .65759 m .40432 .67082 L .41817 .3638 L p .094 0 .298 r
F P
0 g
s
.41817 .3638 m .42745 .35157 L .41545 .65759 L p .094 0 .298 r
F P
0 g
s
.38658 .66212 m .4035 .35576 L .41817 .3638 L p .834 .486 .397 r
F P
0 g
s
.41817 .3638 m .40432 .67082 L .38658 .66212 L p .834 .486 .397 r
F P
0 g
s
.41491 .67137 m .4037 .68463 L .41817 .3638 L p .094 0 .298 r
F P
0 g
s
.41817 .3638 m .42745 .35157 L .41491 .67137 L p .094 0 .298 r
F P
0 g
s
.47554 .34318 m .49008 .35128 L .48054 .36351 L p .694 .677 .829 r
F P
0 g
s
.48054 .36351 m .46604 .35547 L .47554 .34318 L p .694 .677 .829 r
F P
0 g
s
.46415 .49994 m .46604 .35547 L .48054 .36351 L p .835 .482 .386 r
F P
0 g
s
.48054 .36351 m .48006 .50834 L .46415 .49994 L p .835 .482 .386 r
F P
0 g
s
.49053 .49557 m .48006 .50834 L .48054 .36351 L p .133 0 .328 r
F P
0 g
s
.48054 .36351 m .49008 .35128 L .49053 .49557 L p .133 0 .328 r
F P
0 g
s
.464 .51135 m .46604 .35547 L .48054 .36351 L p .835 .482 .386 r
F P
0 g
s
.48054 .36351 m .48002 .51977 L .464 .51135 L p .835 .482 .386 r
F P
0 g
s
.49056 .50696 m .48002 .51977 L .48054 .36351 L p .133 0 .328 r
F P
0 g
s
.48054 .36351 m .49008 .35128 L .49056 .50696 L p .133 0 .328 r
F P
0 g
s
.53835 .34288 m .55271 .35099 L .54292 .36322 L p .694 .677 .829 r
F P
0 g
s
.54292 .36322 m .52859 .35518 L .53835 .34288 L p .694 .677 .829 r
F P
0 g
s
.5383 .68929 m .52859 .35518 L .54292 .36322 L p .836 .477 .374 r
F P
0 g
s
.54292 .36322 m .55582 .69804 L .5383 .68929 L p .836 .477 .374 r
F P
0 g
s
.56789 .68473 m .55582 .69804 L .54292 .36322 L p .169 0 .354 r
F P
0 g
s
.54292 .36322 m .55271 .35099 L .56789 .68473 L p .169 0 .354 r
F P
0 g
s
.5383 .68929 m .52859 .35518 L .54292 .36322 L p .836 .477 .374 r
F P
0 g
s
.54292 .36322 m .55582 .69804 L .5383 .68929 L p .836 .477 .374 r
F P
0 g
s
.56854 .69895 m .55637 .71228 L .54292 .36322 L p .169 0 .354 r
F P
0 g
s
.54292 .36322 m .55271 .35099 L .56854 .69895 L p .169 0 .354 r
F P
0 g
s
.60117 .34259 m .61536 .3507 L .60531 .36293 L p .694 .677 .829 r
F P
0 g
s
.60531 .36293 m .59115 .35489 L .60117 .34259 L p .694 .677 .829 r
F P
0 g
s
.61597 .7032 m .59115 .35489 L .60531 .36293 L p .837 .472 .362 r
F P
0 g
s
.60531 .36293 m .63337 .71197 L .61597 .7032 L p .837 .472 .362 r
F P
0 g
s
.64593 .69863 m .63337 .71197 L .60531 .36293 L p .201 .006 .378 r
F P
0 g
s
.60531 .36293 m .61536 .3507 L .64593 .69863 L p .201 .006 .378 r
F P
0 g
s
.617 .71765 m .59115 .35489 L .60531 .36293 L p .837 .472 .362 r
F P
0 g
s
.60531 .36293 m .63454 .72644 L .617 .71765 L p .837 .472 .362 r
F P
0 g
s
.6472 .71307 m .63454 .72644 L .60531 .36293 L p .201 .006 .378 r
F P
0 g
s
.60531 .36293 m .61536 .3507 L .6472 .71307 L p .201 .006 .378 r
F P
0 g
s
.664 .3423 m .67803 .35041 L .66772 .36264 L p .694 .677 .829 r
F P
0 g
s
.66772 .36264 m .65372 .3546 L .664 .3423 L p .694 .677 .829 r
F P
0 g
s
.69489 .71733 m .65372 .3546 L .66772 .36264 L p .838 .466 .348 r
F P
0 g
s
.66772 .36264 m .71216 .72613 L .69489 .71733 L p .838 .466 .348 r
F P
0 g
s
.72231 .67261 m .70603 .66413 L .71837 .65117 L p .685 .702 .86 r
F P
0 g
s
.71664 .63795 m .70033 .62936 L .71265 .61622 L p .686 .701 .859 r
F P
0 g
s
.71342 .71258 m .72978 .72096 L .7174 .73357 L p .684 .705 .863 r
F P
0 g
s
.70195 .64256 m .71837 .65117 L .70603 .66413 L p .685 .702 .86 r
F P
0 g
s
.70937 .69125 m .72588 .69976 L .71342 .71258 L p .684 .705 .863 r
F P
0 g
s
.72522 .71275 m .71216 .72613 L .66772 .36264 L p .23 .037 .399 r
F P
0 g
s
.66772 .36264 m .67803 .35041 L .72522 .71275 L p .23 .037 .399 r
F P
0 g
s
.69489 .71733 m .65372 .3546 L .66772 .36264 L p .838 .466 .348 r
F P
0 g
s
.66772 .36264 m .71216 .72613 L .69489 .71733 L p .838 .466 .348 r
F P
0 g
s
.71265 .61622 m .70033 .62936 L .66772 .36264 L p .23 .037 .399 r
F P
0 g
s
.66772 .36264 m .67803 .35041 L .71265 .61622 L p .23 .037 .399 r
F P
0 g
s
.72684 .34201 m .7407 .35012 L .73014 .36235 L p .694 .677 .829 r
F P
0 g
s
.73014 .36235 m .71631 .3543 L .72684 .34201 L p .694 .677 .829 r
F P
0 g
s
.77054 .70257 m .71631 .3543 L .73014 .36235 L p .839 .46 .334 r
F P
0 g
s
.73014 .36235 m .78743 .71134 L .77054 .70257 L p .839 .46 .334 r
F P
0 g
s
.80078 .698 m .78743 .71134 L .73014 .36235 L p .256 .065 .418 r
F P
0 g
s
.73014 .36235 m .7407 .35012 L .80078 .698 L p .256 .065 .418 r
F P
0 g
s
.77279 .71701 m .71631 .3543 L .73014 .36235 L p .839 .46 .334 r
F P
0 g
s
.73014 .36235 m .78981 .72581 L .77279 .71701 L p .839 .46 .334 r
F P
0 g
s
.80327 .71243 m .78981 .72581 L .73014 .36235 L p .256 .065 .418 r
F P
0 g
s
.73014 .36235 m .7407 .35012 L .80327 .71243 L p .256 .065 .418 r
F P
0 g
s
.7897 .34171 m .80339 .34983 L .79257 .36206 L p .694 .677 .829 r
F P
0 g
s
.79257 .36206 m .7789 .35401 L .7897 .34171 L p .694 .677 .829 r
F P
0 g
s
.84504 .68802 m .7789 .35401 L .79257 .36206 L p .839 .453 .319 r
F P
0 g
s
.79257 .36206 m .86156 .69678 L .84504 .68802 L p .839 .453 .319 r
F P
0 g
s
.87517 .68347 m .86156 .69678 L .79257 .36206 L p .28 .091 .436 r
F P
0 g
s
.79257 .36206 m .80339 .34983 L .87517 .68347 L p .28 .091 .436 r
F P
0 g
s
.84504 .68802 m .7789 .35401 L .79257 .36206 L p .839 .453 .319 r
F P
0 g
s
.79257 .36206 m .86156 .69678 L .84504 .68802 L p .839 .453 .319 r
F P
0 g
s
.87823 .69768 m .86449 .71103 L .79257 .36206 L p .28 .091 .436 r
F P
0 g
s
.79257 .36206 m .80339 .34983 L .87823 .69768 L p .28 .091 .436 r
F P
0 g
s
.18539 .34043 m .20072 .34855 L .19236 .36079 L p .694 .677 .829 r
F P
0 g
s
.19236 .36079 m .17707 .35274 L .18539 .34043 L p .694 .677 .829 r
F P
0 g
s
.12437 .60575 m .17707 .35274 L .19236 .36079 L p .829 .499 .43 r
F P
0 g
s
.19236 .36079 m .14243 .61438 L .12437 .60575 L p .829 .499 .43 r
F P
0 g
s
.15198 .60126 m .14243 .61438 L .19236 .36079 L p 0 0 .156 r
F P
0 g
s
.19236 .36079 m .20072 .34855 L .15198 .60126 L p 0 0 .156 r
F P
0 g
s
.12167 .61872 m .17707 .35274 L .19236 .36079 L p .829 .499 .43 r
F P
0 g
s
.19236 .36079 m .13987 .62738 L .12167 .61872 L p .829 .499 .43 r
F P
0 g
s
.15198 .60126 m .14243 .61438 L .19236 .36079 L p 0 0 .156 r
F P
0 g
s
.19236 .36079 m .20072 .34855 L .15198 .60126 L p 0 0 .156 r
F P
0 g
s
.24823 .34013 m .26339 .34826 L .25477 .36051 L p .694 .677 .829 r
F P
0 g
s
.25477 .36051 m .23965 .35245 L .24823 .34013 L p .694 .677 .829 r
F P
0 g
s
.19763 .60544 m .23965 .35245 L .25477 .36051 L p .831 .496 .421 r
F P
0 g
s
.25477 .36051 m .21547 .61407 L .19763 .60544 L p .831 .496 .421 r
F P
0 g
s
.23686 .59717 m .21941 .58864 L .22919 .57559 L p .687 .698 .854 r
F P
0 g
s
.21745 .60126 m .23504 .60982 L .22524 .6227 L p .687 .699 .856 r
F P
0 g
s
.22537 .60094 m .21547 .61407 L .25477 .36051 L p 0 0 .2 r
F P
0 g
s
.25477 .36051 m .26339 .34826 L .22537 .60094 L p 0 0 .2 r
F P
0 g
s
.19763 .60544 m .23965 .35245 L .25477 .36051 L p .831 .496 .421 r
F P
0 g
s
.25477 .36051 m .21547 .61407 L .19763 .60544 L p .831 .496 .421 r
F P
0 g
s
.22919 .57559 m .21941 .58864 L .25477 .36051 L p 0 0 .2 r
F P
0 g
s
.25477 .36051 m .26339 .34826 L .22919 .57559 L p 0 0 .2 r
F P
0 g
s
.31107 .33984 m .32607 .34796 L .31719 .36022 L p .694 .677 .829 r
F P
0 g
s
.31719 .36022 m .30224 .35216 L .31107 .33984 L p .694 .677 .829 r
F P
0 g
s
.2725 .59234 m .28997 .60095 L .27988 .61392 L p .687 .699 .856 r
F P
0 g
s
.27988 .61392 m .26246 .60539 L .2725 .59234 L p .687 .699 .856 r
F P
0 g
s
.27092 .60512 m .30224 .35216 L .31719 .36022 L p .832 .492 .412 r
F P
0 g
s
.31719 .36022 m .28852 .61376 L .27092 .60512 L p .832 .492 .412 r
F P
0 g
s
.29878 .60063 m .28852 .61376 L .31719 .36022 L p .02 0 .24 r
F P
0 g
s
.31719 .36022 m .32607 .34796 L .29878 .60063 L p .02 0 .24 r
F P
0 g
s
.2725 .59234 m .30224 .35216 L .31719 .36022 L p .832 .492 .412 r
F P
0 g
s
.31719 .36022 m .28997 .60095 L .2725 .59234 L p .832 .492 .412 r
F P
0 g
s
.29878 .60063 m .28852 .61376 L .31719 .36022 L p .02 0 .24 r
F P
0 g
s
.31719 .36022 m .32607 .34796 L .29878 .60063 L p .02 0 .24 r
F P
0 g
s
.37393 .33955 m .38876 .34767 L .37963 .35993 L p .694 .677 .829 r
F P
0 g
s
.37963 .35993 m .36484 .35187 L .37393 .33955 L p .694 .677 .829 r
F P
0 g
s
.34208 .63096 m .36484 .35187 L .37963 .35993 L p .833 .488 .402 r
F P
0 g
s
.37963 .35993 m .35973 .63964 L .34208 .63096 L p .833 .488 .402 r
F P
0 g
s
.37049 .62644 m .35973 .63964 L .37963 .35993 L p .066 0 .276 r
F P
0 g
s
.37963 .35993 m .38876 .34767 L .37049 .62644 L p .066 0 .276 r
F P
0 g
s
.33989 .6579 m .36484 .35187 L .37963 .35993 L p .833 .488 .402 r
F P
0 g
s
.37963 .35993 m .35781 .66663 L .33989 .6579 L p .833 .488 .402 r
F P
0 g
s
.36872 .65336 m .35781 .66663 L .37963 .35993 L p .066 0 .276 r
F P
0 g
s
.37963 .35993 m .38876 .34767 L .36872 .65336 L p .066 0 .276 r
F P
0 g
s
.43681 .33925 m .45146 .34738 L .44207 .35964 L p .694 .677 .829 r
F P
0 g
s
.44207 .35964 m .42745 .35157 L .43681 .33925 L p .694 .677 .829 r
F P
0 g
s
.42134 .50727 m .42745 .35157 L .44207 .35964 L p .835 .484 .391 r
F P
0 g
s
.44207 .35964 m .43752 .51571 L .42134 .50727 L p .835 .484 .391 r
F P
0 g
s
.44788 .50287 m .43752 .51571 L .44207 .35964 L p .108 0 .308 r
F P
0 g
s
.44207 .35964 m .45146 .34738 L .44788 .50287 L p .108 0 .308 r
F P
0 g
s
.41491 .67137 m .42745 .35157 L .44207 .35964 L p .835 .484 .391 r
F P
0 g
s
.44207 .35964 m .43272 .68012 L .41491 .67137 L p .835 .484 .391 r
F P
0 g
s
.44788 .50287 m .43752 .51571 L .44207 .35964 L p .108 0 .308 r
F P
0 g
s
.44207 .35964 m .45146 .34738 L .44788 .50287 L p .108 0 .308 r
F P
0 g
s
.49969 .33896 m .51418 .34709 L .50453 .35935 L p .694 .677 .829 r
F P
0 g
s
.50453 .35935 m .49008 .35128 L .49969 .33896 L p .694 .677 .829 r
F P
0 g
s
.49056 .50696 m .49008 .35128 L .50453 .35935 L p .836 .479 .38 r
F P
0 g
s
.50453 .35935 m .50653 .51541 L .49056 .50696 L p .836 .479 .38 r
F P
0 g
s
.51721 .50257 m .50653 .51541 L .50453 .35935 L p .145 0 .337 r
F P
0 g
s
.50453 .35935 m .51418 .34709 L .51721 .50257 L p .145 0 .337 r
F P
0 g
s
.49056 .50696 m .49008 .35128 L .50453 .35935 L p .836 .479 .38 r
F P
0 g
s
.50453 .35935 m .50653 .51541 L .49056 .50696 L p .836 .479 .38 r
F P
0 g
s
.52067 .68048 m .50882 .69383 L .50453 .35935 L p .145 0 .337 r
F P
0 g
s
.50453 .35935 m .51418 .34709 L .52067 .68048 L p .145 0 .337 r
F P
0 g
s
.56259 .33867 m .57691 .3468 L .567 .35906 L p .694 .677 .829 r
F P
0 g
s
.567 .35906 m .55271 .35099 L .56259 .33867 L p .694 .677 .829 r
F P
0 g
s
.56663 .65696 m .55271 .35099 L .567 .35906 L p .837 .474 .368 r
F P
0 g
s
.567 .35906 m .58381 .66569 L .56663 .65696 L p .837 .474 .368 r
F P
0 g
s
.59586 .65241 m .58381 .66569 L .567 .35906 L p .18 0 .362 r
F P
0 g
s
.567 .35906 m .57691 .3468 L .59586 .65241 L p .18 0 .362 r
F P
0 g
s
.56854 .69895 m .55271 .35099 L .567 .35906 L p .837 .474 .368 r
F P
0 g
s
.567 .35906 m .58612 .70775 L .56854 .69895 L p .837 .474 .368 r
F P
0 g
s
.59586 .65241 m .58381 .66569 L .567 .35906 L p .18 0 .362 r
F P
0 g
s
.567 .35906 m .57691 .3468 L .59586 .65241 L p .18 0 .362 r
F P
0 g
s
.6255 .33837 m .63965 .34651 L .62948 .35877 L p .694 .677 .829 r
F P
0 g
s
.62948 .35877 m .61536 .3507 L .6255 .33837 L p .694 .677 .829 r
F P
0 g
s
.64468 .68442 m .61536 .3507 L .62948 .35877 L p .838 .469 .355 r
F P
0 g
s
.62948 .35877 m .66188 .6932 L .64468 .68442 L p .838 .469 .355 r
F P
0 g
s
.67451 .67985 m .66188 .6932 L .62948 .35877 L p .211 .017 .385 r
F P
0 g
s
.62948 .35877 m .63965 .34651 L .67451 .67985 L p .211 .017 .385 r
F P
0 g
s
.6472 .71307 m .61536 .3507 L .62948 .35877 L p .838 .469 .355 r
F P
0 g
s
.62948 .35877 m .66466 .72189 L .6472 .71307 L p .838 .469 .355 r
F P
0 g
s
.6775 .70848 m .66466 .72189 L .62948 .35877 L p .211 .017 .385 r
F P
0 g
s
.62948 .35877 m .63965 .34651 L .6775 .70848 L p .211 .017 .385 r
F P
0 g
s
.68842 .33808 m .7024 .34621 L .69198 .35848 L p .694 .677 .829 r
F P
0 g
s
.69198 .35848 m .67803 .35041 L .68842 .33808 L p .694 .677 .829 r
F P
0 g
s
.71265 .61622 m .72899 .62489 L .71664 .63795 L p .686 .701 .859 r
F P
0 g
s
.72522 .71275 m .67803 .35041 L .69198 .35848 L p .839 .463 .341 r
F P
0 g
s
.69198 .35848 m .74243 .72158 L .72522 .71275 L p .839 .463 .341 r
F P
0 g
s
.75566 .70816 m .74243 .72158 L .69198 .35848 L p .239 .047 .406 r
F P
0 g
s
.69198 .35848 m .7024 .34621 L .75566 .70816 L p .239 .047 .406 r
F P
0 g
s
.71265 .61622 m .67803 .35041 L .69198 .35848 L p .839 .463 .341 r
F P
0 g
s
.69198 .35848 m .72899 .62489 L .71265 .61622 L p .839 .463 .341 r
F P
0 g
s
.75566 .70816 m .74243 .72158 L .69198 .35848 L p .239 .047 .406 r
F P
0 g
s
.69198 .35848 m .7024 .34621 L .75566 .70816 L p .239 .047 .406 r
F P
0 g
s
.75135 .33778 m .76517 .34592 L .75449 .35819 L p .694 .677 .829 r
F P
0 g
s
.75449 .35819 m .7407 .35012 L .75135 .33778 L p .694 .677 .829 r
F P
0 g
s
.80327 .71243 m .7407 .35012 L .75449 .35819 L p .839 .457 .326 r
F P
0 g
s
.75449 .35819 m .82021 .72126 L .80327 .71243 L p .839 .457 .326 r
F P
0 g
s
.84808 .70996 m .8316 .70129 L .84504 .68802 L p .683 .708 .867 r
F P
0 g
s
.82842 .67921 m .84504 .68802 L .8316 .70129 L p .683 .708 .867 r
F P
0 g
s
.8316 .70129 m .81502 .69257 L .82842 .67921 L p .683 .708 .867 r
F P
0 g
s
.83385 .70784 m .82021 .72126 L .75449 .35819 L p .264 .074 .424 r
F P
0 g
s
.75449 .35819 m .76517 .34592 L .83385 .70784 L p .264 .074 .424 r
F P
0 g
s
.80327 .71243 m .7407 .35012 L .75449 .35819 L p .839 .457 .326 r
F P
0 g
s
.75449 .35819 m .82021 .72126 L .80327 .71243 L p .839 .457 .326 r
F P
0 g
s
.82842 .67921 m .81502 .69257 L .75449 .35819 L p .264 .074 .424 r
F P
0 g
s
.75449 .35819 m .76517 .34592 L .82842 .67921 L p .264 .074 .424 r
F P
0 g
s
.8143 .33749 m .82794 .34563 L .81701 .3579 L p .694 .677 .829 r
F P
0 g
s
.81701 .3579 m .80339 .34983 L .8143 .33749 L p .694 .677 .829 r
F P
0 g
s
.87823 .69768 m .89479 .70649 L .88102 .71974 L p .682 .709 .868 r
F P
0 g
s
.88133 .71212 m .80339 .34983 L .81701 .3579 L p .839 .45 .311 r
F P
0 g
s
.81701 .3579 m .89801 .72094 L .88133 .71212 L p .839 .45 .311 r
F P
0 g
s
.91205 .70752 m .89801 .72094 L .81701 .3579 L p .288 .099 .441 r
F P
0 g
s
.81701 .3579 m .82794 .34563 L .91205 .70752 L p .288 .099 .441 r
F P
0 g
s
.87823 .69768 m .80339 .34983 L .81701 .3579 L p .839 .45 .311 r
F P
0 g
s
.81701 .3579 m .89479 .70649 L .87823 .69768 L p .839 .45 .311 r
F P
0 g
s
.91205 .70752 m .89801 .72094 L .81701 .3579 L p .288 .099 .441 r
F P
0 g
s
.81701 .3579 m .82794 .34563 L .91205 .70752 L p .288 .099 .441 r
F P
0 g
s
.20915 .3362 m .22444 .34435 L .21597 .35663 L p .694 .677 .829 r
F P
0 g
s
.21597 .35663 m .20072 .34855 L .20915 .3362 L p .694 .677 .829 r
F P
0 g
s
.15198 .60126 m .20072 .34855 L .21597 .35663 L p .83 .498 .426 r
F P
0 g
s
.21597 .35663 m .16999 .60991 L .15198 .60126 L p .83 .498 .426 r
F P
0 g
s
.19006 .6057 m .17231 .59712 L .18195 .58399 L p .687 .699 .856 r
F P
0 g
s
.17969 .59675 m .16999 .60991 L .21597 .35663 L p 0 0 .171 r
F P
0 g
s
.21597 .35663 m .22444 .34435 L .17969 .59675 L p 0 0 .171 r
F P
0 g
s
.15198 .60126 m .20072 .34855 L .21597 .35663 L p .83 .498 .426 r
F P
0 g
s
.21597 .35663 m .16999 .60991 L .15198 .60126 L p .83 .498 .426 r
F P
0 g
s
.18195 .58399 m .17231 .59712 L .21597 .35663 L p 0 0 .171 r
F P
0 g
s
.21597 .35663 m .22444 .34435 L .18195 .58399 L p 0 0 .171 r
F P
0 g
s
.27208 .33591 m .2872 .34405 L .27847 .35634 L p .694 .677 .829 r
F P
0 g
s
.27847 .35634 m .26339 .34826 L .27208 .33591 L p .694 .677 .829 r
F P
0 g
s
.23105 .56319 m .26339 .34826 L .27847 .35634 L p .831 .494 .417 r
F P
0 g
s
.27847 .35634 m .24842 .57177 L .23105 .56319 L p .831 .494 .417 r
F P
0 g
s
.25828 .55871 m .24842 .57177 L .27847 .35634 L p 0 0 .214 r
F P
0 g
s
.27847 .35634 m .2872 .34405 L .25828 .55871 L p 0 0 .214 r
F P
0 g
s
.22919 .57559 m .26339 .34826 L .27847 .35634 L p .831 .494 .417 r
F P
0 g
s
.27847 .35634 m .24669 .5842 L .22919 .57559 L p .831 .494 .417 r
F P
0 g
s
.25661 .5711 m .24669 .5842 L .27847 .35634 L p 0 0 .214 r
F P
0 g
s
.27847 .35634 m .2872 .34405 L .25661 .5711 L p 0 0 .214 r
F P
0 g
s
.33502 .33561 m .34997 .34376 L .34098 .35605 L p .694 .677 .829 r
F P
0 g
s
.34098 .35605 m .32607 .34796 L .33502 .33561 L p .694 .677 .829 r
F P
0 g
s
.29878 .60063 m .32607 .34796 L .34098 .35605 L p .833 .49 .407 r
F P
0 g
s
.34098 .35605 m .31632 .60929 L .29878 .60063 L p .833 .49 .407 r
F P
0 g
s
.32673 .59612 m .31632 .60929 L .34098 .35605 L p .036 0 .253 r
F P
0 g
s
.34098 .35605 m .34997 .34376 L .32673 .59612 L p .036 0 .253 r
F P
0 g
s
.29878 .60063 m .32607 .34796 L .34098 .35605 L p .833 .49 .407 r
F P
0 g
s
.34098 .35605 m .31632 .60929 L .29878 .60063 L p .833 .49 .407 r
F P
0 g
s
.3231 .63556 m .31247 .64884 L .34098 .35605 L p .036 0 .253 r
F P
0 g
s
.34098 .35605 m .34997 .34376 L .3231 .63556 L p .036 0 .253 r
F P
0 g
s
.39797 .33532 m .41275 .34347 L .4035 .35576 L p .694 .677 .829 r
F P
0 g
s
.4035 .35576 m .38876 .34767 L .39797 .33532 L p .694 .677 .829 r
F P
0 g
s
.36961 .6398 m .38876 .34767 L .4035 .35576 L p .834 .486 .397 r
F P
0 g
s
.4035 .35576 m .38733 .64853 L .36961 .6398 L p .834 .486 .397 r
F P
0 g
s
.39833 .63525 m .38733 .64853 L .4035 .35576 L p .08 0 .287 r
F P
0 g
s
.4035 .35576 m .41275 .34347 L .39833 .63525 L p .08 0 .287 r
F P
0 g
s
.36872 .65336 m .38876 .34767 L .4035 .35576 L p .834 .486 .397 r
F P
0 g
s
.4035 .35576 m .38658 .66212 L .36872 .65336 L p .834 .486 .397 r
F P
0 g
s
.39766 .6488 m .38658 .66212 L .4035 .35576 L p .08 0 .287 r
F P
0 g
s
.4035 .35576 m .41275 .34347 L .39766 .6488 L p .08 0 .287 r
F P
0 g
s
.46093 .33502 m .47554 .34318 L .46604 .35547 L p .694 .677 .829 r
F P
0 g
s
.46604 .35547 m .45146 .34738 L .46093 .33502 L p .694 .677 .829 r
F P
0 g
s
.44788 .50287 m .45146 .34738 L .46604 .35547 L p .835 .482 .386 r
F P
0 g
s
.46604 .35547 m .464 .51135 L .44788 .50287 L p .835 .482 .386 r
F P
0 g
s
.48006 .50834 m .46415 .49994 L .47457 .4871 L p .69 .69 .845 r
F P
0 g
s
.4745 .49847 m .464 .51135 L .46604 .35547 L p .121 0 .318 r
F P
0 g
s
.46604 .35547 m .47554 .34318 L .4745 .49847 L p .121 0 .318 r
F P
0 g
s
.44788 .50287 m .45146 .34738 L .46604 .35547 L p .835 .482 .386 r
F P
0 g
s
.46604 .35547 m .464 .51135 L .44788 .50287 L p .835 .482 .386 r
F P
0 g
s
.47457 .4871 m .46415 .49994 L .46604 .35547 L p .121 0 .318 r
F P
0 g
s
.46604 .35547 m .47554 .34318 L .47457 .4871 L p .121 0 .318 r
F P
0 g
s
.52391 .33473 m .53835 .34288 L .52859 .35518 L p .694 .677 .829 r
F P
0 g
s
.52859 .35518 m .51418 .34709 L .52391 .33473 L p .694 .677 .829 r
F P
0 g
s
.5204 .6665 m .51418 .34709 L .52859 .35518 L p .836 .477 .374 r
F P
0 g
s
.52859 .35518 m .5379 .67528 L .5204 .6665 L p .836 .477 .374 r
F P
0 g
s
.54982 .66192 m .5379 .67528 L .52859 .35518 L p .157 0 .346 r
F P
0 g
s
.52859 .35518 m .53835 .34288 L .54982 .66192 L p .157 0 .346 r
F P
0 g
s
.52067 .68048 m .51418 .34709 L .52859 .35518 L p .836 .477 .374 r
F P
0 g
s
.52859 .35518 m .5383 .68929 L .52067 .68048 L p .836 .477 .374 r
F P
0 g
s
.55032 .6759 m .5383 .68929 L .52859 .35518 L p .157 0 .346 r
F P
0 g
s
.52859 .35518 m .53835 .34288 L .55032 .6759 L p .157 0 .346 r
F P
0 g
s
.58689 .33444 m .60117 .34259 L .59115 .35489 L p .694 .677 .829 r
F P
0 g
s
.59115 .35489 m .57691 .3468 L .58689 .33444 L p .694 .677 .829 r
F P
0 g
s
.59586 .65241 m .57691 .3468 L .59115 .35489 L p .837 .472 .362 r
F P
0 g
s
.59115 .35489 m .61298 .66117 L .59586 .65241 L p .837 .472 .362 r
F P
0 g
s
.62519 .64785 m .61298 .66117 L .59115 .35489 L p .19 0 .37 r
F P
0 g
s
.59115 .35489 m .60117 .34259 L .62519 .64785 L p .19 0 .37 r
F P
0 g
s
.59586 .65241 m .57691 .3468 L .59115 .35489 L p .837 .472 .362 r
F P
0 g
s
.59115 .35489 m .61298 .66117 L .59586 .65241 L p .837 .472 .362 r
F P
0 g
s
.62848 .68977 m .61597 .7032 L .59115 .35489 L p .19 0 .37 r
F P
0 g
s
.59115 .35489 m .60117 .34259 L .62848 .68977 L p .19 0 .37 r
F P
0 g
s
.64989 .33414 m .664 .3423 L .65372 .3546 L p .694 .677 .829 r
F P
0 g
s
.65372 .3546 m .63965 .34651 L .64989 .33414 L p .694 .677 .829 r
F P
0 g
s
.67599 .69405 m .63965 .34651 L .65372 .3546 L p .838 .466 .348 r
F P
0 g
s
.65372 .3546 m .69325 .70288 L .67599 .69405 L p .838 .466 .348 r
F P
0 g
s
.70615 .68945 m .69325 .70288 L .65372 .3546 L p .22 .027 .392 r
F P
0 g
s
.65372 .3546 m .664 .3423 L .70615 .68945 L p .22 .027 .392 r
F P
0 g
s
.6775 .70848 m .63965 .34651 L .65372 .3546 L p .838 .466 .348 r
F P
0 g
s
.65372 .3546 m .69489 .71733 L .6775 .70848 L p .838 .466 .348 r
F P
0 g
s
.70791 .70387 m .69489 .71733 L .65372 .3546 L p .22 .027 .392 r
F P
0 g
s
.65372 .3546 m .664 .3423 L .70791 .70387 L p .22 .027 .392 r
F P
0 g
s
.71291 .33385 m .72684 .34201 L .71631 .3543 L p .694 .677 .829 r
F P
0 g
s
.71631 .3543 m .7024 .34621 L .71291 .33385 L p .694 .677 .829 r
F P
0 g
s
.75566 .70816 m .7024 .34621 L .71631 .3543 L p .839 .46 .334 r
F P
0 g
s
.71631 .3543 m .77279 .71701 L .75566 .70816 L p .839 .46 .334 r
F P
0 g
s
.78384 .68913 m .80078 .698 L .78743 .71134 L p .682 .709 .868 r
F P
0 g
s
.78743 .71134 m .77054 .70257 L .78384 .68913 L p .682 .709 .868 r
F P
0 g
s
.78621 .70355 m .77279 .71701 L .71631 .3543 L p .248 .056 .412 r
F P
0 g
s
.71631 .3543 m .72684 .34201 L .78621 .70355 L p .248 .056 .412 r
F P
0 g
s
.75566 .70816 m .7024 .34621 L .71631 .3543 L p .839 .46 .334 r
F P
0 g
s
.71631 .3543 m .77279 .71701 L .75566 .70816 L p .839 .46 .334 r
F P
0 g
s
.78384 .68913 m .77054 .70257 L .71631 .3543 L p .248 .056 .412 r
F P
0 g
s
.71631 .3543 m .72684 .34201 L .78384 .68913 L p .248 .056 .412 r
F P
0 g
s
.77593 .33355 m .7897 .34171 L .7789 .35401 L p .694 .677 .829 r
F P
0 g
s
.7789 .35401 m .76517 .34592 L .77593 .33355 L p .694 .677 .829 r
F P
0 g
s
.82576 .66523 m .76517 .34592 L .7789 .35401 L p .839 .453 .319 r
F P
0 g
s
.7789 .35401 m .84227 .67402 L .82576 .66523 L p .839 .453 .319 r
F P
0 g
s
.85572 .66065 m .84227 .67402 L .7789 .35401 L p .272 .082 .43 r
F P
0 g
s
.7789 .35401 m .7897 .34171 L .85572 .66065 L p .272 .082 .43 r
F P
0 g
s
.82842 .67921 m .76517 .34592 L .7789 .35401 L p .839 .453 .319 r
F P
0 g
s
.7789 .35401 m .84504 .68802 L .82842 .67921 L p .839 .453 .319 r
F P
0 g
s
.85861 .67462 m .84504 .68802 L .7789 .35401 L p .272 .082 .43 r
F P
0 g
s
.7789 .35401 m .7897 .34171 L .85861 .67462 L p .272 .082 .43 r
F P
0 g
s
.83897 .33326 m .85257 .34142 L .84151 .35372 L p .694 .677 .829 r
F P
0 g
s
.84151 .35372 m .82794 .34563 L .83897 .33326 L p .694 .677 .829 r
F P
0 g
s
.91205 .70752 m .82794 .34563 L .84151 .35372 L p .84 .446 .302 r
F P
0 g
s
.84151 .35372 m .92866 .71638 L .91205 .70752 L p .84 .446 .302 r
F P
0 g
s
.94288 .70291 m .92866 .71638 L .84151 .35372 L p .295 .107 .446 r
F P
0 g
s
.84151 .35372 m .85257 .34142 L .94288 .70291 L p .295 .107 .446 r
F P
0 g
s
.91205 .70752 m .82794 .34563 L .84151 .35372 L p .84 .446 .302 r
F P
0 g
s
.84151 .35372 m .92866 .71638 L .91205 .70752 L p .84 .446 .302 r
F P
0 g
s
.13387 .59254 m .12437 .60575 L .17707 .35274 L p 0 0 .14 r
F P
0 g
s
.17707 .35274 m .18539 .34043 L .13387 .59254 L p 0 0 .14 r
F P
0 g
s
.23298 .33196 m .24823 .34013 L .23965 .35245 L p .694 .677 .829 r
F P
0 g
s
.23965 .35245 m .22444 .34435 L .23298 .33196 L p .694 .677 .829 r
F P
0 g
s
.18195 .58399 m .19976 .59265 L .19006 .6057 L p .687 .699 .856 r
F P
0 g
s
.17969 .59675 m .22444 .34435 L .23965 .35245 L p .831 .496 .421 r
F P
0 g
s
.23965 .35245 m .19763 .60544 L .17969 .59675 L p .831 .496 .421 r
F P
0 g
s
.20749 .59223 m .19763 .60544 L .23965 .35245 L p 0 0 .186 r
F P
0 g
s
.23965 .35245 m .24823 .34013 L .20749 .59223 L p 0 0 .186 r
F P
0 g
s
.18195 .58399 m .22444 .34435 L .23965 .35245 L p .831 .496 .421 r
F P
0 g
s
.23965 .35245 m .19976 .59265 L .18195 .58399 L p .831 .496 .421 r
F P
0 g
s
.20749 .59223 m .19763 .60544 L .23965 .35245 L p 0 0 .186 r
F P
0 g
s
.23965 .35245 m .24823 .34013 L .20749 .59223 L p 0 0 .186 r
F P
0 g
s
.296 .33167 m .31107 .33984 L .30224 .35216 L p .694 .677 .829 r
F P
0 g
s
.30224 .35216 m .2872 .34405 L .296 .33167 L p .694 .677 .829 r
F P
0 g
s
.24669 .5842 m .26408 .59276 L .2542 .60565 L p .687 .698 .854 r
F P
0 g
s
.25661 .5711 m .27406 .57974 L .26408 .59276 L p .687 .698 .854 r
F P
0 g
s
.26408 .59276 m .24669 .5842 L .25661 .5711 L p .687 .698 .854 r
F P
0 g
s
.2532 .59644 m .2872 .34405 L .30224 .35216 L p .832 .492 .412 r
F P
0 g
s
.30224 .35216 m .27092 .60512 L .2532 .59644 L p .832 .492 .412 r
F P
0 g
s
.28112 .59191 m .27092 .60512 L .30224 .35216 L p .004 0 .228 r
F P
0 g
s
.30224 .35216 m .31107 .33984 L .28112 .59191 L p .004 0 .228 r
F P
0 g
s
.25661 .5711 m .2872 .34405 L .30224 .35216 L p .832 .492 .412 r
F P
0 g
s
.30224 .35216 m .27406 .57974 L .25661 .5711 L p .832 .492 .412 r
F P
0 g
s
.28112 .59191 m .27092 .60512 L .30224 .35216 L p .004 0 .228 r
F P
0 g
s
.30224 .35216 m .31107 .33984 L .28112 .59191 L p .004 0 .228 r
F P
0 g
s
.35903 .33137 m .37393 .33955 L .36484 .35187 L p .694 .677 .829 r
F P
0 g
s
.36484 .35187 m .34997 .34376 L .35903 .33137 L p .694 .677 .829 r
F P
0 g
s
.32433 .62222 m .34997 .34376 L .36484 .35187 L p .833 .488 .402 r
F P
0 g
s
.36484 .35187 m .34208 .63096 L .32433 .62222 L p .833 .488 .402 r
F P
0 g
s
.35279 .61767 m .34208 .63096 L .36484 .35187 L p .051 0 .265 r
F P
0 g
s
.36484 .35187 m .37393 .33955 L .35279 .61767 L p .051 0 .265 r
F P
0 g
s
.3231 .63556 m .34997 .34376 L .36484 .35187 L p .833 .488 .402 r
F P
0 g
s
.36484 .35187 m .34099 .64433 L .3231 .63556 L p .833 .488 .402 r
F P
0 g
s
.35279 .61767 m .34208 .63096 L .36484 .35187 L p .051 0 .265 r
F P
0 g
s
.36484 .35187 m .37393 .33955 L .35279 .61767 L p .051 0 .265 r
F P
0 g
s
.42207 .33108 m .43681 .33925 L .42745 .35157 L p .694 .677 .829 r
F P
0 g
s
.42745 .35157 m .41275 .34347 L .42207 .33108 L p .694 .677 .829 r
F P
0 g
s
.40507 .49877 m .41275 .34347 L .42745 .35157 L p .835 .484 .391 r
F P
0 g
s
.42745 .35157 m .42134 .50727 L .40507 .49877 L p .835 .484 .391 r
F P
0 g
s
.43166 .49435 m .42134 .50727 L .42745 .35157 L p .094 0 .298 r
F P
0 g
s
.42745 .35157 m .43681 .33925 L .43166 .49435 L p .094 0 .298 r
F P
0 g
s
.39766 .6488 m .41275 .34347 L .42745 .35157 L p .835 .484 .391 r
F P
0 g
s
.42745 .35157 m .41545 .65759 L .39766 .6488 L p .835 .484 .391 r
F P
0 g
s
.43166 .49435 m .42134 .50727 L .42745 .35157 L p .094 0 .298 r
F P
0 g
s
.42745 .35157 m .43681 .33925 L .43166 .49435 L p .094 0 .298 r
F P
0 g
s
.48512 .33078 m .49969 .33896 L .49008 .35128 L p .694 .677 .829 r
F P
0 g
s
.49008 .35128 m .47554 .34318 L .48512 .33078 L p .694 .677 .829 r
F P
0 g
s
.47457 .4871 m .49053 .49557 L .48006 .50834 L p .69 .69 .845 r
F P
0 g
s
.4745 .49847 m .47554 .34318 L .49008 .35128 L p .836 .479 .38 r
F P
0 g
s
.49008 .35128 m .49056 .50696 L .4745 .49847 L p .836 .479 .38 r
F P
0 g
s
.50119 .49404 m .49056 .50696 L .49008 .35128 L p .133 0 .328 r
F P
0 g
s
.49008 .35128 m .49969 .33896 L .50119 .49404 L p .133 0 .328 r
F P
0 g
s
.47457 .4871 m .47554 .34318 L .49008 .35128 L p .836 .479 .38 r
F P
0 g
s
.49008 .35128 m .49053 .49557 L .47457 .4871 L p .836 .479 .38 r
F P
0 g
s
.50119 .49404 m .49056 .50696 L .49008 .35128 L p .133 0 .328 r
F P
0 g
s
.49008 .35128 m .49969 .33896 L .50119 .49404 L p .133 0 .328 r
F P
0 g
s
.54819 .33049 m .56259 .33867 L .55271 .35099 L p .694 .677 .829 r
F P
0 g
s
.55271 .35099 m .53835 .34288 L .54819 .33049 L p .694 .677 .829 r
F P
0 g
s
.54933 .64816 m .53835 .34288 L .55271 .35099 L p .837 .474 .368 r
F P
0 g
s
.55271 .35099 m .56663 .65696 L .54933 .64816 L p .837 .474 .368 r
F P
0 g
s
.57862 .64359 m .56663 .65696 L .55271 .35099 L p .169 0 .354 r
F P
0 g
s
.55271 .35099 m .56259 .33867 L .57862 .64359 L p .169 0 .354 r
F P
0 g
s
.55032 .6759 m .53835 .34288 L .55271 .35099 L p .837 .474 .368 r
F P
0 g
s
.55271 .35099 m .56789 .68473 L .55032 .6759 L p .837 .474 .368 r
F P
0 g
s
.57862 .64359 m .56663 .65696 L .55271 .35099 L p .169 0 .354 r
F P
0 g
s
.55271 .35099 m .56259 .33867 L .57862 .64359 L p .169 0 .354 r
F P
0 g
s
.61127 .33019 m .6255 .33837 L .61536 .3507 L p .694 .677 .829 r
F P
0 g
s
.61536 .3507 m .60117 .34259 L .61127 .33019 L p .694 .677 .829 r
F P
0 g
s
.62737 .67558 m .60117 .34259 L .61536 .3507 L p .838 .469 .355 r
F P
0 g
s
.61536 .3507 m .64468 .68442 L .62737 .67558 L p .838 .469 .355 r
F P
0 g
s
.65726 .67098 m .64468 .68442 L .61536 .3507 L p .201 .006 .378 r
F P
0 g
s
.61536 .3507 m .6255 .33837 L .65726 .67098 L p .201 .006 .378 r
F P
0 g
s
.62848 .68977 m .60117 .34259 L .61536 .3507 L p .838 .469 .355 r
F P
0 g
s
.61536 .3507 m .64593 .69863 L .62848 .68977 L p .838 .469 .355 r
F P
0 g
s
.65726 .67098 m .64468 .68442 L .61536 .3507 L p .201 .006 .378 r
F P
0 g
s
.61536 .3507 m .6255 .33837 L .65726 .67098 L p .201 .006 .378 r
F P
0 g
s
.67436 .3299 m .68842 .33808 L .67803 .35041 L p .694 .677 .829 r
F P
0 g
s
.67803 .35041 m .664 .3423 L .67436 .3299 L p .694 .677 .829 r
F P
0 g
s
.69463 .59455 m .664 .3423 L .67803 .35041 L p .839 .463 .341 r
F P
0 g
s
.67803 .35041 m .71096 .60325 L .69463 .59455 L p .839 .463 .341 r
F P
0 g
s
.7233 .59002 m .71096 .60325 L .67803 .35041 L p .23 .037 .399 r
F P
0 g
s
.67803 .35041 m .68842 .33808 L .7233 .59002 L p .23 .037 .399 r
F P
0 g
s
.70791 .70387 m .664 .3423 L .67803 .35041 L p .839 .463 .341 r
F P
0 g
s
.67803 .35041 m .72522 .71275 L .70791 .70387 L p .839 .463 .341 r
F P
0 g
s
.73842 .69924 m .72522 .71275 L .67803 .35041 L p .23 .037 .399 r
F P
0 g
s
.67803 .35041 m .68842 .33808 L .73842 .69924 L p .23 .037 .399 r
F P
0 g
s
.73746 .3296 m .75135 .33778 L .7407 .35012 L p .694 .677 .829 r
F P
0 g
s
.7407 .35012 m .72684 .34201 L .73746 .3296 L p .694 .677 .829 r
F P
0 g
s
.78621 .70355 m .72684 .34201 L .7407 .35012 L p .839 .457 .326 r
F P
0 g
s
.7407 .35012 m .80327 .71243 L .78621 .70355 L p .839 .457 .326 r
F P
0 g
s
.81687 .69892 m .80327 .71243 L .7407 .35012 L p .256 .065 .418 r
F P
0 g
s
.7407 .35012 m .75135 .33778 L .81687 .69892 L p .256 .065 .418 r
F P
0 g
s
.78384 .68913 m .72684 .34201 L .7407 .35012 L p .839 .457 .326 r
F P
0 g
s
.7407 .35012 m .80078 .698 L .78384 .68913 L p .839 .457 .326 r
F P
0 g
s
.81687 .69892 m .80327 .71243 L .7407 .35012 L p .256 .065 .418 r
F P
0 g
s
.7407 .35012 m .75135 .33778 L .81687 .69892 L p .256 .065 .418 r
F P
0 g
s
.80058 .32931 m .8143 .33749 L .80339 .34983 L p .694 .677 .829 r
F P
0 g
s
.80339 .34983 m .7897 .34171 L .80058 .32931 L p .694 .677 .829 r
F P
0 g
s
.85861 .67462 m .87517 .68347 L .86156 .69678 L p .683 .708 .867 r
F P
0 g
s
.86454 .70323 m .7897 .34171 L .80339 .34983 L p .839 .45 .311 r
F P
0 g
s
.88102 .71974 m .86449 .71103 L .87823 .69768 L p .682 .709 .868 r
F P
0 g
s
.80339 .34983 m .88133 .71212 L .86454 .70323 L p .839 .45 .311 r
F P
0 g
s
.89533 .6986 m .88133 .71212 L .80339 .34983 L p .28 .091 .436 r
F P
0 g
s
.80339 .34983 m .8143 .33749 L .89533 .6986 L p .28 .091 .436 r
F P
0 g
s
.85861 .67462 m .7897 .34171 L .80339 .34983 L p .839 .45 .311 r
F P
0 g
s
.80339 .34983 m .87517 .68347 L .85861 .67462 L p .839 .45 .311 r
F P
0 g
s
.89533 .6986 m .88133 .71212 L .80339 .34983 L p .28 .091 .436 r
F P
0 g
s
.80339 .34983 m .8143 .33749 L .89533 .6986 L p .28 .091 .436 r
F P
0 g
s
.19378 .32801 m .20915 .3362 L .20072 .34855 L p .694 .677 .829 r
F P
0 g
s
.20072 .34855 m .18539 .34043 L .19378 .32801 L p .694 .677 .829 r
F P
0 g
s
.13647 .57979 m .18539 .34043 L .20072 .34855 L p .83 .498 .426 r
F P
0 g
s
.20072 .34855 m .15445 .58848 L .13647 .57979 L p .83 .498 .426 r
F P
0 g
s
.16403 .57527 m .15445 .58848 L .20072 .34855 L p 0 0 .156 r
F P
0 g
s
.20072 .34855 m .20915 .3362 L .16403 .57527 L p 0 0 .156 r
F P
0 g
s
.13387 .59254 m .18539 .34043 L .20072 .34855 L p .83 .498 .426 r
F P
0 g
s
.20072 .34855 m .15198 .60126 L .13387 .59254 L p .83 .498 .426 r
F P
0 g
s
.16163 .58801 m .15198 .60126 L .20072 .34855 L p 0 0 .156 r
F P
0 g
s
.20072 .34855 m .20915 .3362 L .16163 .58801 L p 0 0 .156 r
F P
0 g
s
.25688 .32772 m .27208 .33591 L .26339 .34826 L p .694 .677 .829 r
F P
0 g
s
.26339 .34826 m .24823 .34013 L .25688 .32772 L p .694 .677 .829 r
F P
0 g
s
.20749 .59223 m .24823 .34013 L .26339 .34826 L p .831 .494 .417 r
F P
0 g
s
.26339 .34826 m .22537 .60094 L .20749 .59223 L p .831 .494 .417 r
F P
0 g
s
.24842 .57177 m .23105 .56319 L .24086 .55004 L p .687 .696 .853 r
F P
0 g
s
.22919 .57559 m .24669 .5842 L .23686 .59717 L p .687 .698 .854 r
F P
0 g
s
.23537 .58769 m .22537 .60094 L .26339 .34826 L p 0 0 .2 r
F P
0 g
s
.26339 .34826 m .27208 .33591 L .23537 .58769 L p 0 0 .2 r
F P
0 g
s
.20749 .59223 m .24823 .34013 L .26339 .34826 L p .831 .494 .417 r
F P
0 g
s
.26339 .34826 m .22537 .60094 L .20749 .59223 L p .831 .494 .417 r
F P
0 g
s
.24086 .55004 m .23105 .56319 L .26339 .34826 L p 0 0 .2 r
F P
0 g
s
.26339 .34826 m .27208 .33591 L .24086 .55004 L p 0 0 .2 r
F P
0 g
s
.31999 .32742 m .33502 .33561 L .32607 .34796 L p .694 .677 .829 r
F P
0 g
s
.32607 .34796 m .31107 .33984 L .31999 .32742 L p .694 .677 .829 r
F P
0 g
s
.28264 .57917 m .31107 .33984 L .32607 .34796 L p .833 .49 .407 r
F P
0 g
s
.32607 .34796 m .30016 .58786 L .28264 .57917 L p .833 .49 .407 r
F P
0 g
s
.31044 .57464 m .30016 .58786 L .32607 .34796 L p .02 0 .24 r
F P
0 g
s
.32607 .34796 m .33502 .33561 L .31044 .57464 L p .02 0 .24 r
F P
0 g
s
.28112 .59191 m .31107 .33984 L .32607 .34796 L p .833 .49 .407 r
F P
0 g
s
.32607 .34796 m .29878 .60063 L .28112 .59191 L p .833 .49 .407 r
F P
0 g
s
.30913 .58737 m .29878 .60063 L .32607 .34796 L p .02 0 .24 r
F P
0 g
s
.32607 .34796 m .33502 .33561 L .30913 .58737 L p .02 0 .24 r
F P
0 g
s
.38311 .32712 m .39797 .33532 L .38876 .34767 L p .694 .677 .829 r
F P
0 g
s
.38876 .34767 m .37393 .33955 L .38311 .32712 L p .694 .677 .829 r
F P
0 g
s
.35279 .61767 m .37393 .33955 L .38876 .34767 L p .834 .486 .397 r
F P
0 g
s
.38876 .34767 m .37049 .62644 L .35279 .61767 L p .834 .486 .397 r
F P
0 g
s
.38136 .6131 m .37049 .62644 L .38876 .34767 L p .066 0 .276 r
F P
0 g
s
.38876 .34767 m .39797 .33532 L .38136 .6131 L p .066 0 .276 r
F P
0 g
s
.35279 .61767 m .37393 .33955 L .38876 .34767 L p .834 .486 .397 r
F P
0 g
s
.38876 .34767 m .37049 .62644 L .35279 .61767 L p .834 .486 .397 r
F P
0 g
s
.38056 .62643 m .36961 .6398 L .38876 .34767 L p .066 0 .276 r
F P
0 g
s
.38876 .34767 m .39797 .33532 L .38056 .62643 L p .066 0 .276 r
F P
0 g
s
.44624 .32683 m .46093 .33502 L .45146 .34738 L p .694 .677 .829 r
F P
0 g
s
.45146 .34738 m .43681 .33925 L .44624 .32683 L p .694 .677 .829 r
F P
0 g
s
.43204 .483 m .43681 .33925 L .45146 .34738 L p .835 .482 .386 r
F P
0 g
s
.45146 .34738 m .44814 .4915 L .43204 .483 L p .835 .482 .386 r
F P
0 g
s
.45852 .47858 m .44814 .4915 L .45146 .34738 L p .108 0 .308 r
F P
0 g
s
.45146 .34738 m .46093 .33502 L .45852 .47858 L p .108 0 .308 r
F P
0 g
s
.43166 .49435 m .43681 .33925 L .45146 .34738 L p .835 .482 .386 r
F P
0 g
s
.45146 .34738 m .44788 .50287 L .43166 .49435 L p .835 .482 .386 r
F P
0 g
s
.45833 .48992 m .44788 .50287 L .45146 .34738 L p .108 0 .308 r
F P
0 g
s
.45146 .34738 m .46093 .33502 L .45833 .48992 L p .108 0 .308 r
F P
0 g
s
.50938 .32653 m .52391 .33473 L .51418 .34709 L p .694 .677 .829 r
F P
0 g
s
.51418 .34709 m .49969 .33896 L .50938 .32653 L p .694 .677 .829 r
F P
0 g
s
.50119 .49404 m .49969 .33896 L .51418 .34709 L p .836 .477 .374 r
F P
0 g
s
.51418 .34709 m .51721 .50257 L .50119 .49404 L p .836 .477 .374 r
F P
0 g
s
.52798 .48961 m .51721 .50257 L .51418 .34709 L p .145 0 .337 r
F P
0 g
s
.51418 .34709 m .52391 .33473 L .52798 .48961 L p .145 0 .337 r
F P
0 g
s
.50119 .49404 m .49969 .33896 L .51418 .34709 L p .836 .477 .374 r
F P
0 g
s
.51418 .34709 m .51721 .50257 L .50119 .49404 L p .836 .477 .374 r
F P
0 g
s
.53227 .65305 m .5204 .6665 L .51418 .34709 L p .145 0 .337 r
F P
0 g
s
.51418 .34709 m .52391 .33473 L .53227 .65305 L p .145 0 .337 r
F P
0 g
s
.57254 .32624 m .58689 .33444 L .57691 .3468 L p .694 .677 .829 r
F P
0 g
s
.57691 .3468 m .56259 .33867 L .57254 .32624 L p .694 .677 .829 r
F P
0 g
s
.57791 .63005 m .56259 .33867 L .57691 .3468 L p .837 .472 .362 r
F P
0 g
s
.57691 .3468 m .59502 .63885 L .57791 .63005 L p .837 .472 .362 r
F P
0 g
s
.60708 .62547 m .59502 .63885 L .57691 .3468 L p .18 0 .362 r
F P
0 g
s
.57691 .3468 m .58689 .33444 L .60708 .62547 L p .18 0 .362 r
F P
0 g
s
.57862 .64359 m .56259 .33867 L .57691 .3468 L p .837 .472 .362 r
F P
0 g
s
.57691 .3468 m .59586 .65241 L .57862 .64359 L p .837 .472 .362 r
F P
0 g
s
.60802 .639 m .59586 .65241 L .57691 .3468 L p .18 0 .362 r
F P
0 g
s
.57691 .3468 m .58689 .33444 L .60802 .639 L p .18 0 .362 r
F P
0 g
s
.63571 .32594 m .64989 .33414 L .63965 .34651 L p .694 .677 .829 r
F P
0 g
s
.63965 .34651 m .6255 .33837 L .63571 .32594 L p .694 .677 .829 r
F P
0 g
s
.65726 .67098 m .6255 .33837 L .63965 .34651 L p .838 .466 .348 r
F P
0 g
s
.63965 .34651 m .67451 .67985 L .65726 .67098 L p .838 .466 .348 r
F P
0 g
s
.68726 .66636 m .67451 .67985 L .63965 .34651 L p .211 .017 .385 r
F P
0 g
s
.63965 .34651 m .64989 .33414 L .68726 .66636 L p .211 .017 .385 r
F P
0 g
s
.65726 .67098 m .6255 .33837 L .63965 .34651 L p .838 .466 .348 r
F P
0 g
s
.63965 .34651 m .67451 .67985 L .65726 .67098 L p .838 .466 .348 r
F P
0 g
s
.68885 .68053 m .67599 .69405 L .63965 .34651 L p .211 .017 .385 r
F P
0 g
s
.63965 .34651 m .64989 .33414 L .68885 .68053 L p .211 .017 .385 r
F P
0 g
s
.6989 .32564 m .71291 .33385 L .7024 .34621 L p .694 .677 .829 r
F P
0 g
s
.7024 .34621 m .68842 .33808 L .6989 .32564 L p .694 .677 .829 r
F P
0 g
s
.73642 .68484 m .68842 .33808 L .7024 .34621 L p .839 .46 .334 r
F P
0 g
s
.7024 .34621 m .75354 .69373 L .73642 .68484 L p .839 .46 .334 r
F P
0 g
s
.7668 .68021 m .75354 .69373 L .7024 .34621 L p .239 .047 .406 r
F P
0 g
s
.7024 .34621 m .71291 .33385 L .7668 .68021 L p .239 .047 .406 r
F P
0 g
s
.73842 .69924 m .68842 .33808 L .7024 .34621 L p .839 .46 .334 r
F P
0 g
s
.7024 .34621 m .75566 .70816 L .73842 .69924 L p .839 .46 .334 r
F P
0 g
s
.76904 .6946 m .75566 .70816 L .7024 .34621 L p .239 .047 .406 r
F P
0 g
s
.7024 .34621 m .71291 .33385 L .76904 .6946 L p .239 .047 .406 r
F P
0 g
s
.76209 .32535 m .77593 .33355 L .76517 .34592 L p .694 .677 .829 r
F P
0 g
s
.76517 .34592 m .75135 .33778 L .76209 .32535 L p .694 .677 .829 r
F P
0 g
s
.81687 .69892 m .75135 .33778 L .76517 .34592 L p .839 .453 .319 r
F P
0 g
s
.76517 .34592 m .83385 .70784 L .81687 .69892 L p .839 .453 .319 r
F P
0 g
s
.84504 .68802 m .86156 .69678 L .84808 .70996 L p .683 .708 .867 r
F P
0 g
s
.83918 .65177 m .85572 .66065 L .84227 .67402 L p .683 .706 .865 r
F P
0 g
s
.84227 .67402 m .82576 .66523 L .83918 .65177 L p .683 .706 .865 r
F P
0 g
s
.86156 .69678 m .84504 .68802 L .85861 .67462 L p .683 .708 .867 r
F P
0 g
s
.84763 .69428 m .83385 .70784 L .76517 .34592 L p .264 .074 .424 r
F P
0 g
s
.76517 .34592 m .77593 .33355 L .84763 .69428 L p .264 .074 .424 r
F P
0 g
s
.81687 .69892 m .75135 .33778 L .76517 .34592 L p .839 .453 .319 r
F P
0 g
s
.76517 .34592 m .83385 .70784 L .81687 .69892 L p .839 .453 .319 r
F P
0 g
s
.83918 .65177 m .82576 .66523 L .76517 .34592 L p .264 .074 .424 r
F P
0 g
s
.76517 .34592 m .77593 .33355 L .83918 .65177 L p .264 .074 .424 r
F P
0 g
s
.8253 .32505 m .83897 .33326 L .82794 .34563 L p .694 .677 .829 r
F P
0 g
s
.82794 .34563 m .8143 .33749 L .8253 .32505 L p .694 .677 .829 r
F P
0 g
s
.8921 .6842 m .8143 .33749 L .82794 .34563 L p .84 .446 .302 r
F P
0 g
s
.82794 .34563 m .9087 .69309 L .8921 .6842 L p .84 .446 .302 r
F P
0 g
s
.92275 .67956 m .9087 .69309 L .82794 .34563 L p .288 .099 .441 r
F P
0 g
s
.82794 .34563 m .83897 .33326 L .92275 .67956 L p .288 .099 .441 r
F P
0 g
s
.89533 .6986 m .8143 .33749 L .82794 .34563 L p .84 .446 .302 r
F P
0 g
s
.82794 .34563 m .91205 .70752 L .89533 .6986 L p .84 .446 .302 r
F P
0 g
s
.92623 .69396 m .91205 .70752 L .82794 .34563 L p .288 .099 .441 r
F P
0 g
s
.82794 .34563 m .83897 .33326 L .92623 .69396 L p .288 .099 .441 r
F P
0 g
s
.21765 .32375 m .23298 .33196 L .22444 .34435 L p .694 .677 .829 r
F P
0 g
s
.22444 .34435 m .20915 .3362 L .21765 .32375 L p .694 .677 .829 r
F P
0 g
s
.1664 .56272 m .20915 .3362 L .22444 .34435 L p .831 .496 .421 r
F P
0 g
s
.22444 .34435 m .18418 .57142 L .1664 .56272 L p .831 .496 .421 r
F P
0 g
s
.19385 .5582 m .18418 .57142 L .22444 .34435 L p 0 0 .171 r
F P
0 g
s
.22444 .34435 m .23298 .33196 L .19385 .5582 L p 0 0 .171 r
F P
0 g
s
.16163 .58801 m .20915 .3362 L .22444 .34435 L p .831 .496 .421 r
F P
0 g
s
.22444 .34435 m .17969 .59675 L .16163 .58801 L p .831 .496 .421 r
F P
0 g
s
.18948 .58346 m .17969 .59675 L .22444 .34435 L p 0 0 .171 r
F P
0 g
s
.22444 .34435 m .23298 .33196 L .18948 .58346 L p 0 0 .171 r
F P
0 g
s
.28084 .32345 m .296 .33167 L .2872 .34405 L p .694 .677 .829 r
F P
0 g
s
.2872 .34405 m .27208 .33591 L .28084 .32345 L p .694 .677 .829 r
F P
0 g
s
.24086 .55004 m .25828 .55871 L .24842 .57177 L p .687 .696 .853 r
F P
0 g
s
.23537 .58769 m .27208 .33591 L .2872 .34405 L p .832 .492 .412 r
F P
0 g
s
.2542 .60565 m .23686 .59717 L .24669 .5842 L p .687 .698 .854 r
F P
0 g
s
.2872 .34405 m .2532 .59644 L .23537 .58769 L p .832 .492 .412 r
F P
0 g
s
.26335 .58314 m .2532 .59644 L .2872 .34405 L p 0 0 .214 r
F P
0 g
s
.2872 .34405 m .296 .33167 L .26335 .58314 L p 0 0 .214 r
F P
0 g
s
.24086 .55004 m .27208 .33591 L .2872 .34405 L p .832 .492 .412 r
F P
0 g
s
.2872 .34405 m .25828 .55871 L .24086 .55004 L p .832 .492 .412 r
F P
0 g
s
.26335 .58314 m .2532 .59644 L .2872 .34405 L p 0 0 .214 r
F P
0 g
s
.2872 .34405 m .296 .33167 L .26335 .58314 L p 0 0 .214 r
F P
0 g
s
.34404 .32316 m .35903 .33137 L .34997 .34376 L p .694 .677 .829 r
F P
0 g
s
.34997 .34376 m .33502 .33561 L .34404 .32316 L p .694 .677 .829 r
F P
0 g
s
.30913 .58737 m .33502 .33561 L .34997 .34376 L p .833 .488 .402 r
F P
0 g
s
.34997 .34376 m .32673 .59612 L .30913 .58737 L p .833 .488 .402 r
F P
0 g
s
.33724 .58282 m .32673 .59612 L .34997 .34376 L p .036 0 .253 r
F P
0 g
s
.34997 .34376 m .35903 .33137 L .33724 .58282 L p .036 0 .253 r
F P
0 g
s
.30913 .58737 m .33502 .33561 L .34997 .34376 L p .833 .488 .402 r
F P
0 g
s
.34997 .34376 m .32673 .59612 L .30913 .58737 L p .833 .488 .402 r
F P
0 g
s
.33499 .60884 m .32433 .62222 L .34997 .34376 L p .036 0 .253 r
F P
0 g
s
.34997 .34376 m .35903 .33137 L .33499 .60884 L p .036 0 .253 r
F P
0 g
s
.40725 .32286 m .42207 .33108 L .41275 .34347 L p .694 .677 .829 r
F P
0 g
s
.41275 .34347 m .39797 .33532 L .40725 .32286 L p .694 .677 .829 r
F P
0 g
s
.3887 .49023 m .39797 .33532 L .41275 .34347 L p .835 .484 .391 r
F P
0 g
s
.41275 .34347 m .40507 .49877 L .3887 .49023 L p .835 .484 .391 r
F P
0 g
s
.41535 .48578 m .40507 .49877 L .41275 .34347 L p .08 0 .287 r
F P
0 g
s
.41275 .34347 m .42207 .33108 L .41535 .48578 L p .08 0 .287 r
F P
0 g
s
.38056 .62643 m .39797 .33532 L .41275 .34347 L p .835 .484 .391 r
F P
0 g
s
.41275 .34347 m .39833 .63525 L .38056 .62643 L p .835 .484 .391 r
F P
0 g
s
.41535 .48578 m .40507 .49877 L .41275 .34347 L p .08 0 .287 r
F P
0 g
s
.41275 .34347 m .42207 .33108 L .41535 .48578 L p .08 0 .287 r
F P
0 g
s
.47048 .32257 m .48512 .33078 L .47554 .34318 L p .694 .677 .829 r
F P
0 g
s
.47554 .34318 m .46093 .33502 L .47048 .32257 L p .694 .677 .829 r
F P
0 g
s
.45871 .4674 m .46093 .33502 L .47554 .34318 L p .836 .479 .38 r
F P
0 g
s
.47554 .34318 m .47465 .47589 L .45871 .4674 L p .836 .479 .38 r
F P
0 g
s
.48509 .46298 m .47465 .47589 L .47554 .34318 L p .121 0 .318 r
F P
0 g
s
.47554 .34318 m .48512 .33078 L .48509 .46298 L p .121 0 .318 r
F P
0 g
s
.45833 .48992 m .46093 .33502 L .47554 .34318 L p .836 .479 .38 r
F P
0 g
s
.47554 .34318 m .4745 .49847 L .45833 .48992 L p .836 .479 .38 r
F P
0 g
s
.48509 .48547 m .4745 .49847 L .47554 .34318 L p .121 0 .318 r
F P
0 g
s
.47554 .34318 m .48512 .33078 L .48509 .48547 L p .121 0 .318 r
F P
0 g
s
.53371 .32227 m .54819 .33049 L .53835 .34288 L p .694 .677 .829 r
F P
0 g
s
.53835 .34288 m .52391 .33473 L .53371 .32227 L p .694 .677 .829 r
F P
0 g
s
.53191 .63932 m .52391 .33473 L .53835 .34288 L p .837 .474 .368 r
F P
0 g
s
.53835 .34288 m .54933 .64816 L .53191 .63932 L p .837 .474 .368 r
F P
0 g
s
.56127 .63471 m .54933 .64816 L .53835 .34288 L p .157 0 .346 r
F P
0 g
s
.53835 .34288 m .54819 .33049 L .56127 .63471 L p .157 0 .346 r
F P
0 g
s
.53227 .65305 m .52391 .33473 L .53835 .34288 L p .837 .474 .368 r
F P
0 g
s
.53835 .34288 m .54982 .66192 L .53227 .65305 L p .837 .474 .368 r
F P
0 g
s
.56127 .63471 m .54933 .64816 L .53835 .34288 L p .157 0 .346 r
F P
0 g
s
.53835 .34288 m .54819 .33049 L .56127 .63471 L p .157 0 .346 r
F P
0 g
s
.59696 .32197 m .61127 .33019 L .60117 .34259 L p .694 .677 .829 r
F P
0 g
s
.60117 .34259 m .58689 .33444 L .59696 .32197 L p .694 .677 .829 r
F P
0 g
s
.60802 .639 m .58689 .33444 L .60117 .34259 L p .838 .469 .355 r
F P
0 g
s
.60117 .34259 m .62519 .64785 L .60802 .639 L p .838 .469 .355 r
F P
0 g
s
.63751 .63439 m .62519 .64785 L .60117 .34259 L p .19 0 .37 r
F P
0 g
s
.60117 .34259 m .61127 .33019 L .63751 .63439 L p .19 0 .37 r
F P
0 g
s
.60802 .639 m .58689 .33444 L .60117 .34259 L p .838 .469 .355 r
F P
0 g
s
.60117 .34259 m .62519 .64785 L .60802 .639 L p .838 .469 .355 r
F P
0 g
s
.6399 .66205 m .62737 .67558 L .60117 .34259 L p .19 0 .37 r
F P
0 g
s
.60117 .34259 m .61127 .33019 L .6399 .66205 L p .19 0 .37 r
F P
0 g
s
.66023 .32167 m .67436 .3299 L .664 .3423 L p .694 .677 .829 r
F P
0 g
s
.664 .3423 m .64989 .33414 L .66023 .32167 L p .694 .677 .829 r
F P
0 g
s
.6782 .58579 m .64989 .33414 L .664 .3423 L p .839 .463 .341 r
F P
0 g
s
.664 .3423 m .69463 .59455 L .6782 .58579 L p .839 .463 .341 r
F P
0 g
s
.70693 .58124 m .69463 .59455 L .664 .3423 L p .22 .027 .392 r
F P
0 g
s
.664 .3423 m .67436 .3299 L .70693 .58124 L p .22 .027 .392 r
F P
0 g
s
.68885 .68053 m .64989 .33414 L .664 .3423 L p .839 .463 .341 r
F P
0 g
s
.664 .3423 m .70615 .68945 L .68885 .68053 L p .839 .463 .341 r
F P
0 g
s
.70693 .58124 m .69463 .59455 L .664 .3423 L p .22 .027 .392 r
F P
0 g
s
.664 .3423 m .67436 .3299 L .70693 .58124 L p .22 .027 .392 r
F P
0 g
s
.7235 .32138 m .73746 .3296 L .72684 .34201 L p .694 .677 .829 r
F P
0 g
s
.72684 .34201 m .71291 .33385 L .7235 .32138 L p .694 .677 .829 r
F P
0 g
s
.76459 .66604 m .71291 .33385 L .72684 .34201 L p .839 .457 .326 r
F P
0 g
s
.72684 .34201 m .78151 .67494 L .76459 .66604 L p .839 .457 .326 r
F P
0 g
s
.79483 .6614 m .78151 .67494 L .72684 .34201 L p .248 .056 .412 r
F P
0 g
s
.72684 .34201 m .73746 .3296 L .79483 .6614 L p .248 .056 .412 r
F P
0 g
s
.76904 .6946 m .71291 .33385 L .72684 .34201 L p .839 .457 .326 r
F P
0 g
s
.72684 .34201 m .78621 .70355 L .76904 .6946 L p .839 .457 .326 r
F P
0 g
s
.79977 .68994 m .78621 .70355 L .72684 .34201 L p .248 .056 .412 r
F P
0 g
s
.72684 .34201 m .73746 .3296 L .79977 .68994 L p .248 .056 .412 r
F P
0 g
s
.78679 .32108 m .80058 .32931 L .7897 .34171 L p .694 .677 .829 r
F P
0 g
s
.7897 .34171 m .77593 .33355 L .78679 .32108 L p .694 .677 .829 r
F P
0 g
s
.84763 .69428 m .77593 .33355 L .7897 .34171 L p .839 .45 .311 r
F P
0 g
s
.7897 .34171 m .86454 .70323 L .84763 .69428 L p .839 .45 .311 r
F P
0 g
s
.8785 .68962 m .86454 .70323 L .7897 .34171 L p .272 .082 .43 r
F P
0 g
s
.7897 .34171 m .80058 .32931 L .8785 .68962 L p .272 .082 .43 r
F P
0 g
s
.83918 .65177 m .77593 .33355 L .7897 .34171 L p .839 .45 .311 r
F P
0 g
s
.7897 .34171 m .85572 .66065 L .83918 .65177 L p .839 .45 .311 r
F P
0 g
s
.8785 .68962 m .86454 .70323 L .7897 .34171 L p .272 .082 .43 r
F P
0 g
s
.7897 .34171 m .80058 .32931 L .8785 .68962 L p .272 .082 .43 r
F P
0 g
s
.85009 .32078 m .86371 .32901 L .85257 .34142 L p .694 .677 .829 r
F P
0 g
s
.85257 .34142 m .83897 .33326 L .85009 .32078 L p .694 .677 .829 r
F P
0 g
s
.92623 .69396 m .83897 .33326 L .85257 .34142 L p .839 .442 .294 r
F P
0 g
s
.85257 .34142 m .94288 .70291 L .92623 .69396 L p .839 .442 .294 r
F P
0 g
s
.95725 .6893 m .94288 .70291 L .85257 .34142 L p .295 .107 .446 r
F P
0 g
s
.85257 .34142 m .86371 .32901 L .95725 .6893 L p .295 .107 .446 r
F P
0 g
s
.92623 .69396 m .83897 .33326 L .85257 .34142 L p .839 .442 .294 r
F P
0 g
s
.85257 .34142 m .94288 .70291 L .92623 .69396 L p .839 .442 .294 r
F P
0 g
s
.146 .5665 m .13647 .57979 L .18539 .34043 L p 0 0 .14 r
F P
0 g
s
.18539 .34043 m .19378 .32801 L .146 .5665 L p 0 0 .14 r
F P
0 g
s
.24159 .31948 m .25688 .32772 L .24823 .34013 L p .694 .677 .829 r
F P
0 g
s
.24823 .34013 m .23298 .33196 L .24159 .31948 L p .694 .677 .829 r
F P
0 g
s
.19168 .57073 m .23298 .33196 L .24823 .34013 L p .831 .494 .417 r
F P
0 g
s
.24823 .34013 m .20955 .57948 L .19168 .57073 L p .831 .494 .417 r
F P
0 g
s
.21943 .56618 m .20955 .57948 L .24823 .34013 L p 0 0 .186 r
F P
0 g
s
.24823 .34013 m .25688 .32772 L .21943 .56618 L p 0 0 .186 r
F P
0 g
s
.18948 .58346 m .23298 .33196 L .24823 .34013 L p .831 .494 .417 r
F P
0 g
s
.24823 .34013 m .20749 .59223 L .18948 .58346 L p .831 .494 .417 r
F P
0 g
s
.21743 .57889 m .20749 .59223 L .24823 .34013 L p 0 0 .186 r
F P
0 g
s
.24823 .34013 m .25688 .32772 L .21743 .57889 L p 0 0 .186 r
F P
0 g
s
.30487 .31918 m .31999 .32742 L .31107 .33984 L p .694 .677 .829 r
F P
0 g
s
.31107 .33984 m .296 .33167 L .30487 .31918 L p .694 .677 .829 r
F P
0 g
s
.26335 .58314 m .296 .33167 L .31107 .33984 L p .833 .49 .407 r
F P
0 g
s
.31107 .33984 m .28112 .59191 L .26335 .58314 L p .833 .49 .407 r
F P
0 g
s
.30016 .58786 m .28264 .57917 L .29287 .56586 L p .687 .699 .856 r
F P
0 g
s
.29143 .57857 m .28112 .59191 L .31107 .33984 L p .004 0 .228 r
F P
0 g
s
.31107 .33984 m .31999 .32742 L .29143 .57857 L p .004 0 .228 r
F P
0 g
s
.26335 .58314 m .296 .33167 L .31107 .33984 L p .833 .49 .407 r
F P
0 g
s
.31107 .33984 m .28112 .59191 L .26335 .58314 L p .833 .49 .407 r
F P
0 g
s
.29287 .56586 m .28264 .57917 L .31107 .33984 L p .004 0 .228 r
F P
0 g
s
.31107 .33984 m .31999 .32742 L .29287 .56586 L p .004 0 .228 r
F P
0 g
s
.36816 .31888 m .38311 .32712 L .37393 .33955 L p .694 .677 .829 r
F P
0 g
s
.37393 .33955 m .35903 .33137 L .36816 .31888 L p .694 .677 .829 r
F P
0 g
s
.33612 .59573 m .35903 .33137 L .37393 .33955 L p .834 .486 .397 r
F P
0 g
s
.37393 .33955 m .35379 .60453 L .33612 .59573 L p .834 .486 .397 r
F P
0 g
s
.36453 .59115 m .35379 .60453 L .37393 .33955 L p .051 0 .265 r
F P
0 g
s
.37393 .33955 m .38311 .32712 L .36453 .59115 L p .051 0 .265 r
F P
0 g
s
.33499 .60884 m .35903 .33137 L .37393 .33955 L p .834 .486 .397 r
F P
0 g
s
.37393 .33955 m .35279 .61767 L .33499 .60884 L p .834 .486 .397 r
F P
0 g
s
.36361 .60425 m .35279 .61767 L .37393 .33955 L p .051 0 .265 r
F P
0 g
s
.37393 .33955 m .38311 .32712 L .36361 .60425 L p .051 0 .265 r
F P
0 g
s
.43147 .31859 m .44624 .32683 L .43681 .33925 L p .694 .677 .829 r
F P
0 g
s
.43681 .33925 m .42207 .33108 L .43147 .31859 L p .694 .677 .829 r
F P
0 g
s
.41535 .48578 m .42207 .33108 L .43681 .33925 L p .835 .482 .386 r
F P
0 g
s
.43681 .33925 m .43166 .49435 L .41535 .48578 L p .835 .482 .386 r
F P
0 g
s
.44814 .4915 m .43204 .483 L .44238 .47001 L p .69 .69 .845 r
F P
0 g
s
.44207 .48132 m .43166 .49435 L .43681 .33925 L p .094 0 .298 r
F P
0 g
s
.43681 .33925 m .44624 .32683 L .44207 .48132 L p .094 0 .298 r
F P
0 g
s
.41535 .48578 m .42207 .33108 L .43681 .33925 L p .835 .482 .386 r
F P
0 g
s
.43681 .33925 m .43166 .49435 L .41535 .48578 L p .835 .482 .386 r
F P
0 g
s
.44238 .47001 m .43204 .483 L .43681 .33925 L p .094 0 .298 r
F P
0 g
s
.43681 .33925 m .44624 .32683 L .44238 .47001 L p .094 0 .298 r
F P
0 g
s
.49478 .31829 m .50938 .32653 L .49969 .33896 L p .694 .677 .829 r
F P
0 g
s
.49969 .33896 m .48512 .33078 L .49478 .31829 L p .694 .677 .829 r
F P
0 g
s
.48509 .47414 m .48512 .33078 L .49969 .33896 L p .836 .477 .374 r
F P
0 g
s
.49969 .33896 m .50108 .48269 L .48509 .47414 L p .836 .477 .374 r
F P
0 g
s
.51174 .4697 m .50108 .48269 L .49969 .33896 L p .133 0 .328 r
F P
0 g
s
.49969 .33896 m .50938 .32653 L .51174 .4697 L p .133 0 .328 r
F P
0 g
s
.48509 .48547 m .48512 .33078 L .49969 .33896 L p .836 .477 .374 r
F P
0 g
s
.49969 .33896 m .50119 .49404 L .48509 .48547 L p .836 .477 .374 r
F P
0 g
s
.51192 .48101 m .50119 .49404 L .49969 .33896 L p .133 0 .328 r
F P
0 g
s
.49969 .33896 m .50938 .32653 L .51192 .48101 L p .133 0 .328 r
F P
0 g
s
.55811 .31799 m .57254 .32624 L .56259 .33867 L p .694 .677 .829 r
F P
0 g
s
.56259 .33867 m .54819 .33049 L .55811 .31799 L p .694 .677 .829 r
F P
0 g
s
.56127 .63471 m .54819 .33049 L .56259 .33867 L p .837 .472 .362 r
F P
0 g
s
.56259 .33867 m .57862 .64359 L .56127 .63471 L p .837 .472 .362 r
F P
0 g
s
.59502 .63885 m .57791 .63005 L .58993 .61659 L p .685 .704 .862 r
F P
0 g
s
.59074 .63009 m .57862 .64359 L .56259 .33867 L p .169 0 .354 r
F P
0 g
s
.56259 .33867 m .57254 .32624 L .59074 .63009 L p .169 0 .354 r
F P
0 g
s
.56127 .63471 m .54819 .33049 L .56259 .33867 L p .837 .472 .362 r
F P
0 g
s
.56259 .33867 m .57862 .64359 L .56127 .63471 L p .837 .472 .362 r
F P
0 g
s
.58993 .61659 m .57791 .63005 L .56259 .33867 L p .169 0 .354 r
F P
0 g
s
.56259 .33867 m .57254 .32624 L .58993 .61659 L p .169 0 .354 r
F P
0 g
s
.62145 .31769 m .63571 .32594 L .6255 .33837 L p .694 .677 .829 r
F P
0 g
s
.6255 .33837 m .61127 .33019 L .62145 .31769 L p .694 .677 .829 r
F P
0 g
s
.6387 .64811 m .61127 .33019 L .6255 .33837 L p .838 .466 .348 r
F P
0 g
s
.6255 .33837 m .65593 .65702 L .6387 .64811 L p .838 .466 .348 r
F P
0 g
s
.66853 .64348 m .65593 .65702 L .6255 .33837 L p .201 .006 .378 r
F P
0 g
s
.6255 .33837 m .63571 .32594 L .66853 .64348 L p .201 .006 .378 r
F P
0 g
s
.6399 .66205 m .61127 .33019 L .6255 .33837 L p .838 .466 .348 r
F P
0 g
s
.6255 .33837 m .65726 .67098 L .6399 .66205 L p .838 .466 .348 r
F P
0 g
s
.66997 .6574 m .65726 .67098 L .6255 .33837 L p .201 .006 .378 r
F P
0 g
s
.6255 .33837 m .63571 .32594 L .66997 .6574 L p .201 .006 .378 r
F P
0 g
s
.68481 .3174 m .6989 .32564 L .68842 .33808 L p .694 .677 .829 r
F P
0 g
s
.68842 .33808 m .67436 .3299 L .68481 .3174 L p .694 .677 .829 r
F P
0 g
s
.70693 .58124 m .67436 .3299 L .68842 .33808 L p .839 .46 .334 r
F P
0 g
s
.68842 .33808 m .7233 .59002 L .70693 .58124 L p .839 .46 .334 r
F P
0 g
s
.73575 .57666 m .7233 .59002 L .68842 .33808 L p .23 .037 .399 r
F P
0 g
s
.68842 .33808 m .6989 .32564 L .73575 .57666 L p .23 .037 .399 r
F P
0 g
s
.70693 .58124 m .67436 .3299 L .68842 .33808 L p .839 .46 .334 r
F P
0 g
s
.68842 .33808 m .7233 .59002 L .70693 .58124 L p .839 .46 .334 r
F P
0 g
s
.74964 .67122 m .73642 .68484 L .68842 .33808 L p .23 .037 .399 r
F P
0 g
s
.68842 .33808 m .6989 .32564 L .74964 .67122 L p .23 .037 .399 r
F P
0 g
s
.74818 .3171 m .76209 .32535 L .75135 .33778 L p .694 .677 .829 r
F P
0 g
s
.75135 .33778 m .73746 .3296 L .74818 .3171 L p .694 .677 .829 r
F P
0 g
s
.79728 .67556 m .73746 .3296 L .75135 .33778 L p .839 .453 .319 r
F P
0 g
s
.75135 .33778 m .81425 .68452 L .79728 .67556 L p .839 .453 .319 r
F P
0 g
s
.82787 .6709 m .81425 .68452 L .75135 .33778 L p .256 .065 .418 r
F P
0 g
s
.75135 .33778 m .76209 .32535 L .82787 .6709 L p .256 .065 .418 r
F P
0 g
s
.79977 .68994 m .73746 .3296 L .75135 .33778 L p .839 .453 .319 r
F P
0 g
s
.75135 .33778 m .81687 .69892 L .79977 .68994 L p .839 .453 .319 r
F P
0 g
s
.8306 .68527 m .81687 .69892 L .75135 .33778 L p .256 .065 .418 r
F P
0 g
s
.75135 .33778 m .76209 .32535 L .8306 .68527 L p .256 .065 .418 r
F P
0 g
s
.81155 .3168 m .8253 .32505 L .8143 .33749 L p .694 .677 .829 r
F P
0 g
s
.8143 .33749 m .80058 .32931 L .81155 .3168 L p .694 .677 .829 r
F P
0 g
s
.8785 .68962 m .80058 .32931 L .8143 .33749 L p .84 .446 .302 r
F P
0 g
s
.8143 .33749 m .89533 .6986 L .8785 .68962 L p .84 .446 .302 r
F P
0 g
s
.90611 .67057 m .92275 .67956 L .9087 .69309 L p .682 .709 .868 r
F P
0 g
s
.9087 .69309 m .8921 .6842 L .90611 .67057 L p .682 .709 .868 r
F P
0 g
s
.90947 .68494 m .89533 .6986 L .8143 .33749 L p .28 .091 .436 r
F P
0 g
s
.8143 .33749 m .8253 .32505 L .90947 .68494 L p .28 .091 .436 r
F P
0 g
s
.8785 .68962 m .80058 .32931 L .8143 .33749 L p .84 .446 .302 r
F P
0 g
s
.8143 .33749 m .89533 .6986 L .8785 .68962 L p .84 .446 .302 r
F P
0 g
s
.90611 .67057 m .8921 .6842 L .8143 .33749 L p .28 .091 .436 r
F P
0 g
s
.8143 .33749 m .8253 .32505 L .90611 .67057 L p .28 .091 .436 r
F P
0 g
s
.20224 .31549 m .21765 .32375 L .20915 .3362 L p .694 .677 .829 r
F P
0 g
s
.20915 .3362 m .19378 .32801 L .20224 .31549 L p .694 .677 .829 r
F P
0 g
s
.14851 .55397 m .19378 .32801 L .20915 .3362 L p .831 .496 .421 r
F P
0 g
s
.20915 .3362 m .1664 .56272 L .14851 .55397 L p .831 .496 .421 r
F P
0 g
s
.17602 .54942 m .1664 .56272 L .20915 .3362 L p 0 0 .156 r
F P
0 g
s
.20915 .3362 m .21765 .32375 L .17602 .54942 L p 0 0 .156 r
F P
0 g
s
.146 .5665 m .19378 .32801 L .20915 .3362 L p .831 .496 .421 r
F P
0 g
s
.20915 .3362 m .16403 .57527 L .146 .5665 L p .831 .496 .421 r
F P
0 g
s
.17602 .54942 m .1664 .56272 L .20915 .3362 L p 0 0 .156 r
F P
0 g
s
.20915 .3362 m .21765 .32375 L .17602 .54942 L p 0 0 .156 r
F P
0 g
s
.2656 .3152 m .28084 .32345 L .27208 .33591 L p .694 .677 .829 r
F P
0 g
s
.27208 .33591 m .25688 .32772 L .2656 .3152 L p .694 .677 .829 r
F P
0 g
s
.22524 .52916 m .25688 .32772 L .27208 .33591 L p .832 .492 .412 r
F P
0 g
s
.27208 .33591 m .24264 .53786 L .22524 .52916 L p .832 .492 .412 r
F P
0 g
s
.25247 .52463 m .24264 .53786 L .27208 .33591 L p 0 0 .2 r
F P
0 g
s
.27208 .33591 m .28084 .32345 L .25247 .52463 L p 0 0 .2 r
F P
0 g
s
.21743 .57889 m .25688 .32772 L .27208 .33591 L p .832 .492 .412 r
F P
0 g
s
.27208 .33591 m .23537 .58769 L .21743 .57889 L p .832 .492 .412 r
F P
0 g
s
.24547 .57431 m .23537 .58769 L .27208 .33591 L p 0 0 .2 r
F P
0 g
s
.27208 .33591 m .28084 .32345 L .24547 .57431 L p 0 0 .2 r
F P
0 g
s
.32897 .3149 m .34404 .32316 L .33502 .33561 L p .694 .677 .829 r
F P
0 g
s
.33502 .33561 m .31999 .32742 L .32897 .3149 L p .694 .677 .829 r
F P
0 g
s
.29287 .56586 m .31044 .57464 L .30016 .58786 L p .687 .699 .856 r
F P
0 g
s
.29143 .57857 m .31999 .32742 L .33502 .33561 L p .833 .488 .402 r
F P
0 g
s
.33502 .33561 m .30913 .58737 L .29143 .57857 L p .833 .488 .402 r
F P
0 g
s
.31959 .57399 m .30913 .58737 L .33502 .33561 L p .02 0 .24 r
F P
0 g
s
.33502 .33561 m .34404 .32316 L .31959 .57399 L p .02 0 .24 r
F P
0 g
s
.29287 .56586 m .31999 .32742 L .33502 .33561 L p .833 .488 .402 r
F P
0 g
s
.33502 .33561 m .31044 .57464 L .29287 .56586 L p .833 .488 .402 r
F P
0 g
s
.31959 .57399 m .30913 .58737 L .33502 .33561 L p .02 0 .24 r
F P
0 g
s
.33502 .33561 m .34404 .32316 L .31959 .57399 L p .02 0 .24 r
F P
0 g
s
.39235 .3146 m .40725 .32286 L .39797 .33532 L p .694 .677 .829 r
F P
0 g
s
.39797 .33532 m .38311 .32712 L .39235 .3146 L p .694 .677 .829 r
F P
0 g
s
.37224 .48163 m .38311 .32712 L .39797 .33532 L p .835 .484 .391 r
F P
0 g
s
.39797 .33532 m .3887 .49023 L .37224 .48163 L p .835 .484 .391 r
F P
0 g
s
.39893 .47715 m .3887 .49023 L .39797 .33532 L p .066 0 .276 r
F P
0 g
s
.39797 .33532 m .40725 .32286 L .39893 .47715 L p .066 0 .276 r
F P
0 g
s
.36361 .60425 m .38311 .32712 L .39797 .33532 L p .835 .484 .391 r
F P
0 g
s
.39797 .33532 m .38136 .6131 L .36361 .60425 L p .835 .484 .391 r
F P
0 g
s
.39893 .47715 m .3887 .49023 L .39797 .33532 L p .066 0 .276 r
F P
0 g
s
.39797 .33532 m .40725 .32286 L .39893 .47715 L p .066 0 .276 r
F P
0 g
s
.45575 .3143 m .47048 .32257 L .46093 .33502 L p .694 .677 .829 r
F P
0 g
s
.46093 .33502 m .44624 .32683 L .45575 .3143 L p .694 .677 .829 r
F P
0 g
s
.44268 .45885 m .44624 .32683 L .46093 .33502 L p .836 .479 .38 r
F P
0 g
s
.46093 .33502 m .45871 .4674 L .44268 .45885 L p .836 .479 .38 r
F P
0 g
s
.46911 .4544 m .45871 .4674 L .46093 .33502 L p .108 0 .308 r
F P
0 g
s
.46093 .33502 m .47048 .32257 L .46911 .4544 L p .108 0 .308 r
F P
0 g
s
.44238 .47001 m .44624 .32683 L .46093 .33502 L p .836 .479 .38 r
F P
0 g
s
.46093 .33502 m .45852 .47858 L .44238 .47001 L p .836 .479 .38 r
F P
0 g
s
.46911 .4544 m .45871 .4674 L .46093 .33502 L p .108 0 .308 r
F P
0 g
s
.46093 .33502 m .47048 .32257 L .46911 .4544 L p .108 0 .308 r
F P
0 g
s
.51916 .314 m .53371 .32227 L .52391 .33473 L p .694 .677 .829 r
F P
0 g
s
.52391 .33473 m .50938 .32653 L .51916 .314 L p .694 .677 .829 r
F P
0 g
s
.51192 .48101 m .50938 .32653 L .52391 .33473 L p .837 .474 .368 r
F P
0 g
s
.52391 .33473 m .52798 .48961 L .51192 .48101 L p .837 .474 .368 r
F P
0 g
s
.53885 .47653 m .52798 .48961 L .52391 .33473 L p .145 0 .337 r
F P
0 g
s
.52391 .33473 m .53371 .32227 L .53885 .47653 L p .145 0 .337 r
F P
0 g
s
.51192 .48101 m .50938 .32653 L .52391 .33473 L p .837 .474 .368 r
F P
0 g
s
.52391 .33473 m .52798 .48961 L .51192 .48101 L p .837 .474 .368 r
F P
0 g
s
.54381 .62577 m .53191 .63932 L .52391 .33473 L p .145 0 .337 r
F P
0 g
s
.52391 .33473 m .53371 .32227 L .54381 .62577 L p .145 0 .337 r
F P
0 g
s
.58258 .3137 m .59696 .32197 L .58689 .33444 L p .694 .677 .829 r
F P
0 g
s
.58689 .33444 m .57254 .32624 L .58258 .3137 L p .694 .677 .829 r
F P
0 g
s
.58993 .61659 m .60708 .62547 L .59502 .63885 L p .685 .704 .862 r
F P
0 g
s
.59074 .63009 m .57254 .32624 L .58689 .33444 L p .838 .469 .355 r
F P
0 g
s
.58689 .33444 m .60802 .639 L .59074 .63009 L p .838 .469 .355 r
F P
0 g
s
.6203 .62545 m .60802 .639 L .58689 .33444 L p .18 0 .362 r
F P
0 g
s
.58689 .33444 m .59696 .32197 L .6203 .62545 L p .18 0 .362 r
F P
0 g
s
.58993 .61659 m .57254 .32624 L .58689 .33444 L p .838 .469 .355 r
F P
0 g
s
.58689 .33444 m .60708 .62547 L .58993 .61659 L p .838 .469 .355 r
F P
0 g
s
.6203 .62545 m .60802 .639 L .58689 .33444 L p .18 0 .362 r
F P
0 g
s
.58689 .33444 m .59696 .32197 L .6203 .62545 L p .18 0 .362 r
F P
0 g
s
.64601 .31341 m .66023 .32167 L .64989 .33414 L p .694 .677 .829 r
F P
0 g
s
.64989 .33414 m .63571 .32594 L .64601 .31341 L p .694 .677 .829 r
F P
0 g
s
.66166 .57698 m .63571 .32594 L .64989 .33414 L p .839 .463 .341 r
F P
0 g
s
.64989 .33414 m .6782 .58579 L .66166 .57698 L p .839 .463 .341 r
F P
0 g
s
.69045 .57239 m .6782 .58579 L .64989 .33414 L p .211 .017 .385 r
F P
0 g
s
.64989 .33414 m .66023 .32167 L .69045 .57239 L p .211 .017 .385 r
F P
0 g
s
.66997 .6574 m .63571 .32594 L .64989 .33414 L p .839 .463 .341 r
F P
0 g
s
.64989 .33414 m .68726 .66636 L .66997 .6574 L p .839 .463 .341 r
F P
0 g
s
.69045 .57239 m .6782 .58579 L .64989 .33414 L p .211 .017 .385 r
F P
0 g
s
.64989 .33414 m .66023 .32167 L .69045 .57239 L p .211 .017 .385 r
F P
0 g
s
.70946 .31311 m .7235 .32138 L .71291 .33385 L p .694 .677 .829 r
F P
0 g
s
.71291 .33385 m .6989 .32564 L .70946 .31311 L p .694 .677 .829 r
F P
0 g
s
.74756 .65708 m .6989 .32564 L .71291 .33385 L p .839 .457 .326 r
F P
0 g
s
.71291 .33385 m .76459 .66604 L .74756 .65708 L p .839 .457 .326 r
F P
0 g
s
.77787 .65241 m .76459 .66604 L .71291 .33385 L p .239 .047 .406 r
F P
0 g
s
.71291 .33385 m .7235 .32138 L .77787 .65241 L p .239 .047 .406 r
F P
0 g
s
.74964 .67122 m .6989 .32564 L .71291 .33385 L p .839 .457 .326 r
F P
0 g
s
.71291 .33385 m .7668 .68021 L .74964 .67122 L p .839 .457 .326 r
F P
0 g
s
.77787 .65241 m .76459 .66604 L .71291 .33385 L p .239 .047 .406 r
F P
0 g
s
.71291 .33385 m .7235 .32138 L .77787 .65241 L p .239 .047 .406 r
F P
0 g
s
.77292 .31281 m .78679 .32108 L .77593 .33355 L p .694 .677 .829 r
F P
0 g
s
.77593 .33355 m .76209 .32535 L .77292 .31281 L p .694 .677 .829 r
F P
0 g
s
.81991 .62912 m .76209 .32535 L .77593 .33355 L p .839 .45 .311 r
F P
0 g
s
.77593 .33355 m .83645 .63804 L .81991 .62912 L p .839 .45 .311 r
F P
0 g
s
.84988 .62448 m .83645 .63804 L .77593 .33355 L p .264 .074 .424 r
F P
0 g
s
.77593 .33355 m .78679 .32108 L .84988 .62448 L p .264 .074 .424 r
F P
0 g
s
.8306 .68527 m .76209 .32535 L .77593 .33355 L p .839 .45 .311 r
F P
0 g
s
.77593 .33355 m .84763 .69428 L .8306 .68527 L p .839 .45 .311 r
F P
0 g
s
.86155 .68058 m .84763 .69428 L .77593 .33355 L p .264 .074 .424 r
F P
0 g
s
.77593 .33355 m .78679 .32108 L .86155 .68058 L p .264 .074 .424 r
F P
0 g
s
.83639 .31251 m .85009 .32078 L .83897 .33326 L p .694 .677 .829 r
F P
0 g
s
.83897 .33326 m .8253 .32505 L .83639 .31251 L p .694 .677 .829 r
F P
0 g
s
.90947 .68494 m .8253 .32505 L .83897 .33326 L p .839 .442 .294 r
F P
0 g
s
.83897 .33326 m .92623 .69396 L .90947 .68494 L p .839 .442 .294 r
F P
0 g
s
.94056 .68025 m .92623 .69396 L .83897 .33326 L p .288 .099 .441 r
F P
0 g
s
.83897 .33326 m .85009 .32078 L .94056 .68025 L p .288 .099 .441 r
F P
0 g
s
.90611 .67057 m .8253 .32505 L .83897 .33326 L p .839 .442 .294 r
F P
0 g
s
.83897 .33326 m .92275 .67956 L .90611 .67057 L p .839 .442 .294 r
F P
0 g
s
.94056 .68025 m .92623 .69396 L .83897 .33326 L p .288 .099 .441 r
F P
0 g
s
.83897 .33326 m .85009 .32078 L .94056 .68025 L p .288 .099 .441 r
F P
0 g
s
.22622 .3112 m .24159 .31948 L .23298 .33196 L p .694 .677 .829 r
F P
0 g
s
.23298 .33196 m .21765 .32375 L .22622 .3112 L p .694 .677 .829 r
F P
0 g
s
.17602 .54942 m .21765 .32375 L .23298 .33196 L p .831 .494 .417 r
F P
0 g
s
.23298 .33196 m .19385 .5582 L .17602 .54942 L p .831 .494 .417 r
F P
0 g
s
.20362 .54485 m .19385 .5582 L .23298 .33196 L p 0 0 .171 r
F P
0 g
s
.23298 .33196 m .24159 .31948 L .20362 .54485 L p 0 0 .171 r
F P
0 g
s
.17602 .54942 m .21765 .32375 L .23298 .33196 L p .831 .494 .417 r
F P
0 g
s
.23298 .33196 m .19385 .5582 L .17602 .54942 L p .831 .494 .417 r
F P
0 g
s
.20151 .55735 m .19168 .57073 L .23298 .33196 L p 0 0 .171 r
F P
0 g
s
.23298 .33196 m .24159 .31948 L .20151 .55735 L p 0 0 .171 r
F P
0 g
s
.28967 .3109 m .30487 .31918 L .296 .33167 L p .694 .677 .829 r
F P
0 g
s
.296 .33167 m .28084 .32345 L .28967 .3109 L p .694 .677 .829 r
F P
0 g
s
.24726 .56161 m .28084 .32345 L .296 .33167 L p .833 .49 .407 r
F P
0 g
s
.296 .33167 m .265 .57042 L .24726 .56161 L p .833 .49 .407 r
F P
0 g
s
.27519 .55703 m .265 .57042 L .296 .33167 L p 0 0 .214 r
F P
0 g
s
.296 .33167 m .30487 .31918 L .27519 .55703 L p 0 0 .214 r
F P
0 g
s
.24547 .57431 m .28084 .32345 L .296 .33167 L p .833 .49 .407 r
F P
0 g
s
.296 .33167 m .26335 .58314 L .24547 .57431 L p .833 .49 .407 r
F P
0 g
s
.2736 .56971 m .26335 .58314 L .296 .33167 L p 0 0 .214 r
F P
0 g
s
.296 .33167 m .30487 .31918 L .2736 .56971 L p 0 0 .214 r
F P
0 g
s
.35314 .3106 m .36816 .31888 L .35903 .33137 L p .694 .677 .829 r
F P
0 g
s
.35903 .33137 m .34404 .32316 L .35314 .3106 L p .694 .677 .829 r
F P
0 g
s
.31959 .57399 m .34404 .32316 L .35903 .33137 L p .834 .486 .397 r
F P
0 g
s
.35903 .33137 m .33724 .58282 L .31959 .57399 L p .834 .486 .397 r
F P
0 g
s
.34785 .56939 m .33724 .58282 L .35903 .33137 L p .036 0 .253 r
F P
0 g
s
.35903 .33137 m .36816 .31888 L .34785 .56939 L p .036 0 .253 r
F P
0 g
s
.31959 .57399 m .34404 .32316 L .35903 .33137 L p .834 .486 .397 r
F P
0 g
s
.35903 .33137 m .33724 .58282 L .31959 .57399 L p .834 .486 .397 r
F P
0 g
s
.34681 .58227 m .33612 .59573 L .35903 .33137 L p .036 0 .253 r
F P
0 g
s
.35903 .33137 m .36816 .31888 L .34681 .58227 L p .036 0 .253 r
F P
0 g
s
.41661 .3103 m .43147 .31859 L .42207 .33108 L p .694 .677 .829 r
F P
0 g
s
.42207 .33108 m .40725 .32286 L .41661 .3103 L p .694 .677 .829 r
F P
0 g
s
.39954 .46585 m .40725 .32286 L .42207 .33108 L p .835 .482 .386 r
F P
0 g
s
.42207 .33108 m .41584 .47445 L .39954 .46585 L p .835 .482 .386 r
F P
0 g
s
.42614 .46138 m .41584 .47445 L .42207 .33108 L p .08 0 .287 r
F P
0 g
s
.42207 .33108 m .43147 .31859 L .42614 .46138 L p .08 0 .287 r
F P
0 g
s
.39893 .47715 m .40725 .32286 L .42207 .33108 L p .835 .482 .386 r
F P
0 g
s
.42207 .33108 m .41535 .48578 L .39893 .47715 L p .835 .482 .386 r
F P
0 g
s
.42571 .47267 m .41535 .48578 L .42207 .33108 L p .08 0 .287 r
F P
0 g
s
.42207 .33108 m .43147 .31859 L .42571 .47267 L p .08 0 .287 r
F P
0 g
s
.4801 .31 m .49478 .31829 L .48512 .33078 L p .694 .677 .829 r
F P
0 g
s
.48512 .33078 m .47048 .32257 L .4801 .31 L p .694 .677 .829 r
F P
0 g
s
.46911 .4544 m .47048 .32257 L .48512 .33078 L p .836 .477 .374 r
F P
0 g
s
.48512 .33078 m .48509 .46298 L .46911 .4544 L p .836 .477 .374 r
F P
0 g
s
.49563 .44994 m .48509 .46298 L .48512 .33078 L p .121 0 .318 r
F P
0 g
s
.48512 .33078 m .49478 .31829 L .49563 .44994 L p .121 0 .318 r
F P
0 g
s
.46911 .4544 m .47048 .32257 L .48512 .33078 L p .836 .477 .374 r
F P
0 g
s
.48512 .33078 m .48509 .46298 L .46911 .4544 L p .836 .477 .374 r
F P
0 g
s
.4957 .46107 m .48509 .47414 L .48512 .33078 L p .121 0 .318 r
F P
0 g
s
.48512 .33078 m .49478 .31829 L .4957 .46107 L p .121 0 .318 r
F P
0 g
s
.5436 .3097 m .55811 .31799 L .54819 .33049 L p .694 .677 .829 r
F P
0 g
s
.54819 .33049 m .53371 .32227 L .5436 .3097 L p .694 .677 .829 r
F P
0 g
s
.54336 .61228 m .53371 .32227 L .54819 .33049 L p .837 .472 .362 r
F P
0 g
s
.54819 .33049 m .56069 .6212 L .54336 .61228 L p .837 .472 .362 r
F P
0 g
s
.57267 .60764 m .56069 .6212 L .54819 .33049 L p .157 0 .346 r
F P
0 g
s
.54819 .33049 m .55811 .31799 L .57267 .60764 L p .157 0 .346 r
F P
0 g
s
.54381 .62577 m .53371 .32227 L .54819 .33049 L p .837 .472 .362 r
F P
0 g
s
.54819 .33049 m .56127 .63471 L .54381 .62577 L p .837 .472 .362 r
F P
0 g
s
.57334 .62112 m .56127 .63471 L .54819 .33049 L p .157 0 .346 r
F P
0 g
s
.54819 .33049 m .55811 .31799 L .57334 .62112 L p .157 0 .346 r
F P
0 g
s
.60712 .3094 m .62145 .31769 L .61127 .33019 L p .694 .677 .829 r
F P
0 g
s
.61127 .33019 m .59696 .32197 L .60712 .3094 L p .694 .677 .829 r
F P
0 g
s
.6203 .62545 m .59696 .32197 L .61127 .33019 L p .838 .466 .348 r
F P
0 g
s
.61127 .33019 m .63751 .63439 L .6203 .62545 L p .838 .466 .348 r
F P
0 g
s
.64997 .62079 m .63751 .63439 L .61127 .33019 L p .19 0 .37 r
F P
0 g
s
.61127 .33019 m .62145 .31769 L .64997 .62079 L p .19 0 .37 r
F P
0 g
s
.6203 .62545 m .59696 .32197 L .61127 .33019 L p .838 .466 .348 r
F P
0 g
s
.61127 .33019 m .63751 .63439 L .6203 .62545 L p .838 .466 .348 r
F P
0 g
s
.65125 .63448 m .6387 .64811 L .61127 .33019 L p .19 0 .37 r
F P
0 g
s
.61127 .33019 m .62145 .31769 L .65125 .63448 L p .19 0 .37 r
F P
0 g
s
.67064 .3091 m .68481 .3174 L .67436 .3299 L p .694 .677 .829 r
F P
0 g
s
.67436 .3299 m .66023 .32167 L .67064 .3091 L p .694 .677 .829 r
F P
0 g
s
.68892 .5597 m .66023 .32167 L .67436 .3299 L p .839 .46 .334 r
F P
0 g
s
.67436 .3299 m .70528 .56852 L .68892 .5597 L p .839 .46 .334 r
F P
0 g
s
.7176 .55511 m .70528 .56852 L .67436 .3299 L p .22 .027 .392 r
F P
0 g
s
.67436 .3299 m .68481 .3174 L .7176 .55511 L p .22 .027 .392 r
F P
0 g
s
.69045 .57239 m .66023 .32167 L .67436 .3299 L p .839 .46 .334 r
F P
0 g
s
.67436 .3299 m .70693 .58124 L .69045 .57239 L p .839 .46 .334 r
F P
0 g
s
.71934 .56779 m .70693 .58124 L .67436 .3299 L p .22 .027 .392 r
F P
0 g
s
.67436 .3299 m .68481 .3174 L .71934 .56779 L p .22 .027 .392 r
F P
0 g
s
.73418 .30881 m .74818 .3171 L .73746 .3296 L p .694 .677 .829 r
F P
0 g
s
.73746 .3296 m .7235 .32138 L .73418 .30881 L p .694 .677 .829 r
F P
0 g
s
.77787 .65241 m .7235 .32138 L .73746 .3296 L p .839 .453 .319 r
F P
0 g
s
.73746 .3296 m .79483 .6614 L .77787 .65241 L p .839 .453 .319 r
F P
0 g
s
.80829 .64773 m .79483 .6614 L .73746 .3296 L p .248 .056 .412 r
F P
0 g
s
.73746 .3296 m .74818 .3171 L .80829 .64773 L p .248 .056 .412 r
F P
0 g
s
.77787 .65241 m .7235 .32138 L .73746 .3296 L p .839 .453 .319 r
F P
0 g
s
.73746 .3296 m .79483 .6614 L .77787 .65241 L p .839 .453 .319 r
F P
0 g
s
.81085 .66185 m .79728 .67556 L .73746 .3296 L p .248 .056 .412 r
F P
0 g
s
.73746 .3296 m .74818 .3171 L .81085 .66185 L p .248 .056 .412 r
F P
0 g
s
.79773 .30851 m .81155 .3168 L .80058 .32931 L p .694 .677 .829 r
F P
0 g
s
.80058 .32931 m .78679 .32108 L .79773 .30851 L p .694 .677 .829 r
F P
0 g
s
.85856 .66622 m .78679 .32108 L .80058 .32931 L p .84 .446 .302 r
F P
0 g
s
.80058 .32931 m .87539 .67524 L .85856 .66622 L p .84 .446 .302 r
F P
0 g
s
.88936 .66152 m .87539 .67524 L .80058 .32931 L p .272 .082 .43 r
F P
0 g
s
.80058 .32931 m .81155 .3168 L .88936 .66152 L p .272 .082 .43 r
F P
0 g
s
.86155 .68058 m .78679 .32108 L .80058 .32931 L p .84 .446 .302 r
F P
0 g
s
.80058 .32931 m .8785 .68962 L .86155 .68058 L p .84 .446 .302 r
F P
0 g
s
.8926 .67587 m .8785 .68962 L .80058 .32931 L p .272 .082 .43 r
F P
0 g
s
.80058 .32931 m .81155 .3168 L .8926 .67587 L p .272 .082 .43 r
F P
0 g
s
.8613 .30821 m .87495 .3165 L .86371 .32901 L p .694 .677 .829 r
F P
0 g
s
.86371 .32901 m .85009 .32078 L .8613 .30821 L p .694 .677 .829 r
F P
0 g
s
.94056 .68025 m .85009 .32078 L .86371 .32901 L p .839 .438 .285 r
F P
0 g
s
.86371 .32901 m .95725 .6893 L .94056 .68025 L p .839 .438 .285 r
F P
0 g
s
.97176 .67554 m .95725 .6893 L .86371 .32901 L p .295 .107 .446 r
F P
0 g
s
.86371 .32901 m .87495 .3165 L .97176 .67554 L p .295 .107 .446 r
F P
0 g
s
.94056 .68025 m .85009 .32078 L .86371 .32901 L p .839 .438 .285 r
F P
0 g
s
.86371 .32901 m .95725 .6893 L .94056 .68025 L p .839 .438 .285 r
F P
0 g
s
.15807 .54059 m .14851 .55397 L .19378 .32801 L p 0 0 .14 r
F P
0 g
s
.19378 .32801 m .20224 .31549 L .15807 .54059 L p 0 0 .14 r
F P
0 g
s
.25027 .30689 m .2656 .3152 L .25688 .32772 L p .694 .677 .829 r
F P
0 g
s
.25688 .32772 m .24159 .31948 L .25027 .30689 L p .694 .677 .829 r
F P
0 g
s
.20774 .52041 m .24159 .31948 L .25688 .32772 L p .832 .492 .412 r
F P
0 g
s
.25688 .32772 m .22524 .52916 L .20774 .52041 L p .832 .492 .412 r
F P
0 g
s
.23503 .51585 m .22524 .52916 L .25688 .32772 L p 0 0 .186 r
F P
0 g
s
.25688 .32772 m .2656 .3152 L .23503 .51585 L p 0 0 .186 r
F P
0 g
s
.20151 .55735 m .24159 .31948 L .25688 .32772 L p .832 .492 .412 r
F P
0 g
s
.25688 .32772 m .21943 .56618 L .20151 .55735 L p .832 .492 .412 r
F P
0 g
s
.23503 .51585 m .22524 .52916 L .25688 .32772 L p 0 0 .186 r
F P
0 g
s
.25688 .32772 m .2656 .3152 L .23503 .51585 L p 0 0 .186 r
F P
0 g
s
.31382 .30659 m .32897 .3149 L .31999 .32742 L p .694 .677 .829 r
F P
0 g
s
.31999 .32742 m .30487 .31918 L .31382 .30659 L p .694 .677 .829 r
F P
0 g
s
.27675 .54453 m .30487 .31918 L .31999 .32742 L p .833 .488 .402 r
F P
0 g
s
.31999 .32742 m .2943 .55334 L .27675 .54453 L p .833 .488 .402 r
F P
0 g
s
.30456 .53995 m .2943 .55334 L .31999 .32742 L p .004 0 .228 r
F P
0 g
s
.31999 .32742 m .32897 .3149 L .30456 .53995 L p .004 0 .228 r
F P
0 g
s
.2736 .56971 m .30487 .31918 L .31999 .32742 L p .833 .488 .402 r
F P
0 g
s
.31999 .32742 m .29143 .57857 L .2736 .56971 L p .833 .488 .402 r
F P
0 g
s
.30183 .5651 m .29143 .57857 L .31999 .32742 L p .004 0 .228 r
F P
0 g
s
.31999 .32742 m .32897 .3149 L .30183 .5651 L p .004 0 .228 r
F P
0 g
s
.37737 .30629 m .39235 .3146 L .38311 .32712 L p .694 .677 .829 r
F P
0 g
s
.38311 .32712 m .36816 .31888 L .37737 .30629 L p .694 .677 .829 r
F P
0 g
s
.35567 .47298 m .36816 .31888 L .38311 .32712 L p .835 .484 .391 r
F P
0 g
s
.38311 .32712 m .37224 .48163 L .35567 .47298 L p .835 .484 .391 r
F P
0 g
s
.38242 .46848 m .37224 .48163 L .38311 .32712 L p .051 0 .265 r
F P
0 g
s
.38311 .32712 m .39235 .3146 L .38242 .46848 L p .051 0 .265 r
F P
0 g
s
.34681 .58227 m .36816 .31888 L .38311 .32712 L p .835 .484 .391 r
F P
0 g
s
.38311 .32712 m .36453 .59115 L .34681 .58227 L p .835 .484 .391 r
F P
0 g
s
.38242 .46848 m .37224 .48163 L .38311 .32712 L p .051 0 .265 r
F P
0 g
s
.38311 .32712 m .39235 .3146 L .38242 .46848 L p .051 0 .265 r
F P
0 g
s
.44094 .30599 m .45575 .3143 L .44624 .32683 L p .694 .677 .829 r
F P
0 g
s
.44624 .32683 m .43147 .31859 L .44094 .30599 L p .694 .677 .829 r
F P
0 g
s
.42571 .47267 m .43147 .31859 L .44624 .32683 L p .836 .479 .38 r
F P
0 g
s
.44624 .32683 m .44207 .48132 L .42571 .47267 L p .836 .479 .38 r
F P
0 g
s
.45871 .4674 m .44268 .45885 L .45304 .44578 L p .69 .689 .844 r
F P
0 g
s
.44238 .47001 m .45852 .47858 L .44814 .4915 L p .69 .69 .845 r
F P
0 g
s
.45258 .46816 m .44207 .48132 L .44624 .32683 L p .094 0 .298 r
F P
0 g
s
.44624 .32683 m .45575 .3143 L .45258 .46816 L p .094 0 .298 r
F P
0 g
s
.42571 .47267 m .43147 .31859 L .44624 .32683 L p .836 .479 .38 r
F P
0 g
s
.44624 .32683 m .44207 .48132 L .42571 .47267 L p .836 .479 .38 r
F P
0 g
s
.45304 .44578 m .44268 .45885 L .44624 .32683 L p .094 0 .298 r
F P
0 g
s
.44624 .32683 m .45575 .3143 L .45304 .44578 L p .094 0 .298 r
F P
0 g
s
.50452 .30569 m .51916 .314 L .50938 .32653 L p .694 .677 .829 r
F P
0 g
s
.50938 .32653 m .49478 .31829 L .50452 .30569 L p .694 .677 .829 r
F P
0 g
s
.4957 .46107 m .51174 .4697 L .50108 .48269 L p .69 .69 .845 r
F P
0 g
s
.50108 .48269 m .48509 .47414 L .4957 .46107 L p .69 .69 .845 r
F P
0 g
s
.49578 .47235 m .49478 .31829 L .50938 .32653 L p .837 .474 .368 r
F P
0 g
s
.50938 .32653 m .51192 .48101 L .49578 .47235 L p .837 .474 .368 r
F P
0 g
s
.52275 .46785 m .51192 .48101 L .50938 .32653 L p .133 0 .328 r
F P
0 g
s
.50938 .32653 m .51916 .314 L .52275 .46785 L p .133 0 .328 r
F P
0 g
s
.4957 .46107 m .49478 .31829 L .50938 .32653 L p .837 .474 .368 r
F P
0 g
s
.50938 .32653 m .51174 .4697 L .4957 .46107 L p .837 .474 .368 r
F P
0 g
s
.52275 .46785 m .51192 .48101 L .50938 .32653 L p .133 0 .328 r
F P
0 g
s
.50938 .32653 m .51916 .314 L .52275 .46785 L p .133 0 .328 r
F P
0 g
s
.56812 .30539 m .58258 .3137 L .57254 .32624 L p .694 .677 .829 r
F P
0 g
s
.57254 .32624 m .55811 .31799 L .56812 .30539 L p .694 .677 .829 r
F P
0 g
s
.572 .59437 m .55811 .31799 L .57254 .32624 L p .838 .469 .355 r
F P
0 g
s
.57254 .32624 m .58913 .60329 L .572 .59437 L p .838 .469 .355 r
F P
0 g
s
.60118 .58973 m .58913 .60329 L .57254 .32624 L p .169 0 .354 r
F P
0 g
s
.57254 .32624 m .58258 .3137 L .60118 .58973 L p .169 0 .354 r
F P
0 g
s
.57334 .62112 m .55811 .31799 L .57254 .32624 L p .838 .469 .355 r
F P
0 g
s
.57254 .32624 m .59074 .63009 L .57334 .62112 L p .838 .469 .355 r
F P
0 g
s
.60297 .61645 m .59074 .63009 L .57254 .32624 L p .169 0 .354 r
F P
0 g
s
.57254 .32624 m .58258 .3137 L .60297 .61645 L p .169 0 .354 r
F P
0 g
s
.63173 .30509 m .64601 .31341 L .63571 .32594 L p .694 .677 .829 r
F P
0 g
s
.63571 .32594 m .62145 .31769 L .63173 .30509 L p .694 .677 .829 r
F P
0 g
s
.64501 .56811 m .62145 .31769 L .63571 .32594 L p .839 .463 .341 r
F P
0 g
s
.63571 .32594 m .66166 .57698 L .64501 .56811 L p .839 .463 .341 r
F P
0 g
s
.67387 .5635 m .66166 .57698 L .63571 .32594 L p .201 .006 .378 r
F P
0 g
s
.63571 .32594 m .64601 .31341 L .67387 .5635 L p .201 .006 .378 r
F P
0 g
s
.65125 .63448 m .62145 .31769 L .63571 .32594 L p .839 .463 .341 r
F P
0 g
s
.63571 .32594 m .66853 .64348 L .65125 .63448 L p .839 .463 .341 r
F P
0 g
s
.67387 .5635 m .66166 .57698 L .63571 .32594 L p .201 .006 .378 r
F P
0 g
s
.63571 .32594 m .64601 .31341 L .67387 .5635 L p .201 .006 .378 r
F P
0 g
s
.69534 .30479 m .70946 .31311 L .6989 .32564 L p .694 .677 .829 r
F P
0 g
s
.6989 .32564 m .68481 .3174 L .69534 .30479 L p .694 .677 .829 r
F P
0 g
s
.71934 .56779 m .68481 .3174 L .6989 .32564 L p .839 .457 .326 r
F P
0 g
s
.6989 .32564 m .73575 .57666 L .71934 .56779 L p .839 .457 .326 r
F P
0 g
s
.74833 .56317 m .73575 .57666 L .6989 .32564 L p .23 .037 .399 r
F P
0 g
s
.6989 .32564 m .70946 .31311 L .74833 .56317 L p .23 .037 .399 r
F P
0 g
s
.71934 .56779 m .68481 .3174 L .6989 .32564 L p .839 .457 .326 r
F P
0 g
s
.6989 .32564 m .73575 .57666 L .71934 .56779 L p .839 .457 .326 r
F P
0 g
s
.7608 .64336 m .74756 .65708 L .6989 .32564 L p .23 .037 .399 r
F P
0 g
s
.6989 .32564 m .70946 .31311 L .7608 .64336 L p .23 .037 .399 r
F P
0 g
s
.75898 .30449 m .77292 .31281 L .76209 .32535 L p .694 .677 .829 r
F P
0 g
s
.76209 .32535 m .74818 .3171 L .75898 .30449 L p .694 .677 .829 r
F P
0 g
s
.80327 .62015 m .74818 .3171 L .76209 .32535 L p .839 .45 .311 r
F P
0 g
s
.76209 .32535 m .81991 .62912 L .80327 .62015 L p .839 .45 .311 r
F P
0 g
s
.83331 .61547 m .81991 .62912 L .76209 .32535 L p .256 .065 .418 r
F P
0 g
s
.76209 .32535 m .77292 .31281 L .83331 .61547 L p .256 .065 .418 r
F P
0 g
s
.81085 .66185 m .74818 .3171 L .76209 .32535 L p .839 .45 .311 r
F P
0 g
s
.76209 .32535 m .82787 .6709 L .81085 .66185 L p .839 .45 .311 r
F P
0 g
s
.83331 .61547 m .81991 .62912 L .76209 .32535 L p .256 .065 .418 r
F P
0 g
s
.76209 .32535 m .77292 .31281 L .83331 .61547 L p .256 .065 .418 r
F P
0 g
s
.82262 .30419 m .83639 .31251 L .8253 .32505 L p .694 .677 .829 r
F P
0 g
s
.8253 .32505 m .81155 .3168 L .82262 .30419 L p .694 .677 .829 r
F P
0 g
s
.88618 .6474 m .81155 .3168 L .8253 .32505 L p .839 .442 .294 r
F P
0 g
s
.8253 .32505 m .90281 .65643 L .88618 .6474 L p .839 .442 .294 r
F P
0 g
s
.91684 .64271 m .90281 .65643 L .8253 .32505 L p .28 .091 .436 r
F P
0 g
s
.8253 .32505 m .83639 .31251 L .91684 .64271 L p .28 .091 .436 r
F P
0 g
s
.8926 .67587 m .81155 .3168 L .8253 .32505 L p .839 .442 .294 r
F P
0 g
s
.8253 .32505 m .90947 .68494 L .8926 .67587 L p .839 .442 .294 r
F P
0 g
s
.92377 .67115 m .90947 .68494 L .8253 .32505 L p .28 .091 .436 r
F P
0 g
s
.8253 .32505 m .83639 .31251 L .92377 .67115 L p .28 .091 .436 r
F P
0 g
s
.21077 .30287 m .22622 .3112 L .21765 .32375 L p .694 .677 .829 r
F P
0 g
s
.21765 .32375 m .20224 .31549 L .21077 .30287 L p .694 .677 .829 r
F P
0 g
s
.16048 .52829 m .20224 .31549 L .21765 .32375 L p .831 .494 .417 r
F P
0 g
s
.21765 .32375 m .17829 .5371 L .16048 .52829 L p .831 .494 .417 r
F P
0 g
s
.18794 .52371 m .17829 .5371 L .21765 .32375 L p 0 0 .156 r
F P
0 g
s
.21765 .32375 m .22622 .3112 L .18794 .52371 L p 0 0 .156 r
F P
0 g
s
.15807 .54059 m .20224 .31549 L .21765 .32375 L p .831 .494 .417 r
F P
0 g
s
.21765 .32375 m .17602 .54942 L .15807 .54059 L p .831 .494 .417 r
F P
0 g
s
.18573 .53599 m .17602 .54942 L .21765 .32375 L p 0 0 .156 r
F P
0 g
s
.21765 .32375 m .22622 .3112 L .18573 .53599 L p 0 0 .156 r
F P
0 g
s
.27439 .30257 m .28967 .3109 L .28084 .32345 L p .694 .677 .829 r
F P
0 g
s
.28084 .32345 m .2656 .3152 L .27439 .30257 L p .694 .677 .829 r
F P
0 g
s
.23503 .51585 m .2656 .3152 L .28084 .32345 L p .833 .49 .407 r
F P
0 g
s
.28084 .32345 m .25247 .52463 L .23503 .51585 L p .833 .49 .407 r
F P
0 g
s
.26241 .51128 m .25247 .52463 L .28084 .32345 L p 0 0 .2 r
F P
0 g
s
.28084 .32345 m .28967 .3109 L .26241 .51128 L p 0 0 .2 r
F P
0 g
s
.23503 .51585 m .2656 .3152 L .28084 .32345 L p .833 .49 .407 r
F P
0 g
s
.28084 .32345 m .25247 .52463 L .23503 .51585 L p .833 .49 .407 r
F P
0 g
s
.25739 .54814 m .24726 .56161 L .28084 .32345 L p 0 0 .2 r
F P
0 g
s
.28084 .32345 m .28967 .3109 L .25739 .54814 L p 0 0 .2 r
F P
0 g
s
.33803 .30227 m .35314 .3106 L .34404 .32316 L p .694 .677 .829 r
F P
0 g
s
.34404 .32316 m .32897 .3149 L .33803 .30227 L p .694 .677 .829 r
F P
0 g
s
.3032 .55243 m .32897 .3149 L .34404 .32316 L p .834 .486 .397 r
F P
0 g
s
.34404 .32316 m .32083 .56129 L .3032 .55243 L p .834 .486 .397 r
F P
0 g
s
.33132 .54782 m .32083 .56129 L .34404 .32316 L p .02 0 .24 r
F P
0 g
s
.34404 .32316 m .35314 .3106 L .33132 .54782 L p .02 0 .24 r
F P
0 g
s
.30183 .5651 m .32897 .3149 L .34404 .32316 L p .834 .486 .397 r
F P
0 g
s
.34404 .32316 m .31959 .57399 L .30183 .5651 L p .834 .486 .397 r
F P
0 g
s
.33015 .56047 m .31959 .57399 L .34404 .32316 L p .02 0 .24 r
F P
0 g
s
.34404 .32316 m .35314 .3106 L .33015 .56047 L p .02 0 .24 r
F P
0 g
s
.40168 .30197 m .41661 .3103 L .40725 .32286 L p .694 .677 .829 r
F P
0 g
s
.40725 .32286 m .39235 .3146 L .40168 .30197 L p .694 .677 .829 r
F P
0 g
s
.38242 .46848 m .39235 .3146 L .40725 .32286 L p .835 .482 .386 r
F P
0 g
s
.40725 .32286 m .39893 .47715 L .38242 .46848 L p .835 .482 .386 r
F P
0 g
s
.41584 .47445 m .39954 .46585 L .4098 .4527 L p .69 .69 .845 r
F P
0 g
s
.40926 .46396 m .39893 .47715 L .40725 .32286 L p .066 0 .276 r
F P
0 g
s
.40725 .32286 m .41661 .3103 L .40926 .46396 L p .066 0 .276 r
F P
0 g
s
.38242 .46848 m .39235 .3146 L .40725 .32286 L p .835 .482 .386 r
F P
0 g
s
.40725 .32286 m .39893 .47715 L .38242 .46848 L p .835 .482 .386 r
F P
0 g
s
.4098 .4527 m .39954 .46585 L .40725 .32286 L p .066 0 .276 r
F P
0 g
s
.40725 .32286 m .41661 .3103 L .4098 .4527 L p .066 0 .276 r
F P
0 g
s
.46534 .30167 m .4801 .31 L .47048 .32257 L p .694 .677 .829 r
F P
0 g
s
.47048 .32257 m .45575 .3143 L .46534 .30167 L p .694 .677 .829 r
F P
0 g
s
.45327 .43482 m .45575 .3143 L .47048 .32257 L p .836 .477 .374 r
F P
0 g
s
.47048 .32257 m .46923 .44342 L .45327 .43482 L p .836 .477 .374 r
F P
0 g
s
.47965 .43035 m .46923 .44342 L .47048 .32257 L p .108 0 .308 r
F P
0 g
s
.47048 .32257 m .4801 .31 L .47965 .43035 L p .108 0 .308 r
F P
0 g
s
.45304 .44578 m .45575 .3143 L .47048 .32257 L p .836 .477 .374 r
F P
0 g
s
.47048 .32257 m .46911 .4544 L .45304 .44578 L p .836 .477 .374 r
F P
0 g
s
.47961 .44129 m .46911 .4544 L .47048 .32257 L p .108 0 .308 r
F P
0 g
s
.47048 .32257 m .4801 .31 L .47961 .44129 L p .108 0 .308 r
F P
0 g
s
.52902 .30137 m .5436 .3097 L .53371 .32227 L p .694 .677 .829 r
F P
0 g
s
.53371 .32227 m .51916 .314 L .52902 .30137 L p .694 .677 .829 r
F P
0 g
s
.52275 .46785 m .51916 .314 L .53371 .32227 L p .837 .472 .362 r
F P
0 g
s
.53371 .32227 m .53885 .47653 L .52275 .46785 L p .837 .472 .362 r
F P
0 g
s
.54982 .46333 m .53885 .47653 L .53371 .32227 L p .145 0 .337 r
F P
0 g
s
.53371 .32227 m .5436 .3097 L .54982 .46333 L p .145 0 .337 r
F P
0 g
s
.52275 .46785 m .51916 .314 L .53371 .32227 L p .837 .472 .362 r
F P
0 g
s
.53371 .32227 m .53885 .47653 L .52275 .46785 L p .837 .472 .362 r
F P
0 g
s
.55529 .59864 m .54336 .61228 L .53371 .32227 L p .145 0 .337 r
F P
0 g
s
.53371 .32227 m .5436 .3097 L .55529 .59864 L p .145 0 .337 r
F P
0 g
s
.5927 .30107 m .60712 .3094 L .59696 .32197 L p .694 .677 .829 r
F P
0 g
s
.59696 .32197 m .58258 .3137 L .5927 .30107 L p .694 .677 .829 r
F P
0 g
s
.60207 .60299 m .58258 .3137 L .59696 .32197 L p .838 .466 .348 r
F P
0 g
s
.59696 .32197 m .61926 .61196 L .60207 .60299 L p .838 .466 .348 r
F P
0 g
s
.63157 .59831 m .61926 .61196 L .59696 .32197 L p .18 0 .362 r
F P
0 g
s
.59696 .32197 m .60712 .3094 L .63157 .59831 L p .18 0 .362 r
F P
0 g
s
.60297 .61645 m .58258 .3137 L .59696 .32197 L p .838 .466 .348 r
F P
0 g
s
.59696 .32197 m .6203 .62545 L .60297 .61645 L p .838 .466 .348 r
F P
0 g
s
.63271 .61176 m .6203 .62545 L .59696 .32197 L p .18 0 .362 r
F P
0 g
s
.59696 .32197 m .60712 .3094 L .63271 .61176 L p .18 0 .362 r
F P
0 g
s
.6564 .30077 m .67064 .3091 L .66023 .32167 L p .694 .677 .829 r
F P
0 g
s
.66023 .32167 m .64601 .31341 L .6564 .30077 L p .694 .677 .829 r
F P
0 g
s
.67387 .5635 m .64601 .31341 L .66023 .32167 L p .839 .46 .334 r
F P
0 g
s
.66023 .32167 m .69045 .57239 L .67387 .5635 L p .839 .46 .334 r
F P
0 g
s
.70528 .56852 m .68892 .5597 L .7012 .54621 L p .687 .699 .856 r
F P
0 g
s
.70283 .55886 m .69045 .57239 L .66023 .32167 L p .211 .017 .385 r
F P
0 g
s
.66023 .32167 m .67064 .3091 L .70283 .55886 L p .211 .017 .385 r
F P
0 g
s
.67387 .5635 m .64601 .31341 L .66023 .32167 L p .839 .46 .334 r
F P
0 g
s
.66023 .32167 m .69045 .57239 L .67387 .5635 L p .839 .46 .334 r
F P
0 g
s
.7012 .54621 m .68892 .5597 L .66023 .32167 L p .211 .017 .385 r
F P
0 g
s
.66023 .32167 m .67064 .3091 L .7012 .54621 L p .211 .017 .385 r
F P
0 g
s
.72011 .30047 m .73418 .30881 L .7235 .32138 L p .694 .677 .829 r
F P
0 g
s
.7235 .32138 m .70946 .31311 L .72011 .30047 L p .694 .677 .829 r
F P
0 g
s
.75864 .62947 m .70946 .31311 L .7235 .32138 L p .839 .453 .319 r
F P
0 g
s
.7235 .32138 m .77559 .6385 L .75864 .62947 L p .839 .453 .319 r
F P
0 g
s
.78888 .62477 m .77559 .6385 L .7235 .32138 L p .239 .047 .406 r
F P
0 g
s
.7235 .32138 m .73418 .30881 L .78888 .62477 L p .239 .047 .406 r
F P
0 g
s
.7608 .64336 m .70946 .31311 L .7235 .32138 L p .839 .453 .319 r
F P
0 g
s
.7235 .32138 m .77787 .65241 L .7608 .64336 L p .839 .453 .319 r
F P
0 g
s
.79128 .63865 m .77787 .65241 L .7235 .32138 L p .239 .047 .406 r
F P
0 g
s
.7235 .32138 m .73418 .30881 L .79128 .63865 L p .239 .047 .406 r
F P
0 g
s
.78384 .30016 m .79773 .30851 L .78679 .32108 L p .694 .677 .829 r
F P
0 g
s
.78679 .32108 m .77292 .31281 L .78384 .30016 L p .694 .677 .829 r
F P
0 g
s
.83331 .61547 m .77292 .31281 L .78679 .32108 L p .84 .446 .302 r
F P
0 g
s
.78679 .32108 m .84988 .62448 L .83331 .61547 L p .84 .446 .302 r
F P
0 g
s
.86345 .61079 m .84988 .62448 L .78679 .32108 L p .264 .074 .424 r
F P
0 g
s
.78679 .32108 m .79773 .30851 L .86345 .61079 L p .264 .074 .424 r
F P
0 g
s
.83331 .61547 m .77292 .31281 L .78679 .32108 L p .84 .446 .302 r
F P
0 g
s
.78679 .32108 m .84988 .62448 L .83331 .61547 L p .84 .446 .302 r
F P
0 g
s
.8725 .65241 m .85856 .66622 L .78679 .32108 L p .264 .074 .424 r
F P
0 g
s
.78679 .32108 m .79773 .30851 L .8725 .65241 L p .264 .074 .424 r
F P
0 g
s
.84758 .29986 m .8613 .30821 L .85009 .32078 L p .694 .677 .829 r
F P
0 g
s
.85009 .32078 m .83639 .31251 L .84758 .29986 L p .694 .677 .829 r
F P
0 g
s
.92027 .65681 m .83639 .31251 L .85009 .32078 L p .839 .438 .285 r
F P
0 g
s
.85009 .32078 m .93695 .66589 L .92027 .65681 L p .839 .438 .285 r
F P
0 g
s
.95129 .65208 m .93695 .66589 L .85009 .32078 L p .288 .099 .441 r
F P
0 g
s
.85009 .32078 m .8613 .30821 L .95129 .65208 L p .288 .099 .441 r
F P
0 g
s
.92377 .67115 m .83639 .31251 L .85009 .32078 L p .839 .438 .285 r
F P
0 g
s
.85009 .32078 m .94056 .68025 L .92377 .67115 L p .839 .438 .285 r
F P
0 g
s
.95504 .66641 m .94056 .68025 L .85009 .32078 L p .288 .099 .441 r
F P
0 g
s
.85009 .32078 m .8613 .30821 L .95504 .66641 L p .288 .099 .441 r
F P
0 g
s
.23487 .29854 m .25027 .30689 L .24159 .31948 L p .694 .677 .829 r
F P
0 g
s
.24159 .31948 m .22622 .3112 L .23487 .29854 L p .694 .677 .829 r
F P
0 g
s
.19012 .5116 m .22622 .3112 L .24159 .31948 L p .832 .492 .412 r
F P
0 g
s
.24159 .31948 m .20774 .52041 L .19012 .5116 L p .832 .492 .412 r
F P
0 g
s
.21747 .50702 m .20774 .52041 L .24159 .31948 L p 0 0 .171 r
F P
0 g
s
.24159 .31948 m .25027 .30689 L .21747 .50702 L p 0 0 .171 r
F P
0 g
s
.18573 .53599 m .22622 .3112 L .24159 .31948 L p .832 .492 .412 r
F P
0 g
s
.24159 .31948 m .20362 .54485 L .18573 .53599 L p .832 .492 .412 r
F P
0 g
s
.21747 .50702 m .20774 .52041 L .24159 .31948 L p 0 0 .171 r
F P
0 g
s
.24159 .31948 m .25027 .30689 L .21747 .50702 L p 0 0 .171 r
F P
0 g
s
.29858 .29824 m .31382 .30659 L .30487 .31918 L p .694 .677 .829 r
F P
0 g
s
.30487 .31918 m .28967 .3109 L .29858 .29824 L p .694 .677 .829 r
F P
0 g
s
.25909 .53567 m .28967 .3109 L .30487 .31918 L p .833 .488 .402 r
F P
0 g
s
.30487 .31918 m .27675 .54453 L .25909 .53567 L p .833 .488 .402 r
F P
0 g
s
.28696 .53106 m .27675 .54453 L .30487 .31918 L p 0 0 .214 r
F P
0 g
s
.30487 .31918 m .31382 .30659 L .28696 .53106 L p 0 0 .214 r
F P
0 g
s
.25739 .54814 m .28967 .3109 L .30487 .31918 L p .833 .488 .402 r
F P
0 g
s
.30487 .31918 m .27519 .55703 L .25739 .54814 L p .833 .488 .402 r
F P
0 g
s
.28696 .53106 m .27675 .54453 L .30487 .31918 L p 0 0 .214 r
F P
0 g
s
.30487 .31918 m .31382 .30659 L .28696 .53106 L p 0 0 .214 r
F P
0 g
s
.36231 .29794 m .37737 .30629 L .36816 .31888 L p .694 .677 .829 r
F P
0 g
s
.36816 .31888 m .35314 .3106 L .36231 .29794 L p .694 .677 .829 r
F P
0 g
s
.339 .46428 m .35314 .3106 L .36816 .31888 L p .835 .484 .391 r
F P
0 g
s
.36816 .31888 m .35567 .47298 L .339 .46428 L p .835 .484 .391 r
F P
0 g
s
.36581 .45975 m .35567 .47298 L .36816 .31888 L p .036 0 .253 r
F P
0 g
s
.36816 .31888 m .37737 .30629 L .36581 .45975 L p .036 0 .253 r
F P
0 g
s
.33015 .56047 m .35314 .3106 L .36816 .31888 L p .835 .484 .391 r
F P
0 g
s
.36816 .31888 m .34785 .56939 L .33015 .56047 L p .835 .484 .391 r
F P
0 g
s
.36581 .45975 m .35567 .47298 L .36816 .31888 L p .036 0 .253 r
F P
0 g
s
.36816 .31888 m .37737 .30629 L .36581 .45975 L p .036 0 .253 r
F P
0 g
s
.42605 .29764 m .44094 .30599 L .43147 .31859 L p .694 .677 .829 r
F P
0 g
s
.43147 .31859 m .41661 .3103 L .42605 .29764 L p .694 .677 .829 r
F P
0 g
s
.4098 .4527 m .42614 .46138 L .41584 .47445 L p .69 .69 .845 r
F P
0 g
s
.40926 .46396 m .41661 .3103 L .43147 .31859 L p .836 .479 .38 r
F P
0 g
s
.43147 .31859 m .42571 .47267 L .40926 .46396 L p .836 .479 .38 r
F P
0 g
s
.43618 .45943 m .42571 .47267 L .43147 .31859 L p .08 0 .287 r
F P
0 g
s
.43147 .31859 m .44094 .30599 L .43618 .45943 L p .08 0 .287 r
F P
0 g
s
.4098 .4527 m .41661 .3103 L .43147 .31859 L p .836 .479 .38 r
F P
0 g
s
.43147 .31859 m .42614 .46138 L .4098 .4527 L p .836 .479 .38 r
F P
0 g
s
.43618 .45943 m .42571 .47267 L .43147 .31859 L p .08 0 .287 r
F P
0 g
s
.43147 .31859 m .44094 .30599 L .43618 .45943 L p .08 0 .287 r
F P
0 g
s
.48981 .29733 m .50452 .30569 L .49478 .31829 L p .694 .677 .829 r
F P
0 g
s
.49478 .31829 m .4801 .31 L .48981 .29733 L p .694 .677 .829 r
F P
0 g
s
.46911 .4544 m .48509 .46298 L .47465 .47589 L p .69 .689 .844 r
F P
0 g
s
.47961 .44129 m .49563 .44994 L .48509 .46298 L p .69 .689 .844 r
F P
0 g
s
.48509 .46298 m .46911 .4544 L .47961 .44129 L p .69 .689 .844 r
F P
0 g
s
.47953 .46365 m .4801 .31 L .49478 .31829 L p .837 .474 .368 r
F P
0 g
s
.49478 .31829 m .49578 .47235 L .47953 .46365 L p .837 .474 .368 r
F P
0 g
s
.50656 .45912 m .49578 .47235 L .49478 .31829 L p .121 0 .318 r
F P
0 g
s
.49478 .31829 m .50452 .30569 L .50656 .45912 L p .121 0 .318 r
F P
0 g
s
.47961 .44129 m .4801 .31 L .49478 .31829 L p .837 .474 .368 r
F P
0 g
s
.49478 .31829 m .49563 .44994 L .47961 .44129 L p .837 .474 .368 r
F P
0 g
s
.50656 .45912 m .49578 .47235 L .49478 .31829 L p .121 0 .318 r
F P
0 g
s
.49478 .31829 m .50452 .30569 L .50656 .45912 L p .121 0 .318 r
F P
0 g
s
.55358 .29703 m .56812 .30539 L .55811 .31799 L p .694 .677 .829 r
F P
0 g
s
.55811 .31799 m .5436 .3097 L .55358 .29703 L p .694 .677 .829 r
F P
0 g
s
.55475 .5854 m .5436 .3097 L .55811 .31799 L p .838 .469 .355 r
F P
0 g
s
.55811 .31799 m .572 .59437 L .55475 .5854 L p .838 .469 .355 r
F P
0 g
s
.584 .58072 m .572 .59437 L .55811 .31799 L p .157 0 .346 r
F P
0 g
s
.55811 .31799 m .56812 .30539 L .584 .58072 L p .157 0 .346 r
F P
0 g
s
.55529 .59864 m .5436 .3097 L .55811 .31799 L p .838 .469 .355 r
F P
0 g
s
.55811 .31799 m .57267 .60764 L .55529 .59864 L p .838 .469 .355 r
F P
0 g
s
.584 .58072 m .572 .59437 L .55811 .31799 L p .157 0 .346 r
F P
0 g
s
.55811 .31799 m .56812 .30539 L .584 .58072 L p .157 0 .346 r
F P
0 g
s
.61736 .29673 m .63173 .30509 L .62145 .31769 L p .694 .677 .829 r
F P
0 g
s
.62145 .31769 m .60712 .3094 L .61736 .29673 L p .694 .677 .829 r
F P
0 g
s
.62826 .55919 m .60712 .3094 L .62145 .31769 L p .839 .463 .341 r
F P
0 g
s
.62145 .31769 m .64501 .56811 L .62826 .55919 L p .839 .463 .341 r
F P
0 g
s
.65718 .55454 m .64501 .56811 L .62145 .31769 L p .19 0 .37 r
F P
0 g
s
.62145 .31769 m .63173 .30509 L .65718 .55454 L p .19 0 .37 r
F P
0 g
s
.63271 .61176 m .60712 .3094 L .62145 .31769 L p .839 .463 .341 r
F P
0 g
s
.62145 .31769 m .64997 .62079 L .63271 .61176 L p .839 .463 .341 r
F P
0 g
s
.65718 .55454 m .64501 .56811 L .62145 .31769 L p .19 0 .37 r
F P
0 g
s
.62145 .31769 m .63173 .30509 L .65718 .55454 L p .19 0 .37 r
F P
0 g
s
.68115 .29643 m .69534 .30479 L .68481 .3174 L p .694 .677 .829 r
F P
0 g
s
.68481 .3174 m .67064 .3091 L .68115 .29643 L p .694 .677 .829 r
F P
0 g
s
.7012 .54621 m .7176 .55511 L .70528 .56852 L p .687 .699 .856 r
F P
0 g
s
.70283 .55886 m .67064 .3091 L .68481 .3174 L p .839 .457 .326 r
F P
0 g
s
.68481 .3174 m .71934 .56779 L .70283 .55886 L p .839 .457 .326 r
F P
0 g
s
.73188 .55422 m .71934 .56779 L .68481 .3174 L p .22 .027 .392 r
F P
0 g
s
.68481 .3174 m .69534 .30479 L .73188 .55422 L p .22 .027 .392 r
F P
0 g
s
.7012 .54621 m .67064 .3091 L .68481 .3174 L p .839 .457 .326 r
F P
0 g
s
.68481 .3174 m .7176 .55511 L .7012 .54621 L p .839 .457 .326 r
F P
0 g
s
.73188 .55422 m .71934 .56779 L .68481 .3174 L p .22 .027 .392 r
F P
0 g
s
.68481 .3174 m .69534 .30479 L .73188 .55422 L p .22 .027 .392 r
F P
0 g
s
.74495 .29613 m .75898 .30449 L .74818 .3171 L p .694 .677 .829 r
F P
0 g
s
.74818 .3171 m .73418 .30881 L .74495 .29613 L p .694 .677 .829 r
F P
0 g
s
.78652 .61111 m .73418 .30881 L .74818 .3171 L p .839 .45 .311 r
F P
0 g
s
.74818 .3171 m .80327 .62015 L .78652 .61111 L p .839 .45 .311 r
F P
0 g
s
.81663 .60641 m .80327 .62015 L .74818 .3171 L p .248 .056 .412 r
F P
0 g
s
.74818 .3171 m .75898 .30449 L .81663 .60641 L p .248 .056 .412 r
F P
0 g
s
.79128 .63865 m .73418 .30881 L .74818 .3171 L p .839 .45 .311 r
F P
0 g
s
.74818 .3171 m .80829 .64773 L .79128 .63865 L p .839 .45 .311 r
F P
0 g
s
.81663 .60641 m .80327 .62015 L .74818 .3171 L p .248 .056 .412 r
F P
0 g
s
.74818 .3171 m .75898 .30449 L .81663 .60641 L p .248 .056 .412 r
F P
0 g
s
.80877 .29583 m .82262 .30419 L .81155 .3168 L p .694 .677 .829 r
F P
0 g
s
.81155 .3168 m .79773 .30851 L .80877 .29583 L p .694 .677 .829 r
F P
0 g
s
.86943 .63832 m .79773 .30851 L .81155 .3168 L p .839 .442 .294 r
F P
0 g
s
.81155 .3168 m .88618 .6474 L .86943 .63832 L p .839 .442 .294 r
F P
0 g
s
.90017 .63359 m .88618 .6474 L .81155 .3168 L p .272 .082 .43 r
F P
0 g
s
.81155 .3168 m .82262 .30419 L .90017 .63359 L p .272 .082 .43 r
F P
0 g
s
.8725 .65241 m .79773 .30851 L .81155 .3168 L p .839 .442 .294 r
F P
0 g
s
.81155 .3168 m .88936 .66152 L .8725 .65241 L p .839 .442 .294 r
F P
0 g
s
.90017 .63359 m .88618 .6474 L .81155 .3168 L p .272 .082 .43 r
F P
0 g
s
.81155 .3168 m .82262 .30419 L .90017 .63359 L p .272 .082 .43 r
F P
0 g
s
.95504 .66641 m .8613 .30821 L .87495 .3165 L p .839 .434 .276 r
F P
0 g
s
.87495 .3165 m .97176 .67554 L .95504 .66641 L p .839 .434 .276 r
F P
0 g
s
.17008 .51482 m .16048 .52829 L .20224 .31549 L p 0 0 .14 r
F P
0 g
s
.20224 .31549 m .21077 .30287 L .17008 .51482 L p 0 0 .14 r
F P
0 g
s
.25903 .2942 m .27439 .30257 L .2656 .3152 L p .694 .677 .829 r
F P
0 g
s
.2656 .3152 m .25027 .30689 L .25903 .2942 L p .694 .677 .829 r
F P
0 g
s
.21942 .4951 m .25027 .30689 L .2656 .3152 L p .833 .49 .407 r
F P
0 g
s
.2656 .3152 m .23685 .50391 L .21942 .4951 L p .833 .49 .407 r
F P
0 g
s
.24666 .49052 m .23685 .50391 L .2656 .3152 L p 0 0 .186 r
F P
0 g
s
.2656 .3152 m .27439 .30257 L .24666 .49052 L p 0 0 .186 r
F P
0 g
s
.21747 .50702 m .25027 .30689 L .2656 .3152 L p .833 .49 .407 r
F P
0 g
s
.2656 .3152 m .23503 .51585 L .21747 .50702 L p .833 .49 .407 r
F P
0 g
s
.24491 .50242 m .23503 .51585 L .2656 .3152 L p 0 0 .186 r
F P
0 g
s
.2656 .3152 m .27439 .30257 L .24491 .50242 L p 0 0 .186 r
F P
0 g
s
.32284 .29389 m .33803 .30227 L .32897 .3149 L p .694 .677 .829 r
F P
0 g
s
.32897 .3149 m .31382 .30659 L .32284 .29389 L p .694 .677 .829 r
F P
0 g
s
.28696 .53106 m .31382 .30659 L .32897 .3149 L p .834 .486 .397 r
F P
0 g
s
.32897 .3149 m .30456 .53995 L .28696 .53106 L p .834 .486 .397 r
F P
0 g
s
.31492 .52643 m .30456 .53995 L .32897 .3149 L p .004 0 .228 r
F P
0 g
s
.32897 .3149 m .33803 .30227 L .31492 .52643 L p .004 0 .228 r
F P
0 g
s
.28696 .53106 m .31382 .30659 L .32897 .3149 L p .834 .486 .397 r
F P
0 g
s
.32897 .3149 m .30456 .53995 L .28696 .53106 L p .834 .486 .397 r
F P
0 g
s
.31364 .53887 m .3032 .55243 L .32897 .3149 L p .004 0 .228 r
F P
0 g
s
.32897 .3149 m .33803 .30227 L .31364 .53887 L p .004 0 .228 r
F P
0 g
s
.38666 .29359 m .40168 .30197 L .39235 .3146 L p .694 .677 .829 r
F P
0 g
s
.39235 .3146 m .37737 .30629 L .38666 .29359 L p .694 .677 .829 r
F P
0 g
s
.36666 .4485 m .37737 .30629 L .39235 .3146 L p .835 .482 .386 r
F P
0 g
s
.39235 .3146 m .38315 .4572 L .36666 .4485 L p .835 .482 .386 r
F P
0 g
s
.39336 .44397 m .38315 .4572 L .39235 .3146 L p .051 0 .265 r
F P
0 g
s
.39235 .3146 m .40168 .30197 L .39336 .44397 L p .051 0 .265 r
F P
0 g
s
.36581 .45975 m .37737 .30629 L .39235 .3146 L p .835 .482 .386 r
F P
0 g
s
.39235 .3146 m .38242 .46848 L .36581 .45975 L p .835 .482 .386 r
F P
0 g
s
.3927 .45521 m .38242 .46848 L .39235 .3146 L p .051 0 .265 r
F P
0 g
s
.39235 .3146 m .40168 .30197 L .3927 .45521 L p .051 0 .265 r
F P
0 g
s
.4505 .29329 m .46534 .30167 L .45575 .3143 L p .694 .677 .829 r
F P
0 g
s
.45575 .3143 m .44094 .30599 L .4505 .29329 L p .694 .677 .829 r
F P
0 g
s
.43618 .45943 m .44094 .30599 L .45575 .3143 L p .836 .477 .374 r
F P
0 g
s
.45575 .3143 m .45258 .46816 L .43618 .45943 L p .836 .477 .374 r
F P
0 g
s
.46923 .44342 m .45327 .43482 L .46365 .42167 L p .691 .688 .843 r
F P
0 g
s
.45304 .44578 m .46911 .4544 L .45871 .4674 L p .69 .689 .844 r
F P
0 g
s
.46318 .45489 m .45258 .46816 L .45575 .3143 L p .094 0 .298 r
F P
0 g
s
.45575 .3143 m .46534 .30167 L .46318 .45489 L p .094 0 .298 r
F P
0 g
s
.43618 .45943 m .44094 .30599 L .45575 .3143 L p .836 .477 .374 r
F P
0 g
s
.45575 .3143 m .45258 .46816 L .43618 .45943 L p .836 .477 .374 r
F P
0 g
s
.46365 .42167 m .45327 .43482 L .45575 .3143 L p .094 0 .298 r
F P
0 g
s
.45575 .3143 m .46534 .30167 L .46365 .42167 L p .094 0 .298 r
F P
0 g
s
.51435 .29299 m .52902 .30137 L .51916 .314 L p .694 .677 .829 r
F P
0 g
s
.51916 .314 m .50452 .30569 L .51435 .29299 L p .694 .677 .829 r
F P
0 g
s
.50641 .44787 m .50452 .30569 L .51916 .314 L p .837 .472 .362 r
F P
0 g
s
.51916 .314 m .52249 .45658 L .50641 .44787 L p .837 .472 .362 r
F P
0 g
s
.53334 .44334 m .52249 .45658 L .51916 .314 L p .133 0 .328 r
F P
0 g
s
.51916 .314 m .52902 .30137 L .53334 .44334 L p .133 0 .328 r
F P
0 g
s
.50656 .45912 m .50452 .30569 L .51916 .314 L p .837 .472 .362 r
F P
0 g
s
.51916 .314 m .52275 .46785 L .50656 .45912 L p .837 .472 .362 r
F P
0 g
s
.53368 .45457 m .52275 .46785 L .51916 .314 L p .133 0 .328 r
F P
0 g
s
.51916 .314 m .52902 .30137 L .53368 .45457 L p .133 0 .328 r
F P
0 g
s
.57821 .29268 m .5927 .30107 L .58258 .3137 L p .694 .677 .829 r
F P
0 g
s
.58258 .3137 m .56812 .30539 L .57821 .29268 L p .694 .677 .829 r
F P
0 g
s
.584 .58072 m .56812 .30539 L .58258 .3137 L p .838 .466 .348 r
F P
0 g
s
.58258 .3137 m .60118 .58973 L .584 .58072 L p .838 .466 .348 r
F P
0 g
s
.61334 .57603 m .60118 .58973 L .58258 .3137 L p .169 0 .354 r
F P
0 g
s
.58258 .3137 m .5927 .30107 L .61334 .57603 L p .169 0 .354 r
F P
0 g
s
.584 .58072 m .56812 .30539 L .58258 .3137 L p .838 .466 .348 r
F P
0 g
s
.58258 .3137 m .60118 .58973 L .584 .58072 L p .838 .466 .348 r
F P
0 g
s
.61433 .58925 m .60207 .60299 L .58258 .3137 L p .169 0 .354 r
F P
0 g
s
.58258 .3137 m .5927 .30107 L .61433 .58925 L p .169 0 .354 r
F P
0 g
s
.64208 .29238 m .6564 .30077 L .64601 .31341 L p .694 .677 .829 r
F P
0 g
s
.64601 .31341 m .63173 .30509 L .64208 .29238 L p .694 .677 .829 r
F P
0 g
s
.65589 .5419 m .63173 .30509 L .64601 .31341 L p .839 .46 .334 r
F P
0 g
s
.64601 .31341 m .67246 .55083 L .65589 .5419 L p .839 .46 .334 r
F P
0 g
s
.6847 .53725 m .67246 .55083 L .64601 .31341 L p .201 .006 .378 r
F P
0 g
s
.64601 .31341 m .6564 .30077 L .6847 .53725 L p .201 .006 .378 r
F P
0 g
s
.65718 .55454 m .63173 .30509 L .64601 .31341 L p .839 .46 .334 r
F P
0 g
s
.64601 .31341 m .67387 .5635 L .65718 .55454 L p .839 .46 .334 r
F P
0 g
s
.68621 .54988 m .67387 .5635 L .64601 .31341 L p .201 .006 .378 r
F P
0 g
s
.64601 .31341 m .6564 .30077 L .68621 .54988 L p .201 .006 .378 r
F P
0 g
s
.70597 .29208 m .72011 .30047 L .70946 .31311 L p .694 .677 .829 r
F P
0 g
s
.70946 .31311 m .69534 .30479 L .70597 .29208 L p .694 .677 .829 r
F P
0 g
s
.73188 .55422 m .69534 .30479 L .70946 .31311 L p .839 .453 .319 r
F P
0 g
s
.70946 .31311 m .74833 .56317 L .73188 .55422 L p .839 .453 .319 r
F P
0 g
s
.76103 .54955 m .74833 .56317 L .70946 .31311 L p .23 .037 .399 r
F P
0 g
s
.70946 .31311 m .72011 .30047 L .76103 .54955 L p .23 .037 .399 r
F P
0 g
s
.73188 .55422 m .69534 .30479 L .70946 .31311 L p .839 .453 .319 r
F P
0 g
s
.70946 .31311 m .74833 .56317 L .73188 .55422 L p .839 .453 .319 r
F P
0 g
s
.77189 .61565 m .75864 .62947 L .70946 .31311 L p .23 .037 .399 r
F P
0 g
s
.70946 .31311 m .72011 .30047 L .77189 .61565 L p .23 .037 .399 r
F P
0 g
s
.76987 .29178 m .78384 .30016 L .77292 .31281 L p .694 .677 .829 r
F P
0 g
s
.77292 .31281 m .75898 .30449 L .76987 .29178 L p .694 .677 .829 r
F P
0 g
s
.81406 .59297 m .75898 .30449 L .77292 .31281 L p .84 .446 .302 r
F P
0 g
s
.77292 .31281 m .83062 .60201 L .81406 .59297 L p .84 .446 .302 r
F P
0 g
s
.84403 .58827 m .83062 .60201 L .77292 .31281 L p .256 .065 .418 r
F P
0 g
s
.77292 .31281 m .78384 .30016 L .84403 .58827 L p .256 .065 .418 r
F P
0 g
s
.81663 .60641 m .75898 .30449 L .77292 .31281 L p .84 .446 .302 r
F P
0 g
s
.77292 .31281 m .83331 .61547 L .81663 .60641 L p .84 .446 .302 r
F P
0 g
s
.84684 .60169 m .83331 .61547 L .77292 .31281 L p .256 .065 .418 r
F P
0 g
s
.77292 .31281 m .78384 .30016 L .84684 .60169 L p .256 .065 .418 r
F P
0 g
s
.83378 .29147 m .84758 .29986 L .83639 .31251 L p .694 .677 .829 r
F P
0 g
s
.83639 .31251 m .82262 .30419 L .83378 .29147 L p .694 .677 .829 r
F P
0 g
s
.90017 .63359 m .82262 .30419 L .83639 .31251 L p .839 .438 .285 r
F P
0 g
s
.83639 .31251 m .91684 .64271 L .90017 .63359 L p .839 .438 .285 r
F P
0 g
s
.93101 .62884 m .91684 .64271 L .83639 .31251 L p .28 .091 .436 r
F P
0 g
s
.83639 .31251 m .84758 .29986 L .93101 .62884 L p .28 .091 .436 r
F P
0 g
s
.90017 .63359 m .82262 .30419 L .83639 .31251 L p .839 .438 .285 r
F P
0 g
s
.83639 .31251 m .91684 .64271 L .90017 .63359 L p .839 .438 .285 r
F P
0 g
s
.93458 .64291 m .92027 .65681 L .83639 .31251 L p .28 .091 .436 r
F P
0 g
s
.83639 .31251 m .84758 .29986 L .93458 .64291 L p .28 .091 .436 r
F P
0 g
s
.21937 .29014 m .23487 .29854 L .22622 .3112 L p .694 .677 .829 r
F P
0 g
s
.22622 .3112 m .21077 .30287 L .21937 .29014 L p .694 .677 .829 r
F P
0 g
s
.1724 .50274 m .21077 .30287 L .22622 .3112 L p .832 .492 .412 r
F P
0 g
s
.22622 .3112 m .19012 .5116 L .1724 .50274 L p .832 .492 .412 r
F P
0 g
s
.1998 .49813 m .19012 .5116 L .22622 .3112 L p 0 0 .156 r
F P
0 g
s
.22622 .3112 m .23487 .29854 L .1998 .49813 L p 0 0 .156 r
F P
0 g
s
.17008 .51482 m .21077 .30287 L .22622 .3112 L p .832 .492 .412 r
F P
0 g
s
.22622 .3112 m .18794 .52371 L .17008 .51482 L p .832 .492 .412 r
F P
0 g
s
.1998 .49813 m .19012 .5116 L .22622 .3112 L p 0 0 .156 r
F P
0 g
s
.22622 .3112 m .23487 .29854 L .1998 .49813 L p 0 0 .156 r
F P
0 g
s
.28326 .28984 m .29858 .29824 L .28967 .3109 L p .694 .677 .829 r
F P
0 g
s
.28967 .3109 m .27439 .30257 L .28326 .28984 L p .694 .677 .829 r
F P
0 g
s
.24491 .50242 m .27439 .30257 L .28967 .3109 L p .833 .488 .402 r
F P
0 g
s
.28967 .3109 m .26241 .51128 L .24491 .50242 L p .833 .488 .402 r
F P
0 g
s
.27243 .4978 m .26241 .51128 L .28967 .3109 L p 0 0 .2 r
F P
0 g
s
.28967 .3109 m .29858 .29824 L .27243 .4978 L p 0 0 .2 r
F P
0 g
s
.24491 .50242 m .27439 .30257 L .28967 .3109 L p .833 .488 .402 r
F P
0 g
s
.28967 .3109 m .26241 .51128 L .24491 .50242 L p .833 .488 .402 r
F P
0 g
s
.26925 .52211 m .25909 .53567 L .28967 .3109 L p 0 0 .2 r
F P
0 g
s
.28967 .3109 m .29858 .29824 L .26925 .52211 L p 0 0 .2 r
F P
0 g
s
.34717 .28954 m .36231 .29794 L .35314 .3106 L p .694 .677 .829 r
F P
0 g
s
.35314 .3106 m .33803 .30227 L .34717 .28954 L p .694 .677 .829 r
F P
0 g
s
.32223 .45552 m .33803 .30227 L .35314 .3106 L p .835 .484 .391 r
F P
0 g
s
.35314 .3106 m .339 .46428 L .32223 .45552 L p .835 .484 .391 r
F P
0 g
s
.34909 .45097 m .339 .46428 L .35314 .3106 L p .02 0 .24 r
F P
0 g
s
.35314 .3106 m .36231 .29794 L .34909 .45097 L p .02 0 .24 r
F P
0 g
s
.31364 .53887 m .33803 .30227 L .35314 .3106 L p .835 .484 .391 r
F P
0 g
s
.35314 .3106 m .33132 .54782 L .31364 .53887 L p .835 .484 .391 r
F P
0 g
s
.34909 .45097 m .339 .46428 L .35314 .3106 L p .02 0 .24 r
F P
0 g
s
.35314 .3106 m .36231 .29794 L .34909 .45097 L p .02 0 .24 r
F P
0 g
s
.41108 .28923 m .42605 .29764 L .41661 .3103 L p .694 .677 .829 r
F P
0 g
s
.41661 .3103 m .40168 .30197 L .41108 .28923 L p .694 .677 .829 r
F P
0 g
s
.39401 .4329 m .40168 .30197 L .41661 .3103 L p .836 .479 .38 r
F P
0 g
s
.41661 .3103 m .41033 .4416 L .39401 .4329 L p .836 .479 .38 r
F P
0 g
s
.42061 .42838 m .41033 .4416 L .41661 .3103 L p .066 0 .276 r
F P
0 g
s
.41661 .3103 m .42605 .29764 L .42061 .42838 L p .066 0 .276 r
F P
0 g
s
.3927 .45521 m .40168 .30197 L .41661 .3103 L p .836 .479 .38 r
F P
0 g
s
.41661 .3103 m .40926 .46396 L .3927 .45521 L p .836 .479 .38 r
F P
0 g
s
.41968 .45065 m .40926 .46396 L .41661 .3103 L p .066 0 .276 r
F P
0 g
s
.41661 .3103 m .42605 .29764 L .41968 .45065 L p .066 0 .276 r
F P
0 g
s
.47501 .28893 m .48981 .29733 L .4801 .31 L p .694 .677 .829 r
F P
0 g
s
.4801 .31 m .46534 .30167 L .47501 .28893 L p .694 .677 .829 r
F P
0 g
s
.46365 .42167 m .47965 .43035 L .46923 .44342 L p .691 .688 .843 r
F P
0 g
s
.46318 .45489 m .46534 .30167 L .4801 .31 L p .837 .474 .368 r
F P
0 g
s
.47465 .47589 m .45871 .4674 L .46911 .4544 L p .69 .689 .844 r
F P
0 g
s
.4801 .31 m .47953 .46365 L .46318 .45489 L p .837 .474 .368 r
F P
0 g
s
.49027 .45033 m .47953 .46365 L .4801 .31 L p .108 0 .308 r
F P
0 g
s
.4801 .31 m .48981 .29733 L .49027 .45033 L p .108 0 .308 r
F P
0 g
s
.46365 .42167 m .46534 .30167 L .4801 .31 L p .837 .474 .368 r
F P
0 g
s
.4801 .31 m .47965 .43035 L .46365 .42167 L p .837 .474 .368 r
F P
0 g
s
.49027 .45033 m .47953 .46365 L .4801 .31 L p .108 0 .308 r
F P
0 g
s
.4801 .31 m .48981 .29733 L .49027 .45033 L p .108 0 .308 r
F P
0 g
s
.53895 .28863 m .55358 .29703 L .5436 .3097 L p .694 .677 .829 r
F P
0 g
s
.5436 .3097 m .52902 .30137 L .53895 .28863 L p .694 .677 .829 r
F P
0 g
s
.53368 .45457 m .52902 .30137 L .5436 .3097 L p .838 .469 .355 r
F P
0 g
s
.5436 .3097 m .54982 .46333 L .53368 .45457 L p .838 .469 .355 r
F P
0 g
s
.56089 .45001 m .54982 .46333 L .5436 .3097 L p .145 0 .337 r
F P
0 g
s
.5436 .3097 m .55358 .29703 L .56089 .45001 L p .145 0 .337 r
F P
0 g
s
.53368 .45457 m .52902 .30137 L .5436 .3097 L p .838 .469 .355 r
F P
0 g
s
.5436 .3097 m .54982 .46333 L .53368 .45457 L p .838 .469 .355 r
F P
0 g
s
.5667 .57166 m .55475 .5854 L .5436 .3097 L p .145 0 .337 r
F P
0 g
s
.5436 .3097 m .55358 .29703 L .5667 .57166 L p .145 0 .337 r
F P
0 g
s
.60291 .28832 m .61736 .29673 L .60712 .3094 L p .694 .677 .829 r
F P
0 g
s
.60712 .3094 m .5927 .30107 L .60291 .28832 L p .694 .677 .829 r
F P
0 g
s
.6114 .5502 m .5927 .30107 L .60712 .3094 L p .839 .463 .341 r
F P
0 g
s
.60712 .3094 m .62826 .55919 L .6114 .5502 L p .839 .463 .341 r
F P
0 g
s
.64039 .54552 m .62826 .55919 L .60712 .3094 L p .18 0 .362 r
F P
0 g
s
.60712 .3094 m .61736 .29673 L .64039 .54552 L p .18 0 .362 r
F P
0 g
s
.61433 .58925 m .5927 .30107 L .60712 .3094 L p .839 .463 .341 r
F P
0 g
s
.60712 .3094 m .63157 .59831 L .61433 .58925 L p .839 .463 .341 r
F P
0 g
s
.64039 .54552 m .62826 .55919 L .60712 .3094 L p .18 0 .362 r
F P
0 g
s
.60712 .3094 m .61736 .29673 L .64039 .54552 L p .18 0 .362 r
F P
0 g
s
.66688 .28802 m .68115 .29643 L .67064 .3091 L p .694 .677 .829 r
F P
0 g
s
.67064 .3091 m .6564 .30077 L .66688 .28802 L p .694 .677 .829 r
F P
0 g
s
.68321 .52482 m .6564 .30077 L .67064 .3091 L p .839 .457 .326 r
F P
0 g
s
.67064 .3091 m .69959 .53375 L .68321 .52482 L p .839 .457 .326 r
F P
0 g
s
.71189 .52017 m .69959 .53375 L .67064 .3091 L p .211 .017 .385 r
F P
0 g
s
.67064 .3091 m .68115 .29643 L .71189 .52017 L p .211 .017 .385 r
F P
0 g
s
.68621 .54988 m .6564 .30077 L .67064 .3091 L p .839 .457 .326 r
F P
0 g
s
.67064 .3091 m .70283 .55886 L .68621 .54988 L p .839 .457 .326 r
F P
0 g
s
.71533 .5452 m .70283 .55886 L .67064 .3091 L p .211 .017 .385 r
F P
0 g
s
.67064 .3091 m .68115 .29643 L .71533 .5452 L p .211 .017 .385 r
F P
0 g
s
.73086 .28772 m .74495 .29613 L .73418 .30881 L p .694 .677 .829 r
F P
0 g
s
.73418 .30881 m .72011 .30047 L .73086 .28772 L p .694 .677 .829 r
F P
0 g
s
.76965 .60202 m .72011 .30047 L .73418 .30881 L p .839 .45 .311 r
F P
0 g
s
.73418 .30881 m .78652 .61111 L .76965 .60202 L p .839 .45 .311 r
F P
0 g
s
.79983 .59728 m .78652 .61111 L .73418 .30881 L p .239 .047 .406 r
F P
0 g
s
.73418 .30881 m .74495 .29613 L .79983 .59728 L p .239 .047 .406 r
F P
0 g
s
.77189 .61565 m .72011 .30047 L .73418 .30881 L p .839 .45 .311 r
F P
0 g
s
.73418 .30881 m .78888 .62477 L .77189 .61565 L p .839 .45 .311 r
F P
0 g
s
.79983 .59728 m .78652 .61111 L .73418 .30881 L p .239 .047 .406 r
F P
0 g
s
.73418 .30881 m .74495 .29613 L .79983 .59728 L p .239 .047 .406 r
F P
0 g
s
.79485 .28741 m .80877 .29583 L .79773 .30851 L p .694 .677 .829 r
F P
0 g
s
.79773 .30851 m .78384 .30016 L .79485 .28741 L p .694 .677 .829 r
F P
0 g
s
.84684 .60169 m .78384 .30016 L .79773 .30851 L p .839 .442 .294 r
F P
0 g
s
.79773 .30851 m .86345 .61079 L .84684 .60169 L p .839 .442 .294 r
F P
0 g
s
.87715 .59695 m .86345 .61079 L .79773 .30851 L p .264 .074 .424 r
F P
0 g
s
.79773 .30851 m .80877 .29583 L .87715 .59695 L p .264 .074 .424 r
F P
0 g
s
.84684 .60169 m .78384 .30016 L .79773 .30851 L p .839 .442 .294 r
F P
0 g
s
.79773 .30851 m .86345 .61079 L .84684 .60169 L p .839 .442 .294 r
F P
0 g
s
.88339 .62441 m .86943 .63832 L .79773 .30851 L p .264 .074 .424 r
F P
0 g
s
.79773 .30851 m .80877 .29583 L .88339 .62441 L p .264 .074 .424 r
F P
0 g
s
.93458 .64291 m .84758 .29986 L .8613 .30821 L p .839 .434 .276 r
F P
0 g
s
.8613 .30821 m .95129 .65208 L .93458 .64291 L p .839 .434 .276 r
F P
0 g
s
.24358 .28578 m .25903 .2942 L .25027 .30689 L p .694 .677 .829 r
F P
0 g
s
.25027 .30689 m .23487 .29854 L .24358 .28578 L p .694 .677 .829 r
F P
0 g
s
.1998 .49813 m .23487 .29854 L .25027 .30689 L p .833 .49 .407 r
F P
0 g
s
.25027 .30689 m .21747 .50702 L .1998 .49813 L p .833 .49 .407 r
F P
0 g
s
.23685 .50391 m .21942 .4951 L .22919 .48163 L p .688 .694 .85 r
F P
0 g
s
.22729 .4935 m .21747 .50702 L .25027 .30689 L p 0 0 .171 r
F P
0 g
s
.25027 .30689 m .25903 .2942 L .22729 .4935 L p 0 0 .171 r
F P
0 g
s
.1998 .49813 m .23487 .29854 L .25027 .30689 L p .833 .49 .407 r
F P
0 g
s
.25027 .30689 m .21747 .50702 L .1998 .49813 L p .833 .49 .407 r
F P
0 g
s
.22919 .48163 m .21942 .4951 L .25027 .30689 L p 0 0 .171 r
F P
0 g
s
.25027 .30689 m .25903 .2942 L .22919 .48163 L p 0 0 .171 r
F P
0 g
s
.30757 .28547 m .32284 .29389 L .31382 .30659 L p .694 .677 .829 r
F P
0 g
s
.31382 .30659 m .29858 .29824 L .30757 .28547 L p .694 .677 .829 r
F P
0 g
s
.27085 .50987 m .29858 .29824 L .31382 .30659 L p .834 .486 .397 r
F P
0 g
s
.31382 .30659 m .28843 .51879 L .27085 .50987 L p .834 .486 .397 r
F P
0 g
s
.29867 .50522 m .28843 .51879 L .31382 .30659 L p 0 0 .214 r
F P
0 g
s
.31382 .30659 m .32284 .29389 L .29867 .50522 L p 0 0 .214 r
F P
0 g
s
.26925 .52211 m .29858 .29824 L .31382 .30659 L p .834 .486 .397 r
F P
0 g
s
.31382 .30659 m .28696 .53106 L .26925 .52211 L p .834 .486 .397 r
F P
0 g
s
.29727 .51745 m .28696 .53106 L .31382 .30659 L p 0 0 .214 r
F P
0 g
s
.31382 .30659 m .32284 .29389 L .29727 .51745 L p 0 0 .214 r
F P
0 g
s
.37156 .28517 m .38666 .29359 L .37737 .30629 L p .694 .677 .829 r
F P
0 g
s
.37737 .30629 m .36231 .29794 L .37156 .28517 L p .694 .677 .829 r
F P
0 g
s
.34909 .45097 m .36231 .29794 L .37737 .30629 L p .835 .482 .386 r
F P
0 g
s
.37737 .30629 m .36581 .45975 L .34909 .45097 L p .835 .482 .386 r
F P
0 g
s
.38315 .4572 m .36666 .4485 L .37682 .43519 L p .69 .69 .845 r
F P
0 g
s
.37604 .44639 m .36581 .45975 L .37737 .30629 L p .036 0 .253 r
F P
0 g
s
.37737 .30629 m .38666 .29359 L .37604 .44639 L p .036 0 .253 r
F P
0 g
s
.34909 .45097 m .36231 .29794 L .37737 .30629 L p .835 .482 .386 r
F P
0 g
s
.37737 .30629 m .36581 .45975 L .34909 .45097 L p .835 .482 .386 r
F P
0 g
s
.37682 .43519 m .36666 .4485 L .37737 .30629 L p .036 0 .253 r
F P
0 g
s
.37737 .30629 m .38666 .29359 L .37682 .43519 L p .036 0 .253 r
F P
0 g
s
.43557 .28486 m .4505 .29329 L .44094 .30599 L p .694 .677 .829 r
F P
0 g
s
.44094 .30599 m .42605 .29764 L .43557 .28486 L p .694 .677 .829 r
F P
0 g
s
.42014 .43943 m .42605 .29764 L .44094 .30599 L p .836 .477 .374 r
F P
0 g
s
.44094 .30599 m .43653 .44819 L .42014 .43943 L p .836 .477 .374 r
F P
0 g
s
.44701 .43488 m .43653 .44819 L .44094 .30599 L p .08 0 .287 r
F P
0 g
s
.44094 .30599 m .4505 .29329 L .44701 .43488 L p .08 0 .287 r
F P
0 g
s
.41968 .45065 m .42605 .29764 L .44094 .30599 L p .836 .477 .374 r
F P
0 g
s
.44094 .30599 m .43618 .45943 L .41968 .45065 L p .836 .477 .374 r
F P
0 g
s
.44674 .44608 m .43618 .45943 L .44094 .30599 L p .08 0 .287 r
F P
0 g
s
.44094 .30599 m .4505 .29329 L .44674 .44608 L p .08 0 .287 r
F P
0 g
s
.4996 .28456 m .51435 .29299 L .50452 .30569 L p .694 .677 .829 r
F P
0 g
s
.50452 .30569 m .48981 .29733 L .4996 .28456 L p .694 .677 .829 r
F P
0 g
s
.49027 .45033 m .48981 .29733 L .50452 .30569 L p .837 .472 .362 r
F P
0 g
s
.50452 .30569 m .50656 .45912 L .49027 .45033 L p .837 .472 .362 r
F P
0 g
s
.52249 .45658 m .50641 .44787 L .51722 .43456 L p .69 .69 .845 r
F P
0 g
s
.51745 .44576 m .50656 .45912 L .50452 .30569 L p .121 0 .318 r
F P
0 g
s
.50452 .30569 m .51435 .29299 L .51745 .44576 L p .121 0 .318 r
F P
0 g
s
.49027 .45033 m .48981 .29733 L .50452 .30569 L p .837 .472 .362 r
F P
0 g
s
.50452 .30569 m .50656 .45912 L .49027 .45033 L p .837 .472 .362 r
F P
0 g
s
.51722 .43456 m .50641 .44787 L .50452 .30569 L p .121 0 .318 r
F P
0 g
s
.50452 .30569 m .51435 .29299 L .51722 .43456 L p .121 0 .318 r
F P
0 g
s
.56363 .28426 m .57821 .29268 L .56812 .30539 L p .694 .677 .829 r
F P
0 g
s
.56812 .30539 m .55358 .29703 L .56363 .28426 L p .694 .677 .829 r
F P
0 g
s
.56608 .55865 m .55358 .29703 L .56812 .30539 L p .838 .466 .348 r
F P
0 g
s
.56812 .30539 m .58324 .56769 L .56608 .55865 L p .838 .466 .348 r
F P
0 g
s
.59526 .55395 m .58324 .56769 L .56812 .30539 L p .157 0 .346 r
F P
0 g
s
.56812 .30539 m .57821 .29268 L .59526 .55395 L p .157 0 .346 r
F P
0 g
s
.5667 .57166 m .55358 .29703 L .56812 .30539 L p .838 .466 .348 r
F P
0 g
s
.56812 .30539 m .584 .58072 L .5667 .57166 L p .838 .466 .348 r
F P
0 g
s
.59611 .56694 m .584 .58072 L .56812 .30539 L p .157 0 .346 r
F P
0 g
s
.56812 .30539 m .57821 .29268 L .59611 .56694 L p .157 0 .346 r
F P
0 g
s
.62768 .28395 m .64208 .29238 L .63173 .30509 L p .694 .677 .829 r
F P
0 g
s
.63173 .30509 m .61736 .29673 L .62768 .28395 L p .694 .677 .829 r
F P
0 g
s
.64039 .54552 m .61736 .29673 L .63173 .30509 L p .839 .46 .334 r
F P
0 g
s
.63173 .30509 m .65718 .55454 L .64039 .54552 L p .839 .46 .334 r
F P
0 g
s
.67246 .55083 m .65589 .5419 L .66809 .52824 L p .687 .699 .856 r
F P
0 g
s
.66948 .54083 m .65718 .55454 L .63173 .30509 L p .19 0 .37 r
F P
0 g
s
.63173 .30509 m .64208 .29238 L .66948 .54083 L p .19 0 .37 r
F P
0 g
s
.64039 .54552 m .61736 .29673 L .63173 .30509 L p .839 .46 .334 r
F P
0 g
s
.63173 .30509 m .65718 .55454 L .64039 .54552 L p .839 .46 .334 r
F P
0 g
s
.66809 .52824 m .65589 .5419 L .63173 .30509 L p .19 0 .37 r
F P
0 g
s
.63173 .30509 m .64208 .29238 L .66809 .52824 L p .19 0 .37 r
F P
0 g
s
.69174 .28365 m .70597 .29208 L .69534 .30479 L p .694 .677 .829 r
F P
0 g
s
.69534 .30479 m .68115 .29643 L .69174 .28365 L p .694 .677 .829 r
F P
0 g
s
.71359 .53259 m .68115 .29643 L .69534 .30479 L p .839 .453 .319 r
F P
0 g
s
.69534 .30479 m .73003 .54158 L .71359 .53259 L p .839 .453 .319 r
F P
0 g
s
.74259 .52791 m .73003 .54158 L .69534 .30479 L p .22 .027 .392 r
F P
0 g
s
.69534 .30479 m .70597 .29208 L .74259 .52791 L p .22 .027 .392 r
F P
0 g
s
.71533 .5452 m .68115 .29643 L .69534 .30479 L p .839 .453 .319 r
F P
0 g
s
.69534 .30479 m .73188 .55422 L .71533 .5452 L p .839 .453 .319 r
F P
0 g
s
.74454 .54051 m .73188 .55422 L .69534 .30479 L p .22 .027 .392 r
F P
0 g
s
.69534 .30479 m .70597 .29208 L .74454 .54051 L p .22 .027 .392 r
F P
0 g
s
.75582 .28334 m .76987 .29178 L .75898 .30449 L p .694 .677 .829 r
F P
0 g
s
.75898 .30449 m .74495 .29613 L .75582 .28334 L p .694 .677 .829 r
F P
0 g
s
.79983 .59728 m .74495 .29613 L .75898 .30449 L p .84 .446 .302 r
F P
0 g
s
.75898 .30449 m .81663 .60641 L .79983 .59728 L p .84 .446 .302 r
F P
0 g
s
.82743 .57914 m .84403 .58827 L .83062 .60201 L p .685 .704 .862 r
F P
0 g
s
.83062 .60201 m .81406 .59297 L .82743 .57914 L p .685 .704 .862 r
F P
0 g
s
.83012 .59253 m .81663 .60641 L .75898 .30449 L p .248 .056 .412 r
F P
0 g
s
.75898 .30449 m .76987 .29178 L .83012 .59253 L p .248 .056 .412 r
F P
0 g
s
.79983 .59728 m .74495 .29613 L .75898 .30449 L p .84 .446 .302 r
F P
0 g
s
.75898 .30449 m .81663 .60641 L .79983 .59728 L p .84 .446 .302 r
F P
0 g
s
.82743 .57914 m .81406 .59297 L .75898 .30449 L p .248 .056 .412 r
F P
0 g
s
.75898 .30449 m .76987 .29178 L .82743 .57914 L p .248 .056 .412 r
F P
0 g
s
.8199 .28304 m .83378 .29147 L .82262 .30419 L p .694 .677 .829 r
F P
0 g
s
.82262 .30419 m .80877 .29583 L .8199 .28304 L p .694 .677 .829 r
F P
0 g
s
.88025 .61057 m .80877 .29583 L .82262 .30419 L p .839 .438 .285 r
F P
0 g
s
.82262 .30419 m .89691 .61973 L .88025 .61057 L p .839 .438 .285 r
F P
0 g
s
.91091 .60581 m .89691 .61973 L .82262 .30419 L p .272 .082 .43 r
F P
0 g
s
.82262 .30419 m .83378 .29147 L .91091 .60581 L p .272 .082 .43 r
F P
0 g
s
.88339 .62441 m .80877 .29583 L .82262 .30419 L p .839 .438 .285 r
F P
0 g
s
.82262 .30419 m .90017 .63359 L .88339 .62441 L p .839 .438 .285 r
F P
0 g
s
.91431 .61963 m .90017 .63359 L .82262 .30419 L p .272 .082 .43 r
F P
0 g
s
.82262 .30419 m .83378 .29147 L .91431 .61963 L p .272 .082 .43 r
F P
0 g
s
.18202 .48918 m .1724 .50274 L .21077 .30287 L p 0 0 .14 r
F P
0 g
s
.21077 .30287 m .21937 .29014 L .18202 .48918 L p 0 0 .14 r
F P
0 g
s
.26786 .2814 m .28326 .28984 L .27439 .30257 L p .694 .677 .829 r
F P
0 g
s
.27439 .30257 m .25903 .2942 L .26786 .2814 L p .694 .677 .829 r
F P
0 g
s
.22919 .48163 m .24666 .49052 L .23685 .50391 L p .688 .694 .85 r
F P
0 g
s
.22729 .4935 m .25903 .2942 L .27439 .30257 L p .833 .488 .402 r
F P
0 g
s
.27439 .30257 m .24491 .50242 L .22729 .4935 L p .833 .488 .402 r
F P
0 g
s
.25488 .48886 m .24491 .50242 L .27439 .30257 L p 0 0 .186 r
F P
0 g
s
.27439 .30257 m .28326 .28984 L .25488 .48886 L p 0 0 .186 r
F P
0 g
s
.22919 .48163 m .25903 .2942 L .27439 .30257 L p .833 .488 .402 r
F P
0 g
s
.27439 .30257 m .24666 .49052 L .22919 .48163 L p .833 .488 .402 r
F P
0 g
s
.25488 .48886 m .24491 .50242 L .27439 .30257 L p 0 0 .186 r
F P
0 g
s
.27439 .30257 m .28326 .28984 L .25488 .48886 L p 0 0 .186 r
F P
0 g
s
.33194 .28109 m .34717 .28954 L .33803 .30227 L p .694 .677 .829 r
F P
0 g
s
.33803 .30227 m .32284 .29389 L .33194 .28109 L p .694 .677 .829 r
F P
0 g
s
.30536 .44671 m .32284 .29389 L .33803 .30227 L p .835 .484 .391 r
F P
0 g
s
.33803 .30227 m .32223 .45552 L .30536 .44671 L p .835 .484 .391 r
F P
0 g
s
.33228 .44213 m .32223 .45552 L .33803 .30227 L p .004 0 .228 r
F P
0 g
s
.33803 .30227 m .34717 .28954 L .33228 .44213 L p .004 0 .228 r
F P
0 g
s
.29727 .51745 m .32284 .29389 L .33803 .30227 L p .835 .484 .391 r
F P
0 g
s
.33803 .30227 m .31492 .52643 L .29727 .51745 L p .835 .484 .391 r
F P
0 g
s
.33228 .44213 m .32223 .45552 L .33803 .30227 L p .004 0 .228 r
F P
0 g
s
.33803 .30227 m .34717 .28954 L .33228 .44213 L p .004 0 .228 r
F P
0 g
s
.39603 .28079 m .41108 .28923 L .40168 .30197 L p .694 .677 .829 r
F P
0 g
s
.40168 .30197 m .38666 .29359 L .39603 .28079 L p .694 .677 .829 r
F P
0 g
s
.37759 .42415 m .38666 .29359 L .40168 .30197 L p .836 .479 .38 r
F P
0 g
s
.40168 .30197 m .39401 .4329 L .37759 .42415 L p .836 .479 .38 r
F P
0 g
s
.40424 .41959 m .39401 .4329 L .40168 .30197 L p .051 0 .265 r
F P
0 g
s
.40168 .30197 m .41108 .28923 L .40424 .41959 L p .051 0 .265 r
F P
0 g
s
.37682 .43519 m .38666 .29359 L .40168 .30197 L p .836 .479 .38 r
F P
0 g
s
.40168 .30197 m .39336 .44397 L .37682 .43519 L p .836 .479 .38 r
F P
0 g
s
.40424 .41959 m .39401 .4329 L .40168 .30197 L p .051 0 .265 r
F P
0 g
s
.40168 .30197 m .41108 .28923 L .40424 .41959 L p .051 0 .265 r
F P
0 g
s
.46013 .28048 m .47501 .28893 L .46534 .30167 L p .694 .677 .829 r
F P
0 g
s
.46534 .30167 m .4505 .29329 L .46013 .28048 L p .694 .677 .829 r
F P
0 g
s
.44782 .40221 m .4505 .29329 L .46534 .30167 L p .837 .474 .368 r
F P
0 g
s
.46534 .30167 m .4638 .41091 L .44782 .40221 L p .837 .474 .368 r
F P
0 g
s
.47421 .39769 m .4638 .41091 L .46534 .30167 L p .094 0 .298 r
F P
0 g
s
.46534 .30167 m .47501 .28893 L .47421 .39769 L p .094 0 .298 r
F P
0 g
s
.44674 .44608 m .4505 .29329 L .46534 .30167 L p .837 .474 .368 r
F P
0 g
s
.46534 .30167 m .46318 .45489 L .44674 .44608 L p .837 .474 .368 r
F P
0 g
s
.47389 .44149 m .46318 .45489 L .46534 .30167 L p .094 0 .298 r
F P
0 g
s
.46534 .30167 m .47501 .28893 L .47389 .44149 L p .094 0 .298 r
F P
0 g
s
.52425 .28018 m .53895 .28863 L .52902 .30137 L p .694 .677 .829 r
F P
0 g
s
.52902 .30137 m .51435 .29299 L .52425 .28018 L p .694 .677 .829 r
F P
0 g
s
.51722 .43456 m .53334 .44334 L .52249 .45658 L p .69 .69 .845 r
F P
0 g
s
.51745 .44576 m .51435 .29299 L .52902 .30137 L p .838 .469 .355 r
F P
0 g
s
.52902 .30137 m .53368 .45457 L .51745 .44576 L p .838 .469 .355 r
F P
0 g
s
.54471 .44117 m .53368 .45457 L .52902 .30137 L p .133 0 .328 r
F P
0 g
s
.52902 .30137 m .53895 .28863 L .54471 .44117 L p .133 0 .328 r
F P
0 g
s
.51722 .43456 m .51435 .29299 L .52902 .30137 L p .838 .469 .355 r
F P
0 g
s
.52902 .30137 m .53334 .44334 L .51722 .43456 L p .838 .469 .355 r
F P
0 g
s
.54471 .44117 m .53368 .45457 L .52902 .30137 L p .133 0 .328 r
F P
0 g
s
.52902 .30137 m .53895 .28863 L .54471 .44117 L p .133 0 .328 r
F P
0 g
s
.58838 .27987 m .60291 .28832 L .5927 .30107 L p .694 .677 .829 r
F P
0 g
s
.5927 .30107 m .57821 .29268 L .58838 .27987 L p .694 .677 .829 r
F P
0 g
s
.59443 .54116 m .57821 .29268 L .5927 .30107 L p .839 .463 .341 r
F P
0 g
s
.5927 .30107 m .6114 .5502 L .59443 .54116 L p .839 .463 .341 r
F P
0 g
s
.62348 .53645 m .6114 .5502 L .5927 .30107 L p .169 0 .354 r
F P
0 g
s
.5927 .30107 m .60291 .28832 L .62348 .53645 L p .169 0 .354 r
F P
0 g
s
.59611 .56694 m .57821 .29268 L .5927 .30107 L p .839 .463 .341 r
F P
0 g
s
.5927 .30107 m .61334 .57603 L .59611 .56694 L p .839 .463 .341 r
F P
0 g
s
.62348 .53645 m .6114 .5502 L .5927 .30107 L p .169 0 .354 r
F P
0 g
s
.5927 .30107 m .60291 .28832 L .62348 .53645 L p .169 0 .354 r
F P
0 g
s
.65252 .27957 m .66688 .28802 L .6564 .30077 L p .694 .677 .829 r
F P
0 g
s
.6564 .30077 m .64208 .29238 L .65252 .27957 L p .694 .677 .829 r
F P
0 g
s
.66672 .51583 m .64208 .29238 L .6564 .30077 L p .839 .457 .326 r
F P
0 g
s
.6564 .30077 m .68321 .52482 L .66672 .51583 L p .839 .457 .326 r
F P
0 g
s
.69546 .51115 m .68321 .52482 L .6564 .30077 L p .201 .006 .378 r
F P
0 g
s
.6564 .30077 m .66688 .28802 L .69546 .51115 L p .201 .006 .378 r
F P
0 g
s
.66809 .52824 m .64208 .29238 L .6564 .30077 L p .839 .457 .326 r
F P
0 g
s
.6564 .30077 m .6847 .53725 L .66809 .52824 L p .839 .457 .326 r
F P
0 g
s
.69546 .51115 m .68321 .52482 L .6564 .30077 L p .201 .006 .378 r
F P
0 g
s
.6564 .30077 m .66688 .28802 L .69546 .51115 L p .201 .006 .378 r
F P
0 g
s
.71668 .27926 m .73086 .28772 L .72011 .30047 L p .694 .677 .829 r
F P
0 g
s
.72011 .30047 m .70597 .29208 L .71668 .27926 L p .694 .677 .829 r
F P
0 g
s
.74454 .54051 m .70597 .29208 L .72011 .30047 L p .839 .45 .311 r
F P
0 g
s
.72011 .30047 m .76103 .54955 L .74454 .54051 L p .839 .45 .311 r
F P
0 g
s
.77386 .5358 m .76103 .54955 L .72011 .30047 L p .23 .037 .399 r
F P
0 g
s
.72011 .30047 m .73086 .28772 L .77386 .5358 L p .23 .037 .399 r
F P
0 g
s
.74454 .54051 m .70597 .29208 L .72011 .30047 L p .839 .45 .311 r
F P
0 g
s
.72011 .30047 m .76103 .54955 L .74454 .54051 L p .839 .45 .311 r
F P
0 g
s
.78292 .5881 m .76965 .60202 L .72011 .30047 L p .23 .037 .399 r
F P
0 g
s
.72011 .30047 m .73086 .28772 L .78292 .5881 L p .23 .037 .399 r
F P
0 g
s
.78085 .27896 m .79485 .28741 L .78384 .30016 L p .694 .677 .829 r
F P
0 g
s
.78384 .30016 m .76987 .29178 L .78085 .27896 L p .694 .677 .829 r
F P
0 g
s
.83012 .59253 m .76987 .29178 L .78384 .30016 L p .839 .442 .294 r
F P
0 g
s
.78384 .30016 m .84684 .60169 L .83012 .59253 L p .839 .442 .294 r
F P
0 g
s
.8605 .58776 m .84684 .60169 L .78384 .30016 L p .256 .065 .418 r
F P
0 g
s
.78384 .30016 m .79485 .28741 L .8605 .58776 L p .256 .065 .418 r
F P
0 g
s
.82743 .57914 m .76987 .29178 L .78384 .30016 L p .839 .442 .294 r
F P
0 g
s
.78384 .30016 m .84403 .58827 L .82743 .57914 L p .839 .442 .294 r
F P
0 g
s
.8605 .58776 m .84684 .60169 L .78384 .30016 L p .256 .065 .418 r
F P
0 g
s
.78384 .30016 m .79485 .28741 L .8605 .58776 L p .256 .065 .418 r
F P
0 g
s
.91431 .61963 m .83378 .29147 L .84758 .29986 L p .839 .434 .276 r
F P
0 g
s
.84758 .29986 m .93101 .62884 L .91431 .61963 L p .839 .434 .276 r
F P
0 g
s
.22805 .27731 m .24358 .28578 L .23487 .29854 L p .694 .677 .829 r
F P
0 g
s
.23487 .29854 m .21937 .29014 L .22805 .27731 L p .694 .677 .829 r
F P
0 g
s
.18425 .47732 m .21937 .29014 L .23487 .29854 L p .833 .49 .407 r
F P
0 g
s
.23487 .29854 m .20189 .48624 L .18425 .47732 L p .833 .49 .407 r
F P
0 g
s
.2116 .47268 m .20189 .48624 L .23487 .29854 L p 0 0 .156 r
F P
0 g
s
.23487 .29854 m .24358 .28578 L .2116 .47268 L p 0 0 .156 r
F P
0 g
s
.18202 .48918 m .21937 .29014 L .23487 .29854 L p .833 .49 .407 r
F P
0 g
s
.23487 .29854 m .1998 .49813 L .18202 .48918 L p .833 .49 .407 r
F P
0 g
s
.20957 .48452 m .1998 .49813 L .23487 .29854 L p 0 0 .156 r
F P
0 g
s
.23487 .29854 m .24358 .28578 L .20957 .48452 L p 0 0 .156 r
F P
0 g
s
.29221 .277 m .30757 .28547 L .29858 .29824 L p .694 .677 .829 r
F P
0 g
s
.29858 .29824 m .28326 .28984 L .29221 .277 L p .694 .677 .829 r
F P
0 g
s
.25488 .48886 m .28326 .28984 L .29858 .29824 L p .834 .486 .397 r
F P
0 g
s
.29858 .29824 m .27243 .4978 L .25488 .48886 L p .834 .486 .397 r
F P
0 g
s
.28255 .4842 m .27243 .4978 L .29858 .29824 L p 0 0 .2 r
F P
0 g
s
.29858 .29824 m .30757 .28547 L .28255 .4842 L p 0 0 .2 r
F P
0 g
s
.25488 .48886 m .28326 .28984 L .29858 .29824 L p .834 .486 .397 r
F P
0 g
s
.29858 .29824 m .27243 .4978 L .25488 .48886 L p .834 .486 .397 r
F P
0 g
s
.28104 .49622 m .27085 .50987 L .29858 .29824 L p 0 0 .2 r
F P
0 g
s
.29858 .29824 m .30757 .28547 L .28104 .49622 L p 0 0 .2 r
F P
0 g
s
.35638 .2767 m .37156 .28517 L .36231 .29794 L p .694 .677 .829 r
F P
0 g
s
.36231 .29794 m .34717 .28954 L .35638 .2767 L p .694 .677 .829 r
F P
0 g
s
.33337 .43094 m .34717 .28954 L .36231 .29794 L p .835 .482 .386 r
F P
0 g
s
.36231 .29794 m .35006 .43975 L .33337 .43094 L p .835 .482 .386 r
F P
0 g
s
.36018 .42636 m .35006 .43975 L .36231 .29794 L p .02 0 .24 r
F P
0 g
s
.36231 .29794 m .37156 .28517 L .36018 .42636 L p .02 0 .24 r
F P
0 g
s
.33228 .44213 m .34717 .28954 L .36231 .29794 L p .835 .482 .386 r
F P
0 g
s
.36231 .29794 m .34909 .45097 L .33228 .44213 L p .835 .482 .386 r
F P
0 g
s
.35928 .43753 m .34909 .45097 L .36231 .29794 L p .02 0 .24 r
F P
0 g
s
.36231 .29794 m .37156 .28517 L .35928 .43753 L p .02 0 .24 r
F P
0 g
s
.42057 .27639 m .43557 .28486 L .42605 .29764 L p .694 .677 .829 r
F P
0 g
s
.42605 .29764 m .41108 .28923 L .42057 .27639 L p .694 .677 .829 r
F P
0 g
s
.40424 .41959 m .41108 .28923 L .42605 .29764 L p .836 .477 .374 r
F P
0 g
s
.42605 .29764 m .42061 .42838 L .40424 .41959 L p .836 .477 .374 r
F P
0 g
s
.43098 .41503 m .42061 .42838 L .42605 .29764 L p .066 0 .276 r
F P
0 g
s
.42605 .29764 m .43557 .28486 L .43098 .41503 L p .066 0 .276 r
F P
0 g
s
.40424 .41959 m .41108 .28923 L .42605 .29764 L p .836 .477 .374 r
F P
0 g
s
.42605 .29764 m .42061 .42838 L .40424 .41959 L p .836 .477 .374 r
F P
0 g
s
.43059 .42604 m .42014 .43943 L .42605 .29764 L p .066 0 .276 r
F P
0 g
s
.42605 .29764 m .43557 .28486 L .43059 .42604 L p .066 0 .276 r
F P
0 g
s
.48476 .27609 m .4996 .28456 L .48981 .29733 L p .694 .677 .829 r
F P
0 g
s
.48981 .29733 m .47501 .28893 L .48476 .27609 L p .694 .677 .829 r
F P
0 g
s
.47397 .4303 m .47501 .28893 L .48981 .29733 L p .837 .472 .362 r
F P
0 g
s
.48981 .29733 m .49024 .43912 L .47397 .4303 L p .837 .472 .362 r
F P
0 g
s
.50101 .42572 m .49024 .43912 L .48981 .29733 L p .108 0 .308 r
F P
0 g
s
.48981 .29733 m .4996 .28456 L .50101 .42572 L p .108 0 .308 r
F P
0 g
s
.47389 .44149 m .47501 .28893 L .48981 .29733 L p .837 .472 .362 r
F P
0 g
s
.48981 .29733 m .49027 .45033 L .47389 .44149 L p .837 .472 .362 r
F P
0 g
s
.50112 .43689 m .49027 .45033 L .48981 .29733 L p .108 0 .308 r
F P
0 g
s
.48981 .29733 m .4996 .28456 L .50112 .43689 L p .108 0 .308 r
F P
0 g
s
.54898 .27578 m .56363 .28426 L .55358 .29703 L p .694 .677 .829 r
F P
0 g
s
.55358 .29703 m .53895 .28863 L .54898 .27578 L p .694 .677 .829 r
F P
0 g
s
.54471 .44117 m .53895 .28863 L .55358 .29703 L p .838 .466 .348 r
F P
0 g
s
.55358 .29703 m .56089 .45001 L .54471 .44117 L p .838 .466 .348 r
F P
0 g
s
.57206 .43657 m .56089 .45001 L .55358 .29703 L p .145 0 .337 r
F P
0 g
s
.55358 .29703 m .56363 .28426 L .57206 .43657 L p .145 0 .337 r
F P
0 g
s
.54471 .44117 m .53895 .28863 L .55358 .29703 L p .838 .466 .348 r
F P
0 g
s
.55358 .29703 m .56089 .45001 L .54471 .44117 L p .838 .466 .348 r
F P
0 g
s
.57805 .54482 m .56608 .55865 L .55358 .29703 L p .145 0 .337 r
F P
0 g
s
.55358 .29703 m .56363 .28426 L .57805 .54482 L p .145 0 .337 r
F P
0 g
s
.6132 .27547 m .62768 .28395 L .61736 .29673 L p .694 .677 .829 r
F P
0 g
s
.61736 .29673 m .60291 .28832 L .6132 .27547 L p .694 .677 .829 r
F P
0 g
s
.62244 .52387 m .60291 .28832 L .61736 .29673 L p .839 .46 .334 r
F P
0 g
s
.61736 .29673 m .63922 .53291 L .62244 .52387 L p .839 .46 .334 r
F P
0 g
s
.65137 .51916 m .63922 .53291 L .61736 .29673 L p .18 0 .362 r
F P
0 g
s
.61736 .29673 m .62768 .28395 L .65137 .51916 L p .18 0 .362 r
F P
0 g
s
.62348 .53645 m .60291 .28832 L .61736 .29673 L p .839 .46 .334 r
F P
0 g
s
.61736 .29673 m .64039 .54552 L .62348 .53645 L p .839 .46 .334 r
F P
0 g
s
.65264 .53173 m .64039 .54552 L .61736 .29673 L p .18 0 .362 r
F P
0 g
s
.61736 .29673 m .62768 .28395 L .65264 .53173 L p .18 0 .362 r
F P
0 g
s
.67744 .27517 m .69174 .28365 L .68115 .29643 L p .694 .677 .829 r
F P
0 g
s
.68115 .29643 m .66688 .28802 L .67744 .27517 L p .694 .677 .829 r
F P
0 g
s
.69546 .51115 m .66688 .28802 L .68115 .29643 L p .839 .453 .319 r
F P
0 g
s
.68115 .29643 m .71189 .52017 L .69546 .51115 L p .839 .453 .319 r
F P
0 g
s
.7243 .50646 m .71189 .52017 L .68115 .29643 L p .211 .017 .385 r
F P
0 g
s
.68115 .29643 m .69174 .28365 L .7243 .50646 L p .211 .017 .385 r
F P
0 g
s
.69546 .51115 m .66688 .28802 L .68115 .29643 L p .839 .453 .319 r
F P
0 g
s
.68115 .29643 m .71189 .52017 L .69546 .51115 L p .839 .453 .319 r
F P
0 g
s
.72611 .51883 m .71359 .53259 L .68115 .29643 L p .211 .017 .385 r
F P
0 g
s
.68115 .29643 m .69174 .28365 L .72611 .51883 L p .211 .017 .385 r
F P
0 g
s
.74169 .27486 m .75582 .28334 L .74495 .29613 L p .694 .677 .829 r
F P
0 g
s
.74495 .29613 m .73086 .28772 L .74169 .27486 L p .694 .677 .829 r
F P
0 g
s
.78061 .57472 m .73086 .28772 L .74495 .29613 L p .84 .446 .302 r
F P
0 g
s
.74495 .29613 m .79739 .58387 L .78061 .57472 L p .84 .446 .302 r
F P
0 g
s
.81072 .56995 m .79739 .58387 L .74495 .29613 L p .239 .047 .406 r
F P
0 g
s
.74495 .29613 m .75582 .28334 L .81072 .56995 L p .239 .047 .406 r
F P
0 g
s
.78292 .5881 m .73086 .28772 L .74495 .29613 L p .84 .446 .302 r
F P
0 g
s
.74495 .29613 m .79983 .59728 L .78292 .5881 L p .84 .446 .302 r
F P
0 g
s
.81328 .58331 m .79983 .59728 L .74495 .29613 L p .239 .047 .406 r
F P
0 g
s
.74495 .29613 m .75582 .28334 L .81328 .58331 L p .239 .047 .406 r
F P
0 g
s
.80595 .27456 m .8199 .28304 L .80877 .29583 L p .694 .677 .829 r
F P
0 g
s
.80877 .29583 m .79485 .28741 L .80595 .27456 L p .694 .677 .829 r
F P
0 g
s
.8605 .58776 m .79485 .28741 L .80877 .29583 L p .839 .438 .285 r
F P
0 g
s
.80877 .29583 m .87715 .59695 L .8605 .58776 L p .839 .438 .285 r
F P
0 g
s
.891 .58298 m .87715 .59695 L .80877 .29583 L p .264 .074 .424 r
F P
0 g
s
.80877 .29583 m .8199 .28304 L .891 .58298 L p .264 .074 .424 r
F P
0 g
s
.8605 .58776 m .79485 .28741 L .80877 .29583 L p .839 .438 .285 r
F P
0 g
s
.80877 .29583 m .87715 .59695 L .8605 .58776 L p .839 .438 .285 r
F P
0 g
s
.89422 .59656 m .88025 .61057 L .80877 .29583 L p .264 .074 .424 r
F P
0 g
s
.80877 .29583 m .8199 .28304 L .89422 .59656 L p .264 .074 .424 r
F P
0 g
s
.25237 .27291 m .26786 .2814 L .25903 .2942 L p .694 .677 .829 r
F P
0 g
s
.25903 .2942 m .24358 .28578 L .25237 .27291 L p .694 .677 .829 r
F P
0 g
s
.2136 .46101 m .24358 .28578 L .25903 .2942 L p .833 .488 .402 r
F P
0 g
s
.25903 .2942 m .23105 .46993 L .2136 .46101 L p .833 .488 .402 r
F P
0 g
s
.24084 .45637 m .23105 .46993 L .25903 .2942 L p 0 0 .171 r
F P
0 g
s
.25903 .2942 m .26786 .2814 L .24084 .45637 L p 0 0 .171 r
F P
0 g
s
.20957 .48452 m .24358 .28578 L .25903 .2942 L p .833 .488 .402 r
F P
0 g
s
.25903 .2942 m .22729 .4935 L .20957 .48452 L p .833 .488 .402 r
F P
0 g
s
.23722 .47985 m .22729 .4935 L .25903 .2942 L p 0 0 .171 r
F P
0 g
s
.25903 .2942 m .26786 .2814 L .23722 .47985 L p 0 0 .171 r
F P
0 g
s
.31662 .2726 m .33194 .28109 L .32284 .29389 L p .694 .677 .829 r
F P
0 g
s
.32284 .29389 m .30757 .28547 L .31662 .2726 L p .694 .677 .829 r
F P
0 g
s
.28839 .43785 m .30757 .28547 L .32284 .29389 L p .835 .484 .391 r
F P
0 g
s
.32284 .29389 m .30536 .44671 L .28839 .43785 L p .835 .484 .391 r
F P
0 g
s
.31536 .43324 m .30536 .44671 L .32284 .29389 L p 0 0 .214 r
F P
0 g
s
.32284 .29389 m .33194 .28109 L .31536 .43324 L p 0 0 .214 r
F P
0 g
s
.28104 .49622 m .30757 .28547 L .32284 .29389 L p .835 .484 .391 r
F P
0 g
s
.32284 .29389 m .29867 .50522 L .28104 .49622 L p .835 .484 .391 r
F P
0 g
s
.31536 .43324 m .30536 .44671 L .32284 .29389 L p 0 0 .214 r
F P
0 g
s
.32284 .29389 m .33194 .28109 L .31536 .43324 L p 0 0 .214 r
F P
0 g
s
.38089 .27229 m .39603 .28079 L .38666 .29359 L p .694 .677 .829 r
F P
0 g
s
.38666 .29359 m .37156 .28517 L .38089 .27229 L p .694 .677 .829 r
F P
0 g
s
.35928 .43753 m .37156 .28517 L .38666 .29359 L p .836 .479 .38 r
F P
0 g
s
.38666 .29359 m .37604 .44639 L .35928 .43753 L p .836 .479 .38 r
F P
0 g
s
.39401 .4329 m .37759 .42415 L .38778 .41076 L p .69 .689 .844 r
F P
0 g
s
.37682 .43519 m .39336 .44397 L .38315 .4572 L p .69 .69 .845 r
F P
0 g
s
.38637 .43292 m .37604 .44639 L .38666 .29359 L p .036 0 .253 r
F P
0 g
s
.38666 .29359 m .39603 .28079 L .38637 .43292 L p .036 0 .253 r
F P
0 g
s
.35928 .43753 m .37156 .28517 L .38666 .29359 L p .836 .479 .38 r
F P
0 g
s
.38666 .29359 m .37604 .44639 L .35928 .43753 L p .836 .479 .38 r
F P
0 g
s
.38778 .41076 m .37759 .42415 L .38666 .29359 L p .036 0 .253 r
F P
0 g
s
.38666 .29359 m .39603 .28079 L .38778 .41076 L p .036 0 .253 r
F P
0 g
s
.44517 .27199 m .46013 .28048 L .4505 .29329 L p .694 .677 .829 r
F P
0 g
s
.4505 .29329 m .43557 .28486 L .44517 .27199 L p .694 .677 .829 r
F P
0 g
s
.43174 .39346 m .43557 .28486 L .4505 .29329 L p .837 .474 .368 r
F P
0 g
s
.4505 .29329 m .44782 .40221 L .43174 .39346 L p .837 .474 .368 r
F P
0 g
s
.45818 .38891 m .44782 .40221 L .4505 .29329 L p .08 0 .287 r
F P
0 g
s
.4505 .29329 m .46013 .28048 L .45818 .38891 L p .08 0 .287 r
F P
0 g
s
.43059 .42604 m .43557 .28486 L .4505 .29329 L p .837 .474 .368 r
F P
0 g
s
.4505 .29329 m .44701 .43488 L .43059 .42604 L p .837 .474 .368 r
F P
0 g
s
.45818 .38891 m .44782 .40221 L .4505 .29329 L p .08 0 .287 r
F P
0 g
s
.4505 .29329 m .46013 .28048 L .45818 .38891 L p .08 0 .287 r
F P
0 g
s
.50947 .27168 m .52425 .28018 L .51435 .29299 L p .694 .677 .829 r
F P
0 g
s
.51435 .29299 m .4996 .28456 L .50947 .27168 L p .694 .677 .829 r
F P
0 g
s
.5009 .41471 m .4996 .28456 L .51435 .29299 L p .838 .469 .355 r
F P
0 g
s
.51435 .29299 m .517 .42352 L .5009 .41471 L p .838 .469 .355 r
F P
0 g
s
.52783 .41012 m .517 .42352 L .51435 .29299 L p .121 0 .318 r
F P
0 g
s
.51435 .29299 m .52425 .28018 L .52783 .41012 L p .121 0 .318 r
F P
0 g
s
.50112 .43689 m .4996 .28456 L .51435 .29299 L p .838 .469 .355 r
F P
0 g
s
.51435 .29299 m .51745 .44576 L .50112 .43689 L p .838 .469 .355 r
F P
0 g
s
.52844 .43227 m .51745 .44576 L .51435 .29299 L p .121 0 .318 r
F P
0 g
s
.51435 .29299 m .52425 .28018 L .52844 .43227 L p .121 0 .318 r
F P
0 g
s
.57377 .27137 m .58838 .27987 L .57821 .29268 L p .694 .677 .829 r
F P
0 g
s
.57821 .29268 m .56363 .28426 L .57377 .27137 L p .694 .677 .829 r
F P
0 g
s
.57735 .53206 m .56363 .28426 L .57821 .29268 L p .839 .463 .341 r
F P
0 g
s
.57821 .29268 m .59443 .54116 L .57735 .53206 L p .839 .463 .341 r
F P
0 g
s
.60647 .52732 m .59443 .54116 L .57821 .29268 L p .157 0 .346 r
F P
0 g
s
.57821 .29268 m .58838 .27987 L .60647 .52732 L p .157 0 .346 r
F P
0 g
s
.57805 .54482 m .56363 .28426 L .57821 .29268 L p .839 .463 .341 r
F P
0 g
s
.57821 .29268 m .59526 .55395 L .57805 .54482 L p .839 .463 .341 r
F P
0 g
s
.60647 .52732 m .59443 .54116 L .57821 .29268 L p .157 0 .346 r
F P
0 g
s
.57821 .29268 m .58838 .27987 L .60647 .52732 L p .157 0 .346 r
F P
0 g
s
.63809 .27107 m .65252 .27957 L .64208 .29238 L p .694 .677 .829 r
F P
0 g
s
.64208 .29238 m .62768 .28395 L .63809 .27107 L p .694 .677 .829 r
F P
0 g
s
.65264 .53173 m .62768 .28395 L .64208 .29238 L p .839 .457 .326 r
F P
0 g
s
.64208 .29238 m .66948 .54083 L .65264 .53173 L p .839 .457 .326 r
F P
0 g
s
.68321 .52482 m .66672 .51583 L .67893 .50207 L p .687 .698 .854 r
F P
0 g
s
.66809 .52824 m .6847 .53725 L .67246 .55083 L p .687 .699 .856 r
F P
0 g
s
.68189 .52699 m .66948 .54083 L .64208 .29238 L p .19 0 .37 r
F P
0 g
s
.64208 .29238 m .65252 .27957 L .68189 .52699 L p .19 0 .37 r
F P
0 g
s
.65264 .53173 m .62768 .28395 L .64208 .29238 L p .839 .457 .326 r
F P
0 g
s
.64208 .29238 m .66948 .54083 L .65264 .53173 L p .839 .457 .326 r
F P
0 g
s
.67893 .50207 m .66672 .51583 L .64208 .29238 L p .19 0 .37 r
F P
0 g
s
.64208 .29238 m .65252 .27957 L .67893 .50207 L p .19 0 .37 r
F P
0 g
s
.70242 .27076 m .71668 .27926 L .70597 .29208 L p .694 .677 .829 r
F P
0 g
s
.70597 .29208 m .69174 .28365 L .70242 .27076 L p .694 .677 .829 r
F P
0 g
s
.72611 .51883 m .74259 .52791 L .73003 .54158 L p .687 .699 .856 r
F P
0 g
s
.73003 .54158 m .71359 .53259 L .72611 .51883 L p .687 .699 .856 r
F P
0 g
s
.72795 .5314 m .69174 .28365 L .70597 .29208 L p .839 .45 .311 r
F P
0 g
s
.70597 .29208 m .74454 .54051 L .72795 .5314 L p .839 .45 .311 r
F P
0 g
s
.75733 .52666 m .74454 .54051 L .70597 .29208 L p .22 .027 .392 r
F P
0 g
s
.70597 .29208 m .71668 .27926 L .75733 .52666 L p .22 .027 .392 r
F P
0 g
s
.72611 .51883 m .69174 .28365 L .70597 .29208 L p .839 .45 .311 r
F P
0 g
s
.70597 .29208 m .74259 .52791 L .72611 .51883 L p .839 .45 .311 r
F P
0 g
s
.75733 .52666 m .74454 .54051 L .70597 .29208 L p .22 .027 .392 r
F P
0 g
s
.70597 .29208 m .71668 .27926 L .75733 .52666 L p .22 .027 .392 r
F P
0 g
s
.76677 .27045 m .78085 .27896 L .76987 .29178 L p .694 .677 .829 r
F P
0 g
s
.76987 .29178 m .75582 .28334 L .76677 .27045 L p .694 .677 .829 r
F P
0 g
s
.8082 .55679 m .75582 .28334 L .76987 .29178 L p .839 .442 .294 r
F P
0 g
s
.76987 .29178 m .82479 .56595 L .8082 .55679 L p .839 .442 .294 r
F P
0 g
s
.83818 .55202 m .82479 .56595 L .76987 .29178 L p .248 .056 .412 r
F P
0 g
s
.76987 .29178 m .78085 .27896 L .83818 .55202 L p .248 .056 .412 r
F P
0 g
s
.81328 .58331 m .75582 .28334 L .76987 .29178 L p .839 .442 .294 r
F P
0 g
s
.76987 .29178 m .83012 .59253 L .81328 .58331 L p .839 .442 .294 r
F P
0 g
s
.84374 .57851 m .83012 .59253 L .76987 .29178 L p .248 .056 .412 r
F P
0 g
s
.76987 .29178 m .78085 .27896 L .84374 .57851 L p .248 .056 .412 r
F P
0 g
s
.89422 .59656 m .8199 .28304 L .83378 .29147 L p .839 .434 .276 r
F P
0 g
s
.83378 .29147 m .91091 .60581 L .89422 .59656 L p .839 .434 .276 r
F P
0 g
s
.19391 .46367 m .18425 .47732 L .21937 .29014 L p 0 0 .14 r
F P
0 g
s
.21937 .29014 m .22805 .27731 L .19391 .46367 L p 0 0 .14 r
F P
0 g
s
.27676 .26849 m .29221 .277 L .28326 .28984 L p .694 .677 .829 r
F P
0 g
s
.28326 .28984 m .26786 .2814 L .27676 .26849 L p .694 .677 .829 r
F P
0 g
s
.23904 .46802 m .26786 .2814 L .28326 .28984 L p .834 .486 .397 r
F P
0 g
s
.28326 .28984 m .25657 .477 L .23904 .46802 L p .834 .486 .397 r
F P
0 g
s
.26657 .46335 m .25657 .477 L .28326 .28984 L p 0 0 .186 r
F P
0 g
s
.28326 .28984 m .29221 .277 L .26657 .46335 L p 0 0 .186 r
F P
0 g
s
.23722 .47985 m .26786 .2814 L .28326 .28984 L p .834 .486 .397 r
F P
0 g
s
.28326 .28984 m .25488 .48886 L .23722 .47985 L p .834 .486 .397 r
F P
0 g
s
.26495 .47516 m .25488 .48886 L .28326 .28984 L p 0 0 .186 r
F P
0 g
s
.28326 .28984 m .29221 .277 L .26495 .47516 L p 0 0 .186 r
F P
0 g
s
.34111 .26818 m .35638 .2767 L .34717 .28954 L p .694 .677 .829 r
F P
0 g
s
.34717 .28954 m .33194 .28109 L .34111 .26818 L p .694 .677 .829 r
F P
0 g
s
.31536 .43324 m .33194 .28109 L .34717 .28954 L p .835 .482 .386 r
F P
0 g
s
.34717 .28954 m .33228 .44213 L .31536 .43324 L p .835 .482 .386 r
F P
0 g
s
.35006 .43975 m .33337 .43094 L .34344 .41747 L p .69 .69 .845 r
F P
0 g
s
.34242 .42861 m .33228 .44213 L .34717 .28954 L p .004 0 .228 r
F P
0 g
s
.34717 .28954 m .35638 .2767 L .34242 .42861 L p .004 0 .228 r
F P
0 g
s
.31536 .43324 m .33194 .28109 L .34717 .28954 L p .835 .482 .386 r
F P
0 g
s
.34717 .28954 m .33228 .44213 L .31536 .43324 L p .835 .482 .386 r
F P
0 g
s
.34344 .41747 m .33337 .43094 L .34717 .28954 L p .004 0 .228 r
F P
0 g
s
.34717 .28954 m .35638 .2767 L .34344 .41747 L p .004 0 .228 r
F P
0 g
s
.40548 .26787 m .42057 .27639 L .41108 .28923 L p .694 .677 .829 r
F P
0 g
s
.41108 .28923 m .39603 .28079 L .40548 .26787 L p .694 .677 .829 r
F P
0 g
s
.38847 .39992 m .39603 .28079 L .41108 .28923 L p .836 .477 .374 r
F P
0 g
s
.41108 .28923 m .40481 .40872 L .38847 .39992 L p .836 .477 .374 r
F P
0 g
s
.41507 .39534 m .40481 .40872 L .41108 .28923 L p .051 0 .265 r
F P
0 g
s
.41108 .28923 m .42057 .27639 L .41507 .39534 L p .051 0 .265 r
F P
0 g
s
.38778 .41076 m .39603 .28079 L .41108 .28923 L p .836 .477 .374 r
F P
0 g
s
.41108 .28923 m .40424 .41959 L .38778 .41076 L p .836 .477 .374 r
F P
0 g
s
.41457 .40616 m .40424 .41959 L .41108 .28923 L p .051 0 .265 r
F P
0 g
s
.41108 .28923 m .42057 .27639 L .41457 .40616 L p .051 0 .265 r
F P
0 g
s
.46985 .26757 m .48476 .27609 L .47501 .28893 L p .694 .677 .829 r
F P
0 g
s
.47501 .28893 m .46013 .28048 L .46985 .26757 L p .694 .677 .829 r
F P
0 g
s
.45818 .38891 m .46013 .28048 L .47501 .28893 L p .837 .472 .362 r
F P
0 g
s
.47501 .28893 m .47421 .39769 L .45818 .38891 L p .837 .472 .362 r
F P
0 g
s
.48471 .38434 m .47421 .39769 L .47501 .28893 L p .094 0 .298 r
F P
0 g
s
.47501 .28893 m .48476 .27609 L .48471 .38434 L p .094 0 .298 r
F P
0 g
s
.45818 .38891 m .46013 .28048 L .47501 .28893 L p .837 .472 .362 r
F P
0 g
s
.47501 .28893 m .47421 .39769 L .45818 .38891 L p .837 .472 .362 r
F P
0 g
s
.48469 .41683 m .47397 .4303 L .47501 .28893 L p .094 0 .298 r
F P
0 g
s
.47501 .28893 m .48476 .27609 L .48469 .41683 L p .094 0 .298 r
F P
0 g
s
.53424 .26726 m .54898 .27578 L .53895 .28863 L p .694 .677 .829 r
F P
0 g
s
.53895 .28863 m .52425 .28018 L .53424 .26726 L p .694 .677 .829 r
F P
0 g
s
.52813 .42112 m .52425 .28018 L .53895 .28863 L p .838 .466 .348 r
F P
0 g
s
.53895 .28863 m .54429 .42999 L .52813 .42112 L p .838 .466 .348 r
F P
0 g
s
.55534 .41651 m .54429 .42999 L .53895 .28863 L p .133 0 .328 r
F P
0 g
s
.53895 .28863 m .54898 .27578 L .55534 .41651 L p .133 0 .328 r
F P
0 g
s
.52844 .43227 m .52425 .28018 L .53895 .28863 L p .838 .466 .348 r
F P
0 g
s
.53895 .28863 m .54471 .44117 L .52844 .43227 L p .838 .466 .348 r
F P
0 g
s
.55585 .42764 m .54471 .44117 L .53895 .28863 L p .133 0 .328 r
F P
0 g
s
.53895 .28863 m .54898 .27578 L .55585 .42764 L p .133 0 .328 r
F P
0 g
s
.59864 .26695 m .6132 .27547 L .60291 .28832 L p .694 .677 .829 r
F P
0 g
s
.60291 .28832 m .58838 .27987 L .59864 .26695 L p .694 .677 .829 r
F P
0 g
s
.60647 .52732 m .58838 .27987 L .60291 .28832 L p .839 .46 .334 r
F P
0 g
s
.60291 .28832 m .62348 .53645 L .60647 .52732 L p .839 .46 .334 r
F P
0 g
s
.63922 .53291 m .62244 .52387 L .63455 .51003 L p .687 .699 .856 r
F P
0 g
s
.63569 .52257 m .62348 .53645 L .60291 .28832 L p .169 0 .354 r
F P
0 g
s
.60291 .28832 m .6132 .27547 L .63569 .52257 L p .169 0 .354 r
F P
0 g
s
.60647 .52732 m .58838 .27987 L .60291 .28832 L p .839 .46 .334 r
F P
0 g
s
.60291 .28832 m .62348 .53645 L .60647 .52732 L p .839 .46 .334 r
F P
0 g
s
.63455 .51003 m .62244 .52387 L .60291 .28832 L p .169 0 .354 r
F P
0 g
s
.60291 .28832 m .6132 .27547 L .63455 .51003 L p .169 0 .354 r
F P
0 g
s
.66306 .26664 m .67744 .27517 L .66688 .28802 L p .694 .677 .829 r
F P
0 g
s
.66688 .28802 m .65252 .27957 L .66306 .26664 L p .694 .677 .829 r
F P
0 g
s
.67749 .4899 m .65252 .27957 L .66688 .28802 L p .839 .453 .319 r
F P
0 g
s
.66688 .28802 m .6939 .49894 L .67749 .4899 L p .839 .453 .319 r
F P
0 g
s
.70617 .48519 m .6939 .49894 L .66688 .28802 L p .201 .006 .378 r
F P
0 g
s
.66688 .28802 m .67744 .27517 L .70617 .48519 L p .201 .006 .378 r
F P
0 g
s
.67893 .50207 m .65252 .27957 L .66688 .28802 L p .839 .453 .319 r
F P
0 g
s
.66688 .28802 m .69546 .51115 L .67893 .50207 L p .839 .453 .319 r
F P
0 g
s
.70784 .49735 m .69546 .51115 L .66688 .28802 L p .201 .006 .378 r
F P
0 g
s
.66688 .28802 m .67744 .27517 L .70784 .49735 L p .201 .006 .378 r
F P
0 g
s
.72748 .26633 m .74169 .27486 L .73086 .28772 L p .694 .677 .829 r
F P
0 g
s
.73086 .28772 m .71668 .27926 L .72748 .26633 L p .694 .677 .829 r
F P
0 g
s
.75733 .52666 m .71668 .27926 L .73086 .28772 L p .84 .446 .302 r
F P
0 g
s
.73086 .28772 m .77386 .5358 L .75733 .52666 L p .84 .446 .302 r
F P
0 g
s
.78681 .52191 m .77386 .5358 L .73086 .28772 L p .23 .037 .399 r
F P
0 g
s
.73086 .28772 m .74169 .27486 L .78681 .52191 L p .23 .037 .399 r
F P
0 g
s
.75733 .52666 m .71668 .27926 L .73086 .28772 L p .84 .446 .302 r
F P
0 g
s
.73086 .28772 m .77386 .5358 L .75733 .52666 L p .84 .446 .302 r
F P
0 g
s
.7939 .56069 m .78061 .57472 L .73086 .28772 L p .23 .037 .399 r
F P
0 g
s
.73086 .28772 m .74169 .27486 L .7939 .56069 L p .23 .037 .399 r
F P
0 g
s
.79192 .26603 m .80595 .27456 L .79485 .28741 L p .694 .677 .829 r
F P
0 g
s
.79485 .28741 m .78085 .27896 L .79192 .26603 L p .694 .677 .829 r
F P
0 g
s
.84094 .56516 m .78085 .27896 L .79485 .28741 L p .839 .438 .285 r
F P
0 g
s
.79485 .28741 m .85758 .57438 L .84094 .56516 L p .839 .438 .285 r
F P
0 g
s
.87126 .56036 m .85758 .57438 L .79485 .28741 L p .256 .065 .418 r
F P
0 g
s
.79485 .28741 m .80595 .27456 L .87126 .56036 L p .256 .065 .418 r
F P
0 g
s
.84374 .57851 m .78085 .27896 L .79485 .28741 L p .839 .438 .285 r
F P
0 g
s
.79485 .28741 m .8605 .58776 L .84374 .57851 L p .839 .438 .285 r
F P
0 g
s
.87431 .5737 m .8605 .58776 L .79485 .28741 L p .256 .065 .418 r
F P
0 g
s
.79485 .28741 m .80595 .27456 L .87431 .5737 L p .256 .065 .418 r
F P
0 g
s
.23679 .26437 m .25237 .27291 L .24358 .28578 L p .694 .677 .829 r
F P
0 g
s
.24358 .28578 m .22805 .27731 L .23679 .26437 L p .694 .677 .829 r
F P
0 g
s
.19604 .45203 m .22805 .27731 L .24358 .28578 L p .833 .488 .402 r
F P
0 g
s
.24358 .28578 m .2136 .46101 L .19604 .45203 L p .833 .488 .402 r
F P
0 g
s
.22334 .44736 m .2136 .46101 L .24358 .28578 L p 0 0 .156 r
F P
0 g
s
.24358 .28578 m .25237 .27291 L .22334 .44736 L p 0 0 .156 r
F P
0 g
s
.19391 .46367 m .22805 .27731 L .24358 .28578 L p .833 .488 .402 r
F P
0 g
s
.24358 .28578 m .2116 .47268 L .19391 .46367 L p .833 .488 .402 r
F P
0 g
s
.22334 .44736 m .2136 .46101 L .24358 .28578 L p 0 0 .156 r
F P
0 g
s
.24358 .28578 m .25237 .27291 L .22334 .44736 L p 0 0 .156 r
F P
0 g
s
.30123 .26406 m .31662 .2726 L .30757 .28547 L p .694 .677 .829 r
F P
0 g
s
.30757 .28547 m .29221 .277 L .30123 .26406 L p .694 .677 .829 r
F P
0 g
s
.27131 .42893 m .29221 .277 L .30757 .28547 L p .835 .484 .391 r
F P
0 g
s
.30757 .28547 m .28839 .43785 L .27131 .42893 L p .835 .484 .391 r
F P
0 g
s
.29834 .42429 m .28839 .43785 L .30757 .28547 L p 0 0 .2 r
F P
0 g
s
.30757 .28547 m .31662 .2726 L .29834 .42429 L p 0 0 .2 r
F P
0 g
s
.26495 .47516 m .29221 .277 L .30757 .28547 L p .835 .484 .391 r
F P
0 g
s
.30757 .28547 m .28255 .4842 L .26495 .47516 L p .835 .484 .391 r
F P
0 g
s
.29834 .42429 m .28839 .43785 L .30757 .28547 L p 0 0 .2 r
F P
0 g
s
.30757 .28547 m .31662 .2726 L .29834 .42429 L p 0 0 .2 r
F P
0 g
s
.36567 .26375 m .38089 .27229 L .37156 .28517 L p .694 .677 .829 r
F P
0 g
s
.37156 .28517 m .35638 .2767 L .36567 .26375 L p .694 .677 .829 r
F P
0 g
s
.34344 .41747 m .36018 .42636 L .35006 .43975 L p .69 .69 .845 r
F P
0 g
s
.34242 .42861 m .35638 .2767 L .37156 .28517 L p .836 .479 .38 r
F P
0 g
s
.37156 .28517 m .35928 .43753 L .34242 .42861 L p .836 .479 .38 r
F P
0 g
s
.36956 .42397 m .35928 .43753 L .37156 .28517 L p .02 0 .24 r
F P
0 g
s
.37156 .28517 m .38089 .27229 L .36956 .42397 L p .02 0 .24 r
F P
0 g
s
.34344 .41747 m .35638 .2767 L .37156 .28517 L p .836 .479 .38 r
F P
0 g
s
.37156 .28517 m .36018 .42636 L .34344 .41747 L p .836 .479 .38 r
F P
0 g
s
.36956 .42397 m .35928 .43753 L .37156 .28517 L p .02 0 .24 r
F P
0 g
s
.37156 .28517 m .38089 .27229 L .36956 .42397 L p .02 0 .24 r
F P
0 g
s
.43013 .26344 m .44517 .27199 L .43557 .28486 L p .694 .677 .829 r
F P
0 g
s
.43557 .28486 m .42057 .27639 L .43013 .26344 L p .694 .677 .829 r
F P
0 g
s
.41556 .38466 m .42057 .27639 L .43557 .28486 L p .837 .474 .368 r
F P
0 g
s
.43557 .28486 m .43174 .39346 L .41556 .38466 L p .837 .474 .368 r
F P
0 g
s
.44206 .38008 m .43174 .39346 L .43557 .28486 L p .066 0 .276 r
F P
0 g
s
.43557 .28486 m .44517 .27199 L .44206 .38008 L p .066 0 .276 r
F P
0 g
s
.41457 .40616 m .42057 .27639 L .43557 .28486 L p .837 .474 .368 r
F P
0 g
s
.43557 .28486 m .43098 .41503 L .41457 .40616 L p .837 .474 .368 r
F P
0 g
s
.44206 .38008 m .43174 .39346 L .43557 .28486 L p .066 0 .276 r
F P
0 g
s
.43557 .28486 m .44517 .27199 L .44206 .38008 L p .066 0 .276 r
F P
0 g
s
.4946 .26313 m .50947 .27168 L .4996 .28456 L p .694 .677 .829 r
F P
0 g
s
.4996 .28456 m .48476 .27609 L .4946 .26313 L p .694 .677 .829 r
F P
0 g
s
.4847 .40584 m .48476 .27609 L .4996 .28456 L p .838 .469 .355 r
F P
0 g
s
.4996 .28456 m .5009 .41471 L .4847 .40584 L p .838 .469 .355 r
F P
0 g
s
.51169 .40123 m .5009 .41471 L .4996 .28456 L p .108 0 .308 r
F P
0 g
s
.4996 .28456 m .50947 .27168 L .51169 .40123 L p .108 0 .308 r
F P
0 g
s
.48469 .41683 m .48476 .27609 L .4996 .28456 L p .838 .469 .355 r
F P
0 g
s
.4996 .28456 m .50101 .42572 L .48469 .41683 L p .838 .469 .355 r
F P
0 g
s
.51169 .40123 m .5009 .41471 L .4996 .28456 L p .108 0 .308 r
F P
0 g
s
.4996 .28456 m .50947 .27168 L .51169 .40123 L p .108 0 .308 r
F P
0 g
s
.55908 .26282 m .57377 .27137 L .56363 .28426 L p .694 .677 .829 r
F P
0 g
s
.56363 .28426 m .54898 .27578 L .55908 .26282 L p .694 .677 .829 r
F P
0 g
s
.55585 .42764 m .54898 .27578 L .56363 .28426 L p .839 .463 .341 r
F P
0 g
s
.56363 .28426 m .57206 .43657 L .55585 .42764 L p .839 .463 .341 r
F P
0 g
s
.58334 .423 m .57206 .43657 L .56363 .28426 L p .145 0 .337 r
F P
0 g
s
.56363 .28426 m .57377 .27137 L .58334 .423 L p .145 0 .337 r
F P
0 g
s
.55585 .42764 m .54898 .27578 L .56363 .28426 L p .839 .463 .341 r
F P
0 g
s
.56363 .28426 m .57206 .43657 L .55585 .42764 L p .839 .463 .341 r
F P
0 g
s
.58935 .51813 m .57735 .53206 L .56363 .28426 L p .145 0 .337 r
F P
0 g
s
.56363 .28426 m .57377 .27137 L .58935 .51813 L p .145 0 .337 r
F P
0 g
s
.62358 .26252 m .63809 .27107 L .62768 .28395 L p .694 .677 .829 r
F P
0 g
s
.62768 .28395 m .6132 .27547 L .62358 .26252 L p .694 .677 .829 r
F P
0 g
s
.63455 .51003 m .65137 .51916 L .63922 .53291 L p .687 .699 .856 r
F P
0 g
s
.63569 .52257 m .6132 .27547 L .62768 .28395 L p .839 .457 .326 r
F P
0 g
s
.62768 .28395 m .65264 .53173 L .63569 .52257 L p .839 .457 .326 r
F P
0 g
s
.66501 .5178 m .65264 .53173 L .62768 .28395 L p .18 0 .362 r
F P
0 g
s
.62768 .28395 m .63809 .27107 L .66501 .5178 L p .18 0 .362 r
F P
0 g
s
.63455 .51003 m .6132 .27547 L .62768 .28395 L p .839 .457 .326 r
F P
0 g
s
.62768 .28395 m .65137 .51916 L .63455 .51003 L p .839 .457 .326 r
F P
0 g
s
.66501 .5178 m .65264 .53173 L .62768 .28395 L p .18 0 .362 r
F P
0 g
s
.62768 .28395 m .63809 .27107 L .66501 .5178 L p .18 0 .362 r
F P
0 g
s
.68809 .26221 m .70242 .27076 L .69174 .28365 L p .694 .677 .829 r
F P
0 g
s
.69174 .28365 m .67744 .27517 L .68809 .26221 L p .694 .677 .829 r
F P
0 g
s
.69546 .51115 m .71189 .52017 L .69959 .53375 L p .687 .698 .854 r
F P
0 g
s
.70784 .49735 m .7243 .50646 L .71189 .52017 L p .687 .698 .854 r
F P
0 g
s
.71189 .52017 m .69546 .51115 L .70784 .49735 L p .687 .698 .854 r
F P
0 g
s
.71124 .52224 m .67744 .27517 L .69174 .28365 L p .839 .45 .311 r
F P
0 g
s
.69174 .28365 m .72795 .5314 L .71124 .52224 L p .839 .45 .311 r
F P
0 g
s
.74069 .51747 m .72795 .5314 L .69174 .28365 L p .211 .017 .385 r
F P
0 g
s
.69174 .28365 m .70242 .27076 L .74069 .51747 L p .211 .017 .385 r
F P
0 g
s
.70784 .49735 m .67744 .27517 L .69174 .28365 L p .839 .45 .311 r
F P
0 g
s
.69174 .28365 m .7243 .50646 L .70784 .49735 L p .839 .45 .311 r
F P
0 g
s
.74069 .51747 m .72795 .5314 L .69174 .28365 L p .211 .017 .385 r
F P
0 g
s
.69174 .28365 m .70242 .27076 L .74069 .51747 L p .211 .017 .385 r
F P
0 g
s
.75261 .2619 m .76677 .27045 L .75582 .28334 L p .694 .677 .829 r
F P
0 g
s
.75582 .28334 m .74169 .27486 L .75261 .2619 L p .694 .677 .829 r
F P
0 g
s
.7915 .54756 m .74169 .27486 L .75582 .28334 L p .839 .442 .294 r
F P
0 g
s
.75582 .28334 m .8082 .55679 L .7915 .54756 L p .839 .442 .294 r
F P
0 g
s
.82155 .54276 m .8082 .55679 L .75582 .28334 L p .239 .047 .406 r
F P
0 g
s
.75582 .28334 m .76677 .27045 L .82155 .54276 L p .239 .047 .406 r
F P
0 g
s
.7939 .56069 m .74169 .27486 L .75582 .28334 L p .839 .442 .294 r
F P
0 g
s
.75582 .28334 m .81072 .56995 L .7939 .56069 L p .839 .442 .294 r
F P
0 g
s
.82155 .54276 m .8082 .55679 L .75582 .28334 L p .239 .047 .406 r
F P
0 g
s
.75582 .28334 m .76677 .27045 L .82155 .54276 L p .239 .047 .406 r
F P
0 g
s
.87431 .5737 m .80595 .27456 L .8199 .28304 L p .839 .434 .276 r
F P
0 g
s
.8199 .28304 m .891 .58298 L .87431 .5737 L p .839 .434 .276 r
F P
0 g
s
.26123 .25993 m .27676 .26849 L .26786 .2814 L p .694 .677 .829 r
F P
0 g
s
.26786 .2814 m .25237 .27291 L .26123 .25993 L p .694 .677 .829 r
F P
0 g
s
.22334 .44736 m .25237 .27291 L .26786 .2814 L p .834 .486 .397 r
F P
0 g
s
.26786 .2814 m .24084 .45637 L .22334 .44736 L p .834 .486 .397 r
F P
0 g
s
.25073 .44268 m .24084 .45637 L .26786 .2814 L p 0 0 .171 r
F P
0 g
s
.26786 .2814 m .27676 .26849 L .25073 .44268 L p 0 0 .171 r
F P
0 g
s
.22334 .44736 m .25237 .27291 L .26786 .2814 L p .834 .486 .397 r
F P
0 g
s
.26786 .2814 m .24084 .45637 L .22334 .44736 L p .834 .486 .397 r
F P
0 g
s
.24899 .45429 m .23904 .46802 L .26786 .2814 L p 0 0 .171 r
F P
0 g
s
.26786 .2814 m .27676 .26849 L .24899 .45429 L p 0 0 .171 r
F P
0 g
s
.32576 .25962 m .34111 .26818 L .33194 .28109 L p .694 .677 .829 r
F P
0 g
s
.33194 .28109 m .31662 .2726 L .32576 .25962 L p .694 .677 .829 r
F P
0 g
s
.29968 .41316 m .31662 .2726 L .33194 .28109 L p .835 .482 .386 r
F P
0 g
s
.33194 .28109 m .31657 .42208 L .29968 .41316 L p .835 .482 .386 r
F P
0 g
s
.3266 .40853 m .31657 .42208 L .33194 .28109 L p 0 0 .214 r
F P
0 g
s
.33194 .28109 m .34111 .26818 L .3266 .40853 L p 0 0 .214 r
F P
0 g
s
.29834 .42429 m .31662 .2726 L .33194 .28109 L p .835 .482 .386 r
F P
0 g
s
.33194 .28109 m .31536 .43324 L .29834 .42429 L p .835 .482 .386 r
F P
0 g
s
.32545 .41964 m .31536 .43324 L .33194 .28109 L p 0 0 .214 r
F P
0 g
s
.33194 .28109 m .34111 .26818 L .32545 .41964 L p 0 0 .214 r
F P
0 g
s
.3903 .25931 m .40548 .26787 L .39603 .28079 L p .694 .677 .829 r
F P
0 g
s
.39603 .28079 m .38089 .27229 L .3903 .25931 L p .694 .677 .829 r
F P
0 g
s
.36956 .42397 m .38089 .27229 L .39603 .28079 L p .836 .477 .374 r
F P
0 g
s
.39603 .28079 m .38637 .43292 L .36956 .42397 L p .836 .477 .374 r
F P
0 g
s
.40481 .40872 m .38847 .39992 L .39868 .38645 L p .691 .688 .843 r
F P
0 g
s
.38778 .41076 m .40424 .41959 L .39401 .4329 L p .69 .689 .844 r
F P
0 g
s
.3968 .41931 m .38637 .43292 L .39603 .28079 L p .036 0 .253 r
F P
0 g
s
.39603 .28079 m .40548 .26787 L .3968 .41931 L p .036 0 .253 r
F P
0 g
s
.36956 .42397 m .38089 .27229 L .39603 .28079 L p .836 .477 .374 r
F P
0 g
s
.39603 .28079 m .38637 .43292 L .36956 .42397 L p .836 .477 .374 r
F P
0 g
s
.39868 .38645 m .38847 .39992 L .39603 .28079 L p .036 0 .253 r
F P
0 g
s
.39603 .28079 m .40548 .26787 L .39868 .38645 L p .036 0 .253 r
F P
0 g
s
.45485 .259 m .46985 .26757 L .46013 .28048 L p .694 .677 .829 r
F P
0 g
s
.46013 .28048 m .44517 .27199 L .45485 .259 L p .694 .677 .829 r
F P
0 g
s
.44236 .36957 m .44517 .27199 L .46013 .28048 L p .837 .472 .362 r
F P
0 g
s
.46013 .28048 m .45837 .37837 L .44236 .36957 L p .837 .472 .362 r
F P
0 g
s
.46876 .36499 m .45837 .37837 L .46013 .28048 L p .08 0 .287 r
F P
0 g
s
.46013 .28048 m .46985 .26757 L .46876 .36499 L p .08 0 .287 r
F P
0 g
s
.44206 .38008 m .44517 .27199 L .46013 .28048 L p .837 .472 .362 r
F P
0 g
s
.46013 .28048 m .45818 .38891 L .44206 .38008 L p .837 .472 .362 r
F P
0 g
s
.46864 .37549 m .45818 .38891 L .46013 .28048 L p .08 0 .287 r
F P
0 g
s
.46013 .28048 m .46985 .26757 L .46864 .37549 L p .08 0 .287 r
F P
0 g
s
.51942 .25869 m .53424 .26726 L .52425 .28018 L p .694 .677 .829 r
F P
0 g
s
.52425 .28018 m .50947 .27168 L .51942 .25869 L p .694 .677 .829 r
F P
0 g
s
.51169 .40123 m .50947 .27168 L .52425 .28018 L p .838 .466 .348 r
F P
0 g
s
.52425 .28018 m .52783 .41012 L .51169 .40123 L p .838 .466 .348 r
F P
0 g
s
.53876 .39661 m .52783 .41012 L .52425 .28018 L p .121 0 .318 r
F P
0 g
s
.52425 .28018 m .53424 .26726 L .53876 .39661 L p .121 0 .318 r
F P
0 g
s
.51169 .40123 m .50947 .27168 L .52425 .28018 L p .838 .466 .348 r
F P
0 g
s
.52425 .28018 m .52783 .41012 L .51169 .40123 L p .838 .466 .348 r
F P
0 g
s
.53914 .40756 m .52813 .42112 L .52425 .28018 L p .121 0 .318 r
F P
0 g
s
.52425 .28018 m .53424 .26726 L .53914 .40756 L p .121 0 .318 r
F P
0 g
s
.584 .25838 m .59864 .26695 L .58838 .27987 L p .694 .677 .829 r
F P
0 g
s
.58838 .27987 m .57377 .27137 L .584 .25838 L p .694 .677 .829 r
F P
0 g
s
.58855 .50561 m .57377 .27137 L .58838 .27987 L p .839 .46 .334 r
F P
0 g
s
.58838 .27987 m .60555 .51477 L .58855 .50561 L p .839 .46 .334 r
F P
0 g
s
.61762 .50084 m .60555 .51477 L .58838 .27987 L p .157 0 .346 r
F P
0 g
s
.58838 .27987 m .59864 .26695 L .61762 .50084 L p .157 0 .346 r
F P
0 g
s
.58935 .51813 m .57377 .27137 L .58838 .27987 L p .839 .46 .334 r
F P
0 g
s
.58838 .27987 m .60647 .52732 L .58935 .51813 L p .839 .46 .334 r
F P
0 g
s
.61863 .51334 m .60647 .52732 L .58838 .27987 L p .157 0 .346 r
F P
0 g
s
.58838 .27987 m .59864 .26695 L .61863 .51334 L p .157 0 .346 r
F P
0 g
s
.64859 .25807 m .66306 .26664 L .65252 .27957 L p .694 .677 .829 r
F P
0 g
s
.65252 .27957 m .63809 .27107 L .64859 .25807 L p .694 .677 .829 r
F P
0 g
s
.66501 .5178 m .63809 .27107 L .65252 .27957 L p .839 .453 .319 r
F P
0 g
s
.65252 .27957 m .68189 .52699 L .66501 .5178 L p .839 .453 .319 r
F P
0 g
s
.69959 .53375 m .68321 .52482 L .69546 .51115 L p .687 .698 .854 r
F P
0 g
s
.6939 .49894 m .67749 .4899 L .68972 .47605 L p .687 .696 .853 r
F P
0 g
s
.67893 .50207 m .69546 .51115 L .68321 .52482 L p .687 .698 .854 r
F P
0 g
s
.69443 .51301 m .68189 .52699 L .65252 .27957 L p .19 0 .37 r
F P
0 g
s
.65252 .27957 m .66306 .26664 L .69443 .51301 L p .19 0 .37 r
F P
0 g
s
.66501 .5178 m .63809 .27107 L .65252 .27957 L p .839 .453 .319 r
F P
0 g
s
.65252 .27957 m .68189 .52699 L .66501 .5178 L p .839 .453 .319 r
F P
0 g
s
.68972 .47605 m .67749 .4899 L .65252 .27957 L p .19 0 .37 r
F P
0 g
s
.65252 .27957 m .66306 .26664 L .68972 .47605 L p .19 0 .37 r
F P
0 g
s
.7132 .25776 m .72748 .26633 L .71668 .27926 L p .694 .677 .829 r
F P
0 g
s
.71668 .27926 m .70242 .27076 L .7132 .25776 L p .694 .677 .829 r
F P
0 g
s
.73875 .50494 m .70242 .27076 L .71668 .27926 L p .84 .446 .302 r
F P
0 g
s
.71668 .27926 m .75527 .51411 L .73875 .50494 L p .84 .446 .302 r
F P
0 g
s
.76807 .50017 m .75527 .51411 L .71668 .27926 L p .22 .027 .392 r
F P
0 g
s
.71668 .27926 m .72748 .26633 L .76807 .50017 L p .22 .027 .392 r
F P
0 g
s
.74069 .51747 m .70242 .27076 L .71668 .27926 L p .84 .446 .302 r
F P
0 g
s
.71668 .27926 m .75733 .52666 L .74069 .51747 L p .84 .446 .302 r
F P
0 g
s
.77024 .51268 m .75733 .52666 L .71668 .27926 L p .22 .027 .392 r
F P
0 g
s
.71668 .27926 m .72748 .26633 L .77024 .51268 L p .22 .027 .392 r
F P
0 g
s
.77782 .25745 m .79192 .26603 L .78085 .27896 L p .694 .677 .829 r
F P
0 g
s
.78085 .27896 m .76677 .27045 L .77782 .25745 L p .694 .677 .829 r
F P
0 g
s
.82155 .54276 m .76677 .27045 L .78085 .27896 L p .839 .438 .285 r
F P
0 g
s
.78085 .27896 m .83818 .55202 L .82155 .54276 L p .839 .438 .285 r
F P
0 g
s
.8517 .53794 m .83818 .55202 L .78085 .27896 L p .248 .056 .412 r
F P
0 g
s
.78085 .27896 m .79192 .26603 L .8517 .53794 L p .248 .056 .412 r
F P
0 g
s
.82155 .54276 m .76677 .27045 L .78085 .27896 L p .839 .438 .285 r
F P
0 g
s
.78085 .27896 m .83818 .55202 L .82155 .54276 L p .839 .438 .285 r
F P
0 g
s
.85458 .55104 m .84094 .56516 L .78085 .27896 L p .248 .056 .412 r
F P
0 g
s
.78085 .27896 m .79192 .26603 L .85458 .55104 L p .248 .056 .412 r
F P
0 g
s
.20573 .4383 m .19604 .45203 L .22805 .27731 L p 0 0 .14 r
F P
0 g
s
.22805 .27731 m .23679 .26437 L .20573 .4383 L p 0 0 .14 r
F P
0 g
s
.28574 .25547 m .30123 .26406 L .29221 .277 L p .694 .677 .829 r
F P
0 g
s
.29221 .277 m .27676 .26849 L .28574 .25547 L p .694 .677 .829 r
F P
0 g
s
.25412 .41996 m .27676 .26849 L .29221 .277 L p .835 .484 .391 r
F P
0 g
s
.29221 .277 m .27131 .42893 L .25412 .41996 L p .835 .484 .391 r
F P
0 g
s
.28121 .41529 m .27131 .42893 L .29221 .277 L p 0 0 .186 r
F P
0 g
s
.29221 .277 m .30123 .26406 L .28121 .41529 L p 0 0 .186 r
F P
0 g
s
.24899 .45429 m .27676 .26849 L .29221 .277 L p .835 .484 .391 r
F P
0 g
s
.29221 .277 m .26657 .46335 L .24899 .45429 L p .835 .484 .391 r
F P
0 g
s
.28121 .41529 m .27131 .42893 L .29221 .277 L p 0 0 .186 r
F P
0 g
s
.29221 .277 m .30123 .26406 L .28121 .41529 L p 0 0 .186 r
F P
0 g
s
.35036 .25516 m .36567 .26375 L .35638 .2767 L p .694 .677 .829 r
F P
0 g
s
.35638 .2767 m .34111 .26818 L .35036 .25516 L p .694 .677 .829 r
F P
0 g
s
.32773 .39757 m .34111 .26818 L .35638 .2767 L p .836 .479 .38 r
F P
0 g
s
.35638 .2767 m .34445 .40648 L .32773 .39757 L p .836 .479 .38 r
F P
0 g
s
.35455 .39293 m .34445 .40648 L .35638 .2767 L p .004 0 .228 r
F P
0 g
s
.35638 .2767 m .36567 .26375 L .35455 .39293 L p .004 0 .228 r
F P
0 g
s
.32545 .41964 m .34111 .26818 L .35638 .2767 L p .836 .479 .38 r
F P
0 g
s
.35638 .2767 m .34242 .42861 L .32545 .41964 L p .836 .479 .38 r
F P
0 g
s
.35265 .41497 m .34242 .42861 L .35638 .2767 L p .004 0 .228 r
F P
0 g
s
.35638 .2767 m .36567 .26375 L .35265 .41497 L p .004 0 .228 r
F P
0 g
s
.415 .25485 m .43013 .26344 L .42057 .27639 L p .694 .677 .829 r
F P
0 g
s
.42057 .27639 m .40548 .26787 L .415 .25485 L p .694 .677 .829 r
F P
0 g
s
.39929 .37581 m .40548 .26787 L .42057 .27639 L p .837 .474 .368 r
F P
0 g
s
.42057 .27639 m .41556 .38466 L .39929 .37581 L p .837 .474 .368 r
F P
0 g
s
.42584 .3712 m .41556 .38466 L .42057 .27639 L p .051 0 .265 r
F P
0 g
s
.42057 .27639 m .43013 .26344 L .42584 .3712 L p .051 0 .265 r
F P
0 g
s
.39868 .38645 m .40548 .26787 L .42057 .27639 L p .837 .474 .368 r
F P
0 g
s
.42057 .27639 m .41507 .39534 L .39868 .38645 L p .837 .474 .368 r
F P
0 g
s
.42584 .3712 m .41556 .38466 L .42057 .27639 L p .051 0 .265 r
F P
0 g
s
.42057 .27639 m .43013 .26344 L .42584 .3712 L p .051 0 .265 r
F P
0 g
s
.47965 .25454 m .4946 .26313 L .48476 .27609 L p .694 .677 .829 r
F P
0 g
s
.48476 .27609 m .46985 .26757 L .47965 .25454 L p .694 .677 .829 r
F P
0 g
s
.46864 .37549 m .46985 .26757 L .48476 .27609 L p .838 .469 .355 r
F P
0 g
s
.48476 .27609 m .48471 .38434 L .46864 .37549 L p .838 .469 .355 r
F P
0 g
s
.49531 .37088 m .48471 .38434 L .48476 .27609 L p .094 0 .298 r
F P
0 g
s
.48476 .27609 m .4946 .26313 L .49531 .37088 L p .094 0 .298 r
F P
0 g
s
.46864 .37549 m .46985 .26757 L .48476 .27609 L p .838 .469 .355 r
F P
0 g
s
.48476 .27609 m .48471 .38434 L .46864 .37549 L p .838 .469 .355 r
F P
0 g
s
.49545 .39229 m .4847 .40584 L .48476 .27609 L p .094 0 .298 r
F P
0 g
s
.48476 .27609 m .4946 .26313 L .49545 .39229 L p .094 0 .298 r
F P
0 g
s
.54431 .25423 m .55908 .26282 L .54898 .27578 L p .694 .677 .829 r
F P
0 g
s
.54898 .27578 m .53424 .26726 L .54431 .25423 L p .694 .677 .829 r
F P
0 g
s
.53914 .40756 m .55534 .41651 L .54429 .42999 L p .69 .69 .845 r
F P
0 g
s
.54429 .42999 m .52813 .42112 L .53914 .40756 L p .69 .69 .845 r
F P
0 g
s
.53953 .41867 m .53424 .26726 L .54898 .27578 L p .839 .463 .341 r
F P
0 g
s
.54898 .27578 m .55585 .42764 L .53953 .41867 L p .839 .463 .341 r
F P
0 g
s
.56709 .41399 m .55585 .42764 L .54898 .27578 L p .133 0 .328 r
F P
0 g
s
.54898 .27578 m .55908 .26282 L .56709 .41399 L p .133 0 .328 r
F P
0 g
s
.53914 .40756 m .53424 .26726 L .54898 .27578 L p .839 .463 .341 r
F P
0 g
s
.54898 .27578 m .55534 .41651 L .53914 .40756 L p .839 .463 .341 r
F P
0 g
s
.56709 .41399 m .55585 .42764 L .54898 .27578 L p .133 0 .328 r
F P
0 g
s
.54898 .27578 m .55908 .26282 L .56709 .41399 L p .133 0 .328 r
F P
0 g
s
.60899 .25392 m .62358 .26252 L .6132 .27547 L p .694 .677 .829 r
F P
0 g
s
.6132 .27547 m .59864 .26695 L .60899 .25392 L p .694 .677 .829 r
F P
0 g
s
.61662 .48852 m .59864 .26695 L .6132 .27547 L p .839 .457 .326 r
F P
0 g
s
.6132 .27547 m .63343 .49768 L .61662 .48852 L p .839 .457 .326 r
F P
0 g
s
.64556 .48375 m .63343 .49768 L .6132 .27547 L p .169 0 .354 r
F P
0 g
s
.6132 .27547 m .62358 .26252 L .64556 .48375 L p .169 0 .354 r
F P
0 g
s
.61863 .51334 m .59864 .26695 L .6132 .27547 L p .839 .457 .326 r
F P
0 g
s
.6132 .27547 m .63569 .52257 L .61863 .51334 L p .839 .457 .326 r
F P
0 g
s
.64802 .50854 m .63569 .52257 L .6132 .27547 L p .169 0 .354 r
F P
0 g
s
.6132 .27547 m .62358 .26252 L .64802 .50854 L p .169 0 .354 r
F P
0 g
s
.67368 .25361 m .68809 .26221 L .67744 .27517 L p .694 .677 .829 r
F P
0 g
s
.67744 .27517 m .66306 .26664 L .67368 .25361 L p .694 .677 .829 r
F P
0 g
s
.68972 .47605 m .70617 .48519 L .6939 .49894 L p .687 .696 .853 r
F P
0 g
s
.69443 .51301 m .66306 .26664 L .67744 .27517 L p .839 .45 .311 r
F P
0 g
s
.67744 .27517 m .71124 .52224 L .69443 .51301 L p .839 .45 .311 r
F P
0 g
s
.72395 .50821 m .71124 .52224 L .67744 .27517 L p .201 .006 .378 r
F P
0 g
s
.67744 .27517 m .68809 .26221 L .72395 .50821 L p .201 .006 .378 r
F P
0 g
s
.68972 .47605 m .66306 .26664 L .67744 .27517 L p .839 .45 .311 r
F P
0 g
s
.67744 .27517 m .70617 .48519 L .68972 .47605 L p .839 .45 .311 r
F P
0 g
s
.72395 .50821 m .71124 .52224 L .67744 .27517 L p .201 .006 .378 r
F P
0 g
s
.67744 .27517 m .68809 .26221 L .72395 .50821 L p .201 .006 .378 r
F P
0 g
s
.73838 .2533 m .75261 .2619 L .74169 .27486 L p .694 .677 .829 r
F P
0 g
s
.74169 .27486 m .72748 .26633 L .73838 .2533 L p .694 .677 .829 r
F P
0 g
s
.77024 .51268 m .72748 .26633 L .74169 .27486 L p .839 .442 .294 r
F P
0 g
s
.74169 .27486 m .78681 .52191 L .77024 .51268 L p .839 .442 .294 r
F P
0 g
s
.79989 .50788 m .78681 .52191 L .74169 .27486 L p .23 .037 .399 r
F P
0 g
s
.74169 .27486 m .75261 .2619 L .79989 .50788 L p .23 .037 .399 r
F P
0 g
s
.77024 .51268 m .72748 .26633 L .74169 .27486 L p .839 .442 .294 r
F P
0 g
s
.74169 .27486 m .78681 .52191 L .77024 .51268 L p .839 .442 .294 r
F P
0 g
s
.80481 .53344 m .7915 .54756 L .74169 .27486 L p .23 .037 .399 r
F P
0 g
s
.74169 .27486 m .75261 .2619 L .80481 .53344 L p .23 .037 .399 r
F P
0 g
s
.85458 .55104 m .79192 .26603 L .80595 .27456 L p .839 .434 .276 r
F P
0 g
s
.80595 .27456 m .87126 .56036 L .85458 .55104 L p .839 .434 .276 r
F P
0 g
s
.24561 .25131 m .26123 .25993 L .25237 .27291 L p .694 .677 .829 r
F P
0 g
s
.25237 .27291 m .23679 .26437 L .24561 .25131 L p .694 .677 .829 r
F P
0 g
s
.20777 .42688 m .23679 .26437 L .25237 .27291 L p .834 .486 .397 r
F P
0 g
s
.25237 .27291 m .22524 .43591 L .20777 .42688 L p .834 .486 .397 r
F P
0 g
s
.23502 .42218 m .22524 .43591 L .25237 .27291 L p 0 0 .156 r
F P
0 g
s
.25237 .27291 m .26123 .25993 L .23502 .42218 L p 0 0 .156 r
F P
0 g
s
.20573 .4383 m .23679 .26437 L .25237 .27291 L p .834 .486 .397 r
F P
0 g
s
.25237 .27291 m .22334 .44736 L .20573 .4383 L p .834 .486 .397 r
F P
0 g
s
.23317 .43359 m .22334 .44736 L .25237 .27291 L p 0 0 .156 r
F P
0 g
s
.25237 .27291 m .26123 .25993 L .23317 .43359 L p 0 0 .156 r
F P
0 g
s
.31032 .251 m .32576 .25962 L .31662 .2726 L p .694 .677 .829 r
F P
0 g
s
.31662 .2726 m .30123 .26406 L .31032 .251 L p .694 .677 .829 r
F P
0 g
s
.28121 .41529 m .30123 .26406 L .31662 .2726 L p .835 .482 .386 r
F P
0 g
s
.31662 .2726 m .29834 .42429 L .28121 .41529 L p .835 .482 .386 r
F P
0 g
s
.31657 .42208 m .29968 .41316 L .30965 .39953 L p .69 .69 .845 r
F P
0 g
s
.30838 .41061 m .29834 .42429 L .31662 .2726 L p 0 0 .2 r
F P
0 g
s
.31662 .2726 m .32576 .25962 L .30838 .41061 L p 0 0 .2 r
F P
0 g
s
.28121 .41529 m .30123 .26406 L .31662 .2726 L p .835 .482 .386 r
F P
0 g
s
.31662 .2726 m .29834 .42429 L .28121 .41529 L p .835 .482 .386 r
F P
0 g
s
.30965 .39953 m .29968 .41316 L .31662 .2726 L p 0 0 .2 r
F P
0 g
s
.31662 .2726 m .32576 .25962 L .30965 .39953 L p 0 0 .2 r
F P
0 g
s
.37504 .25069 m .3903 .25931 L .38089 .27229 L p .694 .677 .829 r
F P
0 g
s
.38089 .27229 m .36567 .26375 L .37504 .25069 L p .694 .677 .829 r
F P
0 g
s
.35361 .40387 m .36567 .26375 L .38089 .27229 L p .836 .477 .374 r
F P
0 g
s
.38089 .27229 m .37039 .41284 L .35361 .40387 L p .836 .477 .374 r
F P
0 g
s
.3807 .3992 m .37039 .41284 L .38089 .27229 L p .02 0 .24 r
F P
0 g
s
.38089 .27229 m .3903 .25931 L .3807 .3992 L p .02 0 .24 r
F P
0 g
s
.35265 .41497 m .36567 .26375 L .38089 .27229 L p .836 .477 .374 r
F P
0 g
s
.38089 .27229 m .36956 .42397 L .35265 .41497 L p .836 .477 .374 r
F P
0 g
s
.37994 .41028 m .36956 .42397 L .38089 .27229 L p .02 0 .24 r
F P
0 g
s
.38089 .27229 m .3903 .25931 L .37994 .41028 L p .02 0 .24 r
F P
0 g
s
.43977 .25038 m .45485 .259 L .44517 .27199 L p .694 .677 .829 r
F P
0 g
s
.44517 .27199 m .43013 .26344 L .43977 .25038 L p .694 .677 .829 r
F P
0 g
s
.42584 .3712 m .43013 .26344 L .44517 .27199 L p .837 .472 .362 r
F P
0 g
s
.44517 .27199 m .44206 .38008 L .42584 .3712 L p .837 .472 .362 r
F P
0 g
s
.45837 .37837 m .44236 .36957 L .45271 .35611 L p .691 .686 .84 r
F P
0 g
s
.45248 .36658 m .44206 .38008 L .44517 .27199 L p .066 0 .276 r
F P
0 g
s
.44517 .27199 m .45485 .259 L .45248 .36658 L p .066 0 .276 r
F P
0 g
s
.42584 .3712 m .43013 .26344 L .44517 .27199 L p .837 .472 .362 r
F P
0 g
s
.44517 .27199 m .44206 .38008 L .42584 .3712 L p .837 .472 .362 r
F P
0 g
s
.45271 .35611 m .44236 .36957 L .44517 .27199 L p .066 0 .276 r
F P
0 g
s
.44517 .27199 m .45485 .259 L .45271 .35611 L p .066 0 .276 r
F P
0 g
s
.50452 .25007 m .51942 .25869 L .50947 .27168 L p .694 .677 .829 r
F P
0 g
s
.50947 .27168 m .4946 .26313 L .50452 .25007 L p .694 .677 .829 r
F P
0 g
s
.49538 .38151 m .4946 .26313 L .50947 .27168 L p .838 .466 .348 r
F P
0 g
s
.50947 .27168 m .5115 .39042 L .49538 .38151 L p .838 .466 .348 r
F P
0 g
s
.52231 .37687 m .5115 .39042 L .50947 .27168 L p .108 0 .308 r
F P
0 g
s
.50947 .27168 m .51942 .25869 L .52231 .37687 L p .108 0 .308 r
F P
0 g
s
.49545 .39229 m .4946 .26313 L .50947 .27168 L p .838 .466 .348 r
F P
0 g
s
.50947 .27168 m .51169 .40123 L .49545 .39229 L p .838 .466 .348 r
F P
0 g
s
.52258 .38763 m .51169 .40123 L .50947 .27168 L p .108 0 .308 r
F P
0 g
s
.50947 .27168 m .51942 .25869 L .52258 .38763 L p .108 0 .308 r
F P
0 g
s
.56928 .24976 m .584 .25838 L .57377 .27137 L p .694 .677 .829 r
F P
0 g
s
.57377 .27137 m .55908 .26282 L .56928 .24976 L p .694 .677 .829 r
F P
0 g
s
.56709 .41399 m .55908 .26282 L .57377 .27137 L p .839 .46 .334 r
F P
0 g
s
.57377 .27137 m .58334 .423 L .56709 .41399 L p .839 .46 .334 r
F P
0 g
s
.59473 .4093 m .58334 .423 L .57377 .27137 L p .145 0 .337 r
F P
0 g
s
.57377 .27137 m .584 .25838 L .59473 .4093 L p .145 0 .337 r
F P
0 g
s
.56709 .41399 m .55908 .26282 L .57377 .27137 L p .839 .46 .334 r
F P
0 g
s
.57377 .27137 m .58334 .423 L .56709 .41399 L p .839 .46 .334 r
F P
0 g
s
.60057 .49158 m .58855 .50561 L .57377 .27137 L p .145 0 .337 r
F P
0 g
s
.57377 .27137 m .584 .25838 L .60057 .49158 L p .145 0 .337 r
F P
0 g
s
.63405 .24945 m .64859 .25807 L .63809 .27107 L p .694 .677 .829 r
F P
0 g
s
.63809 .27107 m .62358 .26252 L .63405 .24945 L p .694 .677 .829 r
F P
0 g
s
.64678 .49605 m .62358 .26252 L .63809 .27107 L p .839 .453 .319 r
F P
0 g
s
.63809 .27107 m .66364 .50527 L .64678 .49605 L p .839 .453 .319 r
F P
0 g
s
.67604 .49125 m .66364 .50527 L .63809 .27107 L p .18 0 .362 r
F P
0 g
s
.63809 .27107 m .64859 .25807 L .67604 .49125 L p .18 0 .362 r
F P
0 g
s
.64802 .50854 m .62358 .26252 L .63809 .27107 L p .839 .453 .319 r
F P
0 g
s
.63809 .27107 m .66501 .5178 L .64802 .50854 L p .839 .453 .319 r
F P
0 g
s
.6775 .50373 m .66501 .5178 L .63809 .27107 L p .18 0 .362 r
F P
0 g
s
.63809 .27107 m .64859 .25807 L .6775 .50373 L p .18 0 .362 r
F P
0 g
s
.69883 .24914 m .7132 .25776 L .70242 .27076 L p .694 .677 .829 r
F P
0 g
s
.70242 .27076 m .68809 .26221 L .69883 .24914 L p .694 .677 .829 r
F P
0 g
s
.72395 .50821 m .68809 .26221 L .70242 .27076 L p .84 .446 .302 r
F P
0 g
s
.70242 .27076 m .74069 .51747 L .72395 .50821 L p .84 .446 .302 r
F P
0 g
s
.75152 .49091 m .76807 .50017 L .75527 .51411 L p .687 .699 .856 r
F P
0 g
s
.75527 .51411 m .73875 .50494 L .75152 .49091 L p .687 .699 .856 r
F P
0 g
s
.75357 .50339 m .74069 .51747 L .70242 .27076 L p .211 .017 .385 r
F P
0 g
s
.70242 .27076 m .7132 .25776 L .75357 .50339 L p .211 .017 .385 r
F P
0 g
s
.72395 .50821 m .68809 .26221 L .70242 .27076 L p .84 .446 .302 r
F P
0 g
s
.70242 .27076 m .74069 .51747 L .72395 .50821 L p .84 .446 .302 r
F P
0 g
s
.75152 .49091 m .73875 .50494 L .70242 .27076 L p .211 .017 .385 r
F P
0 g
s
.70242 .27076 m .7132 .25776 L .75152 .49091 L p .211 .017 .385 r
F P
0 g
s
.76363 .24883 m .77782 .25745 L .76677 .27045 L p .694 .677 .829 r
F P
0 g
s
.76677 .27045 m .75261 .2619 L .76363 .24883 L p .694 .677 .829 r
F P
0 g
s
.80233 .52056 m .75261 .2619 L .76677 .27045 L p .839 .438 .285 r
F P
0 g
s
.76677 .27045 m .81895 .52985 L .80233 .52056 L p .839 .438 .285 r
F P
0 g
s
.83232 .51573 m .81895 .52985 L .76677 .27045 L p .239 .047 .406 r
F P
0 g
s
.76677 .27045 m .77782 .25745 L .83232 .51573 L p .239 .047 .406 r
F P
0 g
s
.80481 .53344 m .75261 .2619 L .76677 .27045 L p .839 .438 .285 r
F P
0 g
s
.76677 .27045 m .82155 .54276 L .80481 .53344 L p .839 .438 .285 r
F P
0 g
s
.83503 .52859 m .82155 .54276 L .76677 .27045 L p .239 .047 .406 r
F P
0 g
s
.76677 .27045 m .77782 .25745 L .83503 .52859 L p .239 .047 .406 r
F P
0 g
s
.27017 .24683 m .28574 .25547 L .27676 .26849 L p .694 .677 .829 r
F P
0 g
s
.27676 .26849 m .26123 .25993 L .27017 .24683 L p .694 .677 .829 r
F P
0 g
s
.23683 .41093 m .26123 .25993 L .27676 .26849 L p .835 .484 .391 r
F P
0 g
s
.27676 .26849 m .25412 .41996 L .23683 .41093 L p .835 .484 .391 r
F P
0 g
s
.26397 .40624 m .25412 .41996 L .27676 .26849 L p 0 0 .171 r
F P
0 g
s
.27676 .26849 m .28574 .25547 L .26397 .40624 L p 0 0 .171 r
F P
0 g
s
.23317 .43359 m .26123 .25993 L .27676 .26849 L p .835 .484 .391 r
F P
0 g
s
.27676 .26849 m .25073 .44268 L .23317 .43359 L p .835 .484 .391 r
F P
0 g
s
.26397 .40624 m .25412 .41996 L .27676 .26849 L p 0 0 .171 r
F P
0 g
s
.27676 .26849 m .28574 .25547 L .26397 .40624 L p 0 0 .171 r
F P
0 g
s
.33497 .24652 m .35036 .25516 L .34111 .26818 L p .694 .677 .829 r
F P
0 g
s
.34111 .26818 m .32576 .25962 L .33497 .24652 L p .694 .677 .829 r
F P
0 g
s
.31091 .3886 m .32576 .25962 L .34111 .26818 L p .836 .479 .38 r
F P
0 g
s
.34111 .26818 m .32773 .39757 L .31091 .3886 L p .836 .479 .38 r
F P
0 g
s
.33778 .38394 m .32773 .39757 L .34111 .26818 L p 0 0 .214 r
F P
0 g
s
.34111 .26818 m .35036 .25516 L .33778 .38394 L p 0 0 .214 r
F P
0 g
s
.30965 .39953 m .32576 .25962 L .34111 .26818 L p .836 .479 .38 r
F P
0 g
s
.34111 .26818 m .3266 .40853 L .30965 .39953 L p .836 .479 .38 r
F P
0 g
s
.33778 .38394 m .32773 .39757 L .34111 .26818 L p 0 0 .214 r
F P
0 g
s
.34111 .26818 m .35036 .25516 L .33778 .38394 L p 0 0 .214 r
F P
0 g
s
.39979 .24621 m .415 .25485 L .40548 .26787 L p .694 .677 .829 r
F P
0 g
s
.40548 .26787 m .3903 .25931 L .39979 .24621 L p .694 .677 .829 r
F P
0 g
s
.37994 .41028 m .3903 .25931 L .40548 .26787 L p .837 .474 .368 r
F P
0 g
s
.40548 .26787 m .3968 .41931 L .37994 .41028 L p .837 .474 .368 r
F P
0 g
s
.41556 .38466 m .39929 .37581 L .40953 .36226 L p .691 .687 .841 r
F P
0 g
s
.39868 .38645 m .41507 .39534 L .40481 .40872 L p .691 .688 .843 r
F P
0 g
s
.40732 .40558 m .3968 .41931 L .40548 .26787 L p .036 0 .253 r
F P
0 g
s
.40548 .26787 m .415 .25485 L .40732 .40558 L p .036 0 .253 r
F P
0 g
s
.37994 .41028 m .3903 .25931 L .40548 .26787 L p .837 .474 .368 r
F P
0 g
s
.40548 .26787 m .3968 .41931 L .37994 .41028 L p .837 .474 .368 r
F P
0 g
s
.40953 .36226 m .39929 .37581 L .40548 .26787 L p .036 0 .253 r
F P
0 g
s
.40548 .26787 m .415 .25485 L .40953 .36226 L p .036 0 .253 r
F P
0 g
s
.46462 .2459 m .47965 .25454 L .46985 .26757 L p .694 .677 .829 r
F P
0 g
s
.46985 .26757 m .45485 .259 L .46462 .2459 L p .694 .677 .829 r
F P
0 g
s
.45271 .35611 m .46876 .36499 L .45837 .37837 L p .691 .686 .84 r
F P
0 g
s
.45248 .36658 m .45485 .259 L .46985 .26757 L p .838 .469 .355 r
F P
0 g
s
.46985 .26757 m .46864 .37549 L .45248 .36658 L p .838 .469 .355 r
F P
0 g
s
.4792 .36194 m .46864 .37549 L .46985 .26757 L p .08 0 .287 r
F P
0 g
s
.46985 .26757 m .47965 .25454 L .4792 .36194 L p .08 0 .287 r
F P
0 g
s
.45271 .35611 m .45485 .259 L .46985 .26757 L p .838 .469 .355 r
F P
0 g
s
.46985 .26757 m .46876 .36499 L .45271 .35611 L p .838 .469 .355 r
F P
0 g
s
.4792 .36194 m .46864 .37549 L .46985 .26757 L p .08 0 .287 r
F P
0 g
s
.46985 .26757 m .47965 .25454 L .4792 .36194 L p .08 0 .287 r
F P
0 g
s
.52946 .24559 m .54431 .25423 L .53424 .26726 L p .694 .677 .829 r
F P
0 g
s
.53424 .26726 m .51942 .25869 L .52946 .24559 L p .694 .677 .829 r
F P
0 g
s
.51169 .40123 m .52783 .41012 L .517 .42352 L p .69 .689 .844 r
F P
0 g
s
.52258 .38763 m .53876 .39661 L .52783 .41012 L p .69 .689 .844 r
F P
0 g
s
.52783 .41012 m .51169 .40123 L .52258 .38763 L p .69 .689 .844 r
F P
0 g
s
.52312 .40963 m .51942 .25869 L .53424 .26726 L p .839 .463 .341 r
F P
0 g
s
.53424 .26726 m .53953 .41867 L .52312 .40963 L p .839 .463 .341 r
F P
0 g
s
.55073 .40493 m .53953 .41867 L .53424 .26726 L p .121 0 .318 r
F P
0 g
s
.53424 .26726 m .54431 .25423 L .55073 .40493 L p .121 0 .318 r
F P
0 g
s
.52258 .38763 m .51942 .25869 L .53424 .26726 L p .839 .463 .341 r
F P
0 g
s
.53424 .26726 m .53876 .39661 L .52258 .38763 L p .839 .463 .341 r
F P
0 g
s
.55073 .40493 m .53953 .41867 L .53424 .26726 L p .121 0 .318 r
F P
0 g
s
.53424 .26726 m .54431 .25423 L .55073 .40493 L p .121 0 .318 r
F P
0 g
s
.59431 .24528 m .60899 .25392 L .59864 .26695 L p .694 .677 .829 r
F P
0 g
s
.59864 .26695 m .584 .25838 L .59431 .24528 L p .694 .677 .829 r
F P
0 g
s
.5997 .47929 m .584 .25838 L .59864 .26695 L p .839 .457 .326 r
F P
0 g
s
.59864 .26695 m .61662 .48852 L .5997 .47929 L p .839 .457 .326 r
F P
0 g
s
.6287 .47449 m .61662 .48852 L .59864 .26695 L p .157 0 .346 r
F P
0 g
s
.59864 .26695 m .60899 .25392 L .6287 .47449 L p .157 0 .346 r
F P
0 g
s
.60057 .49158 m .584 .25838 L .59864 .26695 L p .839 .457 .326 r
F P
0 g
s
.59864 .26695 m .61762 .50084 L .60057 .49158 L p .839 .457 .326 r
F P
0 g
s
.6287 .47449 m .61662 .48852 L .59864 .26695 L p .157 0 .346 r
F P
0 g
s
.59864 .26695 m .60899 .25392 L .6287 .47449 L p .157 0 .346 r
F P
0 g
s
.65918 .24496 m .67368 .25361 L .66306 .26664 L p .694 .677 .829 r
F P
0 g
s
.66306 .26664 m .64859 .25807 L .65918 .24496 L p .694 .677 .829 r
F P
0 g
s
.67176 .45494 m .64859 .25807 L .66306 .26664 L p .839 .45 .311 r
F P
0 g
s
.66306 .26664 m .6882 .4641 L .67176 .45494 L p .839 .45 .311 r
F P
0 g
s
.70045 .45017 m .6882 .4641 L .66306 .26664 L p .19 0 .37 r
F P
0 g
s
.66306 .26664 m .67368 .25361 L .70045 .45017 L p .19 0 .37 r
F P
0 g
s
.6775 .50373 m .64859 .25807 L .66306 .26664 L p .839 .45 .311 r
F P
0 g
s
.66306 .26664 m .69443 .51301 L .6775 .50373 L p .839 .45 .311 r
F P
0 g
s
.70709 .49889 m .69443 .51301 L .66306 .26664 L p .19 0 .37 r
F P
0 g
s
.66306 .26664 m .67368 .25361 L .70709 .49889 L p .19 0 .37 r
F P
0 g
s
.72406 .24465 m .73838 .2533 L .72748 .26633 L p .694 .677 .829 r
F P
0 g
s
.72748 .26633 m .7132 .25776 L .72406 .24465 L p .694 .677 .829 r
F P
0 g
s
.75357 .50339 m .7132 .25776 L .72748 .26633 L p .839 .442 .294 r
F P
0 g
s
.72748 .26633 m .77024 .51268 L .75357 .50339 L p .839 .442 .294 r
F P
0 g
s
.78329 .49856 m .77024 .51268 L .72748 .26633 L p .22 .027 .392 r
F P
0 g
s
.72748 .26633 m .73838 .2533 L .78329 .49856 L p .22 .027 .392 r
F P
0 g
s
.75152 .49091 m .7132 .25776 L .72748 .26633 L p .839 .442 .294 r
F P
0 g
s
.72748 .26633 m .76807 .50017 L .75152 .49091 L p .839 .442 .294 r
F P
0 g
s
.78329 .49856 m .77024 .51268 L .72748 .26633 L p .22 .027 .392 r
F P
0 g
s
.72748 .26633 m .73838 .2533 L .78329 .49856 L p .22 .027 .392 r
F P
0 g
s
.83503 .52859 m .77782 .25745 L .79192 .26603 L p .839 .434 .276 r
F P
0 g
s
.79192 .26603 m .8517 .53794 L .83503 .52859 L p .839 .434 .276 r
F P
0 g
s
.21748 .41306 m .20777 .42688 L .23679 .26437 L p 0 0 .14 r
F P
0 g
s
.23679 .26437 m .24561 .25131 L .21748 .41306 L p 0 0 .14 r
F P
0 g
s
.2948 .24234 m .31032 .251 L .30123 .26406 L p .694 .677 .829 r
F P
0 g
s
.30123 .26406 m .28574 .25547 L .2948 .24234 L p .694 .677 .829 r
F P
0 g
s
.26557 .39517 m .28574 .25547 L .30123 .26406 L p .835 .482 .386 r
F P
0 g
s
.30123 .26406 m .28268 .40419 L .26557 .39517 L p .835 .482 .386 r
F P
0 g
s
.29261 .39047 m .28268 .40419 L .30123 .26406 L p 0 0 .186 r
F P
0 g
s
.30123 .26406 m .31032 .251 L .29261 .39047 L p 0 0 .186 r
F P
0 g
s
.26397 .40624 m .28574 .25547 L .30123 .26406 L p .835 .482 .386 r
F P
0 g
s
.30123 .26406 m .28121 .41529 L .26397 .40624 L p .835 .482 .386 r
F P
0 g
s
.2912 .40152 m .28121 .41529 L .30123 .26406 L p 0 0 .186 r
F P
0 g
s
.30123 .26406 m .31032 .251 L .2912 .40152 L p 0 0 .186 r
F P
0 g
s
.35969 .24203 m .37504 .25069 L .36567 .26375 L p .694 .677 .829 r
F P
0 g
s
.36567 .26375 m .35036 .25516 L .35969 .24203 L p .694 .677 .829 r
F P
0 g
s
.33778 .38394 m .35036 .25516 L .36567 .26375 L p .836 .477 .374 r
F P
0 g
s
.36567 .26375 m .35455 .39293 L .33778 .38394 L p .836 .477 .374 r
F P
0 g
s
.36474 .37926 m .35455 .39293 L .36567 .26375 L p .004 0 .228 r
F P
0 g
s
.36567 .26375 m .37504 .25069 L .36474 .37926 L p .004 0 .228 r
F P
0 g
s
.33778 .38394 m .35036 .25516 L .36567 .26375 L p .836 .477 .374 r
F P
0 g
s
.36567 .26375 m .35455 .39293 L .33778 .38394 L p .836 .477 .374 r
F P
0 g
s
.36387 .39015 m .35361 .40387 L .36567 .26375 L p .004 0 .228 r
F P
0 g
s
.36567 .26375 m .37504 .25069 L .36387 .39015 L p .004 0 .228 r
F P
0 g
s
.42461 .24172 m .43977 .25038 L .43013 .26344 L p .694 .677 .829 r
F P
0 g
s
.43013 .26344 m .415 .25485 L .42461 .24172 L p .694 .677 .829 r
F P
0 g
s
.41006 .35181 m .415 .25485 L .43013 .26344 L p .837 .472 .362 r
F P
0 g
s
.43013 .26344 m .42626 .36072 L .41006 .35181 L p .837 .472 .362 r
F P
0 g
s
.43656 .34718 m .42626 .36072 L .43013 .26344 L p .051 0 .265 r
F P
0 g
s
.43013 .26344 m .43977 .25038 L .43656 .34718 L p .051 0 .265 r
F P
0 g
s
.40953 .36226 m .415 .25485 L .43013 .26344 L p .837 .472 .362 r
F P
0 g
s
.43013 .26344 m .42584 .3712 L .40953 .36226 L p .837 .472 .362 r
F P
0 g
s
.43622 .35762 m .42584 .3712 L .43013 .26344 L p .051 0 .265 r
F P
0 g
s
.43013 .26344 m .43977 .25038 L .43622 .35762 L p .051 0 .265 r
F P
0 g
s
.48953 .2414 m .50452 .25007 L .4946 .26313 L p .694 .677 .829 r
F P
0 g
s
.4946 .26313 m .47965 .25454 L .48953 .2414 L p .694 .677 .829 r
F P
0 g
s
.4792 .36194 m .47965 .25454 L .4946 .26313 L p .838 .466 .348 r
F P
0 g
s
.4946 .26313 m .49531 .37088 L .4792 .36194 L p .838 .466 .348 r
F P
0 g
s
.506 .35729 m .49531 .37088 L .4946 .26313 L p .094 0 .298 r
F P
0 g
s
.4946 .26313 m .50452 .25007 L .506 .35729 L p .094 0 .298 r
F P
0 g
s
.4792 .36194 m .47965 .25454 L .4946 .26313 L p .838 .466 .348 r
F P
0 g
s
.4946 .26313 m .49531 .37088 L .4792 .36194 L p .838 .466 .348 r
F P
0 g
s
.50615 .36787 m .49538 .38151 L .4946 .26313 L p .094 0 .298 r
F P
0 g
s
.4946 .26313 m .50452 .25007 L .50615 .36787 L p .094 0 .298 r
F P
0 g
s
.55447 .24109 m .56928 .24976 L .55908 .26282 L p .694 .677 .829 r
F P
0 g
s
.55908 .26282 m .54431 .25423 L .55447 .24109 L p .694 .677 .829 r
F P
0 g
s
.55026 .39387 m .54431 .25423 L .55908 .26282 L p .839 .46 .334 r
F P
0 g
s
.55908 .26282 m .5665 .4029 L .55026 .39387 L p .839 .46 .334 r
F P
0 g
s
.57776 .38917 m .5665 .4029 L .55908 .26282 L p .133 0 .328 r
F P
0 g
s
.55908 .26282 m .56928 .24976 L .57776 .38917 L p .133 0 .328 r
F P
0 g
s
.55073 .40493 m .54431 .25423 L .55908 .26282 L p .839 .46 .334 r
F P
0 g
s
.55908 .26282 m .56709 .41399 L .55073 .40493 L p .839 .46 .334 r
F P
0 g
s
.57843 .40021 m .56709 .41399 L .55908 .26282 L p .133 0 .328 r
F P
0 g
s
.55908 .26282 m .56928 .24976 L .57843 .40021 L p .133 0 .328 r
F P
0 g
s
.61942 .24078 m .63405 .24945 L .62358 .26252 L p .694 .677 .829 r
F P
0 g
s
.62358 .26252 m .60899 .25392 L .61942 .24078 L p .694 .677 .829 r
F P
0 g
s
.6287 .47449 m .60899 .25392 L .62358 .26252 L p .839 .453 .319 r
F P
0 g
s
.62358 .26252 m .64556 .48375 L .6287 .47449 L p .839 .453 .319 r
F P
0 g
s
.6578 .46968 m .64556 .48375 L .62358 .26252 L p .169 0 .354 r
F P
0 g
s
.62358 .26252 m .63405 .24945 L .6578 .46968 L p .169 0 .354 r
F P
0 g
s
.6287 .47449 m .60899 .25392 L .62358 .26252 L p .839 .453 .319 r
F P
0 g
s
.62358 .26252 m .64556 .48375 L .6287 .47449 L p .839 .453 .319 r
F P
0 g
s
.65913 .48193 m .64678 .49605 L .62358 .26252 L p .169 0 .354 r
F P
0 g
s
.62358 .26252 m .63405 .24945 L .65913 .48193 L p .169 0 .354 r
F P
0 g
s
.68439 .24047 m .69883 .24914 L .68809 .26221 L p .694 .677 .829 r
F P
0 g
s
.68809 .26221 m .67368 .25361 L .68439 .24047 L p .694 .677 .829 r
F P
0 g
s
.70539 .48643 m .67368 .25361 L .68809 .26221 L p .84 .446 .302 r
F P
0 g
s
.68809 .26221 m .72213 .49572 L .70539 .48643 L p .84 .446 .302 r
F P
0 g
s
.73485 .4816 m .72213 .49572 L .68809 .26221 L p .201 .006 .378 r
F P
0 g
s
.68809 .26221 m .69883 .24914 L .73485 .4816 L p .201 .006 .378 r
F P
0 g
s
.70709 .49889 m .67368 .25361 L .68809 .26221 L p .84 .446 .302 r
F P
0 g
s
.68809 .26221 m .72395 .50821 L .70709 .49889 L p .84 .446 .302 r
F P
0 g
s
.73678 .49404 m .72395 .50821 L .68809 .26221 L p .201 .006 .378 r
F P
0 g
s
.68809 .26221 m .69883 .24914 L .73678 .49404 L p .201 .006 .378 r
F P
0 g
s
.74936 .24015 m .76363 .24883 L .75261 .2619 L p .694 .677 .829 r
F P
0 g
s
.75261 .2619 m .73838 .2533 L .74936 .24015 L p .694 .677 .829 r
F P
0 g
s
.78329 .49856 m .73838 .2533 L .75261 .2619 L p .839 .438 .285 r
F P
0 g
s
.75261 .2619 m .79989 .50788 L .78329 .49856 L p .839 .438 .285 r
F P
0 g
s
.81311 .49371 m .79989 .50788 L .75261 .2619 L p .23 .037 .399 r
F P
0 g
s
.75261 .2619 m .76363 .24883 L .81311 .49371 L p .23 .037 .399 r
F P
0 g
s
.78329 .49856 m .73838 .2533 L .75261 .2619 L p .839 .438 .285 r
F P
0 g
s
.75261 .2619 m .79989 .50788 L .78329 .49856 L p .839 .438 .285 r
F P
0 g
s
.81566 .50634 m .80233 .52056 L .75261 .2619 L p .23 .037 .399 r
F P
0 g
s
.75261 .2619 m .76363 .24883 L .81566 .50634 L p .23 .037 .399 r
F P
0 g
s
.25451 .23815 m .27017 .24683 L .26123 .25993 L p .694 .677 .829 r
F P
0 g
s
.26123 .25993 m .24561 .25131 L .25451 .23815 L p .694 .677 .829 r
F P
0 g
s
.21943 .40185 m .24561 .25131 L .26123 .25993 L p .835 .484 .391 r
F P
0 g
s
.26123 .25993 m .23683 .41093 L .21943 .40185 L p .835 .484 .391 r
F P
0 g
s
.24663 .39712 m .23683 .41093 L .26123 .25993 L p 0 0 .156 r
F P
0 g
s
.26123 .25993 m .27017 .24683 L .24663 .39712 L p 0 0 .156 r
F P
0 g
s
.21748 .41306 m .24561 .25131 L .26123 .25993 L p .835 .484 .391 r
F P
0 g
s
.26123 .25993 m .23502 .42218 L .21748 .41306 L p .835 .484 .391 r
F P
0 g
s
.24663 .39712 m .23683 .41093 L .26123 .25993 L p 0 0 .156 r
F P
0 g
s
.26123 .25993 m .27017 .24683 L .24663 .39712 L p 0 0 .156 r
F P
0 g
s
.31949 .23784 m .33497 .24652 L .32576 .25962 L p .694 .677 .829 r
F P
0 g
s
.32576 .25962 m .31032 .251 L .31949 .23784 L p .694 .677 .829 r
F P
0 g
s
.2912 .40152 m .31032 .251 L .32576 .25962 L p .836 .479 .38 r
F P
0 g
s
.32576 .25962 m .30838 .41061 L .2912 .40152 L p .836 .479 .38 r
F P
0 g
s
.32773 .39757 m .31091 .3886 L .32092 .37489 L p .69 .689 .844 r
F P
0 g
s
.30965 .39953 m .3266 .40853 L .31657 .42208 L p .69 .69 .845 r
F P
0 g
s
.31852 .39679 m .30838 .41061 L .32576 .25962 L p 0 0 .2 r
F P
0 g
s
.32576 .25962 m .33497 .24652 L .31852 .39679 L p 0 0 .2 r
F P
0 g
s
.2912 .40152 m .31032 .251 L .32576 .25962 L p .836 .479 .38 r
F P
0 g
s
.32576 .25962 m .30838 .41061 L .2912 .40152 L p .836 .479 .38 r
F P
0 g
s
.32092 .37489 m .31091 .3886 L .32576 .25962 L p 0 0 .2 r
F P
0 g
s
.32576 .25962 m .33497 .24652 L .32092 .37489 L p 0 0 .2 r
F P
0 g
s
.38449 .23752 m .39979 .24621 L .3903 .25931 L p .694 .677 .829 r
F P
0 g
s
.3903 .25931 m .37504 .25069 L .38449 .23752 L p .694 .677 .829 r
F P
0 g
s
.36387 .39015 m .3807 .3992 L .37039 .41284 L p .69 .69 .845 r
F P
0 g
s
.37039 .41284 m .35361 .40387 L .36387 .39015 L p .69 .69 .845 r
F P
0 g
s
.36298 .40119 m .37504 .25069 L .3903 .25931 L p .837 .474 .368 r
F P
0 g
s
.3903 .25931 m .37994 .41028 L .36298 .40119 L p .837 .474 .368 r
F P
0 g
s
.39042 .39647 m .37994 .41028 L .3903 .25931 L p .02 0 .24 r
F P
0 g
s
.3903 .25931 m .39979 .24621 L .39042 .39647 L p .02 0 .24 r
F P
0 g
s
.36387 .39015 m .37504 .25069 L .3903 .25931 L p .837 .474 .368 r
F P
0 g
s
.3903 .25931 m .3807 .3992 L .36387 .39015 L p .837 .474 .368 r
F P
0 g
s
.39042 .39647 m .37994 .41028 L .3903 .25931 L p .02 0 .24 r
F P
0 g
s
.3903 .25931 m .39979 .24621 L .39042 .39647 L p .02 0 .24 r
F P
0 g
s
.4495 .23721 m .46462 .2459 L .45485 .259 L p .694 .677 .829 r
F P
0 g
s
.45485 .259 m .43977 .25038 L .4495 .23721 L p .694 .677 .829 r
F P
0 g
s
.4369 .33689 m .43977 .25038 L .45485 .259 L p .838 .469 .355 r
F P
0 g
s
.45485 .259 m .45294 .34579 L .4369 .33689 L p .838 .469 .355 r
F P
0 g
s
.46331 .33226 m .45294 .34579 L .45485 .259 L p .066 0 .276 r
F P
0 g
s
.45485 .259 m .46462 .2459 L .46331 .33226 L p .066 0 .276 r
F P
0 g
s
.43622 .35762 m .43977 .25038 L .45485 .259 L p .838 .469 .355 r
F P
0 g
s
.45485 .259 m .45248 .36658 L .43622 .35762 L p .838 .469 .355 r
F P
0 g
s
.46299 .35295 m .45248 .36658 L .45485 .259 L p .066 0 .276 r
F P
0 g
s
.45485 .259 m .46462 .2459 L .46299 .35295 L p .066 0 .276 r
F P
0 g
s
.51452 .2369 m .52946 .24559 L .51942 .25869 L p .694 .677 .829 r
F P
0 g
s
.51942 .25869 m .50452 .25007 L .51452 .2369 L p .694 .677 .829 r
F P
0 g
s
.50615 .36787 m .52231 .37687 L .5115 .39042 L p .691 .688 .843 r
F P
0 g
s
.5115 .39042 m .49538 .38151 L .50615 .36787 L p .691 .688 .843 r
F P
0 g
s
.49545 .39229 m .51169 .40123 L .5009 .41471 L p .69 .689 .844 r
F P
0 g
s
.5066 .40054 m .50452 .25007 L .51942 .25869 L p .839 .463 .341 r
F P
0 g
s
.517 .42352 m .5009 .41471 L .51169 .40123 L p .69 .689 .844 r
F P
0 g
s
.51942 .25869 m .52312 .40963 L .5066 .40054 L p .839 .463 .341 r
F P
0 g
s
.53427 .39581 m .52312 .40963 L .51942 .25869 L p .108 0 .308 r
F P
0 g
s
.51942 .25869 m .52946 .24559 L .53427 .39581 L p .108 0 .308 r
F P
0 g
s
.50615 .36787 m .50452 .25007 L .51942 .25869 L p .839 .463 .341 r
F P
0 g
s
.51942 .25869 m .52231 .37687 L .50615 .36787 L p .839 .463 .341 r
F P
0 g
s
.53427 .39581 m .52312 .40963 L .51942 .25869 L p .108 0 .308 r
F P
0 g
s
.51942 .25869 m .52946 .24559 L .53427 .39581 L p .108 0 .308 r
F P
0 g
s
.57956 .23658 m .59431 .24528 L .584 .25838 L p .694 .677 .829 r
F P
0 g
s
.584 .25838 m .56928 .24976 L .57956 .23658 L p .694 .677 .829 r
F P
0 g
s
.57843 .40021 m .56928 .24976 L .584 .25838 L p .839 .457 .326 r
F P
0 g
s
.584 .25838 m .59473 .4093 L .57843 .40021 L p .839 .457 .326 r
F P
0 g
s
.60622 .39548 m .59473 .4093 L .584 .25838 L p .145 0 .337 r
F P
0 g
s
.584 .25838 m .59431 .24528 L .60622 .39548 L p .145 0 .337 r
F P
0 g
s
.57843 .40021 m .56928 .24976 L .584 .25838 L p .839 .457 .326 r
F P
0 g
s
.584 .25838 m .59473 .4093 L .57843 .40021 L p .839 .457 .326 r
F P
0 g
s
.61174 .46518 m .5997 .47929 L .584 .25838 L p .145 0 .337 r
F P
0 g
s
.584 .25838 m .59431 .24528 L .61174 .46518 L p .145 0 .337 r
F P
0 g
s
.6446 .23627 m .65918 .24496 L .64859 .25807 L p .694 .677 .829 r
F P
0 g
s
.64859 .25807 m .63405 .24945 L .6446 .23627 L p .694 .677 .829 r
F P
0 g
s
.65522 .44571 m .63405 .24945 L .64859 .25807 L p .839 .45 .311 r
F P
0 g
s
.64859 .25807 m .67176 .45494 L .65522 .44571 L p .839 .45 .311 r
F P
0 g
s
.68397 .44091 m .67176 .45494 L .64859 .25807 L p .18 0 .362 r
F P
0 g
s
.64859 .25807 m .65918 .24496 L .68397 .44091 L p .18 0 .362 r
F P
0 g
s
.65913 .48193 m .63405 .24945 L .64859 .25807 L p .839 .45 .311 r
F P
0 g
s
.64859 .25807 m .67604 .49125 L .65913 .48193 L p .839 .45 .311 r
F P
0 g
s
.68397 .44091 m .67176 .45494 L .64859 .25807 L p .18 0 .362 r
F P
0 g
s
.64859 .25807 m .65918 .24496 L .68397 .44091 L p .18 0 .362 r
F P
0 g
s
.70967 .23595 m .72406 .24465 L .7132 .25776 L p .694 .677 .829 r
F P
0 g
s
.7132 .25776 m .69883 .24914 L .70967 .23595 L p .694 .677 .829 r
F P
0 g
s
.73295 .46934 m .69883 .24914 L .7132 .25776 L p .839 .442 .294 r
F P
0 g
s
.7132 .25776 m .7495 .47863 L .73295 .46934 L p .839 .442 .294 r
F P
0 g
s
.76228 .46451 m .7495 .47863 L .7132 .25776 L p .211 .017 .385 r
F P
0 g
s
.7132 .25776 m .72406 .24465 L .76228 .46451 L p .211 .017 .385 r
F P
0 g
s
.73678 .49404 m .69883 .24914 L .7132 .25776 L p .839 .442 .294 r
F P
0 g
s
.7132 .25776 m .75357 .50339 L .73678 .49404 L p .839 .442 .294 r
F P
0 g
s
.76657 .48918 m .75357 .50339 L .7132 .25776 L p .211 .017 .385 r
F P
0 g
s
.7132 .25776 m .72406 .24465 L .76657 .48918 L p .211 .017 .385 r
F P
0 g
s
.81566 .50634 m .76363 .24883 L .77782 .25745 L p .839 .434 .276 r
F P
0 g
s
.77782 .25745 m .83232 .51573 L .81566 .50634 L p .839 .434 .276 r
F P
0 g
s
.27918 .23363 m .2948 .24234 L .28574 .25547 L p .694 .677 .829 r
F P
0 g
s
.28574 .25547 m .27017 .24683 L .27918 .23363 L p .694 .677 .829 r
F P
0 g
s
.24663 .39712 m .27017 .24683 L .28574 .25547 L p .835 .482 .386 r
F P
0 g
s
.28574 .25547 m .26397 .40624 L .24663 .39712 L p .835 .482 .386 r
F P
0 g
s
.28268 .40419 m .26557 .39517 L .27545 .38136 L p .69 .69 .845 r
F P
0 g
s
.27392 .39238 m .26397 .40624 L .28574 .25547 L p 0 0 .171 r
F P
0 g
s
.28574 .25547 m .2948 .24234 L .27392 .39238 L p 0 0 .171 r
F P
0 g
s
.24663 .39712 m .27017 .24683 L .28574 .25547 L p .835 .482 .386 r
F P
0 g
s
.28574 .25547 m .26397 .40624 L .24663 .39712 L p .835 .482 .386 r
F P
0 g
s
.27545 .38136 m .26557 .39517 L .28574 .25547 L p 0 0 .171 r
F P
0 g
s
.28574 .25547 m .2948 .24234 L .27545 .38136 L p 0 0 .171 r
F P
0 g
s
.34426 .23332 m .35969 .24203 L .35036 .25516 L p .694 .677 .829 r
F P
0 g
s
.35036 .25516 m .33497 .24652 L .34426 .23332 L p .694 .677 .829 r
F P
0 g
s
.32209 .36417 m .33497 .24652 L .35036 .25516 L p .836 .477 .374 r
F P
0 g
s
.35036 .25516 m .33883 .37319 L .32209 .36417 L p .836 .477 .374 r
F P
0 g
s
.34891 .35947 m .33883 .37319 L .35036 .25516 L p 0 0 .214 r
F P
0 g
s
.35036 .25516 m .35969 .24203 L .34891 .35947 L p 0 0 .214 r
F P
0 g
s
.32092 .37489 m .33497 .24652 L .35036 .25516 L p .836 .477 .374 r
F P
0 g
s
.35036 .25516 m .33778 .38394 L .32092 .37489 L p .836 .477 .374 r
F P
0 g
s
.34793 .37018 m .33778 .38394 L .35036 .25516 L p 0 0 .214 r
F P
0 g
s
.35036 .25516 m .35969 .24203 L .34793 .37018 L p 0 0 .214 r
F P
0 g
s
.40936 .233 m .42461 .24172 L .415 .25485 L p .694 .677 .829 r
F P
0 g
s
.415 .25485 m .39979 .24621 L .40936 .233 L p .694 .677 .829 r
F P
0 g
s
.39042 .39647 m .39979 .24621 L .415 .25485 L p .837 .472 .362 r
F P
0 g
s
.415 .25485 m .40732 .40558 L .39042 .39647 L p .837 .472 .362 r
F P
0 g
s
.43174 .39346 m .41556 .38466 L .42584 .3712 L p .691 .687 .841 r
F P
0 g
s
.42626 .36072 m .41006 .35181 L .42032 .3382 L p .691 .686 .84 r
F P
0 g
s
.40953 .36226 m .42584 .3712 L .41556 .38466 L p .691 .687 .841 r
F P
0 g
s
.41794 .39172 m .40732 .40558 L .415 .25485 L p .036 0 .253 r
F P
0 g
s
.415 .25485 m .42461 .24172 L .41794 .39172 L p .036 0 .253 r
F P
0 g
s
.39042 .39647 m .39979 .24621 L .415 .25485 L p .837 .472 .362 r
F P
0 g
s
.415 .25485 m .40732 .40558 L .39042 .39647 L p .837 .472 .362 r
F P
0 g
s
.42032 .3382 m .41006 .35181 L .415 .25485 L p .036 0 .253 r
F P
0 g
s
.415 .25485 m .42461 .24172 L .42032 .3382 L p .036 0 .253 r
F P
0 g
s
.47446 .23269 m .48953 .2414 L .47965 .25454 L p .694 .677 .829 r
F P
0 g
s
.47965 .25454 m .46462 .2459 L .47446 .23269 L p .694 .677 .829 r
F P
0 g
s
.46315 .34253 m .46462 .2459 L .47965 .25454 L p .838 .466 .348 r
F P
0 g
s
.47965 .25454 m .47924 .35149 L .46315 .34253 L p .838 .466 .348 r
F P
0 g
s
.48982 .33787 m .47924 .35149 L .47965 .25454 L p .08 0 .287 r
F P
0 g
s
.47965 .25454 m .48953 .2414 L .48982 .33787 L p .08 0 .287 r
F P
0 g
s
.46299 .35295 m .46462 .2459 L .47965 .25454 L p .838 .466 .348 r
F P
0 g
s
.47965 .25454 m .4792 .36194 L .46299 .35295 L p .838 .466 .348 r
F P
0 g
s
.48985 .34827 m .4792 .36194 L .47965 .25454 L p .08 0 .287 r
F P
0 g
s
.47965 .25454 m .48953 .2414 L .48985 .34827 L p .08 0 .287 r
F P
0 g
s
.53958 .23237 m .55447 .24109 L .54431 .25423 L p .694 .677 .829 r
F P
0 g
s
.54431 .25423 m .52946 .24559 L .53958 .23237 L p .694 .677 .829 r
F P
0 g
s
.53427 .39581 m .52946 .24559 L .54431 .25423 L p .839 .46 .334 r
F P
0 g
s
.54431 .25423 m .55073 .40493 L .53427 .39581 L p .839 .46 .334 r
F P
0 g
s
.5665 .4029 m .55026 .39387 L .56147 .38005 L p .69 .69 .845 r
F P
0 g
s
.56203 .39106 m .55073 .40493 L .54431 .25423 L p .121 0 .318 r
F P
0 g
s
.54431 .25423 m .55447 .24109 L .56203 .39106 L p .121 0 .318 r
F P
0 g
s
.53427 .39581 m .52946 .24559 L .54431 .25423 L p .839 .46 .334 r
F P
0 g
s
.54431 .25423 m .55073 .40493 L .53427 .39581 L p .839 .46 .334 r
F P
0 g
s
.56147 .38005 m .55026 .39387 L .54431 .25423 L p .121 0 .318 r
F P
0 g
s
.54431 .25423 m .55447 .24109 L .56147 .38005 L p .121 0 .318 r
F P
0 g
s
.60471 .23206 m .61942 .24078 L .60899 .25392 L p .694 .677 .829 r
F P
0 g
s
.60899 .25392 m .59431 .24528 L .60471 .23206 L p .694 .677 .829 r
F P
0 g
s
.61079 .45312 m .59431 .24528 L .60899 .25392 L p .839 .453 .319 r
F P
0 g
s
.60899 .25392 m .62762 .46241 L .61079 .45312 L p .839 .453 .319 r
F P
0 g
s
.63973 .44829 m .62762 .46241 L .60899 .25392 L p .157 0 .346 r
F P
0 g
s
.60899 .25392 m .61942 .24078 L .63973 .44829 L p .157 0 .346 r
F P
0 g
s
.61174 .46518 m .59431 .24528 L .60899 .25392 L p .839 .453 .319 r
F P
0 g
s
.60899 .25392 m .6287 .47449 L .61174 .46518 L p .839 .453 .319 r
F P
0 g
s
.64091 .46033 m .6287 .47449 L .60899 .25392 L p .157 0 .346 r
F P
0 g
s
.60899 .25392 m .61942 .24078 L .64091 .46033 L p .157 0 .346 r
F P
0 g
s
.66986 .23175 m .68439 .24047 L .67368 .25361 L p .694 .677 .829 r
F P
0 g
s
.67368 .25361 m .65918 .24496 L .66986 .23175 L p .694 .677 .829 r
F P
0 g
s
.68397 .44091 m .65918 .24496 L .67368 .25361 L p .84 .446 .302 r
F P
0 g
s
.67368 .25361 m .70045 .45017 L .68397 .44091 L p .84 .446 .302 r
F P
0 g
s
.71283 .4361 m .70045 .45017 L .67368 .25361 L p .19 0 .37 r
F P
0 g
s
.67368 .25361 m .68439 .24047 L .71283 .4361 L p .19 0 .37 r
F P
0 g
s
.68397 .44091 m .65918 .24496 L .67368 .25361 L p .84 .446 .302 r
F P
0 g
s
.67368 .25361 m .70045 .45017 L .68397 .44091 L p .84 .446 .302 r
F P
0 g
s
.71808 .47222 m .70539 .48643 L .67368 .25361 L p .19 0 .37 r
F P
0 g
s
.67368 .25361 m .68439 .24047 L .71808 .47222 L p .19 0 .37 r
F P
0 g
s
.73502 .23143 m .74936 .24015 L .73838 .2533 L p .694 .677 .829 r
F P
0 g
s
.73838 .2533 m .72406 .24465 L .73502 .23143 L p .694 .677 .829 r
F P
0 g
s
.76441 .47675 m .72406 .24465 L .73838 .2533 L p .839 .438 .285 r
F P
0 g
s
.73838 .2533 m .781 .4861 L .76441 .47675 L p .839 .438 .285 r
F P
0 g
s
.79406 .47188 m .781 .4861 L .73838 .2533 L p .22 .027 .392 r
F P
0 g
s
.73838 .2533 m .74936 .24015 L .79406 .47188 L p .22 .027 .392 r
F P
0 g
s
.76657 .48918 m .72406 .24465 L .73838 .2533 L p .839 .438 .285 r
F P
0 g
s
.73838 .2533 m .78329 .49856 L .76657 .48918 L p .839 .438 .285 r
F P
0 g
s
.79646 .48429 m .78329 .49856 L .73838 .2533 L p .22 .027 .392 r
F P
0 g
s
.73838 .2533 m .74936 .24015 L .79646 .48429 L p .22 .027 .392 r
F P
0 g
s
.22918 .38795 m .21943 .40185 L .24561 .25131 L p 0 0 .14 r
F P
0 g
s
.24561 .25131 m .25451 .23815 L .22918 .38795 L p 0 0 .14 r
F P
0 g
s
.30393 .2291 m .31949 .23784 L .31032 .251 L p .694 .677 .829 r
F P
0 g
s
.31032 .251 m .2948 .24234 L .30393 .2291 L p .694 .677 .829 r
F P
0 g
s
.27545 .38136 m .29261 .39047 L .28268 .40419 L p .69 .69 .845 r
F P
0 g
s
.27392 .39238 m .2948 .24234 L .31032 .251 L p .836 .479 .38 r
F P
0 g
s
.31032 .251 m .2912 .40152 L .27392 .39238 L p .836 .479 .38 r
F P
0 g
s
.30129 .38762 m .2912 .40152 L .31032 .251 L p 0 0 .186 r
F P
0 g
s
.31032 .251 m .31949 .23784 L .30129 .38762 L p 0 0 .186 r
F P
0 g
s
.27545 .38136 m .2948 .24234 L .31032 .251 L p .836 .479 .38 r
F P
0 g
s
.31032 .251 m .29261 .39047 L .27545 .38136 L p .836 .479 .38 r
F P
0 g
s
.30129 .38762 m .2912 .40152 L .31032 .251 L p 0 0 .186 r
F P
0 g
s
.31032 .251 m .31949 .23784 L .30129 .38762 L p 0 0 .186 r
F P
0 g
s
.36911 .22879 m .38449 .23752 L .37504 .25069 L p .694 .677 .829 r
F P
0 g
s
.37504 .25069 m .35969 .24203 L .36911 .22879 L p .694 .677 .829 r
F P
0 g
s
.33778 .38394 m .35455 .39293 L .34445 .40648 L p .69 .689 .844 r
F P
0 g
s
.34793 .37018 m .36474 .37926 L .35455 .39293 L p .69 .689 .844 r
F P
0 g
s
.35455 .39293 m .33778 .38394 L .34793 .37018 L p .69 .689 .844 r
F P
0 g
s
.34592 .39205 m .35969 .24203 L .37504 .25069 L p .837 .474 .368 r
F P
0 g
s
.37504 .25069 m .36298 .40119 L .34592 .39205 L p .837 .474 .368 r
F P
0 g
s
.37341 .38729 m .36298 .40119 L .37504 .25069 L p .004 0 .228 r
F P
0 g
s
.37504 .25069 m .38449 .23752 L .37341 .38729 L p .004 0 .228 r
F P
0 g
s
.34793 .37018 m .35969 .24203 L .37504 .25069 L p .837 .474 .368 r
F P
0 g
s
.37504 .25069 m .36474 .37926 L .34793 .37018 L p .837 .474 .368 r
F P
0 g
s
.37341 .38729 m .36298 .40119 L .37504 .25069 L p .004 0 .228 r
F P
0 g
s
.37504 .25069 m .38449 .23752 L .37341 .38729 L p .004 0 .228 r
F P
0 g
s
.4343 .22847 m .4495 .23721 L .43977 .25038 L p .694 .677 .829 r
F P
0 g
s
.43977 .25038 m .42461 .24172 L .4343 .22847 L p .694 .677 .829 r
F P
0 g
s
.42078 .32794 m .42461 .24172 L .43977 .25038 L p .838 .469 .355 r
F P
0 g
s
.43977 .25038 m .4369 .33689 L .42078 .32794 L p .838 .469 .355 r
F P
0 g
s
.44723 .32328 m .4369 .33689 L .43977 .25038 L p .051 0 .265 r
F P
0 g
s
.43977 .25038 m .4495 .23721 L .44723 .32328 L p .051 0 .265 r
F P
0 g
s
.42032 .3382 m .42461 .24172 L .43977 .25038 L p .838 .469 .355 r
F P
0 g
s
.43977 .25038 m .43656 .34718 L .42032 .3382 L p .838 .469 .355 r
F P
0 g
s
.44723 .32328 m .4369 .33689 L .43977 .25038 L p .051 0 .265 r
F P
0 g
s
.43977 .25038 m .4495 .23721 L .44723 .32328 L p .051 0 .265 r
F P
0 g
s
.4995 .22816 m .51452 .2369 L .50452 .25007 L p .694 .677 .829 r
F P
0 g
s
.50452 .25007 m .48953 .2414 L .4995 .22816 L p .694 .677 .829 r
F P
0 g
s
.4792 .36194 m .49531 .37088 L .48471 .38434 L p .691 .687 .841 r
F P
0 g
s
.48985 .34827 m .506 .35729 L .49531 .37088 L p .691 .687 .841 r
F P
0 g
s
.49531 .37088 m .4792 .36194 L .48985 .34827 L p .691 .687 .841 r
F P
0 g
s
.48998 .39139 m .48953 .2414 L .50452 .25007 L p .839 .463 .341 r
F P
0 g
s
.5009 .41471 m .4847 .40584 L .49545 .39229 L p .69 .689 .844 r
F P
0 g
s
.50452 .25007 m .5066 .40054 L .48998 .39139 L p .839 .463 .341 r
F P
0 g
s
.51771 .38663 m .5066 .40054 L .50452 .25007 L p .094 0 .298 r
F P
0 g
s
.50452 .25007 m .51452 .2369 L .51771 .38663 L p .094 0 .298 r
F P
0 g
s
.48985 .34827 m .48953 .2414 L .50452 .25007 L p .839 .463 .341 r
F P
0 g
s
.50452 .25007 m .506 .35729 L .48985 .34827 L p .839 .463 .341 r
F P
0 g
s
.51771 .38663 m .5066 .40054 L .50452 .25007 L p .094 0 .298 r
F P
0 g
s
.50452 .25007 m .51452 .2369 L .51771 .38663 L p .094 0 .298 r
F P
0 g
s
.56472 .22784 m .57956 .23658 L .56928 .24976 L p .694 .677 .829 r
F P
0 g
s
.56928 .24976 m .55447 .24109 L .56472 .22784 L p .694 .677 .829 r
F P
0 g
s
.56147 .38005 m .57776 .38917 L .5665 .4029 L p .69 .69 .845 r
F P
0 g
s
.56203 .39106 m .55447 .24109 L .56928 .24976 L p .839 .457 .326 r
F P
0 g
s
.56928 .24976 m .57843 .40021 L .56203 .39106 L p .839 .457 .326 r
F P
0 g
s
.58988 .3863 m .57843 .40021 L .56928 .24976 L p .133 0 .328 r
F P
0 g
s
.56928 .24976 m .57956 .23658 L .58988 .3863 L p .133 0 .328 r
F P
0 g
s
.56147 .38005 m .55447 .24109 L .56928 .24976 L p .839 .457 .326 r
F P
0 g
s
.56928 .24976 m .57776 .38917 L .56147 .38005 L p .839 .457 .326 r
F P
0 g
s
.58988 .3863 m .57843 .40021 L .56928 .24976 L p .133 0 .328 r
F P
0 g
s
.56928 .24976 m .57956 .23658 L .58988 .3863 L p .133 0 .328 r
F P
0 g
s
.62995 .22752 m .6446 .23627 L .63405 .24945 L p .694 .677 .829 r
F P
0 g
s
.63405 .24945 m .61942 .24078 L .62995 .22752 L p .694 .677 .829 r
F P
0 g
s
.63857 .43643 m .61942 .24078 L .63405 .24945 L p .839 .45 .311 r
F P
0 g
s
.63405 .24945 m .65522 .44571 L .63857 .43643 L p .839 .45 .311 r
F P
0 g
s
.66739 .4316 m .65522 .44571 L .63405 .24945 L p .169 0 .354 r
F P
0 g
s
.63405 .24945 m .6446 .23627 L .66739 .4316 L p .169 0 .354 r
F P
0 g
s
.64091 .46033 m .61942 .24078 L .63405 .24945 L p .839 .45 .311 r
F P
0 g
s
.63405 .24945 m .6578 .46968 L .64091 .46033 L p .839 .45 .311 r
F P
0 g
s
.66739 .4316 m .65522 .44571 L .63405 .24945 L p .169 0 .354 r
F P
0 g
s
.63405 .24945 m .6446 .23627 L .66739 .4316 L p .169 0 .354 r
F P
0 g
s
.69519 .22721 m .70967 .23595 L .69883 .24914 L p .694 .677 .829 r
F P
0 g
s
.69883 .24914 m .68439 .24047 L .69519 .22721 L p .694 .677 .829 r
F P
0 g
s
.7163 .45999 m .68439 .24047 L .69883 .24914 L p .839 .442 .294 r
F P
0 g
s
.69883 .24914 m .73295 .46934 L .7163 .45999 L p .839 .442 .294 r
F P
0 g
s
.74569 .45513 m .73295 .46934 L .69883 .24914 L p .201 .006 .378 r
F P
0 g
s
.69883 .24914 m .70967 .23595 L .74569 .45513 L p .201 .006 .378 r
F P
0 g
s
.71808 .47222 m .68439 .24047 L .69883 .24914 L p .839 .442 .294 r
F P
0 g
s
.69883 .24914 m .73485 .4816 L .71808 .47222 L p .839 .442 .294 r
F P
0 g
s
.74569 .45513 m .73295 .46934 L .69883 .24914 L p .201 .006 .378 r
F P
0 g
s
.69883 .24914 m .70967 .23595 L .74569 .45513 L p .201 .006 .378 r
F P
0 g
s
.79646 .48429 m .74936 .24015 L .76363 .24883 L p .839 .434 .276 r
F P
0 g
s
.76363 .24883 m .81311 .49371 L .79646 .48429 L p .839 .434 .276 r
F P
0 g
s
.26348 .22487 m .27918 .23363 L .27017 .24683 L p .694 .677 .829 r
F P
0 g
s
.27017 .24683 m .25451 .23815 L .26348 .22487 L p .694 .677 .829 r
F P
0 g
s
.23104 .37695 m .25451 .23815 L .27017 .24683 L p .835 .482 .386 r
F P
0 g
s
.27017 .24683 m .24836 .38609 L .23104 .37695 L p .835 .482 .386 r
F P
0 g
s
.25819 .3722 m .24836 .38609 L .27017 .24683 L p 0 0 .156 r
F P
0 g
s
.27017 .24683 m .27918 .23363 L .25819 .3722 L p 0 0 .156 r
F P
0 g
s
.22918 .38795 m .25451 .23815 L .27017 .24683 L p .835 .482 .386 r
F P
0 g
s
.27017 .24683 m .24663 .39712 L .22918 .38795 L p .835 .482 .386 r
F P
0 g
s
.25653 .38318 m .24663 .39712 L .27017 .24683 L p 0 0 .156 r
F P
0 g
s
.27017 .24683 m .27918 .23363 L .25653 .38318 L p 0 0 .156 r
F P
0 g
s
.32875 .22456 m .34426 .23332 L .33497 .24652 L p .694 .677 .829 r
F P
0 g
s
.33497 .24652 m .31949 .23784 L .32875 .22456 L p .694 .677 .829 r
F P
0 g
s
.30129 .38762 m .31949 .23784 L .33497 .24652 L p .836 .477 .374 r
F P
0 g
s
.33497 .24652 m .31852 .39679 L .30129 .38762 L p .836 .477 .374 r
F P
0 g
s
.33883 .37319 m .32209 .36417 L .33212 .35037 L p .691 .688 .843 r
F P
0 g
s
.32092 .37489 m .33778 .38394 L .32773 .39757 L p .69 .689 .844 r
F P
0 g
s
.32875 .38285 m .31852 .39679 L .33497 .24652 L p 0 0 .2 r
F P
0 g
s
.33497 .24652 m .34426 .23332 L .32875 .38285 L p 0 0 .2 r
F P
0 g
s
.30129 .38762 m .31949 .23784 L .33497 .24652 L p .836 .477 .374 r
F P
0 g
s
.33497 .24652 m .31852 .39679 L .30129 .38762 L p .836 .477 .374 r
F P
0 g
s
.33212 .35037 m .32209 .36417 L .33497 .24652 L p 0 0 .2 r
F P
0 g
s
.33497 .24652 m .34426 .23332 L .33212 .35037 L p 0 0 .2 r
F P
0 g
s
.39402 .22424 m .40936 .233 L .39979 .24621 L p .694 .677 .829 r
F P
0 g
s
.39979 .24621 m .38449 .23752 L .39402 .22424 L p .694 .677 .829 r
F P
0 g
s
.37423 .37629 m .38449 .23752 L .39979 .24621 L p .837 .472 .362 r
F P
0 g
s
.39979 .24621 m .39111 .38543 L .37423 .37629 L p .837 .472 .362 r
F P
0 g
s
.40161 .37154 m .39111 .38543 L .39979 .24621 L p .02 0 .24 r
F P
0 g
s
.39979 .24621 m .40936 .233 L .40161 .37154 L p .02 0 .24 r
F P
0 g
s
.37341 .38729 m .38449 .23752 L .39979 .24621 L p .837 .472 .362 r
F P
0 g
s
.39979 .24621 m .39042 .39647 L .37341 .38729 L p .837 .472 .362 r
F P
0 g
s
.40099 .38252 m .39042 .39647 L .39979 .24621 L p .02 0 .24 r
F P
0 g
s
.39979 .24621 m .40936 .233 L .40099 .38252 L p .02 0 .24 r
F P
0 g
s
.45931 .22393 m .47446 .23269 L .46462 .2459 L p .694 .677 .829 r
F P
0 g
s
.46462 .2459 m .4495 .23721 L .45931 .22393 L p .694 .677 .829 r
F P
0 g
s
.44723 .32328 m .4495 .23721 L .46462 .2459 L p .838 .466 .348 r
F P
0 g
s
.46462 .2459 m .46331 .33226 L .44723 .32328 L p .838 .466 .348 r
F P
0 g
s
.47377 .31861 m .46331 .33226 L .46462 .2459 L p .066 0 .276 r
F P
0 g
s
.46462 .2459 m .47446 .23269 L .47377 .31861 L p .066 0 .276 r
F P
0 g
s
.44723 .32328 m .4495 .23721 L .46462 .2459 L p .838 .466 .348 r
F P
0 g
s
.46462 .2459 m .46331 .33226 L .44723 .32328 L p .838 .466 .348 r
F P
0 g
s
.47368 .32883 m .46315 .34253 L .46462 .2459 L p .066 0 .276 r
F P
0 g
s
.46462 .2459 m .47446 .23269 L .47368 .32883 L p .066 0 .276 r
F P
0 g
s
.52461 .22361 m .53958 .23237 L .52946 .24559 L p .694 .677 .829 r
F P
0 g
s
.52946 .24559 m .51452 .2369 L .52461 .22361 L p .694 .677 .829 r
F P
0 g
s
.51747 .37563 m .51452 .2369 L .52946 .24559 L p .839 .46 .334 r
F P
0 g
s
.52946 .24559 m .53392 .38478 L .51747 .37563 L p .839 .46 .334 r
F P
0 g
s
.54509 .37087 m .53392 .38478 L .52946 .24559 L p .108 0 .308 r
F P
0 g
s
.52946 .24559 m .53958 .23237 L .54509 .37087 L p .108 0 .308 r
F P
0 g
s
.51771 .38663 m .51452 .2369 L .52946 .24559 L p .839 .46 .334 r
F P
0 g
s
.52946 .24559 m .53427 .39581 L .51771 .38663 L p .839 .46 .334 r
F P
0 g
s
.54553 .38185 m .53427 .39581 L .52946 .24559 L p .108 0 .308 r
F P
0 g
s
.52946 .24559 m .53958 .23237 L .54553 .38185 L p .108 0 .308 r
F P
0 g
s
.58992 .22329 m .60471 .23206 L .59431 .24528 L p .694 .677 .829 r
F P
0 g
s
.59431 .24528 m .57956 .23658 L .58992 .22329 L p .694 .677 .829 r
F P
0 g
s
.58988 .3863 m .57956 .23658 L .59431 .24528 L p .839 .453 .319 r
F P
0 g
s
.59431 .24528 m .60622 .39548 L .58988 .3863 L p .839 .453 .319 r
F P
0 g
s
.61782 .38152 m .60622 .39548 L .59431 .24528 L p .145 0 .337 r
F P
0 g
s
.59431 .24528 m .60471 .23206 L .61782 .38152 L p .145 0 .337 r
F P
0 g
s
.58988 .3863 m .57956 .23658 L .59431 .24528 L p .839 .453 .319 r
F P
0 g
s
.59431 .24528 m .60622 .39548 L .58988 .3863 L p .839 .453 .319 r
F P
0 g
s
.62285 .43892 m .61079 .45312 L .59431 .24528 L p .145 0 .337 r
F P
0 g
s
.59431 .24528 m .60471 .23206 L .62285 .43892 L p .145 0 .337 r
F P
0 g
s
.65525 .22298 m .66986 .23175 L .65918 .24496 L p .694 .677 .829 r
F P
0 g
s
.65918 .24496 m .6446 .23627 L .65525 .22298 L p .694 .677 .829 r
F P
0 g
s
.66603 .41994 m .6446 .23627 L .65918 .24496 L p .84 .446 .302 r
F P
0 g
s
.65918 .24496 m .68249 .42922 L .66603 .41994 L p .84 .446 .302 r
F P
0 g
s
.69473 .41511 m .68249 .42922 L .65918 .24496 L p .18 0 .362 r
F P
0 g
s
.65918 .24496 m .66986 .23175 L .69473 .41511 L p .18 0 .362 r
F P
0 g
s
.66739 .4316 m .6446 .23627 L .65918 .24496 L p .84 .446 .302 r
F P
0 g
s
.65918 .24496 m .68397 .44091 L .66739 .4316 L p .84 .446 .302 r
F P
0 g
s
.69631 .42676 m .68397 .44091 L .65918 .24496 L p .18 0 .362 r
F P
0 g
s
.65918 .24496 m .66986 .23175 L .69631 .42676 L p .18 0 .362 r
F P
0 g
s
.72059 .22266 m .73502 .23143 L .72406 .24465 L p .694 .677 .829 r
F P
0 g
s
.72406 .24465 m .70967 .23595 L .72059 .22266 L p .694 .677 .829 r
F P
0 g
s
.74569 .45513 m .70967 .23595 L .72406 .24465 L p .839 .438 .285 r
F P
0 g
s
.72406 .24465 m .76228 .46451 L .74569 .45513 L p .839 .438 .285 r
F P
0 g
s
.77519 .45025 m .76228 .46451 L .72406 .24465 L p .211 .017 .385 r
F P
0 g
s
.72406 .24465 m .73502 .23143 L .77519 .45025 L p .211 .017 .385 r
F P
0 g
s
.74569 .45513 m .70967 .23595 L .72406 .24465 L p .839 .438 .285 r
F P
0 g
s
.72406 .24465 m .76228 .46451 L .74569 .45513 L p .839 .438 .285 r
F P
0 g
s
.77743 .46244 m .76441 .47675 L .72406 .24465 L p .211 .017 .385 r
F P
0 g
s
.72406 .24465 m .73502 .23143 L .77743 .46244 L p .211 .017 .385 r
F P
0 g
s
.28828 .22032 m .30393 .2291 L .2948 .24234 L p .694 .677 .829 r
F P
0 g
s
.2948 .24234 m .27918 .23363 L .28828 .22032 L p .694 .677 .829 r
F P
0 g
s
.25983 .36137 m .27918 .23363 L .2948 .24234 L p .836 .479 .38 r
F P
0 g
s
.2948 .24234 m .27696 .3705 L .25983 .36137 L p .836 .479 .38 r
F P
0 g
s
.28687 .35662 m .27696 .3705 L .2948 .24234 L p 0 0 .171 r
F P
0 g
s
.2948 .24234 m .30393 .2291 L .28687 .35662 L p 0 0 .171 r
F P
0 g
s
.25653 .38318 m .27918 .23363 L .2948 .24234 L p .836 .479 .38 r
F P
0 g
s
.2948 .24234 m .27392 .39238 L .25653 .38318 L p .836 .479 .38 r
F P
0 g
s
.28396 .3784 m .27392 .39238 L .2948 .24234 L p 0 0 .171 r
F P
0 g
s
.2948 .24234 m .30393 .2291 L .28396 .3784 L p 0 0 .171 r
F P
0 g
s
.35363 .22 m .36911 .22879 L .35969 .24203 L p .694 .677 .829 r
F P
0 g
s
.35969 .24203 m .34426 .23332 L .35363 .22 L p .694 .677 .829 r
F P
0 g
s
.33212 .35037 m .34891 .35947 L .33883 .37319 L p .691 .688 .843 r
F P
0 g
s
.32875 .38285 m .34426 .23332 L .35969 .24203 L p .837 .474 .368 r
F P
0 g
s
.34445 .40648 m .32773 .39757 L .33778 .38394 L p .69 .689 .844 r
F P
0 g
s
.35969 .24203 m .34592 .39205 L .32875 .38285 L p .837 .474 .368 r
F P
0 g
s
.3563 .37806 m .34592 .39205 L .35969 .24203 L p 0 0 .214 r
F P
0 g
s
.35969 .24203 m .36911 .22879 L .3563 .37806 L p 0 0 .214 r
F P
0 g
s
.33212 .35037 m .34426 .23332 L .35969 .24203 L p .837 .474 .368 r
F P
0 g
s
.35969 .24203 m .34891 .35947 L .33212 .35037 L p .837 .474 .368 r
F P
0 g
s
.3563 .37806 m .34592 .39205 L .35969 .24203 L p 0 0 .214 r
F P
0 g
s
.35969 .24203 m .36911 .22879 L .3563 .37806 L p 0 0 .214 r
F P
0 g
s
.41901 .21968 m .4343 .22847 L .42461 .24172 L p .694 .677 .829 r
F P
0 g
s
.42461 .24172 m .40936 .233 L .41901 .21968 L p .694 .677 .829 r
F P
0 g
s
.40099 .38252 m .40936 .233 L .42461 .24172 L p .838 .469 .355 r
F P
0 g
s
.42461 .24172 m .41794 .39172 L .40099 .38252 L p .838 .469 .355 r
F P
0 g
s
.4369 .33689 m .42078 .32794 L .43106 .31425 L p .692 .685 .839 r
F P
0 g
s
.42584 .3712 m .44206 .38008 L .43174 .39346 L p .691 .687 .841 r
F P
0 g
s
.42032 .3382 m .43656 .34718 L .42626 .36072 L p .691 .686 .84 r
F P
0 g
s
.44206 .38008 m .42584 .3712 L .43622 .35762 L p .691 .687 .841 r
F P
0 g
s
.42866 .37773 m .41794 .39172 L .42461 .24172 L p .036 0 .253 r
F P
0 g
s
.42461 .24172 m .4343 .22847 L .42866 .37773 L p .036 0 .253 r
F P
0 g
s
.40099 .38252 m .40936 .233 L .42461 .24172 L p .838 .469 .355 r
F P
0 g
s
.42461 .24172 m .41794 .39172 L .40099 .38252 L p .838 .469 .355 r
F P
0 g
s
.43106 .31425 m .42078 .32794 L .42461 .24172 L p .036 0 .253 r
F P
0 g
s
.42461 .24172 m .4343 .22847 L .43106 .31425 L p .036 0 .253 r
F P
0 g
s
.48439 .21937 m .4995 .22816 L .48953 .2414 L p .694 .677 .829 r
F P
0 g
s
.48953 .2414 m .47446 .23269 L .48439 .21937 L p .694 .677 .829 r
F P
0 g
s
.46864 .37549 m .48471 .38434 L .47421 .39769 L p .691 .687 .841 r
F P
0 g
s
.48471 .38434 m .46864 .37549 L .4792 .36194 L p .691 .687 .841 r
F P
0 g
s
.47368 .32883 m .48982 .33787 L .47924 .35149 L p .691 .686 .84 r
F P
0 g
s
.47924 .35149 m .46315 .34253 L .47368 .32883 L p .691 .686 .84 r
F P
0 g
s
.46299 .35295 m .4792 .36194 L .46864 .37549 L p .691 .687 .841 r
F P
0 g
s
.47325 .38219 m .47446 .23269 L .48953 .2414 L p .839 .463 .341 r
F P
0 g
s
.48953 .2414 m .48998 .39139 L .47325 .38219 L p .839 .463 .341 r
F P
0 g
s
.50104 .3774 m .48998 .39139 L .48953 .2414 L p .08 0 .287 r
F P
0 g
s
.48953 .2414 m .4995 .22816 L .50104 .3774 L p .08 0 .287 r
F P
0 g
s
.47368 .32883 m .47446 .23269 L .48953 .2414 L p .839 .463 .341 r
F P
0 g
s
.48953 .2414 m .48982 .33787 L .47368 .32883 L p .839 .463 .341 r
F P
0 g
s
.50104 .3774 m .48998 .39139 L .48953 .2414 L p .08 0 .287 r
F P
0 g
s
.48953 .2414 m .4995 .22816 L .50104 .3774 L p .08 0 .287 r
F P
0 g
s
.54979 .21905 m .56472 .22784 L .55447 .24109 L p .694 .677 .829 r
F P
0 g
s
.55447 .24109 m .53958 .23237 L .54979 .21905 L p .694 .677 .829 r
F P
0 g
s
.54466 .36005 m .53958 .23237 L .55447 .24109 L p .839 .457 .326 r
F P
0 g
s
.55447 .24109 m .56093 .36919 L .54466 .36005 L p .839 .457 .326 r
F P
0 g
s
.57217 .3553 m .56093 .36919 L .55447 .24109 L p .121 0 .318 r
F P
0 g
s
.55447 .24109 m .56472 .22784 L .57217 .3553 L p .121 0 .318 r
F P
0 g
s
.54553 .38185 m .53958 .23237 L .55447 .24109 L p .839 .457 .326 r
F P
0 g
s
.55447 .24109 m .56203 .39106 L .54553 .38185 L p .839 .457 .326 r
F P
0 g
s
.57344 .37706 m .56203 .39106 L .55447 .24109 L p .121 0 .318 r
F P
0 g
s
.55447 .24109 m .56472 .22784 L .57344 .37706 L p .121 0 .318 r
F P
0 g
s
.6152 .21873 m .62995 .22752 L .61942 .24078 L p .694 .677 .829 r
F P
0 g
s
.61942 .24078 m .60471 .23206 L .6152 .21873 L p .694 .677 .829 r
F P
0 g
s
.62181 .42709 m .60471 .23206 L .61942 .24078 L p .839 .45 .311 r
F P
0 g
s
.61942 .24078 m .63857 .43643 L .62181 .42709 L p .839 .45 .311 r
F P
0 g
s
.6507 .42223 m .63857 .43643 L .61942 .24078 L p .157 0 .346 r
F P
0 g
s
.61942 .24078 m .62995 .22752 L .6507 .42223 L p .157 0 .346 r
F P
0 g
s
.62285 .43892 m .60471 .23206 L .61942 .24078 L p .839 .45 .311 r
F P
0 g
s
.61942 .24078 m .63973 .44829 L .62285 .43892 L p .839 .45 .311 r
F P
0 g
s
.6507 .42223 m .63857 .43643 L .61942 .24078 L p .157 0 .346 r
F P
0 g
s
.61942 .24078 m .62995 .22752 L .6507 .42223 L p .157 0 .346 r
F P
0 g
s
.68063 .21841 m .69519 .22721 L .68439 .24047 L p .694 .677 .829 r
F P
0 g
s
.68439 .24047 m .66986 .23175 L .68063 .21841 L p .694 .677 .829 r
F P
0 g
s
.69631 .42676 m .66986 .23175 L .68439 .24047 L p .839 .442 .294 r
F P
0 g
s
.68439 .24047 m .71283 .4361 L .69631 .42676 L p .839 .442 .294 r
F P
0 g
s
.72532 .42189 m .71283 .4361 L .68439 .24047 L p .19 0 .37 r
F P
0 g
s
.68439 .24047 m .69519 .22721 L .72532 .42189 L p .19 0 .37 r
F P
0 g
s
.69631 .42676 m .66986 .23175 L .68439 .24047 L p .839 .442 .294 r
F P
0 g
s
.68439 .24047 m .71283 .4361 L .69631 .42676 L p .839 .442 .294 r
F P
0 g
s
.729 .44569 m .7163 .45999 L .68439 .24047 L p .19 0 .37 r
F P
0 g
s
.68439 .24047 m .69519 .22721 L .729 .44569 L p .19 0 .37 r
F P
0 g
s
.77743 .46244 m .73502 .23143 L .74936 .24015 L p .839 .434 .276 r
F P
0 g
s
.74936 .24015 m .79406 .47188 L .77743 .46244 L p .839 .434 .276 r
F P
0 g
s
.24082 .36298 m .23104 .37695 L .25451 .23815 L p 0 0 .14 r
F P
0 g
s
.25451 .23815 m .26348 .22487 L .24082 .36298 L p 0 0 .14 r
F P
0 g
s
.31314 .21575 m .32875 .22456 L .31949 .23784 L p .694 .677 .829 r
F P
0 g
s
.31949 .23784 m .30393 .2291 L .31314 .21575 L p .694 .677 .829 r
F P
0 g
s
.28542 .36743 m .30393 .2291 L .31949 .23784 L p .836 .477 .374 r
F P
0 g
s
.31949 .23784 m .30263 .37662 L .28542 .36743 L p .836 .477 .374 r
F P
0 g
s
.31274 .36264 m .30263 .37662 L .31949 .23784 L p 0 0 .186 r
F P
0 g
s
.31949 .23784 m .32875 .22456 L .31274 .36264 L p 0 0 .186 r
F P
0 g
s
.28396 .3784 m .30393 .2291 L .31949 .23784 L p .836 .477 .374 r
F P
0 g
s
.31949 .23784 m .30129 .38762 L .28396 .3784 L p .836 .477 .374 r
F P
0 g
s
.31147 .37359 m .30129 .38762 L .31949 .23784 L p 0 0 .186 r
F P
0 g
s
.31949 .23784 m .32875 .22456 L .31147 .37359 L p 0 0 .186 r
F P
0 g
s
.3786 .21543 m .39402 .22424 L .38449 .23752 L p .694 .677 .829 r
F P
0 g
s
.38449 .23752 m .36911 .22879 L .3786 .21543 L p .694 .677 .829 r
F P
0 g
s
.3563 .37806 m .36911 .22879 L .38449 .23752 L p .837 .472 .362 r
F P
0 g
s
.38449 .23752 m .37341 .38729 L .3563 .37806 L p .837 .472 .362 r
F P
0 g
s
.39111 .38543 m .37423 .37629 L .38468 .36231 L p .69 .69 .845 r
F P
0 g
s
.38394 .37326 m .37341 .38729 L .38449 .23752 L p .004 0 .228 r
F P
0 g
s
.38449 .23752 m .39402 .22424 L .38394 .37326 L p .004 0 .228 r
F P
0 g
s
.3563 .37806 m .36911 .22879 L .38449 .23752 L p .837 .472 .362 r
F P
0 g
s
.38449 .23752 m .37341 .38729 L .3563 .37806 L p .837 .472 .362 r
F P
0 g
s
.38468 .36231 m .37423 .37629 L .38449 .23752 L p .004 0 .228 r
F P
0 g
s
.38449 .23752 m .39402 .22424 L .38468 .36231 L p .004 0 .228 r
F P
0 g
s
.44407 .21511 m .45931 .22393 L .4495 .23721 L p .694 .677 .829 r
F P
0 g
s
.4495 .23721 m .4343 .22847 L .44407 .21511 L p .694 .677 .829 r
F P
0 g
s
.43144 .30419 m .4343 .22847 L .4495 .23721 L p .838 .466 .348 r
F P
0 g
s
.4495 .23721 m .4475 .31319 L .43144 .30419 L p .838 .466 .348 r
F P
0 g
s
.45784 .2995 m .4475 .31319 L .4495 .23721 L p .051 0 .265 r
F P
0 g
s
.4495 .23721 m .45931 .22393 L .45784 .2995 L p .051 0 .265 r
F P
0 g
s
.43106 .31425 m .4343 .22847 L .4495 .23721 L p .838 .466 .348 r
F P
0 g
s
.4495 .23721 m .44723 .32328 L .43106 .31425 L p .838 .466 .348 r
F P
0 g
s
.45765 .30955 m .44723 .32328 L .4495 .23721 L p .051 0 .265 r
F P
0 g
s
.4495 .23721 m .45931 .22393 L .45765 .30955 L p .051 0 .265 r
F P
0 g
s
.50955 .21479 m .52461 .22361 L .51452 .2369 L p .694 .677 .829 r
F P
0 g
s
.51452 .2369 m .4995 .22816 L .50955 .21479 L p .694 .677 .829 r
F P
0 g
s
.50104 .3774 m .4995 .22816 L .51452 .2369 L p .839 .46 .334 r
F P
0 g
s
.51452 .2369 m .51771 .38663 L .50104 .3774 L p .839 .46 .334 r
F P
0 g
s
.53392 .38478 m .51747 .37563 L .52861 .36164 L p .69 .69 .845 r
F P
0 g
s
.52892 .37259 m .51771 .38663 L .51452 .2369 L p .094 0 .298 r
F P
0 g
s
.51452 .2369 m .52461 .22361 L .52892 .37259 L p .094 0 .298 r
F P
0 g
s
.50104 .3774 m .4995 .22816 L .51452 .2369 L p .839 .46 .334 r
F P
0 g
s
.51452 .2369 m .51771 .38663 L .50104 .3774 L p .839 .46 .334 r
F P
0 g
s
.52861 .36164 m .51747 .37563 L .51452 .2369 L p .094 0 .298 r
F P
0 g
s
.51452 .2369 m .52461 .22361 L .52861 .36164 L p .094 0 .298 r
F P
0 g
s
.57505 .21448 m .58992 .22329 L .57956 .23658 L p .694 .677 .829 r
F P
0 g
s
.57956 .23658 m .56472 .22784 L .57505 .21448 L p .694 .677 .829 r
F P
0 g
s
.5728 .3661 m .56472 .22784 L .57956 .23658 L p .839 .453 .319 r
F P
0 g
s
.57956 .23658 m .58912 .3753 L .5728 .3661 L p .839 .453 .319 r
F P
0 g
s
.60059 .36131 m .58912 .3753 L .57956 .23658 L p .133 0 .328 r
F P
0 g
s
.57956 .23658 m .58992 .22329 L .60059 .36131 L p .133 0 .328 r
F P
0 g
s
.57344 .37706 m .56472 .22784 L .57956 .23658 L p .839 .453 .319 r
F P
0 g
s
.57956 .23658 m .58988 .3863 L .57344 .37706 L p .839 .453 .319 r
F P
0 g
s
.60144 .37225 m .58988 .3863 L .57956 .23658 L p .133 0 .328 r
F P
0 g
s
.57956 .23658 m .58992 .22329 L .60144 .37225 L p .133 0 .328 r
F P
0 g
s
.64056 .21416 m .65525 .22298 L .6446 .23627 L p .694 .677 .829 r
F P
0 g
s
.6446 .23627 m .62995 .22752 L .64056 .21416 L p .694 .677 .829 r
F P
0 g
s
.6507 .42223 m .62995 .22752 L .6446 .23627 L p .84 .446 .302 r
F P
0 g
s
.6446 .23627 m .66739 .4316 L .6507 .42223 L p .84 .446 .302 r
F P
0 g
s
.68249 .42922 m .66603 .41994 L .67822 .40574 L p .688 .694 .85 r
F P
0 g
s
.67968 .41735 m .66739 .4316 L .6446 .23627 L p .169 0 .354 r
F P
0 g
s
.6446 .23627 m .65525 .22298 L .67968 .41735 L p .169 0 .354 r
F P
0 g
s
.6507 .42223 m .62995 .22752 L .6446 .23627 L p .84 .446 .302 r
F P
0 g
s
.6446 .23627 m .66739 .4316 L .6507 .42223 L p .84 .446 .302 r
F P
0 g
s
.67822 .40574 m .66603 .41994 L .6446 .23627 L p .169 0 .354 r
F P
0 g
s
.6446 .23627 m .65525 .22298 L .67822 .40574 L p .169 0 .354 r
F P
0 g
s
.70608 .21384 m .72059 .22266 L .70967 .23595 L p .694 .677 .829 r
F P
0 g
s
.70967 .23595 m .69519 .22721 L .70608 .21384 L p .694 .677 .829 r
F P
0 g
s
.72715 .4337 m .69519 .22721 L .70967 .23595 L p .839 .438 .285 r
F P
0 g
s
.70967 .23595 m .74372 .44311 L .72715 .4337 L p .839 .438 .285 r
F P
0 g
s
.75648 .4288 m .74372 .44311 L .70967 .23595 L p .201 .006 .378 r
F P
0 g
s
.70967 .23595 m .72059 .22266 L .75648 .4288 L p .201 .006 .378 r
F P
0 g
s
.729 .44569 m .69519 .22721 L .70967 .23595 L p .839 .438 .285 r
F P
0 g
s
.70967 .23595 m .74569 .45513 L .729 .44569 L p .839 .438 .285 r
F P
0 g
s
.75856 .44078 m .74569 .45513 L .70967 .23595 L p .201 .006 .378 r
F P
0 g
s
.70967 .23595 m .72059 .22266 L .75856 .44078 L p .201 .006 .378 r
F P
0 g
s
.27253 .21148 m .28828 .22032 L .27918 .23363 L p .694 .677 .829 r
F P
0 g
s
.27918 .23363 m .26348 .22487 L .27253 .21148 L p .694 .677 .829 r
F P
0 g
s
.24259 .35218 m .26348 .22487 L .27918 .23363 L p .836 .479 .38 r
F P
0 g
s
.27918 .23363 m .25983 .36137 L .24259 .35218 L p .836 .479 .38 r
F P
0 g
s
.26969 .3474 m .25983 .36137 L .27918 .23363 L p 0 0 .156 r
F P
0 g
s
.27918 .23363 m .28828 .22032 L .26969 .3474 L p 0 0 .156 r
F P
0 g
s
.24082 .36298 m .26348 .22487 L .27918 .23363 L p .836 .479 .38 r
F P
0 g
s
.27918 .23363 m .25819 .3722 L .24082 .36298 L p .836 .479 .38 r
F P
0 g
s
.26969 .3474 m .25983 .36137 L .27918 .23363 L p 0 0 .156 r
F P
0 g
s
.27918 .23363 m .28828 .22032 L .26969 .3474 L p 0 0 .156 r
F P
0 g
s
.33808 .21116 m .35363 .22 L .34426 .23332 L p .694 .677 .829 r
F P
0 g
s
.34426 .23332 m .32875 .22456 L .33808 .21116 L p .694 .677 .829 r
F P
0 g
s
.31644 .33073 m .32875 .22456 L .34426 .23332 L p .837 .474 .368 r
F P
0 g
s
.34426 .23332 m .33321 .33985 L .31644 .33073 L p .837 .474 .368 r
F P
0 g
s
.34327 .32598 m .33321 .33985 L .34426 .23332 L p 0 0 .2 r
F P
0 g
s
.34426 .23332 m .35363 .22 L .34327 .32598 L p 0 0 .2 r
F P
0 g
s
.31147 .37359 m .32875 .22456 L .34426 .23332 L p .837 .474 .368 r
F P
0 g
s
.34426 .23332 m .32875 .38285 L .31147 .37359 L p .837 .474 .368 r
F P
0 g
s
.33908 .36877 m .32875 .38285 L .34426 .23332 L p 0 0 .2 r
F P
0 g
s
.34426 .23332 m .35363 .22 L .33908 .36877 L p 0 0 .2 r
F P
0 g
s
.40363 .21085 m .41901 .21968 L .40936 .233 L p .694 .677 .829 r
F P
0 g
s
.40936 .233 m .39402 .22424 L .40363 .21085 L p .694 .677 .829 r
F P
0 g
s
.38468 .36231 m .40161 .37154 L .39111 .38543 L p .69 .69 .845 r
F P
0 g
s
.38394 .37326 m .39402 .22424 L .40936 .233 L p .838 .469 .355 r
F P
0 g
s
.40936 .233 m .40099 .38252 L .38394 .37326 L p .838 .469 .355 r
F P
0 g
s
.41167 .36844 m .40099 .38252 L .40936 .233 L p .02 0 .24 r
F P
0 g
s
.40936 .233 m .41901 .21968 L .41167 .36844 L p .02 0 .24 r
F P
0 g
s
.38468 .36231 m .39402 .22424 L .40936 .233 L p .838 .469 .355 r
F P
0 g
s
.40936 .233 m .40161 .37154 L .38468 .36231 L p .838 .469 .355 r
F P
0 g
s
.41167 .36844 m .40099 .38252 L .40936 .233 L p .02 0 .24 r
F P
0 g
s
.40936 .233 m .41901 .21968 L .41167 .36844 L p .02 0 .24 r
F P
0 g
s
.4692 .21053 m .48439 .21937 L .47446 .23269 L p .694 .677 .829 r
F P
0 g
s
.47446 .23269 m .45931 .22393 L .4692 .21053 L p .694 .677 .829 r
F P
0 g
s
.44723 .32328 m .46331 .33226 L .45294 .34579 L p .692 .685 .839 r
F P
0 g
s
.45765 .30955 m .47377 .31861 L .46331 .33226 L p .692 .685 .839 r
F P
0 g
s
.46331 .33226 m .44723 .32328 L .45765 .30955 L p .692 .685 .839 r
F P
0 g
s
.46864 .37549 m .45248 .36658 L .46299 .35295 L p .691 .687 .841 r
F P
0 g
s
.45642 .37292 m .45931 .22393 L .47446 .23269 L p .839 .463 .341 r
F P
0 g
s
.47421 .39769 m .45818 .38891 L .46864 .37549 L p .691 .687 .841 r
F P
0 g
s
.47446 .23269 m .47325 .38219 L .45642 .37292 L p .839 .463 .341 r
F P
0 g
s
.48427 .3681 m .47325 .38219 L .47446 .23269 L p .066 0 .276 r
F P
0 g
s
.47446 .23269 m .48439 .21937 L .48427 .3681 L p .066 0 .276 r
F P
0 g
s
.45765 .30955 m .45931 .22393 L .47446 .23269 L p .839 .463 .341 r
F P
0 g
s
.47446 .23269 m .47377 .31861 L .45765 .30955 L p .839 .463 .341 r
F P
0 g
s
.48427 .3681 m .47325 .38219 L .47446 .23269 L p .066 0 .276 r
F P
0 g
s
.47446 .23269 m .48439 .21937 L .48427 .3681 L p .066 0 .276 r
F P
0 g
s
.53478 .21021 m .54979 .21905 L .53958 .23237 L p .694 .677 .829 r
F P
0 g
s
.53958 .23237 m .52461 .22361 L .53478 .21021 L p .694 .677 .829 r
F P
0 g
s
.52829 .35085 m .52461 .22361 L .53958 .23237 L p .839 .457 .326 r
F P
0 g
s
.53958 .23237 m .54466 .36005 L .52829 .35085 L p .839 .457 .326 r
F P
0 g
s
.55586 .34607 m .54466 .36005 L .53958 .23237 L p .108 0 .308 r
F P
0 g
s
.53958 .23237 m .54979 .21905 L .55586 .34607 L p .108 0 .308 r
F P
0 g
s
.52861 .36164 m .52461 .22361 L .53958 .23237 L p .839 .457 .326 r
F P
0 g
s
.53958 .23237 m .54509 .37087 L .52861 .36164 L p .839 .457 .326 r
F P
0 g
s
.55586 .34607 m .54466 .36005 L .53958 .23237 L p .108 0 .308 r
F P
0 g
s
.53958 .23237 m .54979 .21905 L .55586 .34607 L p .108 0 .308 r
F P
0 g
s
.60038 .20989 m .6152 .21873 L .60471 .23206 L p .694 .677 .829 r
F P
0 g
s
.60471 .23206 m .58992 .22329 L .60038 .20989 L p .694 .677 .829 r
F P
0 g
s
.60144 .37225 m .58992 .22329 L .60471 .23206 L p .839 .45 .311 r
F P
0 g
s
.60471 .23206 m .61782 .38152 L .60144 .37225 L p .839 .45 .311 r
F P
0 g
s
.62953 .36743 m .61782 .38152 L .60471 .23206 L p .145 0 .337 r
F P
0 g
s
.60471 .23206 m .6152 .21873 L .62953 .36743 L p .145 0 .337 r
F P
0 g
s
.60144 .37225 m .58992 .22329 L .60471 .23206 L p .839 .45 .311 r
F P
0 g
s
.60471 .23206 m .61782 .38152 L .60144 .37225 L p .839 .45 .311 r
F P
0 g
s
.6339 .4128 m .62181 .42709 L .60471 .23206 L p .145 0 .337 r
F P
0 g
s
.60471 .23206 m .6152 .21873 L .6339 .4128 L p .145 0 .337 r
F P
0 g
s
.66599 .20957 m .68063 .21841 L .66986 .23175 L p .694 .677 .829 r
F P
0 g
s
.66986 .23175 m .65525 .22298 L .66599 .20957 L p .694 .677 .829 r
F P
0 g
s
.67822 .40574 m .69473 .41511 L .68249 .42922 L p .688 .694 .85 r
F P
0 g
s
.67968 .41735 m .65525 .22298 L .66986 .23175 L p .839 .442 .294 r
F P
0 g
s
.66986 .23175 m .69631 .42676 L .67968 .41735 L p .839 .442 .294 r
F P
0 g
s
.70876 .41246 m .69631 .42676 L .66986 .23175 L p .18 0 .362 r
F P
0 g
s
.66986 .23175 m .68063 .21841 L .70876 .41246 L p .18 0 .362 r
F P
0 g
s
.67822 .40574 m .65525 .22298 L .66986 .23175 L p .839 .442 .294 r
F P
0 g
s
.66986 .23175 m .69473 .41511 L .67822 .40574 L p .839 .442 .294 r
F P
0 g
s
.70876 .41246 m .69631 .42676 L .66986 .23175 L p .18 0 .362 r
F P
0 g
s
.66986 .23175 m .68063 .21841 L .70876 .41246 L p .18 0 .362 r
F P
0 g
s
.75856 .44078 m .72059 .22266 L .73502 .23143 L p .839 .434 .276 r
F P
0 g
s
.73502 .23143 m .77519 .45025 L .75856 .44078 L p .839 .434 .276 r
F P
0 g
s
.29744 .20689 m .31314 .21575 L .30393 .2291 L p .694 .677 .829 r
F P
0 g
s
.30393 .2291 m .28828 .22032 L .29744 .20689 L p .694 .677 .829 r
F P
0 g
s
.26969 .3474 m .28828 .22032 L .30393 .2291 L p .836 .477 .374 r
F P
0 g
s
.30393 .2291 m .28687 .35662 L .26969 .3474 L p .836 .477 .374 r
F P
0 g
s
.29687 .3426 m .28687 .35662 L .30393 .2291 L p 0 0 .171 r
F P
0 g
s
.30393 .2291 m .31314 .21575 L .29687 .3426 L p 0 0 .171 r
F P
0 g
s
.26969 .3474 m .28828 .22032 L .30393 .2291 L p .836 .477 .374 r
F P
0 g
s
.30393 .2291 m .28687 .35662 L .26969 .3474 L p .836 .477 .374 r
F P
0 g
s
.29549 .35336 m .28542 .36743 L .30393 .2291 L p 0 0 .171 r
F P
0 g
s
.30393 .2291 m .31314 .21575 L .29549 .35336 L p 0 0 .171 r
F P
0 g
s
.36309 .20657 m .3786 .21543 L .36911 .22879 L p .694 .677 .829 r
F P
0 g
s
.36911 .22879 m .35363 .22 L .36309 .20657 L p .694 .677 .829 r
F P
0 g
s
.34015 .35784 m .35363 .22 L .36911 .22879 L p .837 .472 .362 r
F P
0 g
s
.36911 .22879 m .35724 .3671 L .34015 .35784 L p .837 .472 .362 r
F P
0 g
s
.36765 .35302 m .35724 .3671 L .36911 .22879 L p 0 0 .214 r
F P
0 g
s
.36911 .22879 m .3786 .21543 L .36765 .35302 L p 0 0 .214 r
F P
0 g
s
.33908 .36877 m .35363 .22 L .36911 .22879 L p .837 .472 .362 r
F P
0 g
s
.36911 .22879 m .3563 .37806 L .33908 .36877 L p .837 .472 .362 r
F P
0 g
s
.36678 .36394 m .3563 .37806 L .36911 .22879 L p 0 0 .214 r
F P
0 g
s
.36911 .22879 m .3786 .21543 L .36678 .36394 L p 0 0 .214 r
F P
0 g
s
.42874 .20625 m .44407 .21511 L .4343 .22847 L p .694 .677 .829 r
F P
0 g
s
.4343 .22847 m .41901 .21968 L .42874 .20625 L p .694 .677 .829 r
F P
0 g
s
.41167 .36844 m .41901 .21968 L .4343 .22847 L p .838 .466 .348 r
F P
0 g
s
.4343 .22847 m .42866 .37773 L .41167 .36844 L p .838 .466 .348 r
F P
0 g
s
.45294 .34579 m .4369 .33689 L .44723 .32328 L p .692 .685 .839 r
F P
0 g
s
.4475 .31319 m .43144 .30419 L .44175 .29042 L p .692 .684 .838 r
F P
0 g
s
.43106 .31425 m .44723 .32328 L .4369 .33689 L p .692 .685 .839 r
F P
0 g
s
.43622 .35762 m .45248 .36658 L .44206 .38008 L p .691 .687 .841 r
F P
0 g
s
.43949 .3636 m .42866 .37773 L .4343 .22847 L p .036 0 .253 r
F P
0 g
s
.4343 .22847 m .44407 .21511 L .43949 .3636 L p .036 0 .253 r
F P
0 g
s
.41167 .36844 m .41901 .21968 L .4343 .22847 L p .838 .466 .348 r
F P
0 g
s
.4343 .22847 m .42866 .37773 L .41167 .36844 L p .838 .466 .348 r
F P
0 g
s
.44175 .29042 m .43144 .30419 L .4343 .22847 L p .036 0 .253 r
F P
0 g
s
.4343 .22847 m .44407 .21511 L .44175 .29042 L p .036 0 .253 r
F P
0 g
s
.49441 .20593 m .50955 .21479 L .4995 .22816 L p .694 .677 .829 r
F P
0 g
s
.4995 .22816 m .48439 .21937 L .49441 .20593 L p .694 .677 .829 r
F P
0 g
s
.48428 .35717 m .48439 .21937 L .4995 .22816 L p .839 .46 .334 r
F P
0 g
s
.4995 .22816 m .50093 .36643 L .48428 .35717 L p .839 .46 .334 r
F P
0 g
s
.51202 .35235 m .50093 .36643 L .4995 .22816 L p .08 0 .287 r
F P
0 g
s
.4995 .22816 m .50955 .21479 L .51202 .35235 L p .08 0 .287 r
F P
0 g
s
.48427 .3681 m .48439 .21937 L .4995 .22816 L p .839 .46 .334 r
F P
0 g
s
.4995 .22816 m .50104 .3774 L .48427 .3681 L p .839 .46 .334 r
F P
0 g
s
.51221 .36327 m .50104 .3774 L .4995 .22816 L p .08 0 .287 r
F P
0 g
s
.4995 .22816 m .50955 .21479 L .51221 .36327 L p .08 0 .287 r
F P
0 g
s
.56009 .20561 m .57505 .21448 L .56472 .22784 L p .694 .677 .829 r
F P
0 g
s
.56472 .22784 m .54979 .21905 L .56009 .20561 L p .694 .677 .829 r
F P
0 g
s
.55586 .34607 m .54979 .21905 L .56472 .22784 L p .839 .453 .319 r
F P
0 g
s
.56472 .22784 m .57217 .3553 L .55586 .34607 L p .839 .453 .319 r
F P
0 g
s
.58351 .34127 m .57217 .3553 L .56472 .22784 L p .121 0 .318 r
F P
0 g
s
.56472 .22784 m .57505 .21448 L .58351 .34127 L p .121 0 .318 r
F P
0 g
s
.55586 .34607 m .54979 .21905 L .56472 .22784 L p .839 .453 .319 r
F P
0 g
s
.56472 .22784 m .57217 .3553 L .55586 .34607 L p .839 .453 .319 r
F P
0 g
s
.58423 .35202 m .5728 .3661 L .56472 .22784 L p .121 0 .318 r
F P
0 g
s
.56472 .22784 m .57505 .21448 L .58423 .35202 L p .121 0 .318 r
F P
0 g
s
.62578 .20529 m .64056 .21416 L .62995 .22752 L p .694 .677 .829 r
F P
0 g
s
.62995 .22752 m .6152 .21873 L .62578 .20529 L p .694 .677 .829 r
F P
0 g
s
.63278 .4012 m .6152 .21873 L .62995 .22752 L p .84 .446 .302 r
F P
0 g
s
.62995 .22752 m .64946 .4106 L .63278 .4012 L p .84 .446 .302 r
F P
0 g
s
.66161 .39631 m .64946 .4106 L .62995 .22752 L p .157 0 .346 r
F P
0 g
s
.62995 .22752 m .64056 .21416 L .66161 .39631 L p .157 0 .346 r
F P
0 g
s
.6339 .4128 m .6152 .21873 L .62995 .22752 L p .84 .446 .302 r
F P
0 g
s
.62995 .22752 m .6507 .42223 L .6339 .4128 L p .84 .446 .302 r
F P
0 g
s
.66295 .40789 m .6507 .42223 L .62995 .22752 L p .157 0 .346 r
F P
0 g
s
.62995 .22752 m .64056 .21416 L .66295 .40789 L p .157 0 .346 r
F P
0 g
s
.69149 .20497 m .70608 .21384 L .69519 .22721 L p .694 .677 .829 r
F P
0 g
s
.69519 .22721 m .68063 .21841 L .69149 .20497 L p .694 .677 .829 r
F P
0 g
s
.70876 .41246 m .68063 .21841 L .69519 .22721 L p .839 .438 .285 r
F P
0 g
s
.69519 .22721 m .72532 .42189 L .70876 .41246 L p .839 .438 .285 r
F P
0 g
s
.73793 .40755 m .72532 .42189 L .69519 .22721 L p .19 0 .37 r
F P
0 g
s
.69519 .22721 m .70608 .21384 L .73793 .40755 L p .19 0 .37 r
F P
0 g
s
.70876 .41246 m .68063 .21841 L .69519 .22721 L p .839 .438 .285 r
F P
0 g
s
.69519 .22721 m .72532 .42189 L .70876 .41246 L p .839 .438 .285 r
F P
0 g
s
.73987 .4193 m .72715 .4337 L .69519 .22721 L p .19 0 .37 r
F P
0 g
s
.69519 .22721 m .70608 .21384 L .73987 .4193 L p .19 0 .37 r
F P
0 g
s
.2524 .33812 m .24259 .35218 L .26348 .22487 L p 0 0 .14 r
F P
0 g
s
.26348 .22487 m .27253 .21148 L .2524 .33812 L p 0 0 .14 r
F P
0 g
s
.32243 .20228 m .33808 .21116 L .32875 .22456 L p .694 .677 .829 r
F P
0 g
s
.32875 .22456 m .31314 .21575 L .32243 .20228 L p .694 .677 .829 r
F P
0 g
s
.29957 .32155 m .31314 .21575 L .32875 .22456 L p .837 .474 .368 r
F P
0 g
s
.32875 .22456 m .31644 .33073 L .29957 .32155 L p .837 .474 .368 r
F P
0 g
s
.32645 .31677 m .31644 .33073 L .32875 .22456 L p 0 0 .186 r
F P
0 g
s
.32875 .22456 m .33808 .21116 L .32645 .31677 L p 0 0 .186 r
F P
0 g
s
.29549 .35336 m .31314 .21575 L .32875 .22456 L p .837 .474 .368 r
F P
0 g
s
.32875 .22456 m .31274 .36264 L .29549 .35336 L p .837 .474 .368 r
F P
0 g
s
.32645 .31677 m .31644 .33073 L .32875 .22456 L p 0 0 .186 r
F P
0 g
s
.32875 .22456 m .33808 .21116 L .32645 .31677 L p 0 0 .186 r
F P
0 g
s
.38817 .20196 m .40363 .21085 L .39402 .22424 L p .694 .677 .829 r
F P
0 g
s
.39402 .22424 m .3786 .21543 L .38817 .20196 L p .694 .677 .829 r
F P
0 g
s
.36851 .34227 m .3786 .21543 L .39402 .22424 L p .838 .469 .355 r
F P
0 g
s
.39402 .22424 m .38541 .35152 L .36851 .34227 L p .838 .469 .355 r
F P
0 g
s
.39589 .33745 m .38541 .35152 L .39402 .22424 L p .004 0 .228 r
F P
0 g
s
.39402 .22424 m .40363 .21085 L .39589 .33745 L p .004 0 .228 r
F P
0 g
s
.36678 .36394 m .3786 .21543 L .39402 .22424 L p .838 .469 .355 r
F P
0 g
s
.39402 .22424 m .38394 .37326 L .36678 .36394 L p .838 .469 .355 r
F P
0 g
s
.39457 .35909 m .38394 .37326 L .39402 .22424 L p .004 0 .228 r
F P
0 g
s
.39402 .22424 m .40363 .21085 L .39457 .35909 L p .004 0 .228 r
F P
0 g
s
.45392 .20164 m .4692 .21053 L .45931 .22393 L p .694 .677 .829 r
F P
0 g
s
.45931 .22393 m .44407 .21511 L .45392 .20164 L p .694 .677 .829 r
F P
0 g
s
.44175 .29042 m .45784 .2995 L .4475 .31319 L p .692 .684 .838 r
F P
0 g
s
.43949 .3636 m .44407 .21511 L .45931 .22393 L p .839 .463 .341 r
F P
0 g
s
.45931 .22393 m .45642 .37292 L .43949 .3636 L p .839 .463 .341 r
F P
0 g
s
.4674 .35875 m .45642 .37292 L .45931 .22393 L p .051 0 .265 r
F P
0 g
s
.45931 .22393 m .4692 .21053 L .4674 .35875 L p .051 0 .265 r
F P
0 g
s
.44175 .29042 m .44407 .21511 L .45931 .22393 L p .839 .463 .341 r
F P
0 g
s
.45931 .22393 m .45784 .2995 L .44175 .29042 L p .839 .463 .341 r
F P
0 g
s
.4674 .35875 m .45642 .37292 L .45931 .22393 L p .051 0 .265 r
F P
0 g
s
.45931 .22393 m .4692 .21053 L .4674 .35875 L p .051 0 .265 r
F P
0 g
s
.51969 .20132 m .53478 .21021 L .52461 .22361 L p .694 .677 .829 r
F P
0 g
s
.52461 .22361 m .50955 .21479 L .51969 .20132 L p .694 .677 .829 r
F P
0 g
s
.51221 .36327 m .50955 .21479 L .52461 .22361 L p .839 .457 .326 r
F P
0 g
s
.52461 .22361 m .52892 .37259 L .51221 .36327 L p .839 .457 .326 r
F P
0 g
s
.54466 .36005 m .52829 .35085 L .53945 .33678 L p .69 .689 .844 r
F P
0 g
s
.52861 .36164 m .54509 .37087 L .53392 .38478 L p .69 .69 .845 r
F P
0 g
s
.54025 .35841 m .52892 .37259 L .52461 .22361 L p .094 0 .298 r
F P
0 g
s
.52461 .22361 m .53478 .21021 L .54025 .35841 L p .094 0 .298 r
F P
0 g
s
.51221 .36327 m .50955 .21479 L .52461 .22361 L p .839 .457 .326 r
F P
0 g
s
.52461 .22361 m .52892 .37259 L .51221 .36327 L p .839 .457 .326 r
F P
0 g
s
.53945 .33678 m .52829 .35085 L .52461 .22361 L p .094 0 .298 r
F P
0 g
s
.52461 .22361 m .53478 .21021 L .53945 .33678 L p .094 0 .298 r
F P
0 g
s
.58547 .201 m .60038 .20989 L .58992 .22329 L p .694 .677 .829 r
F P
0 g
s
.58992 .22329 m .57505 .21448 L .58547 .201 L p .694 .677 .829 r
F P
0 g
s
.58423 .35202 m .60059 .36131 L .58912 .3753 L p .69 .69 .845 r
F P
0 g
s
.58912 .3753 m .5728 .3661 L .58423 .35202 L p .69 .69 .845 r
F P
0 g
s
.58496 .36293 m .57505 .21448 L .58992 .22329 L p .839 .45 .311 r
F P
0 g
s
.58992 .22329 m .60144 .37225 L .58496 .36293 L p .839 .45 .311 r
F P
0 g
s
.61311 .35808 m .60144 .37225 L .58992 .22329 L p .133 0 .328 r
F P
0 g
s
.58992 .22329 m .60038 .20989 L .61311 .35808 L p .133 0 .328 r
F P
0 g
s
.58423 .35202 m .57505 .21448 L .58992 .22329 L p .839 .45 .311 r
F P
0 g
s
.58992 .22329 m .60059 .36131 L .58423 .35202 L p .839 .45 .311 r
F P
0 g
s
.61311 .35808 m .60144 .37225 L .58992 .22329 L p .133 0 .328 r
F P
0 g
s
.58992 .22329 m .60038 .20989 L .61311 .35808 L p .133 0 .328 r
F P
0 g
s
.65126 .20067 m .66599 .20957 L .65525 .22298 L p .694 .677 .829 r
F P
0 g
s
.65525 .22298 m .64056 .21416 L .65126 .20067 L p .694 .677 .829 r
F P
0 g
s
.66029 .3849 m .64056 .21416 L .65525 .22298 L p .839 .442 .294 r
F P
0 g
s
.65525 .22298 m .67678 .3943 L .66029 .3849 L p .839 .442 .294 r
F P
0 g
s
.68899 .38001 m .67678 .3943 L .65525 .22298 L p .169 0 .354 r
F P
0 g
s
.65525 .22298 m .66599 .20957 L .68899 .38001 L p .169 0 .354 r
F P
0 g
s
.66295 .40789 m .64056 .21416 L .65525 .22298 L p .839 .442 .294 r
F P
0 g
s
.65525 .22298 m .67968 .41735 L .66295 .40789 L p .839 .442 .294 r
F P
0 g
s
.69209 .40296 m .67968 .41735 L .65525 .22298 L p .169 0 .354 r
F P
0 g
s
.65525 .22298 m .66599 .20957 L .69209 .40296 L p .169 0 .354 r
F P
0 g
s
.73987 .4193 m .70608 .21384 L .72059 .22266 L p .839 .434 .276 r
F P
0 g
s
.72059 .22266 m .75648 .4288 L .73987 .4193 L p .839 .434 .276 r
F P
0 g
s
.28166 .19798 m .29744 .20689 L .28828 .22032 L p .694 .677 .829 r
F P
0 g
s
.28828 .22032 m .27253 .21148 L .28166 .19798 L p .694 .677 .829 r
F P
0 g
s
.25408 .32754 m .27253 .21148 L .28828 .22032 L p .836 .477 .374 r
F P
0 g
s
.28828 .22032 m .27124 .33678 L .25408 .32754 L p .836 .477 .374 r
F P
0 g
s
.28113 .32273 m .27124 .33678 L .28828 .22032 L p 0 0 .156 r
F P
0 g
s
.28828 .22032 m .29744 .20689 L .28113 .32273 L p 0 0 .156 r
F P
0 g
s
.2524 .33812 m .27253 .21148 L .28828 .22032 L p .836 .477 .374 r
F P
0 g
s
.28828 .22032 m .26969 .3474 L .2524 .33812 L p .836 .477 .374 r
F P
0 g
s
.27964 .3333 m .26969 .3474 L .28828 .22032 L p 0 0 .156 r
F P
0 g
s
.28828 .22032 m .29744 .20689 L .27964 .3333 L p 0 0 .156 r
F P
0 g
s
.34749 .19766 m .36309 .20657 L .35363 .22 L p .694 .677 .829 r
F P
0 g
s
.35363 .22 m .33808 .21116 L .34749 .19766 L p .694 .677 .829 r
F P
0 g
s
.32645 .31677 m .33808 .21116 L .35363 .22 L p .837 .472 .362 r
F P
0 g
s
.35363 .22 m .34327 .32598 L .32645 .31677 L p .837 .472 .362 r
F P
0 g
s
.35342 .31198 m .34327 .32598 L .35363 .22 L p 0 0 .2 r
F P
0 g
s
.35363 .22 m .36309 .20657 L .35342 .31198 L p 0 0 .2 r
F P
0 g
s
.32645 .31677 m .33808 .21116 L .35363 .22 L p .837 .472 .362 r
F P
0 g
s
.35363 .22 m .34327 .32598 L .32645 .31677 L p .837 .472 .362 r
F P
0 g
s
.35051 .34368 m .34015 .35784 L .35363 .22 L p 0 0 .2 r
F P
0 g
s
.35363 .22 m .36309 .20657 L .35051 .34368 L p 0 0 .2 r
F P
0 g
s
.41333 .19733 m .42874 .20625 L .41901 .21968 L p .694 .677 .829 r
F P
0 g
s
.41901 .21968 m .40363 .21085 L .41333 .19733 L p .694 .677 .829 r
F P
0 g
s
.39524 .34819 m .40363 .21085 L .41901 .21968 L p .838 .466 .348 r
F P
0 g
s
.41901 .21968 m .41221 .35751 L .39524 .34819 L p .838 .466 .348 r
F P
0 g
s
.42291 .34335 m .41221 .35751 L .41901 .21968 L p .02 0 .24 r
F P
0 g
s
.41901 .21968 m .42874 .20625 L .42291 .34335 L p .02 0 .24 r
F P
0 g
s
.39457 .35909 m .40363 .21085 L .41901 .21968 L p .838 .466 .348 r
F P
0 g
s
.41901 .21968 m .41167 .36844 L .39457 .35909 L p .838 .466 .348 r
F P
0 g
s
.42245 .35422 m .41167 .36844 L .41901 .21968 L p .02 0 .24 r
F P
0 g
s
.41901 .21968 m .42874 .20625 L .42245 .35422 L p .02 0 .24 r
F P
0 g
s
.47918 .19701 m .49441 .20593 L .48439 .21937 L p .694 .677 .829 r
F P
0 g
s
.48439 .21937 m .4692 .21053 L .47918 .19701 L p .694 .677 .829 r
F P
0 g
s
.4674 .35875 m .4692 .21053 L .48439 .21937 L p .839 .46 .334 r
F P
0 g
s
.48439 .21937 m .48427 .3681 L .4674 .35875 L p .839 .46 .334 r
F P
0 g
s
.50093 .36643 m .48428 .35717 L .49533 .34301 L p .69 .69 .845 r
F P
0 g
s
.4954 .35389 m .48427 .3681 L .48439 .21937 L p .066 0 .276 r
F P
0 g
s
.48439 .21937 m .49441 .20593 L .4954 .35389 L p .066 0 .276 r
F P
0 g
s
.4674 .35875 m .4692 .21053 L .48439 .21937 L p .839 .46 .334 r
F P
0 g
s
.48439 .21937 m .48427 .3681 L .4674 .35875 L p .839 .46 .334 r
F P
0 g
s
.49533 .34301 m .48428 .35717 L .48439 .21937 L p .066 0 .276 r
F P
0 g
s
.48439 .21937 m .49441 .20593 L .49533 .34301 L p .066 0 .276 r
F P
0 g
s
.54505 .19669 m .56009 .20561 L .54979 .21905 L p .694 .677 .829 r
F P
0 g
s
.54979 .21905 m .53478 .21021 L .54505 .19669 L p .694 .677 .829 r
F P
0 g
s
.53906 .3262 m .53478 .21021 L .54979 .21905 L p .839 .453 .319 r
F P
0 g
s
.54979 .21905 m .55535 .33545 L .53906 .3262 L p .839 .453 .319 r
F P
0 g
s
.56657 .32139 m .55535 .33545 L .54979 .21905 L p .108 0 .308 r
F P
0 g
s
.54979 .21905 m .56009 .20561 L .56657 .32139 L p .108 0 .308 r
F P
0 g
s
.53945 .33678 m .53478 .21021 L .54979 .21905 L p .839 .453 .319 r
F P
0 g
s
.54979 .21905 m .55586 .34607 L .53945 .33678 L p .839 .453 .319 r
F P
0 g
s
.56716 .33195 m .55586 .34607 L .54979 .21905 L p .108 0 .308 r
F P
0 g
s
.54979 .21905 m .56009 .20561 L .56716 .33195 L p .108 0 .308 r
F P
0 g
s
.61093 .19637 m .62578 .20529 L .6152 .21873 L p .694 .677 .829 r
F P
0 g
s
.6152 .21873 m .60038 .20989 L .61093 .19637 L p .694 .677 .829 r
F P
0 g
s
.61311 .35808 m .60038 .20989 L .6152 .21873 L p .84 .446 .302 r
F P
0 g
s
.6152 .21873 m .62953 .36743 L .61311 .35808 L p .84 .446 .302 r
F P
0 g
s
.64135 .35321 m .62953 .36743 L .6152 .21873 L p .145 0 .337 r
F P
0 g
s
.6152 .21873 m .62578 .20529 L .64135 .35321 L p .145 0 .337 r
F P
0 g
s
.61311 .35808 m .60038 .20989 L .6152 .21873 L p .84 .446 .302 r
F P
0 g
s
.6152 .21873 m .62953 .36743 L .61311 .35808 L p .84 .446 .302 r
F P
0 g
s
.64489 .38682 m .63278 .4012 L .6152 .21873 L p .145 0 .337 r
F P
0 g
s
.6152 .21873 m .62578 .20529 L .64489 .38682 L p .145 0 .337 r
F P
0 g
s
.67682 .19605 m .69149 .20497 L .68063 .21841 L p .694 .677 .829 r
F P
0 g
s
.68063 .21841 m .66599 .20957 L .67682 .19605 L p .694 .677 .829 r
F P
0 g
s
.69053 .3914 m .66599 .20957 L .68063 .21841 L p .839 .438 .285 r
F P
0 g
s
.68063 .21841 m .70708 .40086 L .69053 .3914 L p .839 .438 .285 r
F P
0 g
s
.71955 .38648 m .70708 .40086 L .68063 .21841 L p .18 0 .362 r
F P
0 g
s
.68063 .21841 m .69149 .20497 L .71955 .38648 L p .18 0 .362 r
F P
0 g
s
.69209 .40296 m .66599 .20957 L .68063 .21841 L p .839 .438 .285 r
F P
0 g
s
.68063 .21841 m .70876 .41246 L .69209 .40296 L p .839 .438 .285 r
F P
0 g
s
.72133 .39802 m .70876 .41246 L .68063 .21841 L p .18 0 .362 r
F P
0 g
s
.68063 .21841 m .69149 .20497 L .72133 .39802 L p .18 0 .362 r
F P
0 g
s
.30669 .19334 m .32243 .20228 L .31314 .21575 L p .694 .677 .829 r
F P
0 g
s
.31314 .21575 m .29744 .20689 L .30669 .19334 L p .694 .677 .829 r
F P
0 g
s
.28259 .31231 m .29744 .20689 L .31314 .21575 L p .837 .474 .368 r
F P
0 g
s
.31314 .21575 m .29957 .32155 L .28259 .31231 L p .837 .474 .368 r
F P
0 g
s
.30953 .30751 m .29957 .32155 L .31314 .21575 L p 0 0 .171 r
F P
0 g
s
.31314 .21575 m .32243 .20228 L .30953 .30751 L p 0 0 .171 r
F P
0 g
s
.27964 .3333 m .29744 .20689 L .31314 .21575 L p .837 .474 .368 r
F P
0 g
s
.31314 .21575 m .29687 .3426 L .27964 .3333 L p .837 .474 .368 r
F P
0 g
s
.30953 .30751 m .29957 .32155 L .31314 .21575 L p 0 0 .171 r
F P
0 g
s
.31314 .21575 m .32243 .20228 L .30953 .30751 L p 0 0 .171 r
F P
0 g
s
.37262 .19302 m .38817 .20196 L .3786 .21543 L p .694 .677 .829 r
F P
0 g
s
.3786 .21543 m .36309 .20657 L .37262 .19302 L p .694 .677 .829 r
F P
0 g
s
.35149 .33296 m .36309 .20657 L .3786 .21543 L p .838 .469 .355 r
F P
0 g
s
.3786 .21543 m .36851 .34227 L .35149 .33296 L p .838 .469 .355 r
F P
0 g
s
.37894 .32812 m .36851 .34227 L .3786 .21543 L p 0 0 .214 r
F P
0 g
s
.3786 .21543 m .38817 .20196 L .37894 .32812 L p 0 0 .214 r
F P
0 g
s
.35051 .34368 m .36309 .20657 L .3786 .21543 L p .838 .469 .355 r
F P
0 g
s
.3786 .21543 m .36765 .35302 L .35051 .34368 L p .838 .469 .355 r
F P
0 g
s
.37894 .32812 m .36851 .34227 L .3786 .21543 L p 0 0 .214 r
F P
0 g
s
.3786 .21543 m .38817 .20196 L .37894 .32812 L p 0 0 .214 r
F P
0 g
s
.43856 .1927 m .45392 .20164 L .44407 .21511 L p .694 .677 .829 r
F P
0 g
s
.44407 .21511 m .42874 .20625 L .43856 .1927 L p .694 .677 .829 r
F P
0 g
s
.42597 .27145 m .42874 .20625 L .44407 .21511 L p .839 .463 .341 r
F P
0 g
s
.44407 .21511 m .44205 .28055 L .42597 .27145 L p .839 .463 .341 r
F P
0 g
s
.45238 .26671 m .44205 .28055 L .44407 .21511 L p .036 0 .253 r
F P
0 g
s
.44407 .21511 m .45392 .20164 L .45238 .26671 L p .036 0 .253 r
F P
0 g
s
.42245 .35422 m .42874 .20625 L .44407 .21511 L p .839 .463 .341 r
F P
0 g
s
.44407 .21511 m .43949 .3636 L .42245 .35422 L p .839 .463 .341 r
F P
0 g
s
.45042 .34934 m .43949 .3636 L .44407 .21511 L p .036 0 .253 r
F P
0 g
s
.44407 .21511 m .45392 .20164 L .45042 .34934 L p .036 0 .253 r
F P
0 g
s
.50451 .19237 m .51969 .20132 L .50955 .21479 L p .694 .677 .829 r
F P
0 g
s
.50955 .21479 m .49441 .20593 L .50451 .19237 L p .694 .677 .829 r
F P
0 g
s
.49533 .34301 m .51202 .35235 L .50093 .36643 L p .69 .69 .845 r
F P
0 g
s
.4954 .35389 m .49441 .20593 L .50955 .21479 L p .839 .457 .326 r
F P
0 g
s
.50955 .21479 m .51221 .36327 L .4954 .35389 L p .839 .457 .326 r
F P
0 g
s
.52349 .349 m .51221 .36327 L .50955 .21479 L p .08 0 .287 r
F P
0 g
s
.50955 .21479 m .51969 .20132 L .52349 .349 L p .08 0 .287 r
F P
0 g
s
.49533 .34301 m .49441 .20593 L .50955 .21479 L p .839 .457 .326 r
F P
0 g
s
.50955 .21479 m .51202 .35235 L .49533 .34301 L p .839 .457 .326 r
F P
0 g
s
.52349 .349 m .51221 .36327 L .50955 .21479 L p .08 0 .287 r
F P
0 g
s
.50955 .21479 m .51969 .20132 L .52349 .349 L p .08 0 .287 r
F P
0 g
s
.57048 .19205 m .58547 .201 L .57505 .21448 L p .694 .677 .829 r
F P
0 g
s
.57505 .21448 m .56009 .20561 L .57048 .19205 L p .694 .677 .829 r
F P
0 g
s
.55586 .34607 m .57217 .3553 L .56093 .36919 L p .69 .689 .844 r
F P
0 g
s
.56716 .33195 m .58351 .34127 L .57217 .3553 L p .69 .689 .844 r
F P
0 g
s
.57217 .3553 m .55586 .34607 L .56716 .33195 L p .69 .689 .844 r
F P
0 g
s
.56837 .35355 m .56009 .20561 L .57505 .21448 L p .839 .45 .311 r
F P
0 g
s
.57505 .21448 m .58496 .36293 L .56837 .35355 L p .839 .45 .311 r
F P
0 g
s
.59658 .34866 m .58496 .36293 L .57505 .21448 L p .121 0 .318 r
F P
0 g
s
.57505 .21448 m .58547 .201 L .59658 .34866 L p .121 0 .318 r
F P
0 g
s
.56716 .33195 m .56009 .20561 L .57505 .21448 L p .839 .45 .311 r
F P
0 g
s
.57505 .21448 m .58351 .34127 L .56716 .33195 L p .839 .45 .311 r
F P
0 g
s
.59658 .34866 m .58496 .36293 L .57505 .21448 L p .121 0 .318 r
F P
0 g
s
.57505 .21448 m .58547 .201 L .59658 .34866 L p .121 0 .318 r
F P
0 g
s
.63646 .19173 m .65126 .20067 L .64056 .21416 L p .694 .677 .829 r
F P
0 g
s
.64056 .21416 m .62578 .20529 L .63646 .19173 L p .694 .677 .829 r
F P
0 g
s
.64369 .37545 m .62578 .20529 L .64056 .21416 L p .839 .442 .294 r
F P
0 g
s
.64056 .21416 m .66029 .3849 L .64369 .37545 L p .839 .442 .294 r
F P
0 g
s
.67246 .37053 m .66029 .3849 L .64056 .21416 L p .157 0 .346 r
F P
0 g
s
.64056 .21416 m .65126 .20067 L .67246 .37053 L p .157 0 .346 r
F P
0 g
s
.64489 .38682 m .62578 .20529 L .64056 .21416 L p .839 .442 .294 r
F P
0 g
s
.64056 .21416 m .66161 .39631 L .64489 .38682 L p .839 .442 .294 r
F P
0 g
s
.67246 .37053 m .66029 .3849 L .64056 .21416 L p .157 0 .346 r
F P
0 g
s
.64056 .21416 m .65126 .20067 L .67246 .37053 L p .157 0 .346 r
F P
0 g
s
.72133 .39802 m .69149 .20497 L .70608 .21384 L p .839 .434 .276 r
F P
0 g
s
.70608 .21384 m .73793 .40755 L .72133 .39802 L p .839 .434 .276 r
F P
0 g
s
.26392 .3134 m .25408 .32754 L .27253 .21148 L p 0 0 .14 r
F P
0 g
s
.27253 .21148 m .28166 .19798 L .26392 .3134 L p 0 0 .14 r
F P
0 g
s
.3318 .18869 m .34749 .19766 L .33808 .21116 L p .694 .677 .829 r
F P
0 g
s
.33808 .21116 m .32243 .20228 L .3318 .18869 L p .694 .677 .829 r
F P
0 g
s
.31079 .29726 m .32243 .20228 L .33808 .21116 L p .837 .472 .362 r
F P
0 g
s
.33808 .21116 m .32758 .30649 L .31079 .29726 L p .837 .472 .362 r
F P
0 g
s
.33762 .29245 m .32758 .30649 L .33808 .21116 L p 0 0 .186 r
F P
0 g
s
.33808 .21116 m .34749 .19766 L .33762 .29245 L p 0 0 .186 r
F P
0 g
s
.30953 .30751 m .32243 .20228 L .33808 .21116 L p .837 .472 .362 r
F P
0 g
s
.33808 .21116 m .32645 .31677 L .30953 .30751 L p .837 .472 .362 r
F P
0 g
s
.33655 .30269 m .32645 .31677 L .33808 .21116 L p 0 0 .186 r
F P
0 g
s
.33808 .21116 m .34749 .19766 L .33655 .30269 L p 0 0 .186 r
F P
0 g
s
.39783 .18837 m .41333 .19733 L .40363 .21085 L p .694 .677 .829 r
F P
0 g
s
.40363 .21085 m .38817 .20196 L .39783 .18837 L p .694 .677 .829 r
F P
0 g
s
.37894 .32812 m .38817 .20196 L .40363 .21085 L p .838 .466 .348 r
F P
0 g
s
.40363 .21085 m .39589 .33745 L .37894 .32812 L p .838 .466 .348 r
F P
0 g
s
.40647 .32326 m .39589 .33745 L .40363 .21085 L p .004 0 .228 r
F P
0 g
s
.40363 .21085 m .41333 .19733 L .40647 .32326 L p .004 0 .228 r
F P
0 g
s
.37894 .32812 m .38817 .20196 L .40363 .21085 L p .838 .466 .348 r
F P
0 g
s
.40363 .21085 m .39589 .33745 L .37894 .32812 L p .838 .466 .348 r
F P
0 g
s
.40589 .33394 m .39524 .34819 L .40363 .21085 L p .004 0 .228 r
F P
0 g
s
.40363 .21085 m .41333 .19733 L .40589 .33394 L p .004 0 .228 r
F P
0 g
s
.46386 .18805 m .47918 .19701 L .4692 .21053 L p .694 .677 .829 r
F P
0 g
s
.4692 .21053 m .45392 .20164 L .46386 .18805 L p .694 .677 .829 r
F P
0 g
s
.45068 .33848 m .45392 .20164 L .4692 .21053 L p .839 .46 .334 r
F P
0 g
s
.4692 .21053 m .46753 .34786 L .45068 .33848 L p .839 .46 .334 r
F P
0 g
s
.47853 .3336 m .46753 .34786 L .4692 .21053 L p .051 0 .265 r
F P
0 g
s
.4692 .21053 m .47918 .19701 L .47853 .3336 L p .051 0 .265 r
F P
0 g
s
.45042 .34934 m .45392 .20164 L .4692 .21053 L p .839 .46 .334 r
F P
0 g
s
.4692 .21053 m .4674 .35875 L .45042 .34934 L p .839 .46 .334 r
F P
0 g
s
.47848 .34444 m .4674 .35875 L .4692 .21053 L p .051 0 .265 r
F P
0 g
s
.4692 .21053 m .47918 .19701 L .47848 .34444 L p .051 0 .265 r
F P
0 g
s
.52992 .18772 m .54505 .19669 L .53478 .21021 L p .694 .677 .829 r
F P
0 g
s
.53478 .21021 m .51969 .20132 L .52992 .18772 L p .694 .677 .829 r
F P
0 g
s
.52349 .349 m .51969 .20132 L .53478 .21021 L p .839 .453 .319 r
F P
0 g
s
.53478 .21021 m .54025 .35841 L .52349 .349 L p .839 .453 .319 r
F P
0 g
s
.55535 .33545 m .53906 .3262 L .55023 .31205 L p .691 .688 .843 r
F P
0 g
s
.53945 .33678 m .55586 .34607 L .54466 .36005 L p .69 .689 .844 r
F P
0 g
s
.55168 .3441 m .54025 .35841 L .53478 .21021 L p .094 0 .298 r
F P
0 g
s
.53478 .21021 m .54505 .19669 L .55168 .3441 L p .094 0 .298 r
F P
0 g
s
.52349 .349 m .51969 .20132 L .53478 .21021 L p .839 .453 .319 r
F P
0 g
s
.53478 .21021 m .54025 .35841 L .52349 .349 L p .839 .453 .319 r
F P
0 g
s
.55023 .31205 m .53906 .3262 L .53478 .21021 L p .094 0 .298 r
F P
0 g
s
.53478 .21021 m .54505 .19669 L .55023 .31205 L p .094 0 .298 r
F P
0 g
s
.59598 .1874 m .61093 .19637 L .60038 .20989 L p .694 .677 .829 r
F P
0 g
s
.60038 .20989 m .58547 .201 L .59598 .1874 L p .694 .677 .829 r
F P
0 g
s
.59577 .3378 m .58547 .201 L .60038 .20989 L p .84 .446 .302 r
F P
0 g
s
.60038 .20989 m .61217 .34718 L .59577 .3378 L p .84 .446 .302 r
F P
0 g
s
.62386 .33292 m .61217 .34718 L .60038 .20989 L p .133 0 .328 r
F P
0 g
s
.60038 .20989 m .61093 .19637 L .62386 .33292 L p .133 0 .328 r
F P
0 g
s
.59658 .34866 m .58547 .201 L .60038 .20989 L p .84 .446 .302 r
F P
0 g
s
.60038 .20989 m .61311 .35808 L .59658 .34866 L p .84 .446 .302 r
F P
0 g
s
.62489 .34376 m .61311 .35808 L .60038 .20989 L p .133 0 .328 r
F P
0 g
s
.60038 .20989 m .61093 .19637 L .62489 .34376 L p .133 0 .328 r
F P
0 g
s
.66206 .18707 m .67682 .19605 L .66599 .20957 L p .694 .677 .829 r
F P
0 g
s
.66599 .20957 m .65126 .20067 L .66206 .18707 L p .694 .677 .829 r
F P
0 g
s
.67246 .37053 m .65126 .20067 L .66599 .20957 L p .839 .438 .285 r
F P
0 g
s
.66599 .20957 m .68899 .38001 L .67246 .37053 L p .839 .438 .285 r
F P
0 g
s
.70132 .36559 m .68899 .38001 L .66599 .20957 L p .169 0 .354 r
F P
0 g
s
.66599 .20957 m .67682 .19605 L .70132 .36559 L p .169 0 .354 r
F P
0 g
s
.67246 .37053 m .65126 .20067 L .66599 .20957 L p .839 .438 .285 r
F P
0 g
s
.66599 .20957 m .68899 .38001 L .67246 .37053 L p .839 .438 .285 r
F P
0 g
s
.70296 .37692 m .69053 .3914 L .66599 .20957 L p .169 0 .354 r
F P
0 g
s
.66599 .20957 m .67682 .19605 L .70296 .37692 L p .169 0 .354 r
F P
0 g
s
.29087 .18436 m .30669 .19334 L .29744 .20689 L p .694 .677 .829 r
F P
0 g
s
.29744 .20689 m .28166 .19798 L .29087 .18436 L p .694 .677 .829 r
F P
0 g
s
.26551 .30302 m .28166 .19798 L .29744 .20689 L p .837 .474 .368 r
F P
0 g
s
.29744 .20689 m .28259 .31231 L .26551 .30302 L p .837 .474 .368 r
F P
0 g
s
.29251 .29818 m .28259 .31231 L .29744 .20689 L p 0 0 .156 r
F P
0 g
s
.29744 .20689 m .30669 .19334 L .29251 .29818 L p 0 0 .156 r
F P
0 g
s
.26392 .3134 m .28166 .19798 L .29744 .20689 L p .837 .474 .368 r
F P
0 g
s
.29744 .20689 m .28113 .32273 L .26392 .3134 L p .837 .474 .368 r
F P
0 g
s
.29251 .29818 m .28259 .31231 L .29744 .20689 L p 0 0 .156 r
F P
0 g
s
.29744 .20689 m .30669 .19334 L .29251 .29818 L p 0 0 .156 r
F P
0 g
s
.35698 .18403 m .37262 .19302 L .36309 .20657 L p .694 .677 .829 r
F P
0 g
s
.36309 .20657 m .34749 .19766 L .35698 .18403 L p .694 .677 .829 r
F P
0 g
s
.33655 .30269 m .34749 .19766 L .36309 .20657 L p .838 .469 .355 r
F P
0 g
s
.36309 .20657 m .35342 .31198 L .33655 .30269 L p .838 .469 .355 r
F P
0 g
s
.36366 .29785 m .35342 .31198 L .36309 .20657 L p 0 0 .2 r
F P
0 g
s
.36309 .20657 m .37262 .19302 L .36366 .29785 L p 0 0 .2 r
F P
0 g
s
.33655 .30269 m .34749 .19766 L .36309 .20657 L p .838 .469 .355 r
F P
0 g
s
.36309 .20657 m .35342 .31198 L .33655 .30269 L p .838 .469 .355 r
F P
0 g
s
.36188 .31872 m .35149 .33296 L .36309 .20657 L p 0 0 .2 r
F P
0 g
s
.36309 .20657 m .37262 .19302 L .36188 .31872 L p 0 0 .2 r
F P
0 g
s
.42311 .18371 m .43856 .1927 L .42874 .20625 L p .694 .677 .829 r
F P
0 g
s
.42874 .20625 m .41333 .19733 L .42311 .18371 L p .694 .677 .829 r
F P
0 g
s
.40979 .26229 m .41333 .19733 L .42874 .20625 L p .839 .463 .341 r
F P
0 g
s
.42874 .20625 m .42597 .27145 L .40979 .26229 L p .839 .463 .341 r
F P
0 g
s
.43626 .25753 m .42597 .27145 L .42874 .20625 L p .02 0 .24 r
F P
0 g
s
.42874 .20625 m .43856 .1927 L .43626 .25753 L p .02 0 .24 r
F P
0 g
s
.40589 .33394 m .41333 .19733 L .42874 .20625 L p .839 .463 .341 r
F P
0 g
s
.42874 .20625 m .42291 .34335 L .40589 .33394 L p .839 .463 .341 r
F P
0 g
s
.43626 .25753 m .42597 .27145 L .42874 .20625 L p .02 0 .24 r
F P
0 g
s
.42874 .20625 m .43856 .1927 L .43626 .25753 L p .02 0 .24 r
F P
0 g
s
.48924 .18338 m .50451 .19237 L .49441 .20593 L p .694 .677 .829 r
F P
0 g
s
.49441 .20593 m .47918 .19701 L .48924 .18338 L p .694 .677 .829 r
F P
0 g
s
.47858 .32292 m .47918 .19701 L .49441 .20593 L p .839 .457 .326 r
F P
0 g
s
.49441 .20593 m .49526 .33229 L .47858 .32292 L p .839 .457 .326 r
F P
0 g
s
.50632 .31804 m .49526 .33229 L .49441 .20593 L p .066 0 .276 r
F P
0 g
s
.49441 .20593 m .50451 .19237 L .50632 .31804 L p .066 0 .276 r
F P
0 g
s
.47848 .34444 m .47918 .19701 L .49441 .20593 L p .839 .457 .326 r
F P
0 g
s
.49441 .20593 m .4954 .35389 L .47848 .34444 L p .839 .457 .326 r
F P
0 g
s
.50663 .33953 m .4954 .35389 L .49441 .20593 L p .066 0 .276 r
F P
0 g
s
.49441 .20593 m .50451 .19237 L .50663 .33953 L p .066 0 .276 r
F P
0 g
s
.5554 .18306 m .57048 .19205 L .56009 .20561 L p .694 .677 .829 r
F P
0 g
s
.56009 .20561 m .54505 .19669 L .5554 .18306 L p .694 .677 .829 r
F P
0 g
s
.55023 .31205 m .56657 .32139 L .55535 .33545 L p .691 .688 .843 r
F P
0 g
s
.55168 .3441 m .54505 .19669 L .56009 .20561 L p .839 .45 .311 r
F P
0 g
s
.56093 .36919 m .54466 .36005 L .55586 .34607 L p .69 .689 .844 r
F P
0 g
s
.56009 .20561 m .56837 .35355 L .55168 .3441 L p .839 .45 .311 r
F P
0 g
s
.57995 .33919 m .56837 .35355 L .56009 .20561 L p .108 0 .308 r
F P
0 g
s
.56009 .20561 m .57048 .19205 L .57995 .33919 L p .108 0 .308 r
F P
0 g
s
.55023 .31205 m .54505 .19669 L .56009 .20561 L p .839 .45 .311 r
F P
0 g
s
.56009 .20561 m .56657 .32139 L .55023 .31205 L p .839 .45 .311 r
F P
0 g
s
.57995 .33919 m .56837 .35355 L .56009 .20561 L p .108 0 .308 r
F P
0 g
s
.56009 .20561 m .57048 .19205 L .57995 .33919 L p .108 0 .308 r
F P
0 g
s
.62156 .18273 m .63646 .19173 L .62578 .20529 L p .694 .677 .829 r
F P
0 g
s
.62578 .20529 m .61093 .19637 L .62156 .18273 L p .694 .677 .829 r
F P
0 g
s
.62489 .34376 m .61093 .19637 L .62578 .20529 L p .839 .442 .294 r
F P
0 g
s
.62578 .20529 m .64135 .35321 L .62489 .34376 L p .839 .442 .294 r
F P
0 g
s
.65329 .33885 m .64135 .35321 L .62578 .20529 L p .145 0 .337 r
F P
0 g
s
.62578 .20529 m .63646 .19173 L .65329 .33885 L p .145 0 .337 r
F P
0 g
s
.62489 .34376 m .61093 .19637 L .62578 .20529 L p .839 .442 .294 r
F P
0 g
s
.62578 .20529 m .64135 .35321 L .62489 .34376 L p .839 .442 .294 r
F P
0 g
s
.65582 .36098 m .64369 .37545 L .62578 .20529 L p .145 0 .337 r
F P
0 g
s
.62578 .20529 m .63646 .19173 L .65582 .36098 L p .145 0 .337 r
F P
0 g
s
.70296 .37692 m .67682 .19605 L .69149 .20497 L p .839 .434 .276 r
F P
0 g
s
.69149 .20497 m .71955 .38648 L .70296 .37692 L p .839 .434 .276 r
F P
0 g
s
.31602 .17968 m .3318 .18869 L .32243 .20228 L p .694 .677 .829 r
F P
0 g
s
.32243 .20228 m .30669 .19334 L .31602 .17968 L p .694 .677 .829 r
F P
0 g
s
.29251 .29818 m .30669 .19334 L .32243 .20228 L p .837 .472 .362 r
F P
0 g
s
.32243 .20228 m .30953 .30751 L .29251 .29818 L p .837 .472 .362 r
F P
0 g
s
.32758 .30649 m .31079 .29726 L .32078 .28314 L p .691 .686 .84 r
F P
0 g
s
.31959 .29333 m .30953 .30751 L .32243 .20228 L p 0 0 .171 r
F P
0 g
s
.32243 .20228 m .3318 .18869 L .31959 .29333 L p 0 0 .171 r
F P
0 g
s
.29251 .29818 m .30669 .19334 L .32243 .20228 L p .837 .472 .362 r
F P
0 g
s
.32243 .20228 m .30953 .30751 L .29251 .29818 L p .837 .472 .362 r
F P
0 g
s
.32078 .28314 m .31079 .29726 L .32243 .20228 L p 0 0 .171 r
F P
0 g
s
.32243 .20228 m .3318 .18869 L .32078 .28314 L p 0 0 .171 r
F P
0 g
s
.38223 .17935 m .39783 .18837 L .38817 .20196 L p .694 .677 .829 r
F P
0 g
s
.38817 .20196 m .37262 .19302 L .38223 .17935 L p .694 .677 .829 r
F P
0 g
s
.36278 .30821 m .37262 .19302 L .38817 .20196 L p .838 .466 .348 r
F P
0 g
s
.38817 .20196 m .37971 .31757 L .36278 .30821 L p .838 .466 .348 r
F P
0 g
s
.39017 .30334 m .37971 .31757 L .38817 .20196 L p 0 0 .214 r
F P
0 g
s
.38817 .20196 m .39783 .18837 L .39017 .30334 L p 0 0 .214 r
F P
0 g
s
.36188 .31872 m .37262 .19302 L .38817 .20196 L p .838 .466 .348 r
F P
0 g
s
.38817 .20196 m .37894 .32812 L .36188 .31872 L p .838 .466 .348 r
F P
0 g
s
.38947 .31383 m .37894 .32812 L .38817 .20196 L p 0 0 .214 r
F P
0 g
s
.38817 .20196 m .39783 .18837 L .38947 .31383 L p 0 0 .214 r
F P
0 g
s
.44846 .17903 m .46386 .18805 L .45392 .20164 L p .694 .677 .829 r
F P
0 g
s
.45392 .20164 m .43856 .1927 L .44846 .17903 L p .694 .677 .829 r
F P
0 g
s
.43626 .25753 m .43856 .1927 L .45392 .20164 L p .839 .46 .334 r
F P
0 g
s
.45392 .20164 m .45238 .26671 L .43626 .25753 L p .839 .46 .334 r
F P
0 g
s
.4628 .25275 m .45238 .26671 L .45392 .20164 L p .036 0 .253 r
F P
0 g
s
.45392 .20164 m .46386 .18805 L .4628 .25275 L p .036 0 .253 r
F P
0 g
s
.43626 .25753 m .43856 .1927 L .45392 .20164 L p .839 .46 .334 r
F P
0 g
s
.45392 .20164 m .45238 .26671 L .43626 .25753 L p .839 .46 .334 r
F P
0 g
s
.46163 .32414 m .45068 .33848 L .45392 .20164 L p .036 0 .253 r
F P
0 g
s
.45392 .20164 m .46386 .18805 L .46163 .32414 L p .036 0 .253 r
F P
0 g
s
.5147 .1787 m .52992 .18772 L .51969 .20132 L p .694 .677 .829 r
F P
0 g
s
.51969 .20132 m .50451 .19237 L .5147 .1787 L p .694 .677 .829 r
F P
0 g
s
.50648 .32871 m .50451 .19237 L .51969 .20132 L p .839 .453 .319 r
F P
0 g
s
.51969 .20132 m .52321 .33814 L .50648 .32871 L p .839 .453 .319 r
F P
0 g
s
.53451 .3238 m .52321 .33814 L .51969 .20132 L p .08 0 .287 r
F P
0 g
s
.51969 .20132 m .52992 .18772 L .53451 .3238 L p .08 0 .287 r
F P
0 g
s
.50663 .33953 m .50451 .19237 L .51969 .20132 L p .839 .453 .319 r
F P
0 g
s
.51969 .20132 m .52349 .349 L .50663 .33953 L p .839 .453 .319 r
F P
0 g
s
.53488 .3346 m .52349 .349 L .51969 .20132 L p .08 0 .287 r
F P
0 g
s
.51969 .20132 m .52992 .18772 L .53488 .3346 L p .08 0 .287 r
F P
0 g
s
.58095 .17838 m .59598 .1874 L .58547 .201 L p .694 .677 .829 r
F P
0 g
s
.58547 .201 m .57048 .19205 L .58095 .17838 L p .694 .677 .829 r
F P
0 g
s
.57995 .33919 m .57048 .19205 L .58547 .201 L p .84 .446 .302 r
F P
0 g
s
.58547 .201 m .59658 .34866 L .57995 .33919 L p .84 .446 .302 r
F P
0 g
s
.61217 .34718 m .59577 .3378 L .60741 .32345 L p .69 .69 .845 r
F P
0 g
s
.60832 .33426 m .59658 .34866 L .58547 .201 L p .121 0 .318 r
F P
0 g
s
.58547 .201 m .59598 .1874 L .60832 .33426 L p .121 0 .318 r
F P
0 g
s
.57995 .33919 m .57048 .19205 L .58547 .201 L p .84 .446 .302 r
F P
0 g
s
.58547 .201 m .59658 .34866 L .57995 .33919 L p .84 .446 .302 r
F P
0 g
s
.60741 .32345 m .59577 .3378 L .58547 .201 L p .121 0 .318 r
F P
0 g
s
.58547 .201 m .59598 .1874 L .60741 .32345 L p .121 0 .318 r
F P
0 g
s
.64722 .17805 m .66206 .18707 L .65126 .20067 L p .694 .677 .829 r
F P
0 g
s
.65126 .20067 m .63646 .19173 L .64722 .17805 L p .694 .677 .829 r
F P
0 g
s
.65455 .34983 m .63646 .19173 L .65126 .20067 L p .839 .438 .285 r
F P
0 g
s
.65126 .20067 m .67107 .35934 L .65455 .34983 L p .839 .438 .285 r
F P
0 g
s
.68325 .34488 m .67107 .35934 L .65126 .20067 L p .157 0 .346 r
F P
0 g
s
.65126 .20067 m .66206 .18707 L .68325 .34488 L p .157 0 .346 r
F P
0 g
s
.65582 .36098 m .63646 .19173 L .65126 .20067 L p .839 .438 .285 r
F P
0 g
s
.65126 .20067 m .67246 .37053 L .65582 .36098 L p .839 .438 .285 r
F P
0 g
s
.68475 .35601 m .67246 .37053 L .65126 .20067 L p .157 0 .346 r
F P
0 g
s
.65126 .20067 m .66206 .18707 L .68475 .35601 L p .157 0 .346 r
F P
0 g
s
.27538 .2888 m .26551 .30302 L .28166 .19798 L p 0 0 .14 r
F P
0 g
s
.28166 .19798 m .29087 .18436 L .27538 .2888 L p 0 0 .14 r
F P
0 g
s
.34125 .17499 m .35698 .18403 L .34749 .19766 L p .694 .677 .829 r
F P
0 g
s
.34749 .19766 m .3318 .18869 L .34125 .17499 L p .694 .677 .829 r
F P
0 g
s
.32078 .28314 m .33762 .29245 L .32758 .30649 L p .691 .686 .84 r
F P
0 g
s
.31959 .29333 m .3318 .18869 L .34749 .19766 L p .838 .469 .355 r
F P
0 g
s
.34749 .19766 m .33655 .30269 L .31959 .29333 L p .838 .469 .355 r
F P
0 g
s
.34675 .28847 m .33655 .30269 L .34749 .19766 L p 0 0 .186 r
F P
0 g
s
.34749 .19766 m .35698 .18403 L .34675 .28847 L p 0 0 .186 r
F P
0 g
s
.32078 .28314 m .3318 .18869 L .34749 .19766 L p .838 .469 .355 r
F P
0 g
s
.34749 .19766 m .33762 .29245 L .32078 .28314 L p .838 .469 .355 r
F P
0 g
s
.34675 .28847 m .33655 .30269 L .34749 .19766 L p 0 0 .186 r
F P
0 g
s
.34749 .19766 m .35698 .18403 L .34675 .28847 L p 0 0 .186 r
F P
0 g
s
.40756 .17466 m .42311 .18371 L .41333 .19733 L p .694 .677 .829 r
F P
0 g
s
.41333 .19733 m .39783 .18837 L .40756 .17466 L p .694 .677 .829 r
F P
0 g
s
.39352 .25308 m .39783 .18837 L .41333 .19733 L p .839 .463 .341 r
F P
0 g
s
.41333 .19733 m .40979 .26229 L .39352 .25308 L p .839 .463 .341 r
F P
0 g
s
.42003 .24829 m .40979 .26229 L .41333 .19733 L p .004 0 .228 r
F P
0 g
s
.41333 .19733 m .42311 .18371 L .42003 .24829 L p .004 0 .228 r
F P
0 g
s
.38947 .31383 m .39783 .18837 L .41333 .19733 L p .839 .463 .341 r
F P
0 g
s
.41333 .19733 m .40647 .32326 L .38947 .31383 L p .839 .463 .341 r
F P
0 g
s
.42003 .24829 m .40979 .26229 L .41333 .19733 L p .004 0 .228 r
F P
0 g
s
.41333 .19733 m .42311 .18371 L .42003 .24829 L p .004 0 .228 r
F P
0 g
s
.47389 .17434 m .48924 .18338 L .47918 .19701 L p .694 .677 .829 r
F P
0 g
s
.47918 .19701 m .46386 .18805 L .47389 .17434 L p .694 .677 .829 r
F P
0 g
s
.4618 .31349 m .46386 .18805 L .47918 .19701 L p .839 .457 .326 r
F P
0 g
s
.47918 .19701 m .47858 .32292 L .4618 .31349 L p .839 .457 .326 r
F P
0 g
s
.48961 .30858 m .47858 .32292 L .47918 .19701 L p .051 0 .265 r
F P
0 g
s
.47918 .19701 m .48924 .18338 L .48961 .30858 L p .051 0 .265 r
F P
0 g
s
.46163 .32414 m .46386 .18805 L .47918 .19701 L p .839 .457 .326 r
F P
0 g
s
.47918 .19701 m .47853 .3336 L .46163 .32414 L p .839 .457 .326 r
F P
0 g
s
.48961 .30858 m .47858 .32292 L .47918 .19701 L p .051 0 .265 r
F P
0 g
s
.47918 .19701 m .48924 .18338 L .48961 .30858 L p .051 0 .265 r
F P
0 g
s
.54023 .17401 m .5554 .18306 L .54505 .19669 L p .694 .677 .829 r
F P
0 g
s
.54505 .19669 m .52992 .18772 L .54023 .17401 L p .694 .677 .829 r
F P
0 g
s
.53345 .29232 m .52992 .18772 L .54505 .19669 L p .839 .45 .311 r
F P
0 g
s
.54505 .19669 m .54977 .30168 L .53345 .29232 L p .839 .45 .311 r
F P
0 g
s
.56097 .28745 m .54977 .30168 L .54505 .19669 L p .094 0 .298 r
F P
0 g
s
.54505 .19669 m .5554 .18306 L .56097 .28745 L p .094 0 .298 r
F P
0 g
s
.53488 .3346 m .52992 .18772 L .54505 .19669 L p .839 .45 .311 r
F P
0 g
s
.54505 .19669 m .55168 .3441 L .53488 .3346 L p .839 .45 .311 r
F P
0 g
s
.56322 .32966 m .55168 .3441 L .54505 .19669 L p .094 0 .298 r
F P
0 g
s
.54505 .19669 m .5554 .18306 L .56322 .32966 L p .094 0 .298 r
F P
0 g
s
.60659 .17368 m .62156 .18273 L .61093 .19637 L p .694 .677 .829 r
F P
0 g
s
.61093 .19637 m .59598 .1874 L .60659 .17368 L p .694 .677 .829 r
F P
0 g
s
.60741 .32345 m .62386 .33292 L .61217 .34718 L p .69 .69 .845 r
F P
0 g
s
.60832 .33426 m .59598 .1874 L .61093 .19637 L p .839 .442 .294 r
F P
0 g
s
.61093 .19637 m .62489 .34376 L .60832 .33426 L p .839 .442 .294 r
F P
0 g
s
.63678 .32931 m .62489 .34376 L .61093 .19637 L p .133 0 .328 r
F P
0 g
s
.61093 .19637 m .62156 .18273 L .63678 .32931 L p .133 0 .328 r
F P
0 g
s
.60741 .32345 m .59598 .1874 L .61093 .19637 L p .839 .442 .294 r
F P
0 g
s
.61093 .19637 m .62386 .33292 L .60741 .32345 L p .839 .442 .294 r
F P
0 g
s
.63678 .32931 m .62489 .34376 L .61093 .19637 L p .133 0 .328 r
F P
0 g
s
.61093 .19637 m .62156 .18273 L .63678 .32931 L p .133 0 .328 r
F P
0 g
s
.68475 .35601 m .66206 .18707 L .67682 .19605 L p .839 .434 .276 r
F P
0 g
s
.67682 .19605 m .70132 .36559 L .68475 .35601 L p .839 .434 .276 r
F P
0 g
s
.30015 .17061 m .31602 .17968 L .30669 .19334 L p .694 .677 .829 r
F P
0 g
s
.30669 .19334 m .29087 .18436 L .30015 .17061 L p .694 .677 .829 r
F P
0 g
s
.27689 .27863 m .29087 .18436 L .30669 .19334 L p .837 .472 .362 r
F P
0 g
s
.30669 .19334 m .29389 .28797 L .27689 .27863 L p .837 .472 .362 r
F P
0 g
s
.30383 .27376 m .29389 .28797 L .30669 .19334 L p 0 0 .156 r
F P
0 g
s
.30669 .19334 m .31602 .17968 L .30383 .27376 L p 0 0 .156 r
F P
0 g
s
.27538 .2888 m .29087 .18436 L .30669 .19334 L p .837 .472 .362 r
F P
0 g
s
.30669 .19334 m .29251 .29818 L .27538 .2888 L p .837 .472 .362 r
F P
0 g
s
.30251 .28392 m .29251 .29818 L .30669 .19334 L p 0 0 .156 r
F P
0 g
s
.30669 .19334 m .31602 .17968 L .30251 .28392 L p 0 0 .156 r
F P
0 g
s
.36656 .17029 m .38223 .17935 L .37262 .19302 L p .694 .677 .829 r
F P
0 g
s
.37262 .19302 m .35698 .18403 L .36656 .17029 L p .694 .677 .829 r
F P
0 g
s
.34675 .28847 m .35698 .18403 L .37262 .19302 L p .838 .466 .348 r
F P
0 g
s
.37262 .19302 m .36366 .29785 L .34675 .28847 L p .838 .466 .348 r
F P
0 g
s
.374 .28358 m .36366 .29785 L .37262 .19302 L p 0 0 .2 r
F P
0 g
s
.37262 .19302 m .38223 .17935 L .374 .28358 L p 0 0 .2 r
F P
0 g
s
.34675 .28847 m .35698 .18403 L .37262 .19302 L p .838 .466 .348 r
F P
0 g
s
.37262 .19302 m .36366 .29785 L .34675 .28847 L p .838 .466 .348 r
F P
0 g
s
.37319 .29389 m .36278 .30821 L .37262 .19302 L p 0 0 .2 r
F P
0 g
s
.37262 .19302 m .38223 .17935 L .37319 .29389 L p 0 0 .2 r
F P
0 g
s
.43297 .16996 m .44846 .17903 L .43856 .1927 L p .694 .677 .829 r
F P
0 g
s
.43856 .1927 m .42311 .18371 L .43297 .16996 L p .694 .677 .829 r
F P
0 g
s
.42049 .23867 m .42311 .18371 L .43856 .1927 L p .839 .46 .334 r
F P
0 g
s
.43856 .1927 m .4366 .24788 L .42049 .23867 L p .839 .46 .334 r
F P
0 g
s
.44691 .23388 m .4366 .24788 L .43856 .1927 L p .02 0 .24 r
F P
0 g
s
.43856 .1927 m .44846 .17903 L .44691 .23388 L p .02 0 .24 r
F P
0 g
s
.42003 .24829 m .42311 .18371 L .43856 .1927 L p .839 .46 .334 r
F P
0 g
s
.43856 .1927 m .43626 .25753 L .42003 .24829 L p .839 .46 .334 r
F P
0 g
s
.44664 .24348 m .43626 .25753 L .43856 .1927 L p .02 0 .24 r
F P
0 g
s
.43856 .1927 m .44846 .17903 L .44664 .24348 L p .02 0 .24 r
F P
0 g
s
.4994 .16963 m .5147 .1787 L .50451 .19237 L p .694 .677 .829 r
F P
0 g
s
.50451 .19237 m .48924 .18338 L .4994 .16963 L p .694 .677 .829 r
F P
0 g
s
.48961 .30858 m .48924 .18338 L .50451 .19237 L p .839 .453 .319 r
F P
0 g
s
.50451 .19237 m .50632 .31804 L .48961 .30858 L p .839 .453 .319 r
F P
0 g
s
.5175 .30366 m .50632 .31804 L .50451 .19237 L p .066 0 .276 r
F P
0 g
s
.50451 .19237 m .5147 .1787 L .5175 .30366 L p .066 0 .276 r
F P
0 g
s
.48961 .30858 m .48924 .18338 L .50451 .19237 L p .839 .453 .319 r
F P
0 g
s
.50451 .19237 m .50632 .31804 L .48961 .30858 L p .839 .453 .319 r
F P
0 g
s
.51773 .31427 m .50648 .32871 L .50451 .19237 L p .066 0 .276 r
F P
0 g
s
.50451 .19237 m .5147 .1787 L .51773 .31427 L p .066 0 .276 r
F P
0 g
s
.56584 .1693 m .58095 .17838 L .57048 .19205 L p .694 .677 .829 r
F P
0 g
s
.57048 .19205 m .5554 .18306 L .56584 .1693 L p .694 .677 .829 r
F P
0 g
s
.56264 .31887 m .5554 .18306 L .57048 .19205 L p .84 .446 .302 r
F P
0 g
s
.57048 .19205 m .57926 .32837 L .56264 .31887 L p .84 .446 .302 r
F P
0 g
s
.59086 .31393 m .57926 .32837 L .57048 .19205 L p .108 0 .308 r
F P
0 g
s
.57048 .19205 m .58095 .17838 L .59086 .31393 L p .108 0 .308 r
F P
0 g
s
.56322 .32966 m .5554 .18306 L .57048 .19205 L p .84 .446 .302 r
F P
0 g
s
.57048 .19205 m .57995 .33919 L .56322 .32966 L p .84 .446 .302 r
F P
0 g
s
.59165 .32469 m .57995 .33919 L .57048 .19205 L p .108 0 .308 r
F P
0 g
s
.57048 .19205 m .58095 .17838 L .59165 .32469 L p .108 0 .308 r
F P
0 g
s
.63229 .16898 m .64722 .17805 L .63646 .19173 L p .694 .677 .829 r
F P
0 g
s
.63646 .19173 m .62156 .18273 L .63229 .16898 L p .694 .677 .829 r
F P
0 g
s
.63678 .32931 m .62156 .18273 L .63646 .19173 L p .839 .438 .285 r
F P
0 g
s
.63646 .19173 m .65329 .33885 L .63678 .32931 L p .839 .438 .285 r
F P
0 g
s
.66534 .32435 m .65329 .33885 L .63646 .19173 L p .145 0 .337 r
F P
0 g
s
.63646 .19173 m .64722 .17805 L .66534 .32435 L p .145 0 .337 r
F P
0 g
s
.63678 .32931 m .62156 .18273 L .63646 .19173 L p .839 .438 .285 r
F P
0 g
s
.63646 .19173 m .65329 .33885 L .63678 .32931 L p .839 .438 .285 r
F P
0 g
s
.66669 .33527 m .65455 .34983 L .63646 .19173 L p .145 0 .337 r
F P
0 g
s
.63646 .19173 m .64722 .17805 L .66669 .33527 L p .145 0 .337 r
F P
0 g
s
.32543 .1659 m .34125 .17499 L .3318 .18869 L p .694 .677 .829 r
F P
0 g
s
.3318 .18869 m .31602 .17968 L .32543 .1659 L p .694 .677 .829 r
F P
0 g
s
.30513 .26375 m .31602 .17968 L .3318 .18869 L p .838 .469 .355 r
F P
0 g
s
.3318 .18869 m .32195 .27309 L .30513 .26375 L p .838 .469 .355 r
F P
0 g
s
.33196 .25889 m .32195 .27309 L .3318 .18869 L p 0 0 .171 r
F P
0 g
s
.3318 .18869 m .34125 .17499 L .33196 .25889 L p 0 0 .171 r
F P
0 g
s
.30251 .28392 m .31602 .17968 L .3318 .18869 L p .838 .469 .355 r
F P
0 g
s
.3318 .18869 m .31959 .29333 L .30251 .28392 L p .838 .469 .355 r
F P
0 g
s
.32974 .27903 m .31959 .29333 L .3318 .18869 L p 0 0 .171 r
F P
0 g
s
.3318 .18869 m .34125 .17499 L .32974 .27903 L p 0 0 .171 r
F P
0 g
s
.39193 .16557 m .40756 .17466 L .39783 .18837 L p .694 .677 .829 r
F P
0 g
s
.39783 .18837 m .38223 .17935 L .39193 .16557 L p .694 .677 .829 r
F P
0 g
s
.37714 .24381 m .38223 .17935 L .39783 .18837 L p .839 .463 .341 r
F P
0 g
s
.39783 .18837 m .39352 .25308 L .37714 .24381 L p .839 .463 .341 r
F P
0 g
s
.40372 .23899 m .39352 .25308 L .39783 .18837 L p 0 0 .214 r
F P
0 g
s
.39783 .18837 m .40756 .17466 L .40372 .23899 L p 0 0 .214 r
F P
0 g
s
.37319 .29389 m .38223 .17935 L .39783 .18837 L p .839 .463 .341 r
F P
0 g
s
.39783 .18837 m .39017 .30334 L .37319 .29389 L p .839 .463 .341 r
F P
0 g
s
.40372 .23899 m .39352 .25308 L .39783 .18837 L p 0 0 .214 r
F P
0 g
s
.39783 .18837 m .40756 .17466 L .40372 .23899 L p 0 0 .214 r
F P
0 g
s
.45845 .16524 m .47389 .17434 L .46386 .18805 L p .694 .677 .829 r
F P
0 g
s
.46386 .18805 m .44846 .17903 L .45845 .16524 L p .694 .677 .829 r
F P
0 g
s
.44664 .24348 m .44846 .17903 L .46386 .18805 L p .839 .457 .326 r
F P
0 g
s
.46386 .18805 m .4628 .25275 L .44664 .24348 L p .839 .457 .326 r
F P
0 g
s
.47332 .23866 m .4628 .25275 L .46386 .18805 L p .036 0 .253 r
F P
0 g
s
.46386 .18805 m .47389 .17434 L .47332 .23866 L p .036 0 .253 r
F P
0 g
s
.44664 .24348 m .44846 .17903 L .46386 .18805 L p .839 .457 .326 r
F P
0 g
s
.46386 .18805 m .4628 .25275 L .44664 .24348 L p .839 .457 .326 r
F P
0 g
s
.47278 .29907 m .4618 .31349 L .46386 .18805 L p .036 0 .253 r
F P
0 g
s
.46386 .18805 m .47389 .17434 L .47278 .29907 L p .036 0 .253 r
F P
0 g
s
.52498 .16491 m .54023 .17401 L .52992 .18772 L p .694 .677 .829 r
F P
0 g
s
.52992 .18772 m .5147 .1787 L .52498 .16491 L p .694 .677 .829 r
F P
0 g
s
.51703 .2829 m .5147 .1787 L .52992 .18772 L p .839 .45 .311 r
F P
0 g
s
.52992 .18772 m .53345 .29232 L .51703 .2829 L p .839 .45 .311 r
F P
0 g
s
.54461 .278 m .53345 .29232 L .52992 .18772 L p .08 0 .287 r
F P
0 g
s
.52992 .18772 m .54023 .17401 L .54461 .278 L p .08 0 .287 r
F P
0 g
s
.51773 .31427 m .5147 .1787 L .52992 .18772 L p .839 .45 .311 r
F P
0 g
s
.52992 .18772 m .53451 .3238 L .51773 .31427 L p .839 .45 .311 r
F P
0 g
s
.54461 .278 m .53345 .29232 L .52992 .18772 L p .08 0 .287 r
F P
0 g
s
.52992 .18772 m .54023 .17401 L .54461 .278 L p .08 0 .287 r
F P
0 g
s
.59152 .16458 m .60659 .17368 L .59598 .1874 L p .694 .677 .829 r
F P
0 g
s
.59598 .1874 m .58095 .17838 L .59152 .16458 L p .694 .677 .829 r
F P
0 g
s
.59009 .30332 m .58095 .17838 L .59598 .1874 L p .839 .442 .294 r
F P
0 g
s
.59598 .1874 m .60652 .31281 L .59009 .30332 L p .839 .442 .294 r
F P
0 g
s
.61819 .29838 m .60652 .31281 L .59598 .1874 L p .121 0 .318 r
F P
0 g
s
.59598 .1874 m .60659 .17368 L .61819 .29838 L p .121 0 .318 r
F P
0 g
s
.59165 .32469 m .58095 .17838 L .59598 .1874 L p .839 .442 .294 r
F P
0 g
s
.59598 .1874 m .60832 .33426 L .59165 .32469 L p .839 .442 .294 r
F P
0 g
s
.62018 .31971 m .60832 .33426 L .59598 .1874 L p .121 0 .318 r
F P
0 g
s
.59598 .1874 m .60659 .17368 L .62018 .31971 L p .121 0 .318 r
F P
0 g
s
.66669 .33527 m .64722 .17805 L .66206 .18707 L p .839 .434 .276 r
F P
0 g
s
.66206 .18707 m .68325 .34488 L .66669 .33527 L p .839 .434 .276 r
F P
0 g
s
.28678 .26433 m .27689 .27863 L .29087 .18436 L p 0 0 .14 r
F P
0 g
s
.29087 .18436 m .30015 .17061 L .28678 .26433 L p 0 0 .14 r
F P
0 g
s
.35079 .16117 m .36656 .17029 L .35698 .18403 L p .694 .677 .829 r
F P
0 g
s
.35698 .18403 m .34125 .17499 L .35079 .16117 L p .694 .677 .829 r
F P
0 g
s
.33086 .26889 m .34125 .17499 L .35698 .18403 L p .838 .466 .348 r
F P
0 g
s
.35698 .18403 m .34775 .27829 L .33086 .26889 L p .838 .466 .348 r
F P
0 g
s
.35797 .26399 m .34775 .27829 L .35698 .18403 L p 0 0 .186 r
F P
0 g
s
.35698 .18403 m .36656 .17029 L .35797 .26399 L p 0 0 .186 r
F P
0 g
s
.32974 .27903 m .34125 .17499 L .35698 .18403 L p .838 .466 .348 r
F P
0 g
s
.35698 .18403 m .34675 .28847 L .32974 .27903 L p .838 .466 .348 r
F P
0 g
s
.35704 .27411 m .34675 .28847 L .35698 .18403 L p 0 0 .186 r
F P
0 g
s
.35698 .18403 m .36656 .17029 L .35704 .27411 L p 0 0 .186 r
F P
0 g
s
.41739 .16084 m .43297 .16996 L .42311 .18371 L p .694 .677 .829 r
F P
0 g
s
.42311 .18371 m .40756 .17466 L .41739 .16084 L p .694 .677 .829 r
F P
0 g
s
.40372 .23899 m .40756 .17466 L .42311 .18371 L p .839 .46 .334 r
F P
0 g
s
.42311 .18371 m .42003 .24829 L .40372 .23899 L p .839 .46 .334 r
F P
0 g
s
.4366 .24788 m .42049 .23867 L .43076 .2246 L p .692 .682 .836 r
F P
0 g
s
.43037 .23415 m .42003 .24829 L .42311 .18371 L p .004 0 .228 r
F P
0 g
s
.42311 .18371 m .43297 .16996 L .43037 .23415 L p .004 0 .228 r
F P
0 g
s
.40372 .23899 m .40756 .17466 L .42311 .18371 L p .839 .46 .334 r
F P
0 g
s
.42311 .18371 m .42003 .24829 L .40372 .23899 L p .839 .46 .334 r
F P
0 g
s
.43076 .2246 m .42049 .23867 L .42311 .18371 L p .004 0 .228 r
F P
0 g
s
.42311 .18371 m .43297 .16996 L .43076 .2246 L p .004 0 .228 r
F P
0 g
s
.48401 .16051 m .4994 .16963 L .48924 .18338 L p .694 .677 .829 r
F P
0 g
s
.48924 .18338 m .47389 .17434 L .48401 .16051 L p .694 .677 .829 r
F P
0 g
s
.47288 .28863 m .47389 .17434 L .48924 .18338 L p .839 .453 .319 r
F P
0 g
s
.48924 .18338 m .48958 .29811 L .47288 .28863 L p .839 .453 .319 r
F P
0 g
s
.50062 .28369 m .48958 .29811 L .48924 .18338 L p .051 0 .265 r
F P
0 g
s
.48924 .18338 m .4994 .16963 L .50062 .28369 L p .051 0 .265 r
F P
0 g
s
.47278 .29907 m .47389 .17434 L .48924 .18338 L p .839 .453 .319 r
F P
0 g
s
.48924 .18338 m .48961 .30858 L .47278 .29907 L p .839 .453 .319 r
F P
0 g
s
.50073 .29411 m .48961 .30858 L .48924 .18338 L p .051 0 .265 r
F P
0 g
s
.48924 .18338 m .4994 .16963 L .50073 .29411 L p .051 0 .265 r
F P
0 g
s
.55064 .16018 m .56584 .1693 L .5554 .18306 L p .694 .677 .829 r
F P
0 g
s
.5554 .18306 m .54023 .17401 L .55064 .16018 L p .694 .677 .829 r
F P
0 g
s
.54461 .278 m .54023 .17401 L .5554 .18306 L p .84 .446 .302 r
F P
0 g
s
.5554 .18306 m .56097 .28745 L .54461 .278 L p .84 .446 .302 r
F P
0 g
s
.57227 .27309 m .56097 .28745 L .5554 .18306 L p .094 0 .298 r
F P
0 g
s
.5554 .18306 m .56584 .1693 L .57227 .27309 L p .094 0 .298 r
F P
0 g
s
.54461 .278 m .54023 .17401 L .5554 .18306 L p .84 .446 .302 r
F P
0 g
s
.5554 .18306 m .56097 .28745 L .54461 .278 L p .84 .446 .302 r
F P
0 g
s
.57421 .30434 m .56264 .31887 L .5554 .18306 L p .094 0 .298 r
F P
0 g
s
.5554 .18306 m .56584 .1693 L .57421 .30434 L p .094 0 .298 r
F P
0 g
s
.61728 .15985 m .63229 .16898 L .62156 .18273 L p .694 .677 .829 r
F P
0 g
s
.62156 .18273 m .60659 .17368 L .61728 .15985 L p .694 .677 .829 r
F P
0 g
s
.61918 .30897 m .60659 .17368 L .62156 .18273 L p .839 .438 .285 r
F P
0 g
s
.62156 .18273 m .63567 .31853 L .61918 .30897 L p .839 .438 .285 r
F P
0 g
s
.64758 .30399 m .63567 .31853 L .62156 .18273 L p .133 0 .328 r
F P
0 g
s
.62156 .18273 m .63229 .16898 L .64758 .30399 L p .133 0 .328 r
F P
0 g
s
.62018 .31971 m .60659 .17368 L .62156 .18273 L p .839 .438 .285 r
F P
0 g
s
.62156 .18273 m .63678 .32931 L .62018 .31971 L p .839 .438 .285 r
F P
0 g
s
.6488 .31472 m .63678 .32931 L .62156 .18273 L p .133 0 .328 r
F P
0 g
s
.62156 .18273 m .63229 .16898 L .6488 .31472 L p .133 0 .328 r
F P
0 g
s
.30952 .15675 m .32543 .1659 L .31602 .17968 L p .694 .677 .829 r
F P
0 g
s
.31602 .17968 m .30015 .17061 L .30952 .15675 L p .694 .677 .829 r
F P
0 g
s
.2882 .25436 m .30015 .17061 L .31602 .17968 L p .838 .469 .355 r
F P
0 g
s
.31602 .17968 m .30513 .26375 L .2882 .25436 L p .838 .469 .355 r
F P
0 g
s
.31509 .24947 m .30513 .26375 L .31602 .17968 L p 0 0 .156 r
F P
0 g
s
.31602 .17968 m .32543 .1659 L .31509 .24947 L p 0 0 .156 r
F P
0 g
s
.28678 .26433 m .30015 .17061 L .31602 .17968 L p .838 .469 .355 r
F P
0 g
s
.31602 .17968 m .30383 .27376 L .28678 .26433 L p .838 .469 .355 r
F P
0 g
s
.31509 .24947 m .30513 .26375 L .31602 .17968 L p 0 0 .156 r
F P
0 g
s
.31602 .17968 m .32543 .1659 L .31509 .24947 L p 0 0 .156 r
F P
0 g
s
.37621 .15642 m .39193 .16557 L .38223 .17935 L p .694 .677 .829 r
F P
0 g
s
.38223 .17935 m .36656 .17029 L .37621 .15642 L p .694 .677 .829 r
F P
0 g
s
.36067 .23449 m .36656 .17029 L .38223 .17935 L p .839 .463 .341 r
F P
0 g
s
.38223 .17935 m .37714 .24381 L .36067 .23449 L p .839 .463 .341 r
F P
0 g
s
.3873 .22964 m .37714 .24381 L .38223 .17935 L p 0 0 .2 r
F P
0 g
s
.38223 .17935 m .39193 .16557 L .3873 .22964 L p 0 0 .2 r
F P
0 g
s
.35704 .27411 m .36656 .17029 L .38223 .17935 L p .839 .463 .341 r
F P
0 g
s
.38223 .17935 m .374 .28358 L .35704 .27411 L p .839 .463 .341 r
F P
0 g
s
.3873 .22964 m .37714 .24381 L .38223 .17935 L p 0 0 .2 r
F P
0 g
s
.38223 .17935 m .39193 .16557 L .3873 .22964 L p 0 0 .2 r
F P
0 g
s
.44292 .15609 m .45845 .16524 L .44846 .17903 L p .694 .677 .829 r
F P
0 g
s
.44846 .17903 m .43297 .16996 L .44292 .15609 L p .694 .677 .829 r
F P
0 g
s
.43076 .2246 m .44691 .23388 L .4366 .24788 L p .692 .682 .836 r
F P
0 g
s
.43037 .23415 m .43297 .16996 L .44846 .17903 L p .839 .457 .326 r
F P
0 g
s
.44846 .17903 m .44664 .24348 L .43037 .23415 L p .839 .457 .326 r
F P
0 g
s
.45711 .2293 m .44664 .24348 L .44846 .17903 L p .02 0 .24 r
F P
0 g
s
.44846 .17903 m .45845 .16524 L .45711 .2293 L p .02 0 .24 r
F P
0 g
s
.43076 .2246 m .43297 .16996 L .44846 .17903 L p .839 .457 .326 r
F P
0 g
s
.44846 .17903 m .44691 .23388 L .43076 .2246 L p .839 .457 .326 r
F P
0 g
s
.45711 .2293 m .44664 .24348 L .44846 .17903 L p .02 0 .24 r
F P
0 g
s
.44846 .17903 m .45845 .16524 L .45711 .2293 L p .02 0 .24 r
F P
0 g
s
.50964 .15576 m .52498 .16491 L .5147 .1787 L p .694 .677 .829 r
F P
0 g
s
.5147 .1787 m .4994 .16963 L .50964 .15576 L p .694 .677 .829 r
F P
0 g
s
.50051 .27343 m .4994 .16963 L .5147 .1787 L p .839 .45 .311 r
F P
0 g
s
.5147 .1787 m .51703 .2829 L .50051 .27343 L p .839 .45 .311 r
F P
0 g
s
.52815 .2685 m .51703 .2829 L .5147 .1787 L p .066 0 .276 r
F P
0 g
s
.5147 .1787 m .52498 .16491 L .52815 .2685 L p .066 0 .276 r
F P
0 g
s
.50073 .29411 m .4994 .16963 L .5147 .1787 L p .839 .45 .311 r
F P
0 g
s
.5147 .1787 m .5175 .30366 L .50073 .29411 L p .839 .45 .311 r
F P
0 g
s
.52815 .2685 m .51703 .2829 L .5147 .1787 L p .066 0 .276 r
F P
0 g
s
.5147 .1787 m .52498 .16491 L .52815 .2685 L p .066 0 .276 r
F P
0 g
s
.57637 .15543 m .59152 .16458 L .58095 .17838 L p .694 .677 .829 r
F P
0 g
s
.58095 .17838 m .56584 .1693 L .57637 .15543 L p .694 .677 .829 r
F P
0 g
s
.57355 .29377 m .56584 .1693 L .58095 .17838 L p .839 .442 .294 r
F P
0 g
s
.58095 .17838 m .59009 .30332 L .57355 .29377 L p .839 .442 .294 r
F P
0 g
s
.60171 .2888 m .59009 .30332 L .58095 .17838 L p .108 0 .308 r
F P
0 g
s
.58095 .17838 m .59152 .16458 L .60171 .2888 L p .108 0 .308 r
F P
0 g
s
.57421 .30434 m .56584 .1693 L .58095 .17838 L p .839 .442 .294 r
F P
0 g
s
.58095 .17838 m .59086 .31393 L .57421 .30434 L p .839 .442 .294 r
F P
0 g
s
.60171 .2888 m .59009 .30332 L .58095 .17838 L p .108 0 .308 r
F P
0 g
s
.58095 .17838 m .59152 .16458 L .60171 .2888 L p .108 0 .308 r
F P
0 g
s
.6488 .31472 m .63229 .16898 L .64722 .17805 L p .839 .434 .276 r
F P
0 g
s
.64722 .17805 m .66534 .32435 L .6488 .31472 L p .839 .434 .276 r
F P
0 g
s
.33492 .15199 m .35079 .16117 L .34125 .17499 L p .694 .677 .829 r
F P
0 g
s
.34125 .17499 m .32543 .1659 L .33492 .15199 L p .694 .677 .829 r
F P
0 g
s
.31509 .24947 m .32543 .1659 L .34125 .17499 L p .838 .466 .348 r
F P
0 g
s
.34125 .17499 m .33196 .25889 L .31509 .24947 L p .838 .466 .348 r
F P
0 g
s
.34207 .24456 m .33196 .25889 L .34125 .17499 L p 0 0 .171 r
F P
0 g
s
.34125 .17499 m .35079 .16117 L .34207 .24456 L p 0 0 .171 r
F P
0 g
s
.31509 .24947 m .32543 .1659 L .34125 .17499 L p .838 .466 .348 r
F P
0 g
s
.34125 .17499 m .33196 .25889 L .31509 .24947 L p .838 .466 .348 r
F P
0 g
s
.34103 .2545 m .33086 .26889 L .34125 .17499 L p 0 0 .171 r
F P
0 g
s
.34125 .17499 m .35079 .16117 L .34103 .2545 L p 0 0 .171 r
F P
0 g
s
.40172 .15166 m .41739 .16084 L .40756 .17466 L p .694 .677 .829 r
F P
0 g
s
.40756 .17466 m .39193 .16557 L .40172 .15166 L p .694 .677 .829 r
F P
0 g
s
.38799 .2201 m .39193 .16557 L .40756 .17466 L p .839 .46 .334 r
F P
0 g
s
.40756 .17466 m .40429 .22942 L .38799 .2201 L p .839 .46 .334 r
F P
0 g
s
.41451 .21525 m .40429 .22942 L .40756 .17466 L p 0 0 .214 r
F P
0 g
s
.40756 .17466 m .41739 .16084 L .41451 .21525 L p 0 0 .214 r
F P
0 g
s
.3873 .22964 m .39193 .16557 L .40756 .17466 L p .839 .46 .334 r
F P
0 g
s
.40756 .17466 m .40372 .23899 L .3873 .22964 L p .839 .46 .334 r
F P
0 g
s
.41401 .22477 m .40372 .23899 L .40756 .17466 L p 0 0 .214 r
F P
0 g
s
.40756 .17466 m .41739 .16084 L .41401 .22477 L p 0 0 .214 r
F P
0 g
s
.46853 .15133 m .48401 .16051 L .47389 .17434 L p .694 .677 .829 r
F P
0 g
s
.47389 .17434 m .45845 .16524 L .46853 .15133 L p .694 .677 .829 r
F P
0 g
s
.45711 .2293 m .45845 .16524 L .47389 .17434 L p .839 .453 .319 r
F P
0 g
s
.47389 .17434 m .47332 .23866 L .45711 .2293 L p .839 .453 .319 r
F P
0 g
s
.48393 .22444 m .47332 .23866 L .47389 .17434 L p .036 0 .253 r
F P
0 g
s
.47389 .17434 m .48401 .16051 L .48393 .22444 L p .036 0 .253 r
F P
0 g
s
.45711 .2293 m .45845 .16524 L .47389 .17434 L p .839 .453 .319 r
F P
0 g
s
.47389 .17434 m .47332 .23866 L .45711 .2293 L p .839 .453 .319 r
F P
0 g
s
.48388 .27412 m .47288 .28863 L .47389 .17434 L p .036 0 .253 r
F P
0 g
s
.47389 .17434 m .48401 .16051 L .48388 .27412 L p .036 0 .253 r
F P
0 g
s
.53535 .151 m .55064 .16018 L .54023 .17401 L p .694 .677 .829 r
F P
0 g
s
.54023 .17401 m .52498 .16491 L .53535 .151 L p .694 .677 .829 r
F P
0 g
s
.52784 .2584 m .52498 .16491 L .54023 .17401 L p .84 .446 .302 r
F P
0 g
s
.54023 .17401 m .54418 .26787 L .52784 .2584 L p .84 .446 .302 r
F P
0 g
s
.55536 .25347 m .54418 .26787 L .54023 .17401 L p .08 0 .287 r
F P
0 g
s
.54023 .17401 m .55064 .16018 L .55536 .25347 L p .08 0 .287 r
F P
0 g
s
.52815 .2685 m .52498 .16491 L .54023 .17401 L p .84 .446 .302 r
F P
0 g
s
.54023 .17401 m .54461 .278 L .52815 .2685 L p .84 .446 .302 r
F P
0 g
s
.55587 .26355 m .54461 .278 L .54023 .17401 L p .08 0 .287 r
F P
0 g
s
.54023 .17401 m .55064 .16018 L .55587 .26355 L p .08 0 .287 r
F P
0 g
s
.60218 .15067 m .61728 .15985 L .60659 .17368 L p .694 .677 .829 r
F P
0 g
s
.60659 .17368 m .59152 .16458 L .60218 .15067 L p .694 .677 .829 r
F P
0 g
s
.60171 .2888 m .59152 .16458 L .60659 .17368 L p .839 .438 .285 r
F P
0 g
s
.60659 .17368 m .61819 .29838 L .60171 .2888 L p .839 .438 .285 r
F P
0 g
s
.62997 .28381 m .61819 .29838 L .60659 .17368 L p .121 0 .318 r
F P
0 g
s
.60659 .17368 m .61728 .15985 L .62997 .28381 L p .121 0 .318 r
F P
0 g
s
.60171 .2888 m .59152 .16458 L .60659 .17368 L p .839 .438 .285 r
F P
0 g
s
.60659 .17368 m .61819 .29838 L .60171 .2888 L p .839 .438 .285 r
F P
0 g
s
.63105 .29434 m .61918 .30897 L .60659 .17368 L p .121 0 .318 r
F P
0 g
s
.60659 .17368 m .61728 .15985 L .63105 .29434 L p .121 0 .318 r
F P
0 g
s
.29812 .23999 m .2882 .25436 L .30015 .17061 L p 0 0 .14 r
F P
0 g
s
.30015 .17061 m .30952 .15675 L .29812 .23999 L p 0 0 .14 r
F P
0 g
s
.3604 .14722 m .37621 .15642 L .36656 .17029 L p .694 .677 .829 r
F P
0 g
s
.36656 .17029 m .35079 .16117 L .3604 .14722 L p .694 .677 .829 r
F P
0 g
s
.3441 .22511 m .35079 .16117 L .36656 .17029 L p .839 .463 .341 r
F P
0 g
s
.36656 .17029 m .36067 .23449 L .3441 .22511 L p .839 .463 .341 r
F P
0 g
s
.37079 .22023 m .36067 .23449 L .36656 .17029 L p 0 0 .186 r
F P
0 g
s
.36656 .17029 m .37621 .15642 L .37079 .22023 L p 0 0 .186 r
F P
0 g
s
.34103 .2545 m .35079 .16117 L .36656 .17029 L p .839 .463 .341 r
F P
0 g
s
.36656 .17029 m .35797 .26399 L .34103 .2545 L p .839 .463 .341 r
F P
0 g
s
.37079 .22023 m .36067 .23449 L .36656 .17029 L p 0 0 .186 r
F P
0 g
s
.36656 .17029 m .37621 .15642 L .37079 .22023 L p 0 0 .186 r
F P
0 g
s
.4273 .14689 m .44292 .15609 L .43297 .16996 L p .694 .677 .829 r
F P
0 g
s
.43297 .16996 m .41739 .16084 L .4273 .14689 L p .694 .677 .829 r
F P
0 g
s
.41501 .20587 m .41739 .16084 L .43297 .16996 L p .839 .457 .326 r
F P
0 g
s
.43297 .16996 m .43114 .21517 L .41501 .20587 L p .839 .457 .326 r
F P
0 g
s
.44143 .20103 m .43114 .21517 L .43297 .16996 L p .004 0 .228 r
F P
0 g
s
.43297 .16996 m .44292 .15609 L .44143 .20103 L p .004 0 .228 r
F P
0 g
s
.41401 .22477 m .41739 .16084 L .43297 .16996 L p .839 .457 .326 r
F P
0 g
s
.43297 .16996 m .43037 .23415 L .41401 .22477 L p .839 .457 .326 r
F P
0 g
s
.44081 .21989 m .43037 .23415 L .43297 .16996 L p .004 0 .228 r
F P
0 g
s
.43297 .16996 m .44292 .15609 L .44081 .21989 L p .004 0 .228 r
F P
0 g
s
.49421 .14656 m .50964 .15576 L .4994 .16963 L p .694 .677 .829 r
F P
0 g
s
.4994 .16963 m .48401 .16051 L .49421 .14656 L p .694 .677 .829 r
F P
0 g
s
.48389 .2639 m .48401 .16051 L .4994 .16963 L p .839 .45 .311 r
F P
0 g
s
.4994 .16963 m .50051 .27343 L .48389 .2639 L p .839 .45 .311 r
F P
0 g
s
.51158 .25893 m .50051 .27343 L .4994 .16963 L p .051 0 .265 r
F P
0 g
s
.4994 .16963 m .50964 .15576 L .51158 .25893 L p .051 0 .265 r
F P
0 g
s
.48388 .27412 m .48401 .16051 L .4994 .16963 L p .839 .45 .311 r
F P
0 g
s
.4994 .16963 m .50062 .28369 L .48388 .27412 L p .839 .45 .311 r
F P
0 g
s
.51158 .25893 m .50051 .27343 L .4994 .16963 L p .051 0 .265 r
F P
0 g
s
.4994 .16963 m .50964 .15576 L .51158 .25893 L p .051 0 .265 r
F P
0 g
s
.56113 .14623 m .57637 .15543 L .56584 .1693 L p .694 .677 .829 r
F P
0 g
s
.56584 .1693 m .55064 .16018 L .56113 .14623 L p .694 .677 .829 r
F P
0 g
s
.55587 .26355 m .55064 .16018 L .56584 .1693 L p .839 .442 .294 r
F P
0 g
s
.56584 .1693 m .57227 .27309 L .55587 .26355 L p .839 .442 .294 r
F P
0 g
s
.58368 .25859 m .57227 .27309 L .56584 .1693 L p .094 0 .298 r
F P
0 g
s
.56584 .1693 m .57637 .15543 L .58368 .25859 L p .094 0 .298 r
F P
0 g
s
.55587 .26355 m .55064 .16018 L .56584 .1693 L p .839 .442 .294 r
F P
0 g
s
.56584 .1693 m .57227 .27309 L .55587 .26355 L p .839 .442 .294 r
F P
0 g
s
.58514 .27915 m .57355 .29377 L .56584 .1693 L p .094 0 .298 r
F P
0 g
s
.56584 .1693 m .57637 .15543 L .58514 .27915 L p .094 0 .298 r
F P
0 g
s
.63105 .29434 m .61728 .15985 L .63229 .16898 L p .839 .434 .276 r
F P
0 g
s
.63229 .16898 m .64758 .30399 L .63105 .29434 L p .839 .434 .276 r
F P
0 g
s
.31897 .14277 m .33492 .15199 L .32543 .1659 L p .694 .677 .829 r
F P
0 g
s
.32543 .1659 m .30952 .15675 L .31897 .14277 L p .694 .677 .829 r
F P
0 g
s
.29946 .23021 m .30952 .15675 L .32543 .1659 L p .838 .466 .348 r
F P
0 g
s
.32543 .1659 m .31631 .23965 L .29946 .23021 L p .838 .466 .348 r
F P
0 g
s
.3263 .2253 m .31631 .23965 L .32543 .1659 L p 0 0 .156 r
F P
0 g
s
.32543 .1659 m .33492 .15199 L .3263 .2253 L p 0 0 .156 r
F P
0 g
s
.29812 .23999 m .30952 .15675 L .32543 .1659 L p .838 .466 .348 r
F P
0 g
s
.32543 .1659 m .31509 .24947 L .29812 .23999 L p .838 .466 .348 r
F P
0 g
s
.32516 .23505 m .31509 .24947 L .32543 .1659 L p 0 0 .156 r
F P
0 g
s
.32543 .1659 m .33492 .15199 L .32516 .23505 L p 0 0 .156 r
F P
0 g
s
.38596 .14244 m .40172 .15166 L .39193 .16557 L p .694 .677 .829 r
F P
0 g
s
.39193 .16557 m .37621 .15642 L .38596 .14244 L p .694 .677 .829 r
F P
0 g
s
.37079 .22023 m .37621 .15642 L .39193 .16557 L p .839 .46 .334 r
F P
0 g
s
.39193 .16557 m .3873 .22964 L .37079 .22023 L p .839 .46 .334 r
F P
0 g
s
.40429 .22942 m .38799 .2201 L .39817 .20586 L p .692 .682 .836 r
F P
0 g
s
.39755 .21534 m .3873 .22964 L .39193 .16557 L p 0 0 .2 r
F P
0 g
s
.39193 .16557 m .40172 .15166 L .39755 .21534 L p 0 0 .2 r
F P
0 g
s
.37079 .22023 m .37621 .15642 L .39193 .16557 L p .839 .46 .334 r
F P
0 g
s
.39193 .16557 m .3873 .22964 L .37079 .22023 L p .839 .46 .334 r
F P
0 g
s
.39817 .20586 m .38799 .2201 L .39193 .16557 L p 0 0 .2 r
F P
0 g
s
.39193 .16557 m .40172 .15166 L .39817 .20586 L p 0 0 .2 r
F P
0 g
s
.45296 .1421 m .46853 .15133 L .45845 .16524 L p .694 .677 .829 r
F P
0 g
s
.45845 .16524 m .44292 .15609 L .45296 .1421 L p .694 .677 .829 r
F P
0 g
s
.44112 .21039 m .44292 .15609 L .45845 .16524 L p .839 .453 .319 r
F P
0 g
s
.45845 .16524 m .45731 .21976 L .44112 .21039 L p .839 .453 .319 r
F P
0 g
s
.46781 .20552 m .45731 .21976 L .45845 .16524 L p .02 0 .24 r
F P
0 g
s
.45845 .16524 m .46853 .15133 L .46781 .20552 L p .02 0 .24 r
F P
0 g
s
.44081 .21989 m .44292 .15609 L .45845 .16524 L p .839 .453 .319 r
F P
0 g
s
.45845 .16524 m .45711 .2293 L .44081 .21989 L p .839 .453 .319 r
F P
0 g
s
.46768 .215 m .45711 .2293 L .45845 .16524 L p .02 0 .24 r
F P
0 g
s
.45845 .16524 m .46853 .15133 L .46768 .215 L p .02 0 .24 r
F P
0 g
s
.51997 .14177 m .53535 .151 L .52498 .16491 L p .694 .677 .829 r
F P
0 g
s
.52498 .16491 m .50964 .15576 L .51997 .14177 L p .694 .677 .829 r
F P
0 g
s
.51158 .25893 m .50964 .15576 L .52498 .16491 L p .84 .446 .302 r
F P
0 g
s
.52498 .16491 m .52815 .2685 L .51158 .25893 L p .84 .446 .302 r
F P
0 g
s
.54418 .26787 m .52784 .2584 L .53897 .24392 L p .691 .686 .84 r
F P
0 g
s
.53936 .25396 m .52815 .2685 L .52498 .16491 L p .066 0 .276 r
F P
0 g
s
.52498 .16491 m .53535 .151 L .53936 .25396 L p .066 0 .276 r
F P
0 g
s
.51158 .25893 m .50964 .15576 L .52498 .16491 L p .84 .446 .302 r
F P
0 g
s
.52498 .16491 m .52815 .2685 L .51158 .25893 L p .84 .446 .302 r
F P
0 g
s
.53897 .24392 m .52784 .2584 L .52498 .16491 L p .066 0 .276 r
F P
0 g
s
.52498 .16491 m .53535 .151 L .53897 .24392 L p .066 0 .276 r
F P
0 g
s
.587 .14144 m .60218 .15067 L .59152 .16458 L p .694 .677 .829 r
F P
0 g
s
.59152 .16458 m .57637 .15543 L .587 .14144 L p .694 .677 .829 r
F P
0 g
s
.5844 .2688 m .57637 .15543 L .59152 .16458 L p .839 .438 .285 r
F P
0 g
s
.59152 .16458 m .60086 .2784 L .5844 .2688 L p .839 .438 .285 r
F P
0 g
s
.61251 .2638 m .60086 .2784 L .59152 .16458 L p .108 0 .308 r
F P
0 g
s
.59152 .16458 m .60218 .15067 L .61251 .2638 L p .108 0 .308 r
F P
0 g
s
.58514 .27915 m .57637 .15543 L .59152 .16458 L p .839 .438 .285 r
F P
0 g
s
.59152 .16458 m .60171 .2888 L .58514 .27915 L p .839 .438 .285 r
F P
0 g
s
.61345 .27413 m .60171 .2888 L .59152 .16458 L p .108 0 .308 r
F P
0 g
s
.59152 .16458 m .60218 .15067 L .61345 .27413 L p .108 0 .308 r
F P
0 g
s
.3445 .13797 m .3604 .14722 L .35079 .16117 L p .694 .677 .829 r
F P
0 g
s
.35079 .16117 m .33492 .15199 L .3445 .13797 L p .694 .677 .829 r
F P
0 g
s
.32743 .21568 m .33492 .15199 L .35079 .16117 L p .839 .463 .341 r
F P
0 g
s
.35079 .16117 m .3441 .22511 L .32743 .21568 L p .839 .463 .341 r
F P
0 g
s
.35417 .21077 m .3441 .22511 L .35079 .16117 L p 0 0 .171 r
F P
0 g
s
.35079 .16117 m .3604 .14722 L .35417 .21077 L p 0 0 .171 r
F P
0 g
s
.32516 .23505 m .33492 .15199 L .35079 .16117 L p .839 .463 .341 r
F P
0 g
s
.35079 .16117 m .34207 .24456 L .32516 .23505 L p .839 .463 .341 r
F P
0 g
s
.35417 .21077 m .3441 .22511 L .35079 .16117 L p 0 0 .171 r
F P
0 g
s
.35079 .16117 m .3604 .14722 L .35417 .21077 L p 0 0 .171 r
F P
0 g
s
.41159 .13764 m .4273 .14689 L .41739 .16084 L p .694 .677 .829 r
F P
0 g
s
.41739 .16084 m .40172 .15166 L .41159 .13764 L p .694 .677 .829 r
F P
0 g
s
.39878 .19651 m .40172 .15166 L .41739 .16084 L p .839 .457 .326 r
F P
0 g
s
.41739 .16084 m .41501 .20587 L .39878 .19651 L p .839 .457 .326 r
F P
0 g
s
.42526 .19164 m .41501 .20587 L .41739 .16084 L p 0 0 .214 r
F P
0 g
s
.41739 .16084 m .4273 .14689 L .42526 .19164 L p 0 0 .214 r
F P
0 g
s
.39817 .20586 m .40172 .15166 L .41739 .16084 L p .839 .457 .326 r
F P
0 g
s
.41739 .16084 m .41451 .21525 L .39817 .20586 L p .839 .457 .326 r
F P
0 g
s
.42526 .19164 m .41501 .20587 L .41739 .16084 L p 0 0 .214 r
F P
0 g
s
.41739 .16084 m .4273 .14689 L .42526 .19164 L p 0 0 .214 r
F P
0 g
s
.47869 .1373 m .49421 .14656 L .48401 .16051 L p .694 .677 .829 r
F P
0 g
s
.48401 .16051 m .46853 .15133 L .47869 .1373 L p .694 .677 .829 r
F P
0 g
s
.46768 .215 m .46853 .15133 L .48401 .16051 L p .839 .45 .311 r
F P
0 g
s
.48401 .16051 m .48393 .22444 L .46768 .215 L p .839 .45 .311 r
F P
0 g
s
.49465 .21008 m .48393 .22444 L .48401 .16051 L p .036 0 .253 r
F P
0 g
s
.48401 .16051 m .49421 .14656 L .49465 .21008 L p .036 0 .253 r
F P
0 g
s
.46768 .215 m .46853 .15133 L .48401 .16051 L p .839 .45 .311 r
F P
0 g
s
.48401 .16051 m .48393 .22444 L .46768 .215 L p .839 .45 .311 r
F P
0 g
s
.49491 .24931 m .48389 .2639 L .48401 .16051 L p .036 0 .253 r
F P
0 g
s
.48401 .16051 m .49421 .14656 L .49491 .24931 L p .036 0 .253 r
F P
0 g
s
.54581 .13697 m .56113 .14623 L .55064 .16018 L p .694 .677 .829 r
F P
0 g
s
.55064 .16018 m .53535 .151 L .54581 .13697 L p .694 .677 .829 r
F P
0 g
s
.53897 .24392 m .55536 .25347 L .54418 .26787 L p .691 .686 .84 r
F P
0 g
s
.53936 .25396 m .53535 .151 L .55064 .16018 L p .839 .442 .294 r
F P
0 g
s
.55064 .16018 m .55587 .26355 L .53936 .25396 L p .839 .442 .294 r
F P
0 g
s
.56724 .24896 m .55587 .26355 L .55064 .16018 L p .08 0 .287 r
F P
0 g
s
.55064 .16018 m .56113 .14623 L .56724 .24896 L p .08 0 .287 r
F P
0 g
s
.53897 .24392 m .53535 .151 L .55064 .16018 L p .839 .442 .294 r
F P
0 g
s
.55064 .16018 m .55536 .25347 L .53897 .24392 L p .839 .442 .294 r
F P
0 g
s
.56724 .24896 m .55587 .26355 L .55064 .16018 L p .08 0 .287 r
F P
0 g
s
.55064 .16018 m .56113 .14623 L .56724 .24896 L p .08 0 .287 r
F P
0 g
s
.61345 .27413 m .60218 .15067 L .61728 .15985 L p .839 .434 .276 r
F P
0 g
s
.61728 .15985 m .62997 .28381 L .61345 .27413 L p .839 .434 .276 r
F P
0 g
s
.30941 .21576 m .29946 .23021 L .30952 .15675 L p 0 0 .14 r
F P
0 g
s
.30952 .15675 m .31897 .14277 L .30941 .21576 L p 0 0 .14 r
F P
0 g
s
.37011 .13316 m .38596 .14244 L .37621 .15642 L p .694 .677 .829 r
F P
0 g
s
.37621 .15642 m .3604 .14722 L .37011 .13316 L p .694 .677 .829 r
F P
0 g
s
.3551 .2013 m .3604 .14722 L .37621 .15642 L p .839 .46 .334 r
F P
0 g
s
.37621 .15642 m .37159 .21073 L .3551 .2013 L p .839 .46 .334 r
F P
0 g
s
.38173 .1964 m .37159 .21073 L .37621 .15642 L p 0 0 .186 r
F P
0 g
s
.37621 .15642 m .38596 .14244 L .38173 .1964 L p 0 0 .186 r
F P
0 g
s
.35417 .21077 m .3604 .14722 L .37621 .15642 L p .839 .46 .334 r
F P
0 g
s
.37621 .15642 m .37079 .22023 L .35417 .21077 L p .839 .46 .334 r
F P
0 g
s
.38099 .20584 m .37079 .22023 L .37621 .15642 L p 0 0 .186 r
F P
0 g
s
.37621 .15642 m .38596 .14244 L .38099 .20584 L p 0 0 .186 r
F P
0 g
s
.4373 .13282 m .45296 .1421 L .44292 .15609 L p .694 .677 .829 r
F P
0 g
s
.44292 .15609 m .4273 .14689 L .4373 .13282 L p .694 .677 .829 r
F P
0 g
s
.42526 .19164 m .4273 .14689 L .44292 .15609 L p .839 .453 .319 r
F P
0 g
s
.44292 .15609 m .44143 .20103 L .42526 .19164 L p .839 .453 .319 r
F P
0 g
s
.45181 .18675 m .44143 .20103 L .44292 .15609 L p .004 0 .228 r
F P
0 g
s
.44292 .15609 m .45296 .1421 L .45181 .18675 L p .004 0 .228 r
F P
0 g
s
.42526 .19164 m .4273 .14689 L .44292 .15609 L p .839 .453 .319 r
F P
0 g
s
.44292 .15609 m .44143 .20103 L .42526 .19164 L p .839 .453 .319 r
F P
0 g
s
.45158 .19606 m .44112 .21039 L .44292 .15609 L p .004 0 .228 r
F P
0 g
s
.44292 .15609 m .45296 .1421 L .45158 .19606 L p .004 0 .228 r
F P
0 g
s
.5045 .13249 m .51997 .14177 L .50964 .15576 L p .694 .677 .829 r
F P
0 g
s
.50964 .15576 m .49421 .14656 L .5045 .13249 L p .694 .677 .829 r
F P
0 g
s
.49485 .23929 m .49421 .14656 L .50964 .15576 L p .84 .446 .302 r
F P
0 g
s
.50964 .15576 m .51139 .24887 L .49485 .23929 L p .84 .446 .302 r
F P
0 g
s
.52248 .2343 m .51139 .24887 L .50964 .15576 L p .051 0 .265 r
F P
0 g
s
.50964 .15576 m .51997 .14177 L .52248 .2343 L p .051 0 .265 r
F P
0 g
s
.49491 .24931 m .49421 .14656 L .50964 .15576 L p .84 .446 .302 r
F P
0 g
s
.50964 .15576 m .51158 .25893 L .49491 .24931 L p .84 .446 .302 r
F P
0 g
s
.52276 .2443 m .51158 .25893 L .50964 .15576 L p .051 0 .265 r
F P
0 g
s
.50964 .15576 m .51997 .14177 L .52276 .2443 L p .051 0 .265 r
F P
0 g
s
.57172 .13215 m .587 .14144 L .57637 .15543 L p .694 .677 .829 r
F P
0 g
s
.57637 .15543 m .56113 .14623 L .57172 .13215 L p .694 .677 .829 r
F P
0 g
s
.56724 .24896 m .56113 .14623 L .57637 .15543 L p .839 .438 .285 r
F P
0 g
s
.57637 .15543 m .58368 .25859 L .56724 .24896 L p .839 .438 .285 r
F P
0 g
s
.5952 .24395 m .58368 .25859 L .57637 .15543 L p .094 0 .298 r
F P
0 g
s
.57637 .15543 m .587 .14144 L .5952 .24395 L p .094 0 .298 r
F P
0 g
s
.56724 .24896 m .56113 .14623 L .57637 .15543 L p .839 .438 .285 r
F P
0 g
s
.57637 .15543 m .58368 .25859 L .56724 .24896 L p .839 .438 .285 r
F P
0 g
s
.59601 .2541 m .5844 .2688 L .57637 .15543 L p .094 0 .298 r
F P
0 g
s
.57637 .15543 m .587 .14144 L .59601 .2541 L p .094 0 .298 r
F P
0 g
s
.32851 .12866 m .3445 .13797 L .33492 .15199 L p .694 .677 .829 r
F P
0 g
s
.33492 .15199 m .31897 .14277 L .32851 .12866 L p .694 .677 .829 r
F P
0 g
s
.31066 .20619 m .31897 .14277 L .33492 .15199 L p .839 .463 .341 r
F P
0 g
s
.33492 .15199 m .32743 .21568 L .31066 .20619 L p .839 .463 .341 r
F P
0 g
s
.33745 .20125 m .32743 .21568 L .33492 .15199 L p 0 0 .156 r
F P
0 g
s
.33492 .15199 m .3445 .13797 L .33745 .20125 L p 0 0 .156 r
F P
0 g
s
.30941 .21576 m .31897 .14277 L .33492 .15199 L p .839 .463 .341 r
F P
0 g
s
.33492 .15199 m .3263 .2253 L .30941 .21576 L p .839 .463 .341 r
F P
0 g
s
.33745 .20125 m .32743 .21568 L .33492 .15199 L p 0 0 .156 r
F P
0 g
s
.33492 .15199 m .3445 .13797 L .33745 .20125 L p 0 0 .156 r
F P
0 g
s
.39579 .12833 m .41159 .13764 L .40172 .15166 L p .694 .677 .829 r
F P
0 g
s
.40172 .15166 m .38596 .14244 L .39579 .12833 L p .694 .677 .829 r
F P
0 g
s
.38099 .20584 m .38596 .14244 L .40172 .15166 L p .839 .457 .326 r
F P
0 g
s
.40172 .15166 m .39755 .21534 L .38099 .20584 L p .839 .457 .326 r
F P
0 g
s
.41501 .20587 m .39878 .19651 L .40899 .18219 L p .693 .681 .835 r
F P
0 g
s
.39817 .20586 m .41451 .21525 L .40429 .22942 L p .692 .682 .836 r
F P
0 g
s
.4079 .2009 m .39755 .21534 L .40172 .15166 L p 0 0 .2 r
F P
0 g
s
.40172 .15166 m .41159 .13764 L .4079 .2009 L p 0 0 .2 r
F P
0 g
s
.38099 .20584 m .38596 .14244 L .40172 .15166 L p .839 .457 .326 r
F P
0 g
s
.40172 .15166 m .39755 .21534 L .38099 .20584 L p .839 .457 .326 r
F P
0 g
s
.40899 .18219 m .39878 .19651 L .40172 .15166 L p 0 0 .2 r
F P
0 g
s
.40172 .15166 m .41159 .13764 L .40899 .18219 L p 0 0 .2 r
F P
0 g
s
.46308 .12799 m .47869 .1373 L .46853 .15133 L p .694 .677 .829 r
F P
0 g
s
.46853 .15133 m .45296 .1421 L .46308 .12799 L p .694 .677 .829 r
F P
0 g
s
.45158 .19606 m .46781 .20552 L .45731 .21976 L p .692 .682 .836 r
F P
0 g
s
.45731 .21976 m .44112 .21039 L .45158 .19606 L p .692 .682 .836 r
F P
0 g
s
.45133 .2055 m .45296 .1421 L .46853 .15133 L p .839 .45 .311 r
F P
0 g
s
.46853 .15133 m .46768 .215 L .45133 .2055 L p .839 .45 .311 r
F P
0 g
s
.47835 .20056 m .46768 .215 L .46853 .15133 L p .02 0 .24 r
F P
0 g
s
.46853 .15133 m .47869 .1373 L .47835 .20056 L p .02 0 .24 r
F P
0 g
s
.45158 .19606 m .45296 .1421 L .46853 .15133 L p .839 .45 .311 r
F P
0 g
s
.46853 .15133 m .46781 .20552 L .45158 .19606 L p .839 .45 .311 r
F P
0 g
s
.47835 .20056 m .46768 .215 L .46853 .15133 L p .02 0 .24 r
F P
0 g
s
.46853 .15133 m .47869 .1373 L .47835 .20056 L p .02 0 .24 r
F P
0 g
s
.53039 .12766 m .54581 .13697 L .53535 .151 L p .694 .677 .829 r
F P
0 g
s
.53535 .151 m .51997 .14177 L .53039 .12766 L p .694 .677 .829 r
F P
0 g
s
.52222 .22445 m .51997 .14177 L .53535 .151 L p .839 .442 .294 r
F P
0 g
s
.53535 .151 m .53859 .23402 L .52222 .22445 L p .839 .442 .294 r
F P
0 g
s
.54974 .21946 m .53859 .23402 L .53535 .151 L p .066 0 .276 r
F P
0 g
s
.53535 .151 m .54581 .13697 L .54974 .21946 L p .066 0 .276 r
F P
0 g
s
.52276 .2443 m .51997 .14177 L .53535 .151 L p .839 .442 .294 r
F P
0 g
s
.53535 .151 m .53936 .25396 L .52276 .2443 L p .839 .442 .294 r
F P
0 g
s
.55069 .23928 m .53936 .25396 L .53535 .151 L p .066 0 .276 r
F P
0 g
s
.53535 .151 m .54581 .13697 L .55069 .23928 L p .066 0 .276 r
F P
0 g
s
.59601 .2541 m .587 .14144 L .60218 .15067 L p .839 .434 .276 r
F P
0 g
s
.60218 .15067 m .61251 .2638 L .59601 .2541 L p .839 .434 .276 r
F P
0 g
s
.35416 .12382 m .37011 .13316 L .3604 .14722 L p .694 .677 .829 r
F P
0 g
s
.3604 .14722 m .3445 .13797 L .35416 .12382 L p .694 .677 .829 r
F P
0 g
s
.33745 .20125 m .3445 .13797 L .3604 .14722 L p .839 .46 .334 r
F P
0 g
s
.3604 .14722 m .35417 .21077 L .33745 .20125 L p .839 .46 .334 r
F P
0 g
s
.37159 .21073 m .3551 .2013 L .36519 .18689 L p .692 .682 .836 r
F P
0 g
s
.36433 .19629 m .35417 .21077 L .3604 .14722 L p 0 0 .171 r
F P
0 g
s
.3604 .14722 m .37011 .13316 L .36433 .19629 L p 0 0 .171 r
F P
0 g
s
.33745 .20125 m .3445 .13797 L .3604 .14722 L p .839 .46 .334 r
F P
0 g
s
.3604 .14722 m .35417 .21077 L .33745 .20125 L p .839 .46 .334 r
F P
0 g
s
.36519 .18689 m .3551 .2013 L .3604 .14722 L p 0 0 .171 r
F P
0 g
s
.3604 .14722 m .37011 .13316 L .36519 .18689 L p 0 0 .171 r
F P
0 g
s
.42155 .12348 m .4373 .13282 L .4273 .14689 L p .694 .677 .829 r
F P
0 g
s
.4273 .14689 m .41159 .13764 L .42155 .12348 L p .694 .677 .829 r
F P
0 g
s
.40952 .17303 m .41159 .13764 L .4273 .14689 L p .839 .453 .319 r
F P
0 g
s
.4273 .14689 m .42568 .18244 L .40952 .17303 L p .839 .453 .319 r
F P
0 g
s
.43595 .16813 m .42568 .18244 L .4273 .14689 L p 0 0 .214 r
F P
0 g
s
.4273 .14689 m .4373 .13282 L .43595 .16813 L p 0 0 .214 r
F P
0 g
s
.40899 .18219 m .41159 .13764 L .4273 .14689 L p .839 .453 .319 r
F P
0 g
s
.4273 .14689 m .42526 .19164 L .40899 .18219 L p .839 .453 .319 r
F P
0 g
s
.4356 .17727 m .42526 .19164 L .4273 .14689 L p 0 0 .214 r
F P
0 g
s
.4273 .14689 m .4373 .13282 L .4356 .17727 L p 0 0 .214 r
F P
0 g
s
.48895 .12315 m .5045 .13249 L .49421 .14656 L p .694 .677 .829 r
F P
0 g
s
.49421 .14656 m .47869 .1373 L .48895 .12315 L p .694 .677 .829 r
F P
0 g
s
.47835 .20056 m .47869 .1373 L .49421 .14656 L p .84 .446 .302 r
F P
0 g
s
.49421 .14656 m .49465 .21008 L .47835 .20056 L p .84 .446 .302 r
F P
0 g
s
.50546 .1956 m .49465 .21008 L .49421 .14656 L p .036 0 .253 r
F P
0 g
s
.49421 .14656 m .5045 .13249 L .50546 .1956 L p .036 0 .253 r
F P
0 g
s
.47835 .20056 m .47869 .1373 L .49421 .14656 L p .84 .446 .302 r
F P
0 g
s
.49421 .14656 m .49465 .21008 L .47835 .20056 L p .84 .446 .302 r
F P
0 g
s
.5059 .22463 m .49485 .23929 L .49421 .14656 L p .036 0 .253 r
F P
0 g
s
.49421 .14656 m .5045 .13249 L .5059 .22463 L p .036 0 .253 r
F P
0 g
s
.55636 .12281 m .57172 .13215 L .56113 .14623 L p .694 .677 .829 r
F P
0 g
s
.56113 .14623 m .54581 .13697 L .55636 .12281 L p .694 .677 .829 r
F P
0 g
s
.55021 .2293 m .54581 .13697 L .56113 .14623 L p .839 .438 .285 r
F P
0 g
s
.56113 .14623 m .56664 .23894 L .55021 .2293 L p .839 .438 .285 r
F P
0 g
s
.57803 .22428 m .56664 .23894 L .56113 .14623 L p .08 0 .287 r
F P
0 g
s
.56113 .14623 m .57172 .13215 L .57803 .22428 L p .08 0 .287 r
F P
0 g
s
.55069 .23928 m .54581 .13697 L .56113 .14623 L p .839 .438 .285 r
F P
0 g
s
.56113 .14623 m .56724 .24896 L .55069 .23928 L p .839 .438 .285 r
F P
0 g
s
.57871 .23424 m .56724 .24896 L .56113 .14623 L p .08 0 .287 r
F P
0 g
s
.56113 .14623 m .57172 .13215 L .57871 .23424 L p .08 0 .287 r
F P
0 g
s
.32064 .19167 m .31066 .20619 L .31897 .14277 L p 0 0 .14 r
F P
0 g
s
.31897 .14277 m .32851 .12866 L .32064 .19167 L p 0 0 .14 r
F P
0 g
s
.37989 .11896 m .39579 .12833 L .38596 .14244 L p .694 .677 .829 r
F P
0 g
s
.38596 .14244 m .37011 .13316 L .37989 .11896 L p .694 .677 .829 r
F P
0 g
s
.36519 .18689 m .38173 .1964 L .37159 .21073 L p .692 .682 .836 r
F P
0 g
s
.36433 .19629 m .37011 .13316 L .38596 .14244 L p .839 .457 .326 r
F P
0 g
s
.38596 .14244 m .38099 .20584 L .36433 .19629 L p .839 .457 .326 r
F P
0 g
s
.39129 .19132 m .38099 .20584 L .38596 .14244 L p 0 0 .186 r
F P
0 g
s
.38596 .14244 m .39579 .12833 L .39129 .19132 L p 0 0 .186 r
F P
0 g
s
.36519 .18689 m .37011 .13316 L .38596 .14244 L p .839 .457 .326 r
F P
0 g
s
.38596 .14244 m .38173 .1964 L .36519 .18689 L p .839 .457 .326 r
F P
0 g
s
.39129 .19132 m .38099 .20584 L .38596 .14244 L p 0 0 .186 r
F P
0 g
s
.38596 .14244 m .39579 .12833 L .39129 .19132 L p 0 0 .186 r
F P
0 g
s
.44738 .11863 m .46308 .12799 L .45296 .1421 L p .694 .677 .829 r
F P
0 g
s
.45296 .1421 m .4373 .13282 L .44738 .11863 L p .694 .677 .829 r
F P
0 g
s
.4356 .17727 m .45181 .18675 L .44143 .20103 L p .693 .681 .835 r
F P
0 g
s
.44143 .20103 m .42526 .19164 L .4356 .17727 L p .693 .681 .835 r
F P
0 g
s
.43489 .19595 m .4373 .13282 L .45296 .1421 L p .839 .45 .311 r
F P
0 g
s
.45296 .1421 m .45133 .2055 L .43489 .19595 L p .839 .45 .311 r
F P
0 g
s
.46196 .19097 m .45133 .2055 L .45296 .1421 L p .004 0 .228 r
F P
0 g
s
.45296 .1421 m .46308 .12799 L .46196 .19097 L p .004 0 .228 r
F P
0 g
s
.4356 .17727 m .4373 .13282 L .45296 .1421 L p .839 .45 .311 r
F P
0 g
s
.45296 .1421 m .45181 .18675 L .4356 .17727 L p .839 .45 .311 r
F P
0 g
s
.46196 .19097 m .45133 .2055 L .45296 .1421 L p .004 0 .228 r
F P
0 g
s
.45296 .1421 m .46308 .12799 L .46196 .19097 L p .004 0 .228 r
F P
0 g
s
.51489 .11829 m .53039 .12766 L .51997 .14177 L p .694 .677 .829 r
F P
0 g
s
.51997 .14177 m .5045 .13249 L .51489 .11829 L p .694 .677 .829 r
F P
0 g
s
.50575 .21481 m .5045 .13249 L .51997 .14177 L p .839 .442 .294 r
F P
0 g
s
.51997 .14177 m .52222 .22445 L .50575 .21481 L p .839 .442 .294 r
F P
0 g
s
.53333 .2098 m .52222 .22445 L .51997 .14177 L p .051 0 .265 r
F P
0 g
s
.51997 .14177 m .53039 .12766 L .53333 .2098 L p .051 0 .265 r
F P
0 g
s
.5059 .22463 m .5045 .13249 L .51997 .14177 L p .839 .442 .294 r
F P
0 g
s
.51997 .14177 m .52248 .2343 L .5059 .22463 L p .839 .442 .294 r
F P
0 g
s
.53333 .2098 m .52222 .22445 L .51997 .14177 L p .051 0 .265 r
F P
0 g
s
.51997 .14177 m .53039 .12766 L .53333 .2098 L p .051 0 .265 r
F P
0 g
s
.57871 .23424 m .57172 .13215 L .587 .14144 L p .839 .434 .276 r
F P
0 g
s
.587 .14144 m .5952 .24395 L .57871 .23424 L p .839 .434 .276 r
F P
0 g
s
.33812 .11443 m .35416 .12382 L .3445 .13797 L p .694 .677 .829 r
F P
0 g
s
.3445 .13797 m .32851 .12866 L .33812 .11443 L p .694 .677 .829 r
F P
0 g
s
.32181 .18228 m .32851 .12866 L .3445 .13797 L p .839 .46 .334 r
F P
0 g
s
.3445 .13797 m .3385 .19182 L .32181 .18228 L p .839 .46 .334 r
F P
0 g
s
.34855 .17732 m .3385 .19182 L .3445 .13797 L p 0 0 .156 r
F P
0 g
s
.3445 .13797 m .35416 .12382 L .34855 .17732 L p 0 0 .156 r
F P
0 g
s
.32064 .19167 m .32851 .12866 L .3445 .13797 L p .839 .46 .334 r
F P
0 g
s
.3445 .13797 m .33745 .20125 L .32064 .19167 L p .839 .46 .334 r
F P
0 g
s
.34757 .18668 m .33745 .20125 L .3445 .13797 L p 0 0 .156 r
F P
0 g
s
.3445 .13797 m .35416 .12382 L .34757 .18668 L p 0 0 .156 r
F P
0 g
s
.4057 .11409 m .42155 .12348 L .41159 .13764 L p .694 .677 .829 r
F P
0 g
s
.41159 .13764 m .39579 .12833 L .4057 .11409 L p .694 .677 .829 r
F P
0 g
s
.39129 .19132 m .39579 .12833 L .41159 .13764 L p .839 .453 .319 r
F P
0 g
s
.41159 .13764 m .4079 .2009 L .39129 .19132 L p .839 .453 .319 r
F P
0 g
s
.42568 .18244 m .40952 .17303 L .41975 .15864 L p .693 .681 .834 r
F P
0 g
s
.40899 .18219 m .42526 .19164 L .41501 .20587 L p .693 .681 .835 r
F P
0 g
s
.41834 .18633 m .4079 .2009 L .41159 .13764 L p 0 0 .2 r
F P
0 g
s
.41159 .13764 m .42155 .12348 L .41834 .18633 L p 0 0 .2 r
F P
0 g
s
.39129 .19132 m .39579 .12833 L .41159 .13764 L p .839 .453 .319 r
F P
0 g
s
.41159 .13764 m .4079 .2009 L .39129 .19132 L p .839 .453 .319 r
F P
0 g
s
.41975 .15864 m .40952 .17303 L .41159 .13764 L p 0 0 .2 r
F P
0 g
s
.41159 .13764 m .42155 .12348 L .41975 .15864 L p 0 0 .2 r
F P
0 g
s
.4733 .11375 m .48895 .12315 L .47869 .1373 L p .694 .677 .829 r
F P
0 g
s
.47869 .1373 m .46308 .12799 L .4733 .11375 L p .694 .677 .829 r
F P
0 g
s
.46213 .18159 m .46308 .12799 L .47869 .1373 L p .84 .446 .302 r
F P
0 g
s
.47869 .1373 m .4784 .19114 L .46213 .18159 L p .84 .446 .302 r
F P
0 g
s
.4891 .17662 m .4784 .19114 L .47869 .1373 L p .02 0 .24 r
F P
0 g
s
.47869 .1373 m .48895 .12315 L .4891 .17662 L p .02 0 .24 r
F P
0 g
s
.46196 .19097 m .46308 .12799 L .47869 .1373 L p .84 .446 .302 r
F P
0 g
s
.47869 .1373 m .47835 .20056 L .46196 .19097 L p .84 .446 .302 r
F P
0 g
s
.48912 .18599 m .47835 .20056 L .47869 .1373 L p .02 0 .24 r
F P
0 g
s
.47869 .1373 m .48895 .12315 L .48912 .18599 L p .02 0 .24 r
F P
0 g
s
.54091 .11342 m .55636 .12281 L .54581 .13697 L p .694 .677 .829 r
F P
0 g
s
.54581 .13697 m .53039 .12766 L .54091 .11342 L p .694 .677 .829 r
F P
0 g
s
.53333 .2098 m .53039 .12766 L .54581 .13697 L p .839 .438 .285 r
F P
0 g
s
.54581 .13697 m .54974 .21946 L .53333 .2098 L p .839 .438 .285 r
F P
0 g
s
.56101 .20477 m .54974 .21946 L .54581 .13697 L p .066 0 .276 r
F P
0 g
s
.54581 .13697 m .55636 .12281 L .56101 .20477 L p .066 0 .276 r
F P
0 g
s
.53333 .2098 m .53039 .12766 L .54581 .13697 L p .839 .438 .285 r
F P
0 g
s
.54581 .13697 m .54974 .21946 L .53333 .2098 L p .839 .438 .285 r
F P
0 g
s
.56156 .21454 m .55021 .2293 L .54581 .13697 L p .066 0 .276 r
F P
0 g
s
.54581 .13697 m .55636 .12281 L .56156 .21454 L p .066 0 .276 r
F P
0 g
s
.36391 .10955 m .37989 .11896 L .37011 .13316 L p .694 .677 .829 r
F P
0 g
s
.37011 .13316 m .35416 .12382 L .36391 .10955 L p .694 .677 .829 r
F P
0 g
s
.34952 .16809 m .35416 .12382 L .37011 .13316 L p .839 .457 .326 r
F P
0 g
s
.37011 .13316 m .36604 .17762 L .34952 .16809 L p .839 .457 .326 r
F P
0 g
s
.37615 .16313 m .36604 .17762 L .37011 .13316 L p 0 0 .171 r
F P
0 g
s
.37011 .13316 m .37989 .11896 L .37615 .16313 L p 0 0 .171 r
F P
0 g
s
.34757 .18668 m .35416 .12382 L .37011 .13316 L p .839 .457 .326 r
F P
0 g
s
.37011 .13316 m .36433 .19629 L .34757 .18668 L p .839 .457 .326 r
F P
0 g
s
.37458 .18168 m .36433 .19629 L .37011 .13316 L p 0 0 .171 r
F P
0 g
s
.37011 .13316 m .37989 .11896 L .37458 .18168 L p 0 0 .171 r
F P
0 g
s
.43159 .10921 m .44738 .11863 L .4373 .13282 L p .694 .677 .829 r
F P
0 g
s
.4373 .13282 m .42155 .12348 L .43159 .10921 L p .694 .677 .829 r
F P
0 g
s
.41975 .15864 m .43595 .16813 L .42568 .18244 L p .693 .681 .834 r
F P
0 g
s
.41834 .18633 m .42155 .12348 L .4373 .13282 L p .839 .45 .311 r
F P
0 g
s
.4373 .13282 m .43489 .19595 L .41834 .18633 L p .839 .45 .311 r
F P
0 g
s
.44547 .18133 m .43489 .19595 L .4373 .13282 L p 0 0 .214 r
F P
0 g
s
.4373 .13282 m .44738 .11863 L .44547 .18133 L p 0 0 .214 r
F P
0 g
s
.41975 .15864 m .42155 .12348 L .4373 .13282 L p .839 .45 .311 r
F P
0 g
s
.4373 .13282 m .43595 .16813 L .41975 .15864 L p .839 .45 .311 r
F P
0 g
s
.44547 .18133 m .43489 .19595 L .4373 .13282 L p 0 0 .214 r
F P
0 g
s
.4373 .13282 m .44738 .11863 L .44547 .18133 L p 0 0 .214 r
F P
0 g
s
.49929 .10887 m .51489 .11829 L .5045 .13249 L p .694 .677 .829 r
F P
0 g
s
.5045 .13249 m .48895 .12315 L .49929 .10887 L p .694 .677 .829 r
F P
0 g
s
.48912 .18599 m .48895 .12315 L .5045 .13249 L p .839 .442 .294 r
F P
0 g
s
.5045 .13249 m .50546 .1956 L .48912 .18599 L p .839 .442 .294 r
F P
0 g
s
.51637 .18098 m .50546 .1956 L .5045 .13249 L p .036 0 .253 r
F P
0 g
s
.5045 .13249 m .51489 .11829 L .51637 .18098 L p .036 0 .253 r
F P
0 g
s
.48912 .18599 m .48895 .12315 L .5045 .13249 L p .839 .442 .294 r
F P
0 g
s
.5045 .13249 m .50546 .1956 L .48912 .18599 L p .839 .442 .294 r
F P
0 g
s
.51682 .20007 m .50575 .21481 L .5045 .13249 L p .036 0 .253 r
F P
0 g
s
.5045 .13249 m .51489 .11829 L .51682 .20007 L p .036 0 .253 r
F P
0 g
s
.56156 .21454 m .55636 .12281 L .57172 .13215 L p .839 .434 .276 r
F P
0 g
s
.57172 .13215 m .57803 .22428 L .56156 .21454 L p .839 .434 .276 r
F P
0 g
s
.33181 .16769 m .32181 .18228 L .32851 .12866 L p 0 0 .14 r
F P
0 g
s
.32851 .12866 m .33812 .11443 L .33181 .16769 L p 0 0 .14 r
F P
0 g
s
.38977 .10465 m .4057 .11409 L .39579 .12833 L p .694 .677 .829 r
F P
0 g
s
.39579 .12833 m .37989 .11896 L .38977 .10465 L p .694 .677 .829 r
F P
0 g
s
.37537 .17234 m .37989 .11896 L .39579 .12833 L p .839 .453 .319 r
F P
0 g
s
.39579 .12833 m .39196 .18194 L .37537 .17234 L p .839 .453 .319 r
F P
0 g
s
.40228 .16734 m .39196 .18194 L .39579 .12833 L p 0 0 .186 r
F P
0 g
s
.39579 .12833 m .4057 .11409 L .40228 .16734 L p 0 0 .186 r
F P
0 g
s
.37458 .18168 m .37989 .11896 L .39579 .12833 L p .839 .453 .319 r
F P
0 g
s
.39579 .12833 m .39129 .19132 L .37458 .18168 L p .839 .453 .319 r
F P
0 g
s
.40169 .17666 m .39129 .19132 L .39579 .12833 L p 0 0 .186 r
F P
0 g
s
.39579 .12833 m .4057 .11409 L .40169 .17666 L p 0 0 .186 r
F P
0 g
s
.45756 .10431 m .4733 .11375 L .46308 .12799 L p .694 .677 .829 r
F P
0 g
s
.46308 .12799 m .44738 .11863 L .45756 .10431 L p .694 .677 .829 r
F P
0 g
s
.44547 .18133 m .44738 .11863 L .46308 .12799 L p .84 .446 .302 r
F P
0 g
s
.46308 .12799 m .46196 .19097 L .44547 .18133 L p .84 .446 .302 r
F P
0 g
s
.4784 .19114 m .46213 .18159 L .47278 .16699 L p .692 .682 .836 r
F P
0 g
s
.47269 .17631 m .46196 .19097 L .46308 .12799 L p .004 0 .228 r
F P
0 g
s
.46308 .12799 m .4733 .11375 L .47269 .17631 L p .004 0 .228 r
F P
0 g
s
.44547 .18133 m .44738 .11863 L .46308 .12799 L p .84 .446 .302 r
F P
0 g
s
.46308 .12799 m .46196 .19097 L .44547 .18133 L p .84 .446 .302 r
F P
0 g
s
.47278 .16699 m .46213 .18159 L .46308 .12799 L p .004 0 .228 r
F P
0 g
s
.46308 .12799 m .4733 .11375 L .47278 .16699 L p .004 0 .228 r
F P
0 g
s
.52536 .10397 m .54091 .11342 L .53039 .12766 L p .694 .677 .829 r
F P
0 g
s
.53039 .12766 m .51489 .11829 L .52536 .10397 L p .694 .677 .829 r
F P
0 g
s
.51659 .19046 m .51489 .11829 L .53039 .12766 L p .839 .438 .285 r
F P
0 g
s
.53039 .12766 m .53299 .20014 L .51659 .19046 L p .839 .438 .285 r
F P
0 g
s
.54412 .18542 m .53299 .20014 L .53039 .12766 L p .051 0 .265 r
F P
0 g
s
.53039 .12766 m .54091 .11342 L .54412 .18542 L p .051 0 .265 r
F P
0 g
s
.51682 .20007 m .51489 .11829 L .53039 .12766 L p .839 .438 .285 r
F P
0 g
s
.53039 .12766 m .53333 .2098 L .51682 .20007 L p .839 .438 .285 r
F P
0 g
s
.54455 .19501 m .53333 .2098 L .53039 .12766 L p .051 0 .265 r
F P
0 g
s
.53039 .12766 m .54091 .11342 L .54455 .19501 L p .051 0 .265 r
F P
0 g
s
.34783 .10007 m .36391 .10955 L .35416 .12382 L p .694 .677 .829 r
F P
0 g
s
.35416 .12382 m .33812 .11443 L .34783 .10007 L p .694 .677 .829 r
F P
0 g
s
.3329 .1585 m .33812 .11443 L .35416 .12382 L p .839 .457 .326 r
F P
0 g
s
.35416 .12382 m .34952 .16809 L .3329 .1585 L p .839 .457 .326 r
F P
0 g
s
.35959 .15351 m .34952 .16809 L .35416 .12382 L p 0 0 .156 r
F P
0 g
s
.35416 .12382 m .36391 .10955 L .35959 .15351 L p 0 0 .156 r
F P
0 g
s
.33181 .16769 m .33812 .11443 L .35416 .12382 L p .839 .457 .326 r
F P
0 g
s
.35416 .12382 m .34855 .17732 L .33181 .16769 L p .839 .457 .326 r
F P
0 g
s
.35959 .15351 m .34952 .16809 L .35416 .12382 L p 0 0 .156 r
F P
0 g
s
.35416 .12382 m .36391 .10955 L .35959 .15351 L p 0 0 .156 r
F P
0 g
s
.41571 .09973 m .43159 .10921 L .42155 .12348 L p .694 .677 .829 r
F P
0 g
s
.42155 .12348 m .4057 .11409 L .41571 .09973 L p .694 .677 .829 r
F P
0 g
s
.40403 .14016 m .4057 .11409 L .42155 .12348 L p .839 .45 .311 r
F P
0 g
s
.42155 .12348 m .42021 .14967 L .40403 .14016 L p .839 .45 .311 r
F P
0 g
s
.43046 .13521 m .42021 .14967 L .42155 .12348 L p 0 0 .2 r
F P
0 g
s
.42155 .12348 m .43159 .10921 L .43046 .13521 L p 0 0 .2 r
F P
0 g
s
.40169 .17666 m .4057 .11409 L .42155 .12348 L p .839 .45 .311 r
F P
0 g
s
.42155 .12348 m .41834 .18633 L .40169 .17666 L p .839 .45 .311 r
F P
0 g
s
.42887 .17163 m .41834 .18633 L .42155 .12348 L p 0 0 .2 r
F P
0 g
s
.42155 .12348 m .43159 .10921 L .42887 .17163 L p 0 0 .2 r
F P
0 g
s
.48361 .09939 m .49929 .10887 L .48895 .12315 L p .694 .677 .829 r
F P
0 g
s
.48895 .12315 m .4733 .11375 L .48361 .09939 L p .694 .677 .829 r
F P
0 g
s
.47278 .16699 m .4891 .17662 L .4784 .19114 L p .692 .682 .836 r
F P
0 g
s
.47269 .17631 m .4733 .11375 L .48895 .12315 L p .839 .442 .294 r
F P
0 g
s
.48895 .12315 m .48912 .18599 L .47269 .17631 L p .839 .442 .294 r
F P
0 g
s
.49999 .17128 m .48912 .18599 L .48895 .12315 L p .02 0 .24 r
F P
0 g
s
.48895 .12315 m .49929 .10887 L .49999 .17128 L p .02 0 .24 r
F P
0 g
s
.47278 .16699 m .4733 .11375 L .48895 .12315 L p .839 .442 .294 r
F P
0 g
s
.48895 .12315 m .4891 .17662 L .47278 .16699 L p .839 .442 .294 r
F P
0 g
s
.49999 .17128 m .48912 .18599 L .48895 .12315 L p .02 0 .24 r
F P
0 g
s
.48895 .12315 m .49929 .10887 L .49999 .17128 L p .02 0 .24 r
F P
0 g
s
.54455 .19501 m .54091 .11342 L .55636 .12281 L p .839 .434 .276 r
F P
0 g
s
.55636 .12281 m .56101 .20477 L .54455 .19501 L p .839 .434 .276 r
F P
0 g
s
.37374 .09515 m .38977 .10465 L .37989 .11896 L p .694 .677 .829 r
F P
0 g
s
.37989 .11896 m .36391 .10955 L .37374 .09515 L p .694 .677 .829 r
F P
0 g
s
.35959 .15351 m .36391 .10955 L .37989 .11896 L p .839 .453 .319 r
F P
0 g
s
.37989 .11896 m .37615 .16313 L .35959 .15351 L p .839 .453 .319 r
F P
0 g
s
.38636 .1485 m .37615 .16313 L .37989 .11896 L p 0 0 .171 r
F P
0 g
s
.37989 .11896 m .38977 .10465 L .38636 .1485 L p 0 0 .171 r
F P
0 g
s
.35959 .15351 m .36391 .10955 L .37989 .11896 L p .839 .453 .319 r
F P
0 g
s
.37989 .11896 m .37615 .16313 L .35959 .15351 L p .839 .453 .319 r
F P
0 g
s
.38565 .15765 m .37537 .17234 L .37989 .11896 L p 0 0 .171 r
F P
0 g
s
.37989 .11896 m .38977 .10465 L .38565 .15765 L p 0 0 .171 r
F P
0 g
s
.44173 .0948 m .45756 .10431 L .44738 .11863 L p .694 .677 .829 r
F P
0 g
s
.44738 .11863 m .43159 .10921 L .44173 .0948 L p .694 .677 .829 r
F P
0 g
s
.42928 .16233 m .43159 .10921 L .44738 .11863 L p .84 .446 .302 r
F P
0 g
s
.44738 .11863 m .44575 .17199 L .42928 .16233 L p .84 .446 .302 r
F P
0 g
s
.45636 .1573 m .44575 .17199 L .44738 .11863 L p 0 0 .214 r
F P
0 g
s
.44738 .11863 m .45756 .10431 L .45636 .1573 L p 0 0 .214 r
F P
0 g
s
.42887 .17163 m .43159 .10921 L .44738 .11863 L p .84 .446 .302 r
F P
0 g
s
.44738 .11863 m .44547 .18133 L .42887 .17163 L p .84 .446 .302 r
F P
0 g
s
.45615 .16658 m .44547 .18133 L .44738 .11863 L p 0 0 .214 r
F P
0 g
s
.44738 .11863 m .45756 .10431 L .45615 .16658 L p 0 0 .214 r
F P
0 g
s
.50973 .09446 m .52536 .10397 L .51489 .11829 L p .694 .677 .829 r
F P
0 g
s
.51489 .11829 m .49929 .10887 L .50973 .09446 L p .694 .677 .829 r
F P
0 g
s
.49999 .17128 m .49929 .10887 L .51489 .11829 L p .839 .438 .285 r
F P
0 g
s
.51489 .11829 m .51637 .18098 L .49999 .17128 L p .839 .438 .285 r
F P
0 g
s
.52738 .16623 m .51637 .18098 L .51489 .11829 L p .036 0 .253 r
F P
0 g
s
.51489 .11829 m .52536 .10397 L .52738 .16623 L p .036 0 .253 r
F P
0 g
s
.49999 .17128 m .49929 .10887 L .51489 .11829 L p .839 .438 .285 r
F P
0 g
s
.51489 .11829 m .51637 .18098 L .49999 .17128 L p .839 .438 .285 r
F P
0 g
s
.52769 .17564 m .51659 .19046 L .51489 .11829 L p .036 0 .253 r
F P
0 g
s
.51489 .11829 m .52536 .10397 L .52769 .17564 L p .036 0 .253 r
F P
0 g
s
.34292 .14383 m .3329 .1585 L .33812 .11443 L p 0 0 .14 r
F P
0 g
s
.33812 .11443 m .34783 .10007 L .34292 .14383 L p 0 0 .14 r
F P
0 g
s
.39973 .0902 m .41571 .09973 L .4057 .11409 L p .694 .677 .829 r
F P
0 g
s
.4057 .11409 m .38977 .10465 L .39973 .0902 L p .694 .677 .829 r
F P
0 g
s
.38775 .13059 m .38977 .10465 L .4057 .11409 L p .839 .45 .311 r
F P
0 g
s
.4057 .11409 m .40403 .14016 L .38775 .13059 L p .839 .45 .311 r
F P
0 g
s
.41424 .12561 m .40403 .14016 L .4057 .11409 L p 0 0 .186 r
F P
0 g
s
.4057 .11409 m .41571 .09973 L .41424 .12561 L p 0 0 .186 r
F P
0 g
s
.38565 .15765 m .38977 .10465 L .4057 .11409 L p .839 .45 .311 r
F P
0 g
s
.4057 .11409 m .40228 .16734 L .38565 .15765 L p .839 .45 .311 r
F P
0 g
s
.41424 .12561 m .40403 .14016 L .4057 .11409 L p 0 0 .186 r
F P
0 g
s
.4057 .11409 m .41571 .09973 L .41424 .12561 L p 0 0 .186 r
F P
0 g
s
.46783 .08986 m .48361 .09939 L .4733 .11375 L p .694 .677 .829 r
F P
0 g
s
.4733 .11375 m .45756 .10431 L .46783 .08986 L p .694 .677 .829 r
F P
0 g
s
.45657 .14815 m .45756 .10431 L .4733 .11375 L p .839 .442 .294 r
F P
0 g
s
.4733 .11375 m .47287 .1578 L .45657 .14815 L p .839 .442 .294 r
F P
0 g
s
.48354 .14313 m .47287 .1578 L .4733 .11375 L p .004 0 .228 r
F P
0 g
s
.4733 .11375 m .48361 .09939 L .48354 .14313 L p .004 0 .228 r
F P
0 g
s
.45615 .16658 m .45756 .10431 L .4733 .11375 L p .839 .442 .294 r
F P
0 g
s
.4733 .11375 m .47269 .17631 L .45615 .16658 L p .839 .442 .294 r
F P
0 g
s
.48351 .16151 m .47269 .17631 L .4733 .11375 L p .004 0 .228 r
F P
0 g
s
.4733 .11375 m .48361 .09939 L .48351 .16151 L p .004 0 .228 r
F P
0 g
s
.52769 .17564 m .52536 .10397 L .54091 .11342 L p .839 .434 .276 r
F P
0 g
s
.54091 .11342 m .54412 .18542 L .52769 .17564 L p .839 .434 .276 r
F P
0 g
s
.35762 .08559 m .37374 .09515 L .36391 .10955 L p .694 .677 .829 r
F P
0 g
s
.36391 .10955 m .34783 .10007 L .35762 .08559 L p .694 .677 .829 r
F P
0 g
s
.34393 .13483 m .34783 .10007 L .36391 .10955 L p .839 .453 .319 r
F P
0 g
s
.36391 .10955 m .36048 .14447 L .34393 .13483 L p .839 .453 .319 r
F P
0 g
s
.37057 .12982 m .36048 .14447 L .36391 .10955 L p 0 0 .156 r
F P
0 g
s
.36391 .10955 m .37374 .09515 L .37057 .12982 L p 0 0 .156 r
F P
0 g
s
.34292 .14383 m .34783 .10007 L .36391 .10955 L p .839 .453 .319 r
F P
0 g
s
.36391 .10955 m .35959 .15351 L .34292 .14383 L p .839 .453 .319 r
F P
0 g
s
.36975 .13879 m .35959 .15351 L .36391 .10955 L p 0 0 .156 r
F P
0 g
s
.36391 .10955 m .37374 .09515 L .36975 .13879 L p 0 0 .156 r
F P
0 g
s
.4258 .08524 m .44173 .0948 L .43159 .10921 L p .694 .677 .829 r
F P
0 g
s
.43159 .10921 m .41571 .09973 L .4258 .08524 L p .694 .677 .829 r
F P
0 g
s
.41424 .12561 m .41571 .09973 L .43159 .10921 L p .84 .446 .302 r
F P
0 g
s
.43159 .10921 m .43046 .13521 L .41424 .12561 L p .84 .446 .302 r
F P
0 g
s
.4408 .12062 m .43046 .13521 L .43159 .10921 L p 0 0 .2 r
F P
0 g
s
.43159 .10921 m .44173 .0948 L .4408 .12062 L p 0 0 .2 r
F P
0 g
s
.41424 .12561 m .41571 .09973 L .43159 .10921 L p .84 .446 .302 r
F P
0 g
s
.43159 .10921 m .43046 .13521 L .41424 .12561 L p .84 .446 .302 r
F P
0 g
s
.43984 .14755 m .42928 .16233 L .43159 .10921 L p 0 0 .2 r
F P
0 g
s
.43159 .10921 m .44173 .0948 L .43984 .14755 L p 0 0 .2 r
F P
0 g
s
.494 .0849 m .50973 .09446 L .49929 .10887 L p .694 .677 .829 r
F P
0 g
s
.49929 .10887 m .48361 .09939 L .494 .0849 L p .694 .677 .829 r
F P
0 g
s
.48353 .15226 m .48361 .09939 L .49929 .10887 L p .839 .438 .285 r
F P
0 g
s
.49929 .10887 m .49989 .16198 L .48353 .15226 L p .839 .438 .285 r
F P
0 g
s
.51078 .1472 m .49989 .16198 L .49929 .10887 L p .02 0 .24 r
F P
0 g
s
.49929 .10887 m .50973 .09446 L .51078 .1472 L p .02 0 .24 r
F P
0 g
s
.48351 .16151 m .48361 .09939 L .49929 .10887 L p .839 .438 .285 r
F P
0 g
s
.49929 .10887 m .49999 .17128 L .48351 .16151 L p .839 .438 .285 r
F P
0 g
s
.51096 .15643 m .49999 .17128 L .49929 .10887 L p .02 0 .24 r
F P
0 g
s
.49929 .10887 m .50973 .09446 L .51096 .15643 L p .02 0 .24 r
F P
0 g
s
.38366 .08062 m .39973 .0902 L .38977 .10465 L p .694 .677 .829 r
F P
0 g
s
.38977 .10465 m .37374 .09515 L .38366 .08062 L p .694 .677 .829 r
F P
0 g
s
.37138 .12097 m .37374 .09515 L .38977 .10465 L p .839 .45 .311 r
F P
0 g
s
.38977 .10465 m .38775 .13059 L .37138 .12097 L p .839 .45 .311 r
F P
0 g
s
.39792 .11596 m .38775 .13059 L .38977 .10465 L p 0 0 .171 r
F P
0 g
s
.38977 .10465 m .39973 .0902 L .39792 .11596 L p 0 0 .171 r
F P
0 g
s
.36975 .13879 m .37374 .09515 L .38977 .10465 L p .839 .45 .311 r
F P
0 g
s
.38977 .10465 m .38636 .1485 L .36975 .13879 L p .839 .45 .311 r
F P
0 g
s
.39792 .11596 m .38775 .13059 L .38977 .10465 L p 0 0 .171 r
F P
0 g
s
.38977 .10465 m .39973 .0902 L .39792 .11596 L p 0 0 .171 r
F P
0 g
s
.45195 .08027 m .46783 .08986 L .45756 .10431 L p .694 .677 .829 r
F P
0 g
s
.45756 .10431 m .44173 .0948 L .45195 .08027 L p .694 .677 .829 r
F P
0 g
s
.44017 .13844 m .44173 .0948 L .45756 .10431 L p .839 .442 .294 r
F P
0 g
s
.45756 .10431 m .45657 .14815 L .44017 .13844 L p .839 .442 .294 r
F P
0 g
s
.4672 .13339 m .45657 .14815 L .45756 .10431 L p 0 0 .214 r
F P
0 g
s
.45756 .10431 m .46783 .08986 L .4672 .13339 L p 0 0 .214 r
F P
0 g
s
.43984 .14755 m .44173 .0948 L .45756 .10431 L p .839 .442 .294 r
F P
0 g
s
.45756 .10431 m .45636 .1573 L .43984 .14755 L p .839 .442 .294 r
F P
0 g
s
.4672 .13339 m .45657 .14815 L .45756 .10431 L p 0 0 .214 r
F P
0 g
s
.45756 .10431 m .46783 .08986 L .4672 .13339 L p 0 0 .214 r
F P
0 g
s
.51096 .15643 m .50973 .09446 L .52536 .10397 L p .839 .434 .276 r
F P
0 g
s
.52536 .10397 m .52738 .16623 L .51096 .15643 L p .839 .434 .276 r
F P
0 g
s
.56652 1.03799 m .58207 1.04477 L .57128 1.05498 L p .682 .71 .87 r
F P
0 g
s
.57128 1.05498 m .55577 1.04826 L .56652 1.03799 L p .682 .71 .87 r
F P
0 g
s
.35398 .12009 m .34393 .13483 L .34783 .10007 L p 0 0 .14 r
F P
0 g
s
.34783 .10007 m .35762 .08559 L .35398 .12009 L p 0 0 .14 r
F P
0 g
s
.40978 .07563 m .4258 .08524 L .41571 .09973 L p .694 .677 .829 r
F P
0 g
s
.41571 .09973 m .39973 .0902 L .40978 .07563 L p .694 .677 .829 r
F P
0 g
s
.39853 .10725 m .39973 .0902 L .41571 .09973 L p .84 .446 .302 r
F P
0 g
s
.41571 .09973 m .41474 .11687 L .39853 .10725 L p .84 .446 .302 r
F P
0 g
s
.42497 .10225 m .41474 .11687 L .41571 .09973 L p 0 0 .186 r
F P
0 g
s
.41571 .09973 m .4258 .08524 L .42497 .10225 L p 0 0 .186 r
F P
0 g
s
.39792 .11596 m .39973 .0902 L .41571 .09973 L p .84 .446 .302 r
F P
0 g
s
.41571 .09973 m .41424 .12561 L .39792 .11596 L p .84 .446 .302 r
F P
0 g
s
.42454 .11094 m .41424 .12561 L .41571 .09973 L p 0 0 .186 r
F P
0 g
s
.41571 .09973 m .4258 .08524 L .42454 .11094 L p 0 0 .186 r
F P
0 g
s
.47818 .07528 m .494 .0849 L .48361 .09939 L p .694 .677 .829 r
F P
0 g
s
.48361 .09939 m .46783 .08986 L .47818 .07528 L p .694 .677 .829 r
F P
0 g
s
.4672 .13339 m .46783 .08986 L .48361 .09939 L p .839 .438 .285 r
F P
0 g
s
.48361 .09939 m .48354 .14313 L .4672 .13339 L p .839 .438 .285 r
F P
0 g
s
.49431 .12832 m .48354 .14313 L .48361 .09939 L p .004 0 .228 r
F P
0 g
s
.48361 .09939 m .494 .0849 L .49431 .12832 L p .004 0 .228 r
F P
0 g
s
.4672 .13339 m .46783 .08986 L .48361 .09939 L p .839 .438 .285 r
F P
0 g
s
.48361 .09939 m .48354 .14313 L .4672 .13339 L p .839 .438 .285 r
F P
0 g
s
.49437 .13738 m .48353 .15226 L .48361 .09939 L p .004 0 .228 r
F P
0 g
s
.48361 .09939 m .494 .0849 L .49437 .13738 L p .004 0 .228 r
F P
0 g
s
.3675 .07097 m .38366 .08062 L .37374 .09515 L p .694 .677 .829 r
F P
0 g
s
.37374 .09515 m .35762 .08559 L .3675 .07097 L p .694 .677 .829 r
F P
0 g
s
.35491 .11128 m .35762 .08559 L .37374 .09515 L p .839 .45 .311 r
F P
0 g
s
.37374 .09515 m .37138 .12097 L .35491 .11128 L p .839 .45 .311 r
F P
0 g
s
.3815 .10625 m .37138 .12097 L .37374 .09515 L p 0 0 .156 r
F P
0 g
s
.37374 .09515 m .38366 .08062 L .3815 .10625 L p 0 0 .156 r
F P
0 g
s
.35398 .12009 m .35762 .08559 L .37374 .09515 L p .839 .45 .311 r
F P
0 g
s
.37374 .09515 m .37057 .12982 L .35398 .12009 L p .839 .45 .311 r
F P
0 g
s
.3815 .10625 m .37138 .12097 L .37374 .09515 L p 0 0 .156 r
F P
0 g
s
.37374 .09515 m .38366 .08062 L .3815 .10625 L p 0 0 .156 r
F P
0 g
s
.43599 .07063 m .45195 .08027 L .44173 .0948 L p .694 .677 .829 r
F P
0 g
s
.44173 .0948 m .4258 .08524 L .43599 .07063 L p .694 .677 .829 r
F P
0 g
s
.42454 .11094 m .4258 .08524 L .44173 .0948 L p .839 .442 .294 r
F P
0 g
s
.44173 .0948 m .4408 .12062 L .42454 .11094 L p .839 .442 .294 r
F P
0 g
s
.45124 .1059 m .4408 .12062 L .44173 .0948 L p 0 0 .2 r
F P
0 g
s
.44173 .0948 m .45195 .08027 L .45124 .1059 L p 0 0 .2 r
F P
0 g
s
.42454 .11094 m .4258 .08524 L .44173 .0948 L p .839 .442 .294 r
F P
0 g
s
.44173 .0948 m .4408 .12062 L .42454 .11094 L p .839 .442 .294 r
F P
0 g
s
.45075 .12359 m .44017 .13844 L .44173 .0948 L p 0 0 .2 r
F P
0 g
s
.44173 .0948 m .45195 .08027 L .45075 .12359 L p 0 0 .2 r
F P
0 g
s
.49437 .13738 m .494 .0849 L .50973 .09446 L p .839 .434 .276 r
F P
0 g
s
.50973 .09446 m .51078 .1472 L .49437 .13738 L p .839 .434 .276 r
F P
0 g
s
.55088 1.03117 m .56652 1.03799 L .55577 1.04826 L p .682 .71 .87 r
F P
0 g
s
.55577 1.04826 m .54017 1.0415 L .55088 1.03117 L p .682 .71 .87 r
F P
0 g
s
.39367 .06596 m .40978 .07563 L .39973 .0902 L p .694 .677 .829 r
F P
0 g
s
.39973 .0902 m .38366 .08062 L .39367 .06596 L p .694 .677 .829 r
F P
0 g
s
.3815 .10625 m .38366 .08062 L .39973 .0902 L p .84 .446 .302 r
F P
0 g
s
.39973 .0902 m .39792 .11596 L .3815 .10625 L p .84 .446 .302 r
F P
0 g
s
.41474 .11687 m .39853 .10725 L .40872 .09255 L p .694 .679 .831 r
F P
0 g
s
.40818 .10119 m .39792 .11596 L .39973 .0902 L p 0 0 .171 r
F P
0 g
s
.39973 .0902 m .40978 .07563 L .40818 .10119 L p 0 0 .171 r
F P
0 g
s
.3815 .10625 m .38366 .08062 L .39973 .0902 L p .84 .446 .302 r
F P
0 g
s
.39973 .0902 m .39792 .11596 L .3815 .10625 L p .84 .446 .302 r
F P
0 g
s
.40872 .09255 m .39853 .10725 L .39973 .0902 L p 0 0 .171 r
F P
0 g
s
.39973 .0902 m .40978 .07563 L .40872 .09255 L p 0 0 .171 r
F P
0 g
s
.46227 .06561 m .47818 .07528 L .46783 .08986 L p .694 .677 .829 r
F P
0 g
s
.46783 .08986 m .45195 .08027 L .46227 .06561 L p .694 .677 .829 r
F P
0 g
s
.451 .11468 m .45195 .08027 L .46783 .08986 L p .839 .438 .285 r
F P
0 g
s
.46783 .08986 m .46733 .12444 L .451 .11468 L p .839 .438 .285 r
F P
0 g
s
.47798 .1096 m .46733 .12444 L .46783 .08986 L p 0 0 .214 r
F P
0 g
s
.46783 .08986 m .47818 .07528 L .47798 .1096 L p 0 0 .214 r
F P
0 g
s
.45075 .12359 m .45195 .08027 L .46783 .08986 L p .839 .438 .285 r
F P
0 g
s
.46783 .08986 m .4672 .13339 L .45075 .12359 L p .839 .438 .285 r
F P
0 g
s
.47792 .11849 m .4672 .13339 L .46783 .08986 L p 0 0 .214 r
F P
0 g
s
.46783 .08986 m .47818 .07528 L .47792 .11849 L p 0 0 .214 r
F P
0 g
s
.52344 .77991 m .53918 .78748 L .52855 .79889 L p .686 .7 .857 r
F P
0 g
s
.52855 .79889 m .51285 .79138 L .52344 .77991 L p .686 .7 .857 r
F P
0 g
s
.57736 1.02762 m .59295 1.03446 L .58207 1.04477 L p .682 .71 .87 r
F P
0 g
s
.58207 1.04477 m .56652 1.03799 L .57736 1.02762 L p .682 .71 .87 r
F P
0 g
s
.36499 .09648 m .35491 .11128 L .35762 .08559 L p 0 0 .14 r
F P
0 g
s
.35762 .08559 m .3675 .07097 L .36499 .09648 L p 0 0 .14 r
F P
0 g
s
.41993 .06092 m .43599 .07063 L .4258 .08524 L p .694 .677 .829 r
F P
0 g
s
.4258 .08524 m .40978 .07563 L .41993 .06092 L p .694 .677 .829 r
F P
0 g
s
.40872 .09255 m .42497 .10225 L .41474 .11687 L p .694 .679 .831 r
F P
0 g
s
.40818 .10119 m .40978 .07563 L .4258 .08524 L p .839 .442 .294 r
F P
0 g
s
.4258 .08524 m .42454 .11094 L .40818 .10119 L p .839 .442 .294 r
F P
0 g
s
.43494 .09612 m .42454 .11094 L .4258 .08524 L p 0 0 .186 r
F P
0 g
s
.4258 .08524 m .43599 .07063 L .43494 .09612 L p 0 0 .186 r
F P
0 g
s
.40872 .09255 m .40978 .07563 L .4258 .08524 L p .839 .442 .294 r
F P
0 g
s
.4258 .08524 m .42497 .10225 L .40872 .09255 L p .839 .442 .294 r
F P
0 g
s
.43494 .09612 m .42454 .11094 L .4258 .08524 L p 0 0 .186 r
F P
0 g
s
.4258 .08524 m .43599 .07063 L .43494 .09612 L p 0 0 .186 r
F P
0 g
s
.47792 .11849 m .47818 .07528 L .494 .0849 L p .839 .434 .276 r
F P
0 g
s
.494 .0849 m .49431 .12832 L .47792 .11849 L p .839 .434 .276 r
F P
0 g
s
.53514 1.02431 m .55088 1.03117 L .54017 1.0415 L p .682 .71 .87 r
F P
0 g
s
.54017 1.0415 m .52447 1.0347 L .53514 1.02431 L p .682 .71 .87 r
F P
0 g
s
.37746 .05623 m .39367 .06596 L .38366 .08062 L p .694 .677 .829 r
F P
0 g
s
.38366 .08062 m .3675 .07097 L .37746 .05623 L p .694 .677 .829 r
F P
0 g
s
.36583 .08786 m .3675 .07097 L .38366 .08062 L p .84 .446 .302 r
F P
0 g
s
.38366 .08062 m .38223 .09758 L .36583 .08786 L p .84 .446 .302 r
F P
0 g
s
.39238 .08279 m .38223 .09758 L .38366 .08062 L p 0 0 .156 r
F P
0 g
s
.38366 .08062 m .39367 .06596 L .39238 .08279 L p 0 0 .156 r
F P
0 g
s
.36499 .09648 m .3675 .07097 L .38366 .08062 L p .84 .446 .302 r
F P
0 g
s
.38366 .08062 m .3815 .10625 L .36499 .09648 L p .84 .446 .302 r
F P
0 g
s
.39172 .09139 m .3815 .10625 L .38366 .08062 L p 0 0 .156 r
F P
0 g
s
.38366 .08062 m .39367 .06596 L .39172 .09139 L p 0 0 .156 r
F P
0 g
s
.44626 .05587 m .46227 .06561 L .45195 .08027 L p .694 .677 .829 r
F P
0 g
s
.45195 .08027 m .43599 .07063 L .44626 .05587 L p .694 .677 .829 r
F P
0 g
s
.43494 .09612 m .43599 .07063 L .45195 .08027 L p .839 .438 .285 r
F P
0 g
s
.45195 .08027 m .45124 .1059 L .43494 .09612 L p .839 .438 .285 r
F P
0 g
s
.46178 .09104 m .45124 .1059 L .45195 .08027 L p 0 0 .2 r
F P
0 g
s
.45195 .08027 m .46227 .06561 L .46178 .09104 L p 0 0 .2 r
F P
0 g
s
.43494 .09612 m .43599 .07063 L .45195 .08027 L p .839 .438 .285 r
F P
0 g
s
.45195 .08027 m .45124 .1059 L .43494 .09612 L p .839 .438 .285 r
F P
0 g
s
.46161 .09976 m .451 .11468 L .45195 .08027 L p 0 0 .2 r
F P
0 g
s
.45195 .08027 m .46227 .06561 L .46161 .09976 L p 0 0 .2 r
F P
0 g
s
.50761 .7723 m .52344 .77991 L .51285 .79138 L p .686 .7 .857 r
F P
0 g
s
.51285 .79138 m .49706 .78384 L .50761 .7723 L p .686 .7 .857 r
F P
0 g
s
.48002 .51977 m .49595 .52814 L .48547 .54075 L p .69 .691 .846 r
F P
0 g
s
.48547 .54075 m .46958 .53245 L .48002 .51977 L p .69 .691 .846 r
F P
0 g
s
.40377 .05116 m .41993 .06092 L .40978 .07563 L p .694 .677 .829 r
F P
0 g
s
.40978 .07563 m .39367 .06596 L .40377 .05116 L p .694 .677 .829 r
F P
0 g
s
.39303 .07432 m .39367 .06596 L .40978 .07563 L p .839 .442 .294 r
F P
0 g
s
.40978 .07563 m .40926 .08403 L .39303 .07432 L p .839 .442 .294 r
F P
0 g
s
.41947 .06926 m .40926 .08403 L .40978 .07563 L p 0 0 .171 r
F P
0 g
s
.40978 .07563 m .41993 .06092 L .41947 .06926 L p 0 0 .171 r
F P
0 g
s
.39172 .09139 m .39367 .06596 L .40978 .07563 L p .839 .442 .294 r
F P
0 g
s
.40978 .07563 m .40818 .10119 L .39172 .09139 L p .839 .442 .294 r
F P
0 g
s
.41853 .08629 m .40818 .10119 L .40978 .07563 L p 0 0 .171 r
F P
0 g
s
.40978 .07563 m .41993 .06092 L .41853 .08629 L p 0 0 .171 r
F P
0 g
s
.46161 .09976 m .46227 .06561 L .47818 .07528 L p .839 .434 .276 r
F P
0 g
s
.47818 .07528 m .47798 .1096 L .46161 .09976 L p .839 .434 .276 r
F P
0 g
s
.51931 1.0174 m .53514 1.02431 L .52447 1.0347 L p .682 .71 .87 r
F P
0 g
s
.52447 1.0347 m .50869 1.02786 L .51931 1.0174 L p .682 .71 .87 r
F P
0 g
s
.5883 1.01715 m .60392 1.02406 L .59295 1.03446 L p .682 .71 .87 r
F P
0 g
s
.59295 1.03446 m .57736 1.02762 L .5883 1.01715 L p .682 .71 .87 r
F P
0 g
s
.37593 .07298 m .36583 .08786 L .3675 .07097 L p 0 0 .14 r
F P
0 g
s
.3675 .07097 m .37746 .05623 L .37593 .07298 L p 0 0 .14 r
F P
0 g
s
.43016 .04608 m .44626 .05587 L .43599 .07063 L p .694 .677 .829 r
F P
0 g
s
.43599 .07063 m .41993 .06092 L .43016 .04608 L p .694 .677 .829 r
F P
0 g
s
.419 .07772 m .41993 .06092 L .43599 .07063 L p .839 .438 .285 r
F P
0 g
s
.43599 .07063 m .43529 .0875 L .419 .07772 L p .839 .438 .285 r
F P
0 g
s
.44571 .07262 m .43529 .0875 L .43599 .07063 L p 0 0 .186 r
F P
0 g
s
.43599 .07063 m .44626 .05587 L .44571 .07262 L p 0 0 .186 r
F P
0 g
s
.41853 .08629 m .41993 .06092 L .43599 .07063 L p .839 .438 .285 r
F P
0 g
s
.43599 .07063 m .43494 .09612 L .41853 .08629 L p .839 .438 .285 r
F P
0 g
s
.44543 .08117 m .43494 .09612 L .43599 .07063 L p 0 0 .186 r
F P
0 g
s
.43599 .07063 m .44626 .05587 L .44543 .08117 L p 0 0 .186 r
F P
0 g
s
.49169 .76464 m .50761 .7723 L .49706 .78384 L p .686 .7 .857 r
F P
0 g
s
.49706 .78384 m .48117 .77625 L .49169 .76464 L p .686 .7 .857 r
F P
0 g
s
.45818 .38891 m .47421 .39769 L .4638 .41091 L p .691 .687 .841 r
F P
0 g
s
.4638 .41091 m .44782 .40221 L .45818 .38891 L p .691 .687 .841 r
F P
0 g
s
.54591 1.01381 m .56168 1.02074 L .55088 1.03117 L p .682 .71 .87 r
F P
0 g
s
.55088 1.03117 m .53514 1.02431 L .54591 1.01381 L p .682 .71 .87 r
F P
0 g
s
.464 .51135 m .48002 .51977 L .46958 .53245 L p .69 .691 .846 r
F P
0 g
s
.46958 .53245 m .4536 .52411 L .464 .51135 L p .69 .691 .846 r
F P
0 g
s
.38752 .04134 m .40377 .05116 L .39367 .06596 L p .694 .677 .829 r
F P
0 g
s
.39367 .06596 m .37746 .05623 L .38752 .04134 L p .694 .677 .829 r
F P
0 g
s
.3767 .06454 m .37746 .05623 L .39367 .06596 L p .839 .442 .294 r
F P
0 g
s
.39367 .06596 m .39303 .07432 L .3767 .06454 L p .839 .442 .294 r
F P
0 g
s
.4032 .05946 m .39303 .07432 L .39367 .06596 L p 0 0 .156 r
F P
0 g
s
.39367 .06596 m .40377 .05116 L .4032 .05946 L p 0 0 .156 r
F P
0 g
s
.37593 .07298 m .37746 .05623 L .39367 .06596 L p .839 .442 .294 r
F P
0 g
s
.39367 .06596 m .39238 .08279 L .37593 .07298 L p .839 .442 .294 r
F P
0 g
s
.4032 .05946 m .39303 .07432 L .39367 .06596 L p 0 0 .156 r
F P
0 g
s
.39367 .06596 m .40377 .05116 L .4032 .05946 L p 0 0 .156 r
F P
0 g
s
.44543 .08117 m .44626 .05587 L .46227 .06561 L p .839 .434 .276 r
F P
0 g
s
.46227 .06561 m .46178 .09104 L .44543 .08117 L p .839 .434 .276 r
F P
0 g
s
.50339 1.01046 m .51931 1.0174 L .50869 1.02786 L p .682 .71 .87 r
F P
0 g
s
.50869 1.02786 m .4928 1.02098 L .50339 1.01046 L p .682 .71 .87 r
F P
0 g
s
.57258 1.01021 m .5883 1.01715 L .57736 1.02762 L p .682 .71 .87 r
F P
0 g
s
.57736 1.02762 m .56168 1.02074 L .57258 1.01021 L p .682 .71 .87 r
F P
0 g
s
.43626 .25753 m .45238 .26671 L .44205 .28055 L p .692 .683 .837 r
F P
0 g
s
.44205 .28055 m .42597 .27145 L .43626 .25753 L p .692 .683 .837 r
F P
0 g
s
.49056 .50696 m .50653 .51541 L .49595 .52814 L p .69 .691 .846 r
F P
0 g
s
.49595 .52814 m .48002 .51977 L .49056 .50696 L p .69 .691 .846 r
F P
0 g
s
.41396 .03624 m .43016 .04608 L .41993 .06092 L p .694 .677 .829 r
F P
0 g
s
.41993 .06092 m .40377 .05116 L .41396 .03624 L p .694 .677 .829 r
F P
0 g
s
.4032 .05946 m .40377 .05116 L .41993 .06092 L p .839 .438 .285 r
F P
0 g
s
.41993 .06092 m .41947 .06926 L .4032 .05946 L p .839 .438 .285 r
F P
0 g
s
.42977 .05436 m .41947 .06926 L .41993 .06092 L p 0 0 .171 r
F P
0 g
s
.41993 .06092 m .43016 .04608 L .42977 .05436 L p 0 0 .171 r
F P
0 g
s
.4032 .05946 m .40377 .05116 L .41993 .06092 L p .839 .438 .285 r
F P
0 g
s
.41993 .06092 m .41947 .06926 L .4032 .05946 L p .839 .438 .285 r
F P
0 g
s
.42938 .06274 m .419 .07772 L .41993 .06092 L p 0 0 .171 r
F P
0 g
s
.41993 .06092 m .43016 .04608 L .42938 .06274 L p 0 0 .171 r
F P
0 g
s
.44206 .38008 m .45818 .38891 L .44782 .40221 L p .691 .687 .841 r
F P
0 g
s
.44782 .40221 m .43174 .39346 L .44206 .38008 L p .691 .687 .841 r
F P
0 g
s
.42526 .19164 m .44143 .20103 L .43114 .21517 L p .693 .681 .835 r
F P
0 g
s
.43114 .21517 m .41501 .20587 L .42526 .19164 L p .693 .681 .835 r
F P
0 g
s
.59934 1.0066 m .615 1.01356 L .60392 1.02406 L p .682 .71 .87 r
F P
0 g
s
.60392 1.02406 m .5883 1.01715 L .59934 1.0066 L p .682 .71 .87 r
F P
0 g
s
.44788 .50287 m .464 .51135 L .4536 .52411 L p .69 .691 .846 r
F P
0 g
s
.4536 .52411 m .43752 .51571 L .44788 .50287 L p .69 .691 .846 r
F P
0 g
s
.38683 .04959 m .3767 .06454 L .37746 .05623 L p 0 0 .14 r
F P
0 g
s
.37746 .05623 m .38752 .04134 L .38683 .04959 L p 0 0 .14 r
F P
0 g
s
.41424 .12561 m .43046 .13521 L .42021 .14967 L p .693 .68 .832 r
F P
0 g
s
.42021 .14967 m .40403 .14016 L .41424 .12561 L p .693 .68 .832 r
F P
0 g
s
.42938 .06274 m .43016 .04608 L .44626 .05587 L p .839 .434 .276 r
F P
0 g
s
.44626 .05587 m .44571 .07262 L .42938 .06274 L p .839 .434 .276 r
F P
0 g
s
.48738 1.00348 m .50339 1.01046 L .4928 1.02098 L p .682 .71 .87 r
F P
0 g
s
.4928 1.02098 m .47683 1.01406 L .48738 1.00348 L p .682 .71 .87 r
F P
0 g
s
.42003 .24829 m .43626 .25753 L .42597 .27145 L p .692 .683 .837 r
F P
0 g
s
.42597 .27145 m .40979 .26229 L .42003 .24829 L p .692 .683 .837 r
F P
0 g
s
.4032 .05946 m .41947 .06926 L .40926 .08403 L p .694 .678 .83 r
F P
0 g
s
.40926 .08403 m .39303 .07432 L .4032 .05946 L p .694 .678 .83 r
F P
0 g
s
.39767 .02633 m .41396 .03624 L .40377 .05116 L p .694 .677 .829 r
F P
0 g
s
.40377 .05116 m .38752 .04134 L .39767 .02633 L p .694 .677 .829 r
F P
0 g
s
.39767 .02633 m .41396 .03624 L .40377 .05116 L p .694 .677 .829 r
F P
0 g
s
.40377 .05116 m .38752 .04134 L .39767 .02633 L p .694 .677 .829 r
F P
0 g
s
.38683 .04959 m .38752 .04134 L .40377 .05116 L p .839 .438 .285 r
F P
0 g
s
.40377 .05116 m .4032 .05946 L .38683 .04959 L p .839 .438 .285 r
F P
0 g
s
.41346 .04446 m .4032 .05946 L .40377 .05116 L p 0 0 .156 r
F P
0 g
s
.40377 .05116 m .41396 .03624 L .41346 .04446 L p 0 0 .156 r
F P
0 g
s
.51408 .99984 m .53004 1.00685 L .51931 1.0174 L p .682 .71 .87 r
F P
0 g
s
.51931 1.0174 m .50339 1.01046 L .51408 .99984 L p .682 .71 .87 r
F P
0 g
s
.44664 .24348 m .4628 .25275 L .45238 .26671 L p .692 .683 .837 r
F P
0 g
s
.45238 .26671 m .43626 .25753 L .44664 .24348 L p .692 .683 .837 r
F P
0 g
s
.43166 .49435 m .44788 .50287 L .43752 .51571 L p .69 .691 .846 r
F P
0 g
s
.43752 .51571 m .42134 .50727 L .43166 .49435 L p .69 .691 .846 r
F P
0 g
s
.39792 .11596 m .41424 .12561 L .40403 .14016 L p .693 .68 .832 r
F P
0 g
s
.40403 .14016 m .38775 .13059 L .39792 .11596 L p .693 .68 .832 r
F P
0 g
s
.50119 .49404 m .51721 .50257 L .50653 .51541 L p .69 .691 .846 r
F P
0 g
s
.50653 .51541 m .49056 .50696 L .50119 .49404 L p .69 .691 .846 r
F P
0 g
s
.41346 .04446 m .41396 .03624 L .43016 .04608 L p .839 .434 .276 r
F P
0 g
s
.43016 .04608 m .42977 .05436 L .41346 .04446 L p .839 .434 .276 r
F P
0 g
s
.47126 .99645 m .48738 1.00348 L .47683 1.01406 L p .682 .71 .87 r
F P
0 g
s
.47683 1.01406 m .46076 1.0071 L .47126 .99645 L p .682 .71 .87 r
F P
0 g
s
.40372 .23899 m .42003 .24829 L .40979 .26229 L p .692 .683 .837 r
F P
0 g
s
.40979 .26229 m .39352 .25308 L .40372 .23899 L p .692 .683 .837 r
F P
0 g
s
.38683 .04959 m .4032 .05946 L .39303 .07432 L p .694 .678 .83 r
F P
0 g
s
.39303 .07432 m .3767 .06454 L .38683 .04959 L p .694 .678 .83 r
F P
0 g
s
.61048 .99594 m .62618 1.00297 L .615 1.01356 L p .682 .71 .87 r
F P
0 g
s
.615 1.01356 m .59934 1.0066 L .61048 .99594 L p .682 .71 .87 r
F P
0 g
s
.45833 .48992 m .4745 .49847 L .464 .51135 L p .69 .691 .846 r
F P
0 g
s
.464 .51135 m .44788 .50287 L .45833 .48992 L p .69 .691 .846 r
F P
0 g
s
.42454 .11094 m .4408 .12062 L .43046 .13521 L p .693 .68 .832 r
F P
0 g
s
.43046 .13521 m .41424 .12561 L .42454 .11094 L p .693 .68 .832 r
F P
0 g
s
.41346 .04446 m .42977 .05436 L .41947 .06926 L p .694 .678 .83 r
F P
0 g
s
.41947 .06926 m .4032 .05946 L .41346 .04446 L p .694 .678 .83 r
F P
0 g
s
.41535 .48578 m .43166 .49435 L .42134 .50727 L p .69 .691 .846 r
F P
0 g
s
.42134 .50727 m .40507 .49877 L .41535 .48578 L p .69 .691 .846 r
F P
0 g
s
.3815 .10625 m .39792 .11596 L .38775 .13059 L p .693 .68 .832 r
F P
0 g
s
.38775 .13059 m .37138 .12097 L .3815 .10625 L p .693 .68 .832 r
F P
0 g
s
.48509 .48547 m .50119 .49404 L .49056 .50696 L p .69 .691 .846 r
F P
0 g
s
.49056 .50696 m .4745 .49847 L .48509 .48547 L p .69 .691 .846 r
F P
0 g
s
.37593 .07298 m .39238 .08279 L .38223 .09758 L p .694 .679 .831 r
F P
0 g
s
.38223 .09758 m .36583 .08786 L .37593 .07298 L p .694 .679 .831 r
F P
0 g
s
.45505 .98938 m .47126 .99645 L .46076 1.0071 L p .682 .71 .87 r
F P
0 g
s
.46076 1.0071 m .44459 1.0001 L .45505 .98938 L p .682 .71 .87 r
F P
0 g
s
.40424 .41959 m .42061 .42838 L .41033 .4416 L p .69 .689 .844 r
F P
0 g
s
.41033 .4416 m .39401 .4329 L .40424 .41959 L p .69 .689 .844 r
F P
0 g
s
.52486 .98913 m .54086 .9962 L .53004 1.00685 L p .682 .71 .87 r
F P
0 g
s
.53004 1.00685 m .51408 .99984 L .52486 .98913 L p .682 .71 .87 r
F P
0 g
s
.3873 .22964 m .40372 .23899 L .39352 .25308 L p .692 .683 .837 r
F P
0 g
s
.39352 .25308 m .37714 .24381 L .3873 .22964 L p .692 .683 .837 r
F P
0 g
s
.59468 .98887 m .61048 .99594 L .59934 1.0066 L p .682 .71 .87 r
F P
0 g
s
.59934 1.0066 m .58358 .99959 L .59468 .98887 L p .682 .71 .87 r
F P
0 g
s
.45711 .2293 m .47332 .23866 L .4628 .25275 L p .692 .683 .837 r
F P
0 g
s
.4628 .25275 m .44664 .24348 L .45711 .2293 L p .692 .683 .837 r
F P
0 g
s
.51936 .95627 m .53539 .96345 L .52458 .97425 L p .682 .709 .868 r
F P
0 g
s
.52458 .97425 m .5086 .96714 L .51936 .95627 L p .682 .709 .868 r
F P
0 g
s
.51192 .48101 m .52798 .48961 L .51721 .50257 L p .69 .691 .846 r
F P
0 g
s
.51721 .50257 m .50119 .49404 L .51192 .48101 L p .69 .691 .846 r
F P
0 g
s
.48186 .9857 m .49802 .99279 L .48738 1.00348 L p .682 .71 .87 r
F P
0 g
s
.48738 1.00348 m .47126 .99645 L .48186 .9857 L p .682 .71 .87 r
F P
0 g
s
.41401 .22477 m .43037 .23415 L .42003 .24829 L p .692 .683 .837 r
F P
0 g
s
.42003 .24829 m .40372 .23899 L .41401 .22477 L p .692 .683 .837 r
F P
0 g
s
.62172 .98519 m .63746 .99228 L .62618 1.00297 L p .682 .71 .87 r
F P
0 g
s
.62618 1.00297 m .61048 .99594 L .62172 .98519 L p .682 .71 .87 r
F P
0 g
s
.39893 .47715 m .41535 .48578 L .40507 .49877 L p .69 .691 .846 r
F P
0 g
s
.40507 .49877 m .3887 .49023 L .39893 .47715 L p .69 .691 .846 r
F P
0 g
s
.36499 .09648 m .3815 .10625 L .37138 .12097 L p .693 .68 .832 r
F P
0 g
s
.37138 .12097 m .35491 .11128 L .36499 .09648 L p .693 .68 .832 r
F P
0 g
s
.43494 .09612 m .45124 .1059 L .4408 .12062 L p .693 .68 .832 r
F P
0 g
s
.4408 .12062 m .42454 .11094 L .43494 .09612 L p .693 .68 .832 r
F P
0 g
s
.42938 .06274 m .44571 .07262 L .43529 .0875 L p .694 .679 .831 r
F P
0 g
s
.43529 .0875 m .419 .07772 L .42938 .06274 L p .694 .679 .831 r
F P
0 g
s
.43874 .98227 m .45505 .98938 L .44459 1.0001 L p .682 .71 .87 r
F P
0 g
s
.44459 1.0001 m .42832 .99305 L .43874 .98227 L p .682 .71 .87 r
F P
0 g
s
.50876 .98201 m .52486 .98913 L .51408 .99984 L p .682 .71 .87 r
F P
0 g
s
.51408 .99984 m .49802 .99279 L .50876 .98201 L p .682 .71 .87 r
F P
0 g
s
.37079 .22023 m .3873 .22964 L .37714 .24381 L p .692 .683 .837 r
F P
0 g
s
.37714 .24381 m .36067 .23449 L .37079 .22023 L p .692 .683 .837 r
F P
0 g
s
.57879 .98176 m .59468 .98887 L .58358 .99959 L p .682 .71 .87 r
F P
0 g
s
.58358 .99959 m .56773 .99254 L .57879 .98176 L p .682 .71 .87 r
F P
0 g
s
.44081 .21989 m .45711 .2293 L .44664 .24348 L p .692 .683 .837 r
F P
0 g
s
.44664 .24348 m .43037 .23415 L .44081 .21989 L p .692 .683 .837 r
F P
0 g
s
.42571 .47267 m .44207 .48132 L .43166 .49435 L p .69 .691 .846 r
F P
0 g
s
.43166 .49435 m .41535 .48578 L .42571 .47267 L p .69 .691 .846 r
F P
0 g
s
.39172 .09139 m .40818 .10119 L .39792 .11596 L p .693 .68 .832 r
F P
0 g
s
.39792 .11596 m .3815 .10625 L .39172 .09139 L p .693 .68 .832 r
F P
0 g
s
.5733 .9488 m .58922 .95601 L .57814 .96689 L p .682 .709 .868 r
F P
0 g
s
.57814 .96689 m .56226 .95974 L .5733 .9488 L p .682 .709 .868 r
F P
0 g
s
.35959 .15351 m .37615 .16313 L .36604 .17762 L p .693 .681 .835 r
F P
0 g
s
.36604 .17762 m .34952 .16809 L .35959 .15351 L p .693 .681 .835 r
F P
0 g
s
.35398 .12009 m .37057 .12982 L .36048 .14447 L p .693 .681 .834 r
F P
0 g
s
.36048 .14447 m .34393 .13483 L .35398 .12009 L p .693 .681 .834 r
F P
0 g
s
.41457 .40616 m .43098 .41503 L .42061 .42838 L p .69 .689 .844 r
F P
0 g
s
.42061 .42838 m .40424 .41959 L .41457 .40616 L p .69 .689 .844 r
F P
0 g
s
.53574 .97831 m .55178 .98545 L .54086 .9962 L p .682 .71 .87 r
F P
0 g
s
.54086 .9962 m .52486 .98913 L .53574 .97831 L p .682 .71 .87 r
F P
0 g
s
.46768 .215 m .48393 .22444 L .47332 .23866 L p .692 .683 .837 r
F P
0 g
s
.47332 .23866 m .45711 .2293 L .46768 .215 L p .692 .683 .837 r
F P
0 g
s
.41647 .85026 m .43288 .85778 L .42249 .86912 L p .684 .705 .863 r
F P
0 g
s
.42249 .86912 m .40613 .86166 L .41647 .85026 L p .684 .705 .863 r
F P
0 g
s
.38242 .46848 m .39893 .47715 L .3887 .49023 L p .69 .691 .846 r
F P
0 g
s
.3887 .49023 m .37224 .48163 L .38242 .46848 L p .69 .691 .846 r
F P
0 g
s
.41853 .08629 m .43494 .09612 L .42454 .11094 L p .693 .68 .832 r
F P
0 g
s
.42454 .11094 m .40818 .10119 L .41853 .08629 L p .693 .68 .832 r
F P
0 g
s
.52275 .46785 m .53885 .47653 L .52798 .48961 L p .69 .691 .846 r
F P
0 g
s
.52798 .48961 m .51192 .48101 L .52275 .46785 L p .69 .691 .846 r
F P
0 g
s
.42234 .97512 m .43874 .98227 L .42832 .99305 L p .682 .71 .87 r
F P
0 g
s
.42832 .99305 m .41196 .98596 L .42234 .97512 L p .682 .71 .87 r
F P
0 g
s
.35417 .21077 m .37079 .22023 L .36067 .23449 L p .692 .683 .837 r
F P
0 g
s
.36067 .23449 m .3441 .22511 L .35417 .21077 L p .692 .683 .837 r
F P
0 g
s
.56281 .9746 m .57879 .98176 L .56773 .99254 L p .682 .71 .87 r
F P
0 g
s
.56773 .99254 m .55178 .98545 L .56281 .9746 L p .682 .71 .87 r
F P
0 g
s
.63307 .97434 m .64884 .9815 L .63746 .99228 L p .682 .71 .87 r
F P
0 g
s
.63746 .99228 m .62172 .98519 L .63307 .97434 L p .682 .71 .87 r
F P
0 g
s
.44543 .08117 m .46178 .09104 L .45124 .1059 L p .693 .68 .832 r
F P
0 g
s
.45124 .1059 m .43494 .09612 L .44543 .08117 L p .693 .68 .832 r
F P
0 g
s
.34292 .14383 m .35959 .15351 L .34952 .16809 L p .693 .681 .835 r
F P
0 g
s
.34952 .16809 m .3329 .1585 L .34292 .14383 L p .693 .681 .835 r
F P
0 g
s
.44926 .97139 m .46561 .97857 L .45505 .98938 L p .682 .71 .87 r
F P
0 g
s
.45505 .98938 m .43874 .98227 L .44926 .97139 L p .682 .71 .87 r
F P
0 g
s
.38099 .20584 m .39755 .21534 L .3873 .22964 L p .692 .683 .837 r
F P
0 g
s
.3873 .22964 m .37079 .22023 L .38099 .20584 L p .692 .683 .837 r
F P
0 g
s
.58996 .97087 m .60589 .97805 L .59468 .98887 L p .682 .71 .87 r
F P
0 g
s
.59468 .98887 m .57879 .98176 L .58996 .97087 L p .682 .71 .87 r
F P
0 g
s
.36581 .45975 m .38242 .46848 L .37224 .48163 L p .69 .691 .846 r
F P
0 g
s
.37224 .48163 m .35567 .47298 L .36581 .45975 L p .69 .691 .846 r
F P
0 g
s
.43618 .45943 m .45258 .46816 L .44207 .48132 L p .69 .691 .846 r
F P
0 g
s
.44207 .48132 m .42571 .47267 L .43618 .45943 L p .69 .691 .846 r
F P
0 g
s
.50656 .45912 m .52275 .46785 L .51192 .48101 L p .69 .691 .846 r
F P
0 g
s
.51192 .48101 m .49578 .47235 L .50656 .45912 L p .69 .691 .846 r
F P
0 g
s
.36975 .13879 m .38636 .1485 L .37615 .16313 L p .693 .681 .835 r
F P
0 g
s
.37615 .16313 m .35959 .15351 L .36975 .13879 L p .693 .681 .835 r
F P
0 g
s
.43059 .42604 m .44701 .43488 L .43653 .44819 L p .69 .69 .845 r
F P
0 g
s
.43653 .44819 m .42014 .43943 L .43059 .42604 L p .69 .69 .845 r
F P
0 g
s
.40583 .96792 m .42234 .97512 L .41196 .98596 L p .682 .71 .87 r
F P
0 g
s
.41196 .98596 m .3955 .97883 L .40583 .96792 L p .682 .71 .87 r
F P
0 g
s
.33745 .20125 m .35417 .21077 L .3441 .22511 L p .692 .683 .837 r
F P
0 g
s
.3441 .22511 m .32743 .21568 L .33745 .20125 L p .692 .683 .837 r
F P
0 g
s
.61719 .96714 m .63307 .97434 L .62172 .98519 L p .682 .71 .87 r
F P
0 g
s
.62172 .98519 m .60589 .97805 L .61719 .96714 L p .682 .71 .87 r
F P
0 g
s
.47835 .20056 m .49465 .21008 L .48393 .22444 L p .692 .683 .837 r
F P
0 g
s
.48393 .22444 m .46768 .215 L .47835 .20056 L p .692 .683 .837 r
F P
0 g
s
.4269 .83875 m .44336 .84634 L .43288 .85778 L p .684 .705 .863 r
F P
0 g
s
.43288 .85778 m .41647 .85026 L .4269 .83875 L p .684 .705 .863 r
F P
0 g
s
.33181 .16769 m .34855 .17732 L .3385 .19182 L p .692 .682 .836 r
F P
0 g
s
.3385 .19182 m .32181 .18228 L .33181 .16769 L p .692 .682 .836 r
F P
0 g
s
.3927 .45521 m .40926 .46396 L .39893 .47715 L p .69 .691 .846 r
F P
0 g
s
.39893 .47715 m .38242 .46848 L .3927 .45521 L p .69 .691 .846 r
F P
0 g
s
.53368 .45457 m .54982 .46333 L .53885 .47653 L p .69 .691 .846 r
F P
0 g
s
.53885 .47653 m .52275 .46785 L .53368 .45457 L p .69 .691 .846 r
F P
0 g
s
.4672 .13339 m .48354 .14313 L .47287 .1578 L p .693 .681 .835 r
F P
0 g
s
.47287 .1578 m .45657 .14815 L .4672 .13339 L p .693 .681 .835 r
F P
0 g
s
.46161 .09976 m .47798 .1096 L .46733 .12444 L p .693 .681 .834 r
F P
0 g
s
.46733 .12444 m .451 .11468 L .46161 .09976 L p .693 .681 .834 r
F P
0 g
s
.64452 .96339 m .66033 .97061 L .64884 .9815 L p .682 .71 .87 r
F P
0 g
s
.64884 .9815 m .63307 .97434 L .64452 .96339 L p .682 .71 .87 r
F P
0 g
s
.34909 .45097 m .36581 .45975 L .35567 .47298 L p .69 .691 .846 r
F P
0 g
s
.35567 .47298 m .339 .46428 L .34909 .45097 L p .69 .691 .846 r
F P
0 g
s
.41968 .45065 m .43618 .45943 L .42571 .47267 L p .69 .691 .846 r
F P
0 g
s
.42571 .47267 m .40926 .46396 L .41968 .45065 L p .69 .691 .846 r
F P
0 g
s
.49027 .45033 m .50656 .45912 L .49578 .47235 L p .69 .691 .846 r
F P
0 g
s
.49578 .47235 m .47953 .46365 L .49027 .45033 L p .69 .691 .846 r
F P
0 g
s
.48469 .41683 m .50101 .42572 L .49024 .43912 L p .69 .69 .845 r
F P
0 g
s
.49024 .43912 m .47397 .4303 L .48469 .41683 L p .69 .69 .845 r
F P
0 g
s
.38922 .96068 m .40583 .96792 L .3955 .97883 L p .682 .71 .87 r
F P
0 g
s
.3955 .97883 m .37893 .97165 L .38922 .96068 L p .682 .71 .87 r
F P
0 g
s
.45987 .96041 m .47627 .96766 L .46561 .97857 L p .682 .71 .87 r
F P
0 g
s
.46561 .97857 m .44926 .97139 L .45987 .96041 L p .682 .71 .87 r
F P
0 g
s
.32064 .19167 m .33745 .20125 L .32743 .21568 L p .692 .683 .837 r
F P
0 g
s
.32743 .21568 m .31066 .20619 L .32064 .19167 L p .692 .683 .837 r
F P
0 g
s
.39129 .19132 m .4079 .2009 L .39755 .21534 L p .692 .683 .837 r
F P
0 g
s
.39755 .21534 m .38099 .20584 L .39129 .19132 L p .692 .683 .837 r
F P
0 g
s
.46196 .19097 m .47835 .20056 L .46768 .215 L p .692 .683 .837 r
F P
0 g
s
.46768 .215 m .45133 .2055 L .46196 .19097 L p .692 .683 .837 r
F P
0 g
s
.38565 .15765 m .40228 .16734 L .39196 .18194 L p .692 .682 .836 r
F P
0 g
s
.39196 .18194 m .37537 .17234 L .38565 .15765 L p .692 .682 .836 r
F P
0 g
s
.44674 .44608 m .46318 .45489 L .45258 .46816 L p .69 .691 .846 r
F P
0 g
s
.45258 .46816 m .43618 .45943 L .44674 .44608 L p .69 .691 .846 r
F P
0 g
s
.32645 .31677 m .34327 .32598 L .33321 .33985 L p .691 .687 .841 r
F P
0 g
s
.33321 .33985 m .31644 .33073 L .32645 .31677 L p .691 .687 .841 r
F P
0 g
s
.45075 .12359 m .4672 .13339 L .45657 .14815 L p .693 .681 .835 r
F P
0 g
s
.45657 .14815 m .44017 .13844 L .45075 .12359 L p .693 .681 .835 r
F P
0 g
s
.41626 .95691 m .43281 .96417 L .42234 .97512 L p .682 .71 .87 r
F P
0 g
s
.42234 .97512 m .40583 .96792 L .41626 .95691 L p .682 .71 .87 r
F P
0 g
s
.34757 .18668 m .36433 .19629 L .35417 .21077 L p .692 .683 .837 r
F P
0 g
s
.35417 .21077 m .33745 .20125 L .34757 .18668 L p .692 .683 .837 r
F P
0 g
s
.48912 .18599 m .50546 .1956 L .49465 .21008 L p .692 .683 .837 r
F P
0 g
s
.49465 .21008 m .47835 .20056 L .48912 .18599 L p .692 .683 .837 r
F P
0 g
s
.33228 .44213 m .34909 .45097 L .339 .46428 L p .69 .691 .846 r
F P
0 g
s
.339 .46428 m .32223 .45552 L .33228 .44213 L p .69 .691 .846 r
F P
0 g
s
.31509 .24947 m .33196 .25889 L .32195 .27309 L p .692 .685 .839 r
F P
0 g
s
.32195 .27309 m .30513 .26375 L .31509 .24947 L p .692 .685 .839 r
F P
0 g
s
.43744 .82713 m .45393 .8348 L .44336 .84634 L p .684 .705 .863 r
F P
0 g
s
.44336 .84634 m .4269 .83875 L .43744 .82713 L p .684 .705 .863 r
F P
0 g
s
.47389 .44149 m .49027 .45033 L .47953 .46365 L p .69 .691 .846 r
F P
0 g
s
.47953 .46365 m .46318 .45489 L .47389 .44149 L p .69 .691 .846 r
F P
0 g
s
.54471 .44117 m .56089 .45001 L .54982 .46333 L p .69 .691 .846 r
F P
0 g
s
.54982 .46333 m .53368 .45457 L .54471 .44117 L p .69 .691 .846 r
F P
0 g
s
.30941 .21576 m .3263 .2253 L .31631 .23965 L p .692 .684 .838 r
F P
0 g
s
.31631 .23965 m .29946 .23021 L .30941 .21576 L p .692 .684 .838 r
F P
0 g
s
.47792 .11849 m .49431 .12832 L .48354 .14313 L p .693 .681 .835 r
F P
0 g
s
.48354 .14313 m .4672 .13339 L .47792 .11849 L p .693 .681 .835 r
F P
0 g
s
.37251 .95339 m .38922 .96068 L .37893 .97165 L p .682 .71 .87 r
F P
0 g
s
.37893 .97165 m .36227 .96443 L .37251 .95339 L p .682 .71 .87 r
F P
0 g
s
.44338 .95313 m .45987 .96041 L .44926 .97139 L p .682 .71 .87 r
F P
0 g
s
.44926 .97139 m .43281 .96417 L .44338 .95313 L p .682 .71 .87 r
F P
0 g
s
.37458 .18168 m .39129 .19132 L .38099 .20584 L p .692 .683 .837 r
F P
0 g
s
.38099 .20584 m .36433 .19629 L .37458 .18168 L p .692 .683 .837 r
F P
0 g
s
.44547 .18133 m .46196 .19097 L .45133 .2055 L p .692 .683 .837 r
F P
0 g
s
.45133 .2055 m .43489 .19595 L .44547 .18133 L p .692 .683 .837 r
F P
0 g
s
.65607 .95234 m .67192 .95963 L .66033 .97061 L p .682 .71 .87 r
F P
0 g
s
.66033 .97061 m .64452 .96339 L .65607 .95234 L p .682 .71 .87 r
F P
0 g
s
.35928 .43753 m .37604 .44639 L .36581 .45975 L p .69 .691 .846 r
F P
0 g
s
.36581 .45975 m .34909 .45097 L .35928 .43753 L p .69 .691 .846 r
F P
0 g
s
.43984 .14755 m .45636 .1573 L .44575 .17199 L p .692 .682 .836 r
F P
0 g
s
.44575 .17199 m .42928 .16233 L .43984 .14755 L p .692 .682 .836 r
F P
0 g
s
.50112 .43689 m .51745 .44576 L .50656 .45912 L p .69 .691 .846 r
F P
0 g
s
.50656 .45912 m .49027 .45033 L .50112 .43689 L p .69 .691 .846 r
F P
0 g
s
.30953 .30751 m .32645 .31677 L .31644 .33073 L p .691 .687 .841 r
F P
0 g
s
.31644 .33073 m .29957 .32155 L .30953 .30751 L p .691 .687 .841 r
F P
0 g
s
.47059 .94933 m .48703 .95664 L .47627 .96766 L p .682 .71 .87 r
F P
0 g
s
.47627 .96766 m .45987 .96041 L .47059 .94933 L p .682 .71 .87 r
F P
0 g
s
.40169 .17666 m .41834 .18633 L .4079 .2009 L p .692 .683 .837 r
F P
0 g
s
.4079 .2009 m .39129 .19132 L .40169 .17666 L p .692 .683 .837 r
F P
0 g
s
.31536 .43324 m .33228 .44213 L .32223 .45552 L p .69 .691 .846 r
F P
0 g
s
.32223 .45552 m .30536 .44671 L .31536 .43324 L p .69 .691 .846 r
F P
0 g
s
.29812 .23999 m .31509 .24947 L .30513 .26375 L p .692 .685 .839 r
F P
0 g
s
.30513 .26375 m .2882 .25436 L .29812 .23999 L p .692 .685 .839 r
F P
0 g
s
.52844 .43227 m .54471 .44117 L .53368 .45457 L p .69 .691 .846 r
F P
0 g
s
.53368 .45457 m .51745 .44576 L .52844 .43227 L p .69 .691 .846 r
F P
0 g
s
.33655 .30269 m .35342 .31198 L .34327 .32598 L p .691 .687 .841 r
F P
0 g
s
.34327 .32598 m .32645 .31677 L .33655 .30269 L p .691 .687 .841 r
F P
0 g
s
.3557 .94606 m .37251 .95339 L .36227 .96443 L p .682 .71 .87 r
F P
0 g
s
.36227 .96443 m .34551 .95717 L .3557 .94606 L p .682 .71 .87 r
F P
0 g
s
.42887 .17163 m .44547 .18133 L .43489 .19595 L p .692 .683 .837 r
F P
0 g
s
.43489 .19595 m .41834 .18633 L .42887 .17163 L p .692 .683 .837 r
F P
0 g
s
.64012 .945 m .65607 .95234 L .64452 .96339 L p .682 .71 .87 r
F P
0 g
s
.64452 .96339 m .62861 .95612 L .64012 .945 L p .682 .71 .87 r
F P
0 g
s
.49999 .17128 m .51637 .18098 L .50546 .1956 L p .692 .683 .837 r
F P
0 g
s
.50546 .1956 m .48912 .18599 L .49999 .17128 L p .692 .683 .837 r
F P
0 g
s
.32516 .23505 m .34207 .24456 L .33196 .25889 L p .692 .685 .839 r
F P
0 g
s
.33196 .25889 m .31509 .24947 L .32516 .23505 L p .692 .685 .839 r
F P
0 g
s
.44807 .81541 m .46461 .82314 L .45393 .8348 L p .684 .705 .863 r
F P
0 g
s
.45393 .8348 m .43744 .82713 L .44807 .81541 L p .684 .705 .863 r
F P
0 g
s
.49437 .13738 m .51078 .1472 L .49989 .16198 L p .692 .682 .836 r
F P
0 g
s
.49989 .16198 m .48353 .15226 L .49437 .13738 L p .692 .682 .836 r
F P
0 g
s
.55585 .42764 m .57206 .43657 L .56089 .45001 L p .69 .691 .846 r
F P
0 g
s
.56089 .45001 m .54471 .44117 L .55585 .42764 L p .69 .691 .846 r
F P
0 g
s
.29251 .29818 m .30953 .30751 L .29957 .32155 L p .691 .687 .841 r
F P
0 g
s
.29957 .32155 m .28259 .31231 L .29251 .29818 L p .691 .687 .841 r
F P
0 g
s
.38285 .94224 m .39961 .9496 L .38922 .96068 L p .682 .71 .87 r
F P
0 g
s
.38922 .96068 m .37251 .95339 L .38285 .94224 L p .682 .71 .87 r
F P
0 g
s
.28678 .26433 m .30383 .27376 L .29389 .28797 L p .691 .686 .84 r
F P
0 g
s
.29389 .28797 m .27689 .27863 L .28678 .26433 L p .691 .686 .84 r
F P
0 g
s
.45615 .16658 m .47269 .17631 L .46196 .19097 L p .692 .683 .837 r
F P
0 g
s
.46196 .19097 m .44547 .18133 L .45615 .16658 L p .692 .683 .837 r
F P
0 g
s
.66774 .94118 m .68363 .94854 L .67192 .95963 L p .682 .71 .87 r
F P
0 g
s
.67192 .95963 m .65607 .95234 L .66774 .94118 L p .682 .71 .87 r
F P
0 g
s
.29834 .42429 m .31536 .43324 L .30536 .44671 L p .69 .691 .846 r
F P
0 g
s
.30536 .44671 m .28839 .43785 L .29834 .42429 L p .69 .691 .846 r
F P
0 g
s
.36956 .42397 m .38637 .43292 L .37604 .44639 L p .69 .691 .846 r
F P
0 g
s
.37604 .44639 m .35928 .43753 L .36956 .42397 L p .69 .691 .846 r
F P
0 g
s
.33879 .93868 m .3557 .94606 L .34551 .95717 L p .682 .71 .87 r
F P
0 g
s
.34551 .95717 m .32864 .94986 L .33879 .93868 L p .682 .71 .87 r
F P
0 g
s
.4814 .93815 m .49788 .94553 L .48703 .95664 L p .682 .71 .87 r
F P
0 g
s
.48703 .95664 m .47059 .94933 L .4814 .93815 L p .682 .71 .87 r
F P
0 g
s
.62408 .93762 m .64012 .945 L .62861 .95612 L p .682 .71 .87 r
F P
0 g
s
.62861 .95612 m .6126 .94881 L .62408 .93762 L p .682 .71 .87 r
F P
0 g
s
.48351 .16151 m .49999 .17128 L .48912 .18599 L p .692 .683 .837 r
F P
0 g
s
.48912 .18599 m .47269 .17631 L .48351 .16151 L p .692 .683 .837 r
F P
0 g
s
.32545 .41964 m .34242 .42861 L .33228 .44213 L p .69 .691 .846 r
F P
0 g
s
.33228 .44213 m .31536 .43324 L .32545 .41964 L p .69 .691 .846 r
F P
0 g
s
.27538 .2888 m .29251 .29818 L .28259 .31231 L p .691 .687 .841 r
F P
0 g
s
.28259 .31231 m .26551 .30302 L .27538 .2888 L p .691 .687 .841 r
F P
0 g
s
.34675 .28847 m .36366 .29785 L .35342 .31198 L p .691 .687 .841 r
F P
0 g
s
.35342 .31198 m .33655 .30269 L .34675 .28847 L p .691 .687 .841 r
F P
0 g
s
.47011 .87093 m .48664 .87852 L .47583 .88996 L p .683 .708 .867 r
F P
0 g
s
.47583 .88996 m .45934 .88244 L .47011 .87093 L p .683 .708 .867 r
F P
0 g
s
.34103 .2545 m .35797 .26399 L .34775 .27829 L p .691 .686 .84 r
F P
0 g
s
.34775 .27829 m .33086 .26889 L .34103 .2545 L p .691 .686 .84 r
F P
0 g
s
.46446 .83727 m .48102 .84497 L .47022 .85657 L p .683 .706 .865 r
F P
0 g
s
.47022 .85657 m .45371 .84894 L .46446 .83727 L p .683 .706 .865 r
F P
0 g
s
.51096 .15643 m .52738 .16623 L .51637 .18098 L p .692 .683 .837 r
F P
0 g
s
.51637 .18098 m .49999 .17128 L .51096 .15643 L p .692 .683 .837 r
F P
0 g
s
.28121 .41529 m .29834 .42429 L .28839 .43785 L p .69 .691 .846 r
F P
0 g
s
.28839 .43785 m .27131 .42893 L .28121 .41529 L p .69 .691 .846 r
F P
0 g
s
.35265 .41497 m .36956 .42397 L .35928 .43753 L p .69 .691 .846 r
F P
0 g
s
.35928 .43753 m .34242 .42861 L .35265 .41497 L p .69 .691 .846 r
F P
0 g
s
.56709 .41399 m .58334 .423 L .57206 .43657 L p .69 .691 .846 r
F P
0 g
s
.57206 .43657 m .55585 .42764 L .56709 .41399 L p .69 .691 .846 r
F P
0 g
s
.30251 .28392 m .31959 .29333 L .30953 .30751 L p .691 .687 .841 r
F P
0 g
s
.30953 .30751 m .29251 .29818 L .30251 .28392 L p .691 .687 .841 r
F P
0 g
s
.32177 .93126 m .33879 .93868 L .32864 .94986 L p .682 .71 .87 r
F P
0 g
s
.32864 .94986 m .31167 .94251 L .32177 .93126 L p .682 .71 .87 r
F P
0 g
s
.26969 .3474 m .28687 .35662 L .27696 .3705 L p .69 .689 .844 r
F P
0 g
s
.27696 .3705 m .25983 .36137 L .26969 .3474 L p .69 .689 .844 r
F P
0 g
s
.39328 .93099 m .41009 .93842 L .39961 .9496 L p .682 .71 .87 r
F P
0 g
s
.39961 .9496 m .38285 .94224 L .39328 .93099 L p .682 .71 .87 r
F P
0 g
s
.46482 .93072 m .4814 .93815 L .47059 .94933 L p .682 .71 .87 r
F P
0 g
s
.47059 .94933 m .45405 .94198 L .46482 .93072 L p .682 .71 .87 r
F P
0 g
s
.60793 .93019 m .62408 .93762 L .6126 .94881 L p .682 .71 .87 r
F P
0 g
s
.6126 .94881 m .59649 .94145 L .60793 .93019 L p .682 .71 .87 r
F P
0 g
s
.67951 .92992 m .69544 .93735 L .68363 .94854 L p .682 .71 .87 r
F P
0 g
s
.68363 .94854 m .66774 .94118 L .67951 .92992 L p .682 .71 .87 r
F P
0 g
s
.26392 .3134 m .28113 .32273 L .27124 .33678 L p .691 .688 .843 r
F P
0 g
s
.27124 .33678 m .25408 .32754 L .26392 .3134 L p .691 .688 .843 r
F P
0 g
s
.38758 .8973 m .40441 .90483 L .39395 .91617 L p .682 .709 .868 r
F P
0 g
s
.39395 .91617 m .37717 .90871 L .38758 .8973 L p .682 .709 .868 r
F P
0 g
s
.37994 .41028 m .3968 .41931 L .38637 .43292 L p .69 .691 .846 r
F P
0 g
s
.38637 .43292 m .36956 .42397 L .37994 .41028 L p .69 .691 .846 r
F P
0 g
s
.32974 .27903 m .34675 .28847 L .33655 .30269 L p .691 .687 .841 r
F P
0 g
s
.33655 .30269 m .31959 .29333 L .32974 .27903 L p .691 .687 .841 r
F P
0 g
s
.45347 .86329 m .47011 .87093 L .45934 .88244 L p .683 .708 .867 r
F P
0 g
s
.45934 .88244 m .44275 .87487 L .45347 .86329 L p .683 .708 .867 r
F P
0 g
s
.54461 .278 m .56097 .28745 L .54977 .30168 L p .691 .687 .841 r
F P
0 g
s
.54977 .30168 m .53345 .29232 L .54461 .278 L p .691 .687 .841 r
F P
0 g
s
.34903 .9274 m .36599 .93484 L .3557 .94606 L p .682 .71 .87 r
F P
0 g
s
.3557 .94606 m .33879 .93868 L .34903 .9274 L p .682 .71 .87 r
F P
0 g
s
.49231 .92686 m .50884 .93431 L .49788 .94553 L p .682 .71 .87 r
F P
0 g
s
.49788 .94553 m .4814 .93815 L .49231 .92686 L p .682 .71 .87 r
F P
0 g
s
.63566 .92632 m .65175 .93377 L .64012 .945 L p .682 .71 .87 r
F P
0 g
s
.64012 .945 m .62408 .93762 L .63566 .92632 L p .682 .71 .87 r
F P
0 g
s
.26397 .40624 m .28121 .41529 L .27131 .42893 L p .69 .691 .846 r
F P
0 g
s
.27131 .42893 m .25412 .41996 L .26397 .40624 L p .69 .691 .846 r
F P
0 g
s
.55073 .40493 m .56709 .41399 L .55585 .42764 L p .69 .691 .846 r
F P
0 g
s
.55585 .42764 m .53953 .41867 L .55073 .40493 L p .69 .691 .846 r
F P
0 g
s
.53333 .2098 m .54974 .21946 L .53859 .23402 L p .692 .685 .839 r
F P
0 g
s
.53859 .23402 m .52222 .22445 L .53333 .2098 L p .692 .685 .839 r
F P
0 g
s
.35704 .27411 m .374 .28358 L .36366 .29785 L p .691 .687 .841 r
F P
0 g
s
.36366 .29785 m .34675 .28847 L .35704 .27411 L p .691 .687 .841 r
F P
0 g
s
.48098 .85931 m .49756 .86698 L .48664 .87852 L p .683 .708 .867 r
F P
0 g
s
.48664 .87852 m .47011 .87093 L .48098 .85931 L p .683 .708 .867 r
F P
0 g
s
.30464 .92379 m .32177 .93126 L .31167 .94251 L p .682 .71 .87 r
F P
0 g
s
.31167 .94251 m .29459 .93511 L .30464 .92379 L p .682 .71 .87 r
F P
0 g
s
.52769 .17564 m .54412 .18542 L .53299 .20014 L p .692 .684 .838 r
F P
0 g
s
.53299 .20014 m .51659 .19046 L .52769 .17564 L p .692 .684 .838 r
F P
0 g
s
.2524 .33812 m .26969 .3474 L .25983 .36137 L p .69 .689 .844 r
F P
0 g
s
.25983 .36137 m .24259 .35218 L .2524 .33812 L p .69 .689 .844 r
F P
0 g
s
.37638 .92352 m .39328 .93099 L .38285 .94224 L p .682 .71 .87 r
F P
0 g
s
.38285 .94224 m .36599 .93484 L .37638 .92352 L p .682 .71 .87 r
F P
0 g
s
.44813 .92325 m .46482 .93072 L .45405 .94198 L p .682 .71 .87 r
F P
0 g
s
.45405 .94198 m .43741 .93458 L .44813 .92325 L p .682 .71 .87 r
F P
0 g
s
.59168 .92271 m .60793 .93019 L .59649 .94145 L p .682 .71 .87 r
F P
0 g
s
.59649 .94145 m .58029 .93404 L .59168 .92271 L p .682 .71 .87 r
F P
0 g
s
.66348 .92244 m .67951 .92992 L .66774 .94118 L p .682 .71 .87 r
F P
0 g
s
.66774 .94118 m .65175 .93377 L .66348 .92244 L p .682 .71 .87 r
F P
0 g
s
.2912 .40152 m .30838 .41061 L .29834 .42429 L p .69 .691 .846 r
F P
0 g
s
.29834 .42429 m .28121 .41529 L .2912 .40152 L p .69 .691 .846 r
F P
0 g
s
.44244 .88945 m .45915 .89703 L .4484 .90844 L p .682 .709 .868 r
F P
0 g
s
.4484 .90844 m .43173 .90093 L .44244 .88945 L p .682 .709 .868 r
F P
0 g
s
.57843 .40021 m .59473 .4093 L .58334 .423 L p .69 .691 .846 r
F P
0 g
s
.58334 .423 m .56709 .41399 L .57843 .40021 L p .69 .691 .846 r
F P
0 g
s
.58044 .85505 m .59673 .86274 L .58534 .87432 L p .683 .708 .867 r
F P
0 g
s
.58534 .87432 m .56908 .8667 L .58044 .85505 L p .683 .708 .867 r
F P
0 g
s
.52815 .2685 m .54461 .278 L .53345 .29232 L p .691 .687 .841 r
F P
0 g
s
.53345 .29232 m .51703 .2829 L .52815 .2685 L p .691 .687 .841 r
F P
0 g
s
.27964 .3333 m .29687 .3426 L .28687 .35662 L p .69 .689 .844 r
F P
0 g
s
.28687 .35662 m .26969 .3474 L .27964 .3333 L p .69 .689 .844 r
F P
0 g
s
.40382 .91964 m .42066 .92713 L .41009 .93842 L p .682 .71 .87 r
F P
0 g
s
.41009 .93842 m .39328 .93099 L .40382 .91964 L p .682 .71 .87 r
F P
0 g
s
.5748 .82116 m .59113 .82896 L .57975 .84071 L p .683 .706 .865 r
F P
0 g
s
.57975 .84071 m .56347 .83298 L .5748 .82116 L p .683 .706 .865 r
F P
0 g
s
.24663 .39712 m .26397 .40624 L .25412 .41996 L p .69 .691 .846 r
F P
0 g
s
.25412 .41996 m .23683 .41093 L .24663 .39712 L p .69 .691 .846 r
F P
0 g
s
.6914 .91855 m .70736 .92605 L .69544 .93735 L p .682 .71 .87 r
F P
0 g
s
.69544 .93735 m .67951 .92992 L .6914 .91855 L p .682 .71 .87 r
F P
0 g
s
.39042 .39647 m .40732 .40558 L .3968 .41931 L p .69 .691 .846 r
F P
0 g
s
.3968 .41931 m .37994 .41028 L .39042 .39647 L p .69 .691 .846 r
F P
0 g
s
.53427 .39581 m .55073 .40493 L .53953 .41867 L p .69 .691 .846 r
F P
0 g
s
.53953 .41867 m .52312 .40963 L .53427 .39581 L p .69 .691 .846 r
F P
0 g
s
.51682 .20007 m .53333 .2098 L .52222 .22445 L p .692 .685 .839 r
F P
0 g
s
.52222 .22445 m .50575 .21481 L .51682 .20007 L p .692 .685 .839 r
F P
0 g
s
.24082 .36298 m .25819 .3722 L .24836 .38609 L p .69 .69 .845 r
F P
0 g
s
.24836 .38609 m .23104 .37695 L .24082 .36298 L p .69 .69 .845 r
F P
0 g
s
.28741 .91628 m .30464 .92379 L .29459 .93511 L p .682 .71 .87 r
F P
0 g
s
.29459 .93511 m .27741 .92767 L .28741 .91628 L p .682 .71 .87 r
F P
0 g
s
.55587 .26355 m .57227 .27309 L .56097 .28745 L p .691 .687 .841 r
F P
0 g
s
.56097 .28745 m .54461 .278 L .55587 .26355 L p .691 .687 .841 r
F P
0 g
s
.43134 .91574 m .44813 .92325 L .43741 .93458 L p .682 .71 .87 r
F P
0 g
s
.43741 .93458 m .42066 .92713 L .43134 .91574 L p .682 .71 .87 r
F P
0 g
s
.37894 .32812 m .39589 .33745 L .38541 .35152 L p .69 .689 .844 r
F P
0 g
s
.38541 .35152 m .36851 .34227 L .37894 .32812 L p .69 .689 .844 r
F P
0 g
s
.50333 .91547 m .5199 .92298 L .50884 .93431 L p .682 .71 .87 r
F P
0 g
s
.50884 .93431 m .49231 .92686 L .50333 .91547 L p .682 .71 .87 r
F P
0 g
s
.57534 .91519 m .59168 .92271 L .58029 .93404 L p .682 .71 .87 r
F P
0 g
s
.58029 .93404 m .56398 .92659 L .57534 .91519 L p .682 .71 .87 r
F P
0 g
s
.37319 .29389 m .39017 .30334 L .37971 .31757 L p .691 .688 .843 r
F P
0 g
s
.37971 .31757 m .36278 .30821 L .37319 .29389 L p .691 .688 .843 r
F P
0 g
s
.49765 .88154 m .51424 .88917 L .5032 .90066 L p .682 .709 .868 r
F P
0 g
s
.5032 .90066 m .48665 .89311 L .49765 .88154 L p .682 .709 .868 r
F P
0 g
s
.25833 .6524 m .27567 .66074 L .26574 .6733 L p .686 .7 .857 r
F P
0 g
s
.26574 .6733 m .24845 .66504 L .25833 .6524 L p .686 .7 .857 r
F P
0 g
s
.54455 .19501 m .56101 .20477 L .54974 .21946 L p .692 .685 .839 r
F P
0 g
s
.54974 .21946 m .53333 .2098 L .54455 .19501 L p .692 .685 .839 r
F P
0 g
s
.56404 .84731 m .58044 .85505 L .56908 .8667 L p .683 .708 .867 r
F P
0 g
s
.56908 .8667 m .55272 .85904 L .56404 .84731 L p .683 .708 .867 r
F P
0 g
s
.51158 .25893 m .52815 .2685 L .51703 .2829 L p .691 .687 .841 r
F P
0 g
s
.51703 .2829 m .50051 .27343 L .51158 .25893 L p .691 .687 .841 r
F P
0 g
s
.31479 .91237 m .33196 .91991 L .32177 .93126 L p .682 .71 .87 r
F P
0 g
s
.32177 .93126 m .30464 .92379 L .31479 .91237 L p .682 .71 .87 r
F P
0 g
s
.45896 .91182 m .47569 .91937 L .46482 .93072 L p .682 .71 .87 r
F P
0 g
s
.46482 .93072 m .44813 .92325 L .45896 .91182 L p .682 .71 .87 r
F P
0 g
s
.60319 .91128 m .61948 .91882 L .60793 .93019 L p .682 .71 .87 r
F P
0 g
s
.60793 .93019 m .59168 .92271 L .60319 .91128 L p .682 .71 .87 r
F P
0 g
s
.5059 .22463 m .52248 .2343 L .51139 .24887 L p .691 .686 .84 r
F P
0 g
s
.51139 .24887 m .49485 .23929 L .5059 .22463 L p .691 .686 .84 r
F P
0 g
s
.22918 .38795 m .24663 .39712 L .23683 .41093 L p .69 .691 .846 r
F P
0 g
s
.23683 .41093 m .21943 .40185 L .22918 .38795 L p .69 .691 .846 r
F P
0 g
s
.30129 .38762 m .31852 .39679 L .30838 .41061 L p .69 .691 .846 r
F P
0 g
s
.30838 .41061 m .2912 .40152 L .30129 .38762 L p .69 .691 .846 r
F P
0 g
s
.37341 .38729 m .39042 .39647 L .37994 .41028 L p .69 .691 .846 r
F P
0 g
s
.37994 .41028 m .36298 .40119 L .37341 .38729 L p .69 .691 .846 r
F P
0 g
s
.51771 .38663 m .53427 .39581 L .52312 .40963 L p .69 .691 .846 r
F P
0 g
s
.52312 .40963 m .5066 .40054 L .51771 .38663 L p .69 .691 .846 r
F P
0 g
s
.58988 .3863 m .60622 .39548 L .59473 .4093 L p .69 .691 .846 r
F P
0 g
s
.59473 .4093 m .57843 .40021 L .58988 .3863 L p .69 .691 .846 r
F P
0 g
s
.29549 .35336 m .31274 .36264 L .30263 .37662 L p .69 .69 .845 r
F P
0 g
s
.30263 .37662 m .28542 .36743 L .29549 .35336 L p .69 .69 .845 r
F P
0 g
s
.5919 .84328 m .60824 .85105 L .59673 .86274 L p .683 .708 .867 r
F P
0 g
s
.59673 .86274 m .58044 .85505 L .5919 .84328 L p .683 .708 .867 r
F P
0 g
s
.27007 .90872 m .28741 .91628 L .27741 .92767 L p .682 .71 .87 r
F P
0 g
s
.27741 .92767 m .26012 .92018 L .27007 .90872 L p .682 .71 .87 r
F P
0 g
s
.23503 .51585 m .25247 .52463 L .24264 .53786 L p .688 .695 .852 r
F P
0 g
s
.24264 .53786 m .22524 .52916 L .23503 .51585 L p .688 .695 .852 r
F P
0 g
s
.36188 .31872 m .37894 .32812 L .36851 .34227 L p .69 .689 .844 r
F P
0 g
s
.36851 .34227 m .35149 .33296 L .36188 .31872 L p .69 .689 .844 r
F P
0 g
s
.48666 .9079 m .50333 .91547 L .49231 .92686 L p .682 .71 .87 r
F P
0 g
s
.49231 .92686 m .47569 .91937 L .48666 .9079 L p .682 .71 .87 r
F P
0 g
s
.55889 .90763 m .57534 .91519 L .56398 .92659 L p .682 .71 .87 r
F P
0 g
s
.56398 .92659 m .54757 .9191 L .55889 .90763 L p .682 .71 .87 r
F P
0 g
s
.25653 .38318 m .27392 .39238 L .26397 .40624 L p .69 .691 .846 r
F P
0 g
s
.26397 .40624 m .24663 .39712 L .25653 .38318 L p .69 .691 .846 r
F P
0 g
s
.70339 .90708 m .7194 .91465 L .70736 .92605 L p .682 .71 .87 r
F P
0 g
s
.70736 .92605 m .6914 .91855 L .70339 .90708 L p .682 .71 .87 r
F P
0 g
s
.40099 .38252 m .41794 .39172 L .40732 .40558 L p .69 .691 .846 r
F P
0 g
s
.40732 .40558 m .39042 .39647 L .40099 .38252 L p .69 .691 .846 r
F P
0 g
s
.55322 .87359 m .56969 .88127 L .55835 .89283 L p .682 .709 .868 r
F P
0 g
s
.55835 .89283 m .54192 .88523 L .55322 .87359 L p .682 .709 .868 r
F P
0 g
s
.24088 .64401 m .25833 .6524 L .24845 .66504 L p .686 .7 .857 r
F P
0 g
s
.24845 .66504 m .23106 .65673 L .24088 .64401 L p .686 .7 .857 r
F P
0 g
s
.54553 .38185 m .56203 .39106 L .55073 .40493 L p .69 .691 .846 r
F P
0 g
s
.55073 .40493 m .53427 .39581 L .54553 .38185 L p .69 .691 .846 r
F P
0 g
s
.22334 .44736 m .24084 .45637 L .23105 .46993 L p .689 .693 .849 r
F P
0 g
s
.23105 .46993 m .2136 .46101 L .22334 .44736 L p .689 .693 .849 r
F P
0 g
s
.49491 .24931 m .51158 .25893 L .50051 .27343 L p .691 .687 .841 r
F P
0 g
s
.50051 .27343 m .48389 .2639 L .49491 .24931 L p .691 .687 .841 r
F P
0 g
s
.21748 .41306 m .23502 .42218 L .22524 .43591 L p .689 .692 .848 r
F P
0 g
s
.22524 .43591 m .20777 .42688 L .21748 .41306 L p .689 .692 .848 r
F P
0 g
s
.56724 .24896 m .58368 .25859 L .57227 .27309 L p .691 .687 .841 r
F P
0 g
s
.57227 .27309 m .55587 .26355 L .56724 .24896 L p .691 .687 .841 r
F P
0 g
s
.38947 .31383 m .40647 .32326 L .39589 .33745 L p .69 .689 .844 r
F P
0 g
s
.39589 .33745 m .37894 .32812 L .38947 .31383 L p .69 .689 .844 r
F P
0 g
s
.51445 .90396 m .53107 .91155 L .5199 .92298 L p .682 .71 .87 r
F P
0 g
s
.5199 .92298 m .50333 .91547 L .51445 .90396 L p .682 .71 .87 r
F P
0 g
s
.56156 .21454 m .57803 .22428 L .56664 .23894 L p .691 .686 .84 r
F P
0 g
s
.56664 .23894 m .55021 .2293 L .56156 .21454 L p .691 .686 .84 r
F P
0 g
s
.28396 .3784 m .30129 .38762 L .2912 .40152 L p .69 .691 .846 r
F P
0 g
s
.2912 .40152 m .27392 .39238 L .28396 .3784 L p .69 .691 .846 r
F P
0 g
s
.3563 .37806 m .37341 .38729 L .36298 .40119 L p .69 .691 .846 r
F P
0 g
s
.36298 .40119 m .34592 .39205 L .3563 .37806 L p .69 .691 .846 r
F P
0 g
s
.50104 .3774 m .51771 .38663 L .5066 .40054 L p .69 .691 .846 r
F P
0 g
s
.5066 .40054 m .48998 .39139 L .50104 .3774 L p .69 .691 .846 r
F P
0 g
s
.2683 .63964 m .28569 .64806 L .27567 .66074 L p .686 .7 .857 r
F P
0 g
s
.27567 .66074 m .25833 .6524 L .2683 .63964 L p .686 .7 .857 r
F P
0 g
s
.57344 .37706 m .58988 .3863 L .57843 .40021 L p .69 .691 .846 r
F P
0 g
s
.57843 .40021 m .56203 .39106 L .57344 .37706 L p .69 .691 .846 r
F P
0 g
s
.35051 .34368 m .36765 .35302 L .35724 .3671 L p .69 .69 .845 r
F P
0 g
s
.35724 .3671 m .34015 .35784 L .35051 .34368 L p .69 .69 .845 r
F P
0 g
s
.25263 .90111 m .27007 .90872 L .26012 .92018 L p .682 .71 .87 r
F P
0 g
s
.26012 .92018 m .24273 .91264 L .25263 .90111 L p .682 .71 .87 r
F P
0 g
s
.21747 .50702 m .23503 .51585 L .22524 .52916 L p .688 .695 .852 r
F P
0 g
s
.22524 .52916 m .20774 .52041 L .21747 .50702 L p .688 .695 .852 r
F P
0 g
s
.52276 .2443 m .53936 .25396 L .52815 .2685 L p .691 .687 .841 r
F P
0 g
s
.52815 .2685 m .51158 .25893 L .52276 .2443 L p .691 .687 .841 r
F P
0 g
s
.32503 .90084 m .34225 .90845 L .33196 .91991 L p .682 .71 .87 r
F P
0 g
s
.33196 .91991 m .31479 .91237 L .32503 .90084 L p .682 .71 .87 r
F P
0 g
s
.54234 .90001 m .55889 .90763 L .54757 .9191 L p .682 .71 .87 r
F P
0 g
s
.54757 .9191 m .53107 .91155 L .54234 .90001 L p .682 .71 .87 r
F P
0 g
s
.48961 .30858 m .50632 .31804 L .49526 .33229 L p .69 .689 .844 r
F P
0 g
s
.49526 .33229 m .47858 .32292 L .48961 .30858 L p .69 .689 .844 r
F P
0 g
s
.6148 .89974 m .63113 .90735 L .61948 .91882 L p .682 .71 .87 r
F P
0 g
s
.61948 .91882 m .60319 .91128 L .6148 .89974 L p .682 .71 .87 r
F P
0 g
s
.68729 .89946 m .70339 .90708 L .6914 .91855 L p .682 .71 .87 r
F P
0 g
s
.6914 .91855 m .67533 .91101 L .68729 .89946 L p .682 .71 .87 r
F P
0 g
s
.31147 .37359 m .32875 .38285 L .31852 .39679 L p .69 .691 .846 r
F P
0 g
s
.31852 .39679 m .30129 .38762 L .31147 .37359 L p .69 .691 .846 r
F P
0 g
s
.48388 .27412 m .50062 .28369 L .48958 .29811 L p .691 .688 .843 r
F P
0 g
s
.48958 .29811 m .47288 .28863 L .48388 .27412 L p .691 .688 .843 r
F P
0 g
s
.60914 .86559 m .6255 .87331 L .61386 .88495 L p .682 .709 .868 r
F P
0 g
s
.61386 .88495 m .59755 .8773 L .60914 .86559 L p .682 .709 .868 r
F P
0 g
s
.22332 .63557 m .24088 .64401 L .23106 .65673 L p .686 .7 .857 r
F P
0 g
s
.23106 .65673 m .21355 .64836 L .22332 .63557 L p .686 .7 .857 r
F P
0 g
s
.20573 .4383 m .22334 .44736 L .2136 .46101 L p .689 .693 .849 r
F P
0 g
s
.2136 .46101 m .19604 .45203 L .20573 .4383 L p .689 .693 .849 r
F P
0 g
s
.60144 .37225 m .61782 .38152 L .60622 .39548 L p .69 .691 .846 r
F P
0 g
s
.60622 .39548 m .58988 .3863 L .60144 .37225 L p .69 .691 .846 r
F P
0 g
s
.28012 .89715 m .29751 .90478 L .28741 .91628 L p .682 .71 .87 r
F P
0 g
s
.28741 .91628 m .27007 .90872 L .28012 .89715 L p .682 .71 .87 r
F P
0 g
s
.24491 .50242 m .26241 .51128 L .25247 .52463 L p .688 .695 .852 r
F P
0 g
s
.25247 .52463 m .23503 .51585 L .24491 .50242 L p .688 .695 .852 r
F P
0 g
s
.55069 .23928 m .56724 .24896 L .55587 .26355 L p .691 .687 .841 r
F P
0 g
s
.55587 .26355 m .53936 .25396 L .55069 .23928 L p .691 .687 .841 r
F P
0 g
s
.57031 .89605 m .5868 .90369 L .57534 .91519 L p .682 .71 .87 r
F P
0 g
s
.57534 .91519 m .55889 .90763 L .57031 .89605 L p .682 .71 .87 r
F P
0 g
s
.7155 .8955 m .73155 .90314 L .7194 .91465 L p .682 .71 .87 r
F P
0 g
s
.7194 .91465 m .70339 .90708 L .7155 .8955 L p .682 .71 .87 r
F P
0 g
s
.33908 .36877 m .3563 .37806 L .34592 .39205 L p .69 .691 .846 r
F P
0 g
s
.34592 .39205 m .32875 .38285 L .33908 .36877 L p .69 .691 .846 r
F P
0 g
s
.41167 .36844 m .42866 .37773 L .41794 .39172 L p .69 .691 .846 r
F P
0 g
s
.41794 .39172 m .40099 .38252 L .41167 .36844 L p .69 .691 .846 r
F P
0 g
s
.48427 .3681 m .50104 .3774 L .48998 .39139 L p .69 .691 .846 r
F P
0 g
s
.48998 .39139 m .47325 .38219 L .48427 .3681 L p .69 .691 .846 r
F P
0 g
s
.23317 .43359 m .25073 .44268 L .24084 .45637 L p .689 .693 .849 r
F P
0 g
s
.24084 .45637 m .22334 .44736 L .23317 .43359 L p .689 .693 .849 r
F P
0 g
s
.40589 .33394 m .42291 .34335 L .41221 .35751 L p .69 .69 .845 r
F P
0 g
s
.41221 .35751 m .39524 .34819 L .40589 .33394 L p .69 .69 .845 r
F P
0 g
s
.23507 .89346 m .25263 .90111 L .24273 .91264 L p .682 .71 .87 r
F P
0 g
s
.24273 .91264 m .22522 .90506 L .23507 .89346 L p .682 .71 .87 r
F P
0 g
s
.1998 .49813 m .21747 .50702 L .20774 .52041 L p .688 .695 .852 r
F P
0 g
s
.20774 .52041 m .19012 .5116 L .1998 .49813 L p .688 .695 .852 r
F P
0 g
s
.3077 .89318 m .32503 .90084 L .31479 .91237 L p .682 .71 .87 r
F P
0 g
s
.31479 .91237 m .29751 .90478 L .3077 .89318 L p .682 .71 .87 r
F P
0 g
s
.57871 .23424 m .5952 .24395 L .58368 .25859 L p .691 .687 .841 r
F P
0 g
s
.58368 .25859 m .56724 .24896 L .57871 .23424 L p .691 .687 .841 r
F P
0 g
s
.47278 .29907 m .48961 .30858 L .47858 .32292 L p .69 .689 .844 r
F P
0 g
s
.47858 .32292 m .4618 .31349 L .47278 .29907 L p .69 .689 .844 r
F P
0 g
s
.59837 .89207 m .6148 .89974 L .60319 .91128 L p .682 .71 .87 r
F P
0 g
s
.60319 .91128 m .5868 .90369 L .59837 .89207 L p .682 .71 .87 r
F P
0 g
s
.19391 .46367 m .2116 .47268 L .20189 .48624 L p .688 .694 .85 r
F P
0 g
s
.20189 .48624 m .18425 .47732 L .19391 .46367 L p .688 .694 .85 r
F P
0 g
s
.67108 .8918 m .68729 .89946 L .67533 .91101 L p .682 .71 .87 r
F P
0 g
s
.67533 .91101 m .65917 .90341 L .67108 .8918 L p .682 .71 .87 r
F P
0 g
s
.36678 .36394 m .38394 .37326 L .37341 .38729 L p .69 .691 .846 r
F P
0 g
s
.37341 .38729 m .3563 .37806 L .36678 .36394 L p .69 .691 .846 r
F P
0 g
s
.22331 .82494 m .24092 .83282 L .23107 .84468 L p .683 .708 .867 r
F P
0 g
s
.23107 .84468 m .21351 .83688 L .22331 .82494 L p .683 .708 .867 r
F P
0 g
s
.20566 .62707 m .22332 .63557 L .21355 .64836 L p .686 .7 .857 r
F P
0 g
s
.21355 .64836 m .19594 .63995 L .20566 .62707 L p .686 .7 .857 r
F P
0 g
s
.51221 .36327 m .52892 .37259 L .51771 .38663 L p .69 .691 .846 r
F P
0 g
s
.51771 .38663 m .50104 .3774 L .51221 .36327 L p .69 .691 .846 r
F P
0 g
s
.27836 .62676 m .2958 .63526 L .28569 .64806 L p .686 .7 .857 r
F P
0 g
s
.28569 .64806 m .2683 .63964 L .27836 .62676 L p .686 .7 .857 r
F P
0 g
s
.66543 .85753 m .68166 .86531 L .66973 .87702 L p .682 .709 .868 r
F P
0 g
s
.66973 .87702 m .65354 .86932 L .66543 .85753 L p .682 .709 .868 r
F P
0 g
s
.33537 .88919 m .35264 .89688 L .34225 .90845 L p .682 .71 .87 r
F P
0 g
s
.34225 .90845 m .32503 .90084 L .33537 .88919 L p .682 .71 .87 r
F P
0 g
s
.50073 .29411 m .5175 .30366 L .50632 .31804 L p .69 .689 .844 r
F P
0 g
s
.50632 .31804 m .48961 .30858 L .50073 .29411 L p .69 .689 .844 r
F P
0 g
s
.62653 .88808 m .6429 .89577 L .63113 .90735 L p .682 .71 .87 r
F P
0 g
s
.63113 .90735 m .6148 .89974 L .62653 .88808 L p .682 .71 .87 r
F P
0 g
s
.39457 .35909 m .41167 .36844 L .40099 .38252 L p .69 .691 .846 r
F P
0 g
s
.40099 .38252 m .38394 .37326 L .39457 .35909 L p .69 .691 .846 r
F P
0 g
s
.4674 .35875 m .48427 .3681 L .47325 .38219 L p .69 .691 .846 r
F P
0 g
s
.47325 .38219 m .45642 .37292 L .4674 .35875 L p .69 .691 .846 r
F P
0 g
s
.23319 .62265 m .2508 .63117 L .24088 .64401 L p .686 .7 .857 r
F P
0 g
s
.24088 .64401 m .22332 .63557 L .23319 .62265 L p .686 .7 .857 r
F P
0 g
s
.61311 .35808 m .62953 .36743 L .61782 .38152 L p .69 .691 .846 r
F P
0 g
s
.61782 .38152 m .60144 .37225 L .61311 .35808 L p .69 .691 .846 r
F P
0 g
s
.2174 .88575 m .23507 .89346 L .22522 .90506 L p .682 .71 .87 r
F P
0 g
s
.22522 .90506 m .20761 .89743 L .2174 .88575 L p .682 .71 .87 r
F P
0 g
s
.46163 .32414 m .47853 .3336 L .46753 .34786 L p .69 .69 .845 r
F P
0 g
s
.46753 .34786 m .45068 .33848 L .46163 .32414 L p .69 .69 .845 r
F P
0 g
s
.18202 .48918 m .1998 .49813 L .19012 .5116 L p .688 .695 .852 r
F P
0 g
s
.19012 .5116 m .1724 .50274 L .18202 .48918 L p .688 .695 .852 r
F P
0 g
s
.25488 .48886 m .27243 .4978 L .26241 .51128 L p .688 .695 .852 r
F P
0 g
s
.26241 .51128 m .24491 .50242 L .25488 .48886 L p .688 .695 .852 r
F P
0 g
s
.65478 .88408 m .67108 .8918 L .65917 .90341 L p .682 .71 .87 r
F P
0 g
s
.65917 .90341 m .6429 .89577 L .65478 .88408 L p .682 .71 .87 r
F P
0 g
s
.24899 .45429 m .26657 .46335 L .25657 .477 L p .688 .694 .85 r
F P
0 g
s
.25657 .477 m .23904 .46802 L .24899 .45429 L p .688 .694 .85 r
F P
0 g
s
.60171 .2888 m .61819 .29838 L .60652 .31281 L p .69 .689 .844 r
F P
0 g
s
.60652 .31281 m .59009 .30332 L .60171 .2888 L p .69 .689 .844 r
F P
0 g
s
.72773 .8838 m .74381 .89152 L .73155 .90314 L p .682 .71 .87 r
F P
0 g
s
.73155 .90314 m .7155 .8955 L .72773 .8838 L p .682 .71 .87 r
F P
0 g
s
.42245 .35422 m .43949 .3636 L .42866 .37773 L p .69 .691 .846 r
F P
0 g
s
.42866 .37773 m .41167 .36844 L .42245 .35422 L p .69 .691 .846 r
F P
0 g
s
.18788 .61852 m .20566 .62707 L .19594 .63995 L p .686 .7 .857 r
F P
0 g
s
.19594 .63995 m .17821 .63148 L .18788 .61852 L p .686 .7 .857 r
F P
0 g
s
.26081 .61821 m .27836 .62676 L .2683 .63964 L p .686 .7 .857 r
F P
0 g
s
.2683 .63964 m .2508 .63117 L .26081 .61821 L p .686 .7 .857 r
F P
0 g
s
.59601 .2541 m .61251 .2638 L .60086 .2784 L p .691 .688 .843 r
F P
0 g
s
.60086 .2784 m .5844 .2688 L .59601 .2541 L p .691 .688 .843 r
F P
0 g
s
.24501 .88174 m .26262 .88947 L .25263 .90111 L p .682 .71 .87 r
F P
0 g
s
.25263 .90111 m .23507 .89346 L .24501 .88174 L p .682 .71 .87 r
F P
0 g
s
.20957 .48452 m .22729 .4935 L .21747 .50702 L p .688 .695 .852 r
F P
0 g
s
.21747 .50702 m .1998 .49813 L .20957 .48452 L p .688 .695 .852 r
F P
0 g
s
.17602 .54942 m .19385 .5582 L .18418 .57142 L p .687 .698 .854 r
F P
0 g
s
.18418 .57142 m .1664 .56272 L .17602 .54942 L p .687 .698 .854 r
F P
0 g
s
.68312 .88007 m .69936 .88781 L .68729 .89946 L p .682 .71 .87 r
F P
0 g
s
.68729 .89946 m .67108 .8918 L .68312 .88007 L p .682 .71 .87 r
F P
0 g
s
.45042 .34934 m .4674 .35875 L .45642 .37292 L p .69 .691 .846 r
F P
0 g
s
.45642 .37292 m .43949 .3636 L .45042 .34934 L p .69 .691 .846 r
F P
0 g
s
.17008 .51482 m .18794 .52371 L .17829 .5371 L p .687 .696 .853 r
F P
0 g
s
.17829 .5371 m .16048 .52829 L .17008 .51482 L p .687 .696 .853 r
F P
0 g
s
.2332 .81289 m .25087 .82084 L .24092 .83282 L p .683 .708 .867 r
F P
0 g
s
.24092 .83282 m .22331 .82494 L .2332 .81289 L p .683 .708 .867 r
F P
0 g
s
.52349 .349 m .54025 .35841 L .52892 .37259 L p .69 .691 .846 r
F P
0 g
s
.52892 .37259 m .51221 .36327 L .52349 .349 L p .69 .691 .846 r
F P
0 g
s
.28852 .61376 m .30601 .62234 L .2958 .63526 L p .686 .7 .857 r
F P
0 g
s
.2958 .63526 m .27836 .62676 L .28852 .61376 L p .686 .7 .857 r
F P
0 g
s
.59658 .34866 m .61311 .35808 L .60144 .37225 L p .69 .691 .846 r
F P
0 g
s
.60144 .37225 m .58496 .36293 L .59658 .34866 L p .69 .691 .846 r
F P
0 g
s
.19963 .878 m .2174 .88575 L .20761 .89743 L p .682 .71 .87 r
F P
0 g
s
.20761 .89743 m .18989 .88975 L .19963 .878 L p .682 .71 .87 r
F P
0 g
s
.51773 .31427 m .53451 .3238 L .52321 .33814 L p .69 .69 .845 r
F P
0 g
s
.52321 .33814 m .50648 .32871 L .51773 .31427 L p .69 .69 .845 r
F P
0 g
s
.23722 .47985 m .25488 .48886 L .24491 .50242 L p .688 .695 .852 r
F P
0 g
s
.24491 .50242 m .22729 .4935 L .23722 .47985 L p .688 .695 .852 r
F P
0 g
s
.34581 .87744 m .36313 .88519 L .35264 .89688 L p .682 .71 .87 r
F P
0 g
s
.35264 .89688 m .33537 .88919 L .34581 .87744 L p .682 .71 .87 r
F P
0 g
s
.58514 .27915 m .60171 .2888 L .59009 .30332 L p .69 .689 .844 r
F P
0 g
s
.59009 .30332 m .57355 .29377 L .58514 .27915 L p .69 .689 .844 r
F P
0 g
s
.71155 .87604 m .72773 .8838 L .7155 .8955 L p .682 .71 .87 r
F P
0 g
s
.7155 .8955 m .69936 .88781 L .71155 .87604 L p .682 .71 .87 r
F P
0 g
s
.16999 .60991 m .18788 .61852 L .17821 .63148 L p .686 .7 .857 r
F P
0 g
s
.17821 .63148 m .16038 .62296 L .16999 .60991 L p .686 .7 .857 r
F P
0 g
s
.47848 .34444 m .4954 .35389 L .48427 .3681 L p .69 .691 .846 r
F P
0 g
s
.48427 .3681 m .4674 .35875 L .47848 .34444 L p .69 .691 .846 r
F P
0 g
s
.62489 .34376 m .64135 .35321 L .62953 .36743 L p .69 .691 .846 r
F P
0 g
s
.62953 .36743 m .61311 .35808 L .62489 .34376 L p .69 .691 .846 r
F P
0 g
s
.26495 .47516 m .28255 .4842 L .27243 .4978 L p .688 .695 .852 r
F P
0 g
s
.27243 .4978 m .25488 .48886 L .26495 .47516 L p .688 .695 .852 r
F P
0 g
s
.15807 .54059 m .17602 .54942 L .1664 .56272 L p .687 .698 .854 r
F P
0 g
s
.1664 .56272 m .14851 .55397 L .15807 .54059 L p .687 .698 .854 r
F P
0 g
s
.61345 .27413 m .62997 .28381 L .61819 .29838 L p .69 .689 .844 r
F P
0 g
s
.61819 .29838 m .60171 .2888 L .61345 .27413 L p .69 .689 .844 r
F P
0 g
s
.74008 .872 m .75619 .87979 L .74381 .89152 L p .682 .71 .87 r
F P
0 g
s
.74381 .89152 m .72773 .8838 L .74008 .872 L p .682 .71 .87 r
F P
0 g
s
.19763 .60544 m .21547 .61407 L .20566 .62707 L p .686 .7 .857 r
F P
0 g
s
.20566 .62707 m .18788 .61852 L .19763 .60544 L p .686 .7 .857 r
F P
0 g
s
.50663 .33953 m .52349 .349 L .51221 .36327 L p .69 .691 .846 r
F P
0 g
s
.51221 .36327 m .4954 .35389 L .50663 .33953 L p .69 .691 .846 r
F P
0 g
s
.57995 .33919 m .59658 .34866 L .58496 .36293 L p .69 .691 .846 r
F P
0 g
s
.58496 .36293 m .56837 .35355 L .57995 .33919 L p .69 .691 .846 r
F P
0 g
s
.18174 .8702 m .19963 .878 L .18989 .88975 L p .682 .71 .87 r
F P
0 g
s
.18989 .88975 m .17205 .88202 L .18174 .8702 L p .682 .71 .87 r
F P
0 g
s
.25505 .86992 m .27271 .87772 L .26262 .88947 L p .682 .71 .87 r
F P
0 g
s
.26262 .88947 m .24501 .88174 L .25505 .86992 L p .682 .71 .87 r
F P
0 g
s
.32837 .86963 m .34581 .87744 L .33537 .88919 L p .682 .71 .87 r
F P
0 g
s
.33537 .88919 m .31799 .88146 L .32837 .86963 L p .682 .71 .87 r
F P
0 g
s
.57421 .30434 m .59086 .31393 L .57926 .32837 L p .69 .69 .845 r
F P
0 g
s
.57926 .32837 m .56264 .31887 L .57421 .30434 L p .69 .69 .845 r
F P
0 g
s
.18573 .53599 m .20362 .54485 L .19385 .5582 L p .687 .698 .854 r
F P
0 g
s
.19385 .5582 m .17602 .54942 L .18573 .53599 L p .687 .698 .854 r
F P
0 g
s
.24912 .83533 m .26681 .84325 L .25675 .85517 L p .682 .709 .868 r
F P
0 g
s
.25675 .85517 m .23911 .84733 L .24912 .83533 L p .682 .709 .868 r
F P
0 g
s
.15198 .60126 m .16999 .60991 L .16038 .62296 L p .686 .7 .857 r
F P
0 g
s
.16038 .62296 m .14243 .61438 L .15198 .60126 L p .686 .7 .857 r
F P
0 g
s
.53488 .3346 m .55168 .3441 L .54025 .35841 L p .69 .691 .846 r
F P
0 g
s
.54025 .35841 m .52349 .349 L .53488 .3346 L p .69 .691 .846 r
F P
0 g
s
.29878 .60063 m .31632 .60929 L .30601 .62234 L p .686 .7 .857 r
F P
0 g
s
.30601 .62234 m .28852 .61376 L .29878 .60063 L p .686 .7 .857 r
F P
0 g
s
.146 .5665 m .16403 .57527 L .15445 .58848 L p .687 .699 .856 r
F P
0 g
s
.15445 .58848 m .13647 .57979 L .146 .5665 L p .687 .699 .856 r
F P
0 g
s
.20946 .86614 m .22729 .87396 L .2174 .88575 L p .682 .71 .87 r
F P
0 g
s
.2174 .88575 m .19963 .878 L .20946 .86614 L p .682 .71 .87 r
F P
0 g
s
.35635 .86557 m .37372 .8734 L .36313 .88519 L p .682 .71 .87 r
F P
0 g
s
.36313 .88519 m .34581 .87744 L .35635 .86557 L p .682 .71 .87 r
F P
0 g
s
.28696 .53106 m .30456 .53995 L .2943 .55334 L p .687 .698 .854 r
F P
0 g
s
.2943 .55334 m .27675 .54453 L .28696 .53106 L p .687 .698 .854 r
F P
0 g
s
.56322 .32966 m .57995 .33919 L .56837 .35355 L p .69 .691 .846 r
F P
0 g
s
.56837 .35355 m .55168 .3441 L .56322 .32966 L p .69 .691 .846 r
F P
0 g
s
.28104 .49622 m .29867 .50522 L .28843 .51879 L p .687 .696 .853 r
F P
0 g
s
.28843 .51879 m .27085 .50987 L .28104 .49622 L p .687 .696 .853 r
F P
0 g
s
.63678 .32931 m .65329 .33885 L .64135 .35321 L p .69 .691 .846 r
F P
0 g
s
.64135 .35321 m .62489 .34376 L .63678 .32931 L p .69 .691 .846 r
F P
0 g
s
.16373 .86235 m .18174 .8702 L .17205 .88202 L p .682 .71 .87 r
F P
0 g
s
.17205 .88202 m .1541 .87424 L .16373 .86235 L p .682 .71 .87 r
F P
0 g
s
.23727 .86206 m .25505 .86992 L .24501 .88174 L p .682 .71 .87 r
F P
0 g
s
.24501 .88174 m .22729 .87396 L .23727 .86206 L p .682 .71 .87 r
F P
0 g
s
.31083 .86178 m .32837 .86963 L .31799 .88146 L p .682 .71 .87 r
F P
0 g
s
.31799 .88146 m .3005 .87368 L .31083 .86178 L p .682 .71 .87 r
F P
0 g
s
.63105 .29434 m .64758 .30399 L .63567 .31853 L p .69 .69 .845 r
F P
0 g
s
.63567 .31853 m .61918 .30897 L .63105 .29434 L p .69 .69 .845 r
F P
0 g
s
.30492 .82708 m .32249 .83505 L .31213 .84705 L p .682 .709 .868 r
F P
0 g
s
.31213 .84705 m .29461 .83916 L .30492 .82708 L p .682 .709 .868 r
F P
0 g
s
.75254 .86008 m .76869 .86794 L .75619 .87979 L p .682 .71 .87 r
F P
0 g
s
.75619 .87979 m .74008 .872 L .75254 .86008 L p .682 .71 .87 r
F P
0 g
s
.13387 .59254 m .15198 .60126 L .14243 .61438 L p .686 .7 .857 r
F P
0 g
s
.14243 .61438 m .12437 .60575 L .13387 .59254 L p .686 .7 .857 r
F P
0 g
s
.20749 .59223 m .22537 .60094 L .21547 .61407 L p .686 .7 .857 r
F P
0 g
s
.21547 .61407 m .19763 .60544 L .20749 .59223 L p .686 .7 .857 r
F P
0 g
s
.28112 .59191 m .29878 .60063 L .28852 .61376 L p .686 .7 .857 r
F P
0 g
s
.28852 .61376 m .27092 .60512 L .28112 .59191 L p .686 .7 .857 r
F P
0 g
s
.59165 .32469 m .60832 .33426 L .59658 .34866 L p .69 .691 .846 r
F P
0 g
s
.59658 .34866 m .57995 .33919 L .59165 .32469 L p .69 .691 .846 r
F P
0 g
s
.20151 .55735 m .21943 .56618 L .20955 .57948 L p .687 .699 .856 r
F P
0 g
s
.20955 .57948 m .19168 .57073 L .20151 .55735 L p .687 .699 .856 r
F P
0 g
s
.26518 .85798 m .28289 .86585 L .27271 .87772 L p .682 .71 .87 r
F P
0 g
s
.27271 .87772 m .25505 .86992 L .26518 .85798 L p .682 .71 .87 r
F P
0 g
s
.13973 .72336 m .15785 .73167 L .14826 .74418 L p .684 .705 .863 r
F P
0 g
s
.14826 .74418 m .1302 .73595 L .13973 .72336 L p .684 .705 .863 r
F P
0 g
s
.26925 .52211 m .28696 .53106 L .27675 .54453 L p .687 .698 .854 r
F P
0 g
s
.27675 .54453 m .25909 .53567 L .26925 .52211 L p .687 .698 .854 r
F P
0 g
s
.16163 .58801 m .17969 .59675 L .16999 .60991 L p .686 .7 .857 r
F P
0 g
s
.16999 .60991 m .15198 .60126 L .16163 .58801 L p .686 .7 .857 r
F P
0 g
s
.30913 .58737 m .32673 .59612 L .31632 .60929 L p .686 .7 .857 r
F P
0 g
s
.31632 .60929 m .29878 .60063 L .30913 .58737 L p .686 .7 .857 r
F P
0 g
s
.62018 .31971 m .63678 .32931 L .62489 .34376 L p .69 .691 .846 r
F P
0 g
s
.62489 .34376 m .60832 .33426 L .62018 .31971 L p .69 .691 .846 r
F P
0 g
s
.72978 .72096 m .74604 .72928 L .73363 .74181 L p .684 .705 .863 r
F P
0 g
s
.73363 .74181 m .7174 .73357 L .72978 .72096 L p .684 .705 .863 r
F P
0 g
s
.14561 .85445 m .16373 .86235 L .1541 .87424 L p .682 .71 .87 r
F P
0 g
s
.1541 .87424 m .13604 .86642 L .14561 .85445 L p .682 .71 .87 r
F P
0 g
s
.12769 .65364 m .14587 .66218 L .13633 .67504 L p .685 .702 .86 r
F P
0 g
s
.13633 .67504 m .11821 .66658 L .12769 .65364 L p .685 .702 .86 r
F P
0 g
s
.29318 .85388 m .31083 .86178 L .3005 .87368 L p .682 .71 .87 r
F P
0 g
s
.3005 .87368 m .28289 .86585 L .29318 .85388 L p .682 .71 .87 r
F P
0 g
s
.36699 .85359 m .38441 .8615 L .37372 .8734 L p .682 .71 .87 r
F P
0 g
s
.37372 .8734 m .35635 .86557 L .36699 .85359 L p .682 .71 .87 r
F P
0 g
s
.12167 .61872 m .13987 .62738 L .13035 .64041 L p .686 .701 .859 r
F P
0 g
s
.13035 .64041 m .1122 .63184 L .12167 .61872 L p .686 .701 .859 r
F P
0 g
s
.29727 .51745 m .31492 .52643 L .30456 .53995 L p .687 .698 .854 r
F P
0 g
s
.30456 .53995 m .28696 .53106 L .29727 .51745 L p .687 .698 .854 r
F P
0 g
s
.73628 .85216 m .75254 .86008 L .74008 .872 L p .682 .71 .87 r
F P
0 g
s
.74008 .872 m .72386 .86416 L .73628 .85216 L p .682 .71 .87 r
F P
0 g
s
.18948 .58346 m .20749 .59223 L .19763 .60544 L p .686 .7 .857 r
F P
0 g
s
.19763 .60544 m .17969 .59675 L .18948 .58346 L p .686 .7 .857 r
F P
0 g
s
.26335 .58314 m .28112 .59191 L .27092 .60512 L p .686 .7 .857 r
F P
0 g
s
.27092 .60512 m .2532 .59644 L .26335 .58314 L p .686 .7 .857 r
F P
0 g
s
.6488 .31472 m .66534 .32435 L .65329 .33885 L p .69 .691 .846 r
F P
0 g
s
.65329 .33885 m .63678 .32931 L .6488 .31472 L p .69 .691 .846 r
F P
0 g
s
.17345 .85033 m .19151 .85826 L .18174 .8702 L p .682 .71 .87 r
F P
0 g
s
.18174 .8702 m .16373 .86235 L .17345 .85033 L p .682 .71 .87 r
F P
0 g
s
.25739 .54814 m .27519 .55703 L .265 .57042 L p .687 .699 .856 r
F P
0 g
s
.265 .57042 m .24726 .56161 L .25739 .54814 L p .687 .699 .856 r
F P
0 g
s
.32127 .84976 m .33886 .85769 L .32837 .86963 L p .682 .71 .87 r
F P
0 g
s
.32837 .86963 m .31083 .86178 L .32127 .84976 L p .682 .71 .87 r
F P
0 g
s
.70693 .58124 m .7233 .59002 L .71096 .60325 L p .686 .7 .857 r
F P
0 g
s
.71096 .60325 m .69463 .59455 L .70693 .58124 L p .686 .7 .857 r
F P
0 g
s
.1215 .715 m .13973 .72336 L .1302 .73595 L p .684 .705 .863 r
F P
0 g
s
.1302 .73595 m .11202 .72767 L .1215 .715 L p .684 .705 .863 r
F P
0 g
s
.76512 .84804 m .78132 .85598 L .76869 .86794 L p .682 .71 .87 r
F P
0 g
s
.76869 .86794 m .75254 .86008 L .76512 .84804 L p .682 .71 .87 r
F P
0 g
s
.21743 .57889 m .23537 .58769 L .22537 .60094 L p .686 .7 .857 r
F P
0 g
s
.22537 .60094 m .20749 .59223 L .21743 .57889 L p .686 .7 .857 r
F P
0 g
s
.12738 .84649 m .14561 .85445 L .13604 .86642 L p .682 .71 .87 r
F P
0 g
s
.13604 .86642 m .11786 .85854 L .12738 .84649 L p .682 .71 .87 r
F P
0 g
s
.1094 .64505 m .12769 .65364 L .11821 .66658 L p .685 .702 .86 r
F P
0 g
s
.11821 .66658 m .09997 .65807 L .1094 .64505 L p .685 .702 .86 r
F P
0 g
s
.34945 .84563 m .36699 .85359 L .35635 .86557 L p .682 .71 .87 r
F P
0 g
s
.35635 .86557 m .33886 .85769 L .34945 .84563 L p .682 .71 .87 r
F P
0 g
s
.14936 .71064 m .16753 .71903 L .15785 .73167 L p .684 .705 .863 r
F P
0 g
s
.15785 .73167 m .13973 .72336 L .14936 .71064 L p .684 .705 .863 r
F P
0 g
s
.71992 .8442 m .73628 .85216 L .72386 .86416 L p .682 .71 .87 r
F P
0 g
s
.72386 .86416 m .70753 .85627 L .71992 .8442 L p .682 .71 .87 r
F P
0 g
s
.68397 .44091 m .70045 .45017 L .6882 .4641 L p .688 .695 .852 r
F P
0 g
s
.6882 .4641 m .67176 .45494 L .68397 .44091 L p .688 .695 .852 r
F P
0 g
s
.24547 .57431 m .26335 .58314 L .2532 .59644 L p .686 .7 .857 r
F P
0 g
s
.2532 .59644 m .23537 .58769 L .24547 .57431 L p .686 .7 .857 r
F P
0 g
s
.31959 .57399 m .33724 .58282 L .32673 .59612 L p .686 .7 .857 r
F P
0 g
s
.32673 .59612 m .30913 .58737 L .31959 .57399 L p .686 .7 .857 r
F P
0 g
s
.13727 .64057 m .15551 .6492 L .14587 .66218 L p .685 .702 .86 r
F P
0 g
s
.14587 .66218 m .12769 .65364 L .13727 .64057 L p .685 .702 .86 r
F P
0 g
s
.31364 .53887 m .33132 .54782 L .32083 .56129 L p .687 .699 .856 r
F P
0 g
s
.32083 .56129 m .3032 .55243 L .31364 .53887 L p .687 .699 .856 r
F P
0 g
s
.37773 .84149 m .3952 .84947 L .38441 .8615 L p .682 .71 .87 r
F P
0 g
s
.38441 .8615 m .36699 .85359 L .37773 .84149 L p .682 .71 .87 r
F P
0 g
s
.69045 .57239 m .70693 .58124 L .69463 .59455 L p .686 .7 .857 r
F P
0 g
s
.69463 .59455 m .6782 .58579 L .69045 .57239 L p .686 .7 .857 r
F P
0 g
s
.67246 .37053 m .68899 .38001 L .67678 .3943 L p .689 .693 .849 r
F P
0 g
s
.67678 .3943 m .66029 .3849 L .67246 .37053 L p .689 .693 .849 r
F P
0 g
s
.10315 .70658 m .1215 .715 L .11202 .72767 L p .684 .705 .863 r
F P
0 g
s
.11202 .72767 m .09373 .71933 L .10315 .70658 L p .684 .705 .863 r
F P
0 g
s
.66669 .33527 m .68325 .34488 L .67107 .35934 L p .689 .692 .848 r
F P
0 g
s
.67107 .35934 m .65455 .34983 L .66669 .33527 L p .689 .692 .848 r
F P
0 g
s
.09707 .67151 m .11545 .68004 L .106 .69289 L p .685 .704 .862 r
F P
0 g
s
.106 .69289 m .08768 .68444 L .09707 .67151 L p .685 .704 .862 r
F P
0 g
s
.2736 .56971 m .29143 .57857 L .28112 .59191 L p .686 .7 .857 r
F P
0 g
s
.28112 .59191 m .26335 .58314 L .2736 .56971 L p .686 .7 .857 r
F P
0 g
s
.10903 .83849 m .12738 .84649 L .11786 .85854 L p .682 .71 .87 r
F P
0 g
s
.11786 .85854 m .09957 .85062 L .10903 .83849 L p .682 .71 .87 r
F P
0 g
s
.18327 .8382 m .20139 .84621 L .19151 .85826 L p .682 .71 .87 r
F P
0 g
s
.19151 .85826 m .17345 .85033 L .18327 .8382 L p .682 .71 .87 r
F P
0 g
s
.71934 .56779 m .73575 .57666 L .7233 .59002 L p .686 .7 .857 r
F P
0 g
s
.7233 .59002 m .70693 .58124 L .71934 .56779 L p .686 .7 .857 r
F P
0 g
s
.70345 .83618 m .71992 .8442 L .70753 .85627 L p .682 .71 .87 r
F P
0 g
s
.70753 .85627 m .6911 .84833 L .70345 .83618 L p .682 .71 .87 r
F P
0 g
s
.66739 .4316 m .68397 .44091 L .67176 .45494 L p .688 .695 .852 r
F P
0 g
s
.67176 .45494 m .65522 .44571 L .66739 .4316 L p .688 .695 .852 r
F P
0 g
s
.77783 .83589 m .79406 .84391 L .78132 .85598 L p .682 .71 .87 r
F P
0 g
s
.78132 .85598 m .76512 .84804 L .77783 .83589 L p .682 .71 .87 r
F P
0 g
s
.30183 .5651 m .31959 .57399 L .30913 .58737 L p .686 .7 .857 r
F P
0 g
s
.30913 .58737 m .29143 .57857 L .30183 .5651 L p .686 .7 .857 r
F P
0 g
s
.13699 .83433 m .15528 .84236 L .14561 .85445 L p .682 .71 .87 r
F P
0 g
s
.14561 .85445 m .12738 .84649 L .13699 .83433 L p .682 .71 .87 r
F P
0 g
s
.67387 .5635 m .69045 .57239 L .6782 .58579 L p .686 .7 .857 r
F P
0 g
s
.6782 .58579 m .66166 .57698 L .67387 .5635 L p .686 .7 .857 r
F P
0 g
s
.65582 .36098 m .67246 .37053 L .66029 .3849 L p .689 .693 .849 r
F P
0 g
s
.66029 .3849 m .64369 .37545 L .65582 .36098 L p .689 .693 .849 r
F P
0 g
s
.08468 .69811 m .10315 .70658 L .09373 .71933 L p .684 .705 .863 r
F P
0 g
s
.09373 .71933 m .07532 .71095 L .08468 .69811 L p .684 .705 .863 r
F P
0 g
s
.15908 .69781 m .17731 .70628 L .16753 .71903 L p .684 .705 .863 r
F P
0 g
s
.16753 .71903 m .14936 .71064 L .15908 .69781 L p .684 .705 .863 r
F P
0 g
s
.73242 .83201 m .74883 .84005 L .73628 .85216 L p .682 .71 .87 r
F P
0 g
s
.73628 .85216 m .71992 .8442 L .73242 .83201 L p .682 .71 .87 r
F P
0 g
s
.69631 .42676 m .71283 .4361 L .70045 .45017 L p .688 .695 .852 r
F P
0 g
s
.70045 .45017 m .68397 .44091 L .69631 .42676 L p .688 .695 .852 r
F P
0 g
s
.15302 .66261 m .17128 .6712 L .16152 .68413 L p .685 .704 .862 r
F P
0 g
s
.16152 .68413 m .14332 .67563 L .15302 .66261 L p .685 .704 .862 r
F P
0 g
s
.33015 .56047 m .34785 .56939 L .33724 .58282 L p .686 .7 .857 r
F P
0 g
s
.33724 .58282 m .31959 .57399 L .33015 .56047 L p .686 .7 .857 r
F P
0 g
s
.09056 .83044 m .10903 .83849 L .09957 .85062 L p .682 .71 .87 r
F P
0 g
s
.09957 .85062 m .08116 .84264 L .09056 .83044 L p .682 .71 .87 r
F P
0 g
s
.16504 .83015 m .18327 .8382 L .17345 .85033 L p .682 .71 .87 r
F P
0 g
s
.17345 .85033 m .15528 .84236 L .16504 .83015 L p .682 .71 .87 r
F P
0 g
s
.38858 .82927 m .4061 .83734 L .3952 .84947 L p .682 .71 .87 r
F P
0 g
s
.3952 .84947 m .37773 .84149 L .38858 .82927 L p .682 .71 .87 r
F P
0 g
s
.68475 .35601 m .70132 .36559 L .68899 .38001 L p .689 .693 .849 r
F P
0 g
s
.68899 .38001 m .67246 .37053 L .68475 .35601 L p .689 .693 .849 r
F P
0 g
s
.11266 .6937 m .13107 .7022 L .1215 .715 L p .684 .705 .863 r
F P
0 g
s
.1215 .715 m .10315 .70658 L .11266 .6937 L p .684 .705 .863 r
F P
0 g
s
.68688 .82811 m .70345 .83618 L .6911 .84833 L p .682 .71 .87 r
F P
0 g
s
.6911 .84833 m .67457 .84034 L .68688 .82811 L p .682 .71 .87 r
F P
0 g
s
.6507 .42223 m .66739 .4316 L .65522 .44571 L p .688 .695 .852 r
F P
0 g
s
.65522 .44571 m .63857 .43643 L .6507 .42223 L p .688 .695 .852 r
F P
0 g
s
.76149 .82782 m .77783 .83589 L .76512 .84804 L p .682 .71 .87 r
F P
0 g
s
.76512 .84804 m .74883 .84005 L .76149 .82782 L p .682 .71 .87 r
F P
0 g
s
.07834 .76009 m .09687 .76838 L .08746 .78086 L p .683 .708 .867 r
F P
0 g
s
.08746 .78086 m .06899 .77265 L .07834 .76009 L p .683 .708 .867 r
F P
0 g
s
.64489 .38682 m .66161 .39631 L .64946 .4106 L p .688 .694 .85 r
F P
0 g
s
.64946 .4106 m .63278 .4012 L .64489 .38682 L p .688 .694 .85 r
F P
0 g
s
.07222 .72486 m .09078 .73326 L .08139 .74592 L p .683 .706 .865 r
F P
0 g
s
.08139 .74592 m .0629 .7376 L .07222 .72486 L p .683 .706 .865 r
F P
0 g
s
.19318 .82595 m .21136 .83404 L .20139 .84621 L p .682 .71 .87 r
F P
0 g
s
.20139 .84621 m .18327 .8382 L .19318 .82595 L p .682 .71 .87 r
F P
0 g
s
.65718 .55454 m .67387 .5635 L .66166 .57698 L p .686 .7 .857 r
F P
0 g
s
.66166 .57698 m .64501 .56811 L .65718 .55454 L p .686 .7 .857 r
F P
0 g
s
.73188 .55422 m .74833 .56317 L .73575 .57666 L p .686 .7 .857 r
F P
0 g
s
.73575 .57666 m .71934 .56779 L .73188 .55422 L p .686 .7 .857 r
F P
0 g
s
.14073 .68928 m .15908 .69781 L .14936 .71064 L p .684 .705 .863 r
F P
0 g
s
.14936 .71064 m .13107 .7022 L .14073 .68928 L p .684 .705 .863 r
F P
0 g
s
.36475 .68836 m .38239 .69689 L .37158 .70974 L p .684 .705 .863 r
F P
0 g
s
.37158 .70974 m .35399 .70129 L .36475 .68836 L p .684 .705 .863 r
F P
0 g
s
.79066 .82362 m .80693 .83171 L .79406 .84391 L p .682 .71 .87 r
F P
0 g
s
.79406 .84391 m .77783 .83589 L .79066 .82362 L p .682 .71 .87 r
F P
0 g
s
.07197 .82233 m .09056 .83044 L .08116 .84264 L p .682 .71 .87 r
F P
0 g
s
.08116 .84264 m .06263 .83462 L .07197 .82233 L p .682 .71 .87 r
F P
0 g
s
.37094 .82116 m .38858 .82927 L .37773 .84149 L p .682 .71 .87 r
F P
0 g
s
.37773 .84149 m .36015 .83346 L .37094 .82116 L p .682 .71 .87 r
F P
0 g
s
.68621 .54988 m .70283 .55886 L .69045 .57239 L p .686 .7 .857 r
F P
0 g
s
.69045 .57239 m .67387 .5635 L .68621 .54988 L p .686 .7 .857 r
F P
0 g
s
.35279 .61767 m .37049 .62644 L .35973 .63964 L p .685 .702 .86 r
F P
0 g
s
.35973 .63964 m .34208 .63096 L .35279 .61767 L p .685 .702 .86 r
F P
0 g
s
.1689 .68484 m .18719 .6934 L .17731 .70628 L p .684 .705 .863 r
F P
0 g
s
.17731 .70628 m .15908 .69781 L .1689 .68484 L p .684 .705 .863 r
F P
0 g
s
.6702 .81999 m .68688 .82811 L .67457 .84034 L p .682 .71 .87 r
F P
0 g
s
.67457 .84034 m .65793 .8323 L .6702 .81999 L p .682 .71 .87 r
F P
0 g
s
.6339 .4128 m .6507 .42223 L .63857 .43643 L p .688 .695 .852 r
F P
0 g
s
.63857 .43643 m .62181 .42709 L .6339 .4128 L p .688 .695 .852 r
F P
0 g
s
.34681 .58227 m .36453 .59115 L .35379 .60453 L p .686 .701 .859 r
F P
0 g
s
.35379 .60453 m .33612 .59573 L .34681 .58227 L p .686 .701 .859 r
F P
0 g
s
.05969 .75175 m .07834 .76009 L .06899 .77265 L p .683 .708 .867 r
F P
0 g
s
.06899 .77265 m .0504 .76439 L .05969 .75175 L p .683 .708 .867 r
F P
0 g
s
.70876 .41246 m .72532 .42189 L .71283 .4361 L p .688 .695 .852 r
F P
0 g
s
.71283 .4361 m .69631 .42676 L .70876 .41246 L p .688 .695 .852 r
F P
0 g
s
.70296 .37692 m .71955 .38648 L .70708 .40086 L p .688 .694 .85 r
F P
0 g
s
.70708 .40086 m .69053 .3914 L .70296 .37692 L p .688 .694 .85 r
F P
0 g
s
.10005 .81811 m .11858 .82625 L .10903 .83849 L p .682 .71 .87 r
F P
0 g
s
.10903 .83849 m .09056 .83044 L .10005 .81811 L p .682 .71 .87 r
F P
0 g
s
.64039 .54552 m .65718 .55454 L .64501 .56811 L p .686 .7 .857 r
F P
0 g
s
.64501 .56811 m .62826 .55919 L .64039 .54552 L p .686 .7 .857 r
F P
0 g
s
.39953 .81694 m .41711 .82508 L .4061 .83734 L p .682 .71 .87 r
F P
0 g
s
.4061 .83734 m .38858 .82927 L .39953 .81694 L p .682 .71 .87 r
F P
0 g
s
.71533 .5452 m .73188 .55422 L .71934 .56779 L p .686 .7 .857 r
F P
0 g
s
.71934 .56779 m .70283 .55886 L .71533 .5452 L p .686 .7 .857 r
F P
0 g
s
.6993 .81576 m .71592 .82391 L .70345 .83618 L p .682 .71 .87 r
F P
0 g
s
.70345 .83618 m .68688 .82811 L .6993 .81576 L p .682 .71 .87 r
F P
0 g
s
.347 .67977 m .36475 .68836 L .35399 .70129 L p .684 .705 .863 r
F P
0 g
s
.35399 .70129 m .33629 .69278 L .347 .67977 L p .684 .705 .863 r
F P
0 g
s
.66295 .40789 m .67968 .41735 L .66739 .4316 L p .688 .695 .852 r
F P
0 g
s
.66739 .4316 m .6507 .42223 L .66295 .40789 L p .688 .695 .852 r
F P
0 g
s
.08778 .74741 m .10637 .75578 L .09687 .76838 L p .683 .708 .867 r
F P
0 g
s
.09687 .76838 m .07834 .76009 L .08778 .74741 L p .683 .708 .867 r
F P
0 g
s
.6287 .47449 m .64556 .48375 L .63343 .49768 L p .687 .698 .854 r
F P
0 g
s
.63343 .49768 m .61662 .48852 L .6287 .47449 L p .687 .698 .854 r
F P
0 g
s
.05326 .81417 m .07197 .82233 L .06263 .83462 L p .682 .71 .87 r
F P
0 g
s
.06263 .83462 m .04399 .82654 L .05326 .81417 L p .682 .71 .87 r
F P
0 g
s
.20319 .81359 m .22142 .82175 L .21136 .83404 L p .682 .71 .87 r
F P
0 g
s
.21136 .83404 m .19318 .82595 L .20319 .81359 L p .682 .71 .87 r
F P
0 g
s
.62285 .43892 m .63973 .44829 L .62762 .46241 L p .687 .696 .853 r
F P
0 g
s
.62762 .46241 m .61079 .45312 L .62285 .43892 L p .687 .696 .853 r
F P
0 g
s
.35319 .813 m .37094 .82116 L .36015 .83346 L p .682 .71 .87 r
F P
0 g
s
.36015 .83346 m .34245 .82537 L .35319 .813 L p .682 .71 .87 r
F P
0 g
s
.33499 .60884 m .35279 .61767 L .34208 .63096 L p .685 .702 .86 r
F P
0 g
s
.34208 .63096 m .32433 .62222 L .33499 .60884 L p .685 .702 .86 r
F P
0 g
s
.04709 .77878 m .06583 .78706 L .05652 .79952 L p .682 .709 .868 r
F P
0 g
s
.05652 .79952 m .03784 .79133 L .04709 .77878 L p .682 .709 .868 r
F P
0 g
s
.74454 .54051 m .76103 .54955 L .74833 .56317 L p .686 .7 .857 r
F P
0 g
s
.74833 .56317 m .73188 .55422 L .74454 .54051 L p .686 .7 .857 r
F P
0 g
s
.65341 .81182 m .6702 .81999 L .65793 .8323 L p .682 .71 .87 r
F P
0 g
s
.65793 .8323 m .64119 .8242 L .65341 .81182 L p .682 .71 .87 r
F P
0 g
s
.37561 .6753 m .3933 .68392 L .38239 .69689 L p .684 .705 .863 r
F P
0 g
s
.38239 .69689 m .36475 .68836 L .37561 .6753 L p .684 .705 .863 r
F P
0 g
s
.69209 .40296 m .70876 .41246 L .69631 .42676 L p .688 .695 .852 r
F P
0 g
s
.69631 .42676 m .67968 .41735 L .69209 .40296 L p .688 .695 .852 r
F P
0 g
s
.80362 .81122 m .81993 .8194 L .80693 .83171 L p .682 .71 .87 r
F P
0 g
s
.80693 .83171 m .79066 .82362 L .80362 .81122 L p .682 .71 .87 r
F P
0 g
s
.19101 .74275 m .2093 .75115 L .19928 .76379 L p .683 .708 .867 r
F P
0 g
s
.19928 .76379 m .18105 .75548 L .19101 .74275 L p .683 .708 .867 r
F P
0 g
s
.18491 .70727 m .20323 .71579 L .19324 .72861 L p .683 .706 .865 r
F P
0 g
s
.19324 .72861 m .17498 .72018 L .18491 .70727 L p .683 .706 .865 r
F P
0 g
s
.62348 .53645 m .64039 .54552 L .62826 .55919 L p .686 .7 .857 r
F P
0 g
s
.62826 .55919 m .6114 .5502 L .62348 .53645 L p .686 .7 .857 r
F P
0 g
s
.36361 .60425 m .38136 .6131 L .37049 .62644 L p .685 .702 .86 r
F P
0 g
s
.37049 .62644 m .35279 .61767 L .36361 .60425 L p .685 .702 .86 r
F P
0 g
s
.32913 .67113 m .347 .67977 L .33629 .69278 L p .684 .705 .863 r
F P
0 g
s
.33629 .69278 m .31848 .68423 L .32913 .67113 L p .684 .705 .863 r
F P
0 g
s
.72133 .39802 m .73793 .40755 L .72532 .42189 L p .688 .695 .852 r
F P
0 g
s
.72532 .42189 m .70876 .41246 L .72133 .39802 L p .688 .695 .852 r
F P
0 g
s
.61174 .46518 m .6287 .47449 L .61662 .48852 L p .687 .698 .854 r
F P
0 g
s
.61662 .48852 m .5997 .47929 L .61174 .46518 L p .687 .698 .854 r
F P
0 g
s
.3231 .63556 m .34099 .64433 L .33031 .65752 L p .685 .704 .862 r
F P
0 g
s
.33031 .65752 m .31247 .64884 L .3231 .63556 L p .685 .704 .862 r
F P
0 g
s
.03443 .80596 m .05326 .81417 L .04399 .82654 L p .682 .71 .87 r
F P
0 g
s
.04399 .82654 m .02522 .81841 L .03443 .80596 L p .682 .71 .87 r
F P
0 g
s
.10963 .80567 m .12822 .81388 L .11858 .82625 L p .682 .71 .87 r
F P
0 g
s
.11858 .82625 m .10005 .81811 L .10963 .80567 L p .682 .71 .87 r
F P
0 g
s
.18484 .80537 m .20319 .81359 L .19318 .82595 L p .682 .71 .87 r
F P
0 g
s
.19318 .82595 m .17489 .81782 L .18484 .80537 L p .682 .71 .87 r
F P
0 g
s
.33533 .80478 m .35319 .813 L .34245 .82537 L p .682 .71 .87 r
F P
0 g
s
.34245 .82537 m .32464 .81723 L .33533 .80478 L p .682 .71 .87 r
F P
0 g
s
.65264 .53173 m .66948 .54083 L .65718 .55454 L p .686 .7 .857 r
F P
0 g
s
.65718 .55454 m .64039 .54552 L .65264 .53173 L p .686 .7 .857 r
F P
0 g
s
.4106 .80448 m .42822 .8127 L .41711 .82508 L p .682 .71 .87 r
F P
0 g
s
.41711 .82508 m .39953 .81694 L .4106 .80448 L p .682 .71 .87 r
F P
0 g
s
.10347 .77015 m .12209 .77848 L .11247 .79103 L p .682 .709 .868 r
F P
0 g
s
.11247 .79103 m .09391 .78278 L .10347 .77015 L p .682 .709 .868 r
F P
0 g
s
.63651 .80359 m .65341 .81182 L .64119 .8242 L p .682 .71 .87 r
F P
0 g
s
.64119 .8242 m .62433 .81606 L .63651 .80359 L p .682 .71 .87 r
F P
0 g
s
.71185 .80329 m .7285 .81152 L .71592 .82391 L p .682 .71 .87 r
F P
0 g
s
.71592 .82391 m .6993 .81576 L .71185 .80329 L p .682 .71 .87 r
F P
0 g
s
.7872 .80299 m .80362 .81122 L .79066 .82362 L p .682 .71 .87 r
F P
0 g
s
.79066 .82362 m .77429 .81547 L .7872 .80299 L p .682 .71 .87 r
F P
0 g
s
.17261 .73429 m .19101 .74275 L .18105 .75548 L p .683 .708 .867 r
F P
0 g
s
.18105 .75548 m .1627 .7471 L .17261 .73429 L p .683 .708 .867 r
F P
0 g
s
.64091 .46033 m .6578 .46968 L .64556 .48375 L p .687 .698 .854 r
F P
0 g
s
.64556 .48375 m .6287 .47449 L .64091 .46033 L p .687 .698 .854 r
F P
0 g
s
.70602 .76774 m .7227 .77609 L .71013 .78866 L p .682 .709 .868 r
F P
0 g
s
.71013 .78866 m .69349 .78039 L .70602 .76774 L p .682 .709 .868 r
F P
0 g
s
.06263 .80169 m .0814 .80993 L .07197 .82233 L p .682 .71 .87 r
F P
0 g
s
.07197 .82233 m .05326 .81417 L .06263 .80169 L p .682 .71 .87 r
F P
0 g
s
.2133 .80109 m .23159 .80934 L .22142 .82175 L p .682 .71 .87 r
F P
0 g
s
.22142 .82175 m .20319 .81359 L .2133 .80109 L p .682 .71 .87 r
F P
0 g
s
.60647 .52732 m .62348 .53645 L .6114 .5502 L p .686 .7 .857 r
F P
0 g
s
.6114 .5502 m .59443 .54116 L .60647 .52732 L p .686 .7 .857 r
F P
0 g
s
.36405 .8005 m .38185 .80874 L .37094 .82116 L p .682 .71 .87 r
F P
0 g
s
.37094 .82116 m .35319 .813 L .36405 .8005 L p .682 .71 .87 r
F P
0 g
s
.75733 .52666 m .77386 .5358 L .76103 .54955 L p .686 .7 .857 r
F P
0 g
s
.76103 .54955 m .74454 .54051 L .75733 .52666 L p .686 .7 .857 r
F P
0 g
s
.60057 .49158 m .61762 .50084 L .60555 .51477 L p .687 .699 .856 r
F P
0 g
s
.60555 .51477 m .58855 .50561 L .60057 .49158 L p .687 .699 .856 r
F P
0 g
s
.66575 .79931 m .68258 .80756 L .6702 .81999 L p .682 .71 .87 r
F P
0 g
s
.6702 .81999 m .65341 .81182 L .66575 .79931 L p .682 .71 .87 r
F P
0 g
s
.31115 .66243 m .32913 .67113 L .31848 .68423 L p .684 .705 .863 r
F P
0 g
s
.31848 .68423 m .30055 .67561 L .31115 .66243 L p .684 .705 .863 r
F P
0 g
s
.38658 .66212 m .40432 .67082 L .3933 .68392 L p .684 .705 .863 r
F P
0 g
s
.3933 .68392 m .37561 .6753 L .38658 .66212 L p .684 .705 .863 r
F P
0 g
s
.8167 .79871 m .83305 .80697 L .81993 .8194 L p .682 .71 .87 r
F P
0 g
s
.81993 .8194 m .80362 .81122 L .8167 .79871 L p .682 .71 .87 r
F P
0 g
s
.20107 .72989 m .21942 .73837 L .2093 .75115 L p .683 .708 .867 r
F P
0 g
s
.2093 .75115 m .19101 .74275 L .20107 .72989 L p .683 .708 .867 r
F P
0 g
s
.38056 .62643 m .39833 .63525 L .38733 .64853 L p .685 .704 .862 r
F P
0 g
s
.38733 .64853 m .36961 .6398 L .38056 .62643 L p .685 .704 .862 r
F P
0 g
s
.09092 .7974 m .10963 .80567 L .10005 .81811 L p .682 .71 .87 r
F P
0 g
s
.10005 .81811 m .0814 .80993 L .09092 .7974 L p .682 .71 .87 r
F P
0 g
s
.74569 .45513 m .76228 .46451 L .7495 .47863 L p .687 .698 .854 r
F P
0 g
s
.7495 .47863 m .73295 .46934 L .74569 .45513 L p .687 .698 .854 r
F P
0 g
s
.16638 .7971 m .18484 .80537 L .17489 .81782 L p .682 .71 .87 r
F P
0 g
s
.17489 .81782 m .15648 .80963 L .16638 .7971 L p .682 .71 .87 r
F P
0 g
s
.31735 .7965 m .33533 .80478 L .32464 .81723 L p .682 .71 .87 r
F P
0 g
s
.32464 .81723 m .30671 .80904 L .31735 .7965 L p .682 .71 .87 r
F P
0 g
s
.39286 .79621 m .4106 .80448 L .39953 .81694 L p .682 .71 .87 r
F P
0 g
s
.39953 .81694 m .38185 .80874 L .39286 .79621 L p .682 .71 .87 r
F P
0 g
s
.73987 .4193 m .75648 .4288 L .74372 .44311 L p .687 .696 .853 r
F P
0 g
s
.74372 .44311 m .72715 .4337 L .73987 .4193 L p .687 .696 .853 r
F P
0 g
s
.16023 .76146 m .17873 .76985 L .1688 .78248 L p .682 .709 .868 r
F P
0 g
s
.1688 .78248 m .15036 .77417 L .16023 .76146 L p .682 .709 .868 r
F P
0 g
s
.6195 .79531 m .63651 .80359 L .62433 .81606 L p .682 .71 .87 r
F P
0 g
s
.62433 .81606 m .60737 .80786 L .6195 .79531 L p .682 .71 .87 r
F P
0 g
s
.69508 .79501 m .71185 .80329 L .6993 .81576 L p .682 .71 .87 r
F P
0 g
s
.6993 .81576 m .68258 .80756 L .69508 .79501 L p .682 .71 .87 r
F P
0 g
s
.33989 .6579 m .35781 .66663 L .347 .67977 L p .684 .705 .863 r
F P
0 g
s
.347 .67977 m .32913 .67113 L .33989 .6579 L p .684 .705 .863 r
F P
0 g
s
.77068 .79471 m .7872 .80299 L .77429 .81547 L p .682 .71 .87 r
F P
0 g
s
.77429 .81547 m .7578 .80726 L .77068 .79471 L p .682 .71 .87 r
F P
0 g
s
.30521 .72517 m .32325 .73368 L .31261 .7465 L p .683 .708 .867 r
F P
0 g
s
.31261 .7465 m .29462 .73807 L .30521 .72517 L p .683 .708 .867 r
F P
0 g
s
.76486 .75904 m .78141 .76744 L .76852 .78009 L p .682 .709 .868 r
F P
0 g
s
.76852 .78009 m .75201 .77177 L .76486 .75904 L p .682 .709 .868 r
F P
0 g
s
.11931 .7931 m .13796 .80139 L .12822 .81388 L p .682 .71 .87 r
F P
0 g
s
.12822 .81388 m .10963 .80567 L .11931 .7931 L p .682 .71 .87 r
F P
0 g
s
.58935 .51813 m .60647 .52732 L .59443 .54116 L p .686 .7 .857 r
F P
0 g
s
.59443 .54116 m .57735 .53206 L .58935 .51813 L p .686 .7 .857 r
F P
0 g
s
.29913 .68944 m .3172 .69807 L .30658 .71107 L p .683 .706 .865 r
F P
0 g
s
.30658 .71107 m .28857 .70253 L .29913 .68944 L p .683 .706 .865 r
F P
0 g
s
.66501 .5178 m .68189 .52699 L .66948 .54083 L p .686 .7 .857 r
F P
0 g
s
.66948 .54083 m .65264 .53173 L .66501 .5178 L p .686 .7 .857 r
F P
0 g
s
.42177 .7919 m .43944 .8002 L .42822 .8127 L p .682 .71 .87 r
F P
0 g
s
.42822 .8127 m .4106 .80448 L .42177 .7919 L p .682 .71 .87 r
F P
0 g
s
.74069 .51747 m .75733 .52666 L .74454 .54051 L p .686 .7 .857 r
F P
0 g
s
.74454 .54051 m .72795 .5314 L .74069 .51747 L p .686 .7 .857 r
F P
0 g
s
.65913 .48193 m .67604 .49125 L .66364 .50527 L p .687 .699 .856 r
F P
0 g
s
.66364 .50527 m .64678 .49605 L .65913 .48193 L p .687 .699 .856 r
F P
0 g
s
.72452 .7907 m .74122 .79901 L .7285 .81152 L p .682 .71 .87 r
F P
0 g
s
.7285 .81152 m .71185 .80329 L .72452 .7907 L p .682 .71 .87 r
F P
0 g
s
.36872 .65336 m .38658 .66212 L .37561 .6753 L p .684 .705 .863 r
F P
0 g
s
.37561 .6753 m .35781 .66663 L .36872 .65336 L p .684 .705 .863 r
F P
0 g
s
.59586 .65241 m .61298 .66117 L .60089 .67437 L p .684 .705 .863 r
F P
0 g
s
.60089 .67437 m .58381 .66569 L .59586 .65241 L p .684 .705 .863 r
F P
0 g
s
.729 .44569 m .74569 .45513 L .73295 .46934 L p .687 .698 .854 r
F P
0 g
s
.73295 .46934 m .7163 .45999 L .729 .44569 L p .687 .698 .854 r
F P
0 g
s
.14779 .78878 m .16638 .7971 L .15648 .80963 L p .682 .71 .87 r
F P
0 g
s
.15648 .80963 m .13796 .80139 L .14779 .78878 L p .682 .71 .87 r
F P
0 g
s
.22351 .78848 m .24185 .7968 L .23159 .80934 L p .682 .71 .87 r
F P
0 g
s
.23159 .80934 m .2133 .80109 L .22351 .78848 L p .682 .71 .87 r
F P
0 g
s
.29925 .78818 m .31735 .7965 L .30671 .80904 L p .682 .71 .87 r
F P
0 g
s
.30671 .80904 m .28866 .8008 L .29925 .78818 L p .682 .71 .87 r
F P
0 g
s
.61863 .51334 m .63569 .52257 L .62348 .53645 L p .686 .7 .857 r
F P
0 g
s
.62348 .53645 m .60647 .52732 L .61863 .51334 L p .686 .7 .857 r
F P
0 g
s
.77024 .51268 m .78681 .52191 L .77386 .5358 L p .686 .7 .857 r
F P
0 g
s
.77386 .5358 m .75733 .52666 L .77024 .51268 L p .686 .7 .857 r
F P
0 g
s
.21737 .75271 m .23575 .76116 L .22551 .77387 L p .682 .709 .868 r
F P
0 g
s
.22551 .77387 m .20719 .76551 L .21737 .75271 L p .682 .709 .868 r
F P
0 g
s
.60238 .78697 m .6195 .79531 L .60737 .80786 L p .682 .71 .87 r
F P
0 g
s
.60737 .80786 m .5903 .7996 L .60238 .78697 L p .682 .71 .87 r
F P
0 g
s
.584 .58072 m .60118 .58973 L .58913 .60329 L p .685 .702 .86 r
F P
0 g
s
.58913 .60329 m .572 .59437 L .584 .58072 L p .685 .702 .86 r
F P
0 g
s
.75406 .78637 m .77068 .79471 L .7578 .80726 L p .682 .71 .87 r
F P
0 g
s
.7578 .80726 m .74122 .79901 L .75406 .78637 L p .682 .71 .87 r
F P
0 g
s
.39766 .6488 m .41545 .65759 L .40432 .67082 L p .684 .705 .863 r
F P
0 g
s
.40432 .67082 m .38658 .66212 L .39766 .6488 L p .684 .705 .863 r
F P
0 g
s
.82992 .78607 m .8463 .79441 L .83305 .80697 L p .682 .71 .87 r
F P
0 g
s
.83305 .80697 m .8167 .79871 L .82992 .78607 L p .682 .71 .87 r
F P
0 g
s
.57805 .54482 m .59526 .55395 L .58324 .56769 L p .686 .701 .859 r
F P
0 g
s
.58324 .56769 m .56608 .55865 L .57805 .54482 L p .686 .701 .859 r
F P
0 g
s
.28705 .7166 m .30521 .72517 L .29462 .73807 L p .683 .708 .867 r
F P
0 g
s
.29462 .73807 m .27652 .72958 L .28705 .7166 L p .683 .708 .867 r
F P
0 g
s
.75856 .44078 m .77519 .45025 L .76228 .46451 L p .687 .698 .854 r
F P
0 g
s
.76228 .46451 m .74569 .45513 L .75856 .44078 L p .687 .698 .854 r
F P
0 g
s
.17637 .78445 m .1949 .7928 L .18484 .80537 L p .682 .71 .87 r
F P
0 g
s
.18484 .80537 m .16638 .7971 L .17637 .78445 L p .682 .71 .87 r
F P
0 g
s
.32809 .78384 m .34613 .7922 L .33533 .80478 L p .682 .71 .87 r
F P
0 g
s
.33533 .80478 m .31735 .7965 L .32809 .78384 L p .682 .71 .87 r
F P
0 g
s
.64802 .50854 m .66501 .5178 L .65264 .53173 L p .686 .7 .857 r
F P
0 g
s
.65264 .53173 m .63569 .52257 L .64802 .50854 L p .686 .7 .857 r
F P
0 g
s
.72395 .50821 m .74069 .51747 L .72795 .5314 L p .686 .7 .857 r
F P
0 g
s
.72795 .5314 m .71124 .52224 L .72395 .50821 L p .686 .7 .857 r
F P
0 g
s
.63175 .78264 m .64881 .791 L .63651 .80359 L p .682 .71 .87 r
F P
0 g
s
.63651 .80359 m .6195 .79531 L .63175 .78264 L p .682 .71 .87 r
F P
0 g
s
.71808 .47222 m .73485 .4816 L .72213 .49572 L p .687 .699 .856 r
F P
0 g
s
.72213 .49572 m .70539 .48643 L .71808 .47222 L p .687 .699 .856 r
F P
0 g
s
.78369 .78203 m .80025 .7904 L .7872 .80299 L p .682 .71 .87 r
F P
0 g
s
.7872 .80299 m .77068 .79471 L .78369 .78203 L p .682 .71 .87 r
F P
0 g
s
.57862 .64359 m .59586 .65241 L .58381 .66569 L p .684 .705 .863 r
F P
0 g
s
.58381 .66569 m .56663 .65696 L .57862 .64359 L p .684 .705 .863 r
F P
0 g
s
.31591 .71214 m .334 .72074 L .32325 .73368 L p .683 .708 .867 r
F P
0 g
s
.32325 .73368 m .30521 .72517 L .31591 .71214 L p .683 .708 .867 r
F P
0 g
s
.20505 .7801 m .22351 .78848 L .2133 .80109 L p .682 .71 .87 r
F P
0 g
s
.2133 .80109 m .1949 .7928 L .20505 .7801 L p .682 .71 .87 r
F P
0 g
s
.28103 .7798 m .29925 .78818 L .28866 .8008 L p .682 .71 .87 r
F P
0 g
s
.28866 .8008 m .2705 .7925 L .28103 .7798 L p .682 .71 .87 r
F P
0 g
s
.6775 .50373 m .69443 .51301 L .68189 .52699 L p .686 .7 .857 r
F P
0 g
s
.68189 .52699 m .66501 .5178 L .6775 .50373 L p .686 .7 .857 r
F P
0 g
s
.43305 .77919 m .45078 .78758 L .43944 .8002 L p .682 .71 .87 r
F P
0 g
s
.43944 .8002 m .42177 .7919 L .43305 .77919 L p .682 .71 .87 r
F P
0 g
s
.58515 .77859 m .60238 .78697 L .5903 .7996 L p .682 .71 .87 r
F P
0 g
s
.5903 .7996 m .57311 .7913 L .58515 .77859 L p .682 .71 .87 r
F P
0 g
s
.5667 .57166 m .584 .58072 L .572 .59437 L p .685 .702 .86 r
F P
0 g
s
.572 .59437 m .55475 .5854 L .5667 .57166 L p .685 .702 .86 r
F P
0 g
s
.27491 .7439 m .29315 .75241 L .28259 .76521 L p .682 .709 .868 r
F P
0 g
s
.28259 .76521 m .2644 .75679 L .27491 .7439 L p .682 .709 .868 r
F P
0 g
s
.81343 .77768 m .82992 .78607 L .8167 .79871 L p .682 .71 .87 r
F P
0 g
s
.8167 .79871 m .80025 .7904 L .81343 .77768 L p .682 .71 .87 r
F P
0 g
s
.60802 .639 m .62519 .64785 L .61298 .66117 L p .684 .705 .863 r
F P
0 g
s
.61298 .66117 m .59586 .65241 L .60802 .639 L p .684 .705 .863 r
F P
0 g
s
.42096 .70735 m .43875 .71598 L .42746 .72897 L p .683 .708 .867 r
F P
0 g
s
.42746 .72897 m .40973 .72043 L .42096 .70735 L p .683 .708 .867 r
F P
0 g
s
.23382 .77574 m .25222 .78414 L .24185 .7968 L p .682 .71 .87 r
F P
0 g
s
.24185 .7968 m .22351 .78848 L .23382 .77574 L p .682 .71 .87 r
F P
0 g
s
.70709 .49889 m .72395 .50821 L .71124 .52224 L p .686 .7 .857 r
F P
0 g
s
.71124 .52224 m .69443 .51301 L .70709 .49889 L p .686 .7 .857 r
F P
0 g
s
.41491 .67137 m .43272 .68012 L .42146 .6933 L p .683 .706 .865 r
F P
0 g
s
.42146 .6933 m .4037 .68463 L .41491 .67137 L p .683 .706 .865 r
F P
0 g
s
.78329 .49856 m .79989 .50788 L .78681 .52191 L p .686 .7 .857 r
F P
0 g
s
.78681 .52191 m .77024 .51268 L .78329 .49856 L p .686 .7 .857 r
F P
0 g
s
.59611 .56694 m .61334 .57603 L .60118 .58973 L p .685 .702 .86 r
F P
0 g
s
.60118 .58973 m .584 .58072 L .59611 .56694 L p .685 .702 .86 r
F P
0 g
s
.77743 .46244 m .79406 .47188 L .781 .4861 L p .687 .699 .856 r
F P
0 g
s
.781 .4861 m .76441 .47675 L .77743 .46244 L p .687 .699 .856 r
F P
0 g
s
.84327 .77331 m .85969 .78173 L .8463 .79441 L p .682 .71 .87 r
F P
0 g
s
.8463 .79441 m .82992 .78607 L .84327 .77331 L p .682 .71 .87 r
F P
0 g
s
.56127 .63471 m .57862 .64359 L .56663 .65696 L p .684 .705 .863 r
F P
0 g
s
.56663 .65696 m .54933 .64816 L .56127 .63471 L p .684 .705 .863 r
F P
0 g
s
.55529 .59864 m .57267 .60764 L .56069 .6212 L p .685 .704 .862 r
F P
0 g
s
.56069 .6212 m .54336 .61228 L .55529 .59864 L p .685 .704 .862 r
F P
0 g
s
.26269 .77136 m .28103 .7798 L .2705 .7925 L p .682 .71 .87 r
F P
0 g
s
.2705 .7925 m .25222 .78414 L .26269 .77136 L p .682 .71 .87 r
F P
0 g
s
.33894 .77106 m .35703 .77949 L .34613 .7922 L p .682 .71 .87 r
F P
0 g
s
.34613 .7922 m .32809 .78384 L .33894 .77106 L p .682 .71 .87 r
F P
0 g
s
.41521 .77075 m .43305 .77919 L .42177 .7919 L p .682 .71 .87 r
F P
0 g
s
.42177 .7919 m .40398 .78354 L .41521 .77075 L p .682 .71 .87 r
F P
0 g
s
.73678 .49404 m .75357 .50339 L .74069 .51747 L p .686 .7 .857 r
F P
0 g
s
.74069 .51747 m .72395 .50821 L .73678 .49404 L p .686 .7 .857 r
F P
0 g
s
.56781 .77014 m .58515 .77859 L .57311 .7913 L p .682 .71 .87 r
F P
0 g
s
.57311 .7913 m .55581 .78294 L .56781 .77014 L p .682 .71 .87 r
F P
0 g
s
.64413 .76984 m .66122 .77828 L .64881 .791 L p .682 .71 .87 r
F P
0 g
s
.64881 .791 m .63175 .78264 L .64413 .76984 L p .682 .71 .87 r
F P
0 g
s
.33283 .73504 m .35095 .7436 L .34007 .75649 L p .682 .709 .868 r
F P
0 g
s
.34007 .75649 m .322 .74801 L .33283 .73504 L p .682 .709 .868 r
F P
0 g
s
.40306 .69866 m .42096 .70735 L .40973 .72043 L p .683 .708 .867 r
F P
0 g
s
.40973 .72043 m .39188 .71183 L .40306 .69866 L p .683 .708 .867 r
F P
0 g
s
.29167 .76697 m .30994 .77543 L .29925 .78818 L p .682 .71 .87 r
F P
0 g
s
.29925 .78818 m .28103 .7798 L .29167 .76697 L p .682 .71 .87 r
F P
0 g
s
.44445 .76636 m .46223 .77483 L .45078 .78758 L p .682 .71 .87 r
F P
0 g
s
.45078 .78758 m .43305 .77919 L .44445 .76636 L p .682 .71 .87 r
F P
0 g
s
.76657 .48918 m .78329 .49856 L .77024 .51268 L p .686 .7 .857 r
F P
0 g
s
.77024 .51268 m .75357 .50339 L .76657 .48918 L p .686 .7 .857 r
F P
0 g
s
.59731 .76575 m .61459 .77422 L .60238 .78697 L p .682 .71 .87 r
F P
0 g
s
.60238 .78697 m .58515 .77859 L .59731 .76575 L p .682 .71 .87 r
F P
0 g
s
.54381 .62577 m .56127 .63471 L .54933 .64816 L p .684 .705 .863 r
F P
0 g
s
.54933 .64816 m .53191 .63932 L .54381 .62577 L p .684 .705 .863 r
F P
0 g
s
.6203 .62545 m .63751 .63439 L .62519 .64785 L p .684 .705 .863 r
F P
0 g
s
.62519 .64785 m .60802 .639 L .6203 .62545 L p .684 .705 .863 r
F P
0 g
s
.43231 .69414 m .45015 .70286 L .43875 .71598 L p .683 .708 .867 r
F P
0 g
s
.43875 .71598 m .42096 .70735 L .43231 .69414 L p .683 .708 .867 r
F P
0 g
s
.61433 .58925 m .63157 .59831 L .61926 .61196 L p .685 .704 .862 r
F P
0 g
s
.61926 .61196 m .60207 .60299 L .61433 .58925 L p .685 .704 .862 r
F P
0 g
s
.32074 .76256 m .33894 .77106 L .32809 .78384 L p .682 .71 .87 r
F P
0 g
s
.32809 .78384 m .30994 .77543 L .32074 .76256 L p .682 .71 .87 r
F P
0 g
s
.39725 .76225 m .41521 .77075 L .40398 .78354 L p .682 .71 .87 r
F P
0 g
s
.40398 .78354 m .38607 .77513 L .39725 .76225 L p .682 .71 .87 r
F P
0 g
s
.79646 .48429 m .81311 .49371 L .79989 .50788 L p .686 .7 .857 r
F P
0 g
s
.79989 .50788 m .78329 .49856 L .79646 .48429 L p .686 .7 .857 r
F P
0 g
s
.55035 .76164 m .56781 .77014 L .55581 .78294 L p .682 .71 .87 r
F P
0 g
s
.55581 .78294 m .5384 .77452 L .55035 .76164 L p .682 .71 .87 r
F P
0 g
s
.62692 .76133 m .64413 .76984 L .63175 .78264 L p .682 .71 .87 r
F P
0 g
s
.63175 .78264 m .61459 .77422 L .62692 .76133 L p .682 .71 .87 r
F P
0 g
s
.39115 .72611 m .40914 .73473 L .39793 .7477 L p .682 .709 .868 r
F P
0 g
s
.39793 .7477 m .38 .73917 L .39115 .72611 L p .682 .709 .868 r
F P
0 g
s
.85675 .76041 m .87321 .76892 L .85969 .78173 L p .682 .71 .87 r
F P
0 g
s
.85969 .78173 m .84327 .77331 L .85675 .76041 L p .682 .71 .87 r
F P
0 g
s
.57334 .62112 m .59074 .63009 L .57862 .64359 L p .684 .705 .863 r
F P
0 g
s
.57862 .64359 m .56127 .63471 L .57334 .62112 L p .684 .705 .863 r
F P
0 g
s
.5383 .68929 m .55582 .69804 L .54387 .71121 L p .683 .708 .867 r
F P
0 g
s
.54387 .71121 m .5264 .70255 L .5383 .68929 L p .683 .708 .867 r
F P
0 g
s
.34991 .75814 m .36805 .76666 L .35703 .77949 L p .682 .71 .87 r
F P
0 g
s
.35703 .77949 m .33894 .77106 L .34991 .75814 L p .682 .71 .87 r
F P
0 g
s
.53227 .65305 m .54982 .66192 L .5379 .67528 L p .683 .706 .865 r
F P
0 g
s
.5379 .67528 m .5204 .6665 L .53227 .65305 L p .683 .706 .865 r
F P
0 g
s
.65663 .75691 m .67377 .76544 L .66122 .77828 L p .682 .71 .87 r
F P
0 g
s
.66122 .77828 m .64413 .76984 L .65663 .75691 L p .682 .71 .87 r
F P
0 g
s
.60297 .61645 m .6203 .62545 L .60802 .639 L p .684 .705 .863 r
F P
0 g
s
.60802 .639 m .59074 .63009 L .60297 .61645 L p .684 .705 .863 r
F P
0 g
s
.83331 .61547 m .84988 .62448 L .83645 .63804 L p .684 .705 .863 r
F P
0 g
s
.83645 .63804 m .81991 .62912 L .83331 .61547 L p .684 .705 .863 r
F P
0 g
s
.37918 .7537 m .39725 .76225 L .38607 .77513 L p .682 .71 .87 r
F P
0 g
s
.38607 .77513 m .36805 .76666 L .37918 .7537 L p .682 .71 .87 r
F P
0 g
s
.45596 .75339 m .47379 .76195 L .46223 .77483 L p .682 .71 .87 r
F P
0 g
s
.46223 .77483 m .44445 .76636 L .45596 .75339 L p .682 .71 .87 r
F P
0 g
s
.53277 .75308 m .55035 .76164 L .5384 .77452 L p .682 .71 .87 r
F P
0 g
s
.5384 .77452 m .52087 .76605 L .53277 .75308 L p .682 .71 .87 r
F P
0 g
s
.44987 .71712 m .46773 .7258 L .45619 .73886 L p .682 .709 .868 r
F P
0 g
s
.45619 .73886 m .43839 .73027 L .44987 .71712 L p .682 .709 .868 r
F P
0 g
s
.84018 .75185 m .85675 .76041 L .84327 .77331 L p .682 .71 .87 r
F P
0 g
s
.84327 .77331 m .82674 .76483 L .84018 .75185 L p .682 .71 .87 r
F P
0 g
s
.82155 .54276 m .83818 .55202 L .82479 .56595 L p .685 .702 .86 r
F P
0 g
s
.82479 .56595 m .8082 .55679 L .82155 .54276 L p .685 .702 .86 r
F P
0 g
s
.63271 .61176 m .64997 .62079 L .63751 .63439 L p .684 .705 .863 r
F P
0 g
s
.63751 .63439 m .6203 .62545 L .63271 .61176 L p .684 .705 .863 r
F P
0 g
s
.81566 .50634 m .83232 .51573 L .81895 .52985 L p .686 .701 .859 r
F P
0 g
s
.81895 .52985 m .80233 .52056 L .81566 .50634 L p .686 .701 .859 r
F P
0 g
s
.52067 .68048 m .5383 .68929 L .5264 .70255 L p .683 .708 .867 r
F P
0 g
s
.5264 .70255 m .50882 .69383 L .52067 .68048 L p .683 .708 .867 r
F P
0 g
s
.40855 .74925 m .42656 .75783 L .41521 .77075 L p .682 .71 .87 r
F P
0 g
s
.41521 .77075 m .39725 .76225 L .40855 .74925 L p .682 .71 .87 r
F P
0 g
s
.56241 .74863 m .57992 .75722 L .56781 .77014 L p .682 .71 .87 r
F P
0 g
s
.56781 .77014 m .55035 .76164 L .56241 .74863 L p .682 .71 .87 r
F P
0 g
s
.87036 .74739 m .88686 .75598 L .87321 .76892 L p .682 .71 .87 r
F P
0 g
s
.87321 .76892 m .85675 .76041 L .87036 .74739 L p .682 .71 .87 r
F P
0 g
s
.81663 .60641 m .83331 .61547 L .81991 .62912 L p .684 .705 .863 r
F P
0 g
s
.81991 .62912 m .80327 .62015 L .81663 .60641 L p .684 .705 .863 r
F P
0 g
s
.55032 .6759 m .56789 .68473 L .55582 .69804 L p .683 .708 .867 r
F P
0 g
s
.55582 .69804 m .5383 .68929 L .55032 .6759 L p .683 .708 .867 r
F P
0 g
s
.43802 .74478 m .45596 .75339 L .44445 .76636 L p .682 .71 .87 r
F P
0 g
s
.44445 .76636 m .42656 .75783 L .43802 .74478 L p .682 .71 .87 r
F P
0 g
s
.51508 .74447 m .53277 .75308 L .52087 .76605 L p .682 .71 .87 r
F P
0 g
s
.52087 .76605 m .50323 .75752 L .51508 .74447 L p .682 .71 .87 r
F P
0 g
s
.66925 .74385 m .68644 .75247 L .67377 .76544 L p .682 .71 .87 r
F P
0 g
s
.67377 .76544 m .65663 .75691 L .66925 .74385 L p .682 .71 .87 r
F P
0 g
s
.8235 .74323 m .84018 .75185 L .82674 .76483 L p .682 .71 .87 r
F P
0 g
s
.82674 .76483 m .8101 .75629 L .8235 .74323 L p .682 .71 .87 r
F P
0 g
s
.80481 .53344 m .82155 .54276 L .8082 .55679 L p .685 .702 .86 r
F P
0 g
s
.8082 .55679 m .7915 .54756 L .80481 .53344 L p .685 .702 .86 r
F P
0 g
s
.509 .70807 m .52672 .7168 L .51485 .72996 L p .682 .709 .868 r
F P
0 g
s
.51485 .72996 m .49718 .72131 L .509 .70807 L p .682 .709 .868 r
F P
0 g
s
.84684 .60169 m .86345 .61079 L .84988 .62448 L p .684 .705 .863 r
F P
0 g
s
.84988 .62448 m .83331 .61547 L .84684 .60169 L p .684 .705 .863 r
F P
0 g
s
.65726 .67098 m .67451 .67985 L .66188 .6932 L p .683 .708 .867 r
F P
0 g
s
.66188 .6932 m .64468 .68442 L .65726 .67098 L p .683 .708 .867 r
F P
0 g
s
.46759 .7403 m .48547 .74894 L .47379 .76195 L p .682 .71 .87 r
F P
0 g
s
.47379 .76195 m .45596 .75339 L .46759 .7403 L p .682 .71 .87 r
F P
0 g
s
.65125 .63448 m .66853 .64348 L .65593 .65702 L p .683 .706 .865 r
F P
0 g
s
.65593 .65702 m .6387 .64811 L .65125 .63448 L p .683 .706 .865 r
F P
0 g
s
.83503 .52859 m .8517 .53794 L .83818 .55202 L p .685 .702 .86 r
F P
0 g
s
.83818 .55202 m .82155 .54276 L .83503 .52859 L p .685 .702 .86 r
F P
0 g
s
.79983 .59728 m .81663 .60641 L .80327 .62015 L p .684 .705 .863 r
F P
0 g
s
.80327 .62015 m .78652 .61111 L .79983 .59728 L p .684 .705 .863 r
F P
0 g
s
.7939 .56069 m .81072 .56995 L .79739 .58387 L p .685 .704 .862 r
F P
0 g
s
.79739 .58387 m .78061 .57472 L .7939 .56069 L p .685 .704 .862 r
F P
0 g
s
.49727 .7358 m .51508 .74447 L .50323 .75752 L p .682 .71 .87 r
F P
0 g
s
.50323 .75752 m .48547 .74894 L .49727 .7358 L p .682 .71 .87 r
F P
0 g
s
.5746 .73549 m .59216 .74416 L .57992 .75722 L p .682 .71 .87 r
F P
0 g
s
.57992 .75722 m .56241 .74863 L .5746 .73549 L p .682 .71 .87 r
F P
0 g
s
.65195 .73517 m .66925 .74385 L .65663 .75691 L p .682 .71 .87 r
F P
0 g
s
.65663 .75691 m .63937 .74832 L .65195 .73517 L p .682 .71 .87 r
F P
0 g
s
.80671 .73455 m .8235 .74323 L .8101 .75629 L p .682 .71 .87 r
F P
0 g
s
.8101 .75629 m .79335 .7477 L .80671 .73455 L p .682 .71 .87 r
F P
0 g
s
.88412 .73423 m .90065 .74292 L .88686 .75598 L p .682 .71 .87 r
F P
0 g
s
.88686 .75598 m .87036 .74739 L .88412 .73423 L p .682 .71 .87 r
F P
0 g
s
.56854 .69895 m .58612 .70775 L .57391 .721 L p .682 .709 .868 r
F P
0 g
s
.57391 .721 m .55637 .71228 L .56854 .69895 L p .682 .709 .868 r
F P
0 g
s
.6399 .66205 m .65726 .67098 L .64468 .68442 L p .683 .708 .867 r
F P
0 g
s
.64468 .68442 m .62737 .67558 L .6399 .66205 L p .683 .708 .867 r
F P
0 g
s
.52705 .73129 m .54479 .73999 L .53277 .75308 L p .682 .71 .87 r
F P
0 g
s
.53277 .75308 m .51508 .74447 L .52705 .73129 L p .682 .71 .87 r
F P
0 g
s
.68201 .73066 m .69924 .73936 L .68644 .75247 L p .682 .71 .87 r
F P
0 g
s
.68644 .75247 m .66925 .74385 L .68201 .73066 L p .682 .71 .87 r
F P
0 g
s
.83704 .73003 m .85376 .73874 L .84018 .75185 L p .682 .71 .87 r
F P
0 g
s
.84018 .75185 m .8235 .74323 L .83704 .73003 L p .682 .71 .87 r
F P
0 g
s
.78292 .5881 m .79983 .59728 L .78652 .61111 L p .684 .705 .863 r
F P
0 g
s
.78652 .61111 m .76965 .60202 L .78292 .5881 L p .684 .705 .863 r
F P
0 g
s
.8605 .58776 m .87715 .59695 L .86345 .61079 L p .684 .705 .863 r
F P
0 g
s
.86345 .61079 m .84684 .60169 L .8605 .58776 L p .684 .705 .863 r
F P
0 g
s
.66997 .6574 m .68726 .66636 L .67451 .67985 L p .683 .708 .867 r
F P
0 g
s
.67451 .67985 m .65726 .67098 L .66997 .6574 L p .683 .708 .867 r
F P
0 g
s
.85458 .55104 m .87126 .56036 L .85758 .57438 L p .685 .704 .862 r
F P
0 g
s
.85758 .57438 m .84094 .56516 L .85458 .55104 L p .685 .704 .862 r
F P
0 g
s
.55693 .72676 m .5746 .73549 L .56241 .74863 L p .682 .71 .87 r
F P
0 g
s
.56241 .74863 m .54479 .73999 L .55693 .72676 L p .682 .71 .87 r
F P
0 g
s
.63454 .72644 m .65195 .73517 L .63937 .74832 L p .682 .71 .87 r
F P
0 g
s
.63937 .74832 m .622 .73968 L .63454 .72644 L p .682 .71 .87 r
F P
0 g
s
.78981 .72581 m .80671 .73455 L .79335 .7477 L p .682 .71 .87 r
F P
0 g
s
.79335 .7477 m .77649 .73905 L .78981 .72581 L p .682 .71 .87 r
F P
0 g
s
.86747 .72549 m .88412 .73423 L .87036 .74739 L p .682 .71 .87 r
F P
0 g
s
.87036 .74739 m .85376 .73874 L .86747 .72549 L p .682 .71 .87 r
F P
0 g
s
.62848 .68977 m .64593 .69863 L .63337 .71197 L p .682 .709 .868 r
F P
0 g
s
.63337 .71197 m .61597 .7032 L .62848 .68977 L p .682 .709 .868 r
F P
0 g
s
.81328 .58331 m .83012 .59253 L .81663 .60641 L p .684 .705 .863 r
F P
0 g
s
.81663 .60641 m .79983 .59728 L .81328 .58331 L p .684 .705 .863 r
F P
0 g
s
.77787 .65241 m .79483 .6614 L .78151 .67494 L p .683 .708 .867 r
F P
0 g
s
.78151 .67494 m .76459 .66604 L .77787 .65241 L p .683 .708 .867 r
F P
0 g
s
.58691 .72221 m .60452 .73097 L .59216 .74416 L p .682 .71 .87 r
F P
0 g
s
.59216 .74416 m .5746 .73549 L .58691 .72221 L p .682 .71 .87 r
F P
0 g
s
.77189 .61565 m .78888 .62477 L .77559 .6385 L p .683 .706 .865 r
F P
0 g
s
.77559 .6385 m .75864 .62947 L .77189 .61565 L p .683 .706 .865 r
F P
0 g
s
.89801 .72094 m .91459 .72971 L .90065 .74292 L p .682 .71 .87 r
F P
0 g
s
.90065 .74292 m .88412 .73423 L .89801 .72094 L p .682 .71 .87 r
F P
0 g
s
.84374 .57851 m .8605 .58776 L .84684 .60169 L p .684 .705 .863 r
F P
0 g
s
.84684 .60169 m .83012 .59253 L .84374 .57851 L p .684 .705 .863 r
F P
0 g
s
.617 .71765 m .63454 .72644 L .622 .73968 L p .682 .71 .87 r
F P
0 g
s
.622 .73968 m .60452 .73097 L .617 .71765 L p .682 .71 .87 r
F P
0 g
s
.69489 .71733 m .71216 .72613 L .69924 .73936 L p .682 .71 .87 r
F P
0 g
s
.69924 .73936 m .68201 .73066 L .69489 .71733 L p .682 .71 .87 r
F P
0 g
s
.77279 .71701 m .78981 .72581 L .77649 .73905 L p .682 .71 .87 r
F P
0 g
s
.77649 .73905 m .75951 .73034 L .77279 .71701 L p .682 .71 .87 r
F P
0 g
s
.68885 .68053 m .70615 .68945 L .69325 .70288 L p .682 .709 .868 r
F P
0 g
s
.69325 .70288 m .67599 .69405 L .68885 .68053 L p .682 .709 .868 r
F P
0 g
s
.87431 .5737 m .891 .58298 L .87715 .59695 L p .684 .705 .863 r
F P
0 g
s
.87715 .59695 m .8605 .58776 L .87431 .5737 L p .684 .705 .863 r
F P
0 g
s
.7608 .64336 m .77787 .65241 L .76459 .66604 L p .683 .708 .867 r
F P
0 g
s
.76459 .66604 m .74756 .65708 L .7608 .64336 L p .683 .708 .867 r
F P
0 g
s
.6472 .71307 m .66466 .72189 L .65195 .73517 L p .682 .71 .87 r
F P
0 g
s
.65195 .73517 m .63454 .72644 L .6472 .71307 L p .682 .71 .87 r
F P
0 g
s
.80327 .71243 m .82021 .72126 L .80671 .73455 L p .682 .71 .87 r
F P
0 g
s
.80671 .73455 m .78981 .72581 L .80327 .71243 L p .682 .71 .87 r
F P
0 g
s
.79128 .63865 m .80829 .64773 L .79483 .6614 L p .683 .708 .867 r
F P
0 g
s
.79483 .6614 m .77787 .65241 L .79128 .63865 L p .683 .708 .867 r
F P
0 g
s
.6775 .70848 m .69489 .71733 L .68201 .73066 L p .682 .71 .87 r
F P
0 g
s
.68201 .73066 m .66466 .72189 L .6775 .70848 L p .682 .71 .87 r
F P
0 g
s
.75566 .70816 m .77279 .71701 L .75951 .73034 L p .682 .71 .87 r
F P
0 g
s
.75951 .73034 m .74243 .72158 L .75566 .70816 L p .682 .71 .87 r
F P
0 g
s
.91205 .70752 m .92866 .71638 L .91459 .72971 L p .682 .71 .87 r
F P
0 g
s
.91459 .72971 m .89801 .72094 L .91205 .70752 L p .682 .71 .87 r
F P
0 g
s
.74964 .67122 m .7668 .68021 L .75354 .69373 L p .682 .709 .868 r
F P
0 g
s
.75354 .69373 m .73642 .68484 L .74964 .67122 L p .682 .709 .868 r
F P
0 g
s
.90017 .63359 m .91684 .64271 L .90281 .65643 L p .683 .708 .867 r
F P
0 g
s
.90281 .65643 m .88618 .6474 L .90017 .63359 L p .683 .708 .867 r
F P
0 g
s
.70791 .70387 m .72522 .71275 L .71216 .72613 L p .682 .71 .87 r
F P
0 g
s
.71216 .72613 m .69489 .71733 L .70791 .70387 L p .682 .71 .87 r
F P
0 g
s
.89422 .59656 m .91091 .60581 L .89691 .61973 L p .683 .706 .865 r
F P
0 g
s
.89691 .61973 m .88025 .61057 L .89422 .59656 L p .683 .706 .865 r
F P
0 g
s
.73842 .69924 m .75566 .70816 L .74243 .72158 L p .682 .71 .87 r
F P
0 g
s
.74243 .72158 m .72522 .71275 L .73842 .69924 L p .682 .71 .87 r
F P
0 g
s
.81687 .69892 m .83385 .70784 L .82021 .72126 L p .682 .71 .87 r
F P
0 g
s
.82021 .72126 m .80327 .71243 L .81687 .69892 L p .682 .71 .87 r
F P
0 g
s
.89533 .6986 m .91205 .70752 L .89801 .72094 L p .682 .71 .87 r
F P
0 g
s
.89801 .72094 m .88133 .71212 L .89533 .6986 L p .682 .71 .87 r
F P
0 g
s
.81085 .66185 m .82787 .6709 L .81425 .68452 L p .682 .709 .868 r
F P
0 g
s
.81425 .68452 m .79728 .67556 L .81085 .66185 L p .682 .709 .868 r
F P
0 g
s
.88339 .62441 m .90017 .63359 L .88618 .6474 L p .683 .708 .867 r
F P
0 g
s
.88618 .6474 m .86943 .63832 L .88339 .62441 L p .683 .708 .867 r
F P
0 g
s
.76904 .6946 m .78621 .70355 L .77279 .71701 L p .682 .71 .87 r
F P
0 g
s
.77279 .71701 m .75566 .70816 L .76904 .6946 L p .682 .71 .87 r
F P
0 g
s
.92623 .69396 m .94288 .70291 L .92866 .71638 L p .682 .71 .87 r
F P
0 g
s
.92866 .71638 m .91205 .70752 L .92623 .69396 L p .682 .71 .87 r
F P
0 g
s
.91431 .61963 m .93101 .62884 L .91684 .64271 L p .683 .708 .867 r
F P
0 g
s
.91684 .64271 m .90017 .63359 L .91431 .61963 L p .683 .708 .867 r
F P
0 g
s
.79977 .68994 m .81687 .69892 L .80327 .71243 L p .682 .71 .87 r
F P
0 g
s
.80327 .71243 m .78621 .70355 L .79977 .68994 L p .682 .71 .87 r
F P
0 g
s
.8785 .68962 m .89533 .6986 L .88133 .71212 L p .682 .71 .87 r
F P
0 g
s
.88133 .71212 m .86454 .70323 L .8785 .68962 L p .682 .71 .87 r
F P
0 g
s
.8725 .65241 m .88936 .66152 L .87539 .67524 L p .682 .709 .868 r
F P
0 g
s
.87539 .67524 m .85856 .66622 L .8725 .65241 L p .682 .709 .868 r
F P
0 g
s
.8306 .68527 m .84763 .69428 L .83385 .70784 L p .682 .71 .87 r
F P
0 g
s
.83385 .70784 m .81687 .69892 L .8306 .68527 L p .682 .71 .87 r
F P
0 g
s
.86155 .68058 m .8785 .68962 L .86454 .70323 L p .682 .71 .87 r
F P
0 g
s
.86454 .70323 m .84763 .69428 L .86155 .68058 L p .682 .71 .87 r
F P
0 g
s
.94056 .68025 m .95725 .6893 L .94288 .70291 L p .682 .71 .87 r
F P
0 g
s
.94288 .70291 m .92623 .69396 L .94056 .68025 L p .682 .71 .87 r
F P
0 g
s
.93458 .64291 m .95129 .65208 L .93695 .66589 L p .682 .709 .868 r
F P
0 g
s
.93695 .66589 m .92027 .65681 L .93458 .64291 L p .682 .709 .868 r
F P
0 g
s
.8926 .67587 m .90947 .68494 L .89533 .6986 L p .682 .71 .87 r
F P
0 g
s
.89533 .6986 m .8785 .68962 L .8926 .67587 L p .682 .71 .87 r
F P
0 g
s
.92377 .67115 m .94056 .68025 L .92623 .69396 L p .682 .71 .87 r
F P
0 g
s
.92623 .69396 m .90947 .68494 L .92377 .67115 L p .682 .71 .87 r
F P
0 g
s
.95504 .66641 m .97176 .67554 L .95725 .6893 L p .682 .71 .87 r
F P
0 g
s
.95725 .6893 m .94056 .68025 L .95504 .66641 L p .682 .71 .87 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 311.063},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0001=b000`400?l00000o`00003oo`3AcJTQ
0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ
0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00LP3AcJT00d000000dLfY0=7=Z@2[0=7=Z@00L@3A
cJT00`000000/JgD0000002/0=7=Z@00L@3AcJT00`000000/JgD0;6]e00200000:X0dLfY001`0=7=
Z@030000002a[M@0/JgD00<0/JgD00<000000=7=Z@3AcJT0Y`3AcJT006l0dLfY00<000000;6]e02a
[M@00`2a[M@400000:L0dLfY001^0=7=Z@<00000102a[M@01000001000000=I_AP3FKdH200000:D0
dLfY001^0=7=Z@80000000@0eW18000000000000/JgD0P0000000`2a[M@00000000000020=I_AP03
0000003AcJT0dLfY0:80dLfY001]0=7=Z@030000000002=0000000<0eW1800<0000000009`000000
0`2a[M@500000:80dLfY001]0=7=Z@80000000@0/JgD0000003FL4P0eW180P0000060;6]e0030000
003FKdH0eVm600800000X03AcJT006`0dLfY00<0000000008`0000000P2a[M@4000000D0/JgD0P00
00040=I_AP030000003AcJT0dLfY09d0dLfY001[0=7=Z@<000001@2a[M@2000000D0/JgD00<00000
@000003FKdH00`3FKdH3000009d0dLfY001[0=7=Z@8000001@2a[M@00`000000/JgD0;6]e0020000
0080/JgD0P0000000`2a[M@000000=I_AP020=I_AP030000003FKdH0eVm600800000V`3AcJT006X0
dLfY0P0000000`3FLD/000000;6]e0030;6]e0030000002a[M@0/JgD0080/JgD0P000000100002/0
00000;6]e02a[M@4000000<0eVm60`00002I0=7=Z@00J@3AcJT00`000000000S@00000020=IaB`80
000000<0/JgD0000002a[M@0102a[M@3000000D0/JgD00<000000=I_AP3FKdH00P3FKdH00`000000
eVm60=I_AP02000009L0dLfY001X0=7=Z@<0000000<0/JgD0000000000000P3FLD/00`000000/JgD
0;6]e0040;6]e0<00000102a[M@2000000@0eVm600<000000=I_AP3FKdH00P3FKdH00`000000dLfY
0=7=Z@2D0=7=Z@00J03AcJT3000000<0/JgD1@0000030;6]e0030000000002/0000000D0/JgD0P00
00040=I_AP030000003FKdH0eVm60080eVm60P00002E0=7=Z@00I`3AcJT3000000H0/JgD00<00000
0=IaB`3FLD/00P0000000`2a[M@000000000:`02000000<0/JgD00<000000000;d000000103FKdH0
0`000000eVm60=I_AP020=I_AP040000003FKdH00000000009<0dLfY001V0=7=Z@040000000002<0
0000000000D0/JgD0P0000040=IaB`050000000002/0000[@000003FL4P00P000000102a[M@00000
0000002a[]@200000080eVm600<000000=I_AP3FKdH00P3FKdH01@000000eVm60=I_AP3FKdH00000
0980dLfY001U0=7=Z@80000000<0000S0000000000001@2a[M@2000000@0eW5;00D000000000:`00
0000/JkD000000020=I`B0030000000002l0000000<0/JkD0`0000040=I_AP040000003FKdH0eVm6
0=I_AP<00000T03AcJT006D0dLfY0P0000000`0002<000000=MbC@0200000080/JgD00<000000000
9d000000103FLD/00`000000000[000000020;6^e0@000001P2a[]@00`000000eVm60=I_AP020=I_
AP050000003FKdH0eVm60=I_AP0000000P3FKdH2000008h0dLfY001T0=7=Z@050000000002<00000
00008d0000000`3GLTd20000000300009`000000/JkD008000000P3FLD/2000000D0/JkD00<00000
0;6^e02a[]@0102a[]@2000000@0eVm600D000000=I_AP3FKdH0eVm6000000040=I_AP030000003A
cJT0dLfY08/0dLfY001S0=7=Z@060000000002<0000000008`000000/JkD0P0000020=MbC@030000
000002L0000000<0/JkD100000040;6^e0040000002a[]@00000000000@0/JkD00<00000@000003F
KdH00`3FKdH01@000000eVm60=I_AP3FKdH0000000@0eVm60`00002;0=7=Z@00H`3AcJT200008`03
0000000002<0000000<0/JkD100000060;6^e0030000002a[]@0/JkD00<0/JkD00@000000;6^e02a
[]@0/JkD0P000000102a[]@000000000002a[]D200000080eVm600D000000=I_AP3FKdH0eVm60000
00040=I_AP030000003FKdH0eVm600800000R@3AcJT00680dLfY0P0000000`0002<0000000000006
0;6^e0030000002a[]@0/JkD00@0/JkD00@000000;6]e000000000000P2a[]@00`000000/JkD0;6^
e0040;6^e0030000000003<0000000<0/JkE0`0000030=I_AP030000003FKdH0eVm60080eVm600@0
00000=I_AP3FKdH0eVm60`0000270=7=Z@00HP3AcJT20000000300008`000000/JkD00D0/JkD00@0
00000;6^e00000000000102a[]@010000000/JgD0;6]e02a[M@2000000H0/JkD0`0000060;6^e@05
0000003FKdH0eVm60=I_AP000000103FKdH01@000000eVm60=I_AP3FKdH000000080eVm60P000025
0=7=Z@00H@3AcJT010000000000S0000000002<3000000@0/JkD00@000000;6^e02a[]@0/JkD0P00
00000`2a[]@000000=MbC@02000000030;6]e0000000/JkD00800000102a[]@2000000H0/JkE00<0
00000=I_AP3FKdH00P3FKdH00`000000eVm60=I_AP020=I_AP050000003FKdH0eVm60=I_AP000000
103FKdH00`000000dLfY0=7=Z@220=7=Z@00H03AcJT01P000000000S00008`000000000S00000080
eW=?0P0000000`2a[]@000000;6^e0050;6^e0070000003GLTd0eg9=0=MbC@000010000000000003
0;6^e080000000<0/JkD0000000003<00`0000040;6^e@03000004000000eVm60080eVm600<00000
0=I_AP3FKdH00P3FKdH01@000000eVm60=I_AP3FKdH0000000@0eVm60P0000230=7=Z@00H03AcJT0
0`000000000S0000000200008`03@000003FLdl0eW=?0080eW=?00<000000;6^e02a[]@0102a[]@0
0`000000/JkD000000020=MbC@8000001P2a[]@010000000000c0000<`0000020=I`B080000000D0
/JkE000000000000/JkE000000020=I_AP030000003FKdH0eVm60080eVm600D000000=I_AP3FKdH0
eVm6000000040=I_AP040000003FKdH0000000000840dLfY001O0=7=Z@070000000002<0000S0000
000002<000000;6^e@0200000080eW=?0`0000040;6^e0030000002a[]@0/JkD00@000001@2a[]@2
00000080000c00=000000=I`B03FL4P00P3FL4P00`000000000f000000020;6^e@<00000103FKdH0
1@000000eVm60=I_AP3FKdH0000000@0eVm600@000000=I_AP3FKdH0eVm60P00001o0=7=Z@00GP3A
cJT01`000000000S0000000002<0000000008`0000000`2a[]D300000080eW=?0P0000000`2a[]@0
00000;6^e0040;6^e08000001@2a[]@2000000030000<`000000/JkE008000000P3FL4P2000000D0
/JkE00<000000=I_AP3FKdH00P3FKdH01@000000eVm60=I_AP3FKdH0000000@0eVm600H000000=I_
AP3FKdH0eVm60000003FKdH2000007d0dLfY001M0=7=Z@050000000002<0000S0000000002<00P00
00060;6^e@040000003FLdl0eW=?0=IcC`8000001@2a[]@00`000000/JkD0;6^e00200000080/JkD
00D000000000<`000000000c000000030;6^e@@00000102a[]D2000000@0eVm600D000000=I_AP3F
KdH0eVm6000000040=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH2000007/0dLfY001M0=7=
Z@060000000002<0000S0000000002<000001P2a[]D2000000<0eW=?00<000000=IcC`000000102a
[]@00`000000/JkD0;6^e0020;6^e08000000P0003<2000000H0/JkE00<000000;6^e@2a[]D00`2a
[]D00`000000eVm60=I_AP030=I_AP040000003FKdH0eVm60=I_AP8000000`3FKdH01@000000eVm6
0=I_AP3FKdH0000000@0eVm60P00001j0=7=Z@00G03AcJT01P000000000S00008`0002<000000000
8`<00000102a[]D00`00001000000=IcC`020=IcC`030000003FLdl0eW=?0080000000<0/JkD0000
002a[]@0102a[]@200000080000c00<000000;6^e@2a[]D0102a[]D00`000000/JkE000000030;6^
e@030000000103Y0000000@0eVm600<000000=I_AP3FKdH00P3FKdH01@000000eVm60=I_AP3FKdH0
000000<0eVm600<000000=I_AP3FKdH00P3FKdH010000000eVm600000000001h0=7=Z@00F`3AcJT0
0`000000000S00008`0200008`030000000002<000000080eW=A0P0000001@2a[]D000000000002a
[]D000000080eW=?00<000000=IcC`3FLdl00P3FLdl2000000D0/JkD0P0000020000<`<00000102a
[]D00`000000/JkE0;6^e@02000000040;6^e@00000000000;6^eP8000000P3FKdH00`000000eVm6
0=I_AP020=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH00`000000eVm60=I_AP020=I_AP05
0000003FKdH0eVm60=I_AP000000M`3AcJT005X0dLfY00@0000000008`0002<000000P0002<00`00
0000000S@00000040=IcD@030000000002L000000080/JkE0`0000040=IcC`@000000P2a[]@00`00
0000000c000000020000<`<0eW5;0P0000000`2a[]D000000;6^e@040;6^e@030000000103X00000
00<0/JkF0`0000040=I_AP050000003FKdH0eVm60=I_AP000000103FKdH01@000000eVm60=I_AP3F
KdH0000000<0eVm60P00001f0=7=Z@00FP3AcJT02@000000000S00008`000000000S0000000002<0
00000;6^e@0200000080eW=A0P0000050;6^e@030000003FLdl0eW=?0080eW=?00@000000=IcC`3F
Ldl0eW=?0P0000020000<`040000000003<0000c@00000<0eW5;0P0000050;6^e@<000001P2a[]H0
0`000000eVm60=I_AP020=I_AP050000003FKdH0eVm60=I_AP000000103FKdH01@000000eVm60=I_
AP3FKdH0000000<0eVm600@000000=I_AP0000000000M03AcJT005T0dLfY00T0000000008`0002<0
000S0000000002<0000000008`0000000`2a[]D4000000@0/JkE0P0000040=IcC`030000003FLdl0
eW=?0080eW=?00P000000000<`0003<000000000<`000000/JkF00000080eW5;00<000000=IaB`00
0000102a[]D2000000H0/JkF00<000000=I_AP3FKdH00`3FKdH00`000000eVm60=I_AP020=I_AP05
0000003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm60P00001b
0=7=Z@00F03AcJT00`000000000S0000000200008`040000000002<00000000000H0/JkE00<00000
0;6^e@2a[]D00`2a[]D00`000000eW=?0=IcC`030=IcC`030000003FLdl0eW=?0080eW=?00H00000
0000<`0003<000000000<`0000020;6^eP<000000P3FLD/2000000030;6^e@0000000@0j00<00000
102a[]H00`00001000000=I_AP030=I_AP030000003FKdH0eVm60080eVm600D000000=I_AP3FKdH0
eVm6000000030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH010000000eVm600000000001`
0=7=Z@00F03AcJT200008`060000000002<0000S0000000002<000001P2a[]D010000000/JkE0000
000000020;6^e@030000000002]0000000@0eW=?00<000000=IcC`3FLdl00P3FLdl00`000000000c
0000<`02000000D0/JkF00<000000=IaB`3FLD/00P3FLD/00`0000000@0j0040>P030=I`B0800000
00@0/JkF000000000000/JkF0P0000020=I_AP030000003FKdH0eVm60080eVm600D000000=I_AP3F
KdH0eVm6000000030=I_AP8000000P3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm60P00001^
0=7=Z@00E`3AcJT010000000000S00008`00000200008`030000000002<0000000800000102a[]D0
10000000/JkE0;6^e@2a[]D2000000030000:`000000/JkF008000000P3FLdl00`000000eW=?0=Ic
C`020=IcC`040000000003<0000c000000D0/JkF00<000000=IaB`3FLD/00`3FLD/0100000000@0j
0040>T0000040=I`B0030000000503d0000000<0/JkF0`0000040=I_AP050000003FKdH0eVm60=I_
AP0000000`3FKdH200000080eVm60P0000020=I_AP030000003FKdH0eVm60080eVm60P00001]0=7=
Z@00E`3AcJT010000000000S00008`00000200008`030000000002<0eWAC0080eWAC0P0000000`2a
[]D000000;6^e@040;6^e@030000000002/0000000<0/JkF0`0000040=IcC`030000000003<0000c
00800000102a[]H00`00001000000=IaB`030=IaB`040000000103X000000;6^eP8000000P3FL4P2
000000H0/JkF00<000000=I_AP3FKdH00P3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm60P00
00020=I_AP8000000P3FKdH00`000000eVm60=I_AP020=I_AP040000003FKdH00000000006/0dLfY
001F0=7=Z@8000000P0002<01`000000000S00008`000000000S@000000000000`3FM5<2000000@0
/JkE0`0000060;6^eP030000003FLdl0eW=?0080eW=?00<000000000<`0003<00P3GLTd200000004
0;6^eP00000000000;6^eP8000000P3FLD/00`0000000@0j000000030;6^eP@000001@2a[]H00`00
0000eVm60=I_AP030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH2000000<0eVm600<00000
0=I_AP3FKdH00P0000030=I_AP050000003FKdH0eVm60=I_AP000000JP3AcJT005D0dLfY00<00000
00008`0000000P0002<01@000000000S0000000002<000000080/JkF0P0000000`3FM5<000000=Id
D`0200000080/JkE0P0000060;6^eP030000003FLdl0eW=?00<0eW=?00@000000000<`0003=00000
0`3GLTd00`000000000f000000030;6^eP@000001P2a[]H2000000D0/JkF00<000000=I_AP3FKdH0
0`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm60P0000030=I_AP050000003FKdH0eVm60=I_
AP0000000`3FKdH010000000eVm60=I_AP3FKdH2000006T0dLfY001E0=7=Z@030000000002<00000
0080000S00D0000000008`000000000S000000040;6^eP8000000`3FM5<2000000040000:`000000
0000000000@0/JkF00<00000@000003FLdl00`3FLdl01@000000000c0000002a[]H000000080eg9=
0P0000060;6^eP030000002a[]H0/JkF00@0/JkF00<000000;6^eP2a[]H00P0000020;6^eP030000
00090410000000@0eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP8000000`3FKdH01@000000
eVm60=I_AP3FKdH0000000<0eVm60P0000020=I_AP040000003FKdH00000000006L0dLfY001D0=7=
Z@050000000002<0000S0000000002<00P0000000`0002<00000000000050;6^eP030000003FM5<0
eWAC00<0eWAC00<000000000:`3FLe400P3FLe42000000040;6^eP00000000000;6^eP8000000P3F
Ldl00`000000000c000000020;6^eP@000001@2a[]H010000000/JkF0000000000040;6^eP030000
002a[]H0/JkF0080/JkF0P0000000`09040000000;6_eP0200000080eVm600D000000=I_AP3FKdH0
eVm6000000040=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH01P000000eVm60=I_AP3FKdH0
7P1A00000080eVm600@000000=I_AP3FKdH0eVm60P00001U0=7=Z@00D`3AcJT01P000000000S0000
000002<0000000008`80000000<0000S0000002a[]H01@2a[]H00`000000eWAC0=IdD`020=IdD`05
0000000002/0000[@000000000000`3FLe400`000000000_000000030;6^eP@000001@2a[]H20000
00D0/JkF00@000000;6^eP2a[]H0/JkF0P0000000`2a[]H000000;6^eP040;6^eP80000000<02@10
0000002a[mH00P2a[mH3000000<0eVm600<000000=I_AP3FKdH00P3FKdH01@000000eVm60=I_AP3F
KdH0000000<0eVm600<000000=I_AP3FKdH00P3FKdH010000000eVm60=I_AP0000030=I_AP040000
003FKdH00000000006<0dLfY001B0=7=Z@070000000002<0000S0000000002<0000000008`020000
000400008`3FMED00000000000<0/JkF00<00000@000003FM5<00`3FM5<00`000000000[00000002
0;6^eP80000000<0eW=A0000000000001P2a[]H00`000000/JkF0;6^eP030;6^eP030000002a[]H0
/JkF008000000P2a[]H300000080/JkF00<0000000D0?@0000001P2a[]H3000000H0/JoF00<00000
0=I_AP3FKdH00P3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0eVm6
000000040=I_AP050000003FKdH0eVm60=I_AP0000000P3FKdH010000000eVm60=I_AP3FKdH20000
0640dLfY001B0=7=Z@070000000002<0000S0000000002<0000000008`020000000400008d000000
eWEE0=IeE@80000000<0/JkF0000002a[]H00P0000020=IdD`030000000002/0000000@0/JkF0P00
00060;6^eP030000002a[]D0000000@0/JkF00<000000;6^eP2a[]H00P2a[]H2000000<0eg9=00D0
0000@000000503d000000;6^eP02000000<0/JkF00<0000000T0@00000001P2a[mH00`000000eVm6
0=I_AP030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH00000
00@0eVm600D000000=I_AP3FKdH0eVm6000000020=I_AP030000003FKdH0eVm60080eVm60P00001P
0=7=Z@00D@3AcJT03@000000000S00008`0002<0000000008`000000000S0000000002<000000;6^
eP0000000P3FMED3000000<0/JkF100000050;6^eP040000002a[]H00000000000@0/JkF00<00000
0;6^e@0000000P0000000`2a[]H000000;6^eP040;6^eP040000002a[]H0000000000080eg9=00<0
000000D0?@0000000`2a[]H2000000050;6^eP0000002@100=I`B0000000102a[mH00`0000003@13
@00000040=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH00000
00@0eVm600D000000=I_AP3FKdH0eVm6000000020=I_AP8000000`3FKdH010000000eVm600000000
001N0=7=Z@00D03AcJT00`000000000S0000000200008`8000000P0002<00`000000000S00000002
0;6^eP@000001P2a[]H00`000000/JkF0;6^eP040;6^eP040000002a[]H0/JkF0;6^eP80000000D0
/JkF0000002a[]D0/JkE000000020;6^e@8000001@2a[]H010000000/JkF0;6^eP2a[]H4000000H0
/JkF00<0000000T0@00904000P3FL4P2000000050;6_eP0000003@130000002a[mH00P0000020=I_
AP050000003FKdH0eVm60=I_AP0000000`3FKdH200000080eVm600<000000=I_AP3FKdH00P3FKdH0
1@000000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP030000
003AcJT0dLfY05/0dLfY001@0=7=Z@80000S00<0000000008`0002<00P00000200008`8000001@2a
[]H00`000000/JkF0;6^eP040;6^eP040000002a[]H00000000000<0/JkF00<000000;6^eP2a[]H0
102a[]H010000000/JkE0;6^e@0000050;6^e@8000000P2a[]H00`000000/JkF0;6^eP040;6^eP03
0000002a[]H0/JkF00@0/JkF0P00000200T0@004@000003FL4P0eW180=I`B080000000<03@130000
002a[mH00P2a[mH3000000<0eVm600@000000=I_AP3FKdH0eVm60P0000020=I_AP8000000`3FKdH0
1@000000eVm60=I_AP3FKdH0000000<0eVm600<000000=I_AP3FKdH00P3FKdH00`000000eVm60=I_
AP03000005/0dLfY001?0=7=Z@090000000002<0000S0000000002<0000000008`000000000S00<0
0000102a[]H010000000/JkF0000000000040;6^eP040000002a[]H0/JkF0;6^eP80000000<0/JkF
0000002a[]H0102a[]H3000000030;6^e@000000/JkE00<0/JkE0P0000000`0103X0000000000006
0;6^eP030000002a[]H0000000@0/JkF00H0000000T0@00000002@100000002a[mH200000080eW18
0P0000060;6_eP050000003FKdH0eVm60=I_AP0000000`3FKdH200000080eVm60P0000030=I_AP05
0000003FKdH0eVm60=I_AP0000000`3FKdH00`000000eVm60=I_AP020=I_AP040000003FKdH0eVm6
00000080eVm60P00001I0=7=Z@00C`3AcJT02@000000000S00008`000000000S0000000002<00000
00008`02000000D0/JkF00@000000;6^eP2a[]H0/JkF0P0000000`2a[]H000000=IeE@0200000003
0;6^eP000000000_008000001@2a[]H010000000eWAC0000000000050;6^e@<000000P2a[]H20000
00@0/JkF00<000000;6^eP2a[]H00P0000001`2a[]H0000000T0@0090400000000T0@00000000`2a
[mH4000000D0/JoF00<000000=I_AP3FKdH00P3FKdH010000000eVm60=I_AP3FKdH200000080eVm6
00<06`1>0000003FKdH00P3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600<000000=I_AP3F
KdH00P3FKdH010000000eVm60=I_AP0000030=I_AP800000F03AcJT004h0dLfY0P00000200008`06
0000000002<0000000008`000000000S0P3FMUL200000080/JkF00<000000;6^eP2a[]H0102a[]H0
0`000000eWEE0=IeE@020=IeE@03@000000002l000000080/JkF0P0000020;6^eP80000000<0eWAC
0000003FM5<00P0000020;6^e@030000000103X0000000D0/JkF0P0000000`2a[]H000000;6^eP04
0;6^eP8000000P090402000000H0/JoF00<000000;6_eP2a[mH00`2a[mH00`00000040160=I_AP03
0=I_AP8000000P3FKdH2000000<0eVm600@000000=I_AP3FKdH0eVm60P0000020=I_AP050000003F
KdH0eVm60=I_AP000000103FKdH01@000000eVm60=I_AP3FKdH000000080eVm600@000000=I_AP00
00000000EP3AcJT004d0dLfY00<0000000008`0000000P0002<01`000000000S0000000002<00000
00008d0000000`3FMUL2000000H0/JkF00@000000;6^eP00000000000P3FMED00`000000000_0000
00040;6^eP8000000P2a[]H2000000<0eWAC0P0000020040>P<000000`2a[]H00`0000001@0m0000
00050;6^eP03000000090400000000802@1000<000000;6_eP2a[mH0102a[mH010000000/JoF0000
000000020;6_eP040000000@04H04016@00000<0eVm600@000000=I_AP3FKdH0eVm60P0000030=I_
AP040000003FKdH0eVm60=I_AP8000000P3FKdH200000080eVm600<000000=I_AP3FKdH00P3FKdH0
1@000000eVm60=I_AP3FKdH000000080eVm600D000000=I_AP3FKdH0eVm60000001E0=7=Z@00C@3A
cJT00`000000000S0000000200008`040000000002<0000000008`80000000<0/JoF000000000000
0P3FMUL3000000@0/JkF00@000000;6^eP2a[]H0/JkF100000050;6^eP030000002a[]H0/JkF0080
/JkF00<000000=IdD`3FM5<00P3FM5<00`0000000@0j0040>P030=IcD@80000000D0/JkF00000000
0000/JkF000000040;6^eP03000000090400000000802@1000<0eW5;0000002a[mH00`2a[mH00`00
0000/JoF0;6_eP020;6_eP8000000P0@04H00`000000/:oG000000020=I_AP030000003FKdH0eVm6
0080eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP8000000P3FKdH200000080eVm600<00000
0=I_AP3FKdH00P3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600<000000=I_AP3FKdH00`00
001C0=7=Z@00C03AcJT20000000400008`000000000S00000080000S0P0000000`0002<000000;6_
eP020;6_eP<000000P3FMUL2000000030;6^eP000000/JkF00D0/JkF0P0000050;6^eP050000002a
[]H0/JkF0;6^eP0000001@3FM5<01@0000000@0j0040>T000000000000<0eW=A00<0000000D0?@00
00000P2a[]H2000000050;6^eP0000002@1000T0@00000000P0904020=IaB`80000000<0/JoF0000
002a[mH0102a[mH2000000030100AP000000/:oG0080/:oG0`0000040=I_AP050000003FKdH0eVm6
0=I_AP0000000`3FKdH00`0N054000000=I_AP020=I_AP030000003FKdH0eVm6008000000`3FKdH0
1@000000eVm60=I_AP3FKdH0000000<0eVm600@000000=I_AP3FKdH000000P3FKdH200000540dLfY
001;0=7=Z@0:0000000002<0000000008`000000000S0000000002<0000000008`8000001P2a[mH0
0`000000eWIG0=IfE`020=IfE`030000002a[]H0/JkF00@0/JkF00<000000;6^eP2a[]H00P000002
0;6^eP<000000P2a[]H00`00001000000=IdD`030=IdD`030000000103X000000080/JkF0P000000
0`3FLe400000000000050;6^eP050000000904002@1000T0@00000000P0904001D000000eW5;0=Ia
B`3FLD/0000000H0/JoF0`0000060;2_e`030000003FKdH0eVm60080eVm600D000000=I_AP3FKdH0
eVm6000000040=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH0
000000<0eVm600D000000=I_AP3FKdH0eVm6000000020=I_AP8000000P3FKdH200000500dLfY001;
0=7=Z@@0000S00H0000000008`000000000S0000000002<2000000D0/JoF0P0000040=IfE`<00000
102a[]H00`000000/JkF0;6^eP020;6^eP8000000`3FMED01000001000000000002a[]H200000080
eWAC00<000000040>P000000102a[]H2000000D0/JkF0P00000300T0@00500000009040000000;2_
e`0000000P3FLD/3000000<0/JoF00<000000100AP0000001P2`[mL00`00000050190=I_AP030=I_
AP040000003FKdH0eVm60=I_AP8000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600<0
00000=I_AP3FKdH00P3FKdH010000000eVm60=I_AP0000030=I_AP050000003FKdH0eVm60=I_AP00
00000P3FKdH010000000eVm600000000001>0=7=Z@00BP3AcJT010000000000S00008`0002<20000
000500008`000000000S0000000002<00P0000050;6_eP030000003FMUL0eWIG00<0eWIG00<00000
0=IfE`3FMUL00P0000000`2a[]H000000;6^eP040;6^eP030000002a[]H000000080eWEE00<00000
0000=P0000000`2a[]H4000000D0/JkF00<000000;6^eP000000102a[]H2000000<02@1000<00000
00T0@00000000P2`[mL300000080eW5;0P000000102a[mH000000100AP0@04H2000000@0/:oG00<0
000001@0B@3FKdH00`3FKdH010000000eVm60=I_AP3FKdH2000000<0eVm600D000000=I_AP3FKdH0
eVm6000000030=I_AP030000003FKdH0eVm60080eVm600@000000=I_AP3FKdH000000`3FKdH01@00
0000eVm60=I_AP3FKdH0000000<0eVm600<000000=I_AP3FKdH00P00001<0=7=Z@00BP3AcJT01000
0000000S00008`0002<20000000500008`000000000S0000000002<00P3FMeT200000080/JoF00<0
000000009d000000103FMUL00`000000eWIG0=IfE`020=IfE`8000001@2a[]H00`000000/JkF0;6^
eP04000000H0/JkF0P0000050;6^eP030000002a[]H0/JkF0080000000@0/JkF0000000904000000
0`090402000000D0/:oG00<000000=IaB`3FLD/00P3FLD/01000000040160100AP0@04H20=I`B080
000000D0/:oG0000000D04T05019@00000030=I_AP040000003FKdH0eVm60=I_AP8000000`3FKdH0
1@000000eVm60=I_AP3FKdH0000000<0eVm600<000000=I_AP3FKdH00P3FKdH01@000000eVm60=I_
AP3FKdH000000080eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60000
003FKdH00P00001:0=7=Z@00B@3AcJT2000000<0000S00P0000000008`0002<0000000008`000000
000S@00000<0eWMI0P0000000`0002L000000;6_eP0200000080eWIG00<000000=IfE`3FMUL00P3F
MUL010000000eWIG0000000000020;6^eP030000002a[]H0/JkF00<0/JkF00<000000;6^eP2a[]H0
102a[]H00`000000/JkF0;6^eP0200000080/JkF00<000000;6^eP2a[]H00`2a[]H0100000002@10
00T0@000000300T0@0030000002`[mL0/:oG00<0/:oG00<0000000d0@`3FLD/00`3FLD/01@000000
40160100AP0@04I0000000<0eW1800D0000001@0B@0D04T000000;2_e`02000000030=I_AP000000
eVm60080eVm60P0000030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH00`000000eVm60=I_
AP020=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH010000000eVm60=I_AP0000030=I_AP04
0000003FKdH0eVm6000000<0eVm60P0000180=7=Z@00B03AcJT02@000000000S0000000002<00000
00008`000000000S0000000200008`80000000<0/JoF0000000000000P3FMeT00`000000000W0000
00030;6_eP<00000103FMUL010000000eWIG0=IfE`3FMUL2000000D0/JkF00@000000;6^eP000000
0000102a[]H00`000000/JkF0;6^eP020;6^eP8000001@2a[]H2000000802@1000H0000000T0@009
04002@100=MbC@0000040;2_e`030000000=04<0eW5;00<0eW5;00H000000100AP0@04H000000;2_
e`0000020=I`B0030000000D04T0000000@0/:oG0P0000030=I_AP8000000`3FKdH010000000eVm6
0=I_AP3FKdH200000080eVm600<000000=I_AP3FKdH00P3FKdH01@000000eVm60=I_AP3FKdH00000
00<0eVm600@000000=I_AP3FKdH000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm60P00
00170=7=Z@00B03AcJT03@000000000S00008`0002<0000000008`000000000S0000000002<00000
00008`0000000`2a[mH4000000H0/JoF00<000000=IfE`3FMUL00P3FMUL00`000000eWIG0=IfE`02
0=IfE`800000102a[]H010000000/JkF0;6^eP2a[]H2000000030;6^eP000000eWEE0080000000D0
/JkF000000000000/JkF000000040;6^eP8000000P090400100000002@1000T0@00904020=MbC@80
000000D0/:oG0000000=04<03@13@00000030=IaB`030000000@04H0000000<0/:oG100000050;2_
e`030000000H04`0eVm600<0eVm600@000000=I_AP3FKdH0eVm60P0000020=I_AP8000000P3FKdH2
000000<0eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP030000003FKdH0eVm6008000000P3F
KdH01@000000eVm60=I_AP3FKdH0000000<0eVm600@000000=I_AP0000000000A@3AcJT004L0dLfY
0P00000300008`060000000002<0000000008`000000000S0P0000060;6_eP030000002a[mH0/JoF
00@0/JoF00<000000=IfE`3FMUL00P3FMUL2000000@0eWIG00H000000=IfE`00000000000;6^eP00
00060;6^eP8000000`3FMED00d0000001@0m000000020;6^eP80000000@0/JkF0000000904000000
0P0904001@0000002@1000T0@0090410000000<0eg9=00D0000000d0@`0=04<000000;2_e`020000
00030=IaB`000000000000H0/:oG00<000000;2_e`2`[mL0102`[mL00`000000601<0=I_AP030=I_
AP040000003FKdH0eVm60=I_AP8000000P3FKdH200000080eVm60P0000030=I_AP050000003FKdH0
eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH000000080eVm600D000000=I_AP3FKdH0
eVm6000000040=I_AP040000003FKdH0eVm6000004@0dLfY00160=7=Z@030000000002<0000000<0
000S00L0000000008`000000000S0000000002<0000000H0/JoF00@000000;6_eP0000000000102a
[mH00`000000eWIG0=IfE`020=IfE`800000103FMUL01@000000eWIG0=IfE`3FMUL0000000H0/JkF
00<000000;6^eP2a[]H00P0000000`3FMED00000000000050;6^eP040000000904002@1000000080
2@1000H0000000T0@009040000000;2_e`0000020=MbC@030000000=04<0000000@0/:oG0P000006
0;2_e`040000002`[mL00000000000<0/:oG00@0000001P0C00H04a000000`3FKdH010000000eVm6
0=I_AP3FKdH200000080eVm60P0000020=I_AP0302D0EP000000eVm600<0eVm600@000000=I_AP3F
KdH000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600@000000=I_AP3FKdH00000103F
KdH00`000000eVm60=I_AP0300000480dLfY00150=7=Z@030000000002<0000S00@0000S0`000000
0`0002<0000000008`03000000@0/JoF00@000000;6_eP2a[mH0/JoF0P000000102a[mH00000@000
000000030=IfE`030000003FMUL0eWIG00<0eWIG00@000000=IfE`3FMUL0eWIG0`0000040;6^eP03
0000002a[]H0/JkF0080/JkF0P0000050;6^eP8000000P0904001P0000002@1000T0@00000002@10
000000<0/:oG100000050;2_e`040000002`[mL00000000000@0/:oG00@000000;2_e`2`[mL0/:oG
0P0000001P2`[mL0000001P0C0000000/;3G00000080eVm600@000000=I_AP3FKdH0eVm60P000003
0=I_AP050000003FKdH0eVm60=I_AP000000103FKdH010000000eVm60=I_AP0000030=I_AP050000
003FKdH0eVm60=I_AP0000000`3FKdH010000000eVm60=I_AP0000040=I_AP040000003FKdH0eVm6
00000080eVm60P0000100=7=Z@00A03AcJT00`000000000S00008`0200008`040000000002<00000
00008`80000000<0000S0000000002<00`3FN5X2000000030;6_eP000000/JoF00D0/JoF0P000002
0;2_e`80000000<0eWIG0000003FMUL00`3FMUL2000000<0eWIG00<000000=IfE`3FMUL00P000000
0`2a[]H000000;6^eP040;6^eP030000002a[]H0000000@0/JkF0P00000200T0@003000000090400
2@10008000001P2`[mL00`000000/:oG0;2_e`040;2_e`040000002`[mL0/:oG0;2_e`80000000<0
/:oG0000002`[mL01@2`[mL00`000000601<000000030;2`e`<000000`3FKdH2000000<0eVm600D0
00000=I_AP3FKdH0eVm6000000040=I_AP050000003FKdH0eVm60=I_AP0000000P3FKdH200000080
eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH0
0`000000eVm60=I_AP02000003l0dLfY00130=7=Z@030000000002<0000000<0000S00D000000000
8`000000000S0000000200008`030000000002=0000000@0eWQJ00<000000;6_eP2a[mH0102a[mH0
0`000000000[000000040;2_e`800000103FMUL2000000<0eWIG00<000000=IfE`3FMUL00P3FMUL2
000000D0/JkF00<000000;6^eP2a[]H00P000000102a[]H0000000T0@000000200T0@00400000009
04002@10000000H0/:oG00@000000;2_e`00000000000`2`[mL300000080/:oG00<0000001@0B@00
00001P2`[mL20000000301P0C0000000/;3G00@0/;3G00H000000=I_AP3FKdH0eVm601h0D@000003
0=I_AP050000003FKdH0eVm60=I_AP000000103FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm6
00@000000=I_AP3FKdH000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_
AP3FKdH0eVm6000000020=I_AP040000003FKdH00000000003d0dLfY00130=7=Z@H0000S00X00000
00008`000000000S0000000002<0000000008`000000/:oG0P0000020=IhFP<00000102a[mH20000
00D0/:oG0P0000040=IfE`030000003FMUL0eWIG0080eWIG00<000000=IfE`3FMUL00P3FMUL01000
0000eWIG0000000000020;6^eP030000002a[]H0/JkF00<0/JkF0P0000001@090400000000T0@009
0400000000802@1000<0eW=?000000000000102`[mL010000000/:oG0;2_e`2`[mL2000000090;2_
e`000000eg9=0=MbC@000010000001@0B@000000/:oG00800000102`[mL3000000D0/;3G00<00000
01/0CP3FKdH00`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600<000000=I_AP3FKdH00P3F
KdH01@000000eVm60=I_AP3FKdH0000000<0eVm600<000000=I_AP3FKdH00P0000020=I_AP050000
003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600@000000=I_
AP3FKdH00000?03AcJT00480dLfY00<0000000008`0002<00P0002<02`000000000S0000000002<0
000000008`000000000S0000000002<0000000<0/:oG0`0000020=IhFP80000000@0/JoF00000000
000000001@2`[mL00`000000eWIG0=IfE`030=IfE`030000003FMUL0eWIG0080eWIG00<000000=If
E`3FMUL00P3FMUL010000000eWIG0=IfE`3FMUL2000000D0/JkF00D0000000T0@00000002@100000
000200T0@0030000000904002@1000<0eW=?0P0000000`2`[mL000000;2_e`050;2_e`8000000`3G
LTd00`0000005019000000030;2_e`80000000<0/:oG0000000H04`00P0000050;2`e`030000000K
04h0eVm600<0eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP030000003FKdH0eVm60080eVm6
00D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH01000
0000eVm60=I_AP0000040=I_AP040000003FKdH0eVm6000000<0eVm600<000000=I_AP3FKdH00`00
000j0=7=Z@00@P3AcJT00`000000000S00008`0200008`080000000002<0000000008`000000000S
0000000002<2000000H0/:oG00<000000=IhFP3FN5X00P3FN5X010000000000[0000003FMeT20000
0080/:oG00<000000000;d000000103FMUL00`000000eWIG0=IfE`020=IfE`030000003FMUL0eWIG
0080eWIG00<000000=IfE`3FMUL00P3FMUL2000000@0/JkF0P00000200T0@0040000000904002@10
000000802@1000=000000=IcC`3FLdl00P3FLdl00`000000/:oG0;2_e`040;2_e`030000002`[mL0
/:oG0080000000<0eg9=0000000000001P2`[mL00`000000601<01P0C0020=I`B08000000P2`/=L0
100000006`1>01/0CT0000030=I_AP040000003FKdH0eVm60=I_AP8000000P3FKdH2000000<0eVm6
00D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH01000
0000eVm60=I_AP0000040=I_AP040000003FKdH0eVm6000000<0eVm600@000000=I_AP3FKdH00000
0P3FKdH2000003P0dLfY00110=7=Z@800000100002<02@000000000S0000000002<0000000008`00
0000000S000000060;2_e`030000003FN5X0eWQJ00<0eWQJ00<000000000:`3FMeT00`3FMeT20000
00030000;`000000/:oG008000000P3FMUL00`000000eWIG0=IfE`020=IfE`030000003FMUL0eWIG
0080eWIG00<000000=IfE`3FMUL00P3FMUL020000000eWIG000000000000/JkF0000000904000000
0P0904001`0000002@1000T0@00000002@100000002`/=L00P0000020=IcC`<00000102`[mL00`00
0000/:oG0;2_e`020;2_e`8000001P2`[mL200000080601<103FL4P2000000806`1>00<000000;2`
f00000000P3FKdH010000000eVm60=I_AP3FKdH200000080eVm60P0000030=I_AP050000003FKdH0
eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600<000000=I_AP3FKdH0
0P0000030=I_AP050000003FKdH0eVm60=I_AP0000000P3FKdH01@000000eVm60=I_AP3FKdH00000
0080eVm60P00000g0=7=Z@00@03AcJT00`000000000S00008`0400008`80000000<0000S00000000
02<00P000000100002<000000000000000040;2_e`030000003FN5X0eWQJ00<0eWQJ00@000000000
:d00000000000`3FMeT00`000000000_000000030;2_e`<00000103FMUL00`000000eWIG0=IfE`02
0=IfE`030000003FMUL0eWIG0080eWIG00@000000=IfE`3FMUL0eWIG0P0000001@090400000000T0
@0090400000000802@1000<0000000T0@00000000`2`/=L300000080eW=?0P0000000`2`[mL00000
0;2_e`040;2_e`040000002`[mL00000000000@0/:oG0P00000201P0C003@00000000000eW180080
eW1800<0000001/0CP0000000`2`/=P3000000<0eVm60P0000020=I_AP800000103FKdH00`000000
eVm60=I_AP0200000080eVm60P0000020=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH01@00
0000eVm60=I_AP3FKdH0000000<0eVm600@000000=I_AP3FKdH000000`3FKdH01@000000eVm60=I_
AP000000eVm600800000=@3AcJT00400dLfY00D0000000008`0002<0000S0000000200008`800000
00<0000S0000000002<00P000000100002<0eWQL0=IhG03FN5`2000000030;2_e`000010000000@0
eWQJ00<000000000:`0000000P2`[mL2000000030=IgF@000000000000H0/:oG00<000000=IfE`3F
MUL00P3FMUL00`000000eWIG0=IfE`020=IfE`030000003FMUL0eWIG0080eWIG00<000000=IfE`3F
MUL00P3FMUL00`0000002@100000000200T0@0030000000904002@10008000001P2`/=L00`000000
eW=?0=IcC`020=IcC`8000001@2`[mL010000000/:oG0;2_e`2`[mL2000000060;2_e`000000601<
0000000H04`000000P2`/=P2000000030=I`B0000000000000H0/;3H00@000000=I_AP3FKdH0eVm6
0P0000030=I_AP030000003FKdH0eVm60080eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP04
0000003FKdH0eVm6000000<0eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0
eVm60=I_AP0000000`3FKdH010000000eVm60=I_AP0000030=I_AP040000003FKdH0eVm6000003@0
dLfY000o0=7=Z@8000000`0002<020000000000S0000000002<0000000008`000000000S0P000000
0`0002=000000=IhG0030=IhG080000000<0/:oG0000000000000P3FN5X00`000000000[00000004
0;2_e`8000001P2`[mL00`000000eWIG0=IfE`020=IfE`800000103FMUL00`000000eWIG0=IfE`02
0=IfE`030000003FMUL0eWIG0080eWIG00<0000000T0@00000000P090400100000002@1000T0@000
00060;2`e`030000003FLdl0eW=?00<0eW=?00@000000=IcC`00000000000P2`[mL00`000000/:oG
0;2_e`040;2_e`060000000H04`0601<0000000H04`00000102`/=P2000000H0/;3H00<0000001h0
D@3FKdH00P3FKdH2000000<0eVm600<000000=I_AP3FKdH00P3FKdH01@000000eVm60=I_AP3FKdH0
000000<0eVm600<000000=I_AP3FKdH00P0000020=I_AP050000003FKdH0eVm60=I_AP000000103F
KdH010000000eVm60=I_AP0000030=I_AP040000003FKdH0eVm6000000<0eVm600<000000=I_AP3F
KdH00`00000b0=7=Z@00?P3AcJT00`000000000S00008`0300008`0=0000000002<0000000008`00
0000000S0000000002<0000000008`000000/:oG000000020=IhG0030000000002L0000000<0/:oG
100000050;2_e`040000002`[mL00000000000@0/:oG00<000000=IfE`3FMUL00P3FMUL00`000000
eWIG0=IfE`030=IfE`030000003FMUL0eWIG0080eWIG00D000000=IfE`3FMUL0eWIG0000000200T0
@0040000000904002@10000000802@1000<0eW=A000000000000102`/=L00`000000eW=?0=IcC`03
0=IcC`040000003FLdl0eW=?0=IcC`8000001P2`[mL200000080601<0P0000050;2`f0040000002`
/=P00000000000@0/;3H00<0000001h0D@3FKdH00`3FKdH01@000000eVm60=I_AP3FKdH0000000@0
eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH0
10000000eVm60=I_AP0000040=I_AP040000003FKdH0eVm6000000<0eVm600D000000=I_AP3FKdH0
eVm6000000020=I_AP040000003FKdH0eVm600000080eVm60P00000`0=7=Z@00?@3AcJT01@000000
000S00008`0002<0000000@0000S00T0000000008`000000000S0000000002<0000000008`000000
0P2`[mL4000000H0/:oG0P0000050;2_e`040000002`[mL0/:oG0;2_e`80000000@0/:oG00000000
03=000000`3FMUL00`000000eWIG0=IfE`020=IfE`800000103FMUL01@000000eWIG0=IfE`3FMUL0
000000802@1000@0000000T0@009040000000P0904030=IcD@80000000@0/;3G0000000=04=00000
103FLdl00`000000eW=?0=IcC`020=IcC`800000102`[mL00`000000601<0000000201P0C0030000
002`/=P0/;3H00@0/;3H00@000000;2`f02`/=P0/;3H0P0000001@2`/=P0000001h0D@0N05500000
00<0eVm600D000000=I_AP3FKdH0eVm6000000040=I_AP050000003FKdH0eVm60=I_AP0000000`3F
KdH01@000000eVm60=I_AP3FKdH0000000<0eVm600<000000=I_AP3FKdH00P0000030=I_AP050000
003FKdH0eVm60=I_AP0000000P3FKdH01@000000eVm60=I_AP3FKdH000000080eVm600D000000=I_
AP3FKdH0eVm6000000020=I_AP800000;`3AcJT003d0dLfY00D0000000008`0002<0000S00000004
00008`040000000002<0000000000080000S0P0000050;2_e`030000002`[mL0/:oG00@0/:oG00<0
00000;2_e`2`[mL00P0000020;2_e`030000002`[mL0/:oG00@0/:oG00D000000000<`000000/;3G
000000020=IfE`030000003FMUL0eWIG0080eWIG0P0000040=IfE`050000003FMUL0eWIG0=IfE`00
00000P090400100000002@1000T0@000000200T0@003@000003FLe40eW=A0080eW=A00@0000000d0
@`000000/;3H0P0000020=IcC`030000003FLdl0eW=?0080eW=?00H000000=IcC`00000000000;2_
e`00000201P0C0040000000H04`0601<0=IaB`8000000`2`/=P00`000000/;3H0;2`f0040;2`f006
0000000N05407P1A0000002`/=P000000P3FKdH010000000eVm60=I_AP3FKdH2000000<0eVm600D0
00000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH01@000000
eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0eVm6000000020=I_AP050000003FKdH0
eVm60=I_AP0000000`3FKdH010000000eVm60=I_AP0000020=I_AP040000003FKdH00000000002d0
dLfY000l0=7=Z@8000000`0002<00`000000000S0000000200008`80000000<0000S0000000002<0
0P0000060;2_e`<00000102`[mL300000080/:oG0P0000060;2_e`80000000@0000c0000002`/=L0
/;3G0`0000040=IfE`030000003FMUL0eWIG00<0eWIG00D000000=IfE`3FMUL0eWIG0000000200T0
@0070000000904002@1000000009040000000;2`f00200000080eW=A00<0000000d0@`0000000`2`
/=P3000000@0eW=?00D000000=IcC`3FLdl0eW=?0000000301P0C0030000000H04`0601<00<0eW5;
0P0000000`2`/=P000000;2`f0040;2`f080000000<07P1A0000002`/=P00P2`/=P3000000<0eVm6
0P0000030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH200000080eVm600D000000=I_AP3F
KdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3F
KdH000000080eVm600D000000=I_AP3FKdH0eVm6000000020=I_AP050000003FKdH0eVm60=I_AP00
00000P3FKdH00`000000dLfY0=7=Z@0Z0=7=Z@00?03AcJT500008`040000000002<0000000008`<0
000000D0000S0000000002<000000=IiGP02000000<0/:oG00@000000;2_e`2`[mL0/:oG0P000000
0`2`[mL000000=IhG0020=IhG00400000400000000000;2_e`800000102`[mL3000000D0/;3G00<0
00000=IfE`3FMUL00P3FMUL00`000000eWIG0=IfE`030=IfE`050000003FMUL0eWIG0=IfE`000000
0P0904001P0000002@1000T0@00000002@10000000<0/;3H100000060;2`f0030000003FLdl0eW=?
0080eW=?00D000000=IcC`3FLdl0eW=?0000000301P0C0040000000H04`0601<@00000@0eW5;0P00
00050;2`f0<000001P2`/=P010000000eVm60=I_AP3FKdH2000000@0eVm600D000000=I_AP3FKdH0
eVm6000000020=I_AP8000000P3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600@000000=I_
AP3FKdH0eVm60P0000020=I_AP050000003FKdH0eVm60=I_AP0000000P3FKdH01@000000eVm60=I_
AP3FKdH000000080eVm600D000000=I_AP3FKdH0eVm6000000020=I_AP<00000:P3AcJT003/0dLfY
00D0000000008`0002<0000S0000000300008`030000000002<000000080000000<0000S00000000
02<0103FNEh2000000030;2_e`000000/:oG00@0/:oG0P0000030=IhG0030000000002l0000000<0
/:oG0P000000102`[mL000000000000000050;2`e`030000003FMUL0eWIG00<0eWIG00<000000=If
E`3FMUL00`3FMUL01@000000eWIG0=IfE`3FMUL0000000802@1000<0000000T0@00904000P000006
0;2`f0030000002`/=P0/;3H00@0/;3H00<000000=IcC`3FLdl00`3FLdl00`000000eW=?0=IcC`02
0=IcC`070000000H04`0601<0000000H04`000000;2`f00200000080eW5;00@000000=IaB`000000
00000P2`/=P00`0000007P1A000000060;2`f0030000000R05<0eVm60080eVm60P0000040=I_AP05
0000003FKdH0eVm60=I_AP0000000`3FKdH00`000000eVm60=I_AP02000000<0eVm600@000000=I_
AP3FKdH00000103FKdH010000000eVm60=I_AP0000030=I_AP050000003FKdH0eVm60=I_AP000000
0P3FKdH01@000000eVm60=I_AP3FKdH000000080eVm600H000000=I_AP3FKdH0eVm60000003FKdH2
000002P0dLfY000k0=7=Z@050000000002<0000S00008`0000000`0002<02@000000000S00000000
02<0000000008`000000000S@00000040=IiGP8000001@2`[mL00`000000/:oG0;2_e`0200000003
0=IhG0000000000000H0/:oG00D000000000<`3FMeT0eWMI000000040;2`e`030000003FMUL0eWIG
00<0eWIG00<000000=IfE`3FMUL00P3FMUL2000000<0eWIG00@0000000T0@009040000000P090400
0`000000/;3H0;2`f0040;2`f0040000002`/=P00000000000@0/;3H00<000000=IcC`3FLdl00`3F
Ldl00`000000eW=?0=IcC`020=IcC`060000000H04`0601<0000000H04`000000`2`/=P3000000<0
eW5;0P00000201h0D@030=I`B0000000000000@0/;3H00<000000280D`3FKdH00`3FKdH00`000000
eVm60=I_AP020=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH0
000000<0eVm600<000000=I_AP3FKdH00P0000030=I_AP050000003FKdH0eVm60=I_AP0000000P3F
KdH01@000000eVm60=I_AP3FKdH0000000<0eVm600@000000=I_AP3FKdH000000P3FKdH01@000000
eVm60=I_AP3FKdH000000080eVm60`00000V0=7=Z@00>P3AcJT00`000000000S00008`0200008`80
00000P0002<01P000000000S0000000002<0000000008`80000000<0/;3G0000000000000P3FNEh0
0`000000eWUN000000040;2_e`030000002`[mL0/:oG0080/:oG0P0000060;2_e`80000000@0000c
0=IgF@3FMeT0eWMI0P0000001@2`/=L000000000=T000000000000<0eWIG00<000000=IfE`3FMUL0
0P3FMUL2000000<0eWIG00@0000000T0@009040000000P0904000`3FM5<00000000000040;2`f004
0000002`/=P0/;3H0;2`f080000000D0/;3H0000000@04I00000000000030=IcC`030000003FLdl0
eW=?0080eW=?00<0000001P0C00H04`00P0000060;2`f0030000003FLD/0eW5;0080eW5;00<00000
01h0D@0N05400`3FL4P2000000050;2`f00000008P1C0280Dd0000000`3FKdH00`000000eVm60=I_
AP020=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0
eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_AP0000000P3FKdH0
1@000000eVm60=I_AP3FKdH0000000<0eVm600@000000=I_AP3FKdH000000`3FKdH010000000eVm6
0=I_AP0000030=I_AP040000003FKdH00000000002@0dLfY000i0=7=Z@040000000002<0000S0000
00<0000S00<0000000008`0000000P0002<01P000000000S000000000000000S000000<0/;3G0`00
00020=IiGP80000000<0/:oG0000002`[mL0102`[mL010000000/:oG0000000000040;2_e`040000
000003<0000c@00000@0eWMI00<000000000=P0000000P2`/=P2000000030=IfE`000000eWIG00<0
eWIG00<000000=IfE`3FMUL00P3FMUL0100000002@1000T0@000000200T0@0<0eWAC0P0000000`2`
/=P000000;2`f0050;2`f0030000000@04H000000080/;3H0P0000000`3FLdl000000=IcC`030=Ic
C`040000000H04`0601<000000H0/;3H00<000000=IaB`3FLD/00`3FLD/0100000007P1A01h0DD00
00040=I`B0060000000R05<08P1C0000002`/=P000000P3FKdH00`000000eVm60=I_AP020=I_AP05
0000003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600D00000
0=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH010000000eVm6
0=I_AP0000030=I_AP040000003FKdH0eVm6000000<0eVm600@000000=I_AP3FKdH000000`3FKdH0
10000000eVm60=I_AP00000T0=7=Z@00>@3AcJT010000000000S00008`00000300008`0300000000
02<000000080000S0P0000000`0002<00000000000060;2`e`030000003FNEh0eWUN0080eWUN0P00
00050;2_e`040000002`[mL0/:oG0;2_e`80000000H0/:oG000000000000000c0000002`/=P20000
0080eWMI00<000000000=P000000102`/=P2000000@0eWIG00<000000=IfE`3FMUL00P3FMUL01000
00002@1000T0@000000200T0@0D0eWAC00<000000;2`f02`/=P0102`/=P2000000030100AP000000
/;3H00<0/;3H0P0000040=IcC`040000000H04`0601<0=MbC@800000102`/=P00`000000eW5;0=Ia
B`030=IaB`040000000N054000000;2`f08000000P3FL4P00`0000008P1C000000030;2`f0<00000
103FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0eVm6000000030=I_
AP050000003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600<0
00000=I_AP3FKdH00P0000020=I_AP050000003FKdH0eVm60=I_AP0000000P3FKdH01@000000eVm6
0=I_AP3FKdH000000080eVm600D000000=I_AP3FKdH0eVm60000000S0=7=Z@00>03AcJT030000000
000S00008`0002<0000000008`000000000S0000000002<0000000008`<0000000<0000S0000002`
/=L01@2`/=L2000000D0eWUN0`0000020;2_e`030000002`[mL0/:oG00@0/:oG00D000000000<`00
0000000c000000030;2`f0@000001@2`/=P00`000000eWIG0=IfE`030=IfE`030000003FMUL0eWIG
0080eWIG00@0000000T0@009040000000P0904000d00000000000=IdD`020=IdD`<00000102`/=P3
000000D0/;3H00<000000=IcC`3FLdl00`3FLdl00`000000601<01P0C0030=MbC@80000000D0/;3H
0000000K04i00000000000030=IaB`030000000N0540000000<0/;3H100000060;2`f0030000003F
KdH0eVm60080eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP8000000P3FKdH010000000eVm6
0=I_AP3FKdH200000080eVm600@000000=I_AP3FKdH0eVm60P0000020=I_AP050000003FKdH0eVm6
0=I_AP0000000`3FKdH010000000eVm60=I_AP0000030=I_AP040000003FKdH0eVm6000000<0eVm6
00@000000=I_AP3FKdH000000`3FKdH00`000000dLfY0=7=Z@0Q0=7=Z@00=`3AcJT010000000000S
00008`00000300008`0:0000000002<0000000008`000000000S0000000002<0000000008`<00000
102`/=L00`000000eWUN0=IiGP030=IiGP040000003FNEh0eWUN0=IiGP8000001P2`[mL200000003
0000<`000000000000H0/;3H0P0000050;2`f0030000003FMUL0eWIG00<0eWIG00<000000=IfE`3F
MUL00P3FMUL01P0000002@1000T0@00000002@1000000080/;3H0P000000103FM5<000000=IdD`3F
M5<2000000040;2`f00000004016000000H0/;3H00<000000=IcC`3FLdl00`3FLdl010000000601<
01P0C40000040=MbC@030000000K04h000000080/;3H0P0000000`3FLD/00000000000060;2`f003
0000002`/=P0/;3H00@0/;3H00<0000002D0EP3FKdH00`3FKdH00`000000eVm60=I_AP020=I_AP05
0000003FKdH0eVm60=I_AP0000000P3FKdH2000000<0eVm600<000000=I_AP3FKdH00P0000030=I_
AP050000003FKdH0eVm60=I_AP0000000P3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600@0
00000=I_AP3FKdH000000`3FKdH010000000eVm60=I_AP0000030=I_AP040000003FKdH0eVm60000
02<0dLfY000f0=7=Z@050000000002<0000S00008`0000000`0002<02`000000000S0000000002<0
000000008`000000000S0000000002<000000080eWYO0P000000102`/=L0000000009d0000040=Ii
GP030000003FNEh0eWUN0080eWUN0`0000040;2_e`80000000<0000c0000002`/=P01@2`/=P00`00
0000/;3H0;2`f00200000080/;3H00<000000040>T000000103FMUL00`000000eWIG0=IfE`020=If
E`060000000904002@100000000904000000102`/=P2000000@0eWAC00@000000100AP0@04H0eW=A
0P0000030;2`f0030000000D04T0eW=?00@0eW=?00@0000001P0C0000000/;3H0P0000020=MbC@03
0000000K04h0000000@0/;3H0P0000060;2`f0040000002`/=P00000000000@0/;3H00<0000002D0
EP3FKdH0103FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0eVm60000
00030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH000000080
eVm60P0000020=I_AP050000003FKdH0eVm60=I_AP0000000P3FKdH01@000000eVm60=I_AP3FKdH0
00000080eVm600D000000=I_AP3FKdH0eVm6000000020=I_AP030000003AcJT0dLfY0240dLfY000f
0=7=Z@050000000002<0000S00008`0000000`0002<200000080000S00H0000000008`000000000S
0000000002<50=IjG`040000000002L000000;2`f08000000P3FNEh00`000000eWUN0=IiGP020=Ii
GP030000003FNEh0eWUN0080000000H0/:oG0000000003<000000000<`3FN5X2000000@0/;3H00<0
00000;2`f02`/=P00P2`/=P2000000030040>P000000/;3H008000000P3FMUL00`000000eWIG0=If
E`020=IfE`030000000904002@10008000001@2`/=P00`000000eWAC0=IdD`030=IdD`030000000@
04H0401600<0eW=A0P0000001@2`/=P0000001@0BD000000000000<0eW=?00<0000001P0C0000000
0`2`/=P4000000D0/;3H00@000000;2`f00000000000102`/=P010000000/;3H0;2`f02`/=P20000
00060;2`f00000009@1F02D0ET00000000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm6
00D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH01@00
0000eVm60=I_AP3FKdH0000000<0eVm600@000000=I_AP3FKdH000000`3FKdH00`000000eVm60=I_
AP0200000080eVm600D000000=I_AP3FKdH0eVm6000000020=I_AP050000003FKdH0eVm60=I_AP00
00008P3AcJT003D0dLfY0P00000400008`030000000002<0000S0080000000X0000S0000000002<0
000S0000000002<0000000008d00000000000`3FNUl00`000000000W000000030;2`f0<00000103F
NEh00`000000eWUN0=IiGP020=IiGP050000000003<0000c0000000003<00`3FN5X2000000030;2`
f0000000/;3H00@0/;3H0P0000000`0103X000000;2`f0020;2`f0<00000103FMUL00`0000002@10
00T0@002000000D0/;3H00<000000=IdD`3FM5<00`3FM5<01000000040160100AT0000040=IcD@03
0000000D04T000000080/;3H0P0000000`3FLdl00000000000060;2`f0030000002`/=P0/;3H00@0
/;3H00@000000;2`f02`/=P0/;3H0P0000000`2`/=P000000;2`f0050;2`f0040000000U05H09@1F
00000080/;7I0P0000000`3FKdH000000=I_AP020=I_AP050000003FKdH0eVm60=I_AP0000000`3F
KdH01@000000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP05
0000003FKdH0eVm60=I_AP0000000`3FKdH010000000eVm60=I_AP0000030=I_AP040000003FKdH0
eVm6000000<0eVm600@000000=I_AP3FKdH000000`3FKdH00`000000dLfY0=7=Z@0P0=7=Z@00=03A
cJT01@000000000S00008`0002<000000080000S00<0000000008`0000000P0000000`0002<00000
00008`030000000400008`000000/;3H0;2`f080000000<0eWYO0000000000001P2`/=P00`000000
eWUN0=IiGP020=IiGP030000003FNEh0eWUN0080eWUN00<000000000<`0000000P0003<00d000000
eWQJ0=IhFP020=IhFP8000001@2`/=P3000000H0/;3H00<000000=IfE`3FMUL00P3FMUL00`000000
2@1000T0@0020=IeE@8000000P2`/=P00`0000003@13@00000040=IdD`040000000@04H000000;2`
f08000000P3FLe400`0000005019000000040;2`f08000001P2`/=P010000000/;3H000000000003
0;2`f0<0000000D0/;3H0000000R05<08P1C000000060;2`f080000000<09@1F0000002`/MT0102`
/MT2000000<0eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_AP00
00000`3FKdH010000000eVm60=I_AP3FKdH200000080eVm600D000000=I_AP3FKdH0eVm600000003
0=I_AP050000003FKdH0eVm60=I_AP0000000P3FKdH01@000000eVm60=I_AP3FKdH000000080eVm6
00D000000=I_AP3FKdH0eVm6000000020=I_AP030000003AcJT0dLfY0200dLfY000d0=7=Z@030000
000002<0000S0080000S00X0000000008`000000000S0000000002<0000000008`000000000S0`00
00000`0002<000000;2`f0030;2`f08000001P2`/=P00`000000eWUN0=IiGP030=IiGP030000003F
NEh0eWUN0080eWUN00H000000000<`000000000c0000002`/=P200000080eWQJ00@000000=IhFP00
000000000P2`/=P00`0000000@0j000000060;2`f0030000003FMUL0eWIG00<0eWIG00<0000000T0
@0090400103FMED20000000300d0@`000000/;3H008000000P3FM5<00`0000004016000000030;2`
f0@000001@2`/=P010000000/;3H0000000000040;2`f0040000002`/=P0/;3H0;2`f080000000D0
/;3H0000003GLTd0eg9=@00000020280D`040000002`/=P00000000000@0/;3H0`0000060;2af@03
0000003FKdH0eVm60080eVm600@000000=I_AP3FKdH0eVm60P0000020=I_AP030000003FKdH0eVm6
0080eVm600<000000=I_AP3FKdH00P0000030=I_AP050000003FKdH0eVm60=I_AP0000000P3FKdH0
1@000000eVm60=I_AP3FKdH0000000<0eVm600@000000=I_AP3FKdH000000`3FKdH010000000eVm6
0=I_AP0000030=I_AP040000003FKdH0eVm600000280dLfY000c0=7=Z@030000000002<0000S00<0
000S00`0000000008`000000000S0000000002<0000000008`000000000S0000000002<2000000D0
/;3H00@000000;2`f00000000000102`/=P00`000000eWUN0=IiGP030=IiGP030000003FNEh0eWUN
0080eWUN00D000000000<`000000000c000000030;2`f0<000000`3FN5X2000000800@0j0`000004
0;2`f0030000003FMUL0eWIG00<0eWIG00D0000000T0@00904100000000000030=IeE@030000000=
04<0000000<0/;3H100000060;2`f08000001@2`/=P200000080/;3H0P0000000`2`/=P000000;2`
f0050;2`f0070000003GLTd0eg9=0=MbC@0000008P1C000000040;2`f080000000@0/;3H0000000U
05H000001P2`/MT00`000000:01H0=I_AP030=I_AP040000003FKdH0eVm60=I_AP8000000P3FKdH2
000000<0eVm600<000000=I_AP3FKdH00P0000030=I_AP050000003FKdH0eVm60=I_AP0000000P3F
KdH200000080eVm600D000000=I_AP3FKdH0eVm6000000020=I_AP050000003FKdH0eVm60=I_AP00
00000`3FKdH010000000eVm60=I_AP0000030=I_AP030000003AcJT0dLfY01l0dLfY000b0=7=Z@03
0000000002<0000S00@0000S00`0000000008`0002<0000S0000000002<0000000008`000000000S
0000000002<2000000D0/;3H00@000000;2`f02`/=P0/;3H0P0000000`2`/=P00000@00000040=Ii
GP030000003FNEh0eWUN00<0eWUN00@000000000<`00000000001P2`/=P00`000000eWQJ0=IhFP02
0=IhFP030000000103X00@0j00<0eWMI0P000000102`/=P0000000D0?D0000040=IfE`0300000009
040000000080/;3H0P0000000`3FMED00000000000060;2`f0030000002`/=P0/;3H00@0/;3H00<0
00000;2`f02`/=P00P0000020;2`f0030000002`/=P0000000@0/;3H00<000000;2`f02`/=P0102`
/=P01@000000/;3H000000000000eg9=008000001`2`/=P0100000009@1F02D0EP0U05H2000000@0
/;7I00<0000002P0F03FKdH0103FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_
AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_
AP3FKdH000000080eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP040000003FKdH0eVm60000
00<0eVm600@000000=I_AP3FKdH000000`3FKdH00`000000dLfY0=7=Z@0O0=7=Z@00<@3AcJT01@00
0000000S00008`0002<0000000<0000S0P00000200008`80000000P0000S0000000002<0000S0000
000002<000000=IjH@8000000P2`/=P00`000000/;3H0;2`f0040;2`f080000000<0/;3H00000000
00000P3FNEh00`000000eWUN0=IiGP030=IiGP030000000003<0000000H0/;3H00<000000=IhFP3F
N5X00`3FN5X00`0000000@0j0040>P050=IgF@040000000503d000000;2`f08000000P3FMUL00`00
00002@10000000040;2`f08000001P2`/=P010000000/;3H0000000000040;2`f0030000002`/=P0
/;3H0080/;3H0P0000000`2`/=P000000;2`f0040;2`f0800000102`/=P00`000000/;3H0;2`f002
0;2`f08000001`2`/=P00`0000009@1F02D0EP0202D0EP80eW180P0000001P2`/MT0000002P0F00X
05Q00000000000<0eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_
AP0000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0eVm60000
00030=I_AP050000003FKdH0eVm60=I_AP0000000P3FKdH01@000000eVm60=I_AP3FKdH000000080
eVm600D000000=I_AP3FKdH0eVm6000000020=I_AP030000003AcJT0dLfY01l0dLfY000a0=7=Z@07
0000000002<0000S00008`000000000S0000000200008`030000000002<0000S0080000000<0000S
0000000002<00P0000000`0002<0eWYQ0=IjH@020=IjH@8000001P2`/=P00`000000000[00000003
0;2`f0<000001@3FNEh00`000000000c0=IhG002000000@0/;3H00<000000=IhFP3FN5X00`3FN5X0
1@0000000@0j0040>T000000000000<0eWMI00<0000000D0?@0000000`2`/=P4000000D0/;3H00<0
00000;2`f0000000102`/=P00`000000/;3H0;2`f0020;2`f080000000<0/;3H0000002`/=P0102`
/=P00`000000eWAC000000050;2`f0030000000N054000000080000000<0/;3H0000002`/=P0102`
/=P010000000/;3H0000000000040;2`f0030000000U05H0000000<09@1F00E000000=I`B03FL4P0
eW180000000202P0F0030000002`/MT0/;7I0080000000<0eVm60000003FKdH00P3FKdH01@000000
eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP8000000P3FKdH0
1@000000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0eVm6000000020=I_AP050000
003FKdH0eVm60=I_AP0000000P3FKdH01@000000eVm60=I_AP3FKdH000000080eVm600<000000=7=
Z@3AcJT07`3AcJT00300dLfY00<0000000008`0002<0100002<20000000300008`000000000S00<0
000000<0000S0000000002<00P0000000`0002=00000000000030=IjH@<00000102`/=P2000000H0
/;3H00<000000=IiGP3FNEh00P3FNEh00`000000000c0000<`030=IhG080000000@0/;3H00000000
03I00000103FN5X00`0000000@0j000000020;2`f080000000<0eWMI0000000000001P2`/=P00`00
0000/;3H0;2`f0030;2`f0040000002`/=P0/;3H0;2`f080000000<0/;3H0000003FMED00P000000
1@2`/=P0000001@0B@0D04T0000000D0/;3H00<000000=IdD`3FM5<00`0000020;2`f0030000000N
05407P1A0080000000<0/;3H0000000000001@2`/=P010000000/;3H0;2`f02`/=P2000000050;2`
f00000009@1F02D0EP0000000P0U05H00`000000/;7I000000020=I`B0030000000X05P0000000D0
/;7I0P0000030=I_AP050000003FKdH0eVm60=I_AP000000103FKdH010000000eVm60=I_AP000003
0=I_AP8000000`3FKdH010000000eVm60=I_AP0000030=I_AP050000003FKdH0eVm60=I_AP000000
0P3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600@000000=I_AP3FKdH000000`3FKdH00`00
0000dLfY0=7=Z@0N0=7=Z@00<03AcJT300008`030000000002<0000S0080000S00X0000000008`00
0000000S0000000002<0000000008`000000000S0`0000020;2`f080000000@0eWYQ0000003FNV40
eWYQ0P0000000`2`/=P00000000000060;2`f0030000003FNEh0eWUN00<0eWUN00@000000000<`00
03=00000103FN5`010000000000f0000002`/=P200000080eWQJ00<000000040>P000000102`/=P2
000000H0/;3H00<000000;2_e`000000102`/=P00`000000/;3H0;2`f0030;2`f0030000003FMED0
eWEE0080eWEE00E0000001@0B@0D04T000000;2`f00200000080/;3H00<000000;2`f00000000P00
00020=IdD`<000000P0N0542000000<0/;3H0P0000020;2`f0030000002`/=P0/;3H00@0/;3H00L0
000002D0EP0U05H09@1F0000000U05H0000000<0/;7I100000060;2af@030000003FKdH0eVm60080
eVm600D000000=I_AP3FKdH0eVm6000000040=I_AP030000003FKdH0eVm6008000000`3FKdH01@00
0000eVm60=I_AP3FKdH000000080eVm60P0000020=I_AP050000003FKdH0eVm60=I_AP0000000`3F
KdH010000000eVm60=I_AP0000030=I_AP040000003FKdH0eVm6000000<0eVm600<000000=7=Z@3A
cJT07P3AcJT002l0dLfY00<0000000008`0002<01P0002<03@000000000S0000000002<000000000
8`000000000S0000000002<0000000008`000000102`/=P2000000@0eWYQ00<000000000:`000000
0P0000040;2`f0030000003FNEh0eWUN00<0eWUN00@000000000<`000000/;3H0P0000020=IhG003
0000000003H0000000<0/;3H100000050;2`f0040000002`/=P00000000000@0/;3H00<000000;2_
e`2`[mL00P0000000`2`/=P000000;2`f0040;2`f0040000002`/=P0000000000080eWEE00<00000
01@0B@000000102`/=P2000000@0/;3H00<000000=IdD`3FM5<00P3FM5<00`0000007P1A01h0D@02
0=IcD@8000000P2`/=P3000000H0/;3H0P00000302D0EP8000001P2`/MT00`000000/;7I0;2af@04
0;2af@030000000[05X0eVm600<0eVm600@000000=I_AP3FKdH0eVm60P0000030=I_AP050000003F
KdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3F
KdH0eVm6000000020=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH010000000eVm60=I_AP00
00030=I_AP040000003FKdH0eVm600000200dLfY000_0=7=Z@D0000S00@0000000008`0002<0000S
0P00000200008`040000000002<0000000000080000S0P0000050;2`f0030000003FNV40eWYQ00<0
eWYQ00<000000000:`3FNUl00P3FNUl2000000050;2`f0000000000_@000000000000`3FNEh00`00
0000000c000000030;2`f0@000001P2`/=P2000000D0/;3H00@000000;2`f02`/=P0/;3H0P000000
0`2`/=P000000;2_e`020;2_e`@000001@2`/=P010000000/;3H0;2`f02`/=P4000000D0/;3H00<0
00000;2`f02`/=P00P2`/=P00`000000eWAC0=IdD`030=IdD`030000000N05407P1A00@0eW=A0P00
00000`0R05<000000;2`f002000000@0/;3H0P00000302D0EP030000002`/MT0/;7I00@0/;7I00@0
00000;2af@0000000000102`/MT00`000000:`1J0=I_AP040=I_AP050000003FKdH0eVm60=I_AP00
00000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0eVm600000003
0=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH010000000eVm60=I_AP0000030=I_AP040000
003FKdH0eVm6000000<0eVm600@000000=I_AP3FKdH00000803AcJT002h0dLfY00<0000000008`00
02<00`0002<010000000000S0000000002<200000080000S0P000000100002<0000000008`0002<2
000000D0/;3H00<000000=IjH@3FNV400`3FNV400`000000000[@00000040=IjG`030000000002l0
00000080/;3H0P0000000`3FNEh00000000000060;2`f0030000002`/=P0/;3H00@0/;3H00<00000
0;2`f02`/=P00P0000020;2`f0030000002`/=P0/;3H00@0/;3H0`0000001P2`[mL000000=IhG03F
N5`00000@000008000000P2`/=P00`000000/;3H0;2`f0040;2`f08000001@2`/=P00`000000/;3H
0;2`f0020;2`f0030000003FM5<0eWAC00<0eWAC00D0000001h0D@0N05500000000000030=IcD@03
0000000R05<0000000<0/;3H0P000000102`/=P0000002D0EP00000402D0EP800000102`/MT01000
0000/;7I0;2af@2`/MT2000000060;2af@000000:`1J02/0FT00000000000`3FKdH01@000000eVm6
0=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP040000003FKdH0eVm6
0=I_AP8000000P3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600@000000=I_AP3FKdH00000
0`3FKdH01@000000eVm60=I_AP3FKdH000000080eVm600D000000=I_AP3FKdH0eVm60000000O0=7=
Z@00;@3AcJT010000000000S00008`00000300008`030000000002<0000000<0000000P0000S0000
00000000000000008`000000000S00000080eG]R0P0000020;2`f003000004000000eWYQ00<0eWYQ
00@000000000:`000000/;3H0P0000020=IjG`030000000002l0000000@0/;3H0P0000060;2`f004
0000002`/=P00000000000@0/;3H0`000000102`/=P000000000000000060;2`f0060000002`[mL0
/:oG0;2_ed00000000000`3FN5`00`000000501900000002000000H0/;3H00<000000;2`f02`/=P0
0P0000020;2`f0080000003FMED000000000002`/=P0000001/0CT0000040=IdD`030000000N0540
00000080/;3H0P0000000`3FLe400000000000060;2`f0040000000U05H09@1F000000@09@1F0P3F
LD/2000000030;2af@000000/;7I00D0/;7I0P000000100[05X000000;2af@2`/MT2000000030=I_
AP000000eVm60080eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP040000003FKdH0eVm60=I_
AP8000000`3FKdH010000000eVm60=I_AP0000030=I_AP050000003FKdH0eVm60=I_AP0000000`3F
KdH010000000eVm60=I_AP0000030=I_AP050000003FKdH0eVm60=I_AP0000000P3FKdH00`000000
dLfY0=7=Z@0M0=7=Z@00;03AcJT00`000000000S00008`0300008`030000000002<0000S0080000S
00X0000000008`000000000S0000000002<0000000008`000000000S1@3ENf83000000030;2`f000
000000000080eWYQ00<000000000:`0000000`2`/=P4000000D0/;3H00@000000;2`f00000000000
102`/=P010000000/;3H0;2`f02`/=P2000000030;2`f0000000eWQL0080eWQL00E0000000D0?@00
0000/;3H000000040;2`f0050000002`[mL0/:oG0;2_e`0000000P2`[mL2000000030=IhG0000000
000000<0/:oG0P0000040;2`f0030000002`/=P0/;3H0080/;3H0P0000040=IeE@04@000000K04h0
00000;2`f08000000P3FM5<00`0000007P1A000000040;2`f08000001P2`/=P2000000809@1F0P00
000302D0EP05@000003FLD/0eW5;0=IaB`0000001P2`/MT30000000302/0FP000000/;7I00<0/;7I
0P0000030=I_AP030000003FKdH0eVm60080eVm600<000000=I_AP3FKdH00P0000030=I_AP050000
003FKdH0eVm60=I_AP0000000P3FKdH01@0m36L000000=I_AP3FKdH0000000<0eVm600D000000=I_
AP3FKdH0eVm6000000030=I_AP040000003FKdH0eVm6000000<0eVm600@000000=I_AP3FKdH00000
7`3AcJT002/0dLfY00<0000000008`0002<02@0002<030000000000S0000000002<0000000008`00
0000000S0000000002=00000000000<0eG]R00<0000000009`0000000`2`/=P4000000H0/;3H0P00
00050;2`f0030000002`/=P0/;3H00<0000000<0/;3H0000002`/=P01@2`/=P2000000<0eWQL00<0
000000D0?@0000000P2`/=P2000000030;2`f000000000000080/:oG00<000000;2_e`2`[mL00`2`
[mL2000000H0/:oG0P0000000`2`/=P000000;2`f0040;2`f0040000002`/=P0000000000080eWEE
00<0000001/0CP0000000`2`/=P4000000D0/;3H00<000000;2`f0000000102`/=P00`0000009@1F
0000000202D0EP8000000P0U05H00`000000/;7I000000020=IaB`<00000102`/MT4000000D0/;7I
00<0000002h0G03FKdH00P3FKdH00`000000eVm60=I_AP020=I_AP050000003FKdH0eVm60=I_AP00
00000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0eVm600000003
0=I_AP040000003FKdH0eVm6000000<0eVm600@000000=I_AP3FKdH000000`3FKdH01@000000eVm6
0=I_AP3FKdH0000001h0dLfY000[0=7=Z@P0000S00`0000000008`0002<0000S0000000002<00000
00008`000000000S0000000002<200000080/;3H0P0000000`3ENf800000000000060;2`f0030000
002`/=P0/;3H00@0/;3H00<000000;2`f02`/=P00P0000020;2`f0040000002`/=P0/;3H000000<0
/;3H00<000000;2`f02`/=P0102`/=P00`000000/;3H0;2`f002000000030=IhG0000000000000D0
/;3H00<000000=IiGP3FNEh00P0000060;2_e`040000002`[mL00000000000@0/:oG100000050;2`
f0040000002`/=P0/;3H0;2`f0@000001P2`/=P2000000D0/;3H00<000000;2`f02`/=P00P000000
1@2`/=P0000002D0EP0U05H0000000809@1F0P0000000`0U05H000000;2af@020;2af@<000000P3F
LD/2000000050;2af@000000:`1J02/0FP0000001@2`/MT00`000000;P1L02h0G0030=I_AP030000
003FKdH0eVm60080eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_
AP0000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600@000000=I_AP3FKdH000000`3F
KdH01@000000eVm60=I_AP3FKdH000000080eVm600D000000=I_AP3FKdH0eVm60000000N0=7=Z@00
:P3AcJT00`000000000S00008`0200008`080000000002<0000S00008`000000000S0000000002<2
00000080000S00H0000000008`000000000000008`0000040;2`f08000001P2`/=P010000000/;3H
0000000000040;2`f0030000002`/=P0/;3H0080/;3H100000000`2`/=P000000;2`f0030;2`f080
0000102`/=P00`000000/;3H0;2`f0020;2`f08000001@2`/=P2000000<0eWUN0`0000040;2_e`04
0000002`[mL0/:oG0;2_e`80000000D0/:oG0000000H04`0000001P0C00300000080/;3H00<00000
0;2`f02`/=P0102`/=P00`000000/;3H0;2`f0040;2`f0030000002`/=P0/;3H008000000P2`/=P0
0`000000/;3H0;2`f0030;2`f08000000P0U05H01`0000009@1F02D0EP0U05H0000002D0EP000000
1@2`/MT00`000000eW5;0=IaB`020=IaB`060000000[05X0:`1J02/0FP3FL4P00000102`/MT00`00
0000;P1L02h0G0040=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3F
KdH0000000<0eVm60P0000020=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH010000000eVm6
0=I_AP0000030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH010000000eVm60=I_AP00000N
0=7=Z@00:P3AcJT500008`060000000002<0000S00008`000000000S1000000200008`80000000<0
000S0000000000001@2`/=P010000000/;3H0000000000040;2`f0<0000000D0/;3H000000000000
/;3H000000050;2`f0030000003FNV40eWYQ008000001@2`/=P4000000030;2`f0000000/;3H00@0
/;3H00<000000;2`f0000000102`/=P00`000000eWUN0=IiGP020=IiGP030000003FNEh0eWUN0080
000000<0/:oG0000002`[mL01@2`[mL01P000000601<01P0C0000000601<00000080/;3H0P000006
0;2`f0040000002`/=P00000000000@0/;3H00D000000;2`f02`/=P000000280D`02000000D0/;3H
0`00000202D0EP040000000U05H09@1F02D0EP8000001@2`/MT00`000000:01H0=IaB`030=IaB`04
0000000[05X0:`1J02/0FP80eW180P0000000`2`/MT0000002h0G00202h0G005@000003FKdH0eVm6
0=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm60P0000030=I_AP040000003F
KdH0eVm6000000<0eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_
AP0000000P3FKdH01@000000eVm60=I_AP3FKdH000000080eVm600<000000=7=Z@3AcJT0703AcJT0
02T0dLfY00@0000000008`0002<000000P0002<01P000000000S0000000002<0000000008`@00000
00D0000S000000000000000000008`02000000D0/;3H00@000000;2`f02`/=P0/;3H0P0000000`2`
/=P000000=EkHP020=EkHP03000004000000000_008000001@2`/=P01@000000eWYQ0=IjH@000000
eWYQ008000000P2`/=P00`0000000@0j000000020;2`f08000001@2`/=P00`000000/;3H0;2`f002
000000030;2`f0000000000000@0eWUN00<000000=IiGP3FNEh00P3FNEh2000000D0/:oG0P000002
01P0C08000001@2`/=P2000000@0/;3H00@000000;2`f02`/=P0/;3H0P0000001@2`/=P000000=Ie
E@000010000000808P1C00<000000;2`f0000000102`/=P00`0000009@1F0000000202D0EP040000
000U05H09@1F02D0EP8000001@2`/MT00`000000:01H0=IaB`030=IaB`0502/0FP000000:`1J02/0
FT0000000`3FL4P200000080;P1L00H000000;2afP00000000000=I_AP0000040=I_AP030000003F
KdH0eVm6008000000P3FKdH2000000<0eVm600D000000=I_AP3FKdH0eVm6000000020=I_AP0303l>
J@000000eVm60080eVm600@000000=I_AP3FKdH000000`3FKdH010000000eVm60=I_AP0000030=I_
AP050000003FKdH0eVm60=I_AP0000007@3AcJT002P0dLfY00<0000000008`0002<00P0002<00`00
0000000S00008`0200008`0>0000000002<0000S00008`000000000S0000000002<0000000008`00
0000000S0000003ENf@200000080/;3H00<000000;2`f02`/=P0102`/=P00`000000eG]R0=EkHP02
0=EkHP030000000002l000000080/;3H0P0000020;2`f0030000002`/=P00000008000000`3FNV43
000000040040>P000000000000000080/;3H0P0000020;2`f0030000002`/=P0/;3H00<0/;3H0P00
00000d000000eWUN0=IiGP020=IiGP030000003FNEh0eWUN0080eWUN00@000000=IiGP0000000000
0P2`[mL00`000000601<0000000201P0C0030000002`/=P0/;3H00<0/;3H00<000000;2`f02`/=P0
0P0000000`2`/=P000000;2`f0050;2`f0070000003FMED0eWEE0=IeE@0000008P1C000000030;2`
f080000000D0/;3H0000000U05H09@1F0000000202D0EP040000000U05H09@1F02D0EP80eg9=0P00
00020;2af@030000000X05P0:01H00D0eW5;00@0000002/0FP000000/;7J0P0000020=I`B0030000
000^05`0000000@0/;7J0P0000040=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH01@000000
eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP040000003FKdH0
eVm6000000<0eVm600D000000=I_AP3FKdH0eVm6000000020=I_AP050000003FKdH0eVm60=I_AP00
00007@3AcJT002P0dLfY00<0000000008`0002<00P0002<00`000000000S00008`0200008`0<0000
000002<0000S00008`000000000S0000000002<0000000008`000000000S103ENf@2000000H0/;3H
00@000000;2`f000000000000P3ENf800`000000000_000000040;2`f0800000102`/=P00`000000
eWYQ0=IjH@020=IjH@030000000103X00@0j00<0eWYO0P000000102`/=P000000000000000050;2`
f0030000040000003@1300<000000P3FNEh00`000000eWUN0=IiGP020=IiGP040000003FNEh0eWUN
0=IiGP8000000P0H04`010000000601<01P0C03FN5X200000080/;3H00<000000;2`f02`/=P00`2`
/=P00`000000/;3H0;2`f0040;2`f0050000002`/=P000000000003FMED00P0000060;2`f0050000
000U05H09@1F02D0EP0000000P0U05H2000000809@1F103GLTd2000000<0:01H00=000000000003F
LD/00P3FLD/00`000000:`1J000000030;2afP@000001@2`/MX2000000@0eVm600D000000=I_AP3F
KdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3F
KdH0000000<0eVm600@000000=I_AP3FKdH000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0
eVm600@000000=I_AP3FKdH000007@3AcJT002L0dLfY00<0000000008`0002<0100002<020000000
000S00008`0002<0000000008`000000000S0P00000200008`050000000002<0000000008d000000
103ENf@3000000@0/;3H00@000000;2`f02`/=P0/;3H100000050;2`f0030000002`/=P0/;3H0080
/;3H00<000000=IjH@3FNV400`3FNV400`0000000@0j0040>P050=IjG`050000000503d000000;2`
f0000000102`/=P3000000<0/;3H0`0000040=IiGP050000003FNEh0eWUN0=IiGP0000000`0H04`0
0`000000601<01P0C0030=IhFP8000001P2`/=P2000000@0/;3H00<000000;2`f02`/=P00P2`/=P2
000000H0/;3H0P00000302D0EP030000000U05H09@1F008000000P0U05H00d000000eg9=0=MbC@02
0=MbC@040000000X05P0:01H00000080/;7J0P0000000`3FLD/00000000000060;2afP030000002`
/MX0/;7J00@0/;7J00<000000300GP3FKdH00`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm6
00@000000=I_AP3FKdH0eVm60P0000020=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH01@00
0000eVm60=I_AP3FKdH0000000<0eVm600@000000=I_AP3FKdH000000`3FKdH010000000eVm60=I_
AP00000M0=7=Z@009P3AcJT00`000000000S00008`0500008`080000000002<0000000008`000000
000S0000000002<200000080000S00D0000000008`00000000000;2af@0200000080eG]T00<00000
0=EkI03ENf@00P0000000`2`/=P000000;2`f0050;2`f08000001@2`/=P00`000000/;3H0;2`f002
0;2`f0030000003FNV40eWYQ00<0eWYQ00D000000040>P0103Y00000000000030=IjG`0300000005
03d000000080/;3H0P0000000`2`/=P0000000000002000000D0/;3H00<000000=IiGP3FNEh00P3F
NEh01@000000eWUN0=IiGP3FNEh0000000<0601<00@0000001P0C00H04a000000`3FN5X3000000@0
/;3H100000000`2`/=P000000;2`f0040;2`f0040000002`/=P00000000000@0/;3H0`00000202D0
EP030000000U05H09@1F0080000000<09@1F0000002`/MX00P0000020=MbC@030000000X05P00000
00D0/;7J0P0000060;2afP040000002`/MX00000000000<0/;7J00<000000300GP0`05h0103FKdH0
1@000000eVm60=I_AP3FKdH0000000<0eVm600<000000=I_AP3FKdH00P3FKdH010000000eVm60=I_
AP0000030=I_AP040000003FKdH0eVm60=I_AP8000000P3FKdH01@000000eVm60=I_AP3FKdH00000
0080eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP030000003AcJT0dLfY01X0dLfY000U0=7=
Z@030000000002<0000S00<0000S00T0000000008`0002<0000000008`000000000S0000000002<0
100000001P0002<00000000000000000000S000000<0/;7I0`0000040=EkI0030000002`/=P0/;3H
00@0/;3H00<000000;2`f02`/=P00P0000020;2`f0090000003ENf8000000000002`/=P000000000
=T000000000000<0eWYQ00<000000040>P0000000P2`/=P2000000030=IjG`000000000000D0/;3H
00@000000;2`f02`/=P000001@2`/=P00`000000eWUN0=IiGP030=IiGP050000003FNEh0eWUN0=Ii
GP0000000`0H04`01@000000601<0000002`/=P000000080eWQJ00<000000=IhFP3FN5X00P000000
102`/=P0000001h0D@0000020;2`f08000001@2`/=P010000000/;3H0;2`f02`/=P2000000030;2`
f00000009@1F008000000P0U05H01`0000009@1F02D0EP0U05H0000002D0EP0000000`2`/MX40000
00H0/;7J00<000000;2af@000000102`/MX00`000000/;7J0;2afP020;2afP80000000D0/;7J0000
000`05h0<01N@00000030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH2000000<0eVm600D0
00000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_AP0000000P3FKdH01@000000
eVm60=I_AP3FKdH0000000<0eVm600@000000=I_AP3FKdH000000`3FKdH00`000000dLfY0=7=Z@0J
0=7=Z@00903AcJT00`000000000S00008`0500008`040000000002<0000000008`<0000000P0000S
000000000000000S0000000002<0000000008`8000001P2`/MT00`000000eG]T0=EkI0020=EkI0<0
0000102`/=P00`000000/;3H0;2`f0020;2`f0800000103ENf800d000000000f000000020;2`f080
000000<0eWYQ0000000000001@2`/=P2000000D0/;3H00D000000;2`f02`/=P000000;2`f0020000
0080/;3H00<000000100AP3FNEh0103FNEh01@000000eWUN0=IiGP3FNEh0000000<0601<00<00000
01P0C00000000P2`/=P3000000@0eWQJ00@0000001h0D@0N0540eWMI0P0000020;2`f08000000P2`
/=P00`000000/;3H0;2`f0040;2`f0050000000U05H09@1F02D0EP0000000P0U05H0100000009@1F
02D0EP0U05H2000000H0/;7J0P0000050;2afP040000002`/MT0/;7I0;2af@80000000<0/;7J0000
002`/MX01P2`/MX01@000000<01N0300GP000000[k;J008000000P3FKdH00`000000eVm60=I_AP02
00000080eVm60P0000030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_
AP3FKdH000000080eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_
AP0000000P3FKdH00`000000dLfY0=7=Z@0J0=7=Z@00903AcJT300008`030000000002<0000S0080
000S00<0000000008`0002<00P0002<02`000000000S00008`0002<0000000008`000000000S0000
000002<0000000H0/;7I00<000000=EkI03ENf@00`3ENf@00`000000eG]T0=EkI002000000030;2`
f0000000/;3H00@0/;3H00@000000;2`f000000000000P3ENf800`000000000f000000040;2`f080
00001P2`/=P00`000000/;3H000000040;2`f0040000002`/=P0/;3H000000<0/;3H0P0000020100
AP03@00000000000eWUN0080eWUN00D000000=IiGP3FNEh0eWUN0000000301P0C08000001@2`/=P0
0`000000eWQJ0=IhFP020=IhFP030000000N05407P1A00<0eWMI0P000000102`/=P0000000000000
00060;2`f08000000`0U05H0100000009@1F02D0EP00000302D0EP030000002`/MX0/;7J00@0/;7J
00<000000;2afP2`/MX00P0000020;2afP<0000000D0/;7I0000000^05`0;P1L000000070;2afP80
000000<0<01N0000002_/]X00`2_/]X3000000<0eVm600D000000=I_AP3FKdH0eVm6000000030=I_
AP050000003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600D0
00000=I_AP3FKdH0eVm6000000020=I_AP050000003FKdH0eVm60=I_AP0000000P3FKdH00`000000
dLfY0=7=Z@0J0=7=Z@008`3AcJT00`000000000S00008`0200008`030000000002<0000S0080000S
00P0000000008`0002<0000S0000000002<0000000008`8000000P0002<00`000000000S00000002
000000@0/;7I00<000000=EkI03ENf@00`3ENf@00`000000eG]T0=EkI0020=EkI08000001@2`/=P0
10000000/;3H0;2`f02`/=P4000000D0/;3H00@000000;2`f00000000000102`/=P00`000000/;3H
0;2`f002000000050;2`f000000000000;2`f0000000102`/=P2000000040100AP000000/;3H0;2`
f080000000<0eWUN0000003FNEh00P3FNEh01@000000601<01P0C00H04`0000000D0/;3H00<00000
0=IhFP3FN5X00`3FN5X00`0000007P1A01h0D@050=IgF@040000000R05<000000;2`f0800000102`
/=P2000000<09@1F00@0000002D0EP0U05H000000`0U05H00`3FLdl00000000000040;2afP030000
002`/MX0/;7J0080/;7J0P0000030=MbC@05@00000000000;P1L0000002`/MX00P0000040;2afP04
0000000`05h00000000000L0[k;J00D000000=I_AP3FKdH0eVm6000000030=I_AP040000003FKdH0
eVm60=I_AP8000000P3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0
eVm6000000030=I_AP040000003FKdH0eVm6000000<0eVm600D000000=I_AP3FKdH0eVm60000000K
0=7=Z@008`3AcJT700008`0;0000000002<0000S0000000002<0000000008`000000000S00000000
02<00P00000200008`030000000002<0eGaU0080eGaU0P0000000`2`/MT00000@00000040=EkI003
0000003ENf@0eG]T00<0eG]T00@000000=EkI000000000000P2`/=P00`000000/;3H0;2`f0040;2`
f08000001@2`/=P010000000/;3H0;2`f02`/=P2000000030;2`f0000000/;3H00@0/;3H00@00000
0=IjH@00000000001@2`/=P2000000030100AP000000/;3H00<0/;3H0P0000030=IiGP060000000H
04`0601<01P0C03FN5`00000102`/=P00`000000eWQJ0=IhFP030=IhFP050000000N05407P1A@000
000000000`3FMeT00`0000008P1C000000030;2`f080000000@0/;3H0000000U05H000000`0U05H0
1@0000009@1F02D0EP0U05H0000000809@1F0`3FLdl2000000030;2afP000000/;7J00@0/;7J00@0
00000;2afP00000000000P3GLTd00`000000;P1L000000030;2afP80000000D0/;7J0000000`05h0
<01N000000070:nbfP030000003FKdH0eVm60080eVm600D000000=I_AP3FKdH0eVm6000000040=I_
AP040000003FKdH0eVm6000000<0eVm60P0000030=I_AP040000003FKdH0eVm6000000<0eVm600D0
00000=I_AP3FKdH0eVm6000000020=I_AP050000003FKdH0eVm60=I_AP0000006`3AcJT00280dLfY
00@0000000008`0002<00000100002<02@000000000S00008`000000000S0000000002<000000000
8`040000000500008`000000000000008d000000103EO6D00`000000000W0000000200000080eG]T
00<000000=EkI03ENf@00`3ENf@010000000eG]T0=EkI03ENf@2000000H0/;3H00<000000;2`f02`
/=P00P0000020;2`f0080000003ENf8000000000002`/=P0000000D0?@0000050;2`f0050000003F
NV40eWYQ0000003FNV400P0000020;2`f0040000000@04H00000000000D0/;3H00<000000=IiGP3F
NEh00P3FNEh010000000601<01P0C00H04`20=IhG080000000D0/;3H0000000K04i0000000000003
0=IhFP030000000N054000000080/;3H0P0000000`3FMeT00000000000060;2`f0040000000U05H0
9@1F000000<09@1F00<0000002D0EP0U05H00P00000202D0EP03@000003FLdl0eW=?0080eW=?0P00
00050;2afP040000002`/MX0/;7J0;2afP@000001P2`/MX00`000000<01N0300GP020300GP800000
102_/]X00`000000<`5P0=I_AP030=I_AP050000003FKdH0eVm60=I_AP000000103FKdH01@000000
eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0eVm6000000020=I_AP050000003FKdH0
eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH000000080eVm600<000000=7=Z@3AcJT0
6@3AcJT00240dLfY00<0000000008`0002<01`0002<010000000000S0000000002<3000000060000
8`000000000000008`000000000S0`0000000`2`/MT00000000000020=ElI@8000000`2`/MT30000
00D0eG]T00<000000=EkI03ENf@00P3ENf@3000000@0/;3H00<000000;2`f02`/=P00P2`/=P20000
00@0eG]R00E0000000D0?@000000/;3H000000040;2`f0@000000`3FNV420000008040160P000005
0;2`f0030000003FNEh0eWUN0080eWUN00D0000001P0C00H04`0601<@00000030=IhG0030000000K
04h000000080/;3H0P0000000`3FN5X00000000000050;2`f08000001P2`/=P2000000809@1F00D0
000002D0EP0U05H09@1F0000000202D0EP80000000<09@1F0000002_/]X00P0000020=IcC`040000
003FLdl0000000000080/;7J00<000000;2afP2`/MX0102`/MX00`000000/;7J0;2afP040;2afP80
0000100`05h20=I`B080000000D0[k;J0000000c0F00<`5P@00000030=I_AP050000003FKdH0eVm6
0=I_AP000000103FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0eVm6
000000020=I_AP8000000`3FKdH010000000eVm60=I_AP0000030=I_AP040000003FKdH0eVm60000
01/0dLfY000Q0=7=Z@030000000002<0000S0080000S00<0000000008`0002<00P0002<00`000000
000S00008`0200008`030000000002<0000S0080000000H0000S0000000002<0000000008`000003
0;2af@@000001@2`/MT00`000000eG]T0=EkI0030=EkI0030000003ENf@0eG]T0080eG]T00<00000
0=EkI03ENf@00P0000000`2`/=P000000;2`f0040;2`f0040000002`/=P0000000000080eG]R00<0
000000D0?@0000000P2`/=P2000000030;2`f0000000/;3H0080/;3H00<000000=IjH@3FNV400P3F
NV400`00000040160100AP020=IjG`8000000P2`/=P00`0000005019@00000030=IiGP060000000H
04`0601<0000002`/=P000000P3FN5`00`0000006`1>000000040;2`f08000001P2`/=P00`000000
/;3H000000040;2`f0<000000P0U05H01@0000009@1F02D0EP0U05H0000000<09@1F00<0000002D0
EP0000000`2_/]X3000000<0eW=?0P0000060;2afP040000002`/MX00000000000@0/;7J0P000004
0300GP05@000003FL4P0eW180=I`B00000000P0c0F0010000000[k;J0000000000020=I_AP050000
003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_
AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_AP0000000P3FKdH01@000000eVm60=I_
AP3FKdH0000000<0eVm600<000000=7=Z@3AcJT0603AcJT00200dLfY00<0000000008`0000001000
02<00`000000000S0000000200008`0<0000000002<0000S00008`000000000S0000000002<00000
00008`000000000S0P0000060;2af@800000102`/MT00`000000eG]T0=EkI0040=EkI0030000003E
Nf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@2000000D0/;3H00@000000;2`f02`/=P0/;3H
100000050;2`f0050000002`/=P0/;3H0;2`f00000001@3FNV400`00000040160100AP040=IjG`80
000000@050190000002`/=P000000P3FNEh00`000000601<000000030;2`f0@000001@2`/=P01000
0000/;3H0000000000040;2`f0030000002`/=P0/;3H0080000000D0/;3H0000000U05H09@1F0000
000202D0EP050000000U05H09@1F02D0EP0000000`0U05H2000000H0[k;J00@000000=IcC`3FLdl0
eW=?0`0000040;2afP030000002`/MX0/;7J0080/;7J0P0000001@2`/MX000000300GP0`05h00000
0080<01N00@000000:nbfP00000000000P3FL4P00`000000<`5P000000030:nbfP<000000`3FKdH0
1@000000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0eVm6000000040=I_AP040000
003FKdH0eVm6000000<0eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP040000003FKdH0eVm6
000001X0dLfY000P0=7=Z@T0000S00/0000000008`0002<0000000008`000000000S0000000002<0
000000008`0200000080000S00<000000;2af@2`/MT0102`/MT00`000000/;7I0;2af@0200000080
/;7I00<000000=EkI03ENf@00`3ENf@2000000@0eG]T00<000000=EkI03ENf@00P3ENf@010000000
eG]T0000000000020;2`f0030000002`/=P0/;3H00@0/;3H00<000000;2`f02`/=P00`2`/=P00`00
0000/;3H0;2`f0020;2`f0030000003FNV40eWYQ00<0eWYQ00D000000100AP0@04I0000000000003
0=IjG`030000000D04T000000080/;3H100000060;2`f08000001@2`/=P010000000/;3H0;2`f02`
/=P2000000030;2`f0000000/;3H00@0/;3H00D0000002D0EP0U05H09@1F0000000202D0EP050000
000U05H09@1F02D0EP0000000`0U05H2000000D0[k;J00<000000=IcC`3FLdl00P3FLdl200000005
0=IcC`00000000000;2afP0000001`2`/MX01`000000<01N0300GP0`05h000000300GP000000102_
/]X4000000H0[k;J00D000000=I_AP3FKdH0eVm6000000040=I_AP040000003FKdH0eVm6000000@0
eVm600D000000=I_AP3FKdH0eVm6000000020=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH0
1@000000eVm60=I_AP3FKdH000000080eVm600<000000=7=Z@3AcJT0603AcJT00200dLfY2@0002<0
2@000000000S00008`000000000S0000000002<0000000008`0400000080000S00<0eGaV00000000
0000102`/MT00`000000/;7I0;2af@020;2af@80000000<0000[@000000000000`3ENf@00`000000
eG]T0=EkI0030=EkI0030000003ENf@0eG]T0080eG]T00@000000=EkI03ENf@0eG]T0P0000060;2`
f0040000002`/=P0000000000080/;3H00P000000=EkHP00000000000;2`f00000003@13@00000@0
eWYQ00<000000100AP0000000P2`/=P2000000030=IjG`000000000000D0/;3H00<000000;2`f02`
/=P0102`/=P00`000000/;3H0;2`f00200000080/;3H0`0000001@2`/=P000000280D`0R05<00000
00D0/;3H0P00000302D0EP040000000U05H09@1F000000<09@1F00@0000002D0EP0U05H09@1F0P00
00050:nbfP030000003FLdl0eW=?00<0eW=?00D000000=IcC`3FLdl0eW=?000000070;2afP800000
0`0`05h2000000L0[k;J00<000000:nbfP2_/]X0102_/]X00`000000=PAR0=I_AP020=I_AP030000
003FKdH0eVm60080eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_
AP0000000P3FKdH010000000eVm60=I_AP3FKdH200000080eVm600D000000=I_AP3FKdH0eVm60000
00020=I_AP030000003AcJT0dLfY01P0dLfY000O0=7=Z@H0000S00@0000000008`0002<0000S0P00
00000`0002<0000000008`0200000080000S0P000000100002<0000000008`0000030=ElIP800000
00<0/;7I0000002`/MT0102`/MT00`000000000[000000020;2af@80000000<0eG]T0000003ENf@0
103ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T0`0000040;2`f0040000
002`/=P0/;3H0;2`f0800000103ENf80140000003@130000002`/=P200000080eWYQ00<000000100
AP000000102`/=P2000000D0/;3H00@000000;2`f00000000000102`/=P00`000000/;3H0;2`f002
0;2`f08000000`3FN5`01D00000000000280D`000000/;3H008000000P2`/=P00`0000009@1F0000
000302D0EP040000000U05H09@1F000000<09@1F0P00000202D0EP80eW=A0P0000020:nbfP030000
000X05P0eW=?00@0eW=?00<000000=IcC`3FLdl00P3FLdl2000000@0/;7J0`0000030300GP030000
002_/]X0[k;J00D0[k;J00<000000:nbfP000000102_/]X00`000000=PAR03H4HP030=I_AP030000
003FKdH0eVm60080eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_
AP0000000`3FKdH01@000000eVm60=I_AP3FKdH000000080eVm600D000000=I_AP3FKdH0eVm60000
00030=I_AP030000003AcJT0dLfY01L0dLfY000O0=7=Z@0300008`000000000S00<0000S00<00000
00008`0002<00P0002<30000000300008`00000000000080000S0P0000000`0002<0000000008`06
0=ElIP8000001@2`/MT00`000000000[000000040;2af@8000001@3ENf@010000000eG]T0=EkI03E
Nf@2000000@0eG]T00<000000=EkI03ENf@00P0000000`2`/=P000000;2`f0040;2`f0<000000P3E
Nf800`0000003@13000000030;2`f0@000001@2`/=P00`000000/;3H000000040;2`f0040000002`
/=P000000;2`f080000000<0/;3H0000002`/=P0102`/=P010000000/;3H0000000000020=IhG003
0000000R05<0000000<0/;3H0`0000000`0U05H000000000000202D0EP040000000U05H09@1F0000
00<09@1F0P00000202D0EP@0eW=A0P00000202P0F003@00000000000eW=?0080eW=?00<000000=Ic
C`3FLdl00P3FLdl01P000000eW=?000000000000/;7J00000080<01N00<000000300GP0`05h00P0`
05h2000000@0[k;J00@000000:nbfP2_/]X0[k;J0P0000000`2_/]X0000003H4HP0203H4HP04@000
003FKdH0eVm6000000@0eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP030000003FKdH0eVm6
0080eVm600@000000=I_AP3FKdH000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600@0
00000=I_AP3FKdH000006@3AcJT001l0dLfY0P0002<00`000000000S00008`0200008`0300000000
02<000000080000S00h0000000008`0002<0000S0000000002<0000000008`000000000S00000000
02=00000000000<0eGaV0P0000000`3EO6H00000000000020;2af@<000001@2`/MT2000000D0eG]T
00@000000=EkI03ENf@0eG]T0P0000040=EkI0030000003ENf@0eG]T0080eG]T0P0000040;2`f004
0000002`/=P0/;3H0;2`f0@000001P2`/=P2000000D0/;3H00<000000;2`f02`/=P00P000000102`
/=P000000;2`f00000040;2`f08000001@2`/=P010000000/;3H0;2`f02`/=P4000000@0/;3H00@0
000002D0EP0000009@1F0P00000202D0EP040000000U05H09@1F000000<09@1F0P00000202D0EP03
@000003FLe40eW=A0080eW=A00<0000002P0F00000000P2_/]X2000000030=IcC`000000eW=?00<0
eW=?00D000000=IcC`3FLdl0eW=?000000030300GP030000000`05h0<01N0080<01N0P3FLD/20000
00030:nbfP000000[k;J00D0[k;J00L0000003H4HP0f1680=PAR0000002_/]/000000080eVm600D0
00000=I_AP3FKdH0eVm6000000030=I_AP040000003FKdH0eVm60=I_AP8000000`3FKdH010000000
eVm60=I_AP0000030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH010000000eVm60=I_AP00
000I0=7=Z@007`3AcJT400008`030000000002<0000S0080000S00/0000000008`0002<000000000
8`000000000S0000000002<0000000008`020000000400008`000000/;7I0;2af@80000000<0eGaV
0000003EO6H00`3EO6H2000000030000:`000000000000D0/;7I00<000000=EkI03ENf@00`3ENf@0
0`000000eG]T0=EkI0020=EkI0800000103ENf@00`000000eG]T0=EkI0020=EkI0040000003ENf@0
000000000080/;3H00<000000;2`f02`/=P00`2`/=P2000000D0/;3H00<000000;2`f02`/=P00P00
00020;2`f0030000002`/=P0/;3H00<0/;3H00@000000=IjH@00000000001@2`/=P300000080/;3H
00<000000;2`f02`/=P0102`/=P00`000000/;3H0;2`f0030;2`f0040000000U05H0000002D0EP80
00000P0U05H0100000009@1F02D0EP00000302D0EP80000000<09@1F0000002_/]X00P0000020=Ic
D@030000000X05P0000000@0[k;J0P0000040=IcC`050000003FLdl0eW=?0=IcC`0000000`0`05h0
0`000000<01N0300GP020300GP<0eW5;0P0000060:nbfP050000000f1680000003H4HP0000000`2_
/]/3000000@0eVm600@000000=I_AP3FKdH00000103FKdH01@000000eVm60=I_AP3FKdH000000080
eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH0
0`000000dLfY0=7=Z@0F0=7=Z@007P3AcJT600008`040000000002<0000S00008`80000000L0000S
0000000002<0000000008`000000000S00D000001@2`/MT2000000D0eGaV00@000000000:`3EO6D0
eGaU0P0000020;2af@030000000002l0eG]T00@0eG]T00<000000=EkI03ENf@00P3ENf@00`000000
eG]T0=EkI0030=EkI0030000003ENf@0eG]T0080eG]T00@000000=EkI03ENf@0eG]T0P0000050;2`
f0030000002`/=P0/;3H008000000P2`/=P01@000000eG]R000000000000/;3H00<000001@2`/=P0
1@000000eWYQ0=IjH@000000eWYQ008000000P2`/=P00`0000007P1A00000003000000H0/;3H00@0
00000;2`f000000000000P2`/=P0100000009@1F02D0EP00000202D0EP040000000U05H09@1F0000
00809@1F00<0000002D0EP0U05H00P0U05H00`0000009@1F000000030:nbfP@000001@2_/]X00`00
0000:`1J0=IcC`030=IcC`050000003FLdl0eW=?0=IcC`0000000`0`05h00`000000<01N0300GP02
0300GP04@000003FLD/0eW5;0=IaB`<00000102_/]X010000000=PAR0000000000060:nbf`030000
003FKdH0eVm60080eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_
AP0000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600@000000=I_AP3FKdH000000`3F
KdH00`000000dLfY0=7=Z@0F0=7=Z@007P3AcJT00`0002<0000000008`0300008`040000000002<0
000S00008`80000000<0000S0000000002<00P00000200008`@000001P2`/MT2000000D0eGaV00<0
00000000:`3EO6D00`3EO6D3000000030000;d000000000000<0eG]T00<000000=EkI03ENf@00P3E
Nf@00`000000eG]T0=EkI0030=EkI0030000003ENf@0eG]T0080eG]T00L000000=EkI03ENf@0eG]T
0000003ENf@0000000@0/;3H00<000000;2`f02`/=P00P2`/=P2000000@0eG]R00E0000001@0B@00
0000/;3H000000040;2`f0@000000`3FNV42000000807P1A00D000000;2`f02`/=P0/;3H00000004
0;2`f0030000002`/=P0/;3H0080/;3H0P00000302D0EP040000000U05H09@1F000000809@1F00@0
000002D0EP0U05H00000100U05H2000000H0[k;J0P0000050:nbfP030000000[05X0eW=?00@0eW=?
00D000000=IcC`3FLdl0eW=?000000020300GP070=MbC@000000<01N0300GP000000[k;K00000002
0=IaB`030000003FLD/0eW5;0080000000D0[k;J0000000f1680=PAR000000060:nbf`030000000h
1V@0eVm600<0eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_AP00
00000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0eVm600000002
0=I_AP030000003AcJT0dLfY01H0dLfY000N0=7=Z@80000S00@0000000008`0002<0000S0P000000
0`0002<0000000008`030000000300008`00000000000080000S0P00000200008`800000102`/MT2
000000D0eGaV00<000000000:d000000103EO6D00`000000000_000000020;2afP80000000<0eG]T
0000003ENf@00`3ENf@00`000000eG]T0=EkI0030=EkI0030000003ENf@0eG]T0080eG]T00D00000
0=EkI03ENf@0eG]T000000020=EkI080000000<0/;3H0000002`/=P0102`/=P010000000/;3H0000
000000020=EkHP030000000D04T000000080/;3H0P0000000`2`/=P000000;2`f0020;2`f0030000
003FNV40eWYQ0080eWYQ00@0000001h0D@0N0540eWYO0P0000020;2`f080000000<0/;3H0000002`
/=P0102`/=P2000000<09@1F00@0000002D0EP0U05H000000P0U05H01@0000009@1F02D0EP0U05H0
000000<09@1F00<000000:nbfP2_/]X0102_/]X00`000000[k;J0:nbfP0200000080[k;J00<00000
02/0FP0[05X01@3FLdl01@000000eW=?0=IcC`3FLdl000000080<01N0P0000000`0`05h000000:nb
f`020:nbf`<00000103FLD/010000000=PAR03H4HP0f1683000000@0[k;K00<0000003P6I03FKdH0
0`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600<000000=I_AP3FKdH00P3FKdH010000000
eVm60=I_AP0000030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH010000000eVm60=I_AP00
000H0=7=Z@007P3AcJT200008`030000000002<000000080000S00<0000000008`0000000P0002<0
1P000000000S00008`0002<0000000008`<0000000@0000S0000003EOFP0eGeX0P0000000`2`/MT0
000000009`050=ElIP040000000002/000000;2afP8000000P3EO6D00`000000000_000000040;2a
fP800000103ENf@00`000000eG]T0=EkI0020=EkI0800000103ENf@01@000000eG]T0=EkI03ENf@0
000000@0eG]T0P0000050;2`f0040000002`/=P0/;3H0;2`f0@000001@2`/=P01@000000/;3H0;2`
f02`/=P0000000D0eWYQ00<0000001h0D@0N05400`3FNUl2000000808P1C0P0000050;2`f0800000
0`0U05H0100000009@1F02D0EP00000202D0EP050000000U05H09@1F02D0EP0000000`0U05H00`3F
M5<000000:nbfP030:nbfP030000002_/]X0[k;J00<0[k;J0P00000302/0FP03@00000000000eW=?
0080eW=?00D000000=IcC`3FLdl0eW=?000000020300GP<000001P2_/]/00`000000eW5;0=IaB`02
0=IaB`030000000f1680=PAR0080=PAR0P3FL4P2000000050:nbf`000000>0IT03P6I40000000`3F
KdH01@000000eVm60=I_AP3FKdH0000000@0eVm600D000000=I_AP3FKdH0eVm6000000020=I_AP05
0000003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600<00000
0=7=Z@3AcJT05@3AcJT001d0dLfY00<0000000008`0002<00P0002<00`000000000S00008`020000
8`0=0000000002<0000S0000000002<0000000008`000000000S0000000002<0000000008`050=Em
J080000000<0000W@000000000000`3EO6H00`000000000[000000030;2afP@000001@2`/MX00`00
0000eG]T0=EkI0030=EkI0030000003ENf@0eG]T0080eG]T0P0000040=EkI0050000003ENf@0eG]T
0=EkI0000000103ENf@010000000eG]T0000000000020;2`f0030000002`/=P0/;3H00@0/;3H00<0
00000;2`f02`/=P00`2`/=P00`000000/;3H0;2`f0020;2`f0030000003FNV40eWYQ00<0eWYQ00@0
000001h0D@0N055000000`3FNUl00`0000008P1C000000020;2`f08000000P2`/=P00`0000009@1F
0000000302D0EP040000000U05H09@1F000000809@1F00D0000002D0EP0U05H09@1F0000000302D0
EP80eWAC0P0000000`2_/]X000000:nbfP050:nbfP8000000P0[05X00`000000[k;K0:nbf`020000
00030=IcC`000000eW=?0080eW=?00<000000300GP0`05h00P0000060:nbf`030000000c0F00eW5;
00<0eW5;00<0000003H4HP0f16800P0f16830=I`B08000000P0h1V@010000000[k?K000000000002
0=I_AP040000003FKdH0eVm6000000@0eVm600D000000=I_AP3FKdH0eVm6000000020=I_AP800000
0`3FKdH01@000000eVm60=I_AP3FKdH000000080eVm600D000000=I_AP3FKdH0eVm60000000G0=7=
Z@007@3AcJT00`0002<0000000008`0300008`040000000002<0000S00008`80000000L0000S0000
000002<0000000008`000000000S00<0000000<0000S@000000000000`3EOFP00`000000000W0000
00020;2afP80000000<0eGaV0000000000001P2`/MX2000000D0/;7J00<000000=EkI03ENf@00P3E
Nf@2000000@0eG]T00<000000=EkI03ENf@00`3ENf@01@000000eG]T0=EkI03ENf@0000000@0eG]T
00@000000=EkI03ENf@0eG]T0P0000060;2`f0040000002`/=P0000000000080/;3H00P000000=Ek
HP00000000000;2`f00000006`1>@00000@0eWYQ00@0000001h0D@000000/;3H0P0000000`3FNUl0
0000000000050;2`f08000000P0U05H01@0000009@1F02D0EP0U05H0000000809@1F00@0000002D0
EP0U05H000000`0U05H0100000009@1F02D0EP0U05H40=IdD`8000001@2_/]X01@000000eW=A0000
000[05X0000000D0[k;K0P0000030=IcC`050000000`05h0<01N0300GP3GLTd00P0000040:nbf`03
0000000c0F00eW5;00<0eW5;00<0000003H4HP0f16800P0f168014000000eW180=I`B000000203P6
I0030000002_/m/0[k?K0080[k?K0`0000030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH0
1@000000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP040000
003FKdH0eVm6000001L0dLfY000M0=7=Z@0300008`000000000000<0000S00@0000000008`0002<0
000S0P0000000`0002<0000000008`0200000080000S100000020;2afP80000000<0eGeX00000000
00001@2`/MX2000000H0/;7J00<000000;2afP2`/MX00P0000020;2afP030000003ENf@0eG]T00<0
eG]T00<000000=EkI03ENf@00`3ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080
eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0<00000102`/=P010000000
/;3H0;2`f02`/=P2000000@0eG]R00A0000001/0CP000000/;3H0P0000020=IjH@030000000N0540
000000<0/;3H0P0000060;2`f08000000P0U05H01@0000009@1F02D0EP0U05H0000000809@1F00@0
000002D0EP0U05H000000`0U05H01P0000009@1F02D0EP0U05I00000000000<0eWAC0`0000020:nb
fP030000000[05X0:`1J008000001P2_/]/00`000000eW=?0=IcC`020=IcC`040000000`05h0<01N
0300GP<0eg9=0P0000001@2_/]/0000003<1H00c0F10000000<0eW5;00L0000003H4HP0f1680=PAR
0000002_/m/000000080eW1800<0000003P6I00000001P2_/m/01@000000eVm60=I_AP3FKdH00000
00<0eVm600<000000=I_AP3FKdH00P3FKdH010000000eVm60=I_AP0000030=I_AP050000003FKdH0
eVm60=I_AP0000000`3FKdH010000000eVm60=I_AP00000G0=7=Z@007@3AcJT200008`0400000000
02<0000S00008`80000000<0000S0000000002<00P00000200008`8000000P0002<2000000030000
8`000000/;7J00<0/;7J0P0000060;2afP040000002`/MT00000000000@0/;7J00<000000;2afP2`
/MX00P2`/MX2000000030000<d000000000000<0eG]T00<000000=EkI03ENf@00`3ENf@00`000000
eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@00`000000
eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080000000<0/;3H0000002`/=P00`2`/=P010000000
/;3H0000000000020=EkHP030000000K04h0000000<0/;3H100000040;2`f0040000002`/=P00000
000000@0/;3H0P00000202D0EP050000000U05H09@1F02D0EP0000000P0U05H0100000009@1F02D0
EP00000302D0EP040000000U05H09@1F00000080[k;K0P000000103FM5<000000=IdD`3FM5<20000
00<0:`1J0P0000050:nbf`030000000^05`0eW=?00<0eW=?00@000000300GP0`05h0<01N1@3GLTd0
1@000000<`5P03<1H0000000[k?K008000000P3FLD/00`000000=PAR000000030:ncf`@000001P2_
/m/2000000<0eVm600D000000=I_AP3FKdH0eVm6000000040=I_AP040000003FKdH0eVm6000000<0
eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_AP0000005P3AcJT0
01`0dLfY00H0000000008`0002<0000000008`00000200008`040000000002<0000000008`800000
0P0002<20000000300008`0000000000008000001@2`/MX010000000/;7J0000000000040;2afP80
00000P2`/MT2000000030;2afP000000/;7J00@0/;7J00<000000000<`0000000P2_/]X200000003
0=EkI0000000eG]T00@0eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI003
0000003ENf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI003
0000002`/=P0/;3H00<0/;3H00@000000;2`f02`/=P0/;3H100000060;2`f0030000002`/=P0/;3H
00<0/;3H00@000000;2`f02`/=P0/;3H0P000000102`/=P0000002D0EP00000202D0EP050000000U
05H09@1F02D0EP0000000P0U05H0100000009@1F02D0EP00000302D0EP030000000U05H0000000D0
[k;K0P0000030=IdD`040000000[05X0:`1J02/0FP80eW=A0P0000020:nbf`030000000^05`0;P1L
00@0eW=?00H000000300GP0`05h0<01N@000000000030=MbC@030000000c0F00000000@0[k?K1000
00060:ncf`8000001@2_/m/00`000000>PUV03X9IP030=I_AP030000003FKdH0eVm60080eVm600D0
00000=I_AP3FKdH0eVm6000000020=I_AP030000003FKdH0eVm60080eVm600D000000=I_AP3FKdH0
eVm6000000020=I_AP050000003FKdH0eVm60=I_AP0000005P3AcJT001`0dLfY1@0002<2000000<0
000S00/0000000008`0002<0000000008`000000000S0000000002<0000000008`02000000D0/;7J
00@000000;2afP2`/MX0/;7J0P000000202`/MX000000=EmJ03EOFP00000@00000000000000_0P00
00050;2afP030000000003<0000000@0[k;J0P0000050=EkI0030000003ENf@0eG]T0080eG]T00<0
00000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T00<0
00000=EkI03ENf@00P3ENf@300000080/;3H00<000000;2`f02`/=P0102`/=P2000000D0/;3H00@0
00000;2`f000000000000P2`/=P00`000000/;3H0;2`f0040;2`f0040000000U05H09@1F00000080
9@1F00D0000002D0EP0U05H09@1F0000000202D0EP030000000U05H09@1F008000000P0U05H20000
00H0[k;K00<000000=IdD`3FM5<00P3FM5<0100[05X0000002/0FP0[05X40=IcD@8000000`0^05`0
0d000000eW=?0=IcC`020=IcC`030000000`05h000000080[k?K0P0000000`3GLTd0000000000007
0:ncf`030000002_/m/0[k?K00@0[k?K00<000000:ncf`2_/m/00P0000020:ncf`040000000j2FH0
>PUV03X9IP<0eVm600<000000=I_AP3FKdH00P3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm6
00D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_AP0000000P3FKdH00`00
0000dLfY0=7=Z@0D0=7=Z@00703AcJT00`0002<0000000008`0300008`040000000002<0000S0000
8`80000000L0000S0000000002<0000000008`000000000S008000000P3DOFT200000080/;7J00<0
00000;2afP2`/MX0102`/MX00`000000eGeX0=EmJ0020=EmJ0030000000002l000000080/;7J0P00
00020;2afP<000001@2_/]X2000000D0eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=Ek
I0020=EkI0030000003ENf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=Ek
I0020=EkI0030000003ENf@0eG]T00<000001@2`/=P00`000000/;3H0;2`f00200000080/;3H00D0
00000=EkHP00001000000280D`03000000D0/;3H0P00000202D0EP040000000U05H09@1F000000<0
9@1F00@0000002D0EP0U05H000000P0U05H2000000809@1F0P0000050:nbf`030000000X05P0eWAC
00@0eWAC00@0000002/0FP0[05Y00000103FLe401@000000;P1L02h0G0000000[k?K008000000P3F
Ldl00`000000<01N000000040:ncf`8000001`2_/m/010000000[k;K0000000000040:ncf`030000
002_/m/0[k?K0080[k?K0P00000403X9IP05@000003FKdH0eVm60=I_AP0000000`3FKdH00`000000
eVm60=I_AP020=I_AP040000003FKdH0eVm6000000<0eVm600D000000=I_AP3FKdH0eVm600000003
0=I_AP040000003FKdH0eVm6000001H0dLfY000L0=7=Z@0300008`000000000000<0000S00T00000
00008`0002<0000000008`000000000S0000000002<00P00000200008`030000003DOFT0e7eY00<0
e7eY0P0000060;2afP040000002`/MX0000000000080eGeX00<000000000;`000000102`/MX20000
00030000<`000000000000D0[k;J00<000000=EkI03ENf@0103ENf@00`000000eG]T0=EkI0020=Ek
I0040000003ENf@0eG]T0=EkI0800000103ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0
eG]T0080eG]T00@000000=EkI03ENf@0eG]T100000020;2`f0030000002`/=P0/;3H00<0/;3H0P00
00030=EkHP030000000R05<000000080/;3H0P0000020;2`f0030000000U05H0000000809@1F00@0
000002D0EP0U05H000000`0U05H0100000009@1F02D0EP00000202D0EP8000000`0U05H00`3FMED0
0000000000020:nbf`030000000X05P0:01H00D0eWAC00@0000002/0FP000000[k?K0P0000020=Ic
D@030000000^05`0000000@0[k?K100000050:ncf`040000002_/m/00000000000@0[k?K0P000000
0`2_/]/0000003P6I002000000030:ncf`000000[k?K00@0[k?K0P00000303X9IP060000002_/m/0
00000000003FKdH000000`3FKdH00`000000eVm60=I_AP020=I_AP040000003FKdH0eVm6000000<0
eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_AP0000005@3AcJT0
01`0dLfY0P0002<010000000000S0000000002<20000000300008`000000000S008000000P0002<2
00000080000S00<00000@000003DOFT0103DOFT3000000@0/;7J00@000000;2afP2`/MX0/;7J1000
00050;2afP80000000<0000c0=ElI@3EO6D00P0000020:nbfP030000000003H0eG]T00@0eG]T00<0
00000=EkI03ENf@00`3ENf@010000000eG]T0=EkI03ENf@2000000<0eG]T0P0000040=EkI0030000
003ENf@0eG]T0080eG]T00D000000=EkI03ENf@0eG]T000000030=EkI08000001P2`/=P00`000000
/;3H000000020=EkHP030000000R05<0000000@0/;3H0P00000202D0EP040000000U05H09@1F0000
00809@1F00D0000002D0EP0U05H09@1F0000000202D0EP050000000U05H09@1F02D0EP0000000`0U
05H30=IeE@<000000P0X05P00d00000000000=IdD`020=IdD`030000000[05X0000000<0[k?K1000
00070:ncf`8000001@2_/m/010000000[k?K0:ncf`2_/m/2000000050:ncf`000000eg9=0=MbC@00
0000100h1V@00`000000[k?K0:ncf`030:ncf`060000000j2FH0eW180000000j2FH00000102_/m/2
000000<0eVm600<000000=I_AP3FKdH00P3FKdH010000000eVm60=I_AP0000040=I_AP050000003F
KdH0eVm60=I_AP0000000P3FKdH01@000000eVm60=I_AP3FKdH0000001D0dLfY000K0=7=Z@060000
000002<0000S0000000002<000000P0002<010000000000S0000000002<200000080000S0P000000
0`0002<000000000000300000080e7eY00@000000=AmJ@3DOFT0e7eY0P0000000`2`/MX000000;2a
fP050;2afP8000001@2`/MX2000000030000<`3EO6D0eGaU0080eGaU0P0000020000=P03@000003E
Nf@0eG]T0080eG]T00<000000=EkI03ENf@00`3ENf@010000000eG]T0=EkI03ENf@2000000<0eG]T
0P0000040=EkI0030000003ENf@0eG]T0080eG]T00D000000=EkI03ENf@0eG]T000000040=EkI0<0
0000102`/=P00`000000/;3H0;2`f004000000D0/;3H0P00000202D0EP040000000U05H09@1F0000
00809@1F00D0000002D0EP0U05H09@1F0000000202D0EP050000000U05H09@1F02D0EP0000000`0U
05H00d000000eWEE0=IeE@020=IeE@030000000X05P000000080[k?K0P0000000`3FM5<000000000
00060:ncf`030000002_/m/0[k?K00D0[k?K00<000000:nbfP2_/]X00P0000020:ncf`030000002_
/m/0[k?K00@0[k?K00D000000=MbC@3GLTd0eg9=0000000303P6I0040000002_/m/0000000000080
[k?K00@0000003X9IP0j2FH0eW180P0000050:ncf`800000103FKdH01@000000eVm60=I_AP3FKdH0
000000<0eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_AP000000
0P3FKdH00`000000dLfY0=7=Z@0C0=7=Z@006`3AcJT00`0002<0000000008`0300008`0500000000
02<0000S00008`0000000P0002<01P000000000S0000000002<0000000008`8000000`2_/]X30000
00D0e7eY0P0000050;2afP030000002`/MX0/;7J008000000P2`/MX3000000030000<d000000eGaU
00<0eGaU00@000000000=P000000[k;J0P0000020=EkI0030000003ENf@0eG]T00<0eG]T00D00000
0=EkI03ENf@0eG]T000000040=EkI0800000103ENf@00`000000eG]T0=EkI0020=EkI0050000003E
Nf@0eG]T0=EkI0000000103ENf@00`000000eG]T0=EkI002000000030;2`f0000000/;3H00@0/;3H
0P0000050;2`f08000000P0U05H0100000009@1F02D0EP00000202D0EP050000000U05H09@1F02D0
EP0000000P0U05H01@0000009@1F02D0EP0U05H0000000809@1F00@000000:ncf`00000000000P3F
MED00`000000:01H000000040:ncf`8000001P2_/m/010000000[k?K0000000000040:ncf`030000
002_/]X0[k;J00<0[k;J0P0000060:ncf`040000002_/m/0000000000080eg9=00<0000003P6I000
0000102_/m/2000000<0>PUV00<0eW180000002_/m/01@2_/m/00`000000?@aW0=I_AP030=I_AP05
0000003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600D00000
0=I_AP3FKdH0eVm6000000020=I_AP030000003AcJT0dLfY01<0dLfY000K0=7=Z@0300008`000000
000000<0000S00@0000000008`0002<0000S0P0000000`0002<0000000008`030000000300008`00
0000000000D0[k;J00<000000=AmJ@3DOFT00`3DOFT010000000e7eY0000000000020;2afP030000
002`/MX0/;7J00<0/;7J0P0000001@0003<000000000<`000000[k;J008000000P3EO6D00`000000
000f000000030:nbfP<000001@3ENf@01@000000eG]T0=EkI03ENf@0000000@0eG]T00<000000=Ek
I03ENf@00`3ENf@00`000000eG]T0=EkI0020=EkI0050000003ENf@0eG]T0=EkI0000000103ENf@0
0`000000eG]T0=EkI0020=EkI0030000002`/=P0/;3H00<0/;3H00<000000;2`f02`/=P00P000002
0;2`f0030000000U05H0000000809@1F00@0000002D0EP0U05H000000P0U05H01@0000009@1F02D0
EP0U05H0000000809@1F00L0000002D0EP0U05H09@1F0000000U05H0000000@0[k?K100000050:nc
f`040000002_/]/00000000000@0[k?K00@000000:ncf`2_/m/0[k?K0P0000000`2_/m/000000:nb
fP050:nbfP<00000102_/m/00`000000[k?K0:ncf`020:ncf`@000001@2_/m/300000080>PUV00@0
00000=I`B000000000000`2_/m/00`000000?@aW03d<I`040=I_AP030000003FKdH0eVm60080eVm6
00@000000=I_AP3FKdH000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_
AP3FKdH0eVm60000000D0=7=Z@006`3AcJT200008`040000000002<0000S00008`80000000<0000S
0000000002<00`0000000`0002<000000000000200008`030000002_/]X0[k;J00@0[k;J00<00000
0=AmJ@3DOFT00`3DOFT010000000e7eY0=AmJ@3DOFT2000000H0/;7J00H000000000<`0003<00000
0000<`0000030:nbfP@000001P2_/]X00`000000eG]T0=EkI0030=EkI0050000003ENf@0eG]T0=Ek
I0000000103ENf@00`000000eG]T0=EkI0030=EkI0040000003ENf@0eG]T0=EkI08000000`3ENf@0
0`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T0`0000020;2`f0030000002`/=P0
/;3H00<0/;3H0P00000202D0EP040000000U05H09@1F000000809@1F00@0000002D0EP0U05H00000
0`0U05H00`0000009@1F02D0EP02000000809@1F0P0000070:ncf`030000002_/m/0[k?K00<0[k?K
0P0000020:nbf`<0000000<0[k?K0000002_/m/01@2_/m/3000000@0[k;J00<0000003H4HP000000
0`0000000`2_/m/000000:ncf`060:ncf`8000001@2_/m/3000000<0>PUV0`3FL4P2000000050:nc
f`000000?@aW03d<Id0000000`3FKdH00`000000eVm60=I_AP020=I_AP040000003FKdH0eVm60000
00@0eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP040000003FKdH0eVm6000001@0dLfY000J
0=7=Z@070000000002<0000S0000000002<0000000008`020000000300008`000000000S00800000
0P0002<200000080000S00<0e7iZ0000000000000`2_/]X00`000000e7eY0=AmJ@040=AmJ@030000
003DOFT0e7eY0080e7eY0`0000040;2afP030000000003<0000c008000001P2_/]X2000000D0[k;J
00<000000=EkI03ENf@00`3ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T
00<000000=EkI03ENf@00P3ENf@2000000<0eG]T0P0000030=EkI0030000003ENf@0eG]T0080eG]T
00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI002000000H0/;3H0P00000202D0EP040000
000U05H09@1F000000809@1F00@0000002D0EP0U05H000000`0U05H00`0000009@1F02D0EP020000
00809@1F00<000000:ncf`2_/m/01@2_/m/010000000[k?K0000000000020:ncf`050000003FMED0
eWEE0000040000000`0^05`00`000000[k?K0:ncf`040:ncf`040000003FM5<000000=IdD`800000
00D0[k;J0000000f1680=PAR000000030:nbf`030000002_/m/0[k?K00D0[k?K00<000000:ncf`2_
/m/00P0000020:ncf`040000000j2FH0>PUV000000<0>PUV103FL4P200000080?@aW00@000000:nc
g000000000000P3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0eVm6
000000030=I_AP050000003FKdH0eVm60=I_AP0000000P3FKdH00`000000dLfY0=7=Z@0B0=7=Z@00
6P3AcJT01@0002<0000000008`000000000S0080000000D0000S0000000002<0000000008`020000
000600008`00000000000000000002<000000`3DOVX2000000030:nbfP000010000000D0e7eY00@0
00000=AmJ@3DOFT0e7eY0P0000020=AmJ@80000000<0/;7J0000000000000P0003<00`000000[k;J
0:nbfP040:nbfP030000002_/]X0[k;J008000000P2_/]X00`0000000@0j0=EkI0040=EkI0030000
003ENf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0800000
0`3ENf@2000000<0eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0030000
003ENf@0eG]T0080eG]T0P0000040;2`f08000000P0U05H0100000009@1F02D0EP00000202D0EP04
0000000U05H09@1F000000<09@1F00<0000002D0EP0U05H00P00000202D0EP030=IfE`0000000000
00@0[k?K00<000000:ncf`2_/m/00P2_/m/2000000@0eWEE00D0000002h0G00^05`000000:ncf`02
000000@0[k?K0`0000030=IdD`030000000f1680=PAR0080=PAR0P0000020:nbf`800000102_/m/0
0`000000[k?K0:ncf`030:ncf`8000000`0j2FH01P000000>PUV03X9IP0j2FI00000000000<0eW18
00<0000003d<I`000000102_/m`3000000<0eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP05
0000003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH0000001<0dLfY000J0=7=
Z@0300008`000000000S00<0000S00D0000000008`000000000S0000000200008`060000000002<0
000000008`000000000S1P3DOVX2000000030:nbfP00000000000080e7eY00<000000=AmJ@3DOFT0
0P3DOFT2000000@0e7eY00H000000000<`000000000c0000003EO6H2000000@0[k;J00<000000:nb
fP2_/]X00P2_/]X2000000800@0j00=000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=Ek
I0030000003ENf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@2000000<0eG]T00<000000=Ek
I03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T00<000000=Ek
I03ENf@00P3ENf@020000000eG]T000000000000/;3H0000000U05H000000P0U05H0100000009@1F
02D0EP00000202D0EP040000000U05H09@1F000000<09@1F0P0000000`0U05H000000000000202D0
EP<0eWIG0P0000000`2_/m/000000:ncf`040:ncf`040000002_/m/0000000000080eWEE00<00000
02h0G0000000102_/m/2000000050:ncf`000000[k;K0:nbf`0000000`3FM5<00`000000=PAR03H4
HP0203H4HP80eW=A0P0000001P2_/]/00000000000000000[k?K000000H0[k?K0P00000303X9IP04
0000000j2FH0>PUV00000080[k?L0P0000000`3FL4P00000000000070:ncg0030000003FKdH0eVm6
0080eVm600@000000=I_AP3FKdH000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600D0
00000=I_AP3FKdH0eVm60000000C0=7=Z@006P3AcJT00`0002<000000000000300008`0900000000
02<0000S0000000002<0000000008`000000000S00<0000000<0000S@000000000000`3DOVX00`00
0000000W000000030:nbfP<00000103DOFT2000000@0e7eY00@000000000<`000000000c103EO6H2
000000030:nbfP000000[k;J00@0[k;J0P0000000`0103X000000:nbf`0200000080eG]T00<00000
0=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T00<00000
0=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T00<00000
0=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0050000003ENf@0eG]T0=EkI00000000P0U
05H0100000009@1F02D0EP00000202D0EP040000000U05H09@1F000000<09@1F00<0000002D0EP0U
05H00P00000202D0EP030000000U05H09@1F00D0eWIG0P0000050:ncf`040000002_/m/0[k?K0:nc
f`@000001`2_/m/010000000[k;K0:nbf`0000040=IdD`030000000f1680=PAR0080=PAR103FLe40
10000000>0IT03P6I00h1V@2000000D0[k?K00<0000003X9IP0000000`0j2FH0103FLD/0000003X9
IP0000040:ncg08000001`2_/m`00`000000eVm60=I_AP030=I_AP040000003FKdH0eVm6000000@0
eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP040000003FKdH0eVm6000001<0dLfY000I0=7=
Z@070000000002<0000S0000000002<0000000008`020000000300008`000000000S00<0000000D0
000S000000000000000S000000020:nbfP80000000<0e7iZ0000000000001P2_/]X00`000000e7eY
0=AmJ@020=AmJ@030000003DOFT0e7eY00<0e7eY00@000000000<`000000000c1@3EO6H3000000D0
[k;J0P0000000`0103X000000:nbf`020:nbf`<00000103ENf@00`000000eG]T0=EkI0020=EkI003
0000003ENf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI003
0000003ENf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI005
0000003ENf@0eG]T0=EkI00000000P0U05H0100000009@1F02D0EP00000202D0EP040000000U05H0
9@1F000000<09@1F00<0000002D0EP0U05H00P00000202D0EP050000000U05H09@1F@00000000000
0`3FMUL010000000eWIG0000000000020:ncf`030000002_/m/0[k?K00@0[k?K00<000000:ncf`2_
/m/01@2_/m/01@000000[k;K0:nbf`000000<`5P00@0eWAC00<0=PAR0000000f16800P0f16800d00
0000eW=A0=IcD@020=IcD@030000000h1V@000000080[k?K0P0000020:ncf`050000000j2FH0>PUV
0=MbC@0000000P0j2FH00`3FLD/00000000000050:ncg0040000002_/m`00000000000@0[k?L00<0
000003l>J@0o3VT0103FKdH010000000eVm60=I_AP0000040=I_AP050000003FKdH0eVm60=I_AP00
00000`3FKdH010000000eVm60=I_AP00000C0=7=Z@006@3AcJT20000000500008`000000000S0000
000002<00P0000000`0002<0000000008`0200000080000S0`0000050:nbfP8000001P2_/]X00`00
0000e7eY0=AmJ@030=AmJ@030000003DOFT0e7eY00<0e7eY00H000000000<`000000000c@0000000
00030=ElIP030000003EO6H0eGaV008000000P2_/]X0100000000@0j0000000000060:nbf`030000
003ENf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0030000
003ENf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0030000
003ENf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@01@000000eG]T0=EkI03ENf@000000080
9@1F00@0000002D0EP0U05H000000P0U05H0100000009@1F02D0EP00000302D0EP030000000U05H0
9@1F008000000P0U05H00`0000009@1F000000020:ncf`80000000<0eWIG0000003FMUL00P3FMUL2
000000H0[k?K00@000000:ncf`0000000000102_/m/2000000050:nbf`000000<`5P03<1H4000000
103FM5<01@000000=PAR03H4HP000000[k?K008000000P3FLe400`000000>0IT000000040:ncf`80
00000`0j2FH200000080>PUV0P0000050:ncg0030000002_/m`0[k?L0080[k?L0P0000000`2_/m`0
000003l>J@0203l>J@@0eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm6
0=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH000000180dLfY000I0=7=Z@0500008`000000
000S0000000002<00P0000001@0002<0000000008`000000000S0080000000@0000S000000000000
00001P2_/]X010000000[k;J0000000000040:nbfP030000003DOFT0e7eY00<0e7eY00<000000=Am
J@3DOFT00`3DOFT2000000040000<`000000[k;K0:nbf`80000000<0eGaV0000003EO6H00`3EO6H2
000000030040>P000000000000H0[k;K00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI003
0=EkI0030000003ENf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI002
0=EkI0030000003ENf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@010000000eG]T0=EkI03E
Nf@2000000<0eG]T00@0000002D0EP0U05H000000P0U05H0100000009@1F02D0EP00000202D0EP05
0000000U05H09@1F02D0EP0000000`0U05H01P0000009@1F02D0EP0000009@1F000000@0[k?K0P00
00040=IfE`<00000102_/m/010000000[k?K0:ncf`2_/m/2000000090:ncf`000000eWEE0=IeED00
0000000003<1H0000000[k?K008000000P3FM5<00`000000=PAR000000040:ncf`@000001@2_/m/2
000000<0>PUV0P00000303X9IP030=IaB`00000000000080[k?L00<000000:ncg02_/m`01@2_/m`0
0`000000?`iY03l>J@0203l>J@03@00000000000eVm60080eVm600@000000=I_AP3FKdH000000`3F
KdH01@000000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0eVm60000000B0=7=Z@00
6@3AcJT00`0002<000000000000300008`030000000002<0000000<0000000H0000S0000000002<0
000000008`3DOV/2000000@0[k;J00@000000:nbfP2_/]X0[k;J0P0000000`2_/]X00000@0000004
0=AmJ@800000103DOFT01@000000000c0000000003<0000000@0[k;K0P0000050=ElIP0400000001
03X000000=ElI@800000102_/]/00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T00<0eG]T
00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T
00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0040000003ENf@0eG]T0=EkI080
00000`3ENf@0100000009@1F02D0EP00000202D0EP040000000U05H09@1F000000809@1F00D00000
02D0EP0U05H09@1F0000000302D0EP030000000U05H09@1F008000001@2_/m/00`000000:01H0=If
E`040=IfE`060000003FMUL000000000002_/m/000001P2_/m/2000000<0eWEE00<0000003<1H000
00000`2_/m/4000000L0[k?K00<000000:ncf`2_/m/00`2_/m/00`000000>PUV0000000303X9IP80
00000`0j2FH30=IaB`8000001`2_/m`2000000<0?`iY00<000000:ndg02_]=`00P0000001@3FKdH0
00000=I_AP3FKdH0000000@0eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP040000003FKdH0
eVm600000180dLfY000H0=7=Z@080000000002<000000000000002<0000000008`00000200008`06
0000000002<0000000008`000000000S0P0000030=AnJ`80000000<0[k;J0000002_/]X01@2_/]X0
0`000000000[0000000200000080e7eY00<000000=AmJ@3DOFT00`3DOFT010000000000c00000000
00060:nbf`030000003EO6H0eGaV00<0eGaV00<000000040>P3EO6D00`3EO6D2000000030:nbf`00
0010000000@0eG]T00<000000=EkI03ENf@00`3ENf@00`000000eG]T0=EkI0020=EkI0030000003E
Nf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0030000003E
Nf@0eG]T0080eG]T00D000000=EkI03ENf@0eG]T000000040=EkI0040000000U05H09@1F00000080
9@1F00@0000002D0EP0U05H000000P0U05H01@0000009@1F02D0EP0U05H0000000<09@1F00<00000
02D0EP0U05H00P0000050:ncf`030000000X05P0eWIG00@0eWIG00D000000=IfE`3FMUL0eWIG0000
00060:ncf`030000002_/m/0[k?K0080000000<0eWEE0000000000001P2_/m/2000000D0[k?K0P00
00000`2_/m/00000000000020:ncf`040000000j2FH0>PUV000000@0>PUV00D0000003X9IP0j2FH0
>PUV@00000030=IaB`<00000102_/m`01P000000?`iY03l>J@000000?`iY000000D0[kCL0P000002
0=I_AP030000003FKdH0eVm60080eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP040000003F
KdH0eVm600000180dLfY000H0=7=Z@070000000002<0000S0000000002<0000000008`0200000003
00008`000000000S00<0000000<0000S0000003DOV/01@3DOV/2000000D0[k;J0`0000030:nbf`<0
00001@3DOFT010000000000c0000000000050:nbf`030000003EO6H0eGaV00@0eGaV00<000000040
>P3EO6D0103EO6D3000000030:ncf`00000000000080eG]T00<000000=EkI03ENf@00`3ENf@00`00
0000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@00`00
0000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T00D000000=EkI03ENf@0eG]T00000004
0=EkI0040000000U05H09@1F000000809@1F00@0000002D0EP0U05H000000P0U05H01@0000009@1F
02D0EP0U05H0000000<09@1F00<0000002D0EP0U05H00P3FMeT200000080[k?K00<0000002P0F00X
05P01@3FMUL010000000eWIG0=IfE`3FMUL3000000@0[k?K00<000000:ncf`2_/m/00P2_/m/20000
00H0[k?K00<000000:nbf`2_/]/00P0000020:ncf`030000002_/m/0[k?K00<0[k?K0P00000303X9
IP030000000j2FH0>PUV0080>PUV00D0000003X9IP0j2FH000000:ndg00200000080eW5;00H00000
0=IaB`00000000000:ncg000000303l>J@8000001P2_]=`00`000000eVm60=I_AP020=I_AP050000
003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600<000000=7=
Z@3AcJT03`3AcJT001P0dLfY00D0000S0000000002<0000000008`020000000500008`000000000S
0000000002<00P00000200008`03000004000000e7i[00D0e7i[0`0000020:nbfP040000000002/0
0000000000D0[k;K00<000000=AmJ@3DOFT00`3DOFT010000000000c0=EmJ03EOFP300000080[k;K
00<000000=ElIP3EO6H00`3EO6H01@0000000@0j0040>T000000000000<0eGaU00<0000000D0?@00
00000`2_/m/3000000@0eG]T00<000000=EkI03ENf@00`3ENf@00`000000eG]T0=EkI0020=EkI003
0000003ENf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI005
0000003ENf@0eG]T0=EkI0000000103ENf@0100000009@1F02D0EP00000202D0EP040000000U05H0
9@1F000000809@1F0P00000202D0EP050000000U05H09@1F02D0EP0000000P0U05H40=IgF@800000
0`0X05P00d000000eWIG0=IfE`020=IfE`050000003FMUL0eWIG0=IfE`0000000P3FMUL200000003
0:ncf`000000[k?K00@0[k?K00@000000:ncf`0000000000102_/m/2000000030:nbf`000000>0IT
008000001P2_/m/2000000<0>PUV00<0000003X9IP0j2FH00P0j2FH0103GLTd0000003X9IP000003
0:ndg0<000000`3FLD/00`000000?`iY03l>J@0203l>J@8000001@2_]=`00`000000@A1[0=I_AP03
0=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm6
00<000000=7=Z@3AcJT03`3AcJT001P0dLfY00D0000S0000000002<0000000008`02000000050000
8`000000000S0000000002<00P0000000`0002<0000000000003000000<0e7i[00@000000=AnJ`3D
OV/0e7i[0P0000020000:`030000002_/]/0[k;K00@0[k;K00<000000=AmJ@3DOFT00`3DOFT00`00
0000000c0=EmJ0040=EmJ080000000<0000f@000003EO6H00`3EO6H00`0000000@0j000000020:nc
f`80000000<0eGaU0000000000001P2_/m/00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T
00<0eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T
0080eG]T00<000000=EkI03ENf@00P3ENf@01@000000eG]T0=EkI03ENf@0000000@0eG]T00@00000
02D0EP0U05H000000P0U05H0100000009@1F02D0EP00000202D0EP8000000P0U05H01@0000009@1F
02D0EP0U05H0000000809@1F1@3FMeT01@000000:01H02P0F0000000[k?L008000000P3FMUL01@00
0000eWIG0=IfE`3FMUL0000000@0eWIG00<000000:ncf`2_/m/00`2_/m/00`000000[k?K0:ncf`02
0:ncf`80000000D0[k?K0000003FMED0eWEE@000000203P6I0040000002_/m/00000000000@0[k?K
0P00000403X9IP050000000j2FH0>PUV03X9IP3GLTd00P0000060:ndg0030000003FLD/0eW5;0080
eW5;00@0000003l>J@0o3VT0?`iY0P3FL4P200000080[kCL00<00000044@J`1146/0103FKdH00`00
0000eVm60=I_AP020=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH010000000eVm60=I_AP00
000A0=7=Z@00603AcJT00`0002<000000000000300008`090000000002<000000000000002<00000
00008`000000000S008000000`2_/]/2000000030=AnJ`000000e7i[00<0e7i[00@000000000:`00
02/0e7iZ0P0000030:nbf`030000003DOFT0e7eY00@0e7eY00<000000000<d000000103EOFP01000
0000000f0000002_/m/200000080eGaV00<000000040>P000000102_/m/2000000H0[k?K00<00000
0=EkI03ENf@00`3ENf@00`000000eG]T0=EkI0030=EkI0030000003ENf@0eG]T0080eG]T00<00000
0=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T00D00000
0=EkI03ENf@0eG]T000000040=EkI0040000000U05H09@1F000000809@1F00@0000002D0EP0U05H0
00000P0U05H2000000809@1F00D0000002D0EP0U05H09@1F0000000202D0EP03@00000000000eWMI
0080eWMI00<0000002P0F0000000102_/m`3000000<0eWIG00<000000=IfE`3FMUL00P3FMUL30000
0080[k?K00<000000:ncf`2_/m/01@2_/m/01`000000eWEE0=IeE@3FMED0000003P6I0000000102_
/m/2000000050:ncf`000000>PUV03X9IP0000000`0j2FH01P000000>PUV03X9IP0j2FH0eg9=0000
00H0[kCL0P0000040=IaB`030000000o3VT0?`iY0080?`iY0`3FL4P2000000<0@A1[00E000000=I_
AP3FKdH0eVm6000000040=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH010000000eVm60=I_
AP00000A0=7=Z@005`3AcJT01`000000000S00008`000000000S0000000002<00P0000001`0002<0
000000008`000000000S0000000002<00P0000050:nbf`800000103DOV/00`000000000[0=AnJP03
0=AnJP80000000<0[k;K0000003DOFT0103DOFT010000000000c0000002_/m/200000080eGeX00<0
00000000=P0000000`2_/m/4000000D0[k?K00@000000:ncf`0000000000102_/m/00`000000eG]T
0=EkI0030=EkI0030000003ENf@0eG]T00<0eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T
0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@01@000000eG]T
0=EkI03ENf@0000000@0eG]T00@0000002D0EP0U05H000000P0U05H0100000009@1F02D0EP000003
02D0EP040000000U05H09@1F000000<09@1F00<0000002D0EP0000000P2_/m`2000000030=IgF@00
0000000000L0[k?L00D000000=IfE`3FMUL0eWIG000000040=IfE`030000003FMUL0eWIG00800000
1`2_/m/01@000000[k?K000000000000eWEE008000001`2_/m/01@000000>PUV03X9IP0j2FH00000
00<0>PUV00L0000003X9IP0j2FH0>PUV0000003GLTd0000000@0[kCL00<0000003d<I`0m36L0103F
LD/00`000000?`iY03l>J@0203l>J@<0eW1800H00000044@J`1146/0@A1[0000002_]=`200000080
eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH0
0`000000dLfY0=7=Z@0>0=7=Z@005`3AcJT20000000300008`000000000S00@0000000<0000S0000
000002<00P00000200008`8000001@2_/]/00`000000e7i[0=AnJ`030=AnJ`030000000002/0e7iZ
00D0e7iZ00@000000000;d00000000000`3DOFT00`000000000c000000030:ncf`@000001P2_/m/2
000000D0[k?K00@000000:ncf`2_/m/0[k?K0P0000000`2_/m/0000000T0@0050=EkI0030000003E
Nf@0eG]T00<0eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0030000003E
Nf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@01@000000eG]T0=EkI03ENf@0000000@0eG]T
00@0000002D0EP0U05H000000P0U05H0100000009@1F02D0EP00000302D0EP040000000U05H09@1F
000000<09@1F0P0000050:ncg08000001`2_/m`00`000000eWIG0=IfE`030=IfE`050000003FMUL0
eWIG0=IfE`0000000`3FMUL3000000@0[k?K00<000000:ncf`2_/m/00P2_/m/2000000L0[k?K0P00
000303X9IP050000000j2FH0>PUV03X9IP000000100j2FH20=MbC@80000000<0[kCL0000000m36L0
0P0m36L40=IaB`030000000o3VT0?`iY0080?`iY00M000000=I`B03FL4P0eW180000001146/00000
00@0[kCL0`0000030=I_AP050000003FKdH0eVm60=I_AP0000000`3FKdH01@000000eVm60=I_AP3F
KdH000000100dLfY000G0=7=Z@0500008`000000000S0000000002<00P0000001@0002<000000000
8`000000000S008000000P0002<20=AoK@8000000P2_/]/00`000000e7i[0=AnJ`040=AnJ`040000
000002]00000000000<0e7iZ00<000000000;`0000000P2_/m/2000000030=AmJ@000000000000H0
[k?K0P0000050:ncf`D000000P2_/m/00`000000[k?K0:ncf`040:ncf`050000000904002@10@000
000000000`3ENf@00`000000eG]T0=EkI0030=EkI0030000003ENf@0eG]T0080eG]T00<000000=Ek
I03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T00D000000=Ek
I03ENf@0eG]T000000040=EkI0040000000U05H09@1F000000809@1F00@0000002D0EP0U05H00000
0`0U05H0100000009@1F02D0EP00000302D0EP030000002_/m`0[k?L00@0[k?L00@000000:ncg000
00000000102_/m`00`000000:`1J0=IfE`040=IfE`050000003FMUL0eWIG0=IfE`0000000`3FMUL2
000000050=IfE`00000000000:ncf`0000001@2_/m/010000000[k?K0000000000040:ncf`030000
000j2FH0000000<0>PUV00D0000003X9IP0j2FH0>PUV0000000403X9IP@0eg9=00<0000003d<I`0m
36L00P0m36L01D000000eW5;0=IaB`3FLD/0000000<0?`iY00D000000:ndg000000000000=I`B002
000000L0[kCL00<000000=I_AP3FKdH00P3FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600@0
00000=I_AP3FKdH00000403AcJT001L0dLfY00<0000S0000000000000`0002<00`000000000S0000
00020000000500008`000000000000008`000000103DOfd20000000300009d000000e7i[00@0e7i[
0P0000020:ncf`80000000<0e7iZ0000000000001@2_/m/2000000H0[k?K00<000000:ncf`2_/m/0
0P0000020:ncf`060000003EOFP0eGeX0=EmJ000001000000P0000060:ncf`80000000@02@100000
002_/m/0[k?K0P0000000`3ENf@000000=EkI0030=EkI0030000003ENf@0eG]T00<0eG]T00<00000
0=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T00D00000
0=EkI03ENf@0eG]T000000040=EkI0040000000U05H09@1F000000809@1F00D0000002D0EP0U05H0
9@1F0000000202D0EP040000000U05H09@1F000000<09@1F00<0eWQJ000000000000102_/m`01000
0000[k?L0:ncg02_/m`2000000040:ncg0000000:`1J02/0FPD0eWIG00D000000=IfE`3FMUL0eWIG
000000030=IfE`8000000`3FMUL2000000D0[k?K00@000000:ncf`2_/m/0[k?K0P0000001@2_/m/0
000003X9IP0j2FH0000000<0>PUV00D0000003X9IP0j2FH0>PUV0000000403X9IP05@000003GLTd0
eg9=0=MbC@0000000`0m36L010000000[kCL0000000000020=IaB`030000000o3VT0000000@0[kCL
0P0000070:ndg0030000003FKdH0eVm600<0eVm600D000000=I_AP3FKdH0eVm6000000030=I_AP04
0000003FKdH0eVm600000100dLfY000F0=7=Z@090000000002<000000000000002<0000000008`00
0000000S0080000000D0000S0000000002<0000000008`060=AoK@80000000<0[k?K000000000000
0P3DOV/00`000000000[000000040:ncf`8000001P2_/m/010000000[k;J0000000000040:ncf`03
0000002_/m/0[k?K0080[k?K0P0000040=EmJ0040000000503d000000:ncf`800000102_/m/30000
00D0[k?K0P0000040=EkI0030000003ENf@0eG]T00<0eG]T00<000000=EkI03ENf@00P3ENf@00`00
0000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T00D000000=EkI03ENf@0eG]T00000004
0=EkI0040000000U05H09@1F000000809@1F00<0000002D0EP0U05H00P00000202D0EP040000000U
05H09@1F000000<09@1F0`3FN5X2000000030:ncg0000000[k?L00D0[k?L00H0000002/0FP0[05X0
:`1J@000000000030=IfE`050000003FMUL0eWIG0=IfE`000000103FMUL01P000000eWIG0=IfE`3F
MUL000000=IfE`8000000P2_/m/00`000000[k?K0:ncf`040:ncf`050000000j2FH0>PUV03X9IP00
00000`0j2FH00`000000>PUV03X9IP0203X9IP050000000j2FH0>PUV0000002_]=`00P0000020=Mb
C@030000000m36L0000000@0[kCL100000050:ndg0040000002_]=`00000000000@0[kCL00<00000
04<BK0134V`0103FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0eVm6
0000000?0=7=Z@005P3AcJT20000000500008`000000000S0000000002<00P0000000`0002<00000
00008`030000000300008d000000000000<0e7m]00<0000000009`0000000`2_/m/4000000D0[k?K
00@000000:ncf`0000000000102_/m/010000000[k;J0000002_/]X2000000030:ncf`000000[k?K
00@0[k?K00@000000:ncf`00000000000P3EOFP00`0000001@0m000000030:ncf`80000000@0[k?K
00000009040000001P2_/m/00`000000eG]T0=EkI0030=EkI0030000003ENf@0eG]T00<0eG]T00<0
00000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T00D0
00000=EkI03ENf@0eG]T000000040=EkI0040000000U05H09@1F000000809@1F00<0000002D0EP0U
05H00P00000202D0EP040000000U05H09@1F000000<09@1F1@3FN5X00`000000[k?L0:ncg0040:nc
g08000000P0[05X00`000000[kCL0:ndg002000000030=IfE`000000eWIG0080eWIG00<000000=If
E`3FMUL00P3FMUL00`000000eWIG0=IfE`020=IfE`030000003FMUL0eWIG008000001P2_/m/20000
00<0>PUV00D0000003X9IP0j2FH0>PUV0000000403X9IP030000000j2FH0000000@0[kCL10000007
0:ndg08000001@2_]=`010000000[kCL0:ndg02_]=`2000000030:ndg0000000@a9/0080@a9/103F
KdH01@000000eVm60=I_AP3FKdH0000000@0eVm600@000000=I_AP3FKdH000003`3AcJT001H0dLfY
00D0000S0000000002<0000000008`020000000500008`000000000S0000000002<00P0000001000
02<000000:ncf`2_/m/2000000030=AoK@000000000000H0[k?K0P0000050:ncf`040000002_/m/0
[k?K0:ncf`80000000<0[k?K0000003DOV/00P0000030:nbfP8000001@2_/m/010000000[k?K0:nc
f`2_/m/4000000H0[k?K0P00000010090400eGaU0000000000040:ncf`030000003ENf@0eG]T00<0
eG]T00<000000=EkI03ENf@00`3ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080
eG]T00<000000=EkI03ENf@00P3ENf@01@000000eG]T0=EkI03ENf@0000000@0eG]T00@0000002D0
EP0U05H000000P0U05H01@0000009@1F02D0EP3FNUl0000000809@1F00@0000002D0EP0U05H00000
0`0U05H00d000000eWQJ0=IhFP020=IhFP<00000102_/m`20000000302/0FP000000[kCL00@0[kCL
0P0000030=IfE`030000003FMUL0eWIG0080eWIG00<000000=IfE`3FMUL00P3FMUL010000000eWIG
0=IfE`3FMUL3000000@0[k?K0P00000303X9IP030000000j2FH0>PUV0080>PUV00@0000003X9IP0j
2FH0>PUV0P0000070:ndg0030000002_]=`0[kCL00D0[kCL00<000000:ndg00000000P0000020:nd
g0030000002_]=`0[kCL00@0[kCL00<0000004<BK0134V`00P134V`00d00000000000=I_AP020=I_
AP050000003FKdH0eVm60=I_AP0000000`3FKdH010000000eVm60=I_AP00000?0=7=Z@005P3AcJT0
1@0002<0000000008`000000000S0080000000D0000S0000000002<0000000008`03000000D0[k?K
0P0000060:ncf`D000000P2_/m/00`000000[k?K0:ncf`040:ncf`050000003DOV/0e7i[0000003D
OV/00P0000020:nbfP<000000P2_/m/00`000000[k?K0:ncf`040:ncf`8000001@2_/m/010000000
eGaV0000000904030=ElI@80000000<0[k?K0000000=04<01@3ENf@00`000000eG]T0=EkI0020=Ek
I0030000003ENf@0eG]T00<0eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=Ek
I0050000003ENf@0eG]T0=EkI0000000103ENf@0100000009@1F02D0EP00000202D0EP050000000U
05H09@1F02D0EP0000000P0U05H0100000009@1F02D0EP00000202D0EP040000002_]=`000000000
0080eWQJ00<000000=IhFP3FN5X00P0000000`2_/m`0000002/0FP02000000H0[kCL00<000000=If
E`3FMUL00P3FMUL00`000000eWIG0=IfE`020=IfE`030000003FMUL0eWIG0080eWIG00D000000=If
E`3FMUL0eWIG000000020=IfE`80000000<0[k?K0000000j2FH00P00000303X9IP050000000j2FH0
>PUV03X9IP0000000`0j2FH00`000000[kCL0:ndg0050:ndg0040000002_]=`00000000000@0[kCL
0`000003044@J`8000001P2_]=`2000000<0@a9/00<000000:jdg@2^]=d00P0000000`3FKdH00000
0=I_AP020=I_AP050000003FKdH0eVm60=I_AP0000000P3FKdH00`000000dLfY0=7=Z@0=0=7=Z@00
5@3AcJT010000000000S00000000000300008`040000000002<0000000000080000S0P0000060:nc
f`040000002_/m/00000000000@0[k?K00D000000=AoK@3DOfd00000@0000002000000H0[k?K0`00
00000`3DOV/000000=AnJ`020=AnJ`8000000P0103X3000000H0[k?K00<000000:ncf`2_/m/00P00
00020:ncf`03000000090400000000802@101@3EO6D01@0000003@1300d0@d000000000000<0eG]T
00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0030=EkI0040000003ENf@0eG]T0=EkI080
0000103ENf@01@000000eG]T0=EkI03ENf@0000000@0eG]T00@0000002D0EP0U05H000000P0U05H0
1@0000009@1F02D0EP0U05H0000000809@1F00H0000002D0EP0U05H0000002D0EP0000040:ndg0<0
0000103FN5X00`000000:`1J02/0FP02000000D0[kCL00<0000002h0G03FMUL0103FMUL01@000000
eWIG0=IfE`3FMUL0000000@0eWIG00D000000=IfE`3FMUL0eWIG000000040=IfE`030000000j2FH0
>PUV008000000`0j2FH01@000000>PUV03X9IP0j2FH0000000<0>PUV00<0eW=?000000000000102_
]=`00`000000[kCL0:ndg0020:ndg080000000D0[kCL0000003GLTd0eg9=00000003044@J`030000
002_]=`0000000@0[kCL00H0000004<BK0134V`0000004<BK00000050:jdg@8000000`3FKdH01@00
0000eVm60=I_AP3FKdH0000000<0eVm600<000000=7=Z@3AcJT0303AcJT001D0dLfY0P0000001`00
02<0000000008`000000000S0000000002<00P000000100002<0000000008`3DOfh2000000@0[k?K
00@000000:ncf`2_/m/0[k?K0P0000000`2_/m/000000=AoK@030=AoK@80000000<0[k?K00000000
0000102_/m/00`000000[k;K0:nbf`02000000@0e7i[00@000000040>P000000e7iZ100000040:nc
f`030000002_/m/0[k?K0080[k?K0P00000200T0@0040000000904002@10@00000@0eGaU00<00000
00d0@`0000000P2_/m`2000000030=EkI0000000eG]T00<0eG]T00<000000=EkI03ENf@00P3ENf@0
0`000000eG]T0=EkI0020=EkI0800000103ENf@01@000000eG]T0=EkI03ENf@0000000@0eG]T00@0
000002D0EP0U05H000000P0U05H01@0000009@1F02D0EP0U05H0000000809@1F00<0000002D0EP0U
05H00P0000070:ndg0030000003FN5X0eWQJ0080eWQJ00D0000002/0FP0[05X0:`1J0=IgF@020000
0080[kCL00<0000002h0G00^05`01@3FMUL01@000000eWIG0=IfE`3FMUL0000000@0eWIG00@00000
0=IfE`3FMUL0eWIG0P0000030=IfE`030000000j2FH0>PUV008000000`0j2FH01@000000>PUV03X9
IP0j2FH0000000@0>PUV0P3FLdl2000000030:ndg0000000[kCL00H0[kCL0P0000030=MbC@030000
001146/0000000<0[kCL0P0000000`2_]=`0000004<BK00204<BK08000001P2^]=d00`000000eVm6
0=I_AP020=I_AP030000003FKdH0eVm60080eVm600@000000=I_AP3FKdH000003P3AcJT001D0dLfY
0P0000000`0002<0000000008`040000000300008`000000000S008000000`3DOfh2000000030:nc
f`000000[k?K00D0[k?K0P0000030=AoK@030000000002l0000000<0[k?K0P0000000`2_/m/00000
0:nbf`020:nbf`030000003DOV/0e7i[00<0e7i[00<000000040>P3DOVX00`3DOVX4000000030:nc
f`000000[k?K00@0[k?K0P00000200T0@00400000009040000000:ncg08000000P3EO6D00`000000
3@13000000040:ncg0800000103ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080
eG]T0P0000040=EkI0050000003ENf@0eG]T0=EkI0000000103ENf@0100000009@1F02D0EP000003
02D0EP040000000U05H09@1F000000809@1F00@0000002D0EP0U05H000001`2_]=`00`000000eWQJ
0=IhFP030=IhFP040000000[05X0:`1J02/0FP<0eWMI0`00000202h0G003@000003FMUL0eWIG0080
eWIG00D000000=IfE`3FMUL0eWIG000000040=IfE`040000003FMUL0eWIG0=IfE`8000000`3FMUL0
1@000000>PUV03X9IP0j2FH0000000<0>PUV00D0000003X9IP0j2FH0>PUV0000000403X9IP@0eW=?
0P0000050:ndg08000000P2_]=`2000000030=MbC@000000000000H0[kCL00<0000004<BK0134V`0
0P134V`2000000D0[[CM00<0000004DDKP1556h0103FKdH01@000000eVm60=I_AP3FKdH000000080
eVm600<000000=7=Z@3AcJT0303AcJT001D0dLfY00D0000S0000000002<0000000008`0200000006
00008`000000000S0000000002<000001P3DOfh2000000D0[k?K00<000000:ncf`2_/m/00P000000
0`3DOfd00000000000060:ncf`030000002_/]/0[k;K0080[k;K00<000000=AnJ`3DOV/00`3DOV/0
0`0000000@0j0=AnJP040=AnJP80000000<01@0m0000000000001@2_/m/2000000802@1000<00000
00T0@00000000`2_/m`4000000D0[k?L00<000000=EkI03ENf@00`3ENf@00`000000eG]T0=EkI002
0=EkI0030000003ENf@0eG]T0080eG]T00<000000=EkI03ENf@00`3ENf@01@000000eG]T0=EkI03E
Nf@0000000@0eG]T00@0000002D0EP0U05H000000P0U05H2000000809@1F00@0000002D0EP0U05H0
00000`0U05H2000000@0[kCL00<0000002P0F03FN5X0103FN5X01@000000:`1J02/0FP0[05Y00000
00@0eWMI00@0000002h0G0000000[kCL0P0000020=IfE`050000003FMUL0eWIG0=IfE`000000103F
MUL010000000eWIG0=IfE`3FMUL2000000<0eWIG00D0000003X9IP0j2FH0>PUV0000000303X9IP05
0000000j2FH0>PUV03X9IP000000100j2FH01T000000eW=?0=IcC`3FLdl000000=IcC`8000000P2_
]=`00`000000[kCL0:ndg0040:ndg08000001P2_]=`2000000@0@a9/0P3FL4P200000080[[CM00@0
000004DDKP1556h0AAA^103FKdH01@000000eVm60=I_AP3FKdH0000000<0eVm600<000000=7=Z@3A
cJT02`3AcJT001@0dLfY00@0000000008`00000000000P0002<20000000300008`00000000000080
000S00<00000@000003DOfh01@3DOfh400000080[k?K00<000000:ncf`2_/m/00P2_/m/3000000D0
[k?K0`0000020:nbf`030000003DOV/0e7i[00@0e7i[00@000000040>T00000000000`3DOVX00`00
00001@0m000000020:ncf`8000000P2_/m/0100000002@10000000090403000000H0[k?L0P000005
0:ncg0030000003ENf@0eG]T00<0eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI002
0=EkI0030000003ENf@0eG]T00<0eG]T00D000000=EkI03ENf@0eG]T000000040=EkI0040000000U
05H09@1F000000809@1F0P00000202D0EP040000000U05H09@1F000000<09@1F0P3FN5`200000004
0:ndg0000000:01H02P0F0D0eWQJ00D0000002/0FP0[05X000000:ndg00200000080eWMI00<00000
02h0G00000000`2_]=`3000000<0eWIG00<000000=IfE`3FMUL00P3FMUL00`000000eWIG0=IfE`02
0=IfE`050000003FMUL0eWIG0=IfE`0000000`0j2FH01@000000>PUV03X9IP0j2FH0000000@0>PUV
00D0000003X9IP0j2FH000000:jdg@0200000080eW=?00<000000=IcC`3FLdl00P0000070:ndg003
0000002_]=`0000000@0[kCL00@0000004<BK0134V`0000010134V`30=I`B0800000101556h01D00
0000eVm60=I_AP3FKdH0000000<0eVm600D000000=I_AP3FKdH0eVm60000000=0=7=Z@00503AcJT0
2@000000000S000000000000000S0000000002<0000000008`020000000300008`000000000000<0
00000`3DOfh00`000000e7m^0=AoKP020=AoKP8000001P2_/m/00`000000[k?K0000000200000080
[k?K00L000000=AoK@3DOfd00000@00000000010000000@0e7i[00<000000040>P0000000P2_/m/2
000000030=AnJP000000000000D0[k?K0`0000000`090400000000T0@002000000H0[k?L00<00000
0:ncg02_/m`00P0000020:ncg0030000000@04H0eG]T00@0eG]T00<000000=EkI03ENf@00P3ENf@0
0`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T0P0000030=EkI0030000003ENf@0
eG]T0080eG]T00@0000002D0EP0U05H000000P0U05H01@3FNV40000002D0EP0U05H0000000809@1F
00@0000002D0EP0U05H09@1F103FN5`200000080:01H00=000000000003FN5X00P3FN5X00`000000
:`1J000000040:ndg0@000001P2_]=`01@000000eWIG0=IfE`3FMUL0000000D0eWIG00D000000=If
E`3FMUL0eWIG000000030=IfE`0503X9IP000000>PUV03X9IP000000100j2FH01`000000>PUV03X9
IP0j2FH0000003X9IP000000102^]=d3000000<0eW=?0`0000040:ndg0040000002_]=`0[kCL0:nd
g080000000<0[kCL000000134V`00P134V`00`000000@a9/04<BK00204<BK0@0eW1800H0000004DD
KP1556h0AAA^0000002^]Md2000000030=I_AP000000eVm600<0eVm600@000000=I_AP3FKdH00000
3@3AcJT001@0dLfY0P0000001@0002<0000000008`000000000S00@0000000<0000S000000000000
0`2_/m/2000000030=AoKP000000e7m^00<0e7m^00@000000=AoKP00000000000`2_/m/00`000000
[k?K0:ncf`030:ncf`800000103DOfd00`000000000f0000000200000080e7i[00<000000040>P00
0000102_/m/2000000H0[k?K0P00000200T0@004000000090400eGaV0=ElIP800000102_/m`00`00
0000[k?L0:ncg0020:ncg08000000P0@04H00d000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T
0080eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI08000000`3ENf@00`00
0000eG]T0=EkI0020=EkI0040000000U05H09@1F000000<09@1F00@0000002D0EP0U05H000000P0U
05H01@0000009@1F02D0EP0U05I0000000@0eWQL00<0000002P0F00000000P2_]=`2000000030=Ih
FP000000000000L0[kCL00<000000:ndg02_]=`0102_]=`00`000000eWIG0=IfE`030=IfE`030000
003FMUL0eWIG0080eWIG00D000000=IfE`3FMUL0eWIG000000040=IfE`030000000j2FH0>PUV0080
00000`0j2FH010000000>PUV03X9IP0j2FH2000000L0[[CM00D000000=IcC`3FLdl0eW=?00000002
0=IcC`80000000<0[kCL0000002_]=`01@2_]=`00`000000@a9/04<BK00204<BK003000000134V`0
@a9/0080@a9/00=000000000003FL4P00P3FL4P00`000000AAA^000000040:jeg@<000000`3FKdH0
10000000eVm60=I_AP00000=0=7=Z@00503AcJT01@0002<0000000008`000000000S0080000000D0
000S0000000002<0000000008`02000000D0[k?K0P0000040=AoKP040000003DOfh0e7m^0=AoKP80
000000<0[k?K0000002_/m/0102_/m/010000000[k?K0000000000020=AoK@8000000`2_/m/40000
00H0[k?K0`0000040:ncf`8000000P0904000`0000002@100=ElIP030=ElIP80000000<0[k?L0000
002_/m`0102_/m`2000000030100AP000000[kCL008000000P3ENf@00`000000eG]T0=EkI0020=Ek
I0030000003ENf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@2000000<0eG]T00<000000=Ek
I03ENf@00P3ENf@0100000009@1F02D0EP00000302D0EP040000000U05H09@1F000000809@1F00D0
000002D0EP0U05H000000:ndg00200000080eWQL00<0000002P0F0000000102_]=`2000000L0[kCL
00<000000:ndg0000000102_]=`00`000000<01N0=IfE`040=IfE`030000003FMUL0eWIG0080eWIG
00D000000=IfE`3FMUL0eWIG000000040=IfE`030000000j2FH0>PUV008000000`0j2FH01@000000
>PUV03X9IP0j2FH0000000L0[[CM0P0000030=IcC`030000003FLdl0eW=?0080eW=?00<000000:nd
g02_]=`0102_]=`00`000000@a9/0000000304<BK005000000134V`0@a9/04<BK00000000P2^]Md2
000000030=I`B0000000000000L0[[GM00D000000=I_AP3FKdH0eVm6000000030=I_AP030000003A
cJT0dLfY00X0dLfY000D0=7=Z@0500008`00000000000000000002<00P0000001@0002<000000000
00000000000S008000001@2_/m/00`000000e7m^0=AoKP030=AoKP030000003DOfh0e7m^00<0e7m^
0P0000050:ncf`040000002_/m/0[k?K0:ncf`@000001@2_/m/2000000D0[k?K00@000000:ncf`2_
/m/0[k?K0P0000001P2_/m/0000000T0@00000002@10000000802@101@3EO6H3000000D0[k?L0P00
00000`0@04H000000:ndg0020:ndg0<00000103ENf@00`000000eG]T0=EkI0020=EkI0030000003E
Nf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0040000000U
05H09@1F000000<09@1F00@0000002D0EP0U05H000000P0U05H00`0000009@1F000000040:ndg0@0
00001@2_]=`010000000[kCL0000000000040:ndg0040000002_]=`0[kCL0:ndg080000000@0[kCL
0000000`05h0<01N1@3FMUL00`000000eWIG0=IfE`020=IfE`050000003FMUL0eWIG0=IfE`000000
103FMUL00`000000>PUV03X9IP02000000<0>PUV00<0000003X9IP0j2FH00P0j2FH2000000@0[[CM
00<0000003d<I`0m36L00`3FLdl00`000000eW=?0=IcC`020=IcC`<00000102_]=`00`000000@a9/
0000000404<BK003000000134V`0000000D0[[GM0P0000070:jeg@030000003FKdH0eVm60080eVm6
00D000000=I_AP3FKdH0eVm60000000<0=7=Z@004`3AcJT02@000000000S000000000000000S0000
000002<0000000008`0200000080000S0P3CP6l200000080[k?K00<000000=AoKP3DOfh0103DOfh0
0`000000e7m^0=AoKP030=AoKP040000003DOfh0000000000080[k?K00<000000:ncf`2_/m/0102_
/m/2000000@0[k?K1P0000020:ncf`030000002_/m/0[k?K00<0[k?K00H0000000T0@00904000000
00T0@000000200T0@003@00000000000eGaV0080eGaV00<000000=ElIP3EO6H00P0000020:ncg0@0
00001P2_]=`00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T00<000000=EkI03E
Nf@00P3ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T00@0000002D0EP0U
05H000000`0U05H0100000009@1F02D0EP00000202D0EP8000001`2_]=`2000000D0[kCL0P000000
1P2_]=`00000000000000000[kCL000000H0[kCL0P0000020300GP03@00000000000eWIG0080eWIG
00<000000=IfE`3FMUL00P3FMUL01@000000eWIG0=IfE`3FMUL0000000@0eWIG00D0000003X9IP0j
2FH0>PUV0000000303X9IP030000000j2FH0>PUV0080>PUV0P3FLe42000000030:jdg@000000?@aW
0080?@aW0`3FLdl00`000000eW=?0=IcC`020=IcC`030000003FLdl0eW=?0080000000D0[kCL0000
00134V`0@a9/0000000404<BK08000001P2^]Md010000000[[GM0000000000040:jeg@0300000017
5fl0000000@0eVm600@000000=I_AP3FKdH00000303AcJT001<0dLfY0P0000001`0002<000000000
8`000000000S0000000002<00P0000000`0002<000000=>0K`030=>0K`80000000<0000W@000003D
Ofh0103DOfh00`000000e7m^0=AoKP030=AoKP040000003DOfh0e7m^0=AoKP8000001P2_/m/00`00
0000[k?K0:ncf`0200000080[k?K00H000000=AoK@3DOfd00000@000000503d2000000D0[k?K0P00
000200T0@005000000090400000000T0@00000000P2_]=`2000000030=ElIP000000eGaV00<0eGaV
0P0000000`0@04H0eGaU000000060:ndg0030000003ENf@0eG]T00<0eG]T00<000000=EkI03ENf@0
0P3ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T00<000000=EkI03ENf@0
0P3ENf@0100000009@1F02D0EP00000302D0EP040000000U05H09@1F000000809@1F0P0000050:nd
g08000000P2_]=`200000080[kCL00D000000=IhG03FN5a000000000000202h0G08000001@2_]=`3
000000040300GP000000[[CM0:jdg@80000000<0eWIG0000003FMUL00`3FMUL01@000000eWIG0=If
E`3FMUL0000000@0eWIG00D0000003X9IP0j2FH0>PUV0000000303X9IP030000000j2FH0>PUV0080
>PUV103FLe400`000000?@aW03d<I`0203d<I`05@000003FLdl0eW=?0=IcC`0000000`3FLdl00`00
0000eW=?0=IcC`020=IcC`05000000134V`0@a9/04<BK000000010134V`2000000D0[[GM00<00000
0:jeg@2^]Md00P2^]Md2000000030:jeg@000000AaM_0080AaM_103FKdH010000000eVm60=I_AP00
000<0=7=Z@004`3AcJT01@0002<0000000008`000000000S0080000000D0000S0000000000000000
00008`060=>0K`80000000<0[k?L0000000000000P3DOfh00`000000e7m^0=AoKP030=AoKP030000
003DOfh0e7m^0080e7m^100000040:ncf`030000002_/m/0[k?K0080[k?K0P0000040=AoK@040000
000503d000000:ncf`8000000P2_/m/0100000002@100000000904020000000400T0@00000002@10
000000@0[kCL0P0000040=ElIP030000000@04H040160080eGaU0P0000040:ndg0030000003ENf@0
eG]T00<0eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0
eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@0100000009@1F02D0EP00000302D0EP040000000U
05H09@1F000000809@1F0P3FNEh200000080[kCL00<000000:ndg02_]=`0102_]=`2000000@0eWQL
00<0000002h0G00000000P2_]=`200000080[kCL00<000000300GP0`05h00P0000050:jdg@800000
103FMUL01@000000eWIG0=IfE`3FMUL0000000@0eWIG00D0000003X9IP0j2FH0>PUV0000000303X9
IP030000000j2FH0>PUV0080>PUV00E000000=IcD@3FLe40eW=A0000000303d<I`060000002^]Md0
00000000003FLdl000000`3FLdl00`000000eW=?0=IcC`020=IcC`03000000134V`0@a9/0080@a9/
00@0000004<BK0134V`0@a9/0P3FLD/200000080[[GM00<000000:jeg@2^]Md01@2^]Md00`000000
AaM_04LGK`0204LGK`05@000003FKdH0eVm60=I_AP0000000`3FKdH00`000000dLfY0=7=Z@090=7=
Z@004`3AcJT01@0002<0000000008`000000000S0080000000L0000S0000000002<0000000008d00
0000000000<0dh1_00<0000000009`0000000`2_/m`3000000D0e7m^00<000000=AoKP3DOfh00P3D
Ofh200000080e7m^0P0000000`2_/m/000000:ncf`040:ncf`040000002_/m/0000000000080e7m]
00<0000000D0?@0000000`2_/m/30000000300T0@00000002@100080000000<02@10000000000000
1@2_]=`00`000000eGaV0=ElIP030=ElIP030000000@04H0401600@0eGaU0P0000000`2_]=`00000
01@0B@050=EkI0030000003ENf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T
0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T00@0000002D0EP0U05H000000`0U05H010000000
9@1F02D0EP00000202D0EP@0eWUN0P0000070:ndg0040000002_]=`0000000000080eWQL00<00000
02h0G0000000102_]=`2000000<0<01N00<000000:jdg@2^]=d0102^]=d00`000000<`5P0=IfE`03
0=IfE`030000003FMUL0eWIG0080eWIG00D000000=IfE`3FMUL0eWIG0000000303X9IP030000000j
2FH0>PUV0080>PUV00D0000003X9IP0j2FH000000:jeg@0200000080eW=A00<0000003d<I`000000
102^]Md2000000@0eW=?00D000000=IcC`3FLdl0eW=?0000000404<BK003000000134V`0@a9/0080
@a9/0`3FLD/2000000L0[[GM0P00000304LGK`060000002^]Mh000000000003FKdH000000`3FKdH0
0`000000dLfY0=7=Z@090=7=Z@004P3AcJT010000000000S00000000000200008`80000000D0000S
000000000000000S000000020:ncg080000000<0dh1_0000000000001P2_/m`00`000000e7m^0=Ao
KP030=AoKP030000003DOfh0e7m^0080e7m^00<000000=AoKP3DOfh00`3DOfh2000000D0[k?K00@0
00000:ncf`2_/m/0[k?K100000050:ncf`80000000<02@100000000904000P0000000`0904000000
000000050:ndg0030000003EO6H0eGaV00<0eGaV00<000000100AP0@04H01@3EO6D2000000805019
00=000000000003ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T
00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0040000000U05H09@1F000000<0
9@1F00@0000002D0EP0U05H000000P0U05H50=IiGP<00000102_]=`00`000000[kCL0:ndg0020:nd
g0@000001@2_]=`2000000<0<01N00<0eWMI000000000000102^]=d00`000000<`5P0=IfE`030=If
E`030000003FMUL0eWIG0080eWIG00<000000=IfE`3FMUL00P3FMUL00`000000>PUV03X9IP020000
00<0>PUV00<0000003X9IP000000102^]Md4000000D0[[GM0P0000040=IcC`050000003FLdl0eW=?
0=IcC`00000010134V`00`000000@a9/04<BK00204<BK0@0eW5;0`0000040:jeg@06000000175fl0
AaM_000000175fl00000102^]Mh300000080eVm600<000000=7=Z@3AcJT02@3AcJT00180dLfY0P00
00001`0002<0000000008`000000000S0000000002<00`0000050:ncg08000001P2_/m`00`000000
e7m^0=AoKP040=AoKP030000003DOfh0e7m^0080e7m^00<000000=AoKP3DOfh00`3DOfh010000000
e7m^0000000000020:ncf`030000002_/m/0[k?K00@0[k?K0P0000040:ncf`8000000P0904001@00
00002@100000000000002@100080eGeX0P0000020:ndg0030000000=04<0eGaV00@0eGaV00@00000
0100AP0@04I00000103EO6D010000000501901@0B@0000020:ndg080000000<0eG]T0000003ENf@0
0`3ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T00<000000=EkI03ENf@0
0P3ENf@0100000009@1F02D0EP00000302D0EP040000000U05H09@1F000000809@1F00=000000000
003FNEh00P3FNEh00`000000eWUN0=IiGP02000000030:ndg0000000[kCL00H0[kCL00<000000:nd
g02_]=`00`2_]=`00`000000<01N000000030300GP<0eWMI0P000000102^]=d0000003<1H00c0F05
0=IfE`050000003FMUL0eWIG0=IfE`000000103FMUL00`000000>PUV03X9IP02000000<0>PUV0P00
00070:jeg@8000001@2^]Md00`000000?`iY0=IcC`030=IcC`030000003FLdl0eW=?0080eW=?00D0
000004<BK0134V`0@a9/0000000404<BK003@00000000000eW5;0080eW5;00H000000=IaB`000000
00000:jeg@00000304LGK`8000001`2^]Mh010000000eVm60=I_AP00000;0=7=Z@004P3AcJT20000
000700008`000000000S0000000002<0000000008`02000000H0[k?L00@000000:ncg00000000000
102_/m`00`000000e7m^0=AoKP040=AoKP030000003DOfh0e7m^0080e7m^00<000000=AoKP3DOfh0
0`3DOfh010000000e7m^0=AoKP3DOfh3000000D0[k?K00<000000:ncf`2_/m/00P0000020:ncf`80
000000L02@100000000904002@100=AmJ@0000002@1000@0eGeX0P00000200d0@`03@000003EO6H0
eGaV0080eGaV00@000000100AP000000[kCL0P0000020=ElI@030000000D04T0000000D0[kCL0P00
00040=EkI0030000003ENf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=Ek
I0020=EkI0040000000U05H09@1F000000<09@1F00H0000002D0EP0U05H0000002D0EP0000020:jd
g@80000000<0eWUN0000003FNEh00`3FNEh00`000000[kCL0:ndg0050:ndg0040000002_]=`00000
00000080[kCL00<000000300GP0`05h00P0000020300GPD0eWMI00D0000003<1H00c0F00<`5P@000
00040=IfE`050000003FMUL0eWIG0=IfE`000000103FMUL00`000000>PUV03X9IP02000000<0>PUV
00<000000:jeg@2^]Md01@2^]Md00`000000[[GM0:jeg@0200000080[[GM00<0000003l>J@0o3VT0
103FLdl00`000000eW=?0=IcC`020=IcC`05000000134V`0@a9/04<BK00000000`134V`00`000000
[[GN0:jegP02000000030=IaB`000000eW5;0080eW5;00<0000004LGK`175fl00P175fl00`000000
[[GN0:jegP050:jegP030000003FKdH0eVm60080eVm600<000000=7=Z@3AcJT0203AcJT00180dLfY
00D0000S0000000002<0000000008`020000000400008`000000000S0=>0L0800000102_/m`01000
0000[k?L0:ncg02_/m`2000000030:ncg0000000e7m^00H0e7m^00<000000=AoKP3DOfh00P3DOfh0
0`000000e7m^0=AoKP020=AoKP030000003DOfh0e7m^0080e7m^0P0000000`3DOfh0000000000002
0:ncf`030000002_/m/0[k?K00<0[k?K0P00000010090400000000T0@000000200T0@00300000009
04002@1000D0eGeX00@0000000d0@`000000[kCL0P0000020=ElIP030000000@04H0000000<0[kCL
100000060:ndg0030000003ENf@0eG]T00<0eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T
0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T00@0000002D0EP0U05H000000`0U05H01P000000
9@1F02D0EP0000009@1F000000@0[[CM0P0000040=IiGP<00000102_]=`00`000000[kCL0:ndg002
0:ndg08000000`0`05h200000080<01N00=000000=IgF@3FMeT00P3FMeT01@000000<`5P03<1H000
0000[[GM008000000P3FMUL01@000000eWIG0=IfE`3FMUL0000000@0eWIG00D0000003X9IP0j2FH0
>PUV0000000403X9IP800000102^]Md00`000000[[GM0:jeg@030:jeg@8000000`0o3VT01D000000
eW=?0=IcC`3FLdl0000000@0eW=?00<0000004<BK0134V`00P134V`00`000000@a9/000000050:je
gP8000000`3FLD/00`000000AaM_04LGK`0204LGK`030=I`B0000000[[GN00<0[[GN0P0000000`19
6G0000000=I_AP020=I_AP030000003AcJT0dLfY00P0dLfY000A0=7=Z@030000000002<000000080
000000@0000S000000000000000S0P0000030=>0L080000000<0[k?L0000002_/m`01@2_/m`20000
0003@00000000000e7m^00<0e7m^00<000000=AoKP3DOfh00P3DOfh2000000@0e7m^00<000000=Ao
KP3DOfh00P3DOfh00`000000e7m^0=AoKP020=AoKP8000001P2_/m/01P0000002@1000T0@0000000
2@10000000802@1000D0000000T0@00904100000000000030=EmJ0030000000=04<0000000<0[kCL
100000060:ndg08000001P2_]=`00`000000eG]T0=EkI0030=EkI0030000003ENf@0eG]T0080eG]T
00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0040000000U05H09@1F000000<0
9@1F00<0000002D0EP0U05H00P0000050:jdg@030000003FNEh0eWUN00<0eWUN00<000000=IiGP3F
NEh00P0000000`2_]=`000000:ndg0040:ndg08000000`0`05h2000000030300GP000000[[GM0080
00000P3FMeT00`000000<`5P000000040:jeg@<000000`3FMUL00`000000eWIG0=IfE`020=IfE`05
0000000j2FH0>PUV03X9IP000000100j2FH20=IdD`80000000<0[[GM0000002^]Md01@2^]Md01P00
0000?`iY03l>J@0o3VT000000:jegP8000000P3FLdl01@000000eW=?0=IcC`3FLdl0000000@0@a9/
0P0000060:jegP030000003FLD/0eW5;00<0eW5;00<0000004LGK`175fl00P175fl01@3FL4P00000
0000002^]Mh0000000@0BAU`0`3FKdH00`000000dLfY0=7=Z@080=7=Z@004@3AcJT2000000030000
8`000000000S00<0000000<0000S0000003CP7001@3CP702000000D0[k?L0`0000020:ndg0<00000
00<0e7m^0000003DOfh00`3DOfh00`000000e7m^0=AoKP030=AoKP030000003DOfh0e7m^0080e7m^
00<000000=AoKP3DOfh00`3DOfh3000000@0[k?K00H0000000T0@0090400000000T0@000000200T0
@00300000009040000000080[kCL0P0000000`3EOFP00000000000060:ndg08000001@2_]=`00`00
0000[kCL0:ndg00300000080[kCL00<0000001P0C03ENf@0103ENf@00`000000eG]T0=EkI0020=Ek
I0030000003ENf@0eG]T0080eG]T00<000000=EkI03ENf@00P3ENf@0100000009@1F02D0EP000003
02D0EP030000000U05H09@1F008000001@2^]=d00`000000eWUN0=IiGP030=IiGP030000003FNEh0
eWUN0080eWUN0P0000050:ndg0800000100`05h00`000000<01N000000030:jeg@@000001`2^]Md0
1@000000eWIG0=IfE`3FMUL0000000@0eWIG00D0000003X9IP0j2FH0>PUV0000000403X9IP@0eWAC
0P0000050:jeg@050000000o3VT0000003l>J@000000102^]Mh3000000<0eW=?00<0000004<BK013
4V`00P134V`2000000D0[[GN00<0000004DDKP1556h0103FLD/00`000000AaM_04LGK`0204LGK`<0
eW1800<0000004TIL0196G000`196G0014000000eVm60=I_AP00000:0=7=Z@004@3AcJT200000009
00008`000000000S0000000002<0000000008`000010000000H0dh1`100000020:ncg0<000001@2_
]=`2000000@0e7m^00<000000=AoKP3DOfh00`3DOfh00`000000e7m^0=AoKP020=AoKP030000003D
Ofh0e7m^00<0e7m^00<000000=AoKP3DOfh00P000000102_/m/000000000000904020000000400T0
@00000002@1000T0@08000001@2_]=`2000000H0[kCL0P0000000`2_]=`00000000000020:ndg003
0000002_]=`0[kCL00@0[kCL0P00000201P0C003@000003ENf@0eG]T0080eG]T00<000000=EkI03E
Nf@00P3ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T00@0000002D0EP0U
05H000000`0U05H00`0000009@1F02D0EP020=IjG`8000000P2^]=d00`000000:01H0=IiGP040=Ii
GP030000003FNEh0eWUN0080eWUN00@000000=IiGP00000000000P2_]=`00`000000<01N00000004
0300GP8000001P2^]Md00`000000[[GM0:jeg@050:jeg@030000003FMUL0eWIG0080eWIG00<00000
0=IfE`3FMUL00P3FMUL01@000000>PUV03X9IP0j2FH0000000@0>PUV00=000000=IdD`3FM5<00P3F
M5<300000080[[GM00<0000003l>J@0o3VT00P0000070:jegP030000003FLdl0eW=?0080eW=?00@0
000004<BK0134V`0@a9/0P3GLTd200000080[[GN00@0000004DDKP1556h0AAA^103FLD/00`000000
AaM_04LGK`0204LGK`04@000003FL4P0eW18000000@0BAU`00H000000:jegP00000000000=I_AP00
00090=7=Z@004@3AcJT01@0002<0000000008`000000000S0080000000<0000S0000000000000`00
00030=>0L0030000003CP700dh1`0080dh1`0P0000000`0002/000000:ndg0050:ndg0030000003D
Ofh0e7m^00<0e7m^00<000000=AoKP3DOfh00`3DOfh00`000000e7m^0=AoKP020=AoKP030000003D
Ofh0e7m^0080e7m^0P0000040=AoKP04000000090400000000T0@080000000<02@10000000090400
0P0000060:ndg0040000002_]=`00000000000@0[kCL00D000000=EmJ0000010000001@0B@020000
00L0[kCL00D0000001P0C00H04`000000:jdg@0200000080eG]T00<000000=EkI03ENf@00P3ENf@0
0`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T00@0000002D0EP0U05H000000`0U
05H00`0000009@1F02D0EP040=IjG`8000000P0X05P00d000000eWUN0=IiGP020=IiGP030000003F
NEh0eWUN0080eWUN00@000000=IiGP3FNEh0eWUN0P0000020300GP030000000`05h0<01N0080<01N
00<000000:jeg@2^]Md0102^]Md010000000[[GM0000000000040:jeg@030000000f1680eWIG00@0
eWIG00<000000=IfE`3FMUL00P3FMUL01@000000>PUV03X9IP3FMED000000080>PUV00@000000:je
gP00000000000P3FM5<00`000000eWAC0=IdD`02000000<0?`iY00<000000:jegP2^]Mh01@2^]Mh2
000000@0eW=?00<0000004<BK0134V`00P134V`30=MbC@800000101556h01D000000eW5;0=IaB`3F
LD/0000000<0AaM_00D000000:jegP000000eW180000000204TIL0800000102^]Mh2000000T0dLfY
000@0=7=Z@060000000002<0000000008`000000000S0P0000000`0002<00000000000030:ndg080
000000<0dh1`0000003CP7000`3CP70010000000000[0000:`3CP6l2000000@0[kCL00<000000=Ao
KP3DOfh00`3DOfh00`000000e7m^0=AoKP030=AoKP040000003DOfh0e7m^0=AoKP800000103DOfh2
000000@0e7m^00@0000000T0@00000002@100P0000000`090400000000T0@0020=AmJ@800000102_
]=`010000000[kCL0:ndg02_]=`2000000030:ndg0000000eGeX0080eGeX00@0000001@0B@000000
[kCL0P0000040:ndg080000000<0601<0000002^]=d00`2^]=d3000000@0eG]T00<000000=EkI03E
Nf@00P3ENf@00`000000eG]T0=EkI0020=EkI0040000000U05H09@1F000000<09@1F00<0000002D0
EP0U05H01@3FNUl010000000:01H0000002^]Md200000080eWUN00<000000=IiGP3FNEh00P3FNEh0
0`000000eWUN0=IiGP020=IiGP050000000`05h0<01N0300GP0000000`0`05h00`3FN5X000000000
00040:jeg@040000002^]Md0[[GM0:jeg@80000000@0[[GM0000000f1680=PAR1@3FMUL00`000000
eWIG0=IfE`020=IfE`070000000j2FH0>PUV0=IeE@000000>PUV000000040:jegP<000000`3FM5<0
10000000?`iY03l>J@0o3VT3000000@0[[GN00<00000044@J`1146/0103FLdl00`000000@a9/04<B
K00204<BK0@0eg9=00H0000004DDKP1556h0AAA^0000002^]Mh200000080eW5;00<0000004LGK`00
00000`2^]Mh4000000H0[[GN00<000000=7=Z@3AcJT0203AcJT00100dLfY1000000200008`800000
00<0000S0000000000001@2_]=`2000000@0dh1`00<000000000:`3CP6l00`3CP6l2000000030:nd
g0000000e7m^00D0e7m^00<000000=AoKP3DOfh00`3DOfh010000000e7m^0=AoKP3DOfh2000000@0
e7m^0P0000040=AoKP04000000090400000000T0@080000000<02@10000000090400103DOFT20000
00030:ndg0000000[kCL00D0[kCL0P0000030=EmJ0030000000D04T0000000<0[kCL0P0000000`2_
]=`0000001P0C002000000L0[[CM00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=Ek
I0030000003ENf@0eG]T0080eG]T00@0000002D0EP0U05H000000`0U05H01@0000009@1F02D0ET00
0000000000<0eWYO00<0000002P0F00000000`2^]Md3000000D0eWUN00D000000=IiGP3FNEh0eWUN
000000030300GP040000000`05h0<01N0300GP<0eWQJ0P0000000`2^]Md000000:jeg@050:jeg@80
00000P0f16800d00000000000=IfE`020=IfE`030000003FMUL0eWIG0080eWIG00<0000003X9IP0j
2FH00`0000070:jegP050000003FM5<0eWAC0=IdD`000000100o3VT20=IcD@80000000<0[[GN0000
001146/00P1146/40=IcC`03000000134V`0@a9/0080@a9/00=000000000003GLTd00P3GLTd00`00
0000AAA^000000040:jegP@000001P2^]Mh2000000D0[[GN00<000000=7=Z@3AcJT02@3AcJT00100
dLfY0P0000001`0002<0000000008`000000000S0000000002<00P0000050:ndg0030000003CP700
dh1`00<0dh1`00<000000000:`3CP6l01@3CP6l010000000000_@000000000030=AoKP030000003D
Ofh0e7m^00<0e7m^00<000000=AoKP3DOfh00P3DOfh2000000@0e7m^00<000000=AoKP3DOfh00`3D
Ofh2000000802@1000D0000000T0@0090400000000T0@0060=AmJ@8000001@2_]=`00`000000[kCL
0:ndg002000000030=EmJ0000000000000H0[kCL00<0000001P0C00H04`00P0000050:jdg@800000
1@3ENf@00`000000eG]T0=EkI0020=EkI0030000003ENf@0eG]T0080eG]T00@0000002D0EP0U05H0
00000`0U05H00`0000009@1F000000020:jeg@80000000<0eWYO0000000000001P2^]Md00`000000
eWUN0=IiGP030=IiGP050000003FNEh0eWUN0=IiGP0000000`0`05h010000000<01N0300GP0`05h5
0=IhFP030000002^]Md0[[GM00<0[[GM10000000100f168000000:jegP2^]Mh2000000030=IfE`00
0000eWIG00<0eWIG00<0000003X9IP0j2FH00P0000070:jegP030000003FM5<0eWAC0080eWAC00<0
000003l>J@0o3VT00P0o3VT40=IcD@030000001146/0@A1[0080@A1[00E000000=IcC`3FLdl0eW=?
0000000304<BK0030000002^]Mh0[[GN0080000000<0eg9=0000000000001`2^]Mh00`000000[[GN
0:jegP040:jegP030000002^]Mh0[[GN008000000P2^]Mh00`000000dLfY0=7=Z@0:0=7=Z@00403A
cJT20000000300008`000000000S00<0000000<0000S0=>1L@3CPG400P0000020:ndg08000001@3C
P7000`000000000[@00000050=>0K`8000000P2_]=`2000000030=AoKP000000e7m^00@0e7m^00<0
00000=AoKP3DOfh00P3DOfh00`000000e7m^0=AoKP030=AoKP030000003DOfh0e7m^0080e7m^00<0
000000T0@00000000P0904000`0000002@100000000200T0@003@000003DOFT0e7eY00<0e7eY00@0
00000=AmJ@00000000000P2_]=`00`000000[kCL0:ndg0030:ndg0<000001@2_]=`200000080601<
0P3EO6D200000080[[CM00<0000001/0CP0K04h01@3ENf@00`000000eG]T0=EkI0020=EkI0030000
003ENf@0eG]T0080eG]T00@0000002D0EP0U05H000000`0U05H00`0000009@1F000000040:jeg@80
00001P2^]Md00`000000:`1J0=IiGP040=IiGP050000003FNEh0eWUN0=IiGP0000000`0`05h01@00
0000<01N0300GP0`05i0000000@0eWQJ0`0000020:jeg@030000000f1680=PAR0080000000<0=PAR
0000002^]Mh00`2^]Mh2000000@0eWIG00D0000003X9IP0j2FH0>PUV0=IeE@02000000@0[[GN00<0
000003d<I`3FM5<00`3FM5<00`000000?`iY03l>J@0203l>J@05@000003FLe40eW=A0=IcD@000000
0`1146/010000000[[GN0000000000020=IcC`03000000134V`0000000D0[[GN0P0000070:jegP<0
0000102^]Mh00`000000[[GN0:jegP030:jegP8000003@3AcJT000l0dLfY00H0000000008`000000
000S0000000002<20000000300008`000000dh5a00<0dh5a0P0000000`0002L0dh1`0=>0L0040=>0
L080000000<0[kCL0000000000000P3CP6l00`000000000_000000040:ndg08000001@3DOfh00`00
0000e7m^0=AoKP020=AoKP030000003DOfh0e7m^00<0e7m^00<000000=AoKP3DOfh00P3DOfh00`00
00002@100000000200T0@006000000090400000000T0@0000000[[CM0P0000030=AmJ@040000003D
OFT0e7eY0=AmJ@8000001P2_]=`00`000000[kCL0:ndg00200000080[kCL00<0000001P0C0000000
0P0H04`40=ElI@8000000`0K04h50=EkI0030000003ENf@0eG]T0080eG]T00<000000=EkI03ENf@0
0P3ENf@0100000009@1F02D0EP00000302D0EP8000001@2^]Md010000000[[GM0000000000040:je
g@030000000[05X0eWUN00@0eWUN00D000000=IiGP3FNEh0eWUN000000030300GP050000000`05h0
<01N0000002^]Mh00P0000020=IhFP030000003FN5X0eWQJ008000000`0f1683000000D0[[GN00<0
000003P6I03FMUL00`3FMUL010000000>PUV03X9IP0j2FH30=IeE@80000000@0[[GN0000000m36L0
?@aW1@3FM5<01@000000?`iY03l>J@000000[[GN008000000P3FLe400`000000@A1[000000040:je
gP@000001P2^]Mh00`000000[[GN000000040:jegP<000000P196G02000000030:jegP000000[[GN
00D0[[GN00<000000=7=Z@3AcJT0303AcJT000l0dLfY00@0000000008`00000000000P0002<20000
000300008`3CPG40dh5a00@0dh5a00@0000000009d00000000000`3CP7000`000000000[00000003
0:ndg0@000001@2_]=`2000000D0e7m^00<000000=AoKP3DOfh00P3DOfh00`000000e7m^0=AoKP03
0=AoKP030000003DOfh0e7m^0080e7m^00<0000000T0@00000000P0904001@0000002@1000000009
0400000000<0[[CM0P0000000`3DOFT000000=AmJ@030=AmJ@<00000102_]=`00`000000[kCL0:nd
g0020:ndg0<0000000@0601<0000000H04`0601<1@3EO6D01P0000006`1>01/0CP0K04i000000000
00<0eG]T00<000000=EkI03ENf@00P3ENf@00`000000eG]T0=EkI0020=EkI0040000000U05H09@1F
000000<09@1F0P0000050:jeg@040000002^]Md0[[GM0:jeg@80000000@0[[GM0000000[05X0:`1J
1@3FNEh01@000000eWUN0=IiGP3FNEh0000000<0<01N00<000000300GP000000102^]Mh3000000<0
eWQJ00<0000003H4HP0f16800P0f16800`000000[[GN0:jegP030:jegP030000000h1V@0>0IT00@0
eWIG00@0000003X9IP0j2FH0>PUV103FMED2000000<0?@aW00=000000000003FM5<00P3FM5<00`00
0000?`iY000000040:jegP@000001`2^]Mh2000000D0[[GN00@000000:jegP2^]Mh0[[GN0P000000
1@2^]Mh000000=MbC@3GLTd0000000@0BAU`0P0000050:jegP030000003AcJT0dLfY00d0dLfY000?
0=7=Z@80000000T0000S0000000002<0000000008`000000000S@000000000000`3CPG400`000000
000W000000020:ndg080000000<0dh1`0000000000001P2_]=`2000000D0[kCL00<000000=AoKP3D
Ofh0103DOfh00`000000e7m^0=AoKP020=AoKP030000003DOfh0e7m^0080e7m^0P0000040=AoKP03
000000090400000000802@1000@0000000T0@000000000001P2^]=d2000000@0e7eY00<000000=Am
J@3DOFT00P0000000`2_]=`000000:ndg0040:ndg0<0000000H0601<0000000H04`0601<@0000000
00030=ElI@040000000K04h0000000000080[[GM0P0000000`3ENf@000000=EkI0030=EkI0030000
003ENf@0eG]T0080eG]T00@0000002D0EP0U05H000000`0U05H20=IjH@8000000P2^]Md00`000000
[[GM0:jeg@040:jeg@050000000[05X0:`1J02/0FT000000103FNEh01@000000eWUN0=IiGP3FNEh0
000000<0<01N0P0000070:jegP050000003FN5X0eWQJ0=IhFP000000100f16800`3FMeT000000000
00020:jegP040000000h1V@0>0IT03P6I0@0eWIG00D0000003X9IP0j2FH0>PUV@00000040=IeE@04
0000000m36L0?@aW00000080[[GN0P0000000`3FM5<00000000000070:jegP030000002^]Mh0[[GN
00D0[[GN00<000000:jeg@2^]Md00P0000020:jegP030000002^]Mh0[[GN00@0[[GN00D000000=Mb
C@3GLTd0eg9=0000000304TIL0030000002^]Mh0[[GN008000000P2^]Mh00`000000dLfY0=7=Z@0>
0=7=Z@003`3AcJT20000000500008`000000000S0000000002<00P0000020:ndg080000000<0dh5a
0000000000001@2_]=`3000000D0[kCL00<000000:ndg02_]=`00P0000020:ndg0030000000003<0
e7m^00D0e7m^00@000000=AoKP3DOfh0e7m^0P0000040=AoKP800000103DOfh0100000002@100000
000904020000000300T0@0000000[[CM00H0[[CM00<000000=AmJ@3DOFT00P3DOFT00`000000e7eY
0=AmJ@030=AmJ@8000001@2_]=`01`000000eGeX0000000H04`0000001P0C00000000P2^]Md20000
00030=ElI@000000000000H0[[GM0P0000040=EkI0030000003ENf@0eG]T0080eG]T00@0000002D0
EP0U05H000000`0U05H40=IjH@8000001P2^]Md200000080:`1J00@000000:jegP00000000000P3F
NEh01@000000eWUN0=IiGP3FNEh0000000<0<01N00<000000:jegP2^]Mh01@2^]Mh00`000000eWQJ
0=IhFP020=IhFP030000000f1680=PAR0080=PAR0`3FMeT3000000<0>0IT00=000000=IfE`3FMUL0
0P3FMUL010000000>PUV0000002^]Mh200000080eWEE00<0000003d<I`0000001@2^]Mh2000000L0
[[GN00@000000:jegP0000000000102^]Mh01P000000[[GM0:jeg@2^]Md0000004LGK`8000001P2^
]Mh010000000[[GN0000000000020=MbC@03000000196G00000000D0[[GN0P00000A0=7=Z@003`3A
cJT01@0002<0000000008`000000000S0080000000<0000S0000002_]=`00`2_]=`2000000H0[kCL
1@0000020:ndg0030000002_]=`0[kCL00<0[kCL0`0000000`0003=000000=AoKP030=AoKP030000
003DOfh0e7m^0080e7m^0P0000040=AoKP030000003DOfh0e7m^00<0e7m^00@0000000T0@0000000
2@100P00000010090400e7iZ0000000000040:jdg@030000003DOFT0e7eY00<0e7eY00<000000=Am
J@3DOFT00`3DOFT010000000e7eY0000000000020:ndg0030000000H04`000000080601<00<00000
01P0C0000000102^]Md2000000L0[[GM00<000000=EkI03ENf@00`3ENf@00`000000eG]T0=EkI002
0=EkI0040000000U05H09@1F000000<09@1F1@3FNV43000000@0[[GM0P0000000`0[05X000000:je
gP030:jegP<00000103FNEh010000000<01N0300GP0`05h2000000@0[[GN00<0000003<1H03FN5X0
103FN5X010000000=PAR03H4HP0f16850=IgF@050000000h1V@0>0IT0000002^]Mh00P0000020=If
E`030000000j2FH0000000<0[[GN100000060:jegP040000002^]Mh00000000000@0[[GN00<00000
0:jegP2^]Mh00P2^]Mh2000000030:jegP00000000000080[[GM00@0000004LGK`175fl0eW=A0P00
00040:jegP030000002^]Mh0[[GN0080[[GN100000060:jegP030000003AcJT0dLfY0100dLfY000>
0=7=Z@060000000002<0000000008`000000000S0`0000050:ndg0040000002_]=`00000000000@0
[kCL00D000000=>1L@3CPG400000@0000002000000L0[kCL00@000000000<`000000[[CM0P000002
0=AoKP030000003DOfh0e7m^0080e7m^00<000000=AoKP3DOfh00`3DOfh00`000000e7m^0=AoKP03
0=AoKP04000000090400000000T0@080000000@02@100=AnJP3DOVX0e7iZ0P0000000`2^]=d00000
00d0@`050=AmJ@030000003DOFT0e7eY00<0e7eY00@000000=AmJ@3DOFT0e7eY0P00000201P0C003
0000000H04`0601<008000001@2^]Md010000000[[GM0000000000040:jeg@030000000N0540eG]T
00@0eG]T00<000000=EkI03ENf@00P3ENf@0100000009@1F02D0EP00000302D0EP03@00000000000
eWYQ0080eWYQ00<000000=IjH@3FNV400P0000000`2^]Md0000002/0FP02000000L0[[GN00<00000
0=IiGP3FNEh00P3FNEh010000000<01N0300GP0`05h20=IhG080000000@0[[GN0000000c0F00<`5P
1@3FN5X01P000000=PAR03H4HP0f16900000000000<0eWMI00<0000003P6I0000000102^]Mh40000
00H0[[GN0P0000050:jegP80000000<0[[GN0000001146/00P0000000`2^]Mh000000:jegP060:je
gP050000003FM5<0eWAC0000040000000`175fl00`3FLe40000000000002000000030:jegP000000
[[GN00H0[[GN0P0000050:jegP030000003AcJT0dLfY0140dLfY000>0=7=Z@80000000<0000S0000
000002<0100000050:ndg0040000002_]=`0[kCL0:ndg080000000<0[kCL0000003CPG40103CPG44
000000@0[kCL0P0000000`0003<000000:jdg@020:jdg@<00000103DOfh00`000000e7m^0=AoKP03
0=AoKP030000003DOfh0e7m^00<0e7m^00L0000000T0@00000002@100=AnJ`0000002@1000D0e7iZ
00D0000000d0@`0=04=00000000000030=AmJ@030000003DOFT0e7eY00<0e7eY00<000000=AmJ@3D
OFT00P3DOFT010000000601<01P0C000000201P0C08000001@2^]Md010000000[[GM0:jeg@2^]Md2
000000040:jeg@0000007P1A01h0D@D0eG]T00<000000=EkI03ENf@00P3ENf@01@0000009@1F02D0
EP0000009@1F008000000P2^]Mh2000000030=IjH@000000eWYQ00<0eWYQ00<0000002/0FP0[05X0
0P0000050:jegP8000001@3FNEh010000000<01N0300GP0`05h40=IhG08000000P0c0F000d000000
eWQJ0=IhFP020=IhFP040000000f1680=PAR00000080[[GN0P0000000`3FMeT00000000000070:je
gP030000002^]Mh0[[GN00@0[[GN00<000000:jegP2^]Mh00P0000020:jegP040000003FMED0eWEE
000000@0@A1[0P0000050:jegP<00000103FM5<01@000000AaM_04LGK`3FLe40000000<0[[GN0P00
00050:jegP8000000P2^]Mh200000080[[GN00<000000=7=Z@3AcJT04P3AcJT000h0dLfY0P000000
1@0002<0000000008`000000000S0080dh5b0P0000020:ndg0030000002_]=`0[kCL00@0[kCL0P00
00040=>1L@8000000`2_]=`200000080[kCL0`0000060:jdg@030000003DOfh0e7m^0080e7m^00<0
00000=AoKP3DOfh00`3DOfh00`000000e7m^0=AoKP020=AoKP03000000090400000000802@1000@0
000000T0@00904100000103DOVX00`0000003@13000000020:jeg@80000000<0e7eY0000003DOFT0
103DOFT00`000000e7eY0=AmJ@020=AmJ@040000000H04`0601<00000080601<0P3EO6H200000080
[[GM00<000000:jeg@2^]Md0102^]Md01@0000007P1A01h0D@0N0550000000@0eG]T00<000000=Ek
I03ENf@00P3ENf@00`0000009@1F02D0EP02000000H0[[GN0P0000040=IjH@030000000[05X0:`1J
0080eWYO0P0000020:jegP030000000^05`0;P1L00D0eWUN00D000000300GP0`05h0<01N@0000004
0=IhG0040000000c0F0000000:jegP8000000P3FN5X00`000000=PAR000000050:jegP8000001`2^
]Mh010000000eWQL0000000000040:jegP030000002^]Mh0[[GN0080[[GN0P0000040=IeE@040000
001146/0@A1[00000080[[GN0P0000020:jegP040000002^]Mh0[[GN000000@0eWAC00<0000004LG
K`175fl00P3FLe4200000080[[GN0`0000020:jegP030000002^]Mh0[[GN00@0[[GN0P00000E0=7=
Z@003P3AcJT20000000300008`000000000S00800000103CPG83000000D0[kCL00<000000:ndg02_
]=`00`0000000`3CPG400000000000050:ndg080000000<0000c0000002^]=d01@2^]=d00`000000
e7m^0=AoKP030=AoKP030000003DOfh0e7m^00<0e7m^00<000000=AoKP3DOfh00P3DOfh00`000000
2@100000000200T0@00400000009040000000:jeg@8000000P3DOVX00`0000003@13000000040:je
g@800000103DOFT00`000000e7eY0=AmJ@030=AmJ@040000000H04`0601<00000080601<103EO6H2
000000H0[[GM0P00000201h0D@040000002^]Mh0000000000080eG]T00<000000=EkI03ENf@00P3E
Nf@0100000009@1F02D0EP0000070:jegP030000003FNV40eWYQ00<0eWYQ00<0000002/0FP0[05X0
103FNUl2000000<0;P1L1@3FNEh01@000000<01N0300GP000000[[GN008000000P3FN5`00`000000
<`5P000000030:jegP@000001P2^]Mh010000000[[GN0000000000040:jegP050000002_]=`00000
@000002_]=`00P0000000`2^]Mh000000:jegP040:jegP040000002^]Mh0000000000080eWEE00<0
0000044@J`0000001@2^]Mh200000080[[GN0P0000040=IdD`04000000175fl0AaM_04LGK`<0eW=A
0P00000304TIL08000001`2^]Mh00`000000dLfY0=7=Z@0D0=7=Z@003@3AcJT01`000000000S0000
000002<0000000008`0000001`3CPG8400000080[kCL00<000000:ndg02_]=`00`2_]=`3000000D0
[kCL00@000000000<`000000dh1_0P0000040:jdg@030000003DOfh0e7m^00<0e7m^00<000000=Ao
KP3DOfh00`3DOfh00`000000e7m^0=AoKP020=AoKP03000000090400000000802@1000<0000000T0
@00000000`2^]Md4000000D0[[GM00<000000=AmJ@3DOFT00`3DOFT00`000000e7eY0=AmJ@030=Am
J@040000000H04`0601<00000080601<1@3EO6H3000000@0[[GM0P0000000`0N054000000:jegP03
0:jegP<00000103ENf@0100000009@1F02D0EP3ENf82000000@0[[GN00<0000002P0F03FNV40103F
NV400`000000:`1J02/0FP050=IjG`060000000^05`0;P1L02h0G400000000000`3FNEh00`000000
<01N000000040:jegP@000001P2^]Mh2000000D0[[GN00<000000:jegP2^]Mh00P2^]Mh200000006
0:jegP000000[kCL0:ndg0000000[kCL0P0000000`2_]=`000000:jegP040:jegP030000002^]Mh0
[[GN0080[[GN100000060:jegP040000002^]Mh0[[GN00000080AAA^103FM5<010000000AaM_04LG
K`175fl40=IcD@06000000196G00BAU`04TIL0000000[[GN0P0000040:jegP030000003AcJT0dLfY
01D0dLfY000=0=7=Z@80000000L0000S0000000002<0000S000004000000000000@0dh5b00<00000
0=>1LP3CPG800P3CPG82000000H0[kCL00<000000:ndg02_]=`00P0000020:ndg080000000<0000c
0=>0K`3CP6l00P3CP6l2000000030:jdg@000000e7m^00@0e7m^00<000000=AoKP3DOfh00`3DOfh0
0`000000e7m^0=AoKP030=AoKP03000000090400000000802@100P0000060:jeg@8000001@2^]Md0
0`000000e7eY0=AmJ@030=AmJ@030000003DOFT0e7eY00<0e7eY00@0000001P0C000000000000P0H
04`00d00000000000=ElIP020=ElIP030000003EO6H0eGaV0080000000<0[[GM0000000N05400P00
00070:jegP030000003ENf@0eG]T0080eG]T00<0000002D0EP0U05H00`3ENf82000000040:jegP00
0000:01H02P0F0D0eWYQ00@0000002/0FP0[05Y00000103FNUl010000000;P1L02h0G00000020:je
gP80000000<0eWUN0000000000001`2^]Mh2000000D0[[GN0P0000000`2^]Mh00000000000020:je
gP030000002^]Mh0[[GN00D0[[GN00@000000:ndg02_]=`00000102_]=`400000080[[GN00<00000
0:jegP2^]Mh01@2^]Mh2000000D0[[GN0P0000000`2^]Mh0000004DDKP0204DDKP@0eWAC00H00000
04LGK`175fl0AaM_@000000000030=IcD@03000000196G00000000@0[[GN0P0000000`2^]Mh00000
0=7=Z@0G0=7=Z@003@3AcJT20000000300008`000000000S008000000P2^]=d3000000030=>1LP00
0000dh5b00<0dh5b00@000000=>1LP0000000000102_]=`00`000000[kCL0:ndg0020:ndg0800000
00<0000c0000000003<01P3CP6l010000000000f@000000000030=AoKP030000003DOfh0e7m^00<0
e7m^00<000000=AoKP3DOfh00`3DOfh0100000002@10000000090403000000D0[[GM00<000000:je
g@2^]Md00P0000020:jeg@030000000@04H0e7eY00@0e7eY00<000000=AmJ@3DOFT00`3DOFT01P00
0000601<000000000000601<00000080[[GN0P0000000`3EO6H000000=ElIP030=ElIP040000000N
05407P1A000000L0[[GN00<000000=EkI03ENf@00`3ENf@00`0000009@1F02D0EP050=EkHP050000
000X05P0:01H02P0F4000000103FNV4010000000:`1J0000002^]Mh200000080eWYO00<0000002h0
G00000001@2^]Mh2000000L0[[GN00<000000:jegP2^]Mh00P0000020:jegP060000003FN5`0eWQL
@00000000000>0IT0P0000070:jegP040000002_]=`0[kCL000000L0[kCL00@0000004<BK0000000
00001`2^]Mh00`000000[[GN0:jegP0200000080[[GN00@000000=IeE@3FMED00000101556h00d00
000000000=IdD`020=IdD`03000000175fl000000080[[GN0P0000000`3FLe400000000000070:je
gP030000003AcJT0dLfY01L0dLfY000=0=7=Z@80000000<0000S0000000002<00P0000050:jdg@80
0000103CPG8010000000dh5b0=>1LP3CPG82000000030:ndg0000000[kCL00@0[kCL100000000`00
03=000000=>0K`030=>0K`030000000003H000000080[[GM0P0000000`3DOfh000000=AoKP040=Ao
KP030000003DOfh0e7m^00<0e7m^00@0000000T0@00000002@100`3DOV/200000080[[GM00<00000
0:jeg@2^]Md00`2^]Md200000080401600=000000=AmJ@3DOFT00P3DOFT00`000000e7eY0=AmJ@03
0=AmJ@060000000H04`000000000000H04`00000102^]Mh2000000@0eGaV00@0000001h0D@0N0540
eGaU0P0000040:jegP030000000R05<0eG]T00@0eG]T00<0000002D0EP0U05H01@3ENf801@000000
:01H02P0F0000000[[GN008000000P3FNV400`000000:`1J000000030:jegP@000001P2^]Mh01000
0000[[GM0000000000040:jegP030000002^]Mh0[[GN00<0[[GN0P0000040=IhG0040000000h1V@0
00000:jegP800000102^]Mh00`000000eWUN00000002000000D0[kCL0P00000404<BK0800000102^
]Mh00`000000[[GN0:jegP030:jegP8000000`3FMED01@000000AAA^04DDKP1556h000000080[[GN
0P0000000`3FM5<00000000000050:jegP8000001`2^]Mh00`000000dLfY0=7=Z@0H0=7=Z@00303A
cJT01`000000000S0000000002<0000000008`0000001P2^]=d00`000000dh5b0=>1LP030=>1LP03
0000003CPG80dh5b00<0dh5b0P0000050:ndg0D0000000<0[[GM0000000000000P3CP6l00`000000
000f000000040:jeg@8000001@3DOfh00`000000e7m^0=AoKP030=AoKP04000000090400000000T0
@0D0e7i[0P0000060:jeg@80000000<040160000002^]Mh00P0000020=AmJ@030000003DOFT0e7eY
00<0e7eY00<0000001P0C03EOFP00P0000050:jegP030000003EO6H0eGaV00<0eGaV00<0000001h0
D@0N05400`3EO6D2000000040:jegP0000008P1C0280D`D0eG]T00D0000002D0EP0U05I000000000
00030=EkHP030000000X05P0000000@0[[GN100000060:jegP8000001@2^]Mh00`000000[[GM0:je
g@020:jeg@80000000<0[[GN0000002^]Mh01@2^]Mh010000000[[GN0000000000020=IhG0030000
000h1V@0000000<0[[GN0P0000000`2^]Mh000000=IiGP030=IiGP<000000P2_]=`010000000@a9/
04<BK000000304<BK006000000134V`000000000002^]Mh000001P2^]Mh010000000[[GN00000000
00020=IeE@030000001556h0000000D0[[GN0P0000060:jegP040000002^]Mh00000000000@0[[GN
00<000000=7=Z@3AcJT06@3AcJT000`0dLfY1@000000100002<0dh5c0000000000040:jdg@030000
003CPG80dh5b00<0dh5b00<000000=>1LP3CPG800`3CPG8010000000dh5b0000000000020:ndg006
0000000003<000000000000003<000000`2^]Md4000000H0[[GM00<000000=AoKP3DOfh00`3DOfh0
0`000000e7m^0=AoKP030=AoKP04000000090400000000T0@0H0e7i[0`0000040:jeg@80000000<0
40160000002^]Mh00P2^]Mh3000000D0e7eY00<0000001P0C03EOFP00P0000050:jegP030000003E
O6H0eGaV00<0eGaV00<0000001h0D@0N05401@3EO6D01P0000008P1C0280D`0R05=00000000000<0
eG]T00<0000002D0EP0000000P2^]Mh2000000030=EkHP000000000000L0[[GN0P0000050:jegP03
0000002^]Mh0[[GN008000000P2^]Mh400000080[[GM00@0000003H4HP00000000001@2^]Mh00`00
0000[[GN0:jegP020:jegP@000001P2^]Mh00`000000eWUN000000030=IiGP030000003FNEh0eWUN
008000000`134V`010000000@a9/04<BK0134V`200000080[[GM0P0000050:jegP030000002^]Mh0
[[GN0080[[GN100000060:jegP030000002^]Mh0000000@0[[GN00<000000:jegP2^]Mh00P2^]Mh2
000000030:jegP000000dLfY01/0dLfY000<0=7=Z@80000000@0000S0000000002<000000`3CPG<2
000000030:jdg@000000dh5b00D0dh5b00<000000=>1LP3CPG800`3CPG8010000000dh5b0=>1LP3C
PG82000000030000<`0000000000008000001P2^]Md2000000D0[[GM00<000000=AoKP3DOfh0103D
Ofh00`000000e7m^0=AoKP020=AoKP03000000090400000000802@1000=000000000003DOV/00`3D
OV/00`000000e7i[0=AnJ`02000000030:jeg@0000004016008000001P2^]Mh00`000000e7eY0=Am
J@020=AmJ@030000000H04`0601<00<0eGeX0P0000020:jegP030000000K04h0eGaV00@0eGaV00@0
000001h0D@0N05500000103EO6D0100000008P1C0280D`0000020:jegP80000000<0eG]T00000000
00001@2^]Mh2000000L0[[GN0P0000000`2^]Mh00000000000020:jegP030000002^]Mh0[[GN00<0
[[GN0P000000103FNV4000000=IjH@3FNV42000000<0=PAR0`0000020:jegP030000002^]Mh0[[GN
00D0[[GN0P0000050:jegP040000003FNEh0eWUN000000<0eWUN00D000000=IiGP3FNEh0eWUN0000
000304<BK005000000134V`0@a9/04<BK00000001@2^]Md200000080[[GN00<000000:jegP2^]Mh0
1@2^]Mh2000000D0[[GN0P0000001P2^]Mh00000000000000000[[GN000000L0[[GN00<000000=7=
Z@3AcJT06`3AcJT000`0dLfY0P0000000`0002<0000000008`060=>1L`040000000002M000000000
00<0dh5b00<000000=>1LP3CPG80103CPG800`000000dh5b0=>1LP020=>1LP040000000003<00000
0000<`8000001@2^]Md00`000000[[GM0:jeg@0300000080[[GM00<000000=AoKP3DOfh0103DOfh0
0`000000e7m^0=AoKP020=AoKP05000000090400000000T0@00000000P2^]Mh3000000030=AnJ`00
0000e7i[00<0e7i[00@000000100AP0@04H000001P2^]Mh00`000000e7eY0=AmJ@030=AmJ@030000
000H04`0601<00D0eGeX0P00000201/0CPD0eGaV00@0000001h0D@000000[[GN0P0000020=ElI@03
0000000R05<0000000D0[[GN0P0000060:jegP040000002^]Mh00000000000@0[[GN00@000000=Ek
HP3ENf9000000P0^05`2000000H0[[GN0P0000000`3FNV4000000=IjH@020=IjH@040000000f1680
=PAR03H4HP80000000<0[[GN0000000000001`2^]Mh00`000000[[GN0:jegP0200000080[[GN0P00
00020=IiGP050000003FNEh0eWUN0=IiGP0000000`3FNEh01@000000@a9/04<BK0134V`0000000@0
@a9/0P0000040:jeg@<000001`2^]Mh00`000000[[GN0:jegP0200000080[[GN00@000000=IeE@00
000000000`196G02000000D0[[GN0P00000N0=7=Z@002`3AcJT01`000000000S0000000002<00000
00008d0000001@3CPG<200000080[[GM0P0000000`3CPG8000000=>1LP040=>1LP030000003CPG80
dh5b00<0dh5b00@000000000<`000000000c0P3CP70200000080[[GM00<000000:jeg@2^]Md0102^
]Md2000000030040>T000000e7m^00<0e7m^00<000000=AoKP3DOfh00`3DOfh01@0000002@100000
00090400000000D0[[GN0P0000040=AnJ`040000000@04H040160=AnJP800000102^]Mh00`000000
e7eY0=AmJ@030=AmJ@030000000H04`0601<00H0eGeX00D0000001/0CP0K04i00000000000030=El
IP030000000N0540000000<0[[GN100000060:jegP040000003DOfd00000000000@0[[GN00@00000
0:jegP2^]Mh0[[GN0P0000000`2^]Mh000000=EkHP020=EkHP050000000^05`0;P1L0000002^]Mh0
0P0000040:jegP040000002^]Mh00000000000@0eWYQ00<0000003H4HP0f16800P3FNUl200000003
0:jegP000000000000@0[[GN00<000000:jegP2^]Mh00`2^]Mh200000080[[GM0`0000030=IiGP05
0000003FNEh0eWUN0=IiGP0000000`134V`00`000000@a9/04<BK00204<BK080eWQJ0P0000000`2^
]Md000000:jeg@020:jeg@800000102^]Mh00`000000[[GN0:jegP030:jegP8000000P3FMED01@00
0000BAU`04TIL0196G0000000080[[GN0P0000020:jegP030000003AcJT0dLfY01h0dLfY000;0=7=
Z@040000000002<0000000008`80000000<0[[GM0000000000000P3CPG<00`000000000W00000004
0:jeg@8000001@3CPG800`000000dh5b0=>1LP020=>1LP040000000003<0000c000000D0dh1`0P00
00070:jeg@040000000103X000000:jegP8000000P3DOfh00`000000e7m^0=AoKP030=AoKP040000
000904000000000000H0[[GN00<000000=AnJ`3DOV/00`3DOV/00`00000040160100AP030=AnJP80
000000<0[[GN0000000D04T01@3DOFT01@000000601<01P0C4000000000000@0eGeX00<0000001/0
CP0000000P2^]Mh2000000030=ElIP000000000000H0[[GN0P0000050:jegP040000003DOfd0e7m]
0=AoK@<0000000<0[[GN0000002^]Mh01@2^]Mh2000000<0eG]R00<0000002h0G0000000102^]Mh2
000000050:jegP000000[[GN0:jegP0000001@3FNV400`000000=PAR03H4HP040=IjG`80000000D0
>0IT000000000000[[GN000000060:jegP030000002^]Md0[[GM00<0[[GM00D000000=IiGP3FNEh0
eWUN000000030=IiGP05000000134V`0@a9/04<BK000000010134V`40=IhFP8000001@2^]Md20000
00030:jegP000000[[GN00D0[[GN00<000000:jegP0000000P3FMED00`000000BAU`000000050:je
gP8000008@3AcJT000/0dLfY0P000000100002<0000000008`0000030:jeg@@000001@2^]Md00`00
0000dh5b0=>1LP040=>1LP030000003CPG80dh5b0080dh5b00@000000000<`0003<000001P3CP703
000000D0[[GM00<000000040>P0000000`2^]Mh3000000D0e7m^00@0000000T0@000000000001P2^
]Mh00`000000e7i[0=AnJ`020=AnJ`040000000@04H040160100APD0e7iZ00@0000001@0B@0D04U0
0000103DOFT00`000000601<000000020:jegP<0000000<0eGeX0000000000001@2^]Mh3000000D0
[[GN00<000000:jegP2^]Mh00P0000020:jegP8000000`3DOfd00`000000<`5P00000002000000D0
[[GN00<000000:jegP2^]Mh00P0000000`3ENf800000000000070:jegP050000002^]Mh0[[GN0000
000c0F001@3FNV400`000000=PAR03H4HP050=IjG`040000000h1V@0>0IT03P6I08000001@2^]Mh0
0`000000[[GM0:jeg@020:jeg@800000103FNEh01@000000eWUN0=IiGP3FNEh0000000<0@a9/00<0
000004<BK0134V`00P134V`00d000000eWQJ0=IhFP020=IhFP<000000P2^]Md00`000000AaM_04LG
K`02000000D0[[GN00@000000:jegP2^]Mh0[[GN100000060:jegP030000003AcJT0dLfY0200dLfY
000;0=7=Z@80000000<0000S0000000000001P2^]Md2000000D0[[GM00<000000=>1LP3CPG80103C
PG800`000000dh5b0=>1LP020=>1LP060000000003<000000000040000000000103CP7000`000000
dh1`0=>0L00200000080[[GM0`0000060:jegP030000003DOfh0e7m^00<0e7m^00@0000000T0@03D
Ofd0e7m]0`0000020:jegP030000003DOV/0e7i[00<0e7i[00D000000100AP0@04H04016@0000004
0=AnJP040000000D04T000000:jegP8000000P3DOFT00`000000601<000000050:jegP8000001P2^
]Mh500000080[[GN00<000000:jegP2^]Mh00`2^]Mh200000080[k?K0P0000000`3DOfd000000000
00030:ncf`8000000P2^]Mh00`000000[[GN0:jegP030:jegP8000001`2^]Mh2000000040:jegP00
0000<`5P03<1H0D0eWYQ00D0000003H4HP0f16900000000000030=IjG`040000000h1V@000000000
0080[[GN0P0000020:jegP<000000P2^]Md00`000000?`iY03l>J@040=IiGP030000003FNEh0eWUN
0080eWUN00D0000004<BK0134V`0@a9/0000000204<BK0040000002^]Mh0000000000080eWQJ00<0
00000=IhFP3FN5X00P00000304LGK`040000002^]Mh0000000000080[[GN00<000000:jegP2^]Mh0
102^]Mh2000000D0[[GN00<000000=7=Z@3AcJT08@3AcJT000/0dLfY0P0000000`0002<000000000
00050:jeg@030000002^]Md0[[GM008000000P2^]Md2000000H0dh5b00<000000=>1LP3CPG800P3C
PG800`000000000c00000002000000060:jegP00000000000000003CP7000000103CP70200000003
0040>P000000[[GN00D0[[GN0P0000050=AoKP03000000090400e7m]00@0e7m]0P0000000`0=04<0
e7i[0=AnJ`030=AnJ`050000000@04H040160000002^]Mh00P0000020=AnJP030000000D04T00000
00<0[[GN100000060:jegP040000002^]Mh00000000000@0[[GN00D000000=EmJ03EOFQ000000280
D`02000000H0[[GN00<000000:ncf`2_/m/00`2_/m/00`00001000000:ncf`040:ncf`<000001P2^
]Mh010000000[[GN0000000000040:jegP040000003ENf80eG]R@00000<0<`5P00=000000=IjH@3F
NV400P3FNV400`000000=PAR000000020:jegP80000000<0eWYO0000000000001P2^]Mh2000000<0
[[GM00<00000@000000000000P0o3VT50=IiGP050000003FNEh0eWUN0=IiGP0000000`134V`00`00
0000@a9/000000040:jegP<000000`3FN5X01@000000AaM_04LGK`175fl0eWMI0080000000@0[[GN
00000000000000001@2^]Mh00`000000[[GN0:jegP0200000080[[GN00<000000=7=Z@3AcJT08P3A
cJT000X0dLfY00@0000000008`000000000S0P3CPW@200000080[[GM00<000000:jeg@2^]Md00`2^
]Md2000000030000:`3CPG80dh5b00D0dh5b00<000000=>1LP3CPG800P3CPG8010000000000c0000
000000050:jegP800000103CP700100000000@0j0000003CP6l2000000@0[[GN00<000000=AoKP3D
Ofh0103DOfh00`0000002@100=AoK@040=AoK@050000000=04<03@13@000000000000`3DOV/00`00
00004016000000040:jegP@000001P2^]Mh2000000D0[[GN00<000000:jegP2^]Mh00P2^]Mh20000
00030:jegP000000eGeX0080eGeX00@000000280D`000000[[GN0P0000040:jegP030000002_/m/0
[k?K00<0[k?K00@000000:ncf`00000000000P2_/m/010000000e7m]0=AoK@3DOfd2000000@0[[GN
00@000000:jegP2^]Mh0[[GN0P0000000`2^]Mh000000=EkHP020=EkHP050000000c0F00<`5P0000
002^]Mh00P0000020=IjH@030000000f1680000000@0[[GN0P0000070:jegP030000002^]Md0[[GM
0080[[GM00<000000=IjG`0000000P0o3VT00d00000000000=IiGP020=IiGP050000003FNEh0eWUN
0=IiGP0000000`134V`2000000L0[[GN00D000000=IhFP3FN5X0eWQJ0000000304LGK`030000003F
MeT0eWMI0080000000@0[[GN00000000000000000P2^]Mh00`000000[[GN0:jegP030:jegP800000
9@3AcJT000X0dLfY0P0000000`0002<000000=>2M0030=>2M08000001`2^]Md010000000000[@000
000000040=>1LP030000003CPG80dh5b0080dh5b00<000000000<`0003<00P0000050:jegP030000
003CP700dh1`00<0dh1`00<000000040>P3CP6l00`3CP6l2000000030:jegP0000001@0m00D0e7m^
00D0000000T0@00904100000000000030=AoK@030000000=04<000000080[[GN0P0000000`3DOV/0
0000000000070:jegP8000001@2^]Mh500000080[[GN00<000000:jegP2^]Mh01@2^]Mh2000000<0
eGeX00<000000280D`0000000`2^]Mh2000000030:jegP000000e7m^008000000P2_/m/00`000000
[k?K0:ncf`020:ncf`<000000`3DOfd01P000000>0IT000000000000[[GN000000H0[[GN0P000003
0=EkHP030000000c0F00000000@0[[GN100000050:jegP040000002^]Mh00000000000@0[[GN00<0
00000:jeg@2^]Md00`2^]Md01@000000eWYO0000000o3VT000000080[[GN0P0000000`3FNEh00000
0=IiGP020=IiGP04000000134V`0@a9/04<BK08000001@2^]Mh2000000@0eWQJ00<0000004LGK`17
5fl00P175fl40=IgF@04000000196G00BAU`04TIL08000001P2^]Mh00`000000dLfY0=7=Z@0T0=7=
Z@002P3AcJT20000000300008`3CPW@0dh9d00@0dh9d0`0000040:jeg@030000000002/000000080
[[GN0`0000000`3CPG8000000=>1LP030=>1LP030000000003<0000c008000001@2^]Mh00`000000
dh1`0=>0L0030=>0L0030000000103X0dh1_00D0dh1_0P0000000`0503e000000=AoKP030=AoKP03
00000009040000000080[[GN0P0000000`3DOfd00000000000050:jegP<000001P2^]Mh00`000000
[[GN0:jegP0200000080[[GN0P0000020=AnJ`D000001@2^]Mh200000080[[GN0P0000000`3EOFP0
0000000000060:jegP8000000`3DOfh2000000D0[k?K00<000000:ncf`2_/m/00P0000000`3DOfd0
0000000000020:ncf`8000001@2^]Mh00`000000[[GN0:jegP02000000030=EkHP000000000000L0
[[GN0P0000050:jegP040000002^]Mh0[[GN0:jegP80000000<0[[GN0000003FNV400P0000020:je
g@030000000o3VT00000008000001@2^]Mh2000000<0eWUN00<0000004<BK0134V`00P134V`00`3F
N5`00000000000020:jegP030000001556h0AAA^00@0eWQJ00<0000004LGK`175fl00P175fl40=Ig
F@07000000196G00BAU`04TIL0000000[[GN000000040:jegP030000003AcJT0dLfY02D0dLfY000:
0=7=Z@80000000<0000S@000000000000`3CPW@010000000dh9d0=>2M03CPW@200000080[[GM0P00
00060:jegP800000103CPG800`000000000c0000<`020=>1L@8000000P2^]Mh00`000000dh1`0=>0
L0040=>0L0030000000103Y0000000D0dh1_00@0000000D0?@000000[[GN0P0000020=AoKP030000
00090400000000@0[[GN0P0000060:jegP030000003DOfd0000000<000000P2^]Mh00`000000[[GN
0:jegP030:jegP80000000<0e7i[0000003DOV/00`3DOV/20000000301h0D@00000000000080[[GN
00<000000:jegP2^]Mh0102^]Mh2000000H0[[GN00<000000=AoKP000000103DOfh300000080[k?K
00<000000:ncf`2_/m/00`2_/m/2000000D0[k?K0P0000020:jegP030000002^]Mh0[[GN00<0[[GN
0`0000050:jegP<0000000<0[[GN0000000000000P2^]Mh00`000000[[GN0:jegP040:jegP800000
0`3FNV4010000010000003l>J@0o3VT2000000H0[[GN00<000000=IiGP3FNEh00P3FNEh00`000000
@a9/04<BK00204<BK0<0eWQL0P00000304DDKPD0eWQJ00H0000004LGK`175fl0AaM_@00000000003
0=IgF@03000000196G00000000<0[[GN0P0000000`2^]Mh000000=7=Z@0W0=7=Z@002@3AcJT01000
0000000S0000000000020:jegP80000000<0dh9d0000003CPW@0103CPW@4000000H0[[GN00<00000
0=>1LP3CPG800`3CPG800`000000000c0=>1L@040=>1L@80000000<0000f0=>0L03CP7000`3CP700
100000000@0j0000002^]Mh2000000<0dh1_00<0000000D0?@0000000`2^]Mh4000000D0[[GN00@0
00000:jegP0000000000102^]Mh01P000000e7m]0=AoK@3DOfe0000001@0B@8000001P2^]Mh20000
00030=AnJ`000000e7i[00<0e7i[00<0000001h0D@0N0540100000070:jegP040000002^]Mh00000
000000@0[[GN00<000000=AoKP000000103DOfh00`000000e7m^0=AoKP02000000H0[k?K00@00000
0:ncf`00000000000P2_/m/00`000000>PUV00000002000000H0[[GN00<000000:jegP2^]Mh00P00
00020:jegP050000003ENf80eG]R0=EkHT0000000P0h1V@3000000D0[[GN0`0000030=IjH@030000
000o3VT0?`iY0080?`iY00<0eWYO0000002^]Mh00`2^]Mh00`000000@A1[0=IiGP030=IiGP030000
00134V`0@a9/0080@a9/103FN5`01P000000AAA^04DDKP1556i00000000000<0eWQJ00@0000004LG
K`00000000000P2^]Mh2000000030=IgF@000000000000H0[[GN00<000000=7=Z@3AcJT09`3AcJT0
00T0dLfY0P0000000`0002<000000:jegP030:jegP8000001@3CPW@010000000000[0000:`3CPG<3
00000080[[GN00<000000=>1LP3CPG80103CPG800`000000000c0=>1L@050=>1L@040000000003I0
0000000000<0dh1`00<000000040>P0000000`2^]Mh2000000030=>0K`000000000000H0[[GN0P00
00050:jegP040000002^]Mh0[[GN0:jegP80000000<0[[GN0000003DOfd00`3DOfd0100000005019
0000002^]Mh2000000@0[[GN00@000000:jegP0000000000103DOV/00`0000007P1A01h0D@020=An
JP@000001@2^]Mh010000000[[GN0:jegP2^]Mh2000000050:jegP000000e7m^0=AoKP000000103D
Ofh010000000e7m^0=AoKP3DOfh3000000@0[k?K00@000000:ncf`2_/m/0[k?K0P00000203X9IP03
0000000j2FH0>PUV00800000102^]Mh00`000000[[GN0:jegP020:jegP800000103ENf8010000000
>0IT03P6I00000020:jegP8000000P2^]Mh010000000[[GN0:jegP0000030=IjH@030000000o3VT0
?`iY0080?`iY0P3FNUl2000000040:jegP000000@A1[044@J`@0eWUN00<0000004<BK0134V`00P13
4V`00d000000eWQL0=IhG0020=IhG0030000001556h000000080[[GN0P0000000`3FN5X000000000
00060:jegP8000001@2^]Mh2000002X0dLfY00090=7=Z@<000001P2^]Mh00`000000dh9d0=>2M003
0=>2M0030000000002/0000000@0dh5c0P0000000`0002l0dh5b0=>1LP040=>1LP040000000003=0
0000000000<0dh5a00<000000000=P0000000P2^]Mh2000000030=>0L0000000000000H0[[GN0`00
00050:jegP030000002_]=`00000008000000P2^]Mh00`000000[[GN0:jegP040:jegP800000103D
Ofd00`0000005019000000030:jegP80000000D0[[GN0000002^]Mh0[[GN000000050=AnJ`030000
000N05407P1A00D0e7iZ0`0000020:jegP030000002^]Mh0[[GN00@0[[GN00D000000=AoKP3DOfh0
e7m^000000040=AoKP050000003DOfh0e7m^0=AoKP0000000P3DOfh2000000030:ncf`000000[k?K
00<0[k?K0P00000203X9IP050000000j2FH0>PUV0000000j2FH00P0000000`2^]Mh000000:jegP04
0:jegP040000002^]Mh0000000000080eG]R00<0000003P6I00000001@2^]Mh200000080[[GN00<0
000003d<I`3FNV400`3FNV4010000000?`iY03l>J@0o3VT40=IjG`8000000P1146/00d000000eWUN
0=IiGP020=IiGP05000000134V`0@a9/0000002^]Mh00P0000020=IhG0030000001556h0000000@0
[[GN0P0000070:jegP040000002^]Mh0000000000080[[GN00<000000=7=Z@3AcJT0:P3AcJT000T0
dLfY0`0000050:jegP030000003CPW@0dh9d00@0dh9d00<000000000:`3CPG<01@3CPG<010000000
000_@000000000030=>1LP030000000003<000000080[[GN0P0000000`3CPG400000000000050:je
gP<000001P2^]Mh00`000000[[GN0:jegP0200000080[[GN100000020:ndg0<000001@2^]Mh00`00
0000[[GN0:jegP03000000030=AoK@000000000000H0[[GN00D000000:jegP2^]Mh0[[GN00000005
0=AnJ`030000000N05407P1A00D0e7iZ00<000000280D`0R05<00`0000050:jegP030000003DOfh0
e7m^0080e7m^00<000000=AoKP3DOfh00P3DOfh01@000000e7m^0=AoKP3DOfh0000000@0e7m^00<0
00000:ncf`2_/m/00`2_/m/200000080>PUV00@0000003X9IP0j2FH000000`0j2FH2000000D0[[GN
00@000000:jegP2^]Mh0[[GN100000060:jegP040000002^]Mh0[[GN00000080?@aW103FNV401000
0000?`iY03l>J@0o3VT50=IjG`040000001146/000000:jegP8000000P3FNEh00`000000@a9/0000
00040:jegP@000001@2^]Mh010000000[[GN0000000000040:jegP030000002^]Mh0[[GN0080[[GN
0P00000]0=7=Z@00203AcJT010000000000S0=:2M@3BPWD300000080[[GN00<000000=>2M03CPW@0
103CPW@00`000000000[@00000050=>1L`8000000P2^]Mh2000000030=>1LP000000000000D0[[GN
0P0000070:jegPD000000P2^]Mh00`000000[[GN0:jegP030:jegP8000000`3CPG8300000080[kCL
0`0000020:jegP030000002^]Mh0[[GN00@0[[GN0`0000050:jegP<0000000<0[[GN0000000K04h0
1@3DOV/01@0000007P1A01h0DD000000000000<0e7iZ00@000000280D`00000000000P2^]Mh20000
0080[[GN0P0000040=AoKP030000003DOfh0e7m^0080e7m^00D000000=AoKP3DOfh0e7m^00000004
0=AoKP<000000P2_/m/00`000000>PUV0000000203X9IP030000000j2FH0>PUV008000000P0j2FH0
10000000>PUV0000000000020:jegP030000002^]Mh0[[GN00@0[[GN0P0000050:jegP040000003E
Nf800000@00000<0?@aW103FNV401P000000?`iY03l>J@0o3VU00000000000<0eWYO00<00000044@
J`0000000`2^]Mh4000000L0[[GN00<000000:jegP2^]Mh00`2^]Mh300000080BAU`0P0000000`2^
]Mh000000:jegP040:jegP030000003AcJT0dLfY02`0dLfY00080=7=Z@8000001@3BPWD2000000L0
dh9d0P0000000`2^]Mh00000000000020=>1L`030000000002l0000000@0[[GN0P0000060:jegP04
0000002^]Mh00000000000@0[[GN00D000000=>1L@3CPG40dh5a@0000003000000H0[[GN00<00000
0=>1LP3CPG800P3CPG800`000000dh5b0=>1LP0300000080[kCL0P0000070:jegP030000002^]Mh0
[[GN008000000P2^]Mh01@000000e7m]0=AoK@3DOfe0000000806`1>00=000000=AnJ`3DOV/00P3D
OV/00`0000007P1A000000020:jegP80000000<0e7iZ0000000000001P2^]Mh4000000@0e7m^00<0
00000=AoKP3DOfh00P3DOfh01@000000e7m^0=AoKP3DOfh0000000@0e7m^00<000000=AoKP3DOfh0
0P00000203X9IP040000000j2FH0>PUV00000080>PUV0P00000203X9IP030000000j2FH0000000@0
00001@2^]Mh00`000000[[GN0:jegP0200000080[[GN00D000000=EkHP3ENf80eG]R0000000303d<
I`06@000003FNV40eWYQ0=IjH@000000?`iY0P0000020:jegP80000000<0eWYO0000000000001P2^
]Mh2000000D0[[GN0P0000000`2^]Mh00000000000020:jegP050000003FN5`0eWQL0=IhG0000000
0`196G02000000D0[[GN00<000000=7=Z@3AcJT0;03AcJT000P0dLfY00<000000=:2M@3BPWD01@3B
PWD00`0000100000000000040=>2M0030000000002/0000000<0[[GN100000050:jegP@00000102^
]Mh010000000[[GN0:jegP2^]Mh200000080[[GN00P000000=>1L@3CPG40dh5a0000000503d00000
0:jegP800000102^]Mh00`000000dh5b0=>1LP020=>1LP060000003CPG80dh5b0=>1LP000000dh5b
0P0000020:ndg08000001@2^]Mh00`000000[[GN0:jegP020:jegP800000103DOfd0100000006`1>
0000002^]Mh200000080e7i[00<0000001h0D@000000102^]Mh2000000L0[[GN00@000000:ndg02_
]=`00000103DOfh00`000000e7m^0=AoKP020=AoKP050000003DOfh0e7m^0=AoKP000000103DOfh0
1@000000e7m^0=AoKP3DOfh000000080>PUV00<0000003X9IP0j2FH00P0000000`0j2FH000000000
000203X9IP8000001@2_]=`200000080[[GN00<000000:jegP2^]Mh00`2^]Mh3000000<0eG]R00D0
000003d<I`00000000000:jegP02000000030=IjH@000000000000H0[[GN0`0000050:jegP030000
002^]Md0[[GM008000000P2^]Mh00`000000[[GN0:jegP030:jegP<000000`3FN5`010000000BAU`
0000000000020:jegP8000000P2^]Mh00`000000dLfY0=7=Z@0]0=7=Z@00203AcJT00`0000100000
000000040=:2M@8000000P2^]Mh3000000030=>2M0000000000000H0[[GN0P0000050:jegP030000
003CPWA0000000<0000000<0[[GN0000002^]Mh01@2^]Mh3000000<0dh5a00<0000000D0?@000000
0`2^]Mh2000000030:jegP000000dh5b00<0dh5b00<000000=>1LP3CPG800P3CPG8010000000dh5b
0=>1LP3CPG830000000301P0C000000000000080[[GN00<000000:jegP2^]Mh00`2^]Mh010000000
[[GN0000000000020=AoK@030000000K04h0000000<0[[GN100000050:jegP040000002^]Mh00000
000000@0[[GN00@000000:ndg02_]=`000001@3DOfh00`000000e7m^0=AoKP020=AoKP050000003D
Ofh0e7m^0=AoKP000000103DOfh01@000000e7m^0=AoKP3DOfh000000080>PUV00<0000003X9IP0j
2FH00P00000203X9IP030000000j2FH0>PUV008000001@2_]=`010000000[kCL0000000000060:je
gP030000002^]Mh0[[GN0080000000<0eG]R0000000000001@2^]Mh2000000L0[[GN00<000000:je
gP2^]Mh00P0000020:jegP8000000P2^]Md010000000AaM_0000000000060:jegP030000002^]Mh0
[[GN0080000000<0eWQL0000000000001P2^]Mh200000300dLfY00070=7=Z@8000000P2^]Mh30000
00030=:2M@000000000000D0[[GN0`0000050:jegP030000002^]Mh0[[GN008000000P2^]Mh01000
0000dh9d0=>2M03CPW@5000000H0[[GN00<000000:jegP2^]Mh00P0000000`3CPG40000000000006
0:jegP030000003CPG80dh5b00<0dh5b00<000000=>1LP3CPG800P3CPG800`000000dh5b0=>1LP03
0=>1LP040000000H04`0000001P0C0<000001@2^]Mh010000000[[GN0:jegP2^]Mh4000000H0[[GN
0P0000050:jegP040000002^]Mh0[[GN0:jegP80000000H0[[GN0000002_]=`0[kCL0000000^05`5
0=AoKP030000003DOfh0e7m^0080e7m^00D000000=AoKP3DOfh0e7m^000000040=AoKP050000003D
Ofh0e7m^0=AoKP0000000P0j2FH00`000000>PUV03X9IP0200000080>PUV00<0000003X9IP0j2FH0
0P3DOFT200000080[kCL00<000000:ndg02_]=`00P2_]=`2000000@0[[GN00<000000:jegP2^]Mh0
0P2^]Mh2000000H0[[GN00@000000:jegP0000000000102^]Mh00`000000[[GN0:jegP030:jegP80
00000P3FNV42000000<0AaM_0`0000040:jegP030000002^]Mh0[[GN0080[[GN0P0000070:jegP03
0000003AcJT0dLfY02l0dLfY00070=7=Z@8000001@2^]Mh3000000D0[[GN00<000000=:2M@000000
0P0000020:jegP030000002^]Mh0[[GN00<0[[GN0P0000030=>2M0040000003CPW@0dh9d0=>2M0D0
00000P2^]Mh00`000000[[GN0:jegP030:jegP<000001@2^]Mh00`0000100000000000040=>1LP03
0000003CPG80dh5b0080dh5b00<000000=>1LP3CPG800`3CPG8010000000601<0000000H04`20000
00030:jeg@00000000000080[[GN00<000000:jegP2^]Mh0102^]Mh2000000D0[[GN00<000000=Ao
K@0000000P0000020:jegP030000002^]Mh0[[GN00@0[[GN00@000000=>0K`00001000000P0^05`0
0d000000e7m^0=AoKP020=AoKP030000003DOfh0e7m^0080e7m^00D000000=AoKP3DOfh0e7m^0000
00040=AoKP050000003DOfh0e7m^0=AoKP0000000P0j2FH01@000000>PUV03X9IP0j2FH000000080
>PUV00<0000003X9IP0j2FH0103DOFT2000000H0[kCL0`0000000`2^]Mh000000:jegP040:jegP04
0000002^]Mh00000000000@0[[GN0P0000001T0000000000000000000000[[GN000000H0[[GN0P00
00030=IjH@04000000175fl0AaM_04LGK`80000000D0[[GN000000000000[[GN000000050:jegP04
0000002^]Mh00000000000@0[[GN00<000000=7=Z@3AcJT0<03AcJT000L0dLfY00<000000:jegP2^
]Mh0102^]Mh00`000000[[GN0:jegP0200000080[[GN00<000000=:2M@3BPWD00P3BPWD00d000000
0000000000070:jegP<0000000<0dh9d0000003CPW@00`3CPW@00`0000000@0j0040>P03000000H0
[[GN00<000000:jegP2^]Mh00P0000020:jegP8000000P2^]Md3000000030=>1LP000000dh5b00<0
dh5b00<000000=>1LP3CPG800P3CPG801@000000601<01P0C0000000601<0080dh1`0P000000102^
]Md000000000000000050:jegP030000002^]Mh0[[GN008000000P2^]Mh01P000000e7m]0=AoK@3D
Ofd000000280D`<000001@2^]Mh020000000dh1_0=>0K`3CP6l0000002h0G0000000[kCL0P000002
0=AoKP030000003DOfh0e7m^0080e7m^00D000000=AoKP3DOfh0e7m^000000040=AoKP050000003D
Ofh0e7m^0=AoKP0000000P0j2FH01@000000>PUV03X9IP0j2FH000000080>PUV00<0000003X9IP0j
2FH01@3DOFT3000000@0[kCL00<000000:ndg02_]=`00P0000050:jegP040000002^]Mh0[[GN0:je
gP80000000<0[[GN0000003ENf800P3ENf800`000000@A1[044@J`02000000D0[[GN0`0000030=Ij
H@03000000175fl0AaM_0080AaM_00D0eWYO000000000000[[GN000000050:jegP030000002^]Mh0
[[GN0080[[GN0P0000000`2^]Mh000000=7=Z@0b0=7=Z@00203AcJT2000000@0[[GN00<000000:je
gP2^]Mh00P2^]Mh2000000D0dX9e0P0000000`2^]Mh00000000000040:jegP040000002^]Mh0[[GN
0:jegP800000103CPW@00`0000000@0j000000020=>1L`<00000102^]Mh00`000000[[GN0:jegP02
0:jegP@000001@2^]Md2000000@0dh5b00<000000=>1LP3CPG800P3CPG800`000000601<00000002
01P0C0@0dh1`0`0000000`2^]Md00000000000020:jegP030000002^]Mh0[[GN00<0[[GN0`000003
0=AoK@030000000R05<000000080[[GN0P0000020:jegP8000000`3CP6l00`000000;P1L00000003
0:ndg0<00000103DOfh01@000000e7m^0=AoKP3DOfh0000000@0e7m^00D000000=AoKP3DOfh0e7m^
0000000203X9IP050000000j2FH0>PUV03X9IP0000000P0j2FH01@000000>PUV03X9IT0000000000
00<0e7eY00<000000=AmJ@3DOFT00P0000000`2_]=`000000:ndg0030:ndg0<000000P2^]Mh00`00
0000[[GN0:jegP040:jegP8000000`3ENf800`000000@A1[000000020:jegP8000000P2^]Mh01000
0000[[GN0000001556h30=IjH@03000000175fl0AaM_0080AaM_0`3FNUl400000080[[GN00<00000
0:jegP2^]Mh01@2^]Mh00`000000dLfY0=7=Z@0b0=7=Z@002P3AcJT2000000030:jegP000000[[GN
00@0[[GN00@000000:jegP00000000000P3BPWD00`000000000_000000030:jegP8000000P2^]Mh0
1@000000[[GN0:jegP2^]Mh0000000D0dh9d00<000000040>P3CPG<0103CPG<3000000030:jegP00
0000[[GN00@0[[GN100000050:jeg@030000003CPG80dh5b00<0dh5b00<000000=>1LP3CPG800P3C
PG800`000000601<0000000201P0C0D0dh1`00D000000=>0L000000000000:jeg@02000000H0[[GN
00<000000:jegP2^]Mh00P0000000`3DOfd00000000000050:jegP8000000P2_]=`2000000030=>0
K`000000000000H0[kCL00<000000=AoKP3DOfh00P3DOfh01@000000e7m^0=AoKP3DOfh0000000@0
e7m^00D000000=AoKP3DOfh0e7m^0000000203X9IP050000000j2FH0>PUV03X9IP0000000P0j2FH0
0`000000>PUV000000020:jdg@80000000<0e7eY0000003DOFT00`3DOFT00`000000[kCL0:ndg003
0:ndg0030000002_]=`0[kCL008000001@2^]Mh200000080[[GN0P0000000`3ENf80000000000005
0:jegP8000000P2^]Mh00`000000AAA^0=IjH@020=IjH@03000000175fl0AaM_0080AaM_1@3FNUl0
0`000000BAU`00000002000000D0[[GN0P00000e0=7=Z@00303AcJT2000000D0[[GN00@000000:je
gP2^]Mh0[[GN100000060:jegP<000000P2^]Mh00`000000dh9d0=>2M0040=>2M0030000000103X0
dh5c00@0dh5c00<0000000D0?@0503d00P0000050:jegP8000000P2^]Md200000080[[GM00<00000
0=>1LP3CPG800`3CPG800`000000dh5b0=>1LP030=>1LP030000000H04`000000080601<00=00000
0000003CP7000P3CP70010000000dh1`0=>0L03CP705000000@0[[GN00<000000:jegP2^]Mh00P2^
]Mh2000000H0[[GN00<000000:ndg02_]=`00`2_]=`3000000D0[kCL00<000000=AoKP3DOfh00`3D
Ofh01@000000e7m^0=AoKP3DOfh0000000@0e7m^00D000000=AoKP3DOfh0e7m^0000000203X9IP80
00000P0j2FH01P000000>PUV03X9IP000000>PUV000000@0[[CM0P0000040=AmJ@<000000P2_]=`0
0`000000[kCL0:ndg0030:ndg08000000P2^]Mh00`000000[[GN0:jegP040:jegP8000001@2^]Mh3
000000040:jegP000000AAA^04DDKP<0eWYQ00<0000004LGK`175fl00P175fl00d00000000000=Ij
G`020=IjG`03000000196G0000000080[[GN0P0000020:jegP030000003AcJT0dLfY03D0dLfY000>
0=7=Z@8000000P2^]Mh00`000000[[GN0:jegP040:jegP8000001P2^]Mh01P000000dX9e0=:2M@00
001000000000=PH0dh9d00@000000040>T00000000000`3CPG<00`0000001@0m000000020:jegP80
00000P2^]Mh00`000000[[GM000000040:jeg@80000000<040160=>1LP3CPG800`3CPG800`000000
dh5b0=>1LP030=>1LP050000000H04`0000001P0C00000000P2^]Mh2000000030=>0L0000000dh1`
00@0dh1`00<0000001h0D@0000000P0000000`2^]Mh000000:jegP040:jegP040000002^]Mh00000
000000@0[[GN00<000000:ndg02_]=`00`2_]=`00`000000[kCL0:ndg00200000080[kCL00<00000
0300GP3DOfh0103DOfh01@000000e7m^0=AoKP3DOfh0000000@0e7m^00D000000=AoKP3DOfh0e7m^
0000000203X9IP8000000P0j2FH00`000000>PUV03X9IP02000000D0[[CM00<000000=AmJ@3DOFT0
0`3DOFT00`000000e7eY0=AmJ@03000000D0[kCL100000070:jegP040000002^]Mh0000000000080
[[GN00D000000=EkHP3ENf80eG]R@000000304DDKP05@000003FNV40eWYQ0=IjH@0000000P175fl0
0`000000[[GN0:jegP02000000030=IjG`000000000000D0[[GN0P00000h0=7=Z@00403AcJT30000
00D0[[GN00<000000:jegP2^]Mh00`0000020:jegP030000003BPWD0dX9e0080dX9e00@000000000
=T00000000000`3CPW@00`0000000@0j000000020:jegP80000000<0dh5c0000000000001@2^]Mh2
000000030:jeg@000000[[GM00@0[[GM0P0000000`0@04I00000000000030=>1LP030000003CPG80
dh5b00<0dh5b00@0000001P0C000000000001@2^]Mh2000000D0dh1`00@0000001h0D@3CP6l0dh1_
0`0000050:jegP040000002^]Mh0[[GN0:jegP80000000<0[[GN0000000000000P0000020:ndg003
0000002_]=`0[kCL00<0[kCL0P0000020300GPD0e7m^00D000000=AoKP3DOfh0e7m^000000040=Ao
KP050000003DOfh0e7m^0=AoKP0000000P0j2FH200000080>PUV00<0000003X9IP0j2FH00P000005
0:jdg@030000003DOFT0e7eY00<0e7eY00H000000=AmJ@3DOFT0e7eY0000003DOFT200000080[kCL
00<0000004<BK00000000P134V`2000000@0[[GN00<000000:jegP2^]Mh00P2^]Mh2000000@0eG]R
00H0000004DDKP1556h000000:jegP0000020=IjH@03000000175fl0000000D0[[GN0P0000060:je
gP030000003AcJT0dLfY03L0dLfY000C0=7=Z@<000000P2^]Mh00`000000[[GN0:jegP030:jegP<0
00000`3BPWD00`000000000f000000020:jegP80000000<0dh9d0000000000001@2^]Mh3000000D0
[[GN00@000000=>2M000000000001@2^]Md00`0000004016000000020:jegP80000000<0dh5b0000
003CPG80103CPG800`000000601<000000060:jegP030000003CP700dh1`00<0dh1`00<0000001h0
D@0N0540103CP6l300000080[[GN00<000000:jegP2^]Mh0102^]Mh01@000000dh5a0=>1L@000000
;P1L00<000001@2_]=`200000080<01N00=000000000003DOfh00P3DOfh01@000000e7m^0=AoKP3D
Ofh0000000@0e7m^00D000000=AoKP3DOfh0e7m^0000000203X9IP050=AoK@000000>PUV03X9IP00
00000P0j2FH20=AnJP8000000P2^]=d00`000000?@aW0=AmJ@040=AmJ@050000003DOFT0e7eY0=Am
J@0000000`3DOFT200000080@a9/00<0000004<BK0134V`0100000000`2^]Mh000000:jegP040:je
gP040000002^]Mh0000000000080eG]R00<0000004DDKP0000000`2^]Mh4000000H0[[GN00<00000
0:jegP000000102^]Mh00`000000dLfY0=7=Z@0h0=7=Z@005P3AcJT2000000H0[[GN00<000000:je
gP2^]Mh00P0000000`3BPWD00000000000050:jegP8000001P2^]Mh00`000000[[GN0:jegP020000
0080[[GN00<000000=>2M00000000P3CPW@200000080[[GM0P0000000`0@04H000000:jegP030:je
gP8000001@3CPG800`000000601<00000002000000@0[[GN00<000000=>0L03CP7000`3CP7000`00
00007P1A01h0D@050=>0K`030000000R05<00000008000001@2^]Mh01`000000dh5a0=>1L@3CPG40
000002h0G00000000P2_]=`200000080[kCL00D000000300GP000000<01N000000020:jdg@800000
00<0e7m^0000003DOfh00P3DOfh00`000000e7m^0=AoKP020=AoKP050000003DOfh0e7m^0=AoKP00
00000`0j2FH010000000>PUV03X9IP00000203X9IP@0e7iZ0P00000203d<I`03@000003DOFT0e7eY
0080e7eY00D000000=AmJ@3DOFT0e7eY000000040=AmJ@04000000134V`0@a9/000000<0@a9/00<0
00000:jeg@2^]Md00P0000050:jegP040000002^]Mh0[[GN0:jegP@000001P2^]Mh2000000D0[[GN
00@000000:jegP2^]Mh0[[GN0P0000000`2^]Mh000000=7=Z@0j0=7=Z@00603AcJT2000000@0[[GN
00<000000:jegP2^]Mh00P2^]Mh2000000H0[[GN00@000000=:2M@0000000000102^]Mh00`000000
[[GN0:jegP020:jegP8000000P3CPW@00`000000dh9d0=>2M0020=>2M080000000<0401600000000
00001@2^]Mh2000000D0dh5b00<0000001P0C03CPG400P3CPG42000000030:jegP0000006`1>00D0
dh1`00D0000001h0D@0N05500000000000030=>0K`030000000R05<000000080[[GN0P0000020:je
gP050000002_]=`000000000003CPG400P0000050:ndg08000000P0`05h2000000D0[[CM0P000003
0=AoKP030000003DOfh0e7m^0080e7m^00D000000=AoKP3DOfh0e7m^0000000303X9IP040000000j
2FH0>PUV00000080>PUV1@3DOVX010000000?@aW0000002^]Md200000080e7eY00D000000=AmJ@3D
OFT0e7eY000000040=AmJ@04000000134V`0@a9/000000<0@a9/00<0eGaV0000000000000P2^]Md2
00000080[[GN00<000000:jegP2^]Mh0102^]Mh2000000D0[[GN0P0000000d000000000000000002
0:jegP030000002^]Mh0[[GN00@0[[GN00<000000=7=Z@3AcJT0>P3AcJT001X0dLfY0P0000000`2^
]Mh000000:jegP040:jegP040000002^]Mh00000000000@0[[GN00@000000=:2M@3BPWD0dX9e0P00
00000`2^]Mh000000:jegP040:jegP<0000000<0dh9d0000003CPW@0103CPW@01000000040160000
000000050:jegP030000003CPG80dh5b00@0dh5b00<0000001P0C03CPG40103CPG40100000006`1>
01/0CT0000040=>0L0030000000N054000000080[[GN0P0000000`3CP6l00000000000050:jegP80
0000102_]=`2000000H0[kCL0P0000020300GP030000002^]=d0[[CM00<0[[CM0P0000040=AoKP03
0000003DOfh0e7m^0080e7m^00H000000=AoKP3DOfh0e7m^03X9IP00000203X9IP040000000j2FH0
>PUV00000080>PUV00=000000000003DOVX00P3DOVX00`000000?@aW000000030:jeg@<00000103D
OFT01@000000e7eY0=AmJ@3DOFT000000080@a9/00@0000004<BK0134V`0@a9/0`3EO6H200000003
0:jeg@0000000000008000001@2^]Mh00`000000[[GN0:jegP0200000080[[GN00@000000=EkHP3E
Nf8000000P196G03000000D0[[GN00<000000=7=Z@3AcJT0>`3AcJT001`0dLfY0P0000050:jegP04
0000002^]Mh0[[GN0:jegP80000000<0[[GN0000003BPWD00`3BPWD0100000001@0m000000000005
0:jegP030000002^]Mh0[[GN008000001@3CPW@01000000040160=>1L`3CPG<200000080[[GN00<0
000001@0B@3CPG80103CPG800`000000601<01P0C0050=>1L@040000000K04h000000:jegP800000
0P3CP7000`0000007P1A000000040:jegP8000001P2^]Mh00`000000[kCL0:ndg0030:ndg0040000
002_]=`00000000000@0[kCL0P0000020300GP030=>0K`00000000000080[[CM00<0000003<1H00c
0F00103DOfh00`000000e7m^0=AoKP020=AoKP030000003DOfh0e7m^0080e7m^00@0000003X9IP0j
2FH000000P0j2FH00`000000>PUV000000020:jeg@80000000<0e7iZ0000000000001P2^]Md00`00
0000e7eY0=AmJ@020=AmJ@050000003DOFT0e7eY0=AmJ@0000000P134V`200000080@a9/1@3EO6H0
0`000000[[GM0:jeg@020:jeg@8000000P2^]Mh00`000000[[GN0:jegP030:jegP8000000`3ENf80
10000000BAU`0000000000020:jegP8000000P2^]Mh00`000000dLfY0=7=Z@0l0=7=Z@007P3AcJT2
00000080[[GN00<000000:jegP2^]Mh0102^]Mh2000000<0dX9e00<0000000D0?@0000000P2^]Mh2
00000080[[GN00@000000:jegP2^]Mh0[[GN0P0000050=>2M0030000000@04H0dh5c00<0dh5c0P00
000201@0B@D0dh5b00D0000001P0C00H04a00000000000030=>1L@030000000K04h0000000<0[[GN
100000050:jegP040000002^]Mh00000000000@0[[GN00<000000:ndg02_]=`00`2_]=`010000000
[kCL0:ndg02_]=`2000000040:ndg0000000000000000080<01N0`3CP6l2000000<0<`5P103DOfh0
0`000000e7m^0=AoKP020=AoKP030000003DOfh0e7m^0080e7m^00@0000003X9IP0j2FH000000P0j
2FH2000000D0[[GM0`0000050:jeg@030000003DOFT0e7eY00<0e7eY00D000000=AmJ@3DOFT0e7eY
0000000204<BK08000000P134V`50=ElIP<000000P2^]Md010000000AaM_0000000000050:jegP80
000000@0[[GN000000000000eG]R0P0000060:jegP800000?`3AcJT00200dLfY0`0000050:jegP03
0000002^]Mh0[[GN0080000000<0dX9e0000000000001@2^]Mh300000080[[GN00<0000000d0@`3C
PW@01@3CPW@00`00000040160=>1L`040=>1L`050000000D04T05019@000000000000`3CPG800`00
0000601<000000020:jegP80000000<0dh5a0000000000001P2^]Mh2000000D0[[GN00@000000:je
gP2^]Mh0[[GN0P0000000`2^]Mh000000=>1LP0200000080[kCL00<000000:ndg02_]=`0102_]=`0
10000000<01N0000000000020300GP@0dh1_00D0000003<1H00c0F00<`5P@00000030=AoKP030000
003DOfh0e7m^0080e7m^00<000000=AoKP3DOfh00P3DOfh010000000>PUV03X9IP00000203X9IP80
00001@2^]Md00`000000[[GM0:jeg@0200000080[[GM00<0000003l>J@3DOFT0103DOFT01@000000
e7eY0=AmJ@3DOFT000000080@a9/0P00000204<BK003@00000000000eGaV0080eGaV00<000000=El
IP3EO6H00P00000304LGK`<000000P2^]Mh00`000000[[GN0:jegP030:jegP8000001`2^]Mh00`00
0000dLfY0=7=Z@0n0=7=Z@008`3AcJT300000080[[GN00<000000:jegP2^]Mh00P2^]Mh3000000D0
[[GN00L000000=:2M@3BPWD00000@000000000003@1300D0dh9d00D000000100AP0@04I000000000
00030=>1L`030000000D04T000000080[[GN0P0000000`3CPG800000000000050:jegP<000001@2^
]Mh00`000000dh5a0000000200000080[[GN00<000000:jegP2^]Mh0102^]Mh2000000<0dh5b0`00
00050:ndg0030000000`05h0<01N008000000P0`05h01T000000dh1_0=>0K`3CP6l0000003<1H080
000000D0[[GM000000000000e7m^000000040=AoKP030000003DOfh0e7m^0080e7m^00@0000003X9
IP0j2FH000000P0j2FH20=AnJ`8000000P2^]Md00`000000[[GM0:jeg@030:jeg@8000000P0o3VT5
0=AmJ@050000003DOFT0e7eY0=AmJ@0000000P134V`20000000404<BK0000000[[GN0:jegP800000
00<0eGaV0000003EO6H00P3EO6H010000000AaM_04LGK`175fl2000000030:jegP000000000000H0
[[GN00@000000:jegP0000000000102^]Mh00`000000dLfY0=7=Z@0o0=7=Z@009P3AcJT3000000@0
[[GN00<000000:jegP2^]Mh00`0000020:jegP050000003BPWD0dX9e0=:2M@0000000P0=04<00d00
000000000=>2M0020=>2M0030000000@04H000000080[[GN0P0000000`3CPG<00000000000050:je
gP<000001@2^]Mh00`000000[[GN0:jegP0200000080[[GN00H000000=>1L@3CPG40dh5a0000000R
05<3000000D0[[GN00<000000=>1LP000000103CPG8010000000dh5b0000000000020:ndg0800000
0P0`05h01@3CP70000000300GP000000[[GM0080000000<0dh1_0000000000001@2^]Md2000000@0
e7m^00<000000=AoKP3DOfh00P3DOfh010000000>PUV03X9IP00000203X9IP@0e7i[0P0000050:je
g@<000000P0o3VT00d00000000000=AmJ@020=AmJ@050000003DOFT0e7eY0=AmJ@0000000`134V`2
000000D0[[GN0P0000030=ElIP03000000175fl0AaM_0080AaM_00@0eGaU000000000000[[GN0P00
00040:jegP040000002^]Mh0[[GN0:jegP80000000<0[[GN0000003AcJT0@@3AcJT002T0dLfY0P00
00020:jegP030000002^]Mh0[[GN00<0[[GN0`0000030=:2M@030000000=04<000000080[[GN0P00
00000`3CPW@00000000000050:jegP<000001@2^]Mh500000080[[GN00<000000:jegP2^]Mh00`2^
]Mh3000000<0dh5a00<000000280D`0000000P2^]Mh200000080[[GN00@000000=>1LP3CPG800000
103CPG8010000000dh5b0=>1LP3CPG82000000080300GP000000<01N0300GP3CP70000000300GP00
00030:jeg@8000001P2^]Md00`000000e7m^0=AoKP030=AoKP030000003DOfh0e7m^0080e7m^00@0
000003X9IP0j2FH000000P0j2FH50=AnJ`<000000P2^]Md01P000000?`iY03l>J@000000?`iY0000
0080[[GN0P0000000`3DOFT000000=AmJ@020=AmJ@04000000134V`0@a9/04<BK08000001@2^]Mh0
0`000000AAA^0=ElIP020=ElIP03000000175fl0AaM_0080AaM_0`3EO6D20000000504TIL0000000
00000:jegP0000001P2^]Mh00`000000dLfY0=7=Z@110=7=Z@00:`3AcJT2000000H0[[GN00<00000
0:jegP2^]Mh00P0000000`3BPWD00000000000050:jegP8000001P2^]Mh00`000000[[GN0:jegP02
00000080[[GN0P0000020=>2M0D000001@2^]Mh00`000000[[GN0:jegP02000000030=>1L@000000
000000D0[[GN0P0000030=>1LP030000003CPG80dh5b0080dh5b00<000000=>1LP3CPG800P3CPG80
0`000000<01N000000020300GP030=>0L0000000000000@0[[GM00@000000:jeg@0000000000102^
]Md00`000000e7m^0=AoKP030=AoKP030000003DOfh0e7m^0080e7m^00@0000003X9IP0j2FH00000
0P0j2FH00d00000000000=AnJ`020=AnJ`030000003DOV/0e7i[00<000000P0o3VT2000000D0[[GN
0P0000030=AmJ@04000000134V`0@a9/04<BK080eGeX0P0000020:jegP030000001556h0AAA^00@0
eGaV00@0000004LGK`175fl0AaM_103EO6D010000000BAU`04TIL0196G02000000D0[[GN00<00000
0=7=Z@3AcJT0@P3AcJT002d0dLfY0P0000040:jegP030000002^]Mh0[[GN0080[[GN0P0000060:je
gP@00000102^]Mh00`000000[[GN0:jegP020:jegP80000000<0dh9d0000003CPW@00`3CPW@20000
000301h0D@00000000000080[[GN00<000000:jegP2^]Mh00`2^]Mh2000000H0[[GN0P0000030=>1
LP030000003CPG80dh5b0080dh5b00<000000=>1LP3CPG800P3CPG800`000000<01N000000020300
GP030=>0L0000000[[GM00@0[[GM00@000000:jeg@2^]Md0[[GM0P0000000`2^]Md0000003H4HP05
0=AoKP030000003DOfh0e7m^0080e7m^00H0000003X9IP0j2FH0000003X9IP0000020:jegP800000
00<0e7i[0000003DOV/00`3DOV/00`000000?`iY03l>J@02000000D0[[GN00<000000=AmJ@3DOFT0
0`3DOFT00`000000@a9/04<BK0040=EmJ08000000`1556h40=ElIP05000000175fl0AaM_04LGKd00
00000`3EO6D010000000BAU`0000000000020:jegP8000000P2^]Mh00`000000dLfY0=7=Z@130=7=
Z@00;`3AcJT2000000030:jegP000000[[GN00@0[[GN00@000000:jegP0000000000102^]Mh01000
0000dX9e0=:2MD000002000000030:jegP000000[[GN00@0[[GN0P0000000`3CPW@000000=>2M004
0=>2M0030000000N0540000000<000001P2^]Mh010000000[[GN0000000000040:jegP060000002^
]Md000000000003CPG800000103CPG800`000000dh5b0=>1LP020=>1LP030000000`05h000000080
<01N0P3CP70200000080[[GM00<000000:jeg@2^]Md0102^]Md010000000=PAR03H4HT0000040=Ao
KP030000003DOfh0e7m^0080e7m^00H0000003X9IP0j2FH0000003X9IP0000040:jegP800000103D
OV/00`000000?`iY03l>J@020=AnJP8000000P2^]Mh00`000000@A1[0=AmJ@040=AmJ@0300000013
4V`0@a9/00D0eGeX00D0000004DDKP1556h0AAA^@00000030=ElIP05000000175fl000000000002^
]Mh00P0000000`3EO6D00000000000060:jegP800000AP3AcJT00340dLfY0P0000050:jegP040000
002^]Mh0[[GN0:jegP80000000<0[[GN0000003BPWD00P3BPWD00`000000501901@0B@02000000D0
[[GN00@000000:jegP00000000001@3CPW@0100000007P1A0=>1L`3CPG<4000000@0[[GN00@00000
0:jegP2^]Mh0[[GN0P0000000`2^]Mh000000:jeg@030:jeg@800000103CPG801@000000dh5b0=>1
LP3CPG8000000080<01N00<000000300GP0`05h0103CP703000000D0[[GM0P0000000`0f16800000
0:jegP0200000080e7m^00<000000=AoKP3DOfh00P3DOfh00`000000>PUV03X9IP02000000D0[[GN
00<000000=AnJ`3DOV/00`3DOV/00`000000?`iY03l>J@040=AnJP8000000P1146/50=AmJ@050000
00134V`0@a9/@000000000000`3EOFP01@000000AAA^000000000000[[GN0080000000<0eGaV0000
000000001@2^]Mh3000000D0[[GN0P0000170=7=Z@00<`3AcJT200000080[[GN00<000000:jegP2^
]Mh0102^]Mh2000000<0dX9e00<0000001@0B@0000000P2^]Mh200000080[[GN00@000000:jegP2^
]Mh000001@3CPW@00`0000007P1A01h0D@040=>1L`@0000000<0[[GN0000002^]Mh01@2^]Mh00`00
0000[[GM0:jeg@030:jeg@030000003CPG80dh5b00<0dh5b00D000000=>1LP3CPG80dh5b00000002
0300GP030000000`05h0<01N00D0dh1`00@000000=>0L000000000000P2^]Md01@000000=PAR0000
000f1680000000<0[[GN0`0000040=AoKP030000000j2FH0>PUV008000001@2^]Mh00`000000e7i[
0=AnJ`030=AnJ`030000000o3VT0?`iY00D0e7iZ00@00000044@J`1146]00000103DOFT00`000000
@a9/000000020:jegP80000000<0eGeX0000000000001@2^]Mh3000000D0[[GN00<000000:jegP2^
]Mh00P0000020:jegP030000003AcJT0dLfY04L0dLfY000e0=7=Z@<000001@2^]Mh00`000000[[GN
0:jegP02000000030=:2M@000000000000D0[[GN0P0000020:jegP030000000K04h0dh9d00@0dh9d
00<0000001h0D@0N05401@3CPG<00`0000008P1C0280D`02000000D0[[GN00@000000:jeg@000000
00000P2^]Md00`000000:`1J0=>1LP040=>1LP050000003CPG80dh5b0=>1LP0000000P0`05h01@00
0000<01N0300GT000000000000<0dh1`00@000000=>0L03CP700dh1`0P00000203H4HP8000001P2^
]Mh00`000000e7m^0=AoKP020=AoKP030000000j2FH0>PUV0080e7m]0P0000020:jegP030000000m
36L0e7i[00@0e7i[00@0000003l>J@0o3VU00000103DOVX010000000@A1[0000002^]Mh200000080
e7eY00<0000004<BK0000000102^]Mh2000000H0[[GN0P0000000`2^]Mh00000000000020:jegP03
0000002^]Mh0[[GN00<0[[GN0P00001:0=7=Z@00>03AcJT200000080[[GN00<000000:jegP2^]Mh0
0`2^]Mh3000000D0[[GN00@000000=:2M@00001000000P0K04h50=>2M0050000000N05407P1A@000
000000000`3CPG<00`0000008P1C000000020:jegP8000000P2^]Mh00`000000[[GM0:jeg@020:je
g@04000004000000:`1J02/0FPD0dh5b00D000000=>1LP3CPG80dh5b000000020300GP030000000`
05h000000080[[GN0P0000000`3CP70000000=>0L0030=>0L0030000000f1680=PAR008000001@2^
]Mh00`000000e7m^0=AoKP030=AoKP030000000j2FH0>PUV00@0e7m]0P00000203d<I`D0e7i[00@0
000003l>J@000000[[GN0P0000020=AnJP030000001146/0000000<0[[GN100000050:jegP040000
002^]Mh00000000000@0[[GN00<000000=EmJ40000000P196G02000000H0[[GN00<000000=7=Z@3A
cJT0B@3AcJT003X0dLfY0`0000050:jegP030000002^]Mh0[[GN008000000P2^]Mh01@000000dX9e
0=:2M@3BPWD0000000806`1>00=000000000003CPW@00P3CPW@00`0000007P1A000000020:jegP80
000000<0dh5c0000000000001@2^]Mh2000000D0[[GM0P00000202/0FP03@00000000000dh5b0080
dh5b00D000000=>1LP3CPG80dh5b000000020300GP8000001@2^]Mh2000000@0dh1`00<0000003H4
HP0f16800P3CP6l200000080[[GN00<0000003P6I03DOfh0103DOfh00`000000>PUV03X9IP050=Ao
K@050000000m36L0?@aW@000000000000`3DOV/00`000000?`iY000000030:jegP@000001P2^]Mh2
000000D0[[GN00@000000:jegP2^]Mh0[[GN0P0000001@2^]Mh000000=EmJ03EOFP000000080BAU`
00<000000:jegP000000102^]Mh00`000000dLfY0=7=Z@1:0=7=Z@00?@3AcJT200000080[[GN00<0
00000:jegP2^]Mh00`2^]Mh3000000<0dX9e00<0000001/0CP0000000P2^]Mh2000000030=>2M000
0000000000D0[[GN0`0000050:jegP040000003CPW@0000000000080[[GM00D0000002/0FP000000
:`1J000000020:jegP80000000<0dh5b0000003CPG800P3CPG800`000000<01N0300GP02000000D0
[[GN00<000000=>0L03CP7000`3CP7000`000000=PAR03H4HP040=>0K`8000000P0h1V@50=AoKP05
0000000j2FH0>PUV@000000000000`3DOfd00`000000?@aW000000020:jegP80000000<0e7i[0000
000000001P2^]Mh2000000D0[[GN0P0000000`2^]Md00000000000020:jegP030000002^]Mh0[[GN
00@0[[GN00L000000=EmJ03EOFP0eGeX000000196G00000000<0[[GN0P0000000`2^]Mh000000=7=
Z@1<0=7=Z@00?`3AcJT3000000D0[[GN00<000000:jegP2^]Mh00P0000000`3BPWD0000000000005
0:jegP<000001@2^]Mh00`000000[[GN0:jegP0200000080[[GN0P0000030=>2M004000004000000
:`1J02/0FP8000001@2^]Mh2000000<0dh5b00<000000300GP0`05h00P3CPG4200000080[[GN00<0
000003<1H03CP700103CP7000`000000=PAR03H4HP050=>0K`050000000h1V@0>0IT@00000000000
0`3DOfh00`000000>PUV000000020:jegP80000000<0e7m]0000000000001@2^]Mh3000000D0[[GN
00<000000:jegP2^]Mh00P0000020:jegP030000003DOV/0e7i[0080000000<0AaM_000000000000
1@2^]Mh2000000040:jegP00000000000=EmJ08000001P2^]Mh00`000000dLfY0=7=Z@1<0=7=Z@00
@P3AcJT200000080[[GN00<000000:jegP2^]Mh00`2^]Mh3000000D0[[GN00<000000=:2M@000000
0P0000020:jegP030000002^]Mh0[[GN00<0[[GN0P0000000`3CPW@000000=>2M0030=>2M0030000
000[05X0:`1J008000001@2^]Mh00`000000dh5b0=>1LP020=>1LP030000000`05h0<01N00@0dh5a
0P00000203<1H0D0dh1`00D0000003H4HP0f16900000000000030=>0K`030000000h1V@000000080
[[GN0P0000000`3DOfh00000000000050:jegP<000001@2^]Mh200000003@0000000000000000080
[[GN00<000000:jegP2^]Mh00`2^]Mh3000000<0e7i[00@0000004LGK`175fl0AaM_0P0000020:je
gP030000002^]Mh0[[GN00<0[[GN0`0000050:jegP030000003AcJT0dLfY04d0dLfY00140=7=Z@80
00001P2^]Mh00`000000[[GN0:jegP0200000080[[GN00H000000=:2M@3BPWD0dX9e0000000R05<3
000000D0[[GN00@000000:jegP0000000000103CPW@00`000000:`1J02/0FP020=>1L`8000000P2^
]Mh00`000000dh5b0=>1LP030=>1LP030000000`05h0<01N00D0dh5a00D0000003<1H00c0F100000
000000030=>0L0030000000f168000000080[[GN0P0000000`3CP6l00000000000050:jegP<00000
1@2^]Mh00`000000[[GN0:jegP0200000080[[GN00@000000=AoK@3DOfd000000P1146/2000000D0
[[GN100000030=AnJ`0504LGK`000000AaM_04LGK`3DOVX0100000050:jegP030000002^]Mh0[[GN
008000000P2^]Mh00`000000dLfY0=7=Z@1>0=7=Z@00AP3AcJT2000000@0[[GN00<000000:jegP2^
]Mh00P2^]Mh2000000@0dX9e00<000000280D`0000000P2^]Mh200000080[[GN00@000000:jegP2^
]Mh000001@3CPW@00`000000:`1J02/0FP040=>1L`80000000<0;P1L0=>1LP3CPG800`3CPG801@00
0000<01N0300GT000000000000<0dh5a00<0000003<1H00000000P2^]Mh2000000030=>0L0000000
000000D0[[GN0`0000050:jegP030000002_]=`0[kCL008000000P2^]Mh00`000000[[GN0:jegP03
0:jegP8000000`3DOfd01@000000@A1[000000000000[[GN008000000P2^]Mh010000000[[GN0000
000000050=AnJ`03000000175fl0AaM_00<0e7iZ100000020:jegP030000002^]Mh0[[GN00<0[[GN
0P00001A0=7=Z@00B03AcJT2000000030:jegP000000[[GN00@0[[GN00@000000:jegP0000000000
0P3BPWD00`0000008P1C000000040:jegP8000000`2^]Mh00`000000dh9d0=>2M0030=>2M0030000
000[05X0:`1J00@0dh5c00@0000002h0G00^05a00000103CPG800`000000<01N000000020:jegP80
000000<0dh5a0000000000001@2^]Mh3000000D0[[GN00<000000:jegP2^]Mh00P0000020:jegP<0
000000<0[kCL0000002_]=`00P0000050:jegP80000000@0[[GN000000000000e7m]0P0000050:je
gP80000000@0[[GN0000001556h0AAA^1@3DOV/00`000000AaM_04LGK`050=AnJP03000000196G00
0000008000001@2^]Mh00`000000dLfY0=7=Z@1@0=7=Z@00BP3AcJT2000000D0[[GN00@000000:je
gP2^]Mh0[[GN100000050:jegP<0000000<0[[GN0000000X05P01@3CPW@00`000000:`1J02/0FP04
0=>1L`040000000^05`000000:jegP8000000P3CPG800`000000<01N000000040:jegP8000001P2^
]Mh00`000000dh5a0000000200000080[[GN00<000000:jegP2^]Mh00`2^]Mh2000000<0dh5b00=0
00000:ndg02_]=`00P2_]=`200000080[[GN00<000000:jegP2^]Mh00`2^]Mh3000000D0[[GN0P00
000014000000000004DDKP1556h50=AnJ`05000000175fl0AaM_@000000000000`3DOVX00`000000
BAU`000000020:jegP8000000P2^]Mh00`000000dLfY0=7=Z@1A0=7=Z@00C03AcJT200000080[[GN
00<000000:jegP2^]Mh0102^]Mh2000000D0[[GN00@000000=:2M@3BPWE000000P0X05P50=>2M004
0000000[05X0:`1J@00000<0dh5c00<0000002h0G00000000`2^]Mh4000000D0[[GN00@000000:je
gP0000000000102^]Mh01@000000dh5a0=>1L@000000>0IT008000001P2^]Mh00`000000dh5b0=>1
LP020=>1LP<000000P2_]=`010000000@a9/0000000000060:jegP030000002^]Mh0[[GN00800000
0P2^]Mh01@000000e7m]0=AoK@3DOfd000000080AAA^00=000000000003DOV/00P3DOV/00`000000
AaM_000000020:jegP80000000<0e7iZ0000000000001@2^]Mh2000005@0dLfY001>0=7=Z@<00000
1@2^]Mh00`000000[[GN0:jegP0200000080[[GN00D000000=:2M@3BPWD0dX9e0000000202P0F003
@00000000000dh9d0080dh9d00@0000002/0FP000000[[GN0P0000000`3CPG<00000000000060:je
gP8000001@2^]Mh010000000[[GN0:jegP2^]Mh2000000030:jegP000000dh5a0080dh5a00@00000
03P6I0000000[[GN0P0000040:jegP030000003CPG80dh5b0080dh5b00<000000=>1LP3CPG800P00
000304<BK0<00000102^]Mh00`000000[[GN0:jegP020:jegP800000103DOfd00`000000AAA^0000
00020:jegP80000000<0e7i[0000000000001@2^]Mh2000000D0[[GN0P00001E0=7=Z@00D@3AcJT2
00000080[[GN00<000000:jegP2^]Mh00`2^]Mh3000000<0dX9e00<0000002P0F00000000P2^]Mh2
000000030=>2M0000000000000@0[[GN0`0000050:jegP030000003CPW@00000008000000P2^]Mh0
0`000000[[GN0:jegP040:jegP8000000`3CPG400`000000>0IT000000030:jegP80000000<0[[GN
000000000000103CPG801@000000dh5b0=>1LP3CPG80000000<0@a9/00<0000004<BK0134V`00P00
00000`2^]Mh000000:jegP040:jegP040000002^]Mh0000000000080e7m]00<0000004DDKP000000
102^]Mh2000000H0[[GN00@000000:jegP00000000000P2^]Mh00`000000dLfY0=7=Z@1E0=7=Z@00
D`3AcJT3000000D0[[GN00<000000:jegP2^]Mh00P0000000`3BPWD00000000000050:jegP800000
1@2^]Mh00`000000[[GN0:jegP0200000080[[GN0P0000030=>2M0@000001@2^]Mh00`000000[[GN
0:jegP02000000030=>1L@000000000000H0[[GN00<000000=>1LP000000103CPG801@000000dh5b
0=>1LP3CPG80000000<0@a9/00D0000004<BK0134V`000000:jeg@02000000D0[[GN00@000000:je
gP2^]Mh0[[GN100000050:jegP030000002^]Mh0000000@0[[GN00<000000:jegP2^]Mh00P2^]Mh2
000005P0dLfY001F0=7=Z@8000000P2^]Mh00`000000[[GN0:jegP030:jegP<000001@2^]Mh01000
0000dX9e0000000000020:jegP030000002^]Mh0[[GN00<0[[GN0P0000000`3CPW@000000=>2M003
0=>2M0030000000f1680=PAR008000000P2^]Mh00`000000[[GN0:jegP030:jegP8000001@2^]Mh3
000000030=>1LP000000dh5b00<0dh5b00<000000=>1LP3CPG800P3CPG8010000000@a9/04<BK000
000204<BK0040=>0L000000000000:jeg@8000000P2^]Mh00`000000[[GN0:jegP040:jegP030000
002^]Mh0[[GN00<0[[GN00<000000=AoKD0000000`0000000`2^]Mh000000:jegP040:jegP030000
003AcJT0dLfY05L0dLfY001H0=7=Z@<000001@2^]Mh00`000000[[GN0:jegP0200000080[[GN00D0
00000=:2M@3BPWD0000002h0G003000000D0[[GN00@000000:jegP0000000000103CPW@00`000000
=PAR03H4HP020=>1L`<000001@2^]Mh010000000[[GN0000000000020:jegP040000002^]Md0[[GM
0:jeg@800000103CPG800`000000dh5b0=>1LP020=>1LP04000000134V`0@a9/00000080@a9/0`3C
P705000000D0[[GN0P0000000`2^]Mh00000000000020:jegP050000003DOfd0e7m]0=AoK@000000
0P196G02000000D0[[GN00<000000=7=Z@3AcJT0E`3AcJT005/0dLfY0P0000020:jegP030000002^
]Mh0[[GN00<0[[GN0P0000030=:2M@030000000^05`000000080[[GN0P0000020:jegP040000002^
]Mh0[[GN000000D0dh9d00<0000003H4HP0f1680103CPG<300000080[[GN00<000000:jegP2^]Mh0
0P2^]Mh2000000@0[[GM00<0000003l>J@3CPG800`3CPG800`000000dh5b0=>1LP020=>1LP040000
00134V`0@a9/00000080@a9/1@3CP70500000080[[GN00<000000:jegP2^]Mh00`2^]Mh3000000<0
e7m]00<0000004TIL00000000P2^]Mh200000080[[GN00<000000=7=Z@3AcJT0F03AcJT005d0dLfY
0`0000050:jegP050000002^]Mh000000000003BPWD00P0000050:jegP8000000P2^]Mh00`000000
<`5P0=>2M0040=>2M0030000000f1680=PAR00@0dh5c00<0000003P6I00h1V@00P0000050:jegP<0
00000P2^]Md00`000000?`iY03l>J@040=>1LP030000003CPG80dh5b0080dh5b00@0000004<BK013
4V`000000P134V`00d00000000000=>0L0020=>0L0030000003CP700dh1`00D000001@2^]Mh00`00
0000[[GN0:jegP02000000030=AoK@000000000000D0[[GN0P00001K0=7=Z@00H03AcJT200000080
[[GN00<000000:jegP2^]Mh00P2^]Mh3000000D0[[GN00@000000=:2M@00001000000P0c0F050=>2
M0040000000f1680=PAR@00000<0dh5c00D0000003P6I000000000000:jegP0200000080[[GN00H0
00000:jeg@2^]Md0[[GM00000400000303l>J@@0dh5b00<000000=>1LP3CPG800P3CPG801P000000
@a9/04<BK0000000@a9/00000080[[GN0P0000000`3CP70000000=>0L0020=>0L003000000175fl0
AaM_00<000000P2^]Mh00`000000[[GN0:jegP030:jegP8000001@2^]Mh2000005`0dLfY001R0=7=
Z@8000001@2^]Mh00`000000[[GN0:jegP0200000080[[GN00D000000=:2M@3BPWD0dX9e00000002
03<1H003@00000000000dh9d0080dh9d00@0000003H4HP000000[[GN0P0000000`3CPG<000000000
00050:jegP800000102^]Md2000000<0?`iY00E000000=>1LP3CPG80dh5b000000040=>1LP030000
00134V`0@a9/008000001@2^]Mh2000000<0dh1`00D0000004LGK`175fl0AaM_0=>0K`03000000D0
[[GN0P0000000`2^]Mh00000000000020:jegP030000003AcJT0dLfY05`0dLfY001T0=7=Z@800000
0P2^]Mh00`000000[[GN0:jegP030:jegP<000000`3BPWD00`000000<`5P000000020:jegP800000
00<0dh9d000000000000102^]Mh3000000D0[[GN0`0000020:jeg@040000000o3VT0000003l>J@80
000000D0[[GN000000000000dh5b000000040=>1LP04000000134V`0@a9/000000D0[[GN0P000004
0=>0L004000000175fl0AaM_04LGK`<0dh1_0`0000020:jegP030000002^]Mh0[[GN00<0[[GN0P00
001O0=7=Z@00IP3AcJT3000000D0[[GN00<000000:jegP2^]Mh00P0000000`3BPWD0000000000005
0:jegP8000001@2^]Mh00`000000[[GN0:jegP0200000080[[GN0P0000020=>2M004000004000000
?`iY03l>J@8000001@2^]Mh2000000@0dh5b00@0000004<BK0134V`0dh5a0P0000020:jegP030000
001556h0AAA^00@0dh1`00@0000004LGK`175fl0AaM_103CP6l00`000000BAU`00000002000000D0
[[GN00<000000=7=Z@3AcJT0GP3AcJT006T0dLfY0P0000020:jegP030000002^]Mh0[[GN00<0[[GN
0`0000050:jegP040000003BPWD0000000000080[[GN00<000000:jegP2^]Mh00`2^]Mh200000003
0=>2M0000000dh9d0080dh9d00<0000003l>J@0o3VT00P0000050:jegP030000003CPG80dh5b00<0
dh5b00<0000004<BK0134V`00`3CPG4300000080AAA^103CP7001@000000AaM_04LGK`175fm00000
00<0dh1_00<0000004TIL00000000P2^]Mh200000080[[GN00<000000=7=Z@3AcJT0G`3AcJT006/0
dLfY0`0000050:jegP030000002^]Mh0[[GN008000000P2^]Mh01@000000dX9e0=:2M@000000>0IT
00<000001@2^]Mh010000000[[GN0000000000030=>2M0050000000o3VT0?`iY03l>J@3CPG<00P00
00020:jegP030000001146/0dh5b00@0dh5b00<0000004<BK0134V`01@3CPG4010000000AAA^04DD
KT0000030=>0L005000000175fl000000000002^]Mh00P0000000`3CP6l00000000000050:jegP80
0000HP3AcJT006h0dLfY0P0000020:jegP030000002^]Mh0[[GN00<0[[GN0P0000030=:2M@030000
000h1V@000000080[[GN0P0000020:jegP040000002^]Mh0[[GN000000@0dh9d00@0000003l>J@0o
3VT0?`iY0`3CPG<200000080@A1[1@3CPG801@000000@a9/04<BK4000000000000<0dh5a00@00000
04DDKP000000[[GN0P0000000`3CP7000000000000050:jegP<000001@2^]Mh00`000000dLfY0=7=
Z@1Q0=7=Z@00L03AcJT3000000D0[[GN00D000000:jegP00000000000=:2M@02000000D0[[GN0P00
00020:jegP030000000m36L0dh9d00<0dh9d00@0000003l>J@0o3VT0?`iY103CPG<01@000000@A1[
044@Jd000000000000<0dh5b00<0000004<BK00000000P2^]Mh2000000030=>1L@000000000000@0
[[GN0`0000050:jegP030000002^]Mh0[[GN008000000P2^]Mh00`000000dLfY0=7=Z@1R0=7=Z@00
L`3AcJT200000080[[GN00<000000:jegP2^]Mh00P2^]Mh3000000D0[[GN00@000000=:2M@000010
00000P0m36L40=>2M0050000000o3VT0?`iY03l>JD0000000`3CPG<00`000000@A1[000000020:je
gP80000000<0dh5b0000000000001@2^]Mh2000000D0[[GN0P0000000d0000000000000000020:je
gP030000002^]Mh0[[GN00<0[[GN0P00001U0=7=Z@00M@3AcJT2000000D0[[GN00<000000:jegP2^
]Mh00P0000020:jegP050000003BPWD0dX9e0=:2M@0000000P0m36L01T000000dh9d0=>2M03CPW@0
000003l>J@80000000@0[[GN000000000000dh5c0P0000050:jegP8000001@2^]Mh2000000030:je
gP00000000000080[[GN00H000000=>1L@3CPG40dh5a000000196G02000000D0[[GN0P00001V0=7=
Z@00M`3AcJT200000080[[GN00<000000:jegP2^]Mh00`2^]Mh3000000<0dX9e00@0000003d<I`00
0000[[GN0P0000000`3CPW@00000000000050:jegP<000001@2^]Mh400000080[[GN00<000000:je
gP2^]Mh00`2^]Mh3000000<0dh5a00@0000004TIL0000000[[GN0P0000020:jegP030000003AcJT0
dLfY06H0dLfY001i0=7=Z@<000001@2^]Mh00`000000[[GN0:jegP02000000030=:2M@0000000000
00@0[[GN0`0000050:jegP030000002^]Mh0[[GN008000000P2^]Mh00`000000dh9d0=>2M0050000
00D0[[GN00<000000:jegP2^]Mh00P0000000`3CPG400000000000040:jegP800000J@3AcJT007`0
dLfY0P0000020:jegP030000002^]Mh0[[GN00<0[[GN0P0000050:jegP030000003BPWD000000080
00000P2^]Mh00`000000[[GN0:jegP030:jegP<00000103CPW@00`000000AaM_04LGK`0200000080
[[GN00<000000:jegP2^]Mh00`2^]Mh2000000D0[[GN00<000000=7=Z@3AcJT0J03AcJT007h0dLfY
0P0000060:jegP040000002^]Mh0000000000080[[GN00H000000=:2M@3BPWD0dX9e0000001146/3
000000D0[[GN0`0000040=>2M004000000175fl0AaM_0=>1L`@000001@2^]Mh010000000[[GN0000
000000020:jegP030000003AcJT0dLfY06T0dLfY00200=7=Z@800000102^]Mh010000000[[GN0:je
gP2^]Mh3000000<0dX9e00<00000044@J`0000000P2^]Mh200000080[[GN00<000000:jegP000000
1@3CPW@00`000000AaM_04LGK`030=>1L`@000000P2^]Mh00`000000[[GN0:jegP020:jegP800000
K03AcJT00880dLfY0P0000000`2^]Mh000000:jegP030:jegP030000002^]Mh0[[GN0080000000<0
dX9e0000000000001@2^]Mh2000000030:jegP000000AAA^00D0dh9d00<0000004LGK`175fl0103C
PG<00`000000BAU`04TIL002000000D0[[GN00<000000=7=Z@3AcJT0J`3AcJT008@0dLfY00<00000
0:jegP2^]Mh00`2^]Mh00`000000[[GN0:jegP020:jegP<000001@2^]Mh200000003@000001556h0
AAA^00D0dh9d00@0000004LGK`175fm000000`3CPG<01@000000BAU`000000000000[[GN00800000
0P2^]Mh00`000000dLfY0=7=Z@1/0=7=Z@00Q@3AcJT200000080[[GN00<000000:jegP2^]Mh00`2^
]Mh00`000000[[GN0:jegP0200000080[[GN00@000000=:2M@3BPWD000000P1556h00d0000000000
0=>2M0020=>2M004000000175fl000000:jegP80000000<0dh5c0000000000001@2^]Mh2000006l0
dLfY00270=7=Z@@000000`2^]Mh00`000000[[GN0:jegP030:jegP8000000`3BPWD00`000000AAA^
000000020:jegP80000000<0dh9d000000000000102^]Mh3000000D0[[GN00<000000=7=Z@3AcJT0
KP3AcJT008/0dLfY0`0000050:jegP80000000@0[[GN000000000000dX9e0P0000050:jegP800000
1@2^]Mh00`000000[[GN0:jegP0200000080[[GN00<000000=7=Z@3AcJT0K`3AcJT008h0dLfY0P00
00020:jegP030000002^]Mh0[[GN00<0[[GN0`0000050:jegP@000000P2^]Mh00`000000[[GN0:je
gP030:jegP800000LP3AcJT00900dLfY0`0000050:jegP030000002^]Mh0[[GN008000000P2^]Mh0
1@000000dX9e0=:2M@000000BAU`00<000001@2^]Mh00`000000dLfY0=7=Z@1a0=7=Z@00T`3AcJT2
00000080[[GN00<000000:jegP2^]Mh00`2^]Mh2000000<0dX9e00<0000004TIL00000000P2^]Mh2
00000080[[GN00<000000=7=Z@3AcJT0LP3AcJT009D0dLfY0`0000050:jegP050000002^]Mh00000
0000003BPWD00P0000050:jegP800000M@3AcJT009P0dLfY0P0000020:jegP030000002^]Mh0[[GN
0080[[GN0`0000050:jegP030000003AcJT0dLfY07@0dLfY002J0=7=Z@8000001@2^]Mh00`000000
[[GN0:jegP0200000080[[GN00<000000=7=Z@3AcJT0M@3AcJT009`0dLfY0P0000020:jegP030000
002^]Mh0[[GN00<0[[GN0P00001h0=7=Z@00WP3AcJT2000000D0[[GN0P00001i0=7=Z@00X03AcJT2
00000080[[GN00<000000=7=Z@3AcJT0N@3AcJT00:80dLfY0P00001l0=7=Z@00o`3AcJTQ0=7=Z@00
o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00
o`3AcJTQ0=7=Z@00\
\>"],
  ImageRangeCache->{{{0, 287}, {310.063, 0}} -> {0.0558752, -0.000122562, \
0.00318756, 0.00318756}}]
}, Open  ]],

Cell["\<\
In generating CA, we have to select those rules such that \
{0,0,1},{0,1,0},{1,0,0} are not all assigned to 0 or we will not get the \
automata started. We also need to have at least two of them equal to 1 and at \
least one of the others equal to 1 or we won\.b4t proliferate. Also,{0,0,0}\
\[Rule]0 (quiescent CA) is prefered to avoid the boundary effect and, in \
doing so, we might miss some interesting behavior as CA number 125 previously \
showed.
When is a rule equivalent to another? Two rules are equivalent if they \
include symmetric elements, that is, they are obtained from each other by the \
transformation 2\[LongLeftRightArrow]5, 4\[LongLeftRightArrow]7. They \
correspond to mutual reflections. This can be shortly described by a \
permutation. For dyadic CA we have that\
\>", "Text"],

Cell[BoxData[
    \(other[r_] := 
      r\[LeftDoubleBracket]{1, 5, 3, 7, 2, 6, 4, 
          8}\[RightDoubleBracket]\)], "Input"],

Cell["\<\
that is, the elements 2nd and 5th are permuted and also elements 4th and 7th. \
More generally, for arbitrary b we have:\
\>", "Text"],

Cell[BoxData[
    \(symm[b_] := \(1 + FromDigits[Reverse[#], b] &\)\  /@ \ 
        IntegerDigits[Range[0, b\^3 - 1], b, 3]\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(symm[2]\)], "Input"],

Cell[BoxData[
    \({1, 5, 3, 7, 2, 6, 4, 8}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(symm[3]\)], "Input"],

Cell[BoxData[
    \({1, 10, 19, 4, 13, 22, 7, 16, 25, 2, 11, 20, 5, 14, 23, 8, 17, 26, 3, 
      12, 21, 6, 15, 24, 9, 18, 27}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(symm[4]\)], "Input"],

Cell[BoxData[
    \({1, 17, 33, 49, 5, 21, 37, 53, 9, 25, 41, 57, 13, 29, 45, 61, 2, 18, 
      34, 50, 6, 22, 38, 54, 10, 26, 42, 58, 14, 30, 46, 62, 3, 19, 35, 51, 
      7, 23, 39, 55, 11, 27, 43, 59, 15, 31, 47, 63, 4, 20, 36, 52, 8, 24, 
      40, 56, 12, 28, 44, 60, 16, 32, 48, 64}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(reflect[b_, r_] := 
      r\[LeftDoubleBracket]symm[b]\[RightDoubleBracket]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(reflect[2, Range[8]]\)], "Input"],

Cell[BoxData[
    \({1, 5, 3, 7, 2, 6, 4, 8}\)], "Output"]
}, Open  ]],

Cell["\<\
There are 68 out of 256 non-anihilable rules quiescent, proliferating, \
minimal rules.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(b = 2;\)\), "\[IndentingNewLine]", 
    \(\(allRules = 
        Select[IntegerDigits[Range[0, b\^\(b\^3 - 1\) - 1], b, 
            b\^3], #\[LeftDoubleBracket]{b, 1 + b, 
                  1 + b\^2}\[RightDoubleBracket] \[NotEqual] {0, 0, 
                0} &];\)\), "\[IndentingNewLine]", 
    \(\(s = symm[b];\)\), "\[IndentingNewLine]", 
    \(\(allRules = 
        Select[allRules, 
          FromDigits[#] \[LessEqual] 
              FromDigits[#\[LeftDoubleBracket]
                  s\[RightDoubleBracket]] &];\)\), "\[IndentingNewLine]", 
    \(\(g = 
        Map[showCA[b, cellularSpace[161], #, 40, 1, 40, 120, 2] &, 
          allRules];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Partition[g, 4]], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.13609 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0508593 0.238095 [
[ 0 0 0 0 ]
[ 1 2.13609 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 2.13609 L
0 2.13609 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0508593 0.245293 0.160234 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(122) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF000000
FFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF0000FF
FFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF000000FFFF
FFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF0000FFFFFF
FFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF000000FFFFFFFF
FFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF
00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF
00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0508593 0.488926 0.160234 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(123) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FF
FFFFFFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFF
FFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000
00000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
0000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000
00000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
0000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0508593 0.732558 0.160234 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(126) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
000000000000000000
FFFFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000
FFFF0000FFFF0000FF
FFFFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFF00000000FFFF
FFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFF0000FFFFFF
FFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000000000FFFFFFFF
FFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF00
00FFFF0000FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF
00000000FFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFF
FF0000FFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF000000000000
0000FFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF00
00FFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF00
00FFFF0000FF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
00000000FFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FF0000FFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
0000FFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00
00FFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFF0000FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0508593 0.97619 0.160234 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(127) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FF
FFFFFFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFF
FFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000
00000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
0000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000
00000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
0000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.171172 0.245293 0.280546 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(108) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FF
FFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FFFF
FFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF
FFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF
000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000
00FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.171172 0.488926 0.280546 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(109) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000000000000000000000000000FF000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000
FFFFFF00FF00FF00FF00FF00FF00FF00FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFF000000FF000000FF000000FF0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF000000FF
000000FF000000FFFF
FFFFFFFFFF00FF0000000000FF00FF000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF00FF00
00000000FF00FFFFFF
FFFFFFFFFFFF00000000000000FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF0000
0000000000FFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FF000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000FF00FF0000000000FF00FF0000000000
FF00FF0000000000FF00FF0000000000FF00FF0000000000FF00FF0000000000FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FF00000000000000FF000000000000
00FF00000000000000FF00000000000000FF00000000000000FF00000000000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF000000000000000000FF00FF00FF00
FF000000000000000000FF00FF00FF00FF000000000000000000FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000000000000000000000FF000000FF
0000000000000000000000FF000000FF0000000000000000000000FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000000000000000000000FF00FF00
000000000000000000000000FF00FF00000000000000000000000000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FF0000
00000000000000000000000000FF000000000000000000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF000000
0000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF00000000
000000000000000000000000000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000FF00FF0000000000
00000000000000000000000000000000FF00FF0000000000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FF000000000000
0000000000000000000000000000000000FF00000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00000000000000
000000000000000000000000000000000000FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000000000000000
00000000000000000000000000000000000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000000000000000
0000000000000000000000000000000000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF
000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000
FF00FF0000000000FF00FF0000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
00FF00000000000000FF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF000000000000000000FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
0000000000000000000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
000000000000000000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF0000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.171172 0.732558 0.280546 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(110) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FFFFFF00FFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FFFFFFFF000000FF00FF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF
FFFFFFFFFF00FFFFFF0000FF00FF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FFFFFF
FFFFFFFFFFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFFFFFF
FFFFFFFFFFFFFF00FFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FF00FF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF00000000FFFFFF0000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00000000FFFFFF0000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF00000000FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FFFFFF0000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00000000FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000
0000FFFFFF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
00FF00000000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF0000FF00FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF00000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF00FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.171172 0.97619 0.280546 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(111) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000
FFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF
FFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FFFFFF
FFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FFFFFFFF
FFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF
000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF00
0000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000
00FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000
FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
0000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.291484 0.245293 0.400859 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(104) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000
00FF000000FF000000
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFF00FFFFFF00FF
FFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFF000000FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FF000000FFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF
000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFF000000FF0000
00FFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFF000000FF000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000
00FFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.291484 0.488926 0.400859 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(105) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000FF0000FF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000FF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF
000000FF0000FF0000
FFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FF00FFFFFF00FF00FF
FFFFFFFF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
000000FF000000FFFF
FFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF00FFFFFF00FFFFFF
FFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00FF0000FFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00
FF00FFFFFF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFF000000FF000000FFFFFFFFFF
000000FF000000FF000000FFFFFFFFFF000000FF000000FFFFFFFFFF000000FF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF
FF00FFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FF0000FF00FF0000FFFFFFFFFFFFFF
FFFF0000FF00FF0000FFFFFFFFFFFFFFFFFF0000FF00FF0000FF0000FF00FF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF000000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFF00
FF00FFFFFF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FFFFFFFFFF
000000FF000000FF000000FFFFFFFFFF000000FF000000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFF
FF00FFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFF
FFFF0000FF00FF0000FFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00
FFFFFF00FF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF
FFFFFFFF000000FFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00
00FF0000FF00FF0000FF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000FF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.291484 0.732558 0.400859 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(106) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000000000FFFF00FFFFFF00FF0000FF0000FFFF00FFFF000000FFFF0000FFFFFF
00FF00FF000000FFFF000000FFFF00FFFF00000000FF00FFFF00FF000000FFFF00FF0000
FFFF00000000FF0000
FFFFFF00FFFF00FFFFFFFF00000000FF00FFFFFF00FF0000FF0000FFFF000000FFFFFFFF
FF0000FF00FFFF000000FFFF000000FF0000FFFF00FF00FF0000FF00FFFF000000FF00FF
FFFFFF00FFFF0000FF
FFFFFFFF000000FF00000000FFFF00FF00FF000000FF00FFFFFF00FF0000FFFF00000000
0000FFFFFF000000FFFF000000FFFF0000FFFFFFFF0000FF00FFFFFF000000FFFF0000FF
00000000FF0000FFFF
FFFFFFFFFF00FFFFFF00FFFF000000FF00FF00FFFF0000FF000000FF00FFFFFFFF00FFFF
00FFFFFFFFFF00FFFFFFFF00FFFFFFFF00FF00000000FFFFFF00000000FFFF000000FFFF
FF00FFFF0000FFFFFF
FFFFFFFFFFFF00000000FF0000FFFF0000FF00FF0000FFFFFF00FFFFFF0000000000FF00
00FF0000000000FF00000000FF00000000FF00FFFF00FF000000FFFF00FF0000FFFF0000
0000FF0000FFFFFFFF
FFFFFFFFFFFFFF00FFFF0000FFFFFFFF00FF00FF00FFFFFFFFFF00000000FFFF00FFFFFF
00FF00FFFF00FFFFFF00FFFF0000FFFF00FF00FF0000FF00FFFF000000FF00FFFFFFFF00
FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFF0000FF00FF0000000000FFFF00FF0000FF0000
00FF00FF0000FF000000FF0000FFFFFFFF0000FF00FFFFFF000000FFFF0000FF00000000
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FF00FF00FFFF00FFFFFFFF0000FFFFFF00
FFFFFF0000FFFFFF00FFFFFF00FF00000000FFFFFF00000000FFFF000000FFFFFF00FFFF
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000FF00FF00FF0000FF00000000FFFFFFFFFF
00000000FFFFFFFFFF00000000FF00FFFF00FF000000FFFF00FF0000FFFF00000000FF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFF0000FF00FFFFFF00FFFF0000000000
00FFFF00FF0000000000FFFF00FF00FF0000FF00FFFF000000FF00FFFFFFFF00FFFF0000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FF000000FFFFFF00000000FF0000FFFF00FF
FF000000FF00FFFF00FFFFFFFF0000FF00FFFFFF000000FFFF0000FF00000000FF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFF00000000FFFF00FF00FFFFFFFF00
0000FFFF0000FF0000FF00000000FFFFFF00000000FFFF000000FFFFFF00FFFF0000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00FF0000FFFF00FF0000FF00FF00000000
FFFF000000FFFFFF00FF00FFFF00FF000000FFFF00FF0000FFFF00000000FF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FF00FFFFFFFF0000FFFFFF0000FFFF00
FF0000FFFF00000000FF00FF0000FF00FFFF000000FF00FFFFFFFF00FFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF0000000000FFFFFFFFFF00FF0000
FF00FFFFFFFF00FFFF0000FF00FFFFFF000000FFFF0000FF00000000FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFF00FF0000000000FF00FF
FFFF0000000000FF0000FFFFFF00000000FFFF000000FFFFFF00FFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF0000FF00FFFF00FFFFFF00
000000FFFF00FFFFFF00FF000000FFFF00FF0000FFFF00000000FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF00FF00FF0000FF000000
FFFF00FF0000FF000000FF00FFFF000000FF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF00FF00FFFFFF00FF
FFFFFF0000FFFFFF00FFFFFF000000FFFF0000FF00000000FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF0000FF000000FF
00000000FFFFFFFFFF00000000FFFF000000FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF000000FFFFFF00FFFF
FF00FFFF000000000000FFFF00FF0000FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFF00000000FF00
0000FF0000FFFF00FFFF000000FF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF00FFFF0000
FFFF0000FFFFFFFF000000FFFF0000FF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF000000FF
FFFFFF00FF00000000FFFF000000FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFF00
00000000FF00FFFF00FF0000FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF000000
FFFF00FFFFFF000000FF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FFFF
000000FF000000FFFF0000FF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00
00FFFF0000FFFF000000FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00
FFFFFFFF00FF0000FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000
FF00000000FF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFF00FFFF0000FF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFF000000FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.291484 0.97619 0.400859 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(107) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF000000
FFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF
FFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF000000FFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FFFFFF
FFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF000000FFFFFFFF
FFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF00
0000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000
FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
0000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.411796 0.245293 0.521171 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(90) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFF00FFFFFF00FF
FFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFF00FF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.411796 0.488926 0.521171 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(91) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFF00FFFFFF00FF
FFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFF00FF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.411796 0.732558 0.521171 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(94) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.411796 0.97619 0.521171 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(95) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.532108 0.245293 0.641483 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(76) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.532108 0.488926 0.641483 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(77) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.532108 0.732558 0.641483 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(78) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.532108 0.97619 0.641483 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(79) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.652421 0.245293 0.761795 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(72) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFF00FFFFFF00FF
FFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFF00FF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.652421 0.488926 0.761795 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(73) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFF00FFFFFF00FF
FFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFF00FF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.652421 0.732558 0.761795 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(74) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFF00FFFFFF00FF
FFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFF00FF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.652421 0.97619 0.761795 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(75) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFF00FFFFFF00FF
FFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFF00FF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.772733 0.245293 0.882108 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.772733 0.488926 0.882108 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(61) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.772733 0.732558 0.882108 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(62) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFF00FF0000FF0000000000FF00FFFF0000FFFF0000
00000000FF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFFFFFFFF000000FFFF00FF0000FFFF00000000FFFFFF0000
FF0000FFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFF0000FFFFFF000000FFFFFF0000FF0000000000FF
FF00FFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00000000000000000000FFFFFFFF00FF0000000000FFFF00FF0000FFFF
FF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FF0000FF0000FFFFFFFFFF000000FF0000FFFFFF000000FFFFFF
FF00FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF000000FFFF00FFFFFFFFFFFF0000FFFF00FFFFFFFF0000FFFFFFFF
FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF0000FFFFFF0000000000000000FFFFFF000000000000FFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFF00FF0000FF00FF0000000000FF0000FF000000000000
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFFFF000000FFFF000000FF0000FFFF00FFFF0000FF00FF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFF0000FFFFFF00FF000000FFFFFF00000000FFFF000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000000000000000FFFFFFFF000000FF0000000000FF00FFFFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FF0000FF000000000000FF000000FF0000FFFF0000000000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF000000FFFF00FF0000FF000000FF000000FFFFFF00FF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF0000FFFFFF000000FFFF0000FFFF0000FFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFF00FF00000000FFFFFF00FFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFFFF000000FF00FFFFFFFF00000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFF0000FFFF000000000000FF00FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000000000000000FFFFFF0000FF0000FFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF0000FF00FF0000000000FFFF00FFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF00FFFF000000FF0000FFFFFF0000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00000000FF000000FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FF00FFFF0000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFF00000000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFF0000FF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000000000FFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FF00000000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF000000FF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF0000FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.772733 0.97619 0.882108 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(63) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
0000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.893045 0.245293 1.00242 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(56) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.893045 0.488926 1.00242 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(57) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.893045 0.732558 1.00242 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(58) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.893045 0.97619 1.00242 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(59) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
0000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.01336 0.245293 1.12273 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 1.01336 0.488926 1.12273 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 1.01336 0.732558 1.12273 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(54) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 1.01336 0.97619 1.12273 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(55) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.13367 0.245293 1.24304 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(44) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 1.13367 0.488926 1.24304 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 1.13367 0.732558 1.24304 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(46) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 1.13367 0.97619 1.24304 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(47) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.25398 0.245293 1.36336 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 1.25398 0.488926 1.36336 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 1.25398 0.732558 1.36336 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(42) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 1.25398 0.97619 1.36336 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(43) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.37429 0.245293 1.48367 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(36) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 1.37429 0.488926 1.48367 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(37) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 1.37429 0.732558 1.48367 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(38) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 1.37429 0.97619 1.48367 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(39) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.49461 0.245293 1.60398 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(32) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 1.49461 0.488926 1.60398 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(33) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 1.49461 0.732558 1.60398 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(34) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 1.49461 0.97619 1.60398 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(35) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.61492 0.245293 1.72429 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(28) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 1.61492 0.488926 1.72429 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(29) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 1.61492 0.732558 1.72429 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 1.61492 0.97619 1.72429 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(31) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.73523 0.245293 1.84461 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 1.73523 0.488926 1.84461 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 1.73523 0.732558 1.84461 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(26) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 1.73523 0.97619 1.84461 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(27) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.85554 0.245293 1.96492 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 1.85554 0.488926 1.96492 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 1.85554 0.732558 1.96492 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 1.85554 0.97619 1.96492 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.97586 0.245293 2.08523 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -5 0 ]
[.5 .50633 5 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 1.97586 0.488926 2.08523 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -5 0 ]
[.5 .50633 5 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 1.97586 0.732558 2.08523 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 1.97586 0.97619 2.08523 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{472.813, 1009.94},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007H0003lB000`400?l00000o`00003oo`3AcJWI
0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI
0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI
0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI
0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI
0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI
0=7=Z@006P3AcJT20?ooo`@0000000P0oooo0000003oool000000?ooo`000000oooo00000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool020000000oooo0000003o
ool000000?ooo`000000oooo0P0000002@3oool000000?ooo`000000oooo0000003oool000000?oo
o`02000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000P0oooo0000
003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`0000000P00000Y0=7=Z@80oooo
B000000Y0=7=Z@80oooo3P00000[0?ooo`l00000:@3AcJT20?ooodP000006`3AcJT001X0dLfY0`3o
ool3000000080?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00P000000?ooo`000000oooo0000003oool00000
0?ooo`80000000T0oooo0000003oool000000?ooo`000000oooo0000003oool00P0000002@3oool0
00000?ooo`000000oooo0000003oool000000?ooo`02000000080?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`050000003oool000000000003oool0:@3AcJT30?ooodH0000000<0oooo
0=7=Z@3AcJT09`3AcJT30?ooo`80000000<0oooo0000000000000P3oool200000080oooo00<00000
0?ooo`3oool0:`3oool200000080oooo0P0000020?ooo`030000003oool0oooo0080000000<0oooo
0=7=Z@3AcJT09`3AcJT30?ooodH0000000<0oooo0=7=Z@3AcJT06@3AcJT001X0dLfY103oool20000
00080?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00P000000?ooo`000000oooo0000003oool000000?ooo`80
000000T0oooo0000003oool000000?ooo`000000oooo0000003oool00P0000002@3oool000000?oo
o`000000oooo0000003oool000000?ooo`02000000080?ooo`000000oooo0000003oool000000?oo
o`0000020?ooo`<000000P3ooolY0=7=Z@@0ooooA00000020?ooobT0dLfY103oool3000000@0oooo
1000000^0?ooo`@000000`3oool400000080oooo:@3AcJT40?oood@000000P3ooolK0=7=Z@006P3A
cJT50?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool020000000oooo0000003oool000000?oo
o`000000oooo0P0000002@3oool000000?ooo`000000oooo0000003oool000000?ooo`0200000009
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000P0oooo0000003oool00000
0?ooo`000000oooo00000080oooo0P0000030?ooobT0dLfY1@3ooom2000000<0oooo:@3AcJT50?oo
o`030000003oool0oooo00@0oooo0P00000`0?ooo`8000001@3oool2000000<0oooo:@3AcJT50?oo
od8000000`3ooolK0=7=Z@006P3AcJT50?ooo`<0000000H0oooo0000003oool000000?ooo`000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00P000000?ooo`00
0000oooo0000003oool000000?ooo`80000000T0oooo0000003oool000000?ooo`000000oooo0000
003oool00P0000002@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000090?oo
o`000000oooo0000003oool000000?ooo`000000oooo00800000103ooolY0=7=Z@D0oooo@@000004
0?ooobT0dLfY1@3oool800000380oooo1`0000040?ooobT0dLfY1@3ooom1000000@0oooo6`3AcJT0
01X0dLfY1`3oool3000000040?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool020000000oooo0000003oool000000?ooo`000000oooo0P00
00002@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000090?ooo`000000oooo
0000003oool000000?ooo`000000oooo0080000000L0oooo0000003oool000000?ooo`000000oooo
008000001P3ooolY0=7=Z@L0oooo?@0000060?ooobT0dLfY1`3oool4000003H0oooo0`0000060?oo
obT0dLfY1`3ooolm000000H0oooo6`3AcJT001X0dLfY203oool2000000040?ooo`000000oooo0000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool020000000oooo
0000003oool000000?ooo`000000oooo0P0000002@3oool000000?ooo`000000oooo0000003oool0
00000?ooo`02000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000L0
oooo0000003oool000000?ooo`000000oooo008000001P3ooolY0=7=Z@P0oooo?00000060?ooobT0
dLfY203oool2000003P0oooo0P0000060?ooobT0dLfY203oooll000000H0oooo6`3AcJT001X0dLfY
2@3oool30000000=0?ooo`000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`080000003oool000000?ooo`000000oooo0000003oool2000000090?ooo`000000
oooo0000003oool000000?ooo`000000oooo0080000000T0oooo0000003oool000000?ooo`000000
oooo0000003oool00P0000001@3oool000000?ooo`000000oooo00<000001`3ooolY0=7=Z@T0oooo
>P0000070?ooobT0dLfY2@3ooolj000000L0oooo:@3AcJT90?ooocX000001`3ooolK0=7=Z@006P3A
cJT:0?ooo`80000000d0oooo0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00P000000?ooo`000000oooo0000003oool000000?ooo`80000000T0oooo0000
003oool000000?ooo`000000oooo0000003oool00P0000002@3oool000000?ooo`000000oooo0000
003oool000000?ooo`02000000050?ooo`000000oooo0000003oool00P0000080?ooobT0dLfY2P3o
oolh000000P0oooo:@3AcJT:0?ooo`8000000P3oool00`000000oooo0?ooo`0200000080oooo0P00
00020?ooo`030000003oool0oooo008000000P3oool200000080oooo00@000000?ooo`0000000000
0P3oool200000080oooo00<000000?ooo`3oool00P0000020?ooo`8000000P3oool00`000000oooo
0?ooo`0200000080oooo0P0000080?ooobT0dLfY2P3ooolh000000P0oooo6`3AcJT001X0dLfY2`3o
ool300000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02000
0000oooo0000003oool000000?ooo`000000oooo0P0000002@3oool000000?ooo`000000oooo0000
003oool000000?ooo`02000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080
000000<0oooo0000003oool00`0000090?ooobT0dLfY2`3ooolf000000T0oooo:@3AcJT;0?ooo`@0
00000`3oool4000000@0oooo0`0000040?ooo`<000000`3oool4000000@0oooo0`0000040?ooo`@0
00000`3oool4000000T0oooo:@3AcJT;0?ooocH000002@3ooolK0=7=Z@006P3AcJT<0?ooo`800000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`080000003oool0
00000?ooo`000000oooo0000003oool2000000090?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0080000000T0oooo0000003oool000000?ooo`000000oooo0000003oool00P0000000`3o
ool000000?ooo`02000000X0oooo:@3AcJT<0?oooc@000002P3ooolY0=7=Z@`0oooo0P0000050?oo
o`8000001@3oool2000000H0oooo0P0000040?ooo`8000001@3oool2000000H0oooo0P0000050?oo
o`8000002P3ooolY0=7=Z@`0oooo=000000:0?oooa/0dLfY000J0=7=Z@d0oooo0P0000002P3oool0
00000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`080000003oool000000?ooo`00
0000oooo0000003oool2000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080
000000T0oooo0000003oool000000?ooo`000000oooo0000003oool00P000000103oool000000000
0000000;0?ooobT0dLfY3@3ooolb000000/0oooo:@3AcJT=0?ooo`L000001`3oool8000000H0oooo
1`0000080?ooo`L000002`3ooolY0=7=Z@d0oooo<P00000;0?oooa/0dLfY000J0=7=Z@h0oooo00/0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`080000003oool0
00000?ooo`000000oooo0000003oool2000000090?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0080000000T0oooo0000003oool000000?ooo`000000oooo0000003oool00P0000000`3o
ool000000000000<0?ooobT0dLfY3P3oool`000000`0oooo:@3AcJT>0?ooo`030000003oool0oooo
008000002@3oool200000080oooo0P0000080?ooo`8000000P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00800000303ooolY0=7=Z@h0oooo<000000<0?oooa/0dLfY000J0=7=Z@l0
oooo0P000000203oool000000?ooo`000000oooo0000003oool000000P3oool020000000oooo0000
003oool000000?ooo`000000oooo0P0000002@3oool000000?ooo`000000oooo0000003oool00000
0?ooo`02000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo00@000003@3ooolY
0=7=Z@l0oooo;P00000=0?ooobT0dLfY3`3oool3000000/0oooo1000000:0?ooo`@000002`3oool3
000000d0oooo:@3AcJT?0?ooobh000003@3ooolK0=7=Z@006P3AcJT@0?ooo`<0000000H0oooo0000
003oool000000?ooo`0000020?ooo`080000003oool000000?ooo`000000oooo0000003oool20000
00090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000T0oooo0000003oool0
00000?ooo`000000oooo0000003oool00P00000?0?ooobT0dLfY403oool[000000l0oooo:@3AcJT@
0?ooo`l000003P3oool>000000l0oooo:@3AcJT@0?ooob/000003`3ooolK0=7=Z@006P3AcJTA0?oo
o`80000000H0oooo0000003oool000000?ooo`0000020?ooo`080000003oool000000?ooo`000000
oooo0000003oool2000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo00800000
00X0oooo0000003oool000000?ooo`000000oooo0000003oool00000403ooolY0=7=ZA40oooo:@00
000@0?ooobT0dLfY4@3oool200000080oooo0P0000020?ooo`030000003oool0oooo00800000403o
ool00`000000oooo0?ooo`0200000080oooo0P0000020?ooo`030000003oool0oooo00h0oooo:@3A
cJTA0?ooobT00000403ooolK0=7=Z@006P3AcJTB0?ooo`<0000000@0oooo0000003oool000000P3o
ool020000000oooo0000003oool000000?ooo`000000oooo0P0000002@3oool000000?ooo`000000
oooo0000003oool000000?ooo`02000000070?ooo`000000oooo0000003oool000000?ooo`030000
0100oooo:@3AcJTB0?ooobP00000403ooolY0=7=ZA80oooo100000040?ooo`<000004P3oool30000
00@0oooo1000000@0?ooobT0dLfY4P3ooolX00000100oooo6`3AcJT001X0dLfY4`3oool200000004
0?ooo`000000oooo00000080oooo00P000000?ooo`000000oooo0000003oool000000?ooo`800000
00T0oooo0000003oool000000?ooo`000000oooo0000003oool00P0000001`3oool000000?ooo`00
0000oooo0000003oool00P00000A0?ooobT0dLfY4`3ooolV00000140oooo:@3AcJTC0?ooo`800000
1@3oool2000001<0oooo0P0000060?ooo`8000004@3ooolY0=7=ZA<0oooo9P00000A0?oooa/0dLfY
000J0=7=ZA@0oooo0`000000303oool000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`80000000T0oooo0000003oool000000?ooo`000000oooo0000003oool00P0000001@3o
ool000000?ooo`000000oooo00<000004P3ooolY0=7=ZA@0oooo9000000B0?ooobT0dLfY503oool7
000001D0oooo2000000B0?ooobT0dLfY503ooolT00000180oooo6`3AcJT001X0dLfY5@3oool20000
000<0?ooo`000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0P0000002@3o
ool000000?ooo`000000oooo0000003oool000000?ooo`02000000050?ooo`000000oooo0000003o
ool00P00000C0?ooobT0dLfY5@3ooolR000001<0oooo:@3AcJTE0?ooo`8000000P3oool00`000000
oooo0?ooo`0E0?ooo`8000000P3oool2000001<0oooo:@3AcJTE0?ooob8000004`3ooolK0=7=Z@00
6P3AcJTF0?ooo`<000000P3oool020000000oooo0000003oool000000?ooo`000000oooo0P000000
2@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000030?ooo`000000oooo00<0
0000503ooolY0=7=ZAH0oooo8000000D0?ooobT0dLfY5P3oool4000001P0oooo1000000D0?ooobT0
dLfY5P3ooolP000001@0oooo6`3AcJT001X0dLfY5`3oool200000080oooo00P000000?ooo`000000
oooo0000003oool000000?ooo`80000000T0oooo0000003oool000000?ooo`000000oooo0000003o
ool00P0000000`3oool000000?ooo`02000001D0oooo:@3AcJTG0?oooah000005@3ooolY0=7=ZAL0
oooo0P00000J0?ooo`8000005@3ooolY0=7=ZAL0oooo7P00000E0?oooa/0dLfY000J0=7=ZAP0oooo
0P0000002@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000090?ooo`000000
oooo0000003oool000000?ooo`000000oooo0080000000@0oooo00000000000000005P3ooolY0=7=
ZAP0oooo7000000F0?ooobT0dLfY603ooolL000001H0oooo:@3AcJTH0?oooa`000005P3ooolK0=7=
Z@006P3AcJTJ0?ooo`80000000L0oooo0000003oool000000?ooo`000000oooo0080000000T0oooo
0000003oool000000?ooo`000000oooo0000003oool01000000H0?ooobT0dLfY6P3ooolH000001P0
oooo:@3AcJTJ0?ooo`<00000103oool3000000<0oooo100000040?ooo`<00000603ooolY0=7=ZAX0
oooo6000000H0?oooa/0dLfY000J0=7=ZAX0oooo0P0000001`3oool000000?ooo`000000oooo0000
003oool00P0000002@3oool000000?ooo`000000oooo0000003oool000000?ooo`03000001T0oooo
:@3AcJTJ0?oooaL000006@3ooolY0=7=ZAX0oooo0P0000060?ooo`800000103oool2000000D0oooo
0P00000I0?ooobT0dLfY6P3ooolG000001T0oooo6`3AcJT001X0dLfY6`3oool3000000050?ooo`00
0000oooo0000003oool00P0000002@3oool000000?ooo`000000oooo0000003oool000000?ooo`02
000001X0oooo:@3AcJTK0?oooaD000006P3ooolY0=7=ZA/0oooo200000060?ooo`L000006P3ooolY
0=7=ZA/0oooo5@00000J0?oooa/0dLfY000J0=7=ZA`0oooo0P0000001@3oool000000?ooo`000000
oooo0080000000X0oooo0000003oool000000?ooo`000000oooo0000003oool000006`3ooolY0=7=
ZA`0oooo4`00000K0?ooobT0dLfY703oool200000080oooo0P0000080?ooo`8000000P3oool00`00
0000oooo0?ooo`0I0?ooobT0dLfY703ooolC000001/0oooo6`3AcJT001X0dLfY7@3oool300000003
0?ooo`000000oooo0080000000L0oooo0000003oool000000?ooo`000000oooo00<000006`3ooolY
0=7=ZAd0oooo4P00000K0?ooobT0dLfY7@3oool4000000X0oooo1000000K0?ooobT0dLfY7@3ooolB
000001/0oooo6`3AcJT001X0dLfY7P3oool2000000030?ooo`000000oooo0080000000L0oooo0000
003oool000000?ooo`000000oooo00800000703ooolY0=7=ZAh0oooo4000000L0?ooobT0dLfY7P3o
ool2000000`0oooo0P00000L0?ooobT0dLfY7P3oool@000001`0oooo6`3AcJT001X0dLfY7`3oool3
000000080?ooo`00000000000?ooo`000000oooo0000003oool3000001d0oooo:@3AcJTO0?ooo`h0
00007@3ooolY0=7=ZAl0oooo3P00000M0?ooobT0dLfY7`3oool>000001d0oooo6`3AcJT001X0dLfY
803oool2000000080?ooo`00000000000?ooo`000000oooo0000003oool2000001h0oooo:@3AcJTP
0?ooo``000007P3ooolY0=7=ZB00oooo0P0000020?ooo`040000003oool0000000000080oooo0P00
000N0?ooobT0dLfY803oool<000001h0oooo6`3AcJT001X0dLfY8@3oool4000000030?ooo`000000
oooo00<000007`3ooolY0=7=ZB40oooo2P00000O0?ooobT0dLfY8@3oool3000000<0oooo1000000O
0?ooobT0dLfY8@3oool:000001l0oooo6`3AcJT001X0dLfY8`3oool2000000040?ooo`0000000000
00000240oooo:@3AcJTS0?ooo`H000008@3ooolY0=7=ZB<0oooo1P00000Q0?ooobT0dLfY8`3oool6
00000240oooo6`3AcJT001X0dLfY903oool010000000oooo00000000000R0?ooobT0dLfY903oool4
00000280oooo:@3AcJTT0?ooo`040000003oool0000000000280oooo:@3AcJTT0?ooo`@000008P3o
oolK0=7=Z@006P3AcJTT0?ooo`<000008`3ooolY0=7=ZB@0oooo0`00000S0?ooobT0dLfY903oool3
000002<0oooo:@3AcJTT0?ooo`<000008`3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo
0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo
0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo6`3AcJT00?l0dLfYf@3AcJT00?l0dLfY
f@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT003L0dLfY
1D0000000`3AcJU00000@0000002@0000080dLfY1400001S0=7=Z@E0000000<0dLfY@00004000000
0T0000030=7=Z@900000I03AcJT5@00000030=7=ZD0000100000009000000P3AcJT3@00006@0dLfY
1D0000000`3AcJU00000@0000002@00000@0dLfY00=000000=7=Z@3AcJT0=`3AcJT003T0dLfY00E0
00000=7=Z@3AcJT0dLfY@00000050=7=Z@03@000003AcJT0dLfY06H0dLfY00E000000=7=Z@3AcJT0
dLfY@00000050=7=Z@04@000003AcJT0dLfY@00006D0dLfY00E000000=7=Z@3AcJT0dLfY@0000005
0=7=Z@04@000003AcJT0dLfY@00006D0dLfY00E000000=7=Z@3AcJT0dLfY@00000070=7=Z@03@000
003AcJT0dLfY03L0dLfY000i0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00`3A
cJT00d000000dLfY0=7=Z@1U0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0103A
cJT00d000000dLfY0=7=Z@1T0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3A
cJT014000000dLfY0=7=ZD00001U0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0
103AcJT00d000000dLfY0=7=Z@0g0=7=Z@00>@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003A
cJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0I03AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003A
cJT0dLfY00@0dLfY00=000000=7=Z@3AcJT0H`3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003A
cJT0dLfY0=7=Z@=00000IP3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00@0dLfY
00=000000=7=Z@3AcJT0=P3AcJT003T0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000
003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0H`3AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@1S0=7=Z@05@000003AcJT0
dLfY0=7=ZD0000000P3AcJT01D000000dLfY0=7=Z@3AcJU0000006L0dLfY00E000000=7=Z@3AcJT0
dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0=P3AcJT003P0
dLfY0T0000040=7=Z@900000103AcJT2@00006D0dLfY0T0000040=7=Z@900000103AcJT2@00006D0
dLfY0T0000040=7=Z@900000103AcJT3@00006@0dLfY0T0000040=7=Z@9000000`3AcJT4@00003P0
dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0
dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY000J0=7=Z@80
oooo1P0000001@3oool00000000000000000oooo0080000000D0oooo00000000000000000?ooo`03
000000040?ooo`00000000000?ooo`<0000000D0oooo00000000000000000?ooo`02000000050?oo
o`00000000000000003oool00`000000103oool000000000003oool3000000050?ooo`0000000000
0000003oool00P0000001@3oool00000000000000000oooo00<0000000@0oooo000000000000oooo
0`00000Y0=7=Z@80oooo3@0000000`3oool000000000000Y000000030?ooo`000000000000`00000
:@3AcJT20?ooo`<000000`3oool2000000030?ooo`000000oooo00<000000`3oool2000000030?oo
o`000000oooo00<000000`3oool2000000030?ooo`000000oooo00<0000000@0oooo000000000000
oooo0P0000000`3oool0000000000002000000040?ooo`00000000000?ooo`80000000<0oooo0000
000000000P000000103oool000000000003oool2000000030?ooo`000000oooo0080000000<0oooo
000000000000:@3AcJT20?ooo`H0000000D0oooo00000000000000000?ooo`02000000050?ooo`00
000000000000003oool00`000000103oool000000000003oool3000000050?ooo`00000000000000
003oool00P0000001@3oool00000000000000000oooo00<0000000@0oooo000000000000oooo0`00
00001@3oool00000000000000000oooo0080000000D0oooo00000000000000000?ooo`0300000004
0?ooo`00000000000?ooo`<000006`3AcJT001X0dLfY0`3oool010000000oooo0?ooo`0000030?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
00001P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`060000003oool0oooo0?ooo`000000oooo:@3AcJT30?ooo`0;0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool0;P0000001`3oool000000?ooo`000000oooo0000003o
ool00P0000001@3oool000000?ooo`000000oooo02T0dLfY0`3oool00`000000oooo000000030000
00<0oooo0P0000020?ooo`@000000`3oool200000080oooo100000030?ooo`<0000000@0oooo0000
00000000oooo0P0000001P3oool000000000003oool000000?ooo`80000000@0oooo000000000000
oooo0P0000000`3oool000000?ooo`02000000040?ooo`00000000000?ooo`@0000000@0oooo0000
00000000oooo:@3AcJT30?ooo`050000003oool000000000003oool00`0000000`3oool000000000
0004000000050?ooo`00000000000000003oool01P0000001@3oool00000000000000000oooo0080
000000D0oooo00000000000000000?ooo`03000000040?ooo`00000000000?ooo`<0000000D0oooo
00000000000000000?ooo`02000000050?ooo`00000000000000003oool00`000000103oool00000
0000003oool3000000030?ooo`3AcJT0dLfY01T0dLfY000J0=7=Z@@0oooo0P0000001@3oool00000
000000000000oooo00<0000000@0oooo000000000000oooo0`0000001@3oool00000000000000000
oooo0080000000D0oooo00000000000000000?ooo`06000000050?ooo`00000000000000003oool0
1P0000001@3oool00000000000000000oooo00H0000000D0oooo00000000000000000?ooo`020000
00040?ooo`000000000000000080oooo:@3AcJT40?ooo`80000000D0oooo00000000000000000?oo
o`03000000030?ooo`000000000002`0000000D0oooo00000000000000000?ooo`02000000040?oo
o`000000000000000080oooo:@3AcJT40?ooo`80000000<0oooo0000003oool0100000020?ooo`80
000000<0oooo0000003oool0100000020?ooo`80000000<0oooo0000003oool0100000020?ooo`80
000000@0oooo000000000000oooo0P0000000`3oool000000?ooo`02000000040?ooo`0000000000
0?ooo`80000000<0oooo0000003oool00P000000103oool000000000003oool2000000030?ooo`00
0000oooo008000000P3ooolY0=7=Z@@0oooo0P0000001@3oool00000000000000000oooo00<00000
00@0oooo000000000000oooo0`0000001@3oool00000000000000000oooo0080000000D0oooo0000
0000000000000?ooo`06000000050?ooo`00000000000000003oool01P0000001@3oool000000000
00000000oooo00H0000000D0oooo00000000000000000?ooo`02000000040?ooo`00000000000000
0080oooo6`3AcJT001X0dLfY203oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000030?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00@0
00000?ooo`3oool000000`3ooolY0=7=Z@H0oooo1@0000000`3oool000000?ooo`0`000000030?oo
o`000000oooo00@0000000<0oooo0000003oool00P3ooolY0=7=Z@P0oooo0P0000000`3oool00000
0?ooo`03000000<0oooo0P0000000`3oool000000?ooo`03000000<0oooo0P0000000`3oool00000
0?ooo`03000000040?ooo`00000000000?ooo`80000000<0oooo0000000000000P000000103oool0
00000000003oool2000000030?ooo`00000000000080000000@0oooo000000000000oooo0P000000
0`3oool000000?ooo`02000000<0oooo:@3AcJT60?ooo`<0000000D0oooo00000000000000000?oo
o`02000000050?ooo`00000000000000003oool00`000000103oool000000000003oool300000005
0?ooo`00000000000000003oool00P0000001@3oool00000000000000000oooo00<0000000@0oooo
000000000000oooo0`0000001@3oool00000000000000000oooo0080000000D0oooo000000000000
00000?ooo`06000000<0oooo6`3AcJT001X0dLfY1@3oool3000000050?ooo`00000000000000003o
ool00P0000001@3oool00000000000000000oooo00<0000000@0oooo000000000000oooo0`000000
1@3oool00000000000000000oooo0080000000D0oooo00000000000000000?ooo`03000000040?oo
o`00000000000?ooo`<0000000D0oooo00000000000000000?ooo`02000000050?ooo`0000000000
0000003oool00`0000000`3oool00000000000040?ooobT0dLfY1@3oool7000000030?ooo`000000
00000300000000<0oooo000000000000100000040?ooobT0dLfY1@3oool4000000<0oooo0P000002
0?ooo`@000000`3oool200000080oooo100000030?ooo`<0000000@0oooo000000000000oooo0P00
00001P3oool000000000003oool000000?ooo`80000000@0oooo000000000000oooo0P0000000`3o
ool000000?ooo`02000000040?ooo`00000000000?ooo`@00000103ooolY0=7=Z@D0oooo0`000000
1@3oool00000000000000000oooo0080000000D0oooo00000000000000000?ooo`03000000040?oo
o`00000000000?ooo`<0000000D0oooo00000000000000000?ooo`02000000050?ooo`0000000000
0000003oool00`000000103oool000000000003oool3000000050?ooo`00000000000000003oool0
0P0000001@3oool00000000000000000oooo00<0000000<0oooo000000000000103ooolK0=7=Z@00
6P3AcJT70?ooo`<0000000D0oooo00000000000000000?ooo`02000000050?ooo`00000000000000
003oool00`000000103oool000000000003oool3000000030?ooo`000000000000@0000000D0oooo
00000000000000000?ooo`06000000050?ooo`00000000000000003oool01P0000001@3oool00000
000000000000oooo008000001P3ooolY0=7=Z@L0oooo0`0000000`3oool000000000000d00000003
0?ooo`000000000000H0oooo:@3AcJT70?ooo`<0000000<0oooo0000003oool00`0000030?ooo`80
000000<0oooo0000003oool00`0000030?ooo`80000000<0oooo0000003oool00`000000103oool0
00000000003oool2000000030?ooo`00000000000080000000@0oooo000000000000oooo0P000000
0`3oool0000000000002000000040?ooo`00000000000?ooo`80000000<0oooo0000003oool01@3o
oolY0=7=Z@L0oooo0`0000001@3oool00000000000000000oooo0080000000D0oooo000000000000
00000?ooo`03000000040?ooo`00000000000?ooo`<0000000<0oooo000000000000100000001@3o
ool00000000000000000oooo00H0000000D0oooo00000000000000000?ooo`06000000050?ooo`00
000000000000003oool00P0000060?oooa/0dLfY000J0=7=Z@P0oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000030?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00@0
00000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00@0oooo:@3AcJT80?ooo`030000003oool00000
03L0000000<0oooo0000003oool01@3ooolY0=7=Z@P0oooo00@000000?ooo`3oool0oooo0P000002
0?ooo`@000000`3oool200000080oooo100000030?ooo`<0000000@0oooo000000000000oooo0P00
00001P3oool000000000003oool000000?ooo`80000000@0oooo000000000000oooo0P0000000`3o
ool000000?ooo`02000000040?ooo`00000000000?ooo`8000001P3ooolY0=7=Z@P0oooo00<00000
0?ooo`0000000P000000103oool000000000003oool3000000050?ooo`00000000000000003oool0
0P0000001@3oool00000000000000000oooo00<0000000@0oooo000000000000oooo0`0000001@3o
ool00000000000000000oooo0080000000D0oooo00000000000000000?ooo`03000000040?ooo`00
000000000?ooo`<0000000@0oooo00000000000000001P3ooolK0=7=Z@006P3AcJT90?ooo`<00000
00@0oooo000000000000oooo0`0000001@3oool00000000000000000oooo0080000000D0oooo0000
0000000000000?ooo`03000000040?ooo`00000000000?ooo`<0000000D0oooo0000000000000000
0?ooo`02000000050?ooo`00000000000000003oool00`000000103oool000000000003oool30000
00040?ooo`0000000000000000L0oooo:@3AcJT90?ooocX000001`3ooolY0=7=Z@T0oooo10000002
0?ooo`80000000<0oooo0000003oool0100000020?ooo`80000000<0oooo0000003oool010000002
0?ooo`80000000@0oooo000000000000oooo0P0000000`3oool000000?ooo`02000000040?ooo`00
000000000?ooo`80000000<0oooo0000003oool00P000000103oool000000000003oool2000000L0
oooo:@3AcJT90?ooo`<0000000@0oooo000000000000oooo0`0000001@3oool00000000000000000
oooo0080000000D0oooo00000000000000000?ooo`03000000040?ooo`00000000000?ooo`<00000
00D0oooo00000000000000000?ooo`02000000050?ooo`00000000000000003oool00`000000103o
ool000000000003oool3000000040?ooo`0000000000000000L0oooo6`3AcJT001X0dLfY2P3oool0
1@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool00000
00H0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`000000203o
oolY0=7=Z@X0oooo00@000000?ooo`000000oooo0P0000002@3oool000000?ooo`000000oooo0000
003oool000000?ooo`02000000080?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`000000203o
oolY0=7=Z@X0oooo00<000000?ooo`3oool00`0000030?ooo`80000000<0oooo0000003oool00`00
00030?ooo`80000000<0oooo0000003oool00`000000103oool000000000003oool2000000030?oo
o`00000000000080000000@0oooo000000000000oooo0P0000000`3oool000000000000200000004
0?ooo`00000000000?ooo`800000203ooolY0=7=Z@X0oooo00<000000?ooo`0000001@0000001@3o
ool00000000000000000oooo00H0000000D0oooo00000000000000000?ooo`02000000050?ooo`00
000000000000003oool00`000000103oool000000000003oool3000000050?ooo`00000000000000
003oool00P0000001@3oool00000000000000000oooo00<00000203ooolK0=7=Z@006P3AcJT;0?oo
o`<0000000@0oooo000000000000oooo0`0000001@3oool00000000000000000oooo0080000000D0
oooo00000000000000000?ooo`06000000050?ooo`00000000000000003oool01P0000001@3oool0
0000000000000000oooo00H0000000@0oooo00000000000000002@3ooolY0=7=Z@/0oooo0`000000
103oool000000000003oool3000000050?ooo`00000000000000003oool00P0000001@3oool00000
000000000000oooo00H0000000D0oooo00000000000000000?ooo`06000000050?ooo`0000000000
0000003oool01P000000103oool000000000000000090?ooobT0dLfY2`3oool300000080oooo1000
00030?ooo`8000000P3oool4000000<0oooo0`000000103oool000000000003oool2000000060?oo
o`00000000000?ooo`000000oooo0P000000103oool000000000003oool2000000030?ooo`000000
oooo0080000000<0oooo0000000000002@3ooolY0=7=Z@/0oooo0`000000103oool000000000003o
ool3000000050?ooo`00000000000000003oool00P0000001@3oool00000000000000000oooo00H0
000000D0oooo00000000000000000?ooo`06000000050?ooo`00000000000000003oool01P000000
103oool000000000000000090?oooa/0dLfY000J0=7=Z@`0oooo00@000000?ooo`3oool000000`3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`04
0000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00P0oooo
:@3AcJT<0?ooo`030000003oool0000000<0000000<0oooo0000003oool01P0000000`3oool00000
00000003000000030?ooo`000000oooo00@0000000<0oooo0000003oool0100000000`3oool00000
0?ooo`05000000030?ooo`000000oooo00@0000000<0oooo0000003oool02@3ooolY0=7=Z@`0oooo
00<000000?ooo`3oool00P0000000`3oool000000?ooo`0400000080oooo0P0000000`3oool00000
0?ooo`0400000080oooo0P000000103oool000000000003oool2000000030?ooo`000000oooo0080
000000@0oooo000000000000oooo0P0000000`3oool000000?ooo`02000000030?ooo`0000000000
00X0oooo:@3AcJT<0?ooo`050000003oool000000000003oool00`0000001@3oool0000000000000
0000oooo0080000000D0oooo00000000000000000?ooo`03000000040?ooo`00000000000?ooo`<0
000000D0oooo00000000000000000?ooo`02000000050?ooo`00000000000000003oool00`000000
103oool000000000003oool3000000X0oooo6`3AcJT001X0dLfY3@3oool2000000050?ooo`000000
00000000003oool00`000000103oool000000000003oool3000000050?ooo`00000000000000003o
ool00P0000001@3oool00000000000000000oooo00<0000000@0oooo000000000000oooo0`000000
1@3oool00000000000000000oooo0080000000@0oooo00000000000000002`3ooolY0=7=Z@d0oooo
1P0000000`3oool0000000000004000000030?ooo`000000000000D0000000<0oooo000000000000
100000000`3oool0000000000004000000030?ooo`000000000000D0000000<0oooo000000000000
1000000;0?ooobT0dLfY3@3oool3000000<0oooo0P0000000`3oool000000?ooo`03000000<0oooo
0P0000000`3oool000000?ooo`03000000040?ooo`00000000000?ooo`80000000<0oooo00000000
00000P000000103oool000000000003oool2000000030?ooo`00000000000080000000<0oooo0000
000000002`3ooolY0=7=Z@d0oooo0P0000001@3oool00000000000000000oooo00<0000000@0oooo
000000000000oooo0`0000001@3oool00000000000000000oooo0080000000D0oooo000000000000
00000?ooo`03000000040?ooo`00000000000?ooo`<0000000D0oooo00000000000000000?ooo`02
000000040?ooo`0000000000000000/0oooo6`3AcJT001X0dLfY3P3oool010000000oooo0?ooo`00
00030?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000H0
oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`0:0?ooobT0dLfY3P3oool2000000030?ooo`000000oooo00P0000000L0oooo
0000003oool000000?ooo`000000oooo00P0000000@0oooo0000003oool000000P3oool900000080
oooo00<000000?ooo`000000303ooolY0=7=Z@h0oooo00<000000?ooo`0000000`0000030?ooo`80
00000P3oool4000000<0oooo0`000000103oool000000000003oool2000000060?ooo`0000000000
0?ooo`000000oooo0P000000103oool000000000003oool2000000030?ooo`000000oooo00800000
303ooolY0=7=Z@h0oooo100000001@3oool00000000000000000oooo00H0000000D0oooo00000000
000000000?ooo`02000000050?ooo`00000000000000003oool00`000000103oool000000000003o
ool3000000050?ooo`00000000000000003oool00P000000103oool0000000000000000<0?oooa/0
dLfY000J0=7=Z@l0oooo0P0000001@3oool00000000000000000oooo00<0000000@0oooo00000000
0000oooo0`0000000`3oool0000000000004000000050?ooo`00000000000000003oool01P000000
1@3oool00000000000000000oooo00H000003@3ooolY0=7=Z@l0oooo0P0000000`3oool000000000
0008000000050?ooo`00000000000000003oool02P0000000`3oool000000000000?000000d0oooo
:@3AcJT?0?ooo`80000000<0oooo0000003oool0100000020?ooo`80000000<0oooo0000003oool0
100000020?ooo`80000000@0oooo000000000000oooo0P0000000`3oool000000?ooo`0200000004
0?ooo`00000000000?ooo`80000000<0oooo0000003oool00P00000=0?ooobT0dLfY3`3oool20000
00050?ooo`00000000000000003oool00`000000103oool000000000003oool3000000030?ooo`00
0000000000@0000000D0oooo00000000000000000?ooo`06000000050?ooo`00000000000000003o
ool01P00000=0?oooa/0dLfY000J0=7=ZA00oooo0`0000001@3oool00000000000000000oooo0080
000000D0oooo00000000000000000?ooo`03000000040?ooo`00000000000?ooo`<0000000D0oooo
00000000000000000?ooo`02000000050?ooo`00000000000000003oool00`0000000`3oool00000
0000000?0?ooobT0dLfY403oool>000000030?ooo`000000000000`0000000<0oooo000000000000
2`00000?0?ooobT0dLfY403oool4000000<0oooo0P0000020?ooo`@000000`3oool3000000040?oo
o`00000000000?ooo`80000000H0oooo000000000000oooo0000003oool2000000040?ooo`000000
00000?ooo`80000000<0oooo0000003oool03P3ooolY0=7=ZA00oooo0`0000001@3oool000000000
00000000oooo0080000000D0oooo00000000000000000?ooo`03000000040?ooo`00000000000?oo
o`<0000000D0oooo00000000000000000?ooo`02000000050?ooo`00000000000000003oool00`00
00000`3oool000000000000?0?oooa/0dLfY000J0=7=ZA40oooo00D000000?ooo`3oool0oooo0000
00030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool01@000000oooo
0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo0000000C0?ooobT0dLfY4@3oool02000
0000oooo0000003oool000000?ooo`000000oooo0P0000000`3oool000000?ooo`0@00000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000004@3ooolY0=7=ZA40oooo00<00000
0?ooo`3oool0100000020?ooo`80000000<0oooo0000003oool0100000020?ooo`80000000@0oooo
000000000000oooo0P0000000`3oool000000?ooo`02000000040?ooo`00000000000?ooo`800000
00<0oooo0000003oool03`3ooolY0=7=ZA40oooo00<000000?ooo`0000000P0000000`3oool00000
00000004000000050?ooo`00000000000000003oool00P0000001@3oool00000000000000000oooo
00<0000000@0oooo000000000000oooo0`0000001@3oool00000000000000000oooo00800000403o
oolK0=7=Z@006P3AcJTB0?ooo`<0000000D0oooo00000000000000000?ooo`02000000050?ooo`00
000000000000003oool01P0000001@3oool00000000000000000oooo00H0000000D0oooo00000000
000000000?ooo`0300000100oooo:@3AcJTB0?ooo`<0000000D0oooo00000000000000000?ooo`02
000000030?ooo`000000000001<0000000D0oooo00000000000000000?ooo`0300000100oooo:@3A
cJTB0?ooo`<0000000<0oooo0000003oool00`0000030?ooo`80000000<0oooo0000003oool00`00
0000103oool000000000003oool2000000030?ooo`00000000000080000000@0oooo000000000000
oooo0P0000000`3oool000000000000@0?ooobT0dLfY4P3oool3000000050?ooo`00000000000000
003oool00P0000001@3oool00000000000000000oooo00H0000000D0oooo00000000000000000?oo
o`06000000050?ooo`00000000000000003oool00`00000@0?oooa/0dLfY000J0=7=ZA<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000
oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool03`3ooolY0=7=ZA<0oooo00<000000?ooo`0000001@00
00000`3oool000000000000A000000030?ooo`000000oooo00D0000000<0oooo0000003oool0403o
oolY0=7=ZA<0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`@000000`3oool3000000040?oo
o`00000000000?ooo`80000000H0oooo000000000000oooo0000003oool2000000040?ooo`000000
00000?ooo`8000004@3ooolY0=7=ZA<0oooo00<000000?ooo`0000000P000000103oool000000000
003oool3000000050?ooo`00000000000000003oool00P0000001@3oool00000000000000000oooo
00<0000000@0oooo000000000000oooo0`000000103oool0000000000000000A0?oooa/0dLfY000J
0=7=ZA@0oooo0`000000103oool000000000003oool3000000050?ooo`00000000000000003oool0
0P0000001@3oool00000000000000000oooo00<0000000@0oooo000000000000oooo0`000000103o
ool0000000000000000B0?ooobT0dLfY503oool6000000030?ooo`000000000001<0000000<0oooo
0000000000001@00000B0?ooobT0dLfY503oool400000080oooo0P0000000`3oool000000?ooo`04
00000080oooo0P000000103oool000000000003oool2000000030?ooo`000000oooo0080000000@0
oooo000000000000oooo0P00000B0?ooobT0dLfY503oool3000000040?ooo`00000000000?ooo`<0
000000D0oooo00000000000000000?ooo`02000000050?ooo`00000000000000003oool00`000000
103oool000000000003oool3000000040?ooo`000000000000000180oooo6`3AcJT001X0dLfY5@3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000060?ooo`05
0000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000001<0oooo:@3AcJTE
0?ooo`040000003oool000000?oooaP0000000H0oooo0000003oool000000?ooo`00000C0?ooobT0
dLfY5@3oool00`000000oooo0?ooo`03000000<0oooo0P0000000`3oool000000?ooo`0300000004
0?ooo`00000000000?ooo`80000000<0oooo0000000000000P000000103oool000000000003oool2
000001<0oooo:@3AcJTE0?ooo`030000003oool0000000D0000000D0oooo00000000000000000?oo
o`02000000050?ooo`00000000000000003oool00`000000103oool000000000003oool300000004
0?ooo`0000000000000001<0oooo6`3AcJT001X0dLfY5P3oool3000000040?ooo`00000000000?oo
o`<0000000<0oooo000000000000100000001@3oool00000000000000000oooo00H0000000@0oooo
0000000000000000503ooolY0=7=ZAH0oooo0`0000000`3oool000000000000F000000040?ooo`00
00000000000001@0oooo:@3AcJTF0?ooo`<000000P3oool4000000<0oooo0`000000103oool00000
0000003oool2000000060?ooo`00000000000?ooo`000000oooo0P0000000`3oool000000000000D
0?ooobT0dLfY5P3oool3000000040?ooo`00000000000?ooo`<0000000<0oooo0000000000001000
00001@3oool00000000000000000oooo00H0000000@0oooo0000000000000000503ooolK0=7=Z@00
6P3AcJTG0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo01<0oooo:@3AcJTG0?ooo`030000003oool0000001T0000000<0oooo0000003oool0503o
oolY0=7=ZAL0oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`0400000080oooo0P00
0000103oool000000000003oool2000000030?ooo`000000oooo0080000000<0oooo000000000000
5@3ooolY0=7=ZAL0oooo00D000000?ooo`00000000000?ooo`03000000050?ooo`00000000000000
003oool00P0000001@3oool00000000000000000oooo00<0000000@0oooo000000000000oooo0`00
000E0?oooa/0dLfY000J0=7=ZAP0oooo0P0000001@3oool00000000000000000oooo00<0000000@0
oooo000000000000oooo0`0000001@3oool00000000000000000oooo0080000000@0oooo00000000
000000005P3ooolY0=7=ZAP0oooo7000000F0?ooobT0dLfY603oool3000000<0oooo0P0000000`3o
ool000000?ooo`03000000040?ooo`00000000000?ooo`80000000<0oooo0000000000000P000000
0`3oool000000000000F0?ooobT0dLfY603oool2000000050?ooo`00000000000000003oool00`00
0000103oool000000000003oool3000000050?ooo`00000000000000003oool00P000000103oool0
000000000000000F0?oooa/0dLfY000J0=7=ZAX0oooo0P0000001@3oool00000000000000000oooo
00H0000000D0oooo00000000000000000?ooo`06000001P0oooo:@3AcJTJ0?ooo`80000000D0oooo
00000000000000000?ooo`06000000050?ooo`00000000000000003oool01P00000H0?ooobT0dLfY
6P3oool2000000030?ooo`000000oooo00@000000P3oool2000000040?ooo`00000000000?ooo`80
000000<0oooo0000003oool00P00000H0?ooobT0dLfY6P3oool2000000050?ooo`00000000000000
003oool01P0000001@3oool00000000000000000oooo00H00000603ooolK0=7=Z@006P3AcJTJ0?oo
o`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0G0?ooobT0dLfY6P3oool00`000000oooo
00000004000000030?ooo`000000oooo00@0000000<0oooo0000003oool0100000000`3oool00000
0?ooo`0H0?ooobT0dLfY6P3oool010000000oooo0?ooo`3oool2000000030?ooo`000000oooo00<0
000000@0oooo000000000000oooo0P0000000`3oool0000000000002000001T0oooo:@3AcJTJ0?oo
o`030000003oool000000080000000D0oooo00000000000000000?ooo`02000000050?ooo`000000
00000000003oool00`0000000`3oool000000000000I0?oooa/0dLfY000J0=7=ZA/0oooo0`000000
1@3oool00000000000000000oooo0080000000D0oooo00000000000000000?ooo`03000000030?oo
o`000000000001X0oooo:@3AcJTK0?ooo`L0000000<0oooo000000000000100000000`3oool00000
00000004000001X0oooo:@3AcJTK0?ooo`@000000`3oool3000000040?ooo`00000000000?ooo`80
000000D0oooo000000000000oooo0000000J0?ooobT0dLfY6`3oool3000000050?ooo`0000000000
0000003oool00P0000001@3oool00000000000000000oooo00<0000000<0oooo0000000000006P3o
oolK0=7=Z@006P3AcJTL0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?oo
o`3oool0000001h0oooo:@3AcJTL0?ooo`060000003oool000000?ooo`000000oooo20000000103o
ool000000?ooo`00000L0?ooobT0dLfY703oool00`000000oooo0?ooo`0400000080oooo0P000000
103oool000000000003oool2000000030?ooo`000000oooo01X0oooo:@3AcJTL0?ooo`030000003o
ool000000080000000@0oooo000000000000oooo0`0000001@3oool00000000000000000oooo0080
00006`3ooolK0=7=Z@006P3AcJTM0?ooo`<0000000<0oooo000000000000100000001@3oool00000
000000000000oooo00<000006`3ooolY0=7=ZAd0oooo0`0000000`3oool000000000000800000004
0?ooo`0000000000000001/0oooo:@3AcJTM0?ooo`<0000000<0oooo0000003oool00`000000103o
ool000000000003oool2000000030?ooo`000000000001/0oooo:@3AcJTM0?ooo`<0000000<0oooo
000000000000100000001@3oool00000000000000000oooo00<000006`3ooolK0=7=Z@006P3AcJTN
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool06P3ooolY0=7=ZAh0oooo00<000000?ooo`0000002`0000000`3oool00000
0?ooo`0K0?ooobT0dLfY7P3oool010000000oooo0?ooo`3oool3000000040?ooo`00000000000?oo
o`80000000<0oooo000000000000703ooolY0=7=ZAh0oooo00<000000?ooo`0000000P000000103o
ool000000000003oool3000000040?ooo`0000000000000001`0oooo6`3AcJT001X0dLfY7`3oool3
000000040?ooo`00000000000?ooo`<0000000@0oooo00000000000000007@3ooolY0=7=ZAl0oooo
3P00000M0?ooobT0dLfY7`3oool400000080oooo0P000000103oool000000000003oool2000001d0
oooo:@3AcJTO0?ooo`<0000000@0oooo000000000000oooo0`000000103oool0000000000000000M
0?oooa/0dLfY000J0=7=ZB00oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0
000001h0oooo:@3AcJTP0?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000
003oool0000001h0oooo:@3AcJTP0?ooo`030000003oool0oooo00<0000000@0oooo000000000000
oooo0P00000N0?ooobT0dLfY803oool01@000000oooo000000000000oooo00<0000000@0oooo0000
0000000000007P3ooolK0=7=Z@006P3AcJTQ0?ooo`H0000000@0oooo00000000000000007`3ooolY
0=7=ZB40oooo1P000000103oool0000000000000000O0?ooobT0dLfY8@3oool4000000040?ooo`00
000000000?ooo`8000007`3ooolY0=7=ZB40oooo1P000000103oool0000000000000000O0?oooa/0
dLfY000J0=7=ZB<0oooo0P000000103oool0000000000000000Q0?ooobT0dLfY8`3oool600000240
oooo:@3AcJTS0?ooo`<0000000<0oooo0000000000008@3ooolY0=7=ZB<0oooo0P000000103oool0
000000000000000Q0?oooa/0dLfY000J0=7=ZBL0oooo00<000000?ooo`3oool0803ooolY0=7=ZBD0
oooo00<000000?ooo`0000008P3ooolY0=7=ZBH0oooo0P00000R0?ooobT0dLfY9@3oool300000280
oooo6`3AcJT001X0dLfY903oool3000002<0oooo:@3AcJTT0?ooo`<000008`3ooolY0=7=ZB@0oooo
0`00000S0?ooobT0dLfY903oool3000002<0oooo6`3AcJT001X0dLfY9@3oool00`000000oooo0?oo
o`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?oo
o`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?oooa/0dLfY003o0=7=ZMT0dLfY003o0=7=
ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY000g0=7=Z@E000000P3AcJT2
@00000@0dLfY0T00001T0=7=Z@E000000P3AcJT2@00000<0dLfY0d00001T0=7=Z@E0000000<0dLfY
@000040000000d0000020=7=Z@900000I03AcJT5@00000030=7=ZD000010000000=0000000<0dLfY
@000040000000d00000g0=7=Z@00>@3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A00000
0=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@1S0=7=Z@05@000003AcJT0dLfY0=7=ZD000000
0P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY06@0dLfY00=000000=7=Z@3AcJT0
0`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0H`3AcJT00d000000
dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0=`3AcJT003T0dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=
Z@3AcJT0H`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJT0dLfY0d00
001U0=7=Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000
003AcJT0dLfY06<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000
003AcJT0dLfY03L0dLfY000i0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY
0=7=Z@3AcJT2@00006H0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00=000000=7=Z@3AcJT0H`3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0
dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@1S0=7=Z@03@000003AcJT0dLfY00<0dLfY00=0
00000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0g0=7=Z@00>@3AcJT01D000000dLfY0=7=Z@3A
cJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@1S0=7=Z@05@000
003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY
06<0dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=00000
0=7=Z@3AcJT0H`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=00000
0=7=Z@3AcJT0=`3AcJT003P0dLfY0T0000040=7=Z@900000103AcJT2@00006D0dLfY0T0000040=7=
Z@900000103AcJT3@00006@0dLfY0T0000040=7=Z@900000103AcJT2@00006D0dLfY0T0000040=7=
Z@900000103AcJT2@00003T0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o
0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o
0=7=ZMT0dLfY000J0=7=Z@80oooo1P0000001@3oool00000000000000000oooo00800000;@3oool3
000000050?ooo`00000000000000003oool00P000000103oool0000000000000000Y0=7=Z@80oooo
0P0000000`3oool000000?ooo`03000000050?ooo`00000000000?ooo`000000403oool200000003
0?ooo`000000000000<0000000@0oooo000000000000oooo0P00000?0?ooo`80000000@0oooo0000
00000000oooo0P000000103oool000000000003oool2000002T0dLfY0P3oool500000080oooo00P0
00000?ooo`3oool0oooo0000003oool000000?ooo`8000000P3oool00`000000oooo0?ooo`020000
0080oooo0P0000030?ooo`030000003oool0000000<000000P3oool300000080oooo00<000000?oo
o`0000000`0000001P3oool000000?ooo`3oool000000?ooo`8000000P3oool010000000oooo0000
000000020?ooo`<0000000<0oooo000000000000:@3AcJT20?ooo`80000000<0oooo000000000000
0P3oool200000080oooo0P0000000`3oool00000000000020?ooo`8000000P3oool2000000030?oo
o`00000000000080oooo0P0000020?ooo`030000003oool0oooo008000000P3oool200000080oooo
00<000000?ooo`3oool00P0000020?ooo`8000000P3oool00`000000oooo0?ooo`0200000080oooo
0P0000020?ooo`030000003oool0oooo00<000006`3AcJT001X0dLfY0`3oool010000000oooo0?oo
o`0000030?ooo`050000003oool0oooo0?ooo`000000;P3oool01@000000oooo0?ooo`3oool00000
0080oooo00H000000?ooo`3oool0oooo0000003ooolY0=7=Z@<0oooo00<000000?ooo`3oool00P3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000004@3oool00`000000oooo000000020?ooo`07
0000003oool0oooo0?ooo`000000oooo0000000A0?ooo`030000003oool0000000<0oooo00L00000
0?ooo`3oool000000?ooo`000000oooo02T0dLfY0`3oool00`000000oooo000000040?ooo`@00000
103oool01@000000oooo000000000000oooo0080000000@0oooo00000000000000001@3oool30000
0080oooo0`0000020?ooo`D000000P3oool010000000oooo0000003oool2000000<0oooo0`000000
0`3oool000000?ooo`020?ooo`030000003oool0oooo0080000000<0oooo0=7=Z@3AcJT09`3AcJT3
0?ooo`050000003oool000000000003oool00`0000000`3oool0000000000004000000050?ooo`00
000000000000003oool01P0000001@3oool00000000000000000oooo0080000000D0oooo00000000
000000000?ooo`03000000040?ooo`00000000000?ooo`<0000000D0oooo00000000000000000?oo
o`02000000050?ooo`00000000000000003oool00`000000103oool000000000003oool300000003
0?ooo`3AcJT0dLfY01T0dLfY000J0=7=Z@@0oooo0P0000050?ooo`<00000<03oool3000000@0oooo
0`0000020?ooobT0dLfY103oool2000000050?ooo`00000000000000003oool00`00000C0?ooo`H0
000000@0oooo00000000000000004`3oool3000000040?ooo`00000000000?ooo`<000000P3ooolY
0=7=Z@@0oooo0P0000000`3oool000000000000200000080oooo00<000000?ooo`3oool00`000000
0`3oool000000?ooo`020?ooo`030000003oool000000080oooo1P0000020?ooo`<000000P3oool3
00000080oooo00<000000?ooo`3oool00P3oool2000000040?ooo`000000oooo0?ooo`<000000P3o
ool2000000050?ooo`00000000000000003oool00P0000020?ooobT0dLfY103oool00`000000oooo
0?ooo`0200000080oooo0P0000020?ooo`030000003oool0oooo008000000P3oool200000080oooo
00<000000?ooo`3oool00P0000020?ooo`80000000<0oooo0000000000000P3oool200000080oooo
0P0000000`3oool00000000000020?ooo`8000000P3oool2000000030?ooo`00000000000080oooo
0P0000020?ooo`80000000@0oooo00000000000000000P3ooolK0=7=Z@006P3AcJT<0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3ooolY0=7=Z@P0
oooo00D000000?ooo`3oool0oooo0000000E0?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool04`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0oooo
:@3AcJT80?ooo`030000003oool0oooo00<000000P3oool00`000000oooo0?ooo`02000000040?oo
o`0000000000000000D0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?oo
o`060000003oool0oooo0?ooo`000000oooo100000030?ooo`<000000P3oool3000000<0oooo00@0
00000?ooo`00000000000`3ooolY0=7=Z@H0oooo0`0000001@3oool00000000000000000oooo0080
000000D0oooo00000000000000000?ooo`03000000040?ooo`00000000000?ooo`<0000000D0oooo
00000000000000000?ooo`02000000050?ooo`00000000000000003oool00`000000103oool00000
0000003oool3000000050?ooo`00000000000000003oool00P0000001@3oool00000000000000000
oooo00H000000`3ooolK0=7=Z@006P3AcJT50?ooo`<0000000@0oooo0000000000000000=03oool3
000000030?ooo`000000000000@0oooo:@3AcJT50?ooo`80000000<0oooo0000003oool00P00000G
0?ooo`040000003oool000000?ooo`8000005`3oool2000000040?ooo`0000000000000000@0oooo
:@3AcJT50?ooo`@0000000<0oooo0000000000000P3oool010000000oooo0000003oool2000000<0
oooo00<000000?ooo`3oool01@000000103oool000000000003oool4000000030?ooo`0000000000
0080000000H0oooo00000000000000000?ooo`0000020?ooo`030000003oool000000080000000<0
oooo0000003oool00P0000020?ooo`H00000103ooolY0=7=Z@D0oooo0P0000020?ooo`8000000P3o
ool2000000030?ooo`00000000000080oooo0P0000020?ooo`80000000<0oooo0000000000000P3o
ool200000080oooo00<000000?ooo`3oool00P0000020?ooo`8000000P3oool00`000000oooo0?oo
o`0200000080oooo0P0000020?ooo`030000003oool0oooo008000000P3oool200000080oooo0P00
00040?oooa/0dLfY000J0=7=Z@H0oooo00D000000?ooo`3oool0oooo0000000f0?ooo`040000003o
ool0oooo000000D0oooo:@3AcJT60?ooo`050000003oool000000?ooo`0000006P3oool00`000000
oooo0000000I0?ooo`040000003oool00000000000D0oooo:@3AcJT60?ooo`030000003oool0oooo
008000001@3oool00`000000oooo000000050?ooo`<000000P3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080000000D0oooo0000003oool0
00000?ooo`02000000040?ooo`000000oooo0?ooo`80000000<0oooo0000003oool00`3oool01000
0000oooo0?ooo`0000050?ooobT0dLfY1P3oool00`000000oooo00000002000000030?ooo`000000
000000@0000000D0oooo00000000000000000?ooo`06000000050?ooo`00000000000000003oool0
0P0000001@3oool00000000000000000oooo00<0000000@0oooo000000000000oooo0`0000001@3o
ool00000000000000000oooo0080000000D0oooo00000000000000000?ooo`03000000030?ooo`00
0000000000D0oooo6`3AcJT001X0dLfY1`3oool3000003P0oooo0P0000060?ooobT0dLfY1`3oool3
000001X0oooo0`00000K0?ooo`8000001P3ooolY0=7=Z@L0oooo0`0000050?ooo`80000000<0oooo
0000003oool01@0000000`3oool000000?ooo`02000000050?ooo`00000000000000003oool00`00
00001@3oool00000000000000000oooo008000000`3oool2000000030?ooo`000000oooo0080oooo
0`000000103oool000000000003oool4000000030?ooo`000000oooo00D0oooo:@3AcJT70?ooo`80
00000P3oool200000080oooo00<000000?ooo`3oool00P0000020?ooo`8000000P3oool00`000000
oooo0?ooo`0200000080oooo0P0000000`3oool00000000000020?ooo`8000000P3oool200000003
0?ooo`00000000000080oooo0P0000020?ooo`80000000<0oooo0000000000000P3oool200000080
oooo0P0000060?oooa/0dLfY000J0=7=Z@T0oooo0`000000103oool000000000003oool300000005
0?ooo`00000000000000003oool00P0000001@3oool00000000000000000oooo00<0000000@0oooo
000000000000oooo0`0000001@3oool00000000000000000oooo0080000000D0oooo000000000000
00000?ooo`03000000040?ooo`00000000000?ooo`<0000000@0oooo00000000000000001`3ooolY
0=7=Z@T0oooo0P0000001P3oool000000000003oool000000?ooo`80000000@0oooo000000000000
oooo0P0000000`3oool000000?ooo`02000000040?ooo`00000000000?ooo`D0000000@0oooo0000
00000000oooo0P0000000`3oool000000?ooo`02000000040?ooo`00000000000?ooo`80000000<0
oooo0000003oool00P000000103oool000000000003oool2000000L0oooo:@3AcJT90?ooo`P00000
00D0oooo0000003oool000000?ooo`02000000040?ooo`0000000000000000D0oooo0`0000050?oo
o`@0000000D0oooo0000003oool000000?ooo`0300000080oooo00<000000?ooo`0000000P3oool4
000000030?ooo`000000000000L0oooo:@3AcJT90?ooo`8000000P3oool2000000030?ooo`000000
00000080oooo0P0000020?ooo`80000000<0oooo0000000000000P3oool200000080oooo00<00000
0?ooo`3oool00P0000020?ooo`8000000P3oool00`000000oooo0?ooo`0200000080oooo0P000002
0?ooo`030000003oool0oooo008000000P3oool3000000L0oooo6`3AcJT001X0dLfY2P3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000H0
oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`000000203ooolY
0=7=Z@X0oooo00<000000?ooo`0000000P3oool00`000000oooo000000030?ooo`030000003oool0
00000080oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`070000003oool0
oooo0?ooo`000000oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000040?oo
o`070000003oool0oooo0?ooo`000000oooo000000080?ooobT0dLfY2P3oool01P000000oooo0?oo
o`000000oooo000000<0oooo0P0000000`3oool000000?ooo`040?ooo`H000000`3oool500000080
oooo00<000000?ooo`0000000P000000103oool000000?ooo`3oool3000000030?ooo`000000oooo
0080oooo00<000000?ooo`3oool00P0000080?ooobT0dLfY2P3oool00`000000oooo000000050000
00050?ooo`00000000000000003oool01P0000001@3oool00000000000000000oooo0080000000D0
oooo00000000000000000?ooo`03000000040?ooo`00000000000?ooo`<0000000D0oooo00000000
000000000?ooo`02000000050?ooo`00000000000000003oool00`0000080?oooa/0dLfY000J0=7=
Z@/0oooo0`0000040?ooo`<000001@3oool2000000D0oooo0`0000040?ooo`<00000103oool30000
00D0oooo0`0000040?ooo`<000002@3ooolY0=7=Z@/0oooo0`0000000`3oool00000000000050?oo
o`<0000000<0oooo0000000000001@3oool6000000040?ooo`0000000000000000@0oooo0`000000
103oool000000000000000040?ooo`<0000000@0oooo00000000000000002@3ooolY0=7=Z@/0oooo
0`0000000`3oool000000?ooo`03000000<0oooo0`0000000`3oool00000000000020?ooo`030000
003oool0oooo0080000000D0oooo0000003oool0oooo000000040?ooo`<000000`3oool300000080
oooo1P0000000`3oool00000000000090?ooobT0dLfY2`3oool200000080oooo00<000000?ooo`3o
ool00P0000020?ooo`8000000P3oool00`000000oooo0?ooo`0200000080oooo0P0000000`3oool0
0000000000020?ooo`8000000P3oool2000000030?ooo`00000000000080oooo0P0000020?ooo`80
000000<0oooo0000000000000P3oool3000000T0oooo6`3AcJT001X0dLfY303oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00P0oooo:@3AcJT<0?ooo`040000003oool0oooo000000L0
oooo00@000000?ooo`3oool000001`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00@0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`000000
2P3ooolY0=7=Z@`0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`@000000`3oool00`00
0000oooo0?ooo`020?ooo`<0000000@0oooo000000000000oooo0P0000000`3oool0000000000002
00000080oooo100000020?ooo`<000000P3oool00`000000oooo0?ooo`02000000X0oooo:@3AcJT<
0?ooo`050000003oool000000000003oool00`0000001@3oool00000000000000000oooo00800000
00D0oooo00000000000000000?ooo`03000000040?ooo`00000000000?ooo`<0000000D0oooo0000
0000000000000?ooo`02000000050?ooo`00000000000000003oool00`000000103oool000000000
003oool3000000X0oooo6`3AcJT001X0dLfY3@3oool2000000040?ooo`0000000000000000P0oooo
0`000000103oool000000000000000080?ooo`<0000000<0oooo0000000000002@3oool200000004
0?ooo`0000000000000000/0oooo:@3AcJT=0?ooo`<0000000@0oooo000000000000oooo0P000000
103oool000000?ooo`0000090?ooo`040000003oool000000?ooo`800000203oool2000000030?oo
o`000000oooo0080000000D0oooo0000003oool000000?ooo`02000000/0oooo:@3AcJT=0?ooo`<0
000000<0oooo0000003oool00P0000020?ooo`060000003oool000000?ooo`000000oooo10000002
0?ooo`8000000`3oool00`000000oooo000000020?ooo`040000003oool0000000000080oooo00@0
00000?ooo`00000000000P3oool3000000030?ooo`000000000000/0oooo:@3AcJT=0?ooo`800000
00<0oooo0000000000000P3oool200000080oooo0P0000000`3oool00000000000020?ooo`800000
0P3oool00`000000oooo0?ooo`0200000080oooo0P0000020?ooo`030000003oool0oooo00800000
0P3oool200000080oooo00<000000?ooo`3oool00`00000;0?oooa/0dLfY000J0=7=Z@h0oooo00@0
00000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0:0?ooobT0dLfY3P3oool2000000030?ooo`000000oooo0080
oooo00D000000?ooo`000000oooo0000000;0?ooo`030000003oool0000000X0oooo00D000000?oo
o`000000oooo000000040?ooo`030000003oool0000000`0oooo:@3AcJT>0?ooo`060000003oool0
00000000003oool00000103oool200000080oooo0P0000020?ooo`050000003oool000000000003o
ool0100000000`3oool000000?ooo`02000000<0oooo0`0000000`3oool000000?ooo`050?ooo`80
0000303ooolY0=7=Z@h0oooo100000001@3oool00000000000000000oooo00H0000000D0oooo0000
0000000000000?ooo`02000000050?ooo`00000000000000003oool00`000000103oool000000000
003oool3000000050?ooo`00000000000000003oool00P000000103oool0000000000000000<0?oo
oa/0dLfY000J0=7=Z@l0oooo0P00000<0?ooo`<00000303oool3000000/0oooo0`00000=0?ooobT0
dLfY3`3oool2000000D0oooo0`00000;0?ooo`<00000303oool3000000@0oooo0`00000=0?ooobT0
dLfY3`3oool2000000<0oooo1@0000040?ooo`060000003oool000000000003oool000000`3oool0
0`000000oooo0?ooo`02000000040?ooo`000000oooo0?ooo`<000000P3oool2000000050?ooo`00
000000000000003oool00P00000=0?ooobT0dLfY3`3oool00`000000oooo0?ooo`0200000080oooo
0P0000020?ooo`030000003oool0oooo008000000P3oool2000000030?ooo`00000000000080oooo
0P0000020?ooo`80000000<0oooo0000000000000P3oool200000080oooo0P000000103oool00000
00000000000=0?oooa/0dLfY000J0=7=Z@l0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303ooolY0=7=Z@l0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooobT0dLfY3`3oool00`000000oooo
0?ooo`030?ooo`050000003oool0oooo0000003oool0100000000`3oool000000?ooo`020?ooo`@0
000000<0oooo0000000000000`3oool300000080oooo0`0000030?ooo`040000003oool000000000
00h0oooo:@3AcJT?0?ooo`030000003oool000000080000000D0oooo00000000000000000?ooo`02
000000050?ooo`00000000000000003oool00`000000103oool000000000003oool3000000050?oo
o`00000000000000003oool00P0000001@3oool00000000000000000oooo00<0000000<0oooo0000
000000003P3ooolK0=7=Z@006P3AcJT@0?ooo`<0000000D0oooo00000000000000000?ooo`020000
00040?ooo`000000000000000100oooo0P0000001@3oool00000000000000000oooo00<0000000<0
oooo0000000000003`3ooolY0=7=ZA00oooo0P000000103oool000000000003oool3000000030?oo
o`000000oooo0080000000@0oooo000000000000oooo1@000000103oool000000000003oool20000
00030?ooo`000000oooo0080000000D0oooo00000000000000000?ooo`02000000030?ooo`000000
oooo00h0oooo:@3AcJT@0?ooo`H0000000<0oooo0000000000000`3oool010000000oooo0?ooo`3o
ool4000000030?ooo`000000oooo0080oooo00<000000?ooo`0000000P0000000`3oool000000?oo
o`0200000080oooo100000000`3oool000000?ooo`0>0?ooobT0dLfY403oool200000080oooo0P00
00020?ooo`80000000<0oooo0000000000000P3oool200000080oooo00<000000?ooo`3oool00P00
00020?ooo`8000000P3oool00`000000oooo0?ooo`0200000080oooo0P0000020?ooo`8000003`3o
oolK0=7=Z@006P3AcJTA0?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?oo
o`00000E0?ooo`050000003oool0oooo0?ooo`0000004`3ooolY0=7=ZA40oooo00<000000?ooo`00
00000`3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000000P3oool0
1`000000oooo0?ooo`3oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool03`3ooolY0=7=ZA40oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`02000000040?ooo`000000000000000080oooo0`0000001P3oool0000000000000
0000oooo00000080oooo0P0000000`3oool000000?ooo`030?ooo`040000003oool0oooo00000100
oooo:@3AcJTA0?ooo`030000003oool000000080000000<0oooo000000000000100000001@3oool0
0000000000000000oooo0080000000D0oooo00000000000000000?ooo`03000000040?ooo`000000
00000?ooo`<0000000D0oooo00000000000000000?ooo`0200000100oooo6`3AcJT001X0dLfY4P3o
ool3000000D0oooo0P00000C0?ooo`<000001@3oool300000100oooo:@3AcJTB0?ooo`<0000000D0
oooo00000000000000000?ooo`02000000D0oooo1P000000103oool000000000000000040?ooo`<0
000000D0oooo00000000000000000?ooo`0300000100oooo:@3AcJTB0?ooo`<0000000@0oooo0000
0000000000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo
000000030?ooo`<0000000@0oooo000000000000oooo100000000`3oool000000000000@0?ooobT0
dLfY4P3oool200000080oooo0P0000020?ooo`030000003oool0oooo008000000P3oool200000003
0?ooo`00000000000080oooo0P0000020?ooo`80000000<0oooo0000000000000P3oool200000080
oooo0`00000@0?oooa/0dLfY000J0=7=ZA<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03`3ooolY0=7=ZA<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`0?0?ooobT0dLfY4`3oool01@000000oooo0?ooo`3oool000000080oooo0P00
00001@3oool00000000000000000oooo00<000001@3oool400000080oooo0P0000030?ooo`030000
003oool0oooo008000004@3ooolY0=7=ZA<0oooo00<000000?ooo`0000000P000000103oool00000
0000003oool3000000050?ooo`00000000000000003oool00P0000001@3oool00000000000000000
oooo00<0000000@0oooo000000000000oooo0`000000103oool0000000000000000A0?oooa/0dLfY
000J0=7=ZAD0oooo00D000000?ooo`3oool0oooo0000000H0?ooo`050000003oool0oooo0?ooo`00
00004`3ooolY0=7=ZAD0oooo00D000000?ooo`000000oooo0000000;0?ooo`030000003oool00000
00X0oooo00D000000?ooo`000000oooo0000000C0?ooobT0dLfY5@3oool00`000000oooo0?ooo`02
000000030?ooo`00000000000080000000H0oooo00000000000000000?ooo`0000020?ooo`030000
003oool0oooo00<0000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`02000001<0oooo
:@3AcJTE0?ooo`030000003oool0000000D0000000D0oooo00000000000000000?ooo`0200000005
0?ooo`00000000000000003oool00`000000103oool000000000003oool3000000040?ooo`000000
0000000001<0oooo6`3AcJT001X0dLfY5P3oool3000001X0oooo0`00000D0?ooobT0dLfY5P3oool3
000000/0oooo0`00000<0?ooo`<00000503ooolY0=7=ZAH0oooo0`0000030?ooo`030000003oool0
oooo008000000P3oool00`000000oooo0?ooo`020?ooo`<000000P3oool6000000030?ooo`000000
000001@0oooo:@3AcJTF0?ooo`8000000P3oool00`000000oooo0?ooo`0200000080oooo0P000000
0`3oool00000000000020?ooo`8000000P3oool2000000030?ooo`00000000000080oooo0`00000D
0?oooa/0dLfY000J0=7=ZAL0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0C0?oo
obT0dLfY5`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool04`3ooolY0=7=ZAL0oooo00<000000?ooo`3oool00`3oool3000000D0oooo100000020?oo
o`<000000P3oool00`000000oooo0?ooo`02000001D0oooo:@3AcJTG0?ooo`050000003oool00000
0000003oool00`0000001@3oool00000000000000000oooo0080000000D0oooo0000000000000000
0?ooo`03000000040?ooo`00000000000?ooo`<000005@3ooolK0=7=Z@006P3AcJTH0?ooo`800000
00D0oooo00000000000000000?ooo`03000000040?ooo`00000000000?ooo`<0000000D0oooo0000
0000000000000?ooo`02000000040?ooo`0000000000000001H0oooo:@3AcJTH0?ooo`@0000000@0
oooo000000000000oooo0P0000001@3oool000000?ooo`000000oooo0080000000@0oooo00000000
0000oooo100000000`3oool000000000000F0?ooobT0dLfY603oool600000080oooo100000001P3o
ool000000?ooo`3oool000000?ooo`8000000P3oool3000000030?ooo`000000000001H0oooo:@3A
cJTH0?ooo`80000000<0oooo0000000000000P3oool200000080oooo00<000000?ooo`3oool00P00
00020?ooo`8000000P3oool00`000000oooo0?ooo`03000001H0oooo6`3AcJT001X0dLfY6@3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo
000000060?ooo`030000003oool0oooo01D0oooo:@3AcJTI0?ooo`8000000`3oool00`000000oooo
000000040?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo
0000000G0?ooobT0dLfY6@3oool00`000000oooo000000020?ooo`<000000P3oool00`000000oooo
0?ooo`03000000030?ooo`000000oooo00D0oooo0P00000G0?ooobT0dLfY6@3oool4000000050?oo
o`00000000000000003oool00P0000001@3oool00000000000000000oooo00<0000000@0oooo0000
00000000oooo0`00000G0?oooa/0dLfY000J0=7=ZAX0oooo0P0000050?ooo`<00000103oool30000
00@0oooo0`00000H0?ooobT0dLfY6P3oool2000000040?ooo`0000000000000000@0oooo0`000005
0?ooo`H00000603ooolY0=7=ZAX0oooo0P0000000`3oool00000000000020?ooo`H000000P3oool2
000000050?ooo`00000000000000003oool00P00000H0?ooobT0dLfY6P3oool00`000000oooo0?oo
o`0200000080oooo0P0000000`3oool00000000000020?ooo`8000000P3oool2000000040?ooo`00
00000000000001P0oooo6`3AcJT001X0dLfY6P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooobT0dLfY6P3o
ool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01@3oool010000000oooo
0?ooo`00000I0?ooobT0dLfY6P3oool01P000000oooo0?ooo`3oool000000?ooo`8000000P3oool0
0`000000oooo0?ooo`03000000<0oooo00@000000?ooo`00000000006@3ooolY0=7=ZAX0oooo00<0
00000?ooo`0000000P0000001@3oool00000000000000000oooo0080000000D0oooo000000000000
00000?ooo`03000000030?ooo`000000000001T0oooo6`3AcJT001X0dLfY6`3oool3000000040?oo
o`0000000000000000P0oooo0`0000000`3oool000000000000J0?ooobT0dLfY6`3oool200000003
0?ooo`000000oooo0080000000D0oooo0000003oool000000?ooo`02000000070?ooo`0000000000
0?ooo`000000oooo0000000J0?ooobT0dLfY6`3oool4000000030?ooo`000000oooo0080oooo00@0
00000?ooo`00000000000P3oool4000000030?ooo`000000oooo01T0oooo:@3AcJTK0?ooo`800000
0P3oool200000080oooo00<000000?ooo`3oool00P0000020?ooo`8000000P3oool2000001X0oooo
6`3AcJT001X0dLfY703oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0
703ooolY0=7=ZA`0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0000000<0
oooo00<000000?ooo`000000703ooolY0=7=ZA`0oooo00<000000?ooo`3oool00P0000001P3oool0
0000000000000000oooo000000@0oooo00@000000?ooo`3oool000006`3ooolY0=7=ZA`0oooo00<0
00000?ooo`0000000P000000103oool000000000003oool3000000050?ooo`00000000000000003o
ool00P00000K0?oooa/0dLfY000J0=7=ZAd0oooo0`00000<0?ooo`<000006`3ooolY0=7=ZAd0oooo
0`0000040?ooo`<000001@3oool3000001/0oooo:@3AcJTM0?ooo`<000000`3oool01@000000oooo
000000000000oooo00@0000000<0oooo0000000000006`3ooolY0=7=ZAd0oooo0P0000020?ooo`80
000000<0oooo0000000000000P3oool200000080oooo0`00000K0?oooa/0dLfY000J0=7=ZAh0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0J0?ooobT0dLfY7P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06P3ooolY0=7=ZAh0oooo
00<000000?ooo`3oool00`3oool2000000<0oooo00<000000?ooo`3oool00P00000L0?ooobT0dLfY
7P3oool00`000000oooo00000002000000040?ooo`00000000000?ooo`<0000000@0oooo00000000
00000000703ooolK0=7=Z@006P3AcJTO0?ooo`<0000000@0oooo000000000000oooo0`000000103o
ool0000000000000000M0?ooobT0dLfY7`3oool2000000030?ooo`000000000000<0000000@0oooo
000000000000oooo0P00000M0?ooobT0dLfY7`3oool500000080oooo100000000`3oool000000000
000M0?ooobT0dLfY7`3oool200000080oooo00<000000?ooo`3oool00P0000020?ooo`<000007@3o
oolK0=7=Z@006P3AcJTQ0?ooo`<00000103oool3000001l0oooo:@3AcJTQ0?ooo`H0000000@0oooo
00000000000000007`3ooolY0=7=ZB40oooo1`0000000`3oool000000000000O0?ooobT0dLfY8@3o
ool2000000030?ooo`00000000000080oooo0`00000O0?oooa/0dLfY000J0=7=ZB80oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0N0?ooobT0dLfY8P3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo01h0oooo:@3AcJTR0?ooo`040000003oool0oooo00000080oooo
0P00000P0?ooobT0dLfY8P3oool01@000000oooo000000000000oooo00<00000803ooolK0=7=Z@00
6P3AcJTS0?ooo`80000000@0oooo00000000000000008@3ooolY0=7=ZB<0oooo00@000000?ooo`00
0000oooo0P00000Q0?ooobT0dLfY8`3oool3000000030?ooo`00000000000240oooo:@3AcJTS0?oo
o`030000003oool0oooo00<000008@3ooolK0=7=Z@006P3AcJTW0?ooo`030000003oool0oooo0200
oooo:@3AcJTU0?ooo`030000003oool000000280oooo:@3AcJTV0?ooo`8000008P3ooolY0=7=ZBD0
oooo0`00000R0?oooa/0dLfY000J0=7=ZB@0oooo0`00000S0?ooobT0dLfY903oool3000002<0oooo
:@3AcJTT0?ooo`<000008`3ooolY0=7=ZB@0oooo0`00000S0?oooa/0dLfY000J0=7=ZBD0oooo00<0
00000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<0
00000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=Z@00o`3AcJWI
0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00=`3AcJT5
@0000080dLfY0T0000050=7=Z@=00000HP3AcJT5@0000080dLfY0T0000040=7=Z@900000I03AcJT5
@0000080dLfY0T0000030=7=Z@=00000I03AcJT5@0000080dLfY0T0000050=7=Z@03@000003AcJT0
dLfY03L0dLfY000i0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@03
0=7=Z@03@000003AcJT0dLfY06<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003A
cJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0H`3AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@1S0=7=Z@05@000003AcJT0dLfY
0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY03L0dLfY000i0=7=
Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@05@00006@0dLfY00E00000
0=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0H`3A
cJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000
dLfY0=7=Z@1S0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=
Z@03@000003AcJT0dLfY03L0dLfY000i0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY06<0dLfY00E000000=7=Z@3AcJT0dLfY@000
00020=7=Z@04@000003AcJT0dLfY0=7=Z@900000IP3AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00=000000=7=Z@3AcJT00d00001V0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d00
0000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY03H0dLfY000i0=7=Z@05@000003AcJT0dLfY0=7=
ZD0000000P3AcJT01d000000dLfY0=7=Z@3AcJU000000=7=ZD000000I@3AcJT01D000000dLfY0=7=
Z@3AcJU000000080dLfY00E000000=7=Z@3AcJT0dLfY@000001W0=7=Z@05@000003AcJT0dLfY0=7=
ZD0000000P3AcJT01D000000dLfY0=7=Z@3AcJU0000006L0dLfY00E000000=7=Z@3AcJT0dLfY@000
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0=P3AcJT003P0dLfY0T00
00040=7=Z@9000001@3AcJT2@00006@0dLfY0T0000040=7=Z@900000103AcJT3@00006@0dLfY0T00
00040=7=Z@900000103AcJT3@00006@0dLfY0T0000040=7=Z@9000000`3AcJT4@00003P0dLfY003o
0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o
0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY000J0=7=Z@80oooo00`0
00000?ooo`00000000000?ooo`000000oooo0000003oool000000?ooo`00000^0?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000:@3AcJT20?oo
o`0<0000003oool000000000003oool000000?ooo`000000oooo0000003oool00000;P3oool01`00
0000oooo0000003oool000000?ooo`0000000P3oool01@000000oooo0000003oool0000002T0dLfY
0P3oool030000000oooo000000000000oooo0000003oool000000?ooo`000000oooo00000080oooo
00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool020000000oooo0000003o
ool000000?ooo`000000oooo0P0000002@3oool000000?ooo`000000oooo0000003oool000000?oo
o`02000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000P0oooo0000
003oool000000?ooo`000000oooo00000080oooo00D000000?ooo`000000oooo0000000Y0=7=Z@80
oooo00`000000?ooo`00000000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00P000000?ooo`000000oooo
0000003oool000000?ooo`80000000T0oooo0000003oool000000?ooo`000000oooo0000003oool0
0P0000002@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000080?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`050000003oool000000?ooo`0000006`3AcJT001X0
dLfY0`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`000000;P3oool0
1@000000oooo0?ooo`3oool000000080oooo00H000000?ooo`3oool0oooo0000003ooolY0=7=Z@<0
oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000002h0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`060000003oool0oooo0?ooo`000000oooo:@3AcJT30?ooo`0;
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00P0000002@3oool00000
0?ooo`000000oooo0000003oool000000?ooo`02000000080?ooo`000000oooo0000003oool00000
0?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool020000000oooo0000003oool0
00000?ooo`000000oooo0P0000001@3oool000000?ooo`000000oooo02T0dLfY0`3oool02`000000
oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000T0oooo0000003oool0
00000?ooo`000000oooo0000003oool00P000000203oool000000?ooo`000000oooo0000003oool0
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00P000000?ooo`000000oooo0000003o
ool000000?ooo`80000000D0oooo0000003oool000000?ooo`0K0=7=Z@006P3AcJT40?ooo`800000
1@3oool00`000000oooo0000000`0?ooo`030000003oool0000000@0oooo00<000000?ooo`000000
0P3ooolY0=7=Z@@0oooo0P0000050?ooo`030000003oool000000300oooo00<000000?ooo`000000
103oool00`000000oooo000000020?ooobT0dLfY103oool2000000080?ooo`000000oooo0000003o
ool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00P000000?ooo`000000oooo0000003oool000000?ooo`80000000T0oooo0000003oool00000
0?ooo`000000oooo0000003oool00P0000002@3oool000000?ooo`000000oooo0000003oool00000
0?ooo`02000000080?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`030000003oool0
00000080oooo:@3AcJT40?ooo`80000000P0oooo0000003oool000000?ooo`000000oooo00000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool020000000oooo0000
003oool000000?ooo`000000oooo0P0000002@3oool000000?ooo`000000oooo0000003oool00000
0?ooo`02000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000P0oooo
0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`0000000P3ooolK0=7=Z@00
6P3AcJT<0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0103oool010000000oooo
0?ooo`3ooolY0=7=Z@`0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`040?ooo`04
0000003oool0oooo0?ooobT0dLfY1P3oool020000000oooo0000003oool000000?ooo`000000oooo
0P0000002@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000080?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02000
0000oooo0000003oool000000?ooo`000000oooo0P0000000`3oool000000?ooo`020?ooobT0dLfY
1P3oool020000000oooo0000003oool000000?ooo`000000oooo0P0000002@3oool000000?ooo`00
0000oooo0000003oool000000?ooo`02000000080?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool020000000oooo0000003oool000000?oo
o`000000oooo0P0000000`3oool000000?ooo`020?oooa/0dLfY000J0=7=Z@D0oooo00L000000?oo
o`000000oooo0000003oool0000003@0oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`020?ooobT0dLfY1@3oool01`000000oooo0000003oool000000?ooo`000000=03oool00`000000
oooo000000020?ooo`030000003oool0oooo0080oooo:@3AcJT50?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool020000000oooo0000003oool000000?ooo`000000oooo0P0000002@3oool00000
0?ooo`000000oooo0000003oool000000?ooo`02000000090?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0080000000P0oooo0000003oool000000?ooo`000000oooo00000080oooo00<0
00000?ooo`3oool00P3ooolY0=7=Z@D0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`080000
003oool000000?ooo`000000oooo0000003oool2000000090?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0080000000T0oooo0000003oool000000?ooo`000000oooo0000003oool00P00
0000203oool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo0?ooo`020?oo
oa/0dLfY000J0=7=Z@H0oooo00D000000?ooo`3oool0oooo0000000f0?ooo`040000003oool0oooo
000000D0oooo:@3AcJT60?ooo`050000003oool0oooo0?ooo`000000=P3oool010000000oooo0?oo
o`0000050?ooobT0dLfY1P3oool020000000oooo0000003oool000000?ooo`000000oooo0P000000
2@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000080?ooo`000000oooo0000
003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool020000000oooo
0000003oool000000?ooo`000000oooo0P0000050?ooobT0dLfY1P3oool020000000oooo0000003o
ool000000?ooo`000000oooo0P0000002@3oool000000?ooo`000000oooo0000003oool000000?oo
o`02000000080?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool020000000oooo0000003oool000000?ooo`000000oooo0P0000050?oooa/0
dLfY000J0=7=Z@L0oooo00<000000?ooo`000000>03oool00`000000oooo0?ooo`050?ooobT0dLfY
1`3oool00`000000oooo0000000h0?ooo`030000003oool0oooo00D0oooo:@3AcJT70?ooo`070000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00P000000?ooo`000000oooo0000003oool000000?ooo`80000000T0oooo
0000003oool000000?ooo`000000oooo0000003oool00P0000002@3oool000000?ooo`000000oooo
0000003oool000000?ooo`02000000080?ooo`000000oooo0000003oool000000?ooo`0000070?oo
obT0dLfY1`3oool01`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000
003oool2000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000T0oooo
0000003oool000000?ooo`000000oooo0000003oool00P000000203oool000000?ooo`000000oooo
0000003oool000001`3ooolK0=7=Z@006P3AcJT90?ooo`050000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`080000003oool00000
0?ooo`000000oooo0000003oool2000000090?ooo`000000oooo0000003oool000000?ooo`000000
oooo0080000000T0oooo0000003oool000000?ooo`000000oooo0000003oool00P000000203oool0
00000?ooo`000000oooo0000003oool000001`3ooolY0=7=Z@T0oooo00D000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00P00000
0?ooo`000000oooo0000003oool000000?ooo`80000000T0oooo0000003oool000000?ooo`000000
oooo0000003oool00P0000002@3oool000000?ooo`000000oooo0000003oool000000?ooo`020000
00080?ooo`000000oooo0000003oool000000?ooo`0000070?ooobT0dLfY2@3oool01@000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool020000000oooo0000003oool000000?ooo`000000oooo0P0000002@3oool000000?ooo`000000
oooo0000003oool000000?ooo`02000000090?ooo`000000oooo0000003oool000000?ooo`000000
oooo0080000000P0oooo0000003oool000000?ooo`000000oooo000000L0oooo:@3AcJT90?ooo`05
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`080000003oool000000?ooo`000000oooo0000003oool2000000090?ooo`000000
oooo0000003oool000000?ooo`000000oooo0080000000T0oooo0000003oool000000?ooo`000000
oooo0000003oool00P000000203oool000000?ooo`000000oooo0000003oool000001`3ooolK0=7=
Z@006P3AcJT:0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3o
ool0oooo000000080?ooobT0dLfY2P3oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
103oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo000000060?oo
o`050000003oool0oooo0?ooo`000000203ooolY0=7=Z@X0oooo00@000000?ooo`000000oooo0P00
00002@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000080?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`000000203ooolY0=7=Z@X0oooo00@000000?ooo`000000oooo0P00
00002@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000080?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000
oooo0000003oool000000?ooo`000000203ooolK0=7=Z@006P3AcJT;0?ooo`030000003oool00000
00@0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool00000
00@0oooo00<000000?ooo`000000103oool00`000000oooo000000050?ooo`030000003oool00000
00@0oooo00<000000?ooo`0000002@3ooolY0=7=Z@/0oooo00<000000?ooo`000000103oool00`00
0000oooo000000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool00`00
0000oooo000000040?ooo`030000003oool0000000D0oooo00<000000?ooo`000000103oool00`00
0000oooo000000090?ooobT0dLfY2`3oool00`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00P000000?ooo`000000oooo0000003oool00000
0?ooo`80000000T0oooo0000003oool000000?ooo`000000oooo0000003oool00P0000002@3oool0
00000?ooo`000000oooo0000003oool000000?ooo`02000000060?ooo`000000oooo0000003oool0
00002@3ooolY0=7=Z@/0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000003oool20000
00090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000T0oooo0000003oool0
00000?ooo`000000oooo0000003oool00P0000001P3oool000000?ooo`000000oooo000000T0oooo
6`3AcJT001X0dLfY303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo:@3A
cJT<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203ooolY0=7=Z@`0oooo00d0
00000?ooo`00000000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000P0
oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`050000003oool000000?ooo`0000002P3ooolY0=7=Z@`0oooo00d000000?ooo`0000000000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000P0oooo0000003oool00000
0?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000
0P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool0
00000?ooo`0000002P3ooolK0=7=Z@006P3AcJT=0?ooo`060000003oool0oooo0000003oool00000
203oool01`000000oooo0000003oool000000?ooo`000000203oool010000000oooo0000003oool2
000000T0oooo0P000000103oool000000?ooo`00000;0?ooobT0dLfY3@3oool01P000000oooo0?oo
o`000000oooo000000P0oooo00L000000?ooo`000000oooo0000003oool0000000P0oooo00@00000
0?ooo`000000oooo0P0000090?ooo`80000000@0oooo0000003oool000002`3ooolY0=7=Z@d0oooo
00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`080000
003oool000000?ooo`000000oooo0000003oool2000000090?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0080000000T0oooo0000003oool000000?ooo`000000oooo0000003oool00P00
0000103oool000000?ooo`00000;0?ooobT0dLfY3@3oool030000000oooo0?ooo`000000oooo0000
003oool000000?ooo`000000oooo00000080oooo00P000000?ooo`000000oooo0000003oool00000
0?ooo`80000000T0oooo0000003oool000000?ooo`000000oooo0000003oool00P0000002@3oool0
00000?ooo`000000oooo0000003oool000000?ooo`02000000040?ooo`000000oooo000000/0oooo
6`3AcJT001X0dLfY3P3oool010000000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`00
00002P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo:@3AcJT>0?ooo`04
0000003oool0oooo000000X0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool02P3ooolY0=7=Z@h0oooo0P0000002@3oool000000?ooo`00
0000oooo0000003oool000000?ooo`02000000080?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000<0?ooobT0dLfY
3P3oool2000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000P0oooo
0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`030000003oool0000000`0oooo6`3AcJT001X0dLfY403oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0000000`0oooo00<000000?ooo`0000002`3oool00`000000oooo0000000=0?ooobT0
dLfY403oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000`0oooo00<000000?ooo`00
00002`3oool00`000000oooo0000000=0?ooobT0dLfY403oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000003oool20000
00090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000T0oooo0000003oool0
00000?ooo`000000oooo0000003oool00P0000000`3oool000000?ooo`0<0?ooobT0dLfY403oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`080000003oool000000?oo
o`000000oooo0000003oool2000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo
0080000000T0oooo0000003oool000000?ooo`000000oooo0000003oool00P0000000`3oool00000
0?ooo`0<0?oooa/0dLfY000J0=7=Z@l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303ooolY0=7=Z@l0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0303ooolY0=7=Z@l0oooo00X000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0P000000203oool000000?ooo`000000oooo0000003oool000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`3oool0303ooolY0=7=Z@l0oooo00X000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0P000000203oool000000?ooo`000000oooo
0000003oool000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0
303ooolK0=7=Z@006P3AcJT@0?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00<000000?ooo`000000403oool2000000090?ooo`000000oooo0000003oool000000?oo
o`000000oooo008000003`3ooolY0=7=ZA00oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo0000000@0?ooo`80000000T0oooo0000003oool000000?oo
o`000000oooo0000003oool00P00000?0?ooobT0dLfY403oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000003oool20000
00090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000T0oooo0000003oool0
00000?ooo`000000oooo0000003oool00P00000?0?ooobT0dLfY403oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000003o
ool2000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000T0oooo0000
003oool000000?ooo`000000oooo0000003oool00P00000?0?oooa/0dLfY000J0=7=ZA40oooo00D0
00000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000001D0oooo00D000000?ooo`3o
ool0oooo0000000C0?ooobT0dLfY4@3oool01@000000oooo0?ooo`3oool0000000<0oooo00@00000
0?ooo`3oool000005@3oool01@000000oooo0?ooo`3oool0000001<0oooo:@3AcJTA0?ooo`080000
003oool000000?ooo`000000oooo0000003oool2000000080?ooo`000000oooo0000003oool00000
0?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000004@3ooolY0=7=ZA40oooo00P000000?oo
o`000000oooo0000003oool000000?ooo`80000000P0oooo0000003oool000000?ooo`000000oooo
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo0000000A0?oooa/0dLfY000J0=7=ZA80oooo00<00000
0?ooo`0000001P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0000000D0oooo00<00000
0?ooo`000000403ooolY0=7=ZA80oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0000000D0oooo00<000000?ooo`000000403ooolY0=7=ZA80oooo00L00000
0?ooo`000000oooo0000003oool000000080oooo00P000000?ooo`000000oooo0000003oool00000
0?ooo`80000000T0oooo0000003oool000000?ooo`000000oooo0000003oool00P0000002P3oool0
00000?ooo`000000oooo0000003oool000000?ooo`00000@0?ooobT0dLfY4P3oool01`000000oooo
0000003oool000000?ooo`0000000P3oool020000000oooo0000003oool000000?ooo`000000oooo
0P0000002@3oool000000?ooo`000000oooo0000003oool000000?ooo`020000000:0?ooo`000000
oooo0000003oool000000?ooo`000000oooo00000100oooo6`3AcJT001X0dLfY4`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0?0?ooobT0dLfY4`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooobT0dLfY4`3oool01P000000
oooo0000003oool000000?ooo`80000000P0oooo0000003oool000000?ooo`000000oooo00000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo0000000A0?ooobT0dLfY4`3oool01P000000oooo0000003oool0
00000?ooo`80000000P0oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo0000000A0?oooa/0dLfY000J0=7=ZAD0oooo00D000000?ooo`3oool0oooo0000000H
0?ooo`050000003oool0oooo0?ooo`0000004`3ooolY0=7=ZAD0oooo00D000000?ooo`3oool0oooo
0000000H0?ooo`050000003oool0oooo0?ooo`0000004`3ooolY0=7=ZAD0oooo00@000000?ooo`00
0000oooo0P000000203oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
0000000C0?ooobT0dLfY5@3oool010000000oooo0000003oool2000000080?ooo`000000oooo0000
003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00L000000?ooo`000000oooo0000003oool0000001<0oooo6`3AcJT001X0dLfY5P3oool0
0`000000oooo0000000J0?ooo`030000003oool0000001@0oooo:@3AcJTF0?ooo`030000003oool0
000001X0oooo00<000000?ooo`000000503ooolY0=7=ZAH0oooo00<000000?ooo`0000000P3oool0
20000000oooo0000003oool000000?ooo`000000oooo0P0000002@3oool000000?ooo`000000oooo
0000003oool000000?ooo`02000000060?ooo`000000oooo0000003oool00000503ooolY0=7=ZAH0
oooo00<000000?ooo`0000000P3oool020000000oooo0000003oool000000?ooo`000000oooo0P00
00002@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000060?ooo`000000oooo
0000003oool00000503ooolK0=7=Z@006P3AcJTG0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool04`3ooolY0=7=ZAL0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0C
0?ooobT0dLfY5`3oool030000000oooo000000000000oooo0000003oool000000?ooo`000000oooo
00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01@000000
oooo0000003oool0000001D0oooo:@3AcJTG0?ooo`0<0000003oool000000000003oool000000?oo
o`000000oooo0000003oool000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`050000003oool000000?ooo`0000005@3ooolK0=7=Z@006P3AcJTH0?ooo`0;0000
003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00P0000002@3oool000000?oo
o`000000oooo0000003oool000000?ooo`02000000040?ooo`000000oooo000001H0oooo:@3AcJTH
0?ooo`0;0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00P0000002@3o
ool000000?ooo`000000oooo0000003oool000000?ooo`02000000040?ooo`000000oooo000001H0
oooo:@3AcJTH0?ooo`0;0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
0P0000002@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000040?ooo`000000
oooo000001H0oooo:@3AcJTH0?ooo`0;0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool00P0000002@3oool000000?ooo`000000oooo0000003oool000000?ooo`0200000004
0?ooo`000000oooo000001H0oooo6`3AcJT001X0dLfY6@3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0
oooo01D0oooo:@3AcJTI0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103o
ool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool05@3ooolY0=7=ZAT0oooo
0P000000203oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`030000003oool0000001L0oooo:@3AcJTI0?ooo`80
000000P0oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0000000G0?oooa/0dLfY000J0=7=ZA/0
oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`030000003oool0000000@0
oooo00<000000?ooo`000000603ooolY0=7=ZA/0oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000040?ooo`030000003oool0000000@0oooo00<000000?ooo`000000603ooolY0=7=ZA/0
oooo00P000000?ooo`000000oooo0000003oool000000?ooo`80000000T0oooo0000003oool00000
0?ooo`000000oooo0000003oool00P0000000`3oool000000?ooo`0G0?ooobT0dLfY6`3oool02000
0000oooo0000003oool000000?ooo`000000oooo0P0000002@3oool000000?ooo`000000oooo0000
003oool000000?ooo`02000000030?ooo`000000oooo01L0oooo6`3AcJT001X0dLfY6P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0G0?ooobT0dLfY6P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooobT0dLfY6P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`3oool05`3ooolY0=7=ZAX0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0oooo01L0oooo6`3AcJT001X0dLfY6`3oool0
1`000000oooo0000003oool000000?ooo`000000203oool010000000oooo0000003oool2000001X0
oooo:@3AcJTK0?ooo`070000003oool000000?ooo`000000oooo000000080?ooo`040000003oool0
00000?ooo`8000006P3ooolY0=7=ZA/0oooo00P000000?ooo`000000oooo0000003oool000000?oo
o`80000000T0oooo0000003oool000000?ooo`000000oooo0000003oool00P00000J0?ooobT0dLfY
6`3oool020000000oooo0000003oool000000?ooo`000000oooo0P0000002@3oool000000?ooo`00
0000oooo0000003oool000000?ooo`02000001X0oooo6`3AcJT001X0dLfY703oool01@000000oooo
0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0703ooolY0=7=ZA`0oooo00D000000?ooo`3o
ool0oooo0000000:0?ooo`030000003oool0oooo01`0oooo:@3AcJTL0?ooo`070000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
01`0oooo:@3AcJTL0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool0000001`0oooo6`3AcJT001X0dLfY7@3oool00`000000
oooo0000000<0?ooo`030000003oool0000001/0oooo:@3AcJTM0?ooo`030000003oool0000000`0
oooo00<000000?ooo`0000006`3ooolY0=7=ZAd0oooo00H000000?ooo`000000oooo0000003oool2
0000000:0?ooo`000000oooo0000003oool000000?ooo`000000oooo000001/0oooo:@3AcJTM0?oo
o`060000003oool000000?ooo`000000oooo0P0000002P3oool000000?ooo`000000oooo0000003o
ool000000?ooo`00000K0?oooa/0dLfY000J0=7=ZAh0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0J0?ooobT0dLfY7P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
01X0oooo:@3AcJTN0?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003o
ool000000?ooo`000000oooo0000000L0?ooobT0dLfY7P3oool01@000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000703ooolK0=7=Z@006P3A
cJTO0?ooo`040000003oool000000?ooo`80000000P0oooo0000003oool000000?ooo`000000oooo
000001d0oooo:@3AcJTO0?ooo`040000003oool000000?ooo`80000000P0oooo0000003oool00000
0?ooo`000000oooo000001d0oooo:@3AcJTO0?ooo`040000003oool000000?ooo`80000000P0oooo
0000003oool000000?ooo`000000oooo000001d0oooo:@3AcJTO0?ooo`040000003oool000000?oo
o`80000000P0oooo0000003oool000000?ooo`000000oooo000001d0oooo6`3AcJT001X0dLfY8@3o
ool00`000000oooo000000040?ooo`030000003oool0000001l0oooo:@3AcJTQ0?ooo`030000003o
ool0000000@0oooo00<000000?ooo`0000007`3ooolY0=7=ZB40oooo00X000000?ooo`0000000000
0?ooo`000000oooo0000003oool000007`3ooolY0=7=ZB40oooo00X000000?ooo`00000000000?oo
o`000000oooo0000003oool000007`3ooolK0=7=Z@006P3AcJTR0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool07P3ooolY0=7=ZB80oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0N0?ooobT0dLfY8P3oool020000000oooo0?ooo`000000oooo0000003oool00000803o
oolY0=7=ZB80oooo00P000000?ooo`3oool000000?ooo`000000oooo00000200oooo6`3AcJT001X0
dLfY8`3oool2000000040?ooo`000000oooo00000240oooo:@3AcJTS0?ooo`80000000@0oooo0000
003oool000008@3ooolY0=7=ZB<0oooo0P000000103oool000000?ooo`00000Q0?ooobT0dLfY8`3o
ool2000000040?ooo`000000oooo00000240oooo6`3AcJT001X0dLfY9`3oool00`000000oooo0?oo
o`0P0?ooobT0dLfY9`3oool00`000000oooo0?ooo`0P0?ooobT0dLfY9@3oool00`000000oooo0000
000R0?ooobT0dLfY9@3oool00`000000oooo0000000R0?oooa/0dLfY000J0=7=ZB@0oooo00<00000
0?ooo`0000008`3ooolY0=7=ZB@0oooo00<000000?ooo`0000008`3ooolY0=7=ZB@0oooo00<00000
0?ooo`0000008`3ooolY0=7=ZB@0oooo00<000000?ooo`0000008`3ooolK0=7=Z@006P3AcJTU0?oo
o`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?oo
o`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo6`3AcJT00?l0
dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT003X0
dLfY0d0000040=7=Z@900000JP3AcJT3@00000<0dLfY1D00001X0=7=Z@=000001@3AcJT3@00006P0
dLfY0d0000040=7=Z@900000?03AcJT003`0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03
@000003AcJT0dLfY06T0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@1Z0=7=Z@03
@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT0J@3AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00=000000=7=Z@3AcJT0>@3AcJT003/0dLfY0d0000020=7=Z@04@000003AcJT0dLfY@000
06X0dLfY0d0000040=7=Z@03@000003AcJT0dLfY06T0dLfY0d0000020=7=Z@E00000J@3AcJT3@000
00D0dLfY00=000000=7=Z@3AcJT0>@3AcJT003X0dLfY00A000000=7=Z@3AcJU000000P3AcJT01400
0000dLfY0=7=ZD00001Y0=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT0J03A
cJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00006T0dLfY00A000000=7=Z@3A
cJU000000`3AcJT2@00003`0dLfY000j0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=
Z@3AcJU00000J@3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY06P0dLfY00A0
00000=7=Z@3AcJU000000`3AcJT00d000000dLfY@000001Y0=7=Z@04@000003AcJT0dLfY@00000<0
dLfY00=000000=7=Z@3AcJT0>`3AcJT003/0dLfY0d0000030=7=Z@900000J`3AcJT3@00000<0dLfY
0T00001[0=7=Z@=00000103AcJT2@00006X0dLfY0d0000030=7=Z@=00000>`3AcJT00?l0dLfYf@3A
cJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3A
cJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT001X0dLfY0P3oool030000000oooo
000000000000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool020000000oooo0000003oool000000?ooo`000000
oooo0P0000002@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000090?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0080000000P0oooo0000003oool000000?ooo`00
0000oooo00000080oooo00D000000?ooo`000000oooo0000000Y0=7=Z@80oooo00`000000?ooo`00
000000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00P000000?ooo`000000oooo0000003oool000000?oo
o`80000000T0oooo0000003oool000000?ooo`000000oooo0000003oool00P0000002@3oool00000
0?ooo`000000oooo0000003oool000000?ooo`02000000080?ooo`000000oooo0000003oool00000
0?ooo`0000020?ooo`050000003oool000000?ooo`000000:@3AcJT20?ooo`0<0000003oool00000
0000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000003oool2
000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000T0oooo0000003o
ool000000?ooo`000000oooo0000003oool00P000000203oool000000?ooo`000000oooo0000003o
ool000000P3oool01@000000oooo0000003oool0000002T0dLfY0P3oool030000000oooo00000000
0000oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool020000000oooo0000003oool000000?ooo`000000oooo0P00
00002@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000090?ooo`000000oooo
0000003oool000000?ooo`000000oooo0080000000P0oooo0000003oool000000?ooo`000000oooo
00000080oooo00D000000?ooo`000000oooo0000000K0=7=Z@006P3AcJT30?ooo`0;0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool00P0000002@3oool000000?ooo`000000
oooo0000003oool000000?ooo`02000000080?ooo`000000oooo0000003oool000000?ooo`000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool020000000oooo0000003oool000000?ooo`00
0000oooo0P0000001@3oool000000?ooo`000000oooo02T0dLfY0`3oool02`000000oooo0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0080000000T0oooo0000003oool000000?ooo`00
0000oooo0000003oool00P000000203oool000000?ooo`000000oooo0000003oool000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00P000000?ooo`000000oooo0000003oool000000?oo
o`80000000D0oooo0000003oool000000?ooo`0Y0=7=Z@<0oooo00/000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`02000000090?ooo`000000oooo0000003oool000000?oo
o`000000oooo0080000000P0oooo0000003oool000000?ooo`000000oooo00000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000003oool20000
00050?ooo`000000oooo0000003oool0:@3AcJT30?ooo`0;0000003oool0oooo0000003oool00000
0?ooo`000000oooo0000003oool00P0000002@3oool000000?ooo`000000oooo0000003oool00000
0?ooo`02000000080?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool020000000oooo0000003oool000000?ooo`000000oooo0P0000001@3o
ool000000?ooo`000000oooo01/0dLfY000J0=7=Z@@0oooo0P000000203oool000000?ooo`000000
oooo0000003oool000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`080000003oool000000?ooo`000000oooo0000003oool2000000090?ooo`000000oooo0000
003oool000000?ooo`000000oooo0080000000T0oooo0000003oool000000?ooo`000000oooo0000
003oool00P000000203oool000000?ooo`000000oooo0000003oool000000P3oool00`000000oooo
000000020?ooobT0dLfY103oool2000000080?ooo`000000oooo0000003oool000000?ooo`000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00P000000?ooo`00
0000oooo0000003oool000000?ooo`80000000T0oooo0000003oool000000?ooo`000000oooo0000
003oool00P0000002@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000080?oo
o`000000oooo0000003oool000000?ooo`0000020?ooo`030000003oool000000080oooo:@3AcJT4
0?ooo`80000000P0oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool020000000oooo0000003oool000000?ooo`00
0000oooo0P0000002@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000090?oo
o`000000oooo0000003oool000000?ooo`000000oooo0080000000P0oooo0000003oool000000?oo
o`000000oooo00000080oooo00<000000?ooo`0000000P3ooolY0=7=Z@@0oooo0P000000203oool0
00000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000003oool2000000090?oo
o`000000oooo0000003oool000000?ooo`000000oooo0080000000T0oooo0000003oool000000?oo
o`000000oooo0000003oool00P000000203oool000000?ooo`000000oooo0000003oool000000P3o
ool00`000000oooo000000020?oooa/0dLfY000J0=7=Z@H0oooo00P000000?ooo`000000oooo0000
003oool000000?ooo`80000000T0oooo0000003oool000000?ooo`000000oooo0000003oool00P00
0000203oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00P000000?ooo`000000oooo0000003oool000000?ooo`80000000<0oooo0000003o
ool00P3ooolY0=7=Z@H0oooo00P000000?ooo`000000oooo0000003oool000000?ooo`80000000T0
oooo0000003oool000000?ooo`000000oooo0000003oool00P000000203oool000000?ooo`000000
oooo0000003oool000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00P000000?ooo`00
0000oooo0000003oool000000?ooo`80000000<0oooo0000003oool00P3ooolY0=7=Z@H0oooo00P0
00000?ooo`000000oooo0000003oool000000?ooo`80000000T0oooo0000003oool000000?ooo`00
0000oooo0000003oool00P000000203oool000000?ooo`000000oooo0000003oool000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool000000080oooo00P000000?ooo`000000oooo0000003oool000000?oo
o`80000000<0oooo0000003oool00P3ooolY0=7=Z@H0oooo00P000000?ooo`000000oooo0000003o
ool000000?ooo`80000000T0oooo0000003oool000000?ooo`000000oooo0000003oool00P000000
203oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00P000000?ooo`000000oooo0000003oool000000?ooo`80000000<0oooo0000003oool0
0P3ooolK0=7=Z@006P3AcJT50?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool020000000oooo
0000003oool000000?ooo`000000oooo0P0000002@3oool000000?ooo`000000oooo0000003oool0
00000?ooo`02000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000P0
oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`3oool00P3ooolY0=7=
Z@D0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`080000003oool000000?ooo`000000oooo
0000003oool2000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000T0
oooo0000003oool000000?ooo`000000oooo0000003oool00P000000203oool000000?ooo`000000
oooo0000003oool000000P3oool00`000000oooo0?ooo`020?ooobT0dLfY1@3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00P000000?ooo`000000oooo0000003oool000000?ooo`80000000T0
oooo0000003oool000000?ooo`000000oooo0000003oool00P0000002@3oool000000?ooo`000000
oooo0000003oool000000?ooo`02000000080?ooo`000000oooo0000003oool000000?ooo`000002
0?ooo`030000003oool0oooo0080oooo:@3AcJT50?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool020000000oooo0000003oool000000?ooo`000000oooo0P0000002@3oool000000?ooo`000000
oooo0000003oool000000?ooo`02000000090?ooo`000000oooo0000003oool000000?ooo`000000
oooo0080000000P0oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`3o
ool00P3ooolK0=7=Z@006P3AcJT70?ooo`070000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00P000000?ooo`000000
oooo0000003oool000000?ooo`80000000T0oooo0000003oool000000?ooo`000000oooo0000003o
ool00P0000002@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000080?ooo`00
0000oooo0000003oool000000?ooo`0000070?ooobT0dLfY1`3oool01`000000oooo0000003oool0
00000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`080000003oool000000?ooo`000000oooo0000003oool2000000090?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0080000000T0oooo0000003oool000000?ooo`000000oooo0000003o
ool00P000000203oool000000?ooo`000000oooo0000003oool000001`3ooolY0=7=Z@L0oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool020000000oooo0000003oool000000?ooo`000000oooo0P0000002@3o
ool000000?ooo`000000oooo0000003oool000000?ooo`02000000090?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0080000000P0oooo0000003oool000000?ooo`000000oooo000000L0
oooo:@3AcJT70?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00P000000?ooo`000000oooo0000003oool0
00000?ooo`80000000T0oooo0000003oool000000?ooo`000000oooo0000003oool00P0000002@3o
ool000000?ooo`000000oooo0000003oool000000?ooo`02000000080?ooo`000000oooo0000003o
ool000000?ooo`0000070?oooa/0dLfY000J0=7=Z@P0oooo00H000000?ooo`000000oooo0000003o
ool2000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000P0oooo0000
003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool0000000H0oooo:@3AcJT80?ooo`060000003o
ool000000?ooo`000000oooo0P0000002@3oool000000?ooo`000000oooo0000003oool000000?oo
o`02000000080?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000060?ooobT0
dLfY203oool01P000000oooo0000003oool000000?ooo`80000000T0oooo0000003oool000000?oo
o`000000oooo0000003oool00P000000203oool000000?ooo`000000oooo0000003oool000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000001P3ooolY0=7=Z@P0oooo00H000000?ooo`000000oooo0000003oool2000000090?oo
o`000000oooo0000003oool000000?ooo`000000oooo0080000000P0oooo0000003oool000000?oo
o`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool0000000H0oooo6`3AcJT001X0dLfY2@3oool01@000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
20000000oooo0000003oool000000?ooo`000000oooo0P0000002@3oool000000?ooo`000000oooo
0000003oool000000?ooo`02000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo
0080000000P0oooo0000003oool000000?ooo`000000oooo000000L0oooo:@3AcJT90?ooo`050000
003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`080000003oool000000?ooo`000000oooo0000003oool2000000090?ooo`000000oooo
0000003oool000000?ooo`000000oooo0080000000T0oooo0000003oool000000?ooo`000000oooo
0000003oool00P000000203oool000000?ooo`000000oooo0000003oool000001`3ooolY0=7=Z@T0
oooo00D000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00P000000?ooo`000000oooo0000003oool000000?ooo`80000000T0oooo
0000003oool000000?ooo`000000oooo0000003oool00P0000002@3oool000000?ooo`000000oooo
0000003oool000000?ooo`02000000080?ooo`000000oooo0000003oool000000?ooo`0000070?oo
obT0dLfY2@3oool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool020000000oooo0000003oool000000?ooo`000000oooo0P00
00002@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000090?ooo`000000oooo
0000003oool000000?ooo`000000oooo0080000000P0oooo0000003oool000000?ooo`000000oooo
000000L0oooo6`3AcJT001X0dLfY2P3oool010000000oooo0000003oool2000000090?ooo`000000
oooo0000003oool000000?ooo`000000oooo0080000000P0oooo0000003oool000000?ooo`000000
oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000080?ooobT0dLfY2P3oool010000000oooo0000003oool2000000090?ooo`000000
oooo0000003oool000000?ooo`000000oooo0080000000P0oooo0000003oool000000?ooo`000000
oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000080?ooobT0dLfY2P3oool010000000oooo0000003oool2000000090?ooo`000000
oooo0000003oool000000?ooo`000000oooo0080000000P0oooo0000003oool000000?ooo`000000
oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000080?ooobT0dLfY2P3oool010000000oooo0000003oool2000000090?ooo`000000
oooo0000003oool000000?ooo`000000oooo0080000000P0oooo0000003oool000000?ooo`000000
oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`00
0000oooo000000080?oooa/0dLfY000J0=7=Z@/0oooo00<000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`080000003oool000000?ooo`000000
oooo0000003oool2000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo00800000
00T0oooo0000003oool000000?ooo`000000oooo0000003oool00P0000001P3oool000000?ooo`00
0000oooo000000T0oooo:@3AcJT;0?ooo`030000003oool000000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool020000000oooo0000003oool000000?ooo`000000
oooo0P0000002@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000090?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0080000000H0oooo0000003oool000000?ooo`00
00090?ooobT0dLfY2`3oool00`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000080oooo00P000000?ooo`000000oooo0000003oool000000?ooo`800000
00T0oooo0000003oool000000?ooo`000000oooo0000003oool00P0000002@3oool000000?ooo`00
0000oooo0000003oool000000?ooo`02000000060?ooo`000000oooo0000003oool000002@3ooolY
0=7=Z@/0oooo00<000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000003oool2000000090?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0080000000T0oooo0000003oool000000?ooo`00
0000oooo0000003oool00P0000001P3oool000000?ooo`000000oooo000000T0oooo6`3AcJT001X0
dLfY303oool03@000000oooo000000000000oooo0000003oool000000?ooo`000000oooo0000003o
ool00P000000203oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00D000000?ooo`000000oooo0000000:0?ooobT0dLfY303oool03@000000
oooo000000000000oooo0000003oool000000?ooo`000000oooo0000003oool00P000000203oool0
00000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo0000000:0?ooobT0dLfY303oool03@000000oooo000000000000oooo
0000003oool000000?ooo`000000oooo0000003oool00P000000203oool000000?ooo`000000oooo
0000003oool000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000
oooo0000000:0?ooobT0dLfY303oool03@000000oooo000000000000oooo0000003oool000000?oo
o`000000oooo0000003oool00P000000203oool000000?ooo`000000oooo0000003oool000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000:0?oooa/0
dLfY000J0=7=Z@d0oooo00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?oo
o`0000020?ooo`080000003oool000000?ooo`000000oooo0000003oool2000000090?ooo`000000
oooo0000003oool000000?ooo`000000oooo0080000000T0oooo0000003oool000000?ooo`000000
oooo0000003oool00P000000103oool000000?ooo`00000;0?ooobT0dLfY3@3oool030000000oooo
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00P000000?ooo`000000
oooo0000003oool000000?ooo`80000000T0oooo0000003oool000000?ooo`000000oooo0000003o
ool00P0000002@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000040?ooo`00
0000oooo000000/0oooo:@3AcJT=0?ooo`0<0000003oool0oooo0000003oool000000?ooo`000000
oooo0000003oool000000P3oool020000000oooo0000003oool000000?ooo`000000oooo0P000000
2@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000090?ooo`000000oooo0000
003oool000000?ooo`000000oooo0080000000@0oooo0000003oool000002`3ooolY0=7=Z@d0oooo
00`000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`080000
003oool000000?ooo`000000oooo0000003oool2000000090?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0080000000T0oooo0000003oool000000?ooo`000000oooo0000003oool00P00
0000103oool000000?ooo`00000;0?oooa/0dLfY000J0=7=Z@h0oooo0P0000002@3oool000000?oo
o`000000oooo0000003oool000000?ooo`02000000080?ooo`000000oooo0000003oool000000?oo
o`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000<0?ooobT0
dLfY3P3oool2000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000P0
oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`030000003oool0000000`0oooo:@3AcJT>0?ooo`80000000T0oooo0000003oool000000?oo
o`000000oooo0000003oool00P000000203oool000000?ooo`000000oooo0000003oool000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`000000303ooolY0=7=Z@h0oooo
0P0000002@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000080?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo0000000<0?oooa/0dLfY000J0=7=ZA00oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool020000000oooo0000003oool000000?ooo`000000oooo0P0000002@3o
ool000000?ooo`000000oooo0000003oool000000?ooo`02000000090?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0080000000<0oooo0000003oool0303ooolY0=7=ZA00oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool020000000oooo0000003oool00000
0?ooo`000000oooo0P0000002@3oool000000?ooo`000000oooo0000003oool000000?ooo`020000
00090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000<0oooo0000003oool0
303ooolY0=7=ZA00oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
20000000oooo0000003oool000000?ooo`000000oooo0P0000002@3oool000000?ooo`000000oooo
0000003oool000000?ooo`02000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo
0080000000<0oooo0000003oool0303ooolY0=7=ZA00oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool020000000oooo0000003oool000000?ooo`000000oooo0P000000
2@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000090?ooo`000000oooo0000
003oool000000?ooo`000000oooo0080000000<0oooo0000003oool0303ooolK0=7=Z@006P3AcJT@
0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00P000000?ooo`00
0000oooo0000003oool000000?ooo`80000000T0oooo0000003oool000000?ooo`000000oooo0000
003oool00P0000002@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000l0oooo
:@3AcJT@0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00P00000
0?ooo`000000oooo0000003oool000000?ooo`80000000T0oooo0000003oool000000?ooo`000000
oooo0000003oool00P0000002@3oool000000?ooo`000000oooo0000003oool000000?ooo`020000
00l0oooo:@3AcJT@0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00P000000?ooo`000000oooo0000003oool000000?ooo`80000000T0oooo0000003oool000000?oo
o`000000oooo0000003oool00P0000002@3oool000000?ooo`000000oooo0000003oool000000?oo
o`02000000l0oooo:@3AcJT@0?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00P000000?ooo`000000oooo0000003oool000000?ooo`80000000T0oooo0000003oool0
00000?ooo`000000oooo0000003oool00P0000002@3oool000000?ooo`000000oooo0000003oool0
00000?ooo`02000000l0oooo6`3AcJT001X0dLfY4@3oool020000000oooo0000003oool000000?oo
o`000000oooo0P000000203oool000000?ooo`000000oooo0000003oool000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000140oooo:@3AcJTA0?ooo`080000003oool000000?ooo`000000oooo0000
003oool2000000080?ooo`000000oooo0000003oool000000?ooo`0000020?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000004@3ooolY0=7=ZA40oooo00P000000?ooo`000000oooo0000003oool000000?oo
o`80000000P0oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo0000000A0?ooobT0dLfY4@3oool020000000oooo0000003oool000000?ooo`000000oooo0P00
0000203oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000140oooo6`3AcJT001X0dLfY4P3oool01`000000oooo0000003oool000000?ooo`0000000P3o
ool020000000oooo0000003oool000000?ooo`000000oooo0P0000002@3oool000000?ooo`000000
oooo0000003oool000000?ooo`020000000:0?ooo`000000oooo0000003oool000000?ooo`000000
oooo00000100oooo:@3AcJTB0?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`08
0000003oool000000?ooo`000000oooo0000003oool2000000090?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0080000000X0oooo0000003oool000000?ooo`000000oooo0000003oool0
0000403ooolY0=7=ZA80oooo00L000000?ooo`000000oooo0000003oool000000080oooo00P00000
0?ooo`000000oooo0000003oool000000?ooo`80000000T0oooo0000003oool000000?ooo`000000
oooo0000003oool00P0000002P3oool000000?ooo`000000oooo0000003oool000000?ooo`00000@
0?ooobT0dLfY4P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool020000000oooo
0000003oool000000?ooo`000000oooo0P0000002@3oool000000?ooo`000000oooo0000003oool0
00000?ooo`020000000:0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000100oooo
6`3AcJT001X0dLfY4`3oool01P000000oooo0000003oool000000?ooo`80000000P0oooo0000003o
ool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo0000000A0?ooobT0dLfY
4`3oool01P000000oooo0000003oool000000?ooo`80000000P0oooo0000003oool000000?ooo`00
0000oooo00000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo0000000A0?ooobT0dLfY4`3oool01P000000
oooo0000003oool000000?ooo`80000000P0oooo0000003oool000000?ooo`000000oooo00000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo0000000A0?ooobT0dLfY4`3oool01P000000oooo0000003oool0
00000?ooo`80000000P0oooo0000003oool000000?ooo`000000oooo00000080oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo0000000A0?oooa/0dLfY000J0=7=ZA@0oooo00D000000?ooo`000000oooo00000002
0?ooo`080000003oool000000?ooo`000000oooo0000003oool2000000090?ooo`000000oooo0000
003oool000000?ooo`000000oooo0080000000P0oooo0000003oool000000?ooo`000000oooo0000
0180oooo:@3AcJTD0?ooo`050000003oool000000?ooo`0000000P3oool020000000oooo0000003o
ool000000?ooo`000000oooo0P0000002@3oool000000?ooo`000000oooo0000003oool000000?oo
o`02000000080?ooo`000000oooo0000003oool000000?ooo`00000B0?ooobT0dLfY503oool01@00
0000oooo0000003oool000000080oooo00P000000?ooo`000000oooo0000003oool000000?ooo`80
000000T0oooo0000003oool000000?ooo`000000oooo0000003oool00P000000203oool000000?oo
o`000000oooo0000003oool000004P3ooolY0=7=ZA@0oooo00D000000?ooo`000000oooo00000002
0?ooo`080000003oool000000?ooo`000000oooo0000003oool2000000090?ooo`000000oooo0000
003oool000000?ooo`000000oooo0080000000P0oooo0000003oool000000?ooo`000000oooo0000
0180oooo6`3AcJT001X0dLfY5@3oool010000000oooo0000003oool2000000080?ooo`000000oooo
0000003oool000000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
00000080oooo00L000000?ooo`000000oooo0000003oool0000001<0oooo:@3AcJTE0?ooo`040000
003oool000000?ooo`80000000P0oooo0000003oool000000?ooo`000000oooo00000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo0000003oool0
00000?ooo`0000004`3ooolY0=7=ZAD0oooo00@000000?ooo`000000oooo0P000000203oool00000
0?ooo`000000oooo0000003oool000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000000C0?ooobT0dLfY5@3oool0
10000000oooo0000003oool2000000080?ooo`000000oooo0000003oool000000?ooo`0000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000001<0oooo6`3AcJT001X0dLfY5P3oool00`000000oooo000000020?ooo`08
0000003oool000000?ooo`000000oooo0000003oool2000000090?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0080000000H0oooo0000003oool000000?ooo`00000D0?ooobT0dLfY5P3o
ool00`000000oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000003oool20000
00090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000H0oooo0000003oool0
00000?ooo`00000D0?ooobT0dLfY5P3oool00`000000oooo000000020?ooo`080000003oool00000
0?ooo`000000oooo0000003oool2000000090?ooo`000000oooo0000003oool000000?ooo`000000
oooo0080000000H0oooo0000003oool000000?ooo`00000D0?ooobT0dLfY5P3oool00`000000oooo
000000020?ooo`080000003oool000000?ooo`000000oooo0000003oool2000000090?ooo`000000
oooo0000003oool000000?ooo`000000oooo0080000000H0oooo0000003oool000000?ooo`00000D
0?oooa/0dLfY000J0=7=ZAL0oooo00`000000?ooo`00000000000?ooo`000000oooo0000003oool0
00000?ooo`0000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00D000000?ooo`000000oooo0000000E0?ooobT0dLfY5`3oool030000000oooo000000000000oooo
0000003oool000000?ooo`000000oooo00000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000P3oool01@000000oooo0000003oool0000001D0oooo:@3AcJTG0?ooo`0<0000
003oool000000000003oool000000?ooo`000000oooo0000003oool000000P3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000005@3o
oolY0=7=ZAL0oooo00`000000?ooo`00000000000?ooo`000000oooo0000003oool000000?ooo`00
00020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`000000oooo0000000E0?oooa/0dLfY000J0=7=ZAP0oooo00/000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`02000000090?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0080000000@0oooo0000003oool000005P3ooolY0=7=ZAP0oooo00/000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`02000000090?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0080000000@0oooo0000003oool000005P3ooolY0=7=ZAP0oooo00/00000
0?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000090?ooo`000000oooo
0000003oool000000?ooo`000000oooo0080000000@0oooo0000003oool000005P3ooolY0=7=ZAP0
oooo00/000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000090?oo
o`000000oooo0000003oool000000?ooo`000000oooo0080000000@0oooo0000003oool000005P3o
oolK0=7=Z@006P3AcJTK0?ooo`080000003oool000000?ooo`000000oooo0000003oool200000009
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000<0oooo0000003oool05`3o
oolY0=7=ZA/0oooo00P000000?ooo`000000oooo0000003oool000000?ooo`80000000T0oooo0000
003oool000000?ooo`000000oooo0000003oool00P0000000`3oool000000?ooo`0G0?ooobT0dLfY
6`3oool020000000oooo0000003oool000000?ooo`000000oooo0P0000002@3oool000000?ooo`00
0000oooo0000003oool000000?ooo`02000000030?ooo`000000oooo01L0oooo:@3AcJTK0?ooo`08
0000003oool000000?ooo`000000oooo0000003oool2000000090?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0080000000<0oooo0000003oool05`3ooolK0=7=Z@006P3AcJTJ0?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0G0?ooobT0dLfY6P3oool02@00
0000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00<000000?ooo`3oool05`3ooolY0=7=ZAX0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`030000003oool0oooo01L0oooo:@3AcJTJ0?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool00`000000oooo0?ooo`0G0?oooa/0dLfY000J0=7=ZA/0oooo00P0
00000?ooo`000000oooo0000003oool000000?ooo`80000000T0oooo0000003oool000000?ooo`00
0000oooo0000003oool00P00000J0?ooobT0dLfY6`3oool020000000oooo0000003oool000000?oo
o`000000oooo0P0000002@3oool000000?ooo`000000oooo0000003oool000000?ooo`02000001X0
oooo:@3AcJTK0?ooo`080000003oool000000?ooo`000000oooo0000003oool2000000090?ooo`00
0000oooo0000003oool000000?ooo`000000oooo008000006P3ooolY0=7=ZA/0oooo00P000000?oo
o`000000oooo0000003oool000000?ooo`80000000T0oooo0000003oool000000?ooo`000000oooo
0000003oool00P00000J0?oooa/0dLfY000J0=7=ZA`0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000703ooolY0=7=
ZA`0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000703ooolY0=7=ZA`0oooo00L000000?ooo`000000oooo0000003o
ool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000703ooolY0=7=
ZA`0oooo00L000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000703ooolK0=7=Z@006P3AcJTM0?ooo`060000003oool000000?oo
o`000000oooo0P0000002P3oool000000?ooo`000000oooo0000003oool000000?ooo`00000K0?oo
obT0dLfY7@3oool01P000000oooo0000003oool000000?ooo`80000000X0oooo0000003oool00000
0?ooo`000000oooo0000003oool000006`3ooolY0=7=ZAd0oooo00H000000?ooo`000000oooo0000
003oool20000000:0?ooo`000000oooo0000003oool000000?ooo`000000oooo000001/0oooo:@3A
cJTM0?ooo`060000003oool000000?ooo`000000oooo0P0000002P3oool000000?ooo`000000oooo
0000003oool000000?ooo`00000K0?oooa/0dLfY000J0=7=ZAh0oooo00D000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000001`0oooo:@3AcJTN
0?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`00
0000oooo0000000L0?ooobT0dLfY7P3oool01@000000oooo0000003oool000000080oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`000000703ooolY0=7=ZAh0oooo00D000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0000001`0oooo
6`3AcJT001X0dLfY7`3oool010000000oooo0000003oool2000000080?ooo`000000oooo0000003o
ool000000?ooo`00000M0?ooobT0dLfY7`3oool010000000oooo0000003oool2000000080?ooo`00
0000oooo0000003oool000000?ooo`00000M0?ooobT0dLfY7`3oool010000000oooo0000003oool2
000000080?ooo`000000oooo0000003oool000000?ooo`00000M0?ooobT0dLfY7`3oool010000000
oooo0000003oool2000000080?ooo`000000oooo0000003oool000000?ooo`00000M0?oooa/0dLfY
000J0=7=ZB00oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`00
00007P3ooolY0=7=ZB00oooo00<000000?ooo`0000000P3oool01`000000oooo0000003oool00000
0?ooo`0000007P3ooolY0=7=ZB00oooo00<000000?ooo`0000000P3oool01`000000oooo0000003o
ool000000?ooo`0000007P3ooolY0=7=ZB00oooo00<000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000007P3ooolK0=7=Z@006P3AcJTQ0?ooo`0:0000003oool000000000
003oool000000?ooo`000000oooo000001l0oooo:@3AcJTQ0?ooo`0:0000003oool000000000003o
ool000000?ooo`000000oooo000001l0oooo:@3AcJTQ0?ooo`0:0000003oool000000000003oool0
00000?ooo`000000oooo000001l0oooo:@3AcJTQ0?ooo`0:0000003oool000000000003oool00000
0?ooo`000000oooo000001l0oooo6`3AcJT001X0dLfY8`3oool2000000040?ooo`000000oooo0000
0240oooo:@3AcJTS0?ooo`80000000@0oooo0000003oool000008@3ooolY0=7=ZB<0oooo0P000000
103oool000000?ooo`00000Q0?ooobT0dLfY8`3oool2000000040?ooo`000000oooo00000240oooo
6`3AcJT001X0dLfY9@3oool00`000000oooo0000000R0?ooobT0dLfY9@3oool00`000000oooo0000
000R0?ooobT0dLfY9@3oool00`000000oooo0000000R0?ooobT0dLfY9@3oool00`000000oooo0000
000R0?oooa/0dLfY000J0=7=ZB@0oooo00<000000?ooo`0000008`3ooolY0=7=ZB@0oooo00<00000
0?ooo`0000008`3ooolY0=7=ZB@0oooo00<000000?ooo`0000008`3ooolY0=7=ZB@0oooo00<00000
0?ooo`0000008`3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?oo
o`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?oo
o`030000003oool0oooo0280oooo6`3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3A
cJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT003`0dLfY00A000000=7=Z@3AcJT0
dLfY0d00001/0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0JP3AcJT00d000000
dLfY0=7=Z@020=7=Z@900000K03AcJT014000000dLfY0=7=Z@3AcJT3@00003`0dLfY000l0=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@1Y0=7=Z@03@000003AcJT0dLfY
00<0dLfY00=000000=7=Z@3AcJT0JP3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=00000
0=7=Z@3AcJT0J@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY03X0dLfY000l0=7=
Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@1Y0=7=Z@03@000003AcJT0
dLfY00<0dLfY00=000000=7=Z@3AcJT0JP3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=0
00000=7=Z@3AcJT0J@3AcJT00d000000dLfY0=7=Z@020=7=Z@=00000>`3AcJT003d0dLfY00=00000
0=7=Z@3AcJT00d00001]0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0JP3AcJT0
14000000dLfY0=7=Z@3AcJT2@00006d0dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY
0=7=Z@0i0=7=Z@00>P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY06T0dLfY
00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00001Y0=7=Z@04@000003AcJT0dLfY
@0000080dLfY00A000000=7=Z@3AcJU00000J@3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000
003AcJT0dLfY@00003/0dLfY000j0=7=Z@A000000`3AcJT3@00006T0dLfY140000020=7=Z@A00000
J@3AcJT4@00000<0dLfY0T00001Z0=7=Z@A000000`3AcJT3@00003/0dLfY003o0=7=ZMT0dLfY003o
0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o
0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY000J0=7=Z@80oooo00`000000?ooo`000000
00000?ooo`000000oooo0000003oool000000?ooo`00000^0?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`050000003oool000000?ooo`000000:@3AcJT20?ooo`0<0000003oool0
00000000003oool000000?ooo`000000oooo0000003oool00000;P3oool01`000000oooo0000003o
ool000000?ooo`0000000P3oool01@000000oooo0000003oool0000002T0dLfY0P3oool030000000
oooo000000000000oooo0000003oool000000?ooo`000000oooo000002h0oooo00L000000?ooo`00
0000oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000Y0=7=Z@80oooo00`0
00000?ooo`00000000000?ooo`000000oooo0000003oool000000?ooo`00000^0?ooo`070000003o
ool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000006`3AcJT001X0
dLfY0`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`000000;P3oool0
1@000000oooo0?ooo`3oool000000080oooo00H000000?ooo`3oool0oooo0000003ooolY0=7=Z@<0
oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000002h0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`060000003oool0oooo0?ooo`000000oooo:@3AcJT30?ooo`04
0000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo0000000^0?ooo`050000003oool0
oooo0?ooo`0000000P3oool01P000000oooo0?ooo`3oool000000?ooobT0dLfY0`3oool010000000
oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`000000;P3oool01@000000oooo0?ooo`3o
ool000000080oooo00H000000?ooo`3oool0oooo0000003ooolK0=7=Z@006P3AcJT40?ooo`800000
1@3oool00`000000oooo0000000`0?ooo`030000003oool0000000@0oooo00<000000?ooo`000000
0P3ooolY0=7=Z@@0oooo0P0000050?ooo`030000003oool000000300oooo00<000000?ooo`000000
103oool00`000000oooo000000020?ooobT0dLfY103oool2000000D0oooo00<000000?ooo`000000
<03oool00`000000oooo000000040?ooo`030000003oool000000080oooo:@3AcJT40?ooo`800000
1@3oool00`000000oooo0000000`0?ooo`030000003oool0000000@0oooo00<000000?ooo`000000
0P3ooolK0=7=Z@006P3AcJT<0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0103o
ool010000000oooo0?ooo`3ooolY0=7=Z@`0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo0?ooobT0dLfY303oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo:@3AcJT<0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3ooolK0=7=Z@006P3AcJT50?oo
o`070000003oool000000?ooo`000000oooo0000000d0?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool00P3ooolY0=7=Z@D0oooo00L000000?ooo`000000oooo0000003oool0000003@0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooobT0dLfY1@3oool01`000000
oooo0000003oool000000?ooo`000000=03oool00`000000oooo000000020?ooo`030000003oool0
oooo0080oooo:@3AcJT50?ooo`070000003oool000000?ooo`000000oooo0000000d0?ooo`030000
003oool000000080oooo00<000000?ooo`3oool00P3ooolK0=7=Z@006P3AcJT70?ooo`030000003o
ool0000003P0oooo00<000000?ooo`3oool01@3ooolY0=7=Z@L0oooo00<000000?ooo`000000>03o
ool00`000000oooo0?ooo`050?ooobT0dLfY1`3oool00`000000oooo0000000h0?ooo`030000003o
ool0oooo00D0oooo:@3AcJT70?ooo`030000003oool0000003P0oooo00<000000?ooo`3oool01@3o
oolK0=7=Z@006P3AcJT80?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0103ooolY
0=7=Z@P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`040?ooobT0dLfY203oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00@0oooo:@3AcJT80?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool0103ooolK0=7=Z@006P3AcJT90?ooo`050000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`08
0000003oool000000?ooo`000000oooo0000003oool2000000090?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0080000000T0oooo0000003oool000000?ooo`000000oooo0000003oool0
0P000000203oool000000?ooo`000000oooo0000003oool000001`3ooolY0=7=Z@T0oooo00D00000
0?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00P000000?ooo`000000oooo0000003oool000000?ooo`80000000T0oooo0000003oool0
00000?ooo`000000oooo0000003oool00P0000002@3oool000000?ooo`000000oooo0000003oool0
00000?ooo`02000000080?ooo`000000oooo0000003oool000000?ooo`0000070?ooobT0dLfY2@3o
ool01@000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool020000000oooo0000003oool000000?ooo`000000oooo0P0000002@3oool0
00000?ooo`000000oooo0000003oool000000?ooo`02000000090?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0080000000P0oooo0000003oool000000?ooo`000000oooo000000L0oooo
:@3AcJT90?ooo`050000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000003oool20000
00090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000T0oooo0000003oool0
00000?ooo`000000oooo0000003oool00P000000203oool000000?ooo`000000oooo0000003oool0
00001`3ooolK0=7=Z@006P3AcJT:0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`04
0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000H0oooo
00D000000?ooo`3oool0oooo000000080?ooobT0dLfY2P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0
oooo000000060?ooo`050000003oool0oooo0?ooo`000000203ooolY0=7=Z@X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000060?ooo`05
0000003oool0oooo0?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000P0oooo:@3AcJT:
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000001P3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo0000
00080?oooa/0dLfY000J0=7=Z@/0oooo00<000000?ooo`000000103oool00`000000oooo00000006
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo00000004
0?ooo`030000003oool0000000D0oooo00<000000?ooo`000000103oool00`000000oooo00000009
0?ooobT0dLfY2`3oool00`000000oooo000000040?ooo`030000003oool0000000H0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000040?ooo`030000003oool0000000@0oooo00<00000
0?ooo`0000001@3oool00`000000oooo000000040?ooo`030000003oool0000000T0oooo:@3AcJT;
0?ooo`030000003oool0000000@0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0000000@0oooo00<000000?ooo`000000103oool00`000000oooo00000005
0?ooo`030000003oool0000000@0oooo00<000000?ooo`0000002@3ooolY0=7=Z@/0oooo00<00000
0?ooo`000000103oool00`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`000000103oool00`000000oooo000000040?ooo`030000003oool0000000D0oooo00<00000
0?ooo`000000103oool00`000000oooo000000090?oooa/0dLfY000J0=7=Z@`0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`080?ooobT0dLfY303oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00P0oooo:@3AcJT<0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0203ooolY0=7=Z@`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?oo
oa/0dLfY000J0=7=Z@d0oooo00H000000?ooo`3oool000000?ooo`0000080?ooo`070000003oool0
00000?ooo`000000oooo000000080?ooo`040000003oool000000?ooo`8000002@3oool200000004
0?ooo`000000oooo000000/0oooo:@3AcJT=0?ooo`060000003oool0oooo0000003oool00000203o
ool01`000000oooo0000003oool000000?ooo`000000203oool010000000oooo0000003oool20000
00T0oooo0P000000103oool000000?ooo`00000;0?ooobT0dLfY3@3oool01P000000oooo0?ooo`00
0000oooo000000P0oooo00L000000?ooo`000000oooo0000003oool0000000P0oooo00@000000?oo
o`000000oooo0P0000090?ooo`80000000@0oooo0000003oool000002`3ooolY0=7=Z@d0oooo00H0
00000?ooo`3oool000000?ooo`0000080?ooo`070000003oool000000?ooo`000000oooo00000008
0?ooo`040000003oool000000?ooo`8000002@3oool2000000040?ooo`000000oooo000000/0oooo
6`3AcJT001X0dLfY3P3oool010000000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`00
00002P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo:@3AcJT>0?ooo`04
0000003oool0oooo000000X0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool02P3ooolY0=7=Z@h0oooo00@000000?ooo`3oool000002P3o
ool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0:0?ooobT0dLfY3P3oool010000000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?oo
o`0000002P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo6`3AcJT001X0
dLfY403oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000`0oooo00<000000?ooo`00
00002`3oool00`000000oooo0000000=0?ooobT0dLfY403oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0000000`0oooo00<000000?ooo`0000002`3oool00`000000oooo0000000=0?ooobT0
dLfY403oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000`0oooo00<000000?ooo`00
00002`3oool00`000000oooo0000000=0?ooobT0dLfY403oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0000000`0oooo00<000000?ooo`0000002`3oool00`000000oooo0000000=0?oooa/0
dLfY000J0=7=ZA00oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo0000000@0?ooo`80000000T0oooo0000003oool000000?ooo`000000oooo0000003o
ool00P00000?0?ooobT0dLfY403oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool000000100oooo0P0000002@3oool000000?ooo`000000oooo0000003o
ool000000?ooo`02000000l0oooo:@3AcJT@0?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00<000000?ooo`000000403oool2000000090?ooo`000000oooo0000003o
ool000000?ooo`000000oooo008000003`3ooolY0=7=ZA00oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo0000000@0?ooo`80000000T0oooo0000003o
ool000000?ooo`000000oooo0000003oool00P00000?0?oooa/0dLfY000J0=7=ZA40oooo00D00000
0?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000001D0oooo00D000000?ooo`3oool0
oooo0000000C0?ooobT0dLfY4@3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?oo
o`3oool000005@3oool01@000000oooo0?ooo`3oool0000001<0oooo:@3AcJTA0?ooo`050000003o
ool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`00000E0?ooo`050000003oool0oooo0?oo
o`0000004`3ooolY0=7=ZA40oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0
oooo000001D0oooo00D000000?ooo`3oool0oooo0000000C0?oooa/0dLfY000J0=7=ZA80oooo00<0
00000?ooo`0000001P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0000000D0oooo00<0
00000?ooo`000000403ooolY0=7=ZA80oooo00<000000?ooo`0000001P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0000000D0oooo00<000000?ooo`000000403ooolY0=7=ZA80oooo00<0
00000?ooo`0000001P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0000000D0oooo00<0
00000?ooo`000000403ooolY0=7=ZA80oooo00<000000?ooo`0000001P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0000000D0oooo00<000000?ooo`000000403ooolK0=7=Z@006P3AcJTC
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00l0oooo:@3AcJTC0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo:@3AcJTC
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00l0oooo:@3AcJTC0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo6`3AcJT0
01X0dLfY503oool01@000000oooo0000003oool0000001P0oooo00L000000?ooo`000000oooo0000
003oool000000180oooo:@3AcJTD0?ooo`050000003oool000000?ooo`000000603oool01`000000
oooo0000003oool000000?ooo`0000004P3ooolY0=7=ZA@0oooo00D000000?ooo`000000oooo0000
000H0?ooo`070000003oool000000?ooo`000000oooo0000000B0?ooobT0dLfY503oool01@000000
oooo0000003oool0000001P0oooo00L000000?ooo`000000oooo0000003oool000000180oooo6`3A
cJT001X0dLfY5@3oool01@000000oooo0?ooo`3oool0000001P0oooo00D000000?ooo`3oool0oooo
0000000C0?ooobT0dLfY5@3oool01@000000oooo0?ooo`3oool0000001P0oooo00D000000?ooo`3o
ool0oooo0000000C0?ooobT0dLfY5@3oool01@000000oooo0?ooo`3oool0000001P0oooo00D00000
0?ooo`3oool0oooo0000000C0?ooobT0dLfY5@3oool01@000000oooo0?ooo`3oool0000001P0oooo
00D000000?ooo`3oool0oooo0000000C0?oooa/0dLfY000J0=7=ZAH0oooo00<000000?ooo`000000
6P3oool00`000000oooo0000000D0?ooobT0dLfY5P3oool00`000000oooo0000000J0?ooo`030000
003oool0000001@0oooo:@3AcJTF0?ooo`030000003oool0000001X0oooo00<000000?ooo`000000
503ooolY0=7=ZAH0oooo00<000000?ooo`0000006P3oool00`000000oooo0000000D0?oooa/0dLfY
000J0=7=ZAL0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0C0?ooobT0dLfY5`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01<0oooo:@3AcJTG0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool04`3ooolY0=7=ZAL0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0C0?oooa/0dLfY000J0=7=ZAP0oooo00/000000?ooo`3oool000000?oo
o`000000oooo0000003oool000000?ooo`02000000090?ooo`000000oooo0000003oool000000?oo
o`000000oooo0080000000@0oooo0000003oool000005P3ooolY0=7=ZAP0oooo00/000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`02000000090?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0080000000@0oooo0000003oool000005P3ooolY0=7=ZAP0oooo00/0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`02000000090?ooo`000000
oooo0000003oool000000?ooo`000000oooo0080000000@0oooo0000003oool000005P3ooolY0=7=
ZAP0oooo00/000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`0200000009
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000@0oooo0000003oool00000
5P3ooolK0=7=Z@006P3AcJTK0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103o
ool00`000000oooo000000040?ooo`030000003oool0000001P0oooo:@3AcJTK0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo000000040?ooo`030000003o
ool0000001P0oooo:@3AcJTK0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000103o
ool00`000000oooo000000040?ooo`030000003oool0000001P0oooo:@3AcJTK0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo000000040?ooo`030000003o
ool0000001P0oooo6`3AcJT001X0dLfY6P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooobT0dLfY6P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0G0?ooobT0dLfY6P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooobT0dLfY6P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0G0?oooa/0dLfY000J0=7=ZA/0oooo00L000000?ooo`000000oooo0000003o
ool0000000P0oooo00@000000?ooo`000000oooo0P00000J0?ooobT0dLfY6`3oool01`000000oooo
0000003oool000000?ooo`000000203oool010000000oooo0000003oool2000001X0oooo:@3AcJTK
0?ooo`070000003oool000000?ooo`000000oooo000000080?ooo`040000003oool000000?ooo`80
00006P3ooolY0=7=ZA/0oooo00L000000?ooo`000000oooo0000003oool0000000P0oooo00@00000
0?ooo`000000oooo0P00000J0?oooa/0dLfY000J0=7=ZA`0oooo00D000000?ooo`3oool0oooo0000
000:0?ooo`030000003oool0oooo01`0oooo:@3AcJTL0?ooo`050000003oool0oooo0?ooo`000000
2P3oool00`000000oooo0?ooo`0L0?ooobT0dLfY703oool01@000000oooo0?ooo`3oool0000000X0
oooo00<000000?ooo`3oool0703ooolY0=7=ZA`0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`030000003oool0oooo01`0oooo6`3AcJT001X0dLfY7@3oool00`000000oooo0000000<0?ooo`03
0000003oool0000001/0oooo:@3AcJTM0?ooo`030000003oool0000000`0oooo00<000000?ooo`00
00006`3ooolY0=7=ZAd0oooo00<000000?ooo`000000303oool00`000000oooo0000000K0?ooobT0
dLfY7@3oool00`000000oooo0000000<0?ooo`030000003oool0000001/0oooo6`3AcJT001X0dLfY
7P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo:@3AcJTN0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool06P3ooolY0=7=ZAh0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0J0?ooobT0dLfY7P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo01X0oooo6`3AcJT001X0dLfY7`3oool010000000oooo0000003oool2000000080?oo
o`000000oooo0000003oool000000?ooo`00000M0?ooobT0dLfY7`3oool010000000oooo0000003o
ool2000000080?ooo`000000oooo0000003oool000000?ooo`00000M0?ooobT0dLfY7`3oool01000
0000oooo0000003oool2000000080?ooo`000000oooo0000003oool000000?ooo`00000M0?ooobT0
dLfY7`3oool010000000oooo0000003oool2000000080?ooo`000000oooo0000003oool000000?oo
o`00000M0?oooa/0dLfY000J0=7=ZB00oooo00<000000?ooo`3oool0103oool01@000000oooo0?oo
o`3oool0000001h0oooo:@3AcJTP0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo0000000N0?ooobT0dLfY803oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000007P3ooolY0=7=ZB00oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0
000001h0oooo6`3AcJT001X0dLfY8@3oool00`000000oooo000000040?ooo`030000003oool00000
01l0oooo:@3AcJTQ0?ooo`030000003oool0000000@0oooo00<000000?ooo`0000007`3ooolY0=7=
ZB40oooo00<000000?ooo`000000103oool00`000000oooo0000000O0?ooobT0dLfY8@3oool00`00
0000oooo000000040?ooo`030000003oool0000001l0oooo6`3AcJT001X0dLfY8`3oool200000004
0?ooo`000000oooo00000240oooo:@3AcJTS0?ooo`80000000@0oooo0000003oool000008@3ooolY
0=7=ZB<0oooo0P000000103oool000000?ooo`00000Q0?ooobT0dLfY8`3oool2000000040?ooo`00
0000oooo00000240oooo6`3AcJT001X0dLfY9`3oool00`000000oooo0?ooo`0P0?ooobT0dLfY9`3o
ool00`000000oooo0?ooo`0P0?ooobT0dLfY9`3oool00`000000oooo0?ooo`0P0?ooobT0dLfY9`3o
ool00`000000oooo0?ooo`0P0?oooa/0dLfY000J0=7=ZB@0oooo00<000000?ooo`0000008`3ooolY
0=7=ZB@0oooo00<000000?ooo`0000008`3ooolY0=7=ZB@0oooo00<000000?ooo`0000008`3ooolY
0=7=ZB@0oooo00<000000?ooo`0000008`3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo
0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo
0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo6`3AcJT00?l0dLfYf@3AcJT00?l0dLfY
f@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT003`0dLfY
00A000000=7=Z@3AcJT0dLfY1400001[0=7=Z@03@000003AcJT0dLfY0080dLfY0T00001/0=7=Z@03
@000003AcJT0dLfY00<0dLfY0d00001Z0=7=Z@03@000003AcJT0dLfY0080dLfY0T00000l0=7=Z@00
?03AcJT01D000000dLfY0=7=Z@3AcJU0000006h0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=
Z@03@000003AcJT0dLfY06T0dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@1Y0=7=
Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0i0=7=Z@00?03AcJT00d00
0000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY06/0dLfY00=000000=7=Z@3AcJT00`3AcJT00d00
0000dLfY0=7=Z@1Z0=7=Z@04@000003AcJT0dLfY0=7=Z@E00000JP3AcJT00d000000dLfY0=7=Z@04
0=7=Z@03@000003AcJT0dLfY03T0dLfY000m0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=
Z@3AcJT0J`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY06X0dLfY00A000000=7=
Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@1Z0=7=Z@04@000003AcJT0dLfY0=7=Z@900000?03A
cJT003X0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00001Y0=7=Z@04@000
003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000J@3AcJT014000000dLfY0=7=ZD000003
0=7=Z@03@000003AcJU0000006T0dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=
Z@0k0=7=Z@00>P3AcJT4@00000<0dLfY0T00001Z0=7=Z@A000000`3AcJT2@00006X0dLfY14000004
0=7=Z@900000J@3AcJT4@00000<0dLfY0d00000k0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00
o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00
o`3AcJWI0=7=Z@006P3AcJTU0?ooo`P000005P3oool7000002T0dLfY9@3oool4000000050?ooo`00
000000000000003oool00P0000001@3oool00000000000000000oooo00<0000000@0oooo00000000
0000oooo0`0000001@3oool00000000000000000oooo0080000000@0oooo0000000000000000:@3A
cJTU0?ooo`D000001@3oool01@000000oooo000000000000oooo00D000000`3oool200000080oooo
1@0000000`3oool000000?ooo`02000002T0dLfY9@3ooolU000001/0dLfY000J0=7=ZBD0oooo00L0
00000?ooo`000000oooo0000003oool0000001L0oooo0P0000001@3oool000000?ooo`000000oooo
02T0dLfY9@3oool00`000000oooo00000002000000050?ooo`00000000000000003oool00P000000
1@3oool00000000000000000oooo00<0000000@0oooo000000000000oooo0`0000000`3oool00000
00000004000000030?ooo`000000oooo02T0dLfY9@3oool010000000oooo0000000000060?ooo`<0
00000P3oool010000000oooo0000000000020?ooo`<000000`3oool2000000040?ooo`000000oooo
0?ooo`<0000000<0oooo0=7=Z@3AcJT09`3AcJTU0?ooob@0000000<0oooo0=7=Z@3AcJT06@3AcJT0
01X0dLfY9@3oool200000080oooo0P00000H0?ooo`030000003oool0oooo008000000P3ooolY0=7=
ZBD0oooo0P0000001@3oool00000000000000000oooo00H0000000D0oooo00000000000000000?oo
o`06000000050?ooo`00000000000000003oool00P000000103oool000000000000000020?ooobT0
dLfY9@3oool3000000L0oooo0P0000030?ooo`<000000`3oool00`000000oooo0000000400000080
oooo00<000000?ooo`3oool00P0000020?ooobT0dLfY9@3ooolS00000080oooo6`3AcJT001X0dLfY
9@3oool01@000000oooo0?ooo`3oool0000001T0oooo00@000000?ooo`3oool000000`3ooolY0=7=
ZBD0oooo0`0000001@3oool00000000000000000oooo0080000000D0oooo00000000000000000?oo
o`03000000040?ooo`00000000000?ooo`<0000000D0oooo00000000000000000?ooo`0200000003
0?ooo`000000oooo0080oooo:@3AcJTU0?ooo`030000003oool0000000P00000103oool00`000000
oooo0000000300000080oooo00@000000?ooo`00000000000`3oool4000000<0oooo:@3AcJTU0?oo
ob8000000`3ooolK0=7=Z@006P3AcJTU0?ooo`@000006P3oool3000000@0oooo:@3AcJTU0?ooo`@0
000000D0oooo00000000000000000?ooo`02000000050?ooo`00000000000000003oool00`000000
103oool000000000003oool3000000050?ooo`00000000000000003oool00P0000040?ooobT0dLfY
9@3oool3000000030?ooo`000000oooo0080000000<0oooo0000003oool0103oool3000000030?oo
o`00000000000080oooo0`0000040?ooo`<00000103ooolY0=7=ZBD0oooo8@0000040?oooa/0dLfY
000J0=7=ZBD0oooo00<000000?ooo`0000006`3oool2000000D0oooo:@3AcJTU0?ooo`030000003o
ool000000080000000D0oooo00000000000000000?ooo`02000000050?ooo`00000000000000003o
ool00`000000103oool000000000003oool3000000030?ooo`0000000000008000001@3ooolY0=7=
ZBD0oooo0P0000020?ooo`<000000P3oool00`000000oooo0?ooo`030?ooo`8000000P3oool01000
0000oooo0?ooo`3oool2000000D0oooo0P0000050?ooobT0dLfY9@3ooolP000000D0oooo6`3AcJT0
01X0dLfY9@3oool2000001`0oooo00<000000?ooo`3oool0103ooolY0=7=ZBD0oooo0P0000001@3o
ool00000000000000000oooo00H0000000D0oooo00000000000000000?ooo`06000000050?ooo`00
000000000000003oool00P0000060?ooobT0dLfY9@3oool010000000oooo0?ooo`3oool2000000<0
oooo1`0000030?ooo`D000001P3oool00`000000oooo0?ooo`040?ooobT0dLfY9@3ooolO000000H0
oooo6`3AcJT001X0dLfY9@3ooolN000000L0oooo:@3AcJTU0?ooo`@0000000D0oooo000000000000
00000?ooo`02000000050?ooo`00000000000000003oool00`000000103oool000000000003oool3
000000040?ooo`0000000000000000L0oooo:@3AcJTU0?ooo`040000003oool00000000000D0oooo
0P0000020?ooo`<0000000<0oooo000000000000103oool2000000030?ooo`000000oooo00800000
1`3ooolY0=7=ZBD0oooo7P0000070?oooa/0dLfY000J0=7=ZBD0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`070000003oool000000?ooo`000000oooo000000080?ooobT0dLfY9@3oool00`00
0000oooo00000002000000050?ooo`00000000000000003oool00P0000001@3oool0000000000000
0000oooo00<0000000@0oooo000000000000oooo0`0000000`3oool000000?ooo`070?ooobT0dLfY
9@3oool3000000H0oooo00H000000?ooo`3oool0oooo0000003oool3000000<0oooo0`0000020?oo
o`<00000203ooolY0=7=ZBD0oooo7@0000080?oooa/0dLfY000J0=7=ZBD0oooo0P0000020?ooo`80
00000P3oool2000000030?ooo`00000000000080oooo0P0000020?ooo`80000000<0oooo00000000
00000P3oool2000000T0oooo:@3AcJTU0?ooo`80000000D0oooo00000000000000000?ooo`060000
00050?ooo`00000000000000003oool01P000000103oool000000000000000090?ooobT0dLfY9@3o
ool00`000000oooo00000007000000<0oooo0`0000000`3oool0000000000002000000030?ooo`00
0000oooo0080oooo0P0000090?ooobT0dLfY9@3ooolL000000T0oooo6`3AcJT001X0dLfY9@3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000000:0?ooobT0dLfY9@3oool30000
00050?ooo`00000000000000003oool00P0000001@3oool00000000000000000oooo00<0000000@0
oooo000000000000oooo0`0000000`3oool000000?ooo`090?ooobT0dLfY9@3oool3000000030?oo
o`000000oooo0080000000<0oooo0000000000000`0000001@3oool00000000000000000oooo0080
000000<0oooo0000000000000`00000:0?ooobT0dLfY9@3ooolK000000X0oooo6`3AcJT001X0dLfY
9@3oool4000000@0oooo0`0000040?ooo`@000000`3oool4000000/0oooo:@3AcJTU0?ooo`@00000
00D0oooo00000000000000000?ooo`02000000050?ooo`00000000000000003oool00`000000103o
ool000000000003oool3000000/0oooo:@3AcJTU0?ooo`8000000P3oool300000080oooo0`000000
1@3oool00000000000000000oooo00<000000P3oool010000000oooo00000000000;0?ooobT0dLfY
9@3ooolJ000000/0oooo6`3AcJT001X0dLfY9@3oool00`000000oooo000000050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`000000103oool00`000000oooo0000000<0?ooobT0dLfY9@3o
ool00`000000oooo00000002000000050?ooo`00000000000000003oool00P0000001@3oool00000
000000000000oooo00<0000000D0oooo000000000000oooo0000000<0?ooobT0dLfY9@3oool01000
0000oooo0?ooo`3oool2000000<0oooo0P0000020?ooo`8000000P3oool2000000<0oooo0`00000<
0?ooobT0dLfY9@3ooolI000000`0oooo6`3AcJT001X0dLfY9@3oool2000000H0oooo0P0000050?oo
o`8000001@3oool2000000d0oooo:@3AcJTU0?ooo`80000000D0oooo00000000000000000?ooo`06
000000050?ooo`00000000000000003oool01P00000=0?ooobT0dLfY9@3oool5000000@0oooo1@00
00030?ooo`030000003oool0oooo0080oooo0P00000=0?ooobT0dLfY9@3ooolH000000d0oooo6`3A
cJT001X0dLfY9@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooobT0dLfY9@3oool3000000050?ooo`000000
00000000003oool00P0000001@3oool00000000000000000oooo00<0000000D0oooo000000000000
oooo0000000>0?ooobT0dLfY9@3oool010000000oooo0000000000050?ooo`80000000<0oooo0000
003oool00`3oool6000000h0oooo:@3AcJTU0?oooaL000003P3ooolK0=7=Z@006P3AcJTU0?ooo`P0
00001`3oool7000000l0oooo:@3AcJTU0?ooo`@0000000D0oooo00000000000000000?ooo`020000
00050?ooo`00000000000000003oool00`0000000`3oool000000000000?0?ooobT0dLfY9@3oool3
000000H0oooo00<000000?ooo`3oool01P000000103oool000000?ooo`00000?0?ooobT0dLfY9@3o
oolF000000l0oooo6`3AcJT001X0dLfY9@3oool01`000000oooo0000003oool000000?ooo`000000
203oool01@000000oooo0000003oool000000140oooo:@3AcJTU0?ooo`030000003oool000000080
000000D0oooo00000000000000000?ooo`02000000050?ooo`00000000000000003oool00`00000A
0?ooobT0dLfY9@3oool00`000000oooo0000000700000080oooo0P0000000`3oool0000000000002
0?ooo`800000403ooolY0=7=ZBD0oooo5@00000@0?oooa/0dLfY000J0=7=ZBD0oooo0P0000020?oo
o`8000002@3oool200000080oooo0P00000@0?ooobT0dLfY9@3oool2000000050?ooo`0000000000
0000003oool01P0000001@3oool00000000000000000oooo00<00000403ooolY0=7=ZBD0oooo0`00
00001P3oool000000000003oool000000?ooo`@000000P3oool010000000oooo0?ooo`3oool20000
0100oooo:@3AcJTU0?oooaD00000403ooolK0=7=Z@006P3AcJTU0?ooo`050000003oool0oooo0?oo
o`0000002P3oool01@000000oooo0?ooo`3oool000000140oooo:@3AcJTU0?ooo`<0000000D0oooo
00000000000000000?ooo`02000000050?ooo`00000000000000003oool00`0000000`3oool00000
0?ooo`0@0?ooobT0dLfY9@3oool200000080oooo00<000000?ooo`3oool01@0000030?ooo`D00000
4@3ooolY0=7=ZBD0oooo5000000A0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`000000303o
ool00`000000oooo0000000C0?ooobT0dLfY9@3oool00`000000oooo00000002000000050?ooo`00
000000000000003oool00P0000001P3oool00000000000000000oooo000001<0oooo:@3AcJTU0?oo
o`D0000000D0oooo0000003oool0oooo000000050?ooo`<000004`3ooolY0=7=ZBD0oooo4P00000C
0?oooa/0dLfY000J0=7=ZBD0oooo0P00000=0?ooo`800000503ooolY0=7=ZBD0oooo0P0000001@3o
ool00000000000000000oooo00H0000000@0oooo0000000000000000503ooolY0=7=ZBD0oooo00@0
00000?ooo`00000000000P3oool4000000D0oooo0P00000D0?ooobT0dLfY9@3ooolA000001@0oooo
6`3AcJT001X0dLfY9@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01<0oooo:@3A
cJTU0?ooo`<0000000D0oooo00000000000000000?ooo`02000000060?ooo`00000000000000003o
ool000005@3ooolY0=7=ZBD0oooo0`0000030?ooo`80000000<0oooo0000000000001@00000E0?oo
obT0dLfY9@3oool@000001D0oooo6`3AcJT001X0dLfY9@3oool?000001H0oooo:@3AcJTU0?ooo`@0
000000D0oooo00000000000000000?ooo`02000000040?ooo`0000000000000001H0oooo:@3AcJTU
0?ooo`030000003oool0000000@000000P3oool010000000oooo0000003oool2000001H0oooo:@3A
cJTU0?ooo`l000005P3ooolK0=7=Z@006P3AcJTU0?ooo`090000003oool000000?ooo`000000oooo
0000003oool000000080oooo00<000000?ooo`0000005`3ooolY0=7=ZBD0oooo00<000000?ooo`00
00000P0000001@3oool00000000000000000oooo0080000000<0oooo0000003oool05P3ooolY0=7=
ZBD0oooo0`0000000`3oool000000?ooo`04000000040?ooo`0000000000000001L0oooo:@3AcJTU
0?ooo`h000005`3ooolK0=7=Z@006P3AcJTU0?ooo`8000000P3oool200000080oooo0P0000000`3o
ool000000000000H0?ooobT0dLfY9@3oool2000000050?ooo`00000000000000003oool01P00000H
0?ooobT0dLfY9@3oool200000080oooo0`000000103oool000000?ooo`3oool2000001P0oooo:@3A
cJTU0?ooo`d00000603ooolK0=7=Z@006P3AcJTU0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool010000000oooo0?ooo`00000I0?ooobT0dLfY9@3oool3000000050?ooo`00000000000000003o
ool00P0000000`3oool000000?ooo`0H0?ooobT0dLfY9@3oool010000000oooo0?ooo`3oool20000
0080oooo1000000I0?ooobT0dLfY9@3oool<000001T0oooo6`3AcJT001X0dLfY9@3oool4000000@0
oooo0`00000J0?ooobT0dLfY9@3oool4000000050?ooo`00000000000000003oool00P00000J0?oo
obT0dLfY9@3oool5000000<0oooo00<000000?ooo`0000006P3ooolY0=7=ZBD0oooo2`00000J0?oo
oa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0J0?ooobT0
dLfY9@3oool00`000000oooo00000002000000040?ooo`0000000000000001`0oooo:@3AcJTU0?oo
o`040000003oool00000000000@0oooo0P00000K0?ooobT0dLfY9@3oool:000001/0oooo6`3AcJT0
01X0dLfY9@3oool2000000H0oooo0P00000K0?ooobT0dLfY9@3oool2000000050?ooo`0000000000
0000003oool00`00000K0?ooobT0dLfY9@3oool3000000D0oooo0P00000K0?ooobT0dLfY9@3oool:
000001/0oooo6`3AcJT001X0dLfY9@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01X0oooo:@3AcJTU0?ooo`<0000000H0oooo00000000000000000?ooo`00000L0?ooobT0dLfY9@3o
ool00`000000oooo00000006000001`0oooo:@3AcJTU0?ooo`T00000703ooolK0=7=Z@006P3AcJTU
0?ooo`P000007@3ooolY0=7=ZBD0oooo10000000103oool0000000000000000M0?ooobT0dLfY9@3o
ool3000000030?ooo`000000oooo008000007@3ooolY0=7=ZBD0oooo2000000M0?oooa/0dLfY000J
0=7=ZBD0oooo0P0000020?ooo`8000007`3ooolY0=7=ZBD0oooo0P000000103oool0000000000000
000O0?ooobT0dLfY9@3oool010000000oooo0?ooo`3oool2000001l0oooo:@3AcJTU0?ooo`H00000
7`3ooolK0=7=Z@006P3AcJTU0?ooo`050000003oool0oooo0?ooo`000000803ooolY0=7=ZBD0oooo
0`0000000`3oool000000?ooo`0O0?ooobT0dLfY9@3oool500000200oooo:@3AcJTU0?ooo`D00000
803ooolK0=7=Z@006P3AcJTU0?ooo`@000008@3ooolY0=7=ZBD0oooo1000000Q0?ooobT0dLfY9@3o
ool010000000oooo00000000000Q0?ooobT0dLfY9@3oool400000240oooo6`3AcJT001X0dLfY9@3o
ool00`000000oooo0000000R0?ooobT0dLfY9@3oool00`000000oooo0000000R0?ooobT0dLfY9@3o
ool300000280oooo:@3AcJTU0?ooo`<000008P3ooolK0=7=Z@006P3AcJTU0?ooo`8000008`3ooolY
0=7=ZBD0oooo0P00000S0?ooobT0dLfY9@3oool2000002<0oooo:@3AcJTU0?ooo`8000008`3ooolK
0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo
0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo
0280oooo6`3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT0
0?l0dLfYf@3AcJT003X0dLfY0d0000040=7=Z@900000JP3AcJT3@00000<0dLfY1D00001X0=7=Z@=0
00000`3AcJT4@00006T0dLfY0d0000040=7=Z@900000?03AcJT003X0dLfY00A000000=7=Z@3AcJU0
00000P3AcJT014000000dLfY0=7=ZD00001Y0=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=00000
0=7=Z@3AcJT0J03AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY06X0dLfY00A0
00000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000k0=7=Z@00>P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00006T0dLfY00A000000=7=Z@3AcJU00000103AcJT0
0d000000dLfY0=7=Z@1X0=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT0J@3A
cJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY03X0dLfY000j0=7=Z@=000000`3A
cJT014000000dLfY0=7=ZD00001Y0=7=Z@=000001@3AcJT00d000000dLfY0=7=Z@1X0=7=Z@=00000
1@3AcJT00d000000dLfY0=7=Z@1X0=7=Z@=000001P3AcJT00d000000dLfY0=7=Z@0i0=7=Z@00>`3A
cJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@00006X0dLfY00=000000=7=Z@3AcJT0
103AcJT00d000000dLfY0=7=Z@1Y0=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU0
0000JP3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@00003/0dLfY000k0=7=Z@=0
00000`3AcJT2@00006/0dLfY0d0000030=7=Z@900000J`3AcJT3@00000<0dLfY0T00001[0=7=Z@=0
00000`3AcJT2@00003`0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=
ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=
ZMT0dLfY000J0=7=ZBD0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`080000003oool00000
0?ooo`000000oooo0000003oool2000000030?ooo`000000oooo00800000:@3AcJTU0?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool020000000oooo0000003oool000000?ooo`000000oooo0P00
00000`3oool000000?ooo`02000002T0dLfY9@3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00P000000?ooo`000000oooo0000003oool000000?ooo`80000000<0oooo0000003oool00P00000Y
0=7=ZBD0oooo9@00000K0=7=Z@006P3AcJTU0?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
20000000oooo0000003oool000000?ooo`000000oooo0P0000001@3oool000000?ooo`000000oooo
02T0dLfY9@3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00P000000?ooo`000000oooo0000
003oool000000?ooo`80000000D0oooo0000003oool000000?ooo`0Y0=7=ZBD0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000003oool200000005
0?ooo`00000000000000003oool0:@3AcJTU0?ooob@0000000<0oooo0=7=Z@3AcJT06@3AcJT001X0
dLfY9@3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00P000000?ooo`000000oooo0000003o
ool000000?ooo`80000000<0oooo0000000000000P3ooolY0=7=ZBD0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000003oool2000000030?ooo`00
000000000080oooo:@3AcJTU0?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool020000000oooo
0000003oool000000?ooo`000000oooo0P0000000`3oool00000000000020?ooobT0dLfY9@3ooolS
00000080oooo6`3AcJT001X0dLfY9@3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00P00000
0?ooo`000000oooo0000003oool000000?ooo`80000000<0oooo0000003oool00P3ooolY0=7=ZBD0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000
003oool2000000030?ooo`000000oooo0080oooo:@3AcJTU0?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool020000000oooo0000003oool000000?ooo`000000oooo100000030?ooobT0dLfY9@3o
oolR000000<0oooo6`3AcJT001X0dLfY9@3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00P0
00000?ooo`000000oooo0000003oool000000?ooo`<00000103ooolY0=7=ZBD0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000003oool3000000@0
oooo:@3AcJTU0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool020000000oooo0000003oool0
00000?ooo`000000oooo0`0000040?ooobT0dLfY9@3ooolQ000000@0oooo6`3AcJT001X0dLfY9@3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00P000000?ooo`000000oooo0000003oool00000
0?ooo`8000001@3ooolY0=7=ZBD0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`080000003o
ool000000?ooo`000000oooo0000003oool2000000D0oooo:@3AcJTU0?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool020000000oooo0000003oool000000?ooo`000000oooo0P0000050?ooobT0
dLfY9@3ooolP000000D0oooo6`3AcJT001X0dLfY9@3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000001P3ooolY0=7=ZBD0oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool0
00000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000H0oooo:@3AcJTU0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000060?ooobT0dLfY9@3ooolO000000H0oooo6`3AcJT001X0
dLfY9@3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003o
ool000000?ooo`000000oooo0000003oool000000080oooo00H000000?ooo`000000oooo0000003o
ool2000000L0oooo:@3AcJTU0?ooo`090000003oool000000?ooo`000000oooo0000003oool00000
0080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01P000000oooo
0000003oool000000?ooo`8000001`3ooolY0=7=ZBD0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo00000002
0?ooo`060000003oool000000?ooo`000000oooo0P0000070?ooobT0dLfY9@3ooolN000000L0oooo
6`3AcJT001X0dLfY9@3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00L000000?ooo`000000
oooo0000003oool0000000P0oooo:@3AcJTU0?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
1`000000oooo0000003oool000000?ooo`000000203ooolY0=7=ZBD0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`040000003oool000000?ooo`<00000203ooolY0=7=ZBD0oooo7@0000080?oo
oa/0dLfY000J0=7=ZBD0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`040000003oool00000
0?ooo`8000002@3ooolY0=7=ZBD0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`040000003o
ool000000?ooo`8000002@3ooolY0=7=ZBD0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`04
0000003oool000000?ooo`8000002@3ooolY0=7=ZBD0oooo700000090?oooa/0dLfY000J0=7=ZBD0
oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000002P3ooolY
0=7=ZBD0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`000000
2P3ooolY0=7=ZBD0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool000000080
00002P3ooolY0=7=ZBD0oooo6`00000:0?oooa/0dLfY000J0=7=ZBD0oooo00T000000?ooo`000000
oooo0000003oool000000?ooo`0000000P3oool02@000000oooo0000003oool000000?ooo`000000
oooo000000020?ooo`040000003oool00000000000/0oooo:@3AcJTU0?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool010000000oooo00000000000;0?ooobT0dLfY9@3oool02@000000oooo0000
003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00@000000?ooo`00000000002`3ooolY0=7=ZBD0oooo6P00000;0?oooa/0
dLfY000J0=7=ZBD0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000`0
oooo:@3AcJTU0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00T0
00000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0000000<0?oo
obT0dLfY9@3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo0`00000<0?ooobT0dLfY9@3ooolI
000000`0oooo6`3AcJT001X0dLfY9@3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo0P00000=
0?ooobT0dLfY9@3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo0P00000=0?ooobT0dLfY9@3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool00000
0?ooo`000000oooo0000003oool000000080oooo0P00000=0?ooobT0dLfY9@3ooolH000000d0oooo
6`3AcJT001X0dLfY9@3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<000000?ooo`3oool0
303ooolY0=7=ZBD0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
2@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00`0
oooo:@3AcJTU0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00X0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0P00000>0?ooobT0dLfY9@3ooolG
000000h0oooo6`3AcJT001X0dLfY9@3oool02@000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000003`3o
oolY0=7=ZBD0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool02`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool0000000l0oooo:@3AcJTU0?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000000?0?ooobT0dLfY9@3ooolF000000l0oooo6`3AcJT0
01X0dLfY9@3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000140oooo:@3AcJTU0?ooo`090000003oool0
00000?ooo`000000oooo0000003oool000000080oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000004@3ooolY0=7=ZBD0oooo00T000000?ooo`000000oooo0000003oool000000?oo
o`0000000P3oool020000000oooo0000003oool000000?ooo`000000oooo0P00000@0?ooobT0dLfY
9@3ooolE00000100oooo6`3AcJT001X0dLfY9@3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`080000003oool000000?ooo`000000oooo0000003oool200000100oooo
:@3AcJTU0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00P00000
0?ooo`000000oooo0000003oool000000?ooo`800000403ooolY0=7=ZBD0oooo00T000000?ooo`00
0000oooo0000003oool000000?ooo`0000000P3oool020000000oooo0000003oool000000?ooo`00
0000oooo0P00000@0?ooobT0dLfY9@3ooolE00000100oooo6`3AcJT001X0dLfY9@3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?ooo`000000
oooo0000003oool000000140oooo:@3AcJTU0?ooo`090000003oool000000?ooo`000000oooo0000
003oool000000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000004@3ooolY
0=7=ZBD0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01P000000
oooo0000003oool000000?ooo`<000004@3ooolY0=7=ZBD0oooo5000000A0?oooa/0dLfY000J0=7=
ZBD0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool01`000000oooo
0000003oool000000?ooo`0000004`3ooolY0=7=ZBD0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool01`000000oooo0000003oool000000?ooo`0000004`3ooolY0=7=
ZBD0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool010000000oooo
0000003oool3000001<0oooo:@3AcJTU0?oooa8000004`3ooolK0=7=Z@006P3AcJTU0?ooo`090000
003oool000000?ooo`000000oooo0000003oool000000080oooo00@000000?ooo`000000oooo0P00
000D0?ooobT0dLfY9@3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?oo
o`040000003oool000000?ooo`800000503ooolY0=7=ZBD0oooo00T000000?ooo`000000oooo0000
003oool000000?ooo`0000000P3oool010000000oooo0000003oool2000001@0oooo:@3AcJTU0?oo
oa400000503ooolK0=7=Z@006P3AcJTU0?ooo`090000003oool000000?ooo`000000oooo0000003o
ool000000080oooo00D000000?ooo`000000oooo0000000E0?ooobT0dLfY9@3oool02@000000oooo
0000003oool000000?ooo`000000oooo000000020?ooo`050000003oool000000?ooo`0000005@3o
oolY0=7=ZBD0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo00000002000001D0oooo:@3AcJTU0?oooa0000005@3ooolK0=7=Z@006P3AcJTU0?ooo`09
0000003oool000000?ooo`000000oooo0000003oool000000080oooo00@000000?ooo`0000000000
5P3ooolY0=7=ZBD0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool0
10000000oooo00000000000F0?ooobT0dLfY9@3oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`040000003oool00000000001H0oooo:@3AcJTU0?ooo`l000005P3ooolK
0=7=Z@006P3AcJTU0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo
00<000000?ooo`0000005`3ooolY0=7=ZBD0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000P3oool00`000000oooo0000000G0?ooobT0dLfY9@3oool02@000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`<000005`3ooolY0=7=ZBD0oooo3P00000G0?oooa/0
dLfY000J0=7=ZBD0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool2
000001P0oooo:@3AcJTU0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080
oooo0P00000H0?ooobT0dLfY9@3oool02@000000oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`800000603ooolY0=7=ZBD0oooo3@00000H0?oooa/0dLfY000J0=7=ZBD0oooo00T00000
0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0G0?ooobT0
dLfY9@3oool02@000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003o
ool0oooo01L0oooo:@3AcJTU0?ooo`0:0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`8000006@3ooolY0=7=ZBD0oooo3000000I0?oooa/0dLfY000J0=7=ZBD0oooo00/000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000000J0?ooobT0dLfY9@3oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000001X0oooo:@3AcJTU0?ooo`0;0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000006P3ooolY0=7=ZBD0oooo2`00
000J0?oooa/0dLfY000J0=7=ZBD0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
0000703ooolY0=7=ZBD0oooo00T000000?ooo`000000oooo0000003oool000000?ooo`000000703o
oolY0=7=ZBD0oooo00P000000?ooo`000000oooo0000003oool000000?ooo`8000006`3ooolY0=7=
ZBD0oooo2P00000K0?oooa/0dLfY000J0=7=ZBD0oooo00P000000?ooo`000000oooo0000003oool0
00000?ooo`8000006`3ooolY0=7=ZBD0oooo00P000000?ooo`000000oooo0000003oool000000?oo
o`8000006`3ooolY0=7=ZBD0oooo00P000000?ooo`000000oooo0000003oool000000?ooo`800000
6`3ooolY0=7=ZBD0oooo2P00000K0?oooa/0dLfY000J0=7=ZBD0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`000000703ooolY0=7=ZBD0oooo00T000000?ooo`000000oooo0000003o
ool000000?ooo`000000703ooolY0=7=ZBD0oooo00H000000?ooo`000000oooo0000003oool30000
01`0oooo:@3AcJTU0?ooo`T00000703ooolK0=7=Z@006P3AcJTU0?ooo`060000003oool000000?oo
o`000000oooo0P00000M0?ooobT0dLfY9@3oool01P000000oooo0000003oool000000?ooo`800000
7@3ooolY0=7=ZBD0oooo00H000000?ooo`000000oooo0000003oool2000001d0oooo:@3AcJTU0?oo
o`P000007@3ooolK0=7=Z@006P3AcJTU0?ooo`040000003oool000000?ooo`8000007`3ooolY0=7=
ZBD0oooo00@000000?ooo`000000oooo0P00000O0?ooobT0dLfY9@3oool010000000oooo0000003o
ool2000001l0oooo:@3AcJTU0?ooo`H000007`3ooolK0=7=Z@006P3AcJTU0?ooo`050000003oool0
00000?ooo`000000803ooolY0=7=ZBD0oooo00D000000?ooo`000000oooo0000000P0?ooobT0dLfY
9@3oool00`000000oooo0000000200000200oooo:@3AcJTU0?ooo`D00000803ooolK0=7=Z@006P3A
cJTU0?ooo`040000003oool0000000000240oooo:@3AcJTU0?ooo`040000003oool0000000000240
oooo:@3AcJTU0?ooo`040000003oool0000000000240oooo:@3AcJTU0?ooo`@000008@3ooolK0=7=
Z@006P3AcJTU0?ooo`030000003oool000000280oooo:@3AcJTU0?ooo`030000003oool000000280
oooo:@3AcJTU0?ooo`<000008P3ooolY0=7=ZBD0oooo0`00000R0?oooa/0dLfY000J0=7=ZBD0oooo
0P00000S0?ooobT0dLfY9@3oool2000002<0oooo:@3AcJTU0?ooo`8000008`3ooolY0=7=ZBD0oooo
0P00000S0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<0
00000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<0
00000?ooo`3oool08P3ooolK0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00
o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00>`3AcJT2@00000<0dLfY0d00001[0=7=Z@9000001@3AcJT0
0d000000dLfY0=7=Z@1Y0=7=Z@900000103AcJT2@00006/0dLfY0T0000030=7=Z@=00000?03AcJT0
03X0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00001Y0=7=Z@04@000003A
cJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT0J03AcJT014000000dLfY0=7=ZD0000020=7=Z@04
@000003AcJT0dLfY@00006T0dLfY00A000000=7=Z@3AcJU00000103AcJT00d000000dLfY0=7=Z@0j
0=7=Z@00?@3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY06X0dLfY00=00000
0=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@1[0=7=Z@04@000003AcJT0dLfY@0000080dLfY00=0
00000=7=Z@3AcJT0JP3AcJT014000000dLfY0=7=Z@3AcJT3@00003/0dLfY000k0=7=Z@9000000`3A
cJT3@00006/0dLfY0T0000060=7=Z@03@000003AcJT0dLfY06P0dLfY0T0000040=7=Z@900000J`3A
cJT2@00000<0dLfY00A000000=7=Z@3AcJU00000>`3AcJT003/0dLfY00=000000=7=Z@3AcJT00`3A
cJT00d000000dLfY0=7=Z@1Z0=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU00000
JP3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@00006X0dLfY00=000000=7=Z@3A
cJT00P3AcJT014000000dLfY0=7=ZD00000k0=7=Z@00>`3AcJT3@00000<0dLfY0d00001Z0=7=Z@=0
00000P3AcJT4@00006X0dLfY0d0000030=7=Z@900000J`3AcJT3@00000<0dLfY0d00000k0=7=Z@00
o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00
o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@006P3AcJTU0?ooo`03
0000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`03
0000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo6`3AcJT001X0dLfY
9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY
9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?oooa/0dLfY
000J0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3o
oolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3o
oolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0
oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0
oooo0280oooo6`3AcJT001X0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`00
0000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`00
0000oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0
oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0
oooo00<000000?ooo`3oool08P3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo0280oooo
:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo
:@3AcJTU0?ooo`030000003oool0oooo0280oooo6`3AcJT001X0dLfY9@3oool00`000000oooo0?oo
o`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?oo
o`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0oooo00<00000
0?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<00000
0?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=Z@006P3AcJTU0?oo
o`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?oo
o`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo6`3AcJT001X0
dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0
dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?oooa/0
dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool0
8P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool0
8P3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003o
ool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003o
ool0oooo0280oooo6`3AcJT001X0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool0
0`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool0
0`000000oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=
ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=
ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo0280
oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280
oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo6`3AcJT001X0dLfY9@3oool00`000000oooo
0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo
0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0oooo00<0
00000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<0
00000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=Z@006P3AcJTU
0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU
0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo6`3AcJT0
01X0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?oo
obT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?oo
oa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3o
ool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3o
ool08P3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000
003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000
003oool0oooo0280oooo6`3AcJT001X0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3o
ool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3o
ool00`000000oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY
0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY
0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo
0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo
0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo6`3AcJT001X0dLfY9@3oool00`000000
oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000
oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0oooo
00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo
00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=Z@006P3A
cJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3A
cJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo6`3A
cJT001X0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R
0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R
0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?oo
o`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?oo
o`3oool08P3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`03
0000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`03
0000003oool0oooo0280oooo6`3AcJT001X0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY
9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY
9@3oool00`000000oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3o
oolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3o
oolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0
oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0
oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo6`3AcJT001X0dLfY9@3oool00`00
0000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`00
0000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0
oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0
oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=Z@00
o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00
o`3AcJWI0=7=Z@00>`3AcJT2@00000@0dLfY0T00001[0=7=Z@9000000`3AcJT5@00006T0dLfY0T00
00050=7=Z@=00000J@3AcJT2@00000@0dLfY0T00000l0=7=Z@00>P3AcJT014000000dLfY0=7=ZD00
00020=7=Z@04@000003AcJT0dLfY@00006T0dLfY00A000000=7=Z@3AcJU00000103AcJT00d000000
dLfY0=7=Z@1X0=7=Z@04@000003AcJT0dLfY@00000D0dLfY00=000000=7=Z@3AcJT0I`3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00003/0dLfY000m0=7=Z@04@000003AcJT0
dLfY@0000080dLfY00=000000=7=Z@3AcJT0JP3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003A
cJT0dLfY06/0dLfY00=000000=7=Z@3AcJT01D00001[0=7=Z@03@000003AcJT0dLfY00<0dLfY00=0
00000=7=Z@3AcJT0>@3AcJT003/0dLfY0T0000030=7=Z@04@000003AcJT0dLfY@00006X0dLfY0T00
00050=7=Z@03@000003AcJT0dLfY06T0dLfY0T0000030=7=Z@04@000003AcJT0dLfY@00006X0dLfY
0T0000040=7=Z@900000?03AcJT003/0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=
ZD00001Z0=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT0J@3AcJT00d000000dLfY
0=7=Z@030=7=Z@03@000003AcJU0000006X0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY
0=7=Z@0k0=7=Z@00>`3AcJT3@00000<0dLfY0T00001[0=7=Z@=000000`3AcJT2@00006/0dLfY0d00
00040=7=Z@900000JP3AcJT3@00000<0dLfY0d00000k0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=
Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=
Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@006P3AcJU80?ooo`800000:@3AcJU80?ooo`800000:@3A
cJU80?ooo`800000:@3AcJU80?ooo`8000006`3AcJT001X0dLfYB03oool00`000000oooo0=7=Z@0X
0=7=ZDP0oooo00<000000?ooo`3AcJT0:03AcJU70?ooo`80000000<0oooo0=7=Z@3AcJT09`3AcJU7
0?ooo`80000000<0oooo0=7=Z@3AcJT06@3AcJT001X0dLfYAP3oool200000080oooo:@3AcJU60?oo
o`8000000P3ooolY0=7=ZDH0oooo0P0000020?ooobT0dLfYAP3oool200000080oooo6`3AcJT001X0
dLfYAP3oool010000000oooo0?ooo`3ooolY0=7=ZDH0oooo00@000000?ooo`3oool0oooo:@3AcJU5
0?ooo`8000000`3ooolY0=7=ZDD0oooo0P0000030?oooa/0dLfY000J0=7=ZD@0oooo0P0000040?oo
obT0dLfYA03oool2000000@0oooo:@3AcJU40?ooo`800000103ooolY0=7=ZD@0oooo0P0000040?oo
oa/0dLfY000J0=7=ZD<0oooo00<000000?ooo`3oool0103ooolY0=7=ZD<0oooo00<000000?ooo`3o
ool0103ooolY0=7=ZD<0oooo00<000000?ooo`3oool0103ooolY0=7=ZD<0oooo00<000000?ooo`3o
ool0103ooolK0=7=Z@006P3AcJU30?ooo`030000003oool0oooo00@0oooo:@3AcJU30?ooo`030000
003oool0oooo00@0oooo:@3AcJU20?ooo`8000001P3ooolY0=7=ZD80oooo0P0000060?oooa/0dLfY
000J0=7=ZD40oooo0P0000070?ooobT0dLfY@@3oool2000000L0oooo:@3AcJU10?ooo`8000001`3o
oolY0=7=ZD40oooo0P0000070?oooa/0dLfY000J0=7=ZD40oooo00<000000?ooo`3oool01P3ooolY
0=7=ZD40oooo00<000000?ooo`3oool01P3ooolY0=7=ZD00oooo0P0000080?ooobT0dLfY@03oool2
000000P0oooo6`3AcJT001X0dLfY?`3oool2000000T0oooo:@3AcJTo0?ooo`8000002@3ooolY0=7=
ZCl0oooo0P0000090?ooobT0dLfY?`3oool2000000T0oooo6`3AcJT001X0dLfY?`3oool00`000000
oooo0?ooo`080?ooobT0dLfY?`3oool00`000000oooo0?ooo`080?ooobT0dLfY?P3oool2000000X0
oooo:@3AcJTn0?ooo`8000002P3ooolK0=7=Z@006P3AcJTm0?ooo`8000002`3ooolY0=7=ZCd0oooo
0P00000;0?ooobT0dLfY?@3oool2000000/0oooo:@3AcJTm0?ooo`8000002`3ooolK0=7=Z@006P3A
cJTm0?ooo`030000003oool0oooo00X0oooo:@3AcJTm0?ooo`030000003oool0oooo00X0oooo:@3A
cJTl0?ooo`800000303ooolY0=7=ZC`0oooo0P00000<0?oooa/0dLfY000J0=7=ZC/0oooo0P00000=
0?ooobT0dLfY>`3oool2000000d0oooo:@3AcJTk0?ooo`8000003@3ooolY0=7=ZC/0oooo0P00000=
0?oooa/0dLfY000J0=7=ZCX0oooo00<000000?ooo`3oool03@3ooolY0=7=ZCX0oooo00<000000?oo
o`3oool03@3ooolY0=7=ZCX0oooo00<000000?ooo`3oool03@3ooolY0=7=ZCX0oooo00<000000?oo
o`3oool03@3ooolK0=7=Z@006P3AcJU:0?ooobT0dLfYBP3ooolY0=7=ZCT0oooo00<000000?ooo`3o
ool03P3ooolY0=7=ZCT0oooo00<000000?ooo`3oool03P3ooolK0=7=Z@006P3AcJTh0?ooo`800000
403ooolY0=7=ZCP0oooo0P00000@0?ooobT0dLfY>03oool200000100oooo:@3AcJTh0?ooo`800000
403ooolK0=7=Z@006P3AcJTh0?ooo`030000003oool0oooo00l0oooo:@3AcJTh0?ooo`030000003o
ool0oooo00l0oooo:@3AcJTg0?ooo`8000004@3ooolY0=7=ZCL0oooo0P00000A0?oooa/0dLfY000J
0=7=ZCH0oooo0P00000B0?ooobT0dLfY=P3oool200000180oooo:@3AcJTf0?ooo`8000004P3ooolY
0=7=ZCH0oooo0P00000B0?oooa/0dLfY000J0=7=ZCH0oooo00<000000?ooo`3oool04@3ooolY0=7=
ZCH0oooo00<000000?ooo`3oool04@3ooolY0=7=ZCD0oooo0P00000C0?ooobT0dLfY=@3oool20000
01<0oooo6`3AcJT001X0dLfY=03oool2000001@0oooo:@3AcJTd0?ooo`800000503ooolY0=7=ZC@0
oooo0P00000D0?ooobT0dLfY=03oool2000001@0oooo6`3AcJT001X0dLfY=03oool00`000000oooo
0?ooo`0C0?ooobT0dLfY=03oool00`000000oooo0?ooo`0C0?ooobT0dLfY<`3oool2000001D0oooo
:@3AcJTc0?ooo`8000005@3ooolK0=7=Z@006P3AcJTb0?ooo`8000005P3ooolY0=7=ZC80oooo0P00
000F0?ooobT0dLfY<P3oool2000001H0oooo:@3AcJTb0?ooo`8000005P3ooolK0=7=Z@006P3AcJT`
0?ooo`800000603ooolY0=7=ZC00oooo0P00000H0?ooobT0dLfY<03oool2000001P0oooo:@3AcJT`
0?ooo`800000603ooolK0=7=Z@006P3AcJT`0?ooo`030000003oool0oooo01L0oooo:@3AcJT`0?oo
o`030000003oool0oooo01L0oooo:@3AcJT_0?ooo`8000006@3ooolY0=7=ZBl0oooo0P00000I0?oo
oa/0dLfY000J0=7=ZBl0oooo00<000000?ooo`3oool0603ooolY0=7=ZBl0oooo00<000000?ooo`3o
ool0603ooolY0=7=ZBl0oooo00<000000?ooo`3oool0603ooolY0=7=ZBl0oooo00<000000?ooo`3o
ool0603ooolK0=7=Z@006P3AcJU:0?ooobT0dLfYBP3ooolY0=7=ZBh0oooo00<000000?ooo`3oool0
6@3ooolY0=7=ZBh0oooo00<000000?ooo`3oool06@3ooolK0=7=Z@006P3AcJT]0?ooo`8000006`3o
oolY0=7=ZBd0oooo0P00000K0?ooobT0dLfY;@3oool2000001/0oooo:@3AcJT]0?ooo`8000006`3o
oolK0=7=Z@006P3AcJT]0?ooo`030000003oool0oooo01X0oooo:@3AcJT]0?ooo`030000003oool0
oooo01X0oooo:@3AcJT/0?ooo`800000703ooolY0=7=ZB`0oooo0P00000L0?oooa/0dLfY000J0=7=
ZB/0oooo0P00000M0?ooobT0dLfY:`3oool2000001d0oooo:@3AcJT[0?ooo`8000007@3ooolY0=7=
ZB/0oooo0P00000M0?oooa/0dLfY000J0=7=ZB/0oooo00<000000?ooo`3oool0703ooolY0=7=ZB/0
oooo00<000000?ooo`3oool0703ooolY0=7=ZBX0oooo0P00000N0?ooobT0dLfY:P3oool2000001h0
oooo6`3AcJT001X0dLfY:@3oool2000001l0oooo:@3AcJTY0?ooo`8000007`3ooolY0=7=ZBT0oooo
0P00000O0?ooobT0dLfY:@3oool2000001l0oooo6`3AcJT001X0dLfY9`3oool200000240oooo:@3A
cJTW0?ooo`8000008@3ooolY0=7=ZBL0oooo0P00000Q0?ooobT0dLfY9`3oool200000240oooo6`3A
cJT001X0dLfY9`3oool00`000000oooo0?ooo`0P0?ooobT0dLfY9`3oool00`000000oooo0?ooo`0P
0?ooobT0dLfY9P3oool200000280oooo:@3AcJTV0?ooo`8000008P3ooolK0=7=Z@006P3AcJTU0?oo
o`8000008`3ooolY0=7=ZBD0oooo0P00000S0?ooobT0dLfY9@3oool2000002<0oooo:@3AcJTU0?oo
o`8000008`3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`03
0000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`03
0000003oool0oooo0280oooo6`3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT0
0?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT003`0dLfY0d0000030=7=Z@=00000JP3A
cJT3@0000080dLfY0T00001/0=7=Z@=0000000@0dLfY@000040000100000K03AcJT3@00000<0dLfY
00=000000=7=Z@3AcJT0>P3AcJT003d0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=
Z@1Z0=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0JP3AcJT014000000dLfY
0=7=ZD0000020=7=Z@03@000003AcJT0dLfY06X0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000
dLfY0=7=Z@0j0=7=Z@00>P3AcJT5@00000030=7=ZD000010000000=00000J03AcJT5@00000@0dLfY
00=000000=7=Z@3AcJT0I`3AcJT5@00000050=7=ZD000000dLfY0=7=ZD000000J@3AcJT5@00000<0
dLfY00=000000=7=Z@3AcJT0>P3AcJT003X0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000
dLfY0=7=ZD00001Y0=7=Z@04@000003AcJT0dLfY@00000<0dLfY0T00001Z0=7=Z@04@000003AcJT0
dLfY@0000080dLfY0d00001Z0=7=Z@04@000003AcJT0dLfY@00000D0dLfY00=000000=7=Z@3AcJT0
>@3AcJT003/0dLfY00=000000=7=ZD0000000`3AcJT00d000000dLfY@000001Z0=7=Z@03@000003A
cJU0000000<0dLfY00=000000=7=Z@3AcJT0JP3AcJT00d000000dLfY@00000030=7=Z@03@000003A
cJT0dLfY06X0dLfY00=000000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD00000k0=7=Z@00?03A
cJT2@00000@0dLfY0T00001[0=7=Z@9000000`3AcJT3@00006/0dLfY0T0000030=7=Z@=00000J`3A
cJT2@0000080dLfY1400000k0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00
o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00
6P3AcJU80?ooo`800000:@3AcJU80?ooo`800000:@3AcJU80?ooo`800000:@3AcJU80?ooo`800000
6`3AcJT001X0dLfYB03oool00`000000oooo0=7=Z@0X0=7=ZDP0oooo00<000000?ooo`3AcJT0:03A
cJU70?ooo`80000000<0oooo0=7=Z@3AcJT09`3AcJU70?ooo`80000000<0oooo0=7=Z@3AcJT06@3A
cJT001X0dLfYAP3oool200000080oooo:@3AcJU60?ooo`8000000P3ooolY0=7=ZDH0oooo0P000002
0?ooobT0dLfYAP3oool200000080oooo6`3AcJT001X0dLfYAP3oool010000000oooo0?ooo`3ooolY
0=7=ZDH0oooo00@000000?ooo`3oool0oooo:@3AcJU50?ooo`8000000`3ooolY0=7=ZDD0oooo0P00
00030?oooa/0dLfY000J0=7=ZD@0oooo0P0000040?ooobT0dLfYA03oool2000000@0oooo:@3AcJU4
0?ooo`800000103ooolY0=7=ZD@0oooo0P0000040?oooa/0dLfY000J0=7=ZD@0oooo00<000000?oo
o`3oool00`3ooolY0=7=ZD@0oooo00<000000?ooo`3oool00`3ooolY0=7=ZD@0oooo00<000000?oo
o`3oool00`3ooolY0=7=ZD@0oooo00<000000?ooo`3oool00`3ooolK0=7=Z@006P3AcJU30?ooo`03
0000003oool0oooo00@0oooo:@3AcJU30?ooo`030000003oool0oooo00@0oooo:@3AcJU30?ooo`03
0000003oool0oooo00@0oooo:@3AcJU30?ooo`030000003oool0oooo00@0oooo6`3AcJT001X0dLfY
@@3oool2000000L0oooo:@3AcJU10?ooo`8000001`3ooolY0=7=ZD40oooo0P0000070?ooobT0dLfY
@@3oool2000000L0oooo6`3AcJT001X0dLfY@@3oool00`000000oooo0?ooo`060?ooobT0dLfY@@3o
ool00`000000oooo0?ooo`060?ooobT0dLfY@03oool2000000P0oooo:@3AcJU00?ooo`800000203o
oolK0=7=Z@006P3AcJTo0?ooo`8000002@3ooolY0=7=ZCl0oooo0P0000090?ooobT0dLfY?`3oool2
000000T0oooo:@3AcJTo0?ooo`8000002@3ooolK0=7=Z@006P3AcJTo0?ooo`030000003oool0oooo
00P0oooo:@3AcJTo0?ooo`030000003oool0oooo00P0oooo:@3AcJTn0?ooo`8000002P3ooolY0=7=
ZCh0oooo0P00000:0?oooa/0dLfY000J0=7=ZCd0oooo0P00000;0?ooobT0dLfY?@3oool2000000/0
oooo:@3AcJTm0?ooo`8000002`3ooolY0=7=ZCd0oooo0P00000;0?oooa/0dLfY000J0=7=ZCd0oooo
00<000000?ooo`3oool02P3ooolY0=7=ZCd0oooo00<000000?ooo`3oool02P3ooolY0=7=ZC`0oooo
0P00000<0?ooobT0dLfY?03oool2000000`0oooo6`3AcJT001X0dLfY>`3oool2000000d0oooo:@3A
cJTk0?ooo`8000003@3ooolY0=7=ZC/0oooo0P00000=0?ooobT0dLfY>`3oool2000000d0oooo6`3A
cJT001X0dLfY>`3oool00`000000oooo0?ooo`0<0?ooobT0dLfY>`3oool00`000000oooo0?ooo`0<
0?ooobT0dLfY>P3oool2000000h0oooo:@3AcJTj0?ooo`8000003P3ooolK0=7=Z@006P3AcJTj0?oo
o`030000003oool0oooo00d0oooo:@3AcJTj0?ooo`030000003oool0oooo00d0oooo:@3AcJTj0?oo
o`030000003oool0oooo00d0oooo:@3AcJTj0?ooo`030000003oool0oooo00d0oooo6`3AcJT001X0
dLfYBP3ooolY0=7=ZDX0oooo:@3AcJTi0?ooo`030000003oool0oooo00h0oooo:@3AcJTi0?ooo`03
0000003oool0oooo00h0oooo6`3AcJT001X0dLfY>03oool200000100oooo:@3AcJTh0?ooo`800000
403ooolY0=7=ZCP0oooo0P00000@0?ooobT0dLfY>03oool200000100oooo6`3AcJT001X0dLfY>03o
ool00`000000oooo0?ooo`0?0?ooobT0dLfY>03oool00`000000oooo0?ooo`0?0?ooobT0dLfY=`3o
ool200000140oooo:@3AcJTg0?ooo`8000004@3ooolK0=7=Z@006P3AcJTf0?ooo`030000003oool0
oooo0140oooo:@3AcJTf0?ooo`030000003oool0oooo0140oooo:@3AcJTe0?ooo`8000004`3ooolY
0=7=ZCD0oooo0P00000C0?oooa/0dLfY000J0=7=ZC@0oooo0P00000D0?ooobT0dLfY=03oool20000
01@0oooo:@3AcJTd0?ooo`800000503ooolY0=7=ZC@0oooo0P00000D0?oooa/0dLfY000J0=7=ZC@0
oooo00<000000?ooo`3oool04`3ooolY0=7=ZC@0oooo00<000000?ooo`3oool04`3ooolY0=7=ZC<0
oooo0P00000E0?ooobT0dLfY<`3oool2000001D0oooo6`3AcJT001X0dLfY<P3oool2000001H0oooo
:@3AcJTb0?ooo`8000005P3ooolY0=7=ZC80oooo0P00000F0?ooobT0dLfY<P3oool2000001H0oooo
6`3AcJT001X0dLfY<P3oool00`000000oooo0?ooo`0E0?ooobT0dLfY<P3oool00`000000oooo0?oo
o`0E0?ooobT0dLfY<@3oool2000001L0oooo:@3AcJTa0?ooo`8000005`3ooolK0=7=Z@006P3AcJT`
0?ooo`800000603ooolY0=7=ZC00oooo0P00000H0?ooobT0dLfY<03oool2000001P0oooo:@3AcJT`
0?ooo`800000603ooolK0=7=Z@006P3AcJT`0?ooo`030000003oool0oooo01L0oooo:@3AcJT`0?oo
o`030000003oool0oooo01L0oooo:@3AcJT_0?ooo`8000006@3ooolY0=7=ZBl0oooo0P00000I0?oo
oa/0dLfY000J0=7=ZBl0oooo00<000000?ooo`3oool0603ooolY0=7=ZBl0oooo00<000000?ooo`3o
ool0603ooolY0=7=ZBl0oooo00<000000?ooo`3oool0603ooolY0=7=ZBl0oooo00<000000?ooo`3o
ool0603ooolK0=7=Z@006P3AcJU:0?ooobT0dLfYBP3ooolY0=7=ZBh0oooo00<000000?ooo`3oool0
6@3ooolY0=7=ZBh0oooo00<000000?ooo`3oool06@3ooolK0=7=Z@006P3AcJT]0?ooo`8000006`3o
oolY0=7=ZBd0oooo0P00000K0?ooobT0dLfY;@3oool2000001/0oooo:@3AcJT]0?ooo`8000006`3o
oolK0=7=Z@006P3AcJT]0?ooo`030000003oool0oooo01X0oooo:@3AcJT]0?ooo`030000003oool0
oooo01X0oooo:@3AcJT/0?ooo`800000703ooolY0=7=ZB`0oooo0P00000L0?oooa/0dLfY000J0=7=
ZB/0oooo0P00000M0?ooobT0dLfY:`3oool2000001d0oooo:@3AcJT[0?ooo`8000007@3ooolY0=7=
ZB/0oooo0P00000M0?oooa/0dLfY000J0=7=ZBT0oooo0P00000O0?ooobT0dLfY:@3oool2000001l0
oooo:@3AcJTY0?ooo`8000007`3ooolY0=7=ZBT0oooo0P00000O0?oooa/0dLfY000J0=7=ZBT0oooo
00<000000?ooo`3oool07P3ooolY0=7=ZBT0oooo00<000000?ooo`3oool07P3ooolY0=7=ZBP0oooo
0P00000P0?ooobT0dLfY:03oool200000200oooo6`3AcJT001X0dLfY9`3oool200000240oooo:@3A
cJTW0?ooo`8000008@3ooolY0=7=ZBL0oooo0P00000Q0?ooobT0dLfY9`3oool200000240oooo6`3A
cJT001X0dLfY9`3oool00`000000oooo0?ooo`0P0?ooobT0dLfY9`3oool00`000000oooo0?ooo`0P
0?ooobT0dLfY9P3oool200000280oooo:@3AcJTV0?ooo`8000008P3ooolK0=7=Z@006P3AcJTU0?oo
o`8000008`3ooolY0=7=ZBD0oooo0P00000S0?ooobT0dLfY9@3oool2000002<0oooo:@3AcJTU0?oo
o`8000008`3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`03
0000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`03
0000003oool0oooo0280oooo6`3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT0
0?l0dLfYf@3AcJT00?l0dLfYf@3AcJT003`0dLfY0d0000020=7=Z@900000K03AcJT3@00000030=7=
ZD000010000000=00000JP3AcJT3@00000030=7=ZD000010000000900000J`3AcJT3@0000080dLfY
0T00000l0=7=Z@00?@3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY06X0dLfY
00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@1[0=7=Z@04@000003AcJT0dLfY@00006l0
dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0i0=7=Z@00>P3AcJT5@0000005
0=7=ZD000000dLfY0=7=ZD000000J@3AcJT5@00000<0dLfY00=000000=7=Z@3AcJT0J03AcJT5@000
0080dLfY00=000000=7=Z@3AcJT0J@3AcJT5@00000<0dLfY00=000000=7=Z@3AcJT0>P3AcJT003X0
dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00001Y0=7=Z@04@000003AcJT0
dLfY@00000@0dLfY00=000000=7=Z@3AcJT0J03AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000
003AcJT0dLfY06P0dLfY00A000000=7=Z@3AcJU000001@3AcJT00d000000dLfY0=7=Z@0i0=7=Z@00
>`3AcJT00d000000dLfY@00000020=7=Z@04@000003AcJT0dLfY@00006X0dLfY00=000000=7=ZD00
0000103AcJT00d000000dLfY0=7=Z@1Y0=7=Z@03@000003AcJU000000080dLfY00A000000=7=Z@3A
cJU00000JP3AcJT00d000000dLfY@00000020=7=Z@04@000003AcJT0dLfY@00003/0dLfY000l0=7=
Z@9000000`3AcJT2@00006`0dLfY0T0000030=7=Z@900000K03AcJT2@00000<0dLfY0T00001/0=7=
Z@9000000`3AcJT2@00003`0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o
0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o
0=7=ZMT0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?oo
o`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?oo
o`3oool08P3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`03
0000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`03
0000003oool0oooo0280oooo6`3AcJT001X0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY
9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY
9@3oool00`000000oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3o
oolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3o
oolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0
oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0
oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo6`3AcJT001X0dLfY9@3oool00`00
0000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`00
0000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0
oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0
oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=Z@00
6P3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo
:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo
6`3AcJT001X0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?oo
o`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?oo
o`0R0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<00000
0?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<00000
0?ooo`3oool08P3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?oo
o`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?oo
o`030000003oool0oooo0280oooo6`3AcJT001X0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0
dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0
dLfY9@3oool00`000000oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool0
8P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool0
8P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=Z@006P3AcJTU0?ooo`030000003o
ool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003o
ool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo6`3AcJT001X0dLfY9@3oool0
0`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool0
0`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?oooa/0dLfY000J0=7=
ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=
ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=
Z@006P3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280
oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280
oooo6`3AcJT001X0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo
0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo
0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<0
00000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<0
00000?ooo`3oool08P3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU
0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU
0?ooo`030000003oool0oooo0280oooo6`3AcJT001X0dLfY9@3oool00`000000oooo0?ooo`0R0?oo
obT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?oo
obT0dLfY9@3oool00`000000oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3o
ool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3o
ool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=Z@006P3AcJTU0?ooo`030000
003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000
003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo6`3AcJT001X0dLfY9@3o
ool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3o
ool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?oooa/0dLfY000J
0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY
0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolK
0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo
0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo
0280oooo6`3AcJT001X0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000
oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000
oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo
00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo
00<000000?ooo`3oool08P3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo0280oooo:@3A
cJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3A
cJTU0?ooo`030000003oool0oooo0280oooo6`3AcJT001X0dLfY9@3oool00`000000oooo0?ooo`0R
0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R
0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?oo
o`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?oo
o`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=Z@006P3AcJTU0?ooo`03
0000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`03
0000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo6`3AcJT001X0dLfY
9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY
9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?oooa/0dLfY
000J0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3o
oolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3o
oolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0
oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0
oooo0280oooo6`3AcJT001X0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`00
0000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`00
0000oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0
oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0
oooo00<000000?ooo`3oool08P3ooolK0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI
0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00>`3AcJT2@00000<0dLfY0d00001[0=7=Z@900000
1@3AcJT00d000000dLfY0=7=Z@1Y0=7=Z@900000103AcJT2@00006/0dLfY0T0000030=7=Z@=00000
?03AcJT003X0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00001Y0=7=Z@04
@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT0J03AcJT014000000dLfY0=7=ZD000002
0=7=Z@04@000003AcJT0dLfY@00006T0dLfY00A000000=7=Z@3AcJU00000103AcJT00d000000dLfY
0=7=Z@0j0=7=Z@00?03AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0
J@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY06X0dLfY00E000000=7=Z@3AcJT0
dLfY@00000020=7=Z@03@000003AcJT0dLfY06T0dLfY00=000000=7=Z@3AcJT00P3AcJT3@00003/0
dLfY000m0=7=Z@03@000003AcJT0dLfY00=00000K@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000
003AcJT0dLfY06X0dLfY00A000000=7=Z@3AcJT0dLfY0T00001]0=7=Z@04@000003AcJT0dLfY@000
0080dLfY00=000000=7=Z@3AcJT0>@3AcJT003X0dLfY00A000000=7=Z@3AcJU000000`3AcJT00d00
0000dLfY0=7=Z@1Y0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000J@3A
cJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00006T0dLfY00A000000=7=Z@3A
cJU000000P3AcJT014000000dLfY0=7=ZD00000k0=7=Z@00>`3AcJT2@00000@0dLfY0d00001Z0=7=
Z@9000000`3AcJT4@00006X0dLfY0T0000040=7=Z@900000J`3AcJT2@00000@0dLfY0d00000k0=7=
Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=
Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@006P3AcJTU0?oo
o`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?oo
o`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo6`3AcJT001X0
dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0
dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?oooa/0
dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool0
8P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool0
8P3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003o
ool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003o
ool0oooo0280oooo6`3AcJT001X0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool0
0`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool0
0`000000oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=
ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=
ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo0280
oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280
oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo6`3AcJT001X0dLfY9@3oool00`000000oooo
0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo
0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0oooo00<0
00000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<0
00000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=Z@006P3AcJTU
0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU
0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo6`3AcJT0
01X0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?oo
obT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?oo
oa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3o
ool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3o
ool08P3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000
003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000
003oool0oooo0280oooo6`3AcJT001X0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3o
ool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3o
ool00`000000oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY
0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY
0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo
0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo
0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo6`3AcJT001X0dLfY9@3oool00`000000
oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000
oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0oooo
00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo
00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=Z@006P3A
cJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3A
cJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo6`3A
cJT001X0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R
0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R
0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?oo
o`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?oo
o`3oool08P3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`03
0000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`03
0000003oool0oooo0280oooo6`3AcJT001X0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY
9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY
9@3oool00`000000oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3o
oolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3o
oolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0
oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0
oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo6`3AcJT001X0dLfY9@3oool00`00
0000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`00
0000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0
oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0
oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=Z@00
6P3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo
:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo
6`3AcJT001X0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?oo
o`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?oo
o`0R0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<00000
0?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<00000
0?ooo`3oool08P3ooolK0=7=Z@006P3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?oo
o`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?oo
o`030000003oool0oooo0280oooo6`3AcJT001X0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0
dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0
dLfY9@3oool00`000000oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool0
8P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool0
8P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=Z@006P3AcJTU0?ooo`030000003o
ool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo:@3AcJTU0?ooo`030000003o
ool0oooo0280oooo:@3AcJTU0?ooo`030000003oool0oooo0280oooo6`3AcJT001X0dLfY9@3oool0
0`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool0
0`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?oooa/0dLfY000J0=7=
ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=
ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=
Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=
Z@00o`3AcJWI0=7=Z@00>`3AcJT2@00000<0dLfY1400001Z0=7=Z@900000103AcJT2@00006/0dLfY
0T0000050=7=Z@=00000J@3AcJT2@00000@0dLfY0T00000l0=7=Z@00>P3AcJT014000000dLfY0=7=
ZD0000020=7=Z@03@000003AcJT0dLfY06X0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000
dLfY0=7=ZD00001Y0=7=Z@04@000003AcJT0dLfY@00000D0dLfY00=000000=7=Z@3AcJT0I`3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00003/0dLfY000l0=7=Z@03@000003A
cJT0dLfY0080dLfY00=000000=7=Z@3AcJT0J`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003A
cJT0dLfY06X0dLfY00A000000=7=Z@3AcJT0dLfY1D00001Z0=7=Z@03@000003AcJT0dLfY00@0dLfY
00=000000=7=Z@3AcJT0>@3AcJT003d0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=
Z@1[0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0JP3AcJT014000000dLfY0=7=
ZD0000020=7=Z@03@000003AcJT0dLfY06X0dLfY00A000000=7=Z@3AcJT0dLfY0T00000l0=7=Z@00
>P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00006T0dLfY00A000000=7=
Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00001Y0=7=Z@04@000003AcJT0dLfY@00000<0dLfY
00=000000=7=ZD000000J@3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY03/0
dLfY000k0=7=Z@900000103AcJT2@00006/0dLfY0T0000040=7=Z@900000J`3AcJT2@00000D0dLfY
0T00001Z0=7=Z@900000103AcJT3@00003/0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=
ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=
ZMT0dLfY003o0=7=ZMT0dLfY000J0=7=ZDT0oooo00<000000=7=Z@3AcJT09`3AcJU90?ooo`030000
003AcJT0dLfY02L0dLfYB@3oool00`000000dLfY0=7=Z@0W0=7=ZDT0oooo00<000000=7=Z@3AcJT0
6@3AcJT001X0dLfYB03oool00`000000oooo0=7=Z@0X0=7=ZDP0oooo00<000000?ooo`3AcJT0:03A
cJU80?ooo`030000003oool0dLfY02P0dLfYB03oool00`000000oooo0=7=Z@0J0=7=Z@006P3AcJU7
0?ooo`030000003oool0oooo02T0dLfYA`3oool00`000000oooo0?ooo`0Y0=7=ZDL0oooo00<00000
0?ooo`3oool0:@3AcJU70?ooo`030000003oool0oooo01/0dLfY000J0=7=ZDH0oooo00@000000?oo
o`3oool0oooo:@3AcJU60?ooo`040000003oool0oooo0?ooobT0dLfYAP3oool010000000oooo0?oo
o`3ooolY0=7=ZDH0oooo00@000000?ooo`3oool0oooo6`3AcJT001X0dLfYA@3oool00`000000oooo
0?ooo`020?ooobT0dLfYA@3oool00`000000oooo0?ooo`020?ooobT0dLfYA@3oool00`000000oooo
0?ooo`020?ooobT0dLfYA@3oool00`000000oooo0?ooo`020?oooa/0dLfY000J0=7=ZDX0oooo:@3A
cJU:0?ooobT0dLfYBP3ooolY0=7=ZDX0oooo6`3AcJT001X0dLfY@`3oool00`000000oooo0?ooo`04
0?ooobT0dLfY@`3oool00`000000oooo0?ooo`040?ooobT0dLfY@`3oool00`000000oooo0?ooo`04
0?ooobT0dLfY@`3oool00`000000oooo0?ooo`040?oooa/0dLfY000J0=7=ZD80oooo00<000000?oo
o`3oool01@3ooolY0=7=ZD80oooo00<000000?ooo`3oool01@3ooolY0=7=ZD80oooo00<000000?oo
o`3oool01@3ooolY0=7=ZD80oooo00<000000?ooo`3oool01@3ooolK0=7=Z@006P3AcJU10?ooo`03
0000003oool0oooo00H0oooo:@3AcJU10?ooo`030000003oool0oooo00H0oooo:@3AcJU10?ooo`03
0000003oool0oooo00H0oooo:@3AcJU10?ooo`030000003oool0oooo00H0oooo6`3AcJT001X0dLfY
@03oool00`000000oooo0?ooo`070?ooobT0dLfY@03oool00`000000oooo0?ooo`070?ooobT0dLfY
@03oool00`000000oooo0?ooo`070?ooobT0dLfY@03oool00`000000oooo0?ooo`070?oooa/0dLfY
000J0=7=ZCl0oooo00<000000?ooo`3oool0203ooolY0=7=ZCl0oooo00<000000?ooo`3oool0203o
oolY0=7=ZCl0oooo00<000000?ooo`3oool0203ooolY0=7=ZCl0oooo00<000000?ooo`3oool0203o
oolK0=7=Z@006P3AcJTn0?ooo`030000003oool0oooo00T0oooo:@3AcJTn0?ooo`030000003oool0
oooo00T0oooo:@3AcJTn0?ooo`030000003oool0oooo00T0oooo:@3AcJTn0?ooo`030000003oool0
oooo00T0oooo6`3AcJT001X0dLfY?@3oool00`000000oooo0?ooo`0:0?ooobT0dLfY?@3oool00`00
0000oooo0?ooo`0:0?ooobT0dLfY?@3oool00`000000oooo0?ooo`0:0?ooobT0dLfY?@3oool00`00
0000oooo0?ooo`0:0?oooa/0dLfY000J0=7=ZC`0oooo00<000000?ooo`3oool02`3ooolY0=7=ZC`0
oooo00<000000?ooo`3oool02`3ooolY0=7=ZC`0oooo00<000000?ooo`3oool02`3ooolY0=7=ZC`0
oooo00<000000?ooo`3oool02`3ooolK0=7=Z@006P3AcJTj0?ooo`030000003oool0oooo00d0oooo
:@3AcJTj0?ooo`030000003oool0oooo00d0oooo:@3AcJTj0?ooo`030000003oool0oooo00d0oooo
:@3AcJTj0?ooo`030000003oool0oooo00d0oooo6`3AcJT001X0dLfYBP3ooolY0=7=ZDX0oooo:@3A
cJU:0?ooobT0dLfYBP3ooolK0=7=Z@006P3AcJTi0?ooo`030000003oool0oooo00h0oooo:@3AcJTi
0?ooo`030000003oool0oooo00h0oooo:@3AcJTi0?ooo`030000003oool0oooo00h0oooo:@3AcJTi
0?ooo`030000003oool0oooo00h0oooo6`3AcJT001X0dLfY>03oool00`000000oooo0?ooo`0?0?oo
obT0dLfY>03oool00`000000oooo0?ooo`0?0?ooobT0dLfY>03oool00`000000oooo0?ooo`0?0?oo
obT0dLfY>03oool00`000000oooo0?ooo`0?0?oooa/0dLfY000J0=7=ZCL0oooo00<000000?ooo`3o
ool0403ooolY0=7=ZCL0oooo00<000000?ooo`3oool0403ooolY0=7=ZCL0oooo00<000000?ooo`3o
ool0403ooolY0=7=ZCL0oooo00<000000?ooo`3oool0403ooolK0=7=Z@006P3AcJTf0?ooo`030000
003oool0oooo0140oooo:@3AcJTf0?ooo`030000003oool0oooo0140oooo:@3AcJTf0?ooo`030000
003oool0oooo0140oooo:@3AcJTf0?ooo`030000003oool0oooo0140oooo6`3AcJT001X0dLfY=@3o
ool00`000000oooo0?ooo`0B0?ooobT0dLfY=@3oool00`000000oooo0?ooo`0B0?ooobT0dLfY=@3o
ool00`000000oooo0?ooo`0B0?ooobT0dLfY=@3oool00`000000oooo0?ooo`0B0?oooa/0dLfY000J
0=7=ZC@0oooo00<000000?ooo`3oool04`3ooolY0=7=ZC@0oooo00<000000?ooo`3oool04`3ooolY
0=7=ZC@0oooo00<000000?ooo`3oool04`3ooolY0=7=ZC@0oooo00<000000?ooo`3oool04`3ooolK
0=7=Z@006P3AcJTc0?ooo`030000003oool0oooo01@0oooo:@3AcJTc0?ooo`030000003oool0oooo
01@0oooo:@3AcJTc0?ooo`030000003oool0oooo01@0oooo:@3AcJTc0?ooo`030000003oool0oooo
01@0oooo6`3AcJT001X0dLfY<@3oool00`000000oooo0?ooo`0F0?ooobT0dLfY<@3oool00`000000
oooo0?ooo`0F0?ooobT0dLfY<@3oool00`000000oooo0?ooo`0F0?ooobT0dLfY<@3oool00`000000
oooo0?ooo`0F0?oooa/0dLfY000J0=7=ZC00oooo00<000000?ooo`3oool05`3ooolY0=7=ZC00oooo
00<000000?ooo`3oool05`3ooolY0=7=ZC00oooo00<000000?ooo`3oool05`3ooolY0=7=ZC00oooo
00<000000?ooo`3oool05`3ooolK0=7=Z@006P3AcJT_0?ooo`030000003oool0oooo01P0oooo:@3A
cJT_0?ooo`030000003oool0oooo01P0oooo:@3AcJT_0?ooo`030000003oool0oooo01P0oooo:@3A
cJT_0?ooo`030000003oool0oooo01P0oooo6`3AcJT001X0dLfYBP3ooolY0=7=ZDX0oooo:@3AcJU:
0?ooobT0dLfYBP3ooolK0=7=Z@006P3AcJT^0?ooo`030000003oool0oooo01T0oooo:@3AcJT^0?oo
o`030000003oool0oooo01T0oooo:@3AcJT^0?ooo`030000003oool0oooo01T0oooo:@3AcJT^0?oo
o`030000003oool0oooo01T0oooo6`3AcJT001X0dLfY;@3oool00`000000oooo0?ooo`0J0?ooobT0
dLfY;@3oool00`000000oooo0?ooo`0J0?ooobT0dLfY;@3oool00`000000oooo0?ooo`0J0?ooobT0
dLfY;@3oool00`000000oooo0?ooo`0J0?oooa/0dLfY000J0=7=ZB`0oooo00<000000?ooo`3oool0
6`3ooolY0=7=ZB`0oooo00<000000?ooo`3oool06`3ooolY0=7=ZB`0oooo00<000000?ooo`3oool0
6`3ooolY0=7=ZB`0oooo00<000000?ooo`3oool06`3ooolK0=7=Z@006P3AcJT[0?ooo`030000003o
ool0oooo01`0oooo:@3AcJT[0?ooo`030000003oool0oooo01`0oooo:@3AcJT[0?ooo`030000003o
ool0oooo01`0oooo:@3AcJT[0?ooo`030000003oool0oooo01`0oooo6`3AcJT001X0dLfY:P3oool0
0`000000oooo0?ooo`0M0?ooobT0dLfY:P3oool00`000000oooo0?ooo`0M0?ooobT0dLfY:P3oool0
0`000000oooo0?ooo`0M0?ooobT0dLfY:P3oool00`000000oooo0?ooo`0M0?oooa/0dLfY000J0=7=
ZBP0oooo00<000000?ooo`3oool07`3ooolY0=7=ZBP0oooo00<000000?ooo`3oool07`3ooolY0=7=
ZBP0oooo00<000000?ooo`3oool07`3ooolY0=7=ZBP0oooo00<000000?ooo`3oool07`3ooolK0=7=
Z@006P3AcJTW0?ooo`030000003oool0oooo0200oooo:@3AcJTW0?ooo`030000003oool0oooo0200
oooo:@3AcJTW0?ooo`030000003oool0oooo0200oooo:@3AcJTW0?ooo`030000003oool0oooo0200
oooo6`3AcJT001X0dLfY9P3oool00`000000oooo0?ooo`0Q0?ooobT0dLfY9P3oool00`000000oooo
0?ooo`0Q0?ooobT0dLfY9P3oool00`000000oooo0?ooo`0Q0?ooobT0dLfY9P3oool00`000000oooo
0?ooo`0Q0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<0
00000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<0
00000?ooo`3oool08P3ooolK0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00
o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00>P3AcJT4@00000<0dLfY0T00001Z0=7=
Z@A000000P3AcJT3@00006/0dLfY0T0000040=7=Z@900000J`3AcJT2@00000<0dLfY1D00000j0=7=
Z@00>P3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@00006T0dLfY00=000000=7=
Z@3AcJT01@3AcJT00d000000dLfY0=7=Z@1X0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A00000
0=7=Z@3AcJU00000J@3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY03X0dLfY
000k0=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU00000JP3AcJT00d000000dLfY
0=7=Z@030=7=Z@=00000J`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3A
cJT0J@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY03X0dLfY000l0=7=Z@03@000
003AcJT0dLfY0080dLfY0T00001/0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000
dLfY0=7=Z@1Z0=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0JP3AcJT00d00
0000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY03X0dLfY000j0=7=Z@04@000003AcJT0dLfY@000
0080dLfY00A000000=7=Z@3AcJU00000J@3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003A
cJT0dLfY@00006T0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00001Y0=7=
Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT0>P3AcJT003/0dLfY0T0000040=7=
Z@900000J`3AcJT2@00000@0dLfY0d00001Z0=7=Z@900000103AcJT2@00006/0dLfY0T0000040=7=
Z@900000?03AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT0
0?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT001X0dLfYB@3oool0
0`000000dLfY0=7=Z@0W0=7=ZDT0oooo00<000000=7=Z@3AcJT09`3AcJU90?ooo`030000003AcJT0
dLfY02L0dLfYB@3oool00`000000dLfY0=7=Z@0I0=7=Z@006P3AcJU80?ooo`030000003oool0dLfY
02P0dLfYB03oool00`000000oooo0=7=Z@0X0=7=ZDP0oooo00<000000?ooo`3AcJT0:03AcJU80?oo
o`030000003oool0dLfY01X0dLfY000J0=7=ZDL0oooo00<000000?ooo`3oool0:@3AcJU70?ooo`03
0000003oool0oooo02T0dLfYA`3oool00`000000oooo0?ooo`0Y0=7=ZDL0oooo00<000000?ooo`3o
ool06`3AcJT001X0dLfYAP3oool010000000oooo0?ooo`3ooolY0=7=ZDH0oooo00@000000?ooo`3o
ool0oooo:@3AcJU60?ooo`040000003oool0oooo0?ooobT0dLfYAP3oool010000000oooo0?ooo`3o
oolK0=7=Z@006P3AcJU50?ooo`030000003oool0oooo0080oooo:@3AcJU50?ooo`030000003oool0
oooo0080oooo:@3AcJU50?ooo`030000003oool0oooo0080oooo:@3AcJU50?ooo`030000003oool0
oooo0080oooo6`3AcJT001X0dLfYA03oool00`000000oooo0?ooo`030?ooobT0dLfYA03oool00`00
0000oooo0?ooo`030?ooobT0dLfYA03oool00`000000oooo0?ooo`030?ooobT0dLfYA03oool00`00
0000oooo0?ooo`030?oooa/0dLfY000J0=7=ZDX0oooo:@3AcJU:0?ooobT0dLfYBP3ooolY0=7=ZDX0
oooo6`3AcJT001X0dLfY@P3oool00`000000oooo0?ooo`050?ooobT0dLfY@P3oool00`000000oooo
0?ooo`050?ooobT0dLfY@P3oool00`000000oooo0?ooo`050?ooobT0dLfY@P3oool00`000000oooo
0?ooo`050?oooa/0dLfY000J0=7=ZD40oooo00<000000?ooo`3oool01P3ooolY0=7=ZD40oooo00<0
00000?ooo`3oool01P3ooolY0=7=ZD40oooo00<000000?ooo`3oool01P3ooolY0=7=ZD40oooo00<0
00000?ooo`3oool01P3ooolK0=7=Z@006P3AcJU00?ooo`030000003oool0oooo00L0oooo:@3AcJU0
0?ooo`030000003oool0oooo00L0oooo:@3AcJU00?ooo`030000003oool0oooo00L0oooo:@3AcJU0
0?ooo`030000003oool0oooo00L0oooo6`3AcJT001X0dLfY?`3oool00`000000oooo0?ooo`080?oo
obT0dLfY?`3oool00`000000oooo0?ooo`080?ooobT0dLfY?`3oool00`000000oooo0?ooo`080?oo
obT0dLfY?`3oool00`000000oooo0?ooo`080?oooa/0dLfY000J0=7=ZCh0oooo00<000000?ooo`3o
ool02@3ooolY0=7=ZCh0oooo00<000000?ooo`3oool02@3ooolY0=7=ZCh0oooo00<000000?ooo`3o
ool02@3ooolY0=7=ZCh0oooo00<000000?ooo`3oool02@3ooolK0=7=Z@006P3AcJTm0?ooo`030000
003oool0oooo00X0oooo:@3AcJTm0?ooo`030000003oool0oooo00X0oooo:@3AcJTm0?ooo`030000
003oool0oooo00X0oooo:@3AcJTm0?ooo`030000003oool0oooo00X0oooo6`3AcJT001X0dLfY?03o
ool00`000000oooo0?ooo`0;0?ooobT0dLfY?03oool00`000000oooo0?ooo`0;0?ooobT0dLfY?03o
ool00`000000oooo0?ooo`0;0?ooobT0dLfY?03oool00`000000oooo0?ooo`0;0?oooa/0dLfY000J
0=7=ZC/0oooo00<000000?ooo`3oool0303ooolY0=7=ZC/0oooo00<000000?ooo`3oool0303ooolY
0=7=ZC/0oooo00<000000?ooo`3oool0303ooolY0=7=ZC/0oooo00<000000?ooo`3oool0303ooolK
0=7=Z@006P3AcJTj0?ooo`030000003oool0oooo00d0oooo:@3AcJTj0?ooo`030000003oool0oooo
00d0oooo:@3AcJTj0?ooo`030000003oool0oooo00d0oooo:@3AcJTj0?ooo`030000003oool0oooo
00d0oooo6`3AcJT001X0dLfYBP3ooolY0=7=ZDX0oooo:@3AcJU:0?ooobT0dLfYBP3ooolK0=7=Z@00
6P3AcJTi0?ooo`030000003oool0oooo00h0oooo:@3AcJTi0?ooo`030000003oool0oooo00h0oooo
:@3AcJTi0?ooo`030000003oool0oooo00h0oooo:@3AcJTi0?ooo`030000003oool0oooo00h0oooo
6`3AcJT001X0dLfY>03oool00`000000oooo0?ooo`0?0?ooobT0dLfY>03oool00`000000oooo0?oo
o`0?0?ooobT0dLfY>03oool00`000000oooo0?ooo`0?0?ooobT0dLfY>03oool00`000000oooo0?oo
o`0?0?oooa/0dLfY000J0=7=ZCH0oooo00<000000?ooo`3oool04@3ooolY0=7=ZCH0oooo00<00000
0?ooo`3oool04@3ooolY0=7=ZCH0oooo00<000000?ooo`3oool04@3ooolY0=7=ZCH0oooo00<00000
0?ooo`3oool04@3ooolK0=7=Z@006P3AcJTe0?ooo`030000003oool0oooo0180oooo:@3AcJTe0?oo
o`030000003oool0oooo0180oooo:@3AcJTe0?ooo`030000003oool0oooo0180oooo:@3AcJTe0?oo
o`030000003oool0oooo0180oooo6`3AcJT001X0dLfY=03oool00`000000oooo0?ooo`0C0?ooobT0
dLfY=03oool00`000000oooo0?ooo`0C0?ooobT0dLfY=03oool00`000000oooo0?ooo`0C0?ooobT0
dLfY=03oool00`000000oooo0?ooo`0C0?oooa/0dLfY000J0=7=ZC<0oooo00<000000?ooo`3oool0
503ooolY0=7=ZC<0oooo00<000000?ooo`3oool0503ooolY0=7=ZC<0oooo00<000000?ooo`3oool0
503ooolY0=7=ZC<0oooo00<000000?ooo`3oool0503ooolK0=7=Z@006P3AcJTb0?ooo`030000003o
ool0oooo01D0oooo:@3AcJTb0?ooo`030000003oool0oooo01D0oooo:@3AcJTb0?ooo`030000003o
ool0oooo01D0oooo:@3AcJTb0?ooo`030000003oool0oooo01D0oooo6`3AcJT001X0dLfY<@3oool0
0`000000oooo0?ooo`0F0?ooobT0dLfY<@3oool00`000000oooo0?ooo`0F0?ooobT0dLfY<@3oool0
0`000000oooo0?ooo`0F0?ooobT0dLfY<@3oool00`000000oooo0?ooo`0F0?oooa/0dLfY000J0=7=
ZC00oooo00<000000?ooo`3oool05`3ooolY0=7=ZC00oooo00<000000?ooo`3oool05`3ooolY0=7=
ZC00oooo00<000000?ooo`3oool05`3ooolY0=7=ZC00oooo00<000000?ooo`3oool05`3ooolK0=7=
Z@006P3AcJT_0?ooo`030000003oool0oooo01P0oooo:@3AcJT_0?ooo`030000003oool0oooo01P0
oooo:@3AcJT_0?ooo`030000003oool0oooo01P0oooo:@3AcJT_0?ooo`030000003oool0oooo01P0
oooo6`3AcJT001X0dLfYBP3ooolY0=7=ZDX0oooo:@3AcJU:0?ooobT0dLfYBP3ooolK0=7=Z@006P3A
cJT^0?ooo`030000003oool0oooo01T0oooo:@3AcJT^0?ooo`030000003oool0oooo01T0oooo:@3A
cJT^0?ooo`030000003oool0oooo01T0oooo:@3AcJT^0?ooo`030000003oool0oooo01T0oooo6`3A
cJT001X0dLfY;@3oool00`000000oooo0?ooo`0J0?ooobT0dLfY;@3oool00`000000oooo0?ooo`0J
0?ooobT0dLfY;@3oool00`000000oooo0?ooo`0J0?ooobT0dLfY;@3oool00`000000oooo0?ooo`0J
0?oooa/0dLfY000J0=7=ZB`0oooo00<000000?ooo`3oool06`3ooolY0=7=ZB`0oooo00<000000?oo
o`3oool06`3ooolY0=7=ZB`0oooo00<000000?ooo`3oool06`3ooolY0=7=ZB`0oooo00<000000?oo
o`3oool06`3ooolK0=7=Z@006P3AcJTZ0?ooo`030000003oool0oooo01d0oooo:@3AcJTZ0?ooo`03
0000003oool0oooo01d0oooo:@3AcJTZ0?ooo`030000003oool0oooo01d0oooo:@3AcJTZ0?ooo`03
0000003oool0oooo01d0oooo6`3AcJT001X0dLfY:@3oool00`000000oooo0?ooo`0N0?ooobT0dLfY
:@3oool00`000000oooo0?ooo`0N0?ooobT0dLfY:@3oool00`000000oooo0?ooo`0N0?ooobT0dLfY
:@3oool00`000000oooo0?ooo`0N0?oooa/0dLfY000J0=7=ZBP0oooo00<000000?ooo`3oool07`3o
oolY0=7=ZBP0oooo00<000000?ooo`3oool07`3ooolY0=7=ZBP0oooo00<000000?ooo`3oool07`3o
oolY0=7=ZBP0oooo00<000000?ooo`3oool07`3ooolK0=7=Z@006P3AcJTW0?ooo`030000003oool0
oooo0200oooo:@3AcJTW0?ooo`030000003oool0oooo0200oooo:@3AcJTW0?ooo`030000003oool0
oooo0200oooo:@3AcJTW0?ooo`030000003oool0oooo0200oooo6`3AcJT001X0dLfY9P3oool00`00
0000oooo0?ooo`0Q0?ooobT0dLfY9P3oool00`000000oooo0?ooo`0Q0?ooobT0dLfY9P3oool00`00
0000oooo0?ooo`0Q0?ooobT0dLfY9P3oool00`000000oooo0?ooo`0Q0?oooa/0dLfY000J0=7=ZBD0
oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0
oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolK0=7=Z@00
o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00
>P3AcJT4@00000@0dLfY0d00001X0=7=Z@A000000`3AcJT2@00006X0dLfY140000020=7=Z@=00000
JP3AcJT4@00000@0dLfY00=000000=7=Z@3AcJT0>P3AcJT003X0dLfY00=000000=7=Z@3AcJT01P3A
cJT00d000000dLfY0=7=Z@1W0=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU00000
J@3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@00006T0dLfY00=000000=7=Z@3A
cJT01@3AcJT00d000000dLfY0=7=Z@0j0=7=Z@00>`3AcJT00d000000dLfY0=7=Z@020=7=Z@E00000
J@3AcJT00d000000dLfY0=7=Z@050=7=Z@03@000003AcJT0dLfY06P0dLfY00=000000=7=Z@3AcJT0
0P3AcJT014000000dLfY0=7=ZD00001Z0=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3A
cJT0>P3AcJT003`0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY06T0
dLfY00=000000=7=Z@3AcJT00P3AcJT2@00006`0dLfY00A000000=7=Z@3AcJT0dLfY0d00001/0=7=
Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT0>@3AcJT003X0dLfY00A000000=7=Z@3A
cJU000000`3AcJT00d000000dLfY@000001Y0=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=00000
0=7=Z@3AcJT0J@3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY06T0dLfY00A0
00000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000k0=7=Z@00>`3AcJT2@00000D0dLfY
0T00001Z0=7=Z@900000103AcJT3@00006X0dLfY0T0000040=7=Z@=00000JP3AcJT2@00000<0dLfY
1400000k0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00
o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00
6P3AcJU90?ooo`030000003AcJT0dLfY02L0dLfYB@3oool00`000000dLfY0=7=Z@0W0=7=ZDT0oooo
00<000000=7=Z@3AcJT09`3AcJU90?ooo`030000003AcJT0dLfY01T0dLfY000J0=7=ZDP0oooo00<0
00000?ooo`3AcJT0:03AcJU80?ooo`030000003oool0dLfY02P0dLfYB03oool00`000000oooo0=7=
Z@0X0=7=ZDP0oooo00<000000?ooo`3AcJT06P3AcJT001X0dLfYA`3oool00`000000oooo0?ooo`0Y
0=7=ZDL0oooo00<000000?ooo`3oool0:@3AcJU70?ooo`030000003oool0oooo02T0dLfYA`3oool0
0`000000oooo0?ooo`0K0=7=Z@006P3AcJU60?ooo`040000003oool0oooo0?ooobT0dLfYAP3oool0
10000000oooo0?ooo`3ooolY0=7=ZDH0oooo00@000000?ooo`3oool0oooo:@3AcJU60?ooo`040000
003oool0oooo0?oooa/0dLfY000J0=7=ZDD0oooo00<000000?ooo`3oool00P3ooolY0=7=ZDD0oooo
00<000000?ooo`3oool00P3ooolY0=7=ZDD0oooo00<000000?ooo`3oool00P3ooolY0=7=ZDD0oooo
00<000000?ooo`3oool00P3ooolK0=7=Z@006P3AcJU40?ooo`030000003oool0oooo00<0oooo:@3A
cJU40?ooo`030000003oool0oooo00<0oooo:@3AcJU40?ooo`030000003oool0oooo00<0oooo:@3A
cJU40?ooo`030000003oool0oooo00<0oooo6`3AcJT001X0dLfYBP3ooolY0=7=ZDX0oooo:@3AcJU:
0?ooobT0dLfYBP3ooolK0=7=Z@006P3AcJU20?ooo`030000003oool0oooo00D0oooo:@3AcJU20?oo
o`030000003oool0oooo00D0oooo:@3AcJU20?ooo`030000003oool0oooo00D0oooo:@3AcJU20?oo
o`030000003oool0oooo00D0oooo6`3AcJT001X0dLfY@@3oool00`000000oooo0?ooo`060?ooobT0
dLfY@@3oool00`000000oooo0?ooo`060?ooobT0dLfY@@3oool00`000000oooo0?ooo`060?ooobT0
dLfY@@3oool00`000000oooo0?ooo`060?oooa/0dLfY000J0=7=ZD00oooo00<000000?ooo`3oool0
1`3ooolY0=7=ZD00oooo00<000000?ooo`3oool01`3ooolY0=7=ZD00oooo00<000000?ooo`3oool0
1`3ooolY0=7=ZD00oooo00<000000?ooo`3oool01`3ooolK0=7=Z@006P3AcJTo0?ooo`030000003o
ool0oooo00P0oooo:@3AcJTo0?ooo`030000003oool0oooo00P0oooo:@3AcJTo0?ooo`030000003o
ool0oooo00P0oooo:@3AcJTo0?ooo`030000003oool0oooo00P0oooo6`3AcJT001X0dLfY?P3oool0
0`000000oooo0?ooo`090?ooobT0dLfY?P3oool00`000000oooo0?ooo`090?ooobT0dLfY?P3oool0
0`000000oooo0?ooo`090?ooobT0dLfY?P3oool00`000000oooo0?ooo`090?oooa/0dLfY000J0=7=
ZCd0oooo00<000000?ooo`3oool02P3ooolY0=7=ZCd0oooo00<000000?ooo`3oool02P3ooolY0=7=
ZCd0oooo00<000000?ooo`3oool02P3ooolY0=7=ZCd0oooo00<000000?ooo`3oool02P3ooolK0=7=
Z@006P3AcJTl0?ooo`030000003oool0oooo00/0oooo:@3AcJTl0?ooo`030000003oool0oooo00/0
oooo:@3AcJTl0?ooo`030000003oool0oooo00/0oooo:@3AcJTl0?ooo`030000003oool0oooo00/0
oooo6`3AcJT001X0dLfY>`3oool00`000000oooo0?ooo`0<0?ooobT0dLfY>`3oool00`000000oooo
0?ooo`0<0?ooobT0dLfY>`3oool00`000000oooo0?ooo`0<0?ooobT0dLfY>`3oool00`000000oooo
0?ooo`0<0?oooa/0dLfY000J0=7=ZCX0oooo00<000000?ooo`3oool03@3ooolY0=7=ZCX0oooo00<0
00000?ooo`3oool03@3ooolY0=7=ZCX0oooo00<000000?ooo`3oool03@3ooolY0=7=ZCX0oooo00<0
00000?ooo`3oool03@3ooolK0=7=Z@006P3AcJU:0?ooobT0dLfYBP3ooolY0=7=ZDX0oooo:@3AcJU:
0?oooa/0dLfY000J0=7=ZCT0oooo00<000000?ooo`3oool03P3ooolY0=7=ZCT0oooo00<000000?oo
o`3oool03P3ooolY0=7=ZCT0oooo00<000000?ooo`3oool03P3ooolY0=7=ZCT0oooo00<000000?oo
o`3oool03P3ooolK0=7=Z@006P3AcJTh0?ooo`030000003oool0oooo00l0oooo:@3AcJTh0?ooo`03
0000003oool0oooo00l0oooo:@3AcJTh0?ooo`030000003oool0oooo00l0oooo:@3AcJTh0?ooo`03
0000003oool0oooo00l0oooo6`3AcJT001X0dLfY=P3oool00`000000oooo0?ooo`0A0?ooobT0dLfY
=P3oool00`000000oooo0?ooo`0A0?ooobT0dLfY=P3oool00`000000oooo0?ooo`0A0?ooobT0dLfY
=P3oool00`000000oooo0?ooo`0A0?oooa/0dLfY000J0=7=ZCD0oooo00<000000?ooo`3oool04P3o
oolY0=7=ZCD0oooo00<000000?ooo`3oool04P3ooolY0=7=ZCD0oooo00<000000?ooo`3oool04P3o
oolY0=7=ZCD0oooo00<000000?ooo`3oool04P3ooolK0=7=Z@006P3AcJTd0?ooo`030000003oool0
oooo01<0oooo:@3AcJTd0?ooo`030000003oool0oooo01<0oooo:@3AcJTd0?ooo`030000003oool0
oooo01<0oooo:@3AcJTd0?ooo`030000003oool0oooo01<0oooo6`3AcJT001X0dLfY<`3oool00`00
0000oooo0?ooo`0D0?ooobT0dLfY<`3oool00`000000oooo0?ooo`0D0?ooobT0dLfY<`3oool00`00
0000oooo0?ooo`0D0?ooobT0dLfY<`3oool00`000000oooo0?ooo`0D0?oooa/0dLfY000J0=7=ZC80
oooo00<000000?ooo`3oool05@3ooolY0=7=ZC80oooo00<000000?ooo`3oool05@3ooolY0=7=ZC80
oooo00<000000?ooo`3oool05@3ooolY0=7=ZC80oooo00<000000?ooo`3oool05@3ooolK0=7=Z@00
6P3AcJTa0?ooo`030000003oool0oooo01H0oooo:@3AcJTa0?ooo`030000003oool0oooo01H0oooo
:@3AcJTa0?ooo`030000003oool0oooo01H0oooo:@3AcJTa0?ooo`030000003oool0oooo01H0oooo
6`3AcJT001X0dLfY<03oool00`000000oooo0?ooo`0G0?ooobT0dLfY<03oool00`000000oooo0?oo
o`0G0?ooobT0dLfY<03oool00`000000oooo0?ooo`0G0?ooobT0dLfY<03oool00`000000oooo0?oo
o`0G0?oooa/0dLfY000J0=7=ZBl0oooo00<000000?ooo`3oool0603ooolY0=7=ZBl0oooo00<00000
0?ooo`3oool0603ooolY0=7=ZBl0oooo00<000000?ooo`3oool0603ooolY0=7=ZBl0oooo00<00000
0?ooo`3oool0603ooolK0=7=Z@006P3AcJU:0?ooobT0dLfYBP3ooolY0=7=ZDX0oooo:@3AcJU:0?oo
oa/0dLfY000J0=7=ZBh0oooo00<000000?ooo`3oool06@3ooolY0=7=ZBh0oooo00<000000?ooo`3o
ool06@3ooolY0=7=ZBh0oooo00<000000?ooo`3oool06@3ooolY0=7=ZBh0oooo00<000000?ooo`3o
ool06@3ooolK0=7=Z@006P3AcJT]0?ooo`030000003oool0oooo01X0oooo:@3AcJT]0?ooo`030000
003oool0oooo01X0oooo:@3AcJT]0?ooo`030000003oool0oooo01X0oooo:@3AcJT]0?ooo`030000
003oool0oooo01X0oooo6`3AcJT001X0dLfY;03oool00`000000oooo0?ooo`0K0?ooobT0dLfY;03o
ool00`000000oooo0?ooo`0K0?ooobT0dLfY;03oool00`000000oooo0?ooo`0K0?ooobT0dLfY;03o
ool00`000000oooo0?ooo`0K0?oooa/0dLfY000J0=7=ZBX0oooo00<000000?ooo`3oool07@3ooolY
0=7=ZBX0oooo00<000000?ooo`3oool07@3ooolY0=7=ZBX0oooo00<000000?ooo`3oool07@3ooolY
0=7=ZBX0oooo00<000000?ooo`3oool07@3ooolK0=7=Z@006P3AcJTY0?ooo`030000003oool0oooo
01h0oooo:@3AcJTY0?ooo`030000003oool0oooo01h0oooo:@3AcJTY0?ooo`030000003oool0oooo
01h0oooo:@3AcJTY0?ooo`030000003oool0oooo01h0oooo6`3AcJT001X0dLfY:03oool00`000000
oooo0?ooo`0O0?ooobT0dLfY:03oool00`000000oooo0?ooo`0O0?ooobT0dLfY:03oool00`000000
oooo0?ooo`0O0?ooobT0dLfY:03oool00`000000oooo0?ooo`0O0?oooa/0dLfY000J0=7=ZBL0oooo
00<000000?ooo`3oool0803ooolY0=7=ZBL0oooo00<000000?ooo`3oool0803ooolY0=7=ZBL0oooo
00<000000?ooo`3oool0803ooolY0=7=ZBL0oooo00<000000?ooo`3oool0803ooolK0=7=Z@006P3A
cJTV0?ooo`030000003oool0oooo0240oooo:@3AcJTV0?ooo`030000003oool0oooo0240oooo:@3A
cJTV0?ooo`030000003oool0oooo0240oooo:@3AcJTV0?ooo`030000003oool0oooo0240oooo6`3A
cJT001X0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R
0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R0?ooobT0dLfY9@3oool00`000000oooo0?ooo`0R
0?oooa/0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o
0=7=ZMT0dLfY000j0=7=Z@E0000000<0dLfY@000040000000T00001Y0=7=Z@E000000P3AcJT2@000
06X0dLfY1D0000030=7=Z@=00000J03AcJT5@0000080dLfY0T00000l0=7=Z@00?03AcJT01D000000
dLfY0=7=Z@3AcJU0000006h0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0
dLfY06T0dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@1Y0=7=Z@05@000003AcJT0
dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0i0=7=Z@00?03AcJT00d000000dLfY0=7=Z@02
0=7=Z@03@000003AcJT0dLfY06/0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@1Z
0=7=Z@04@000003AcJT0dLfY0=7=Z@E00000JP3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003A
cJT0dLfY03T0dLfY000l0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0JP3AcJT0
0d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY06T0dLfY00E000000=7=Z@3AcJT0dLfY@000
00020=7=Z@03@000003AcJT0dLfY06T0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00003`0dLfY000l
0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@1Y0=7=Z@05@000003A
cJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@1Y0=7=Z@03@000003AcJT0dLfY0080dLfY
00=000000=7=ZD000000J`3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY03/0dLfY
000k0=7=Z@900000103AcJT2@00006/0dLfY0T0000040=7=Z@900000J`3AcJT2@00000D0dLfY0T00
001Z0=7=Z@900000103AcJT3@00003/0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0
dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0dLfY003o0=7=ZMT0
dLfY003o0=7=ZMT0dLfY000J0=7=ZDT0oooo00<000000=7=Z@3AcJT09`3AcJU90?ooo`030000003A
cJT0dLfY02L0dLfYB@3oool00`000000dLfY0=7=Z@0W0=7=ZDT0oooo00<000000=7=Z@3AcJT06@3A
cJT001X0dLfYB03oool00`000000oooo0=7=Z@0X0=7=ZDP0oooo00<000000?ooo`3AcJT0:03AcJU8
0?ooo`030000003oool0dLfY02P0dLfYB03oool00`000000oooo0=7=Z@0J0=7=Z@006P3AcJU70?oo
o`030000003oool0oooo02T0dLfYA`3oool00`000000oooo0?ooo`0Y0=7=ZDL0oooo00<000000?oo
o`3oool0:@3AcJU70?ooo`030000003oool0oooo01/0dLfY000J0=7=ZDH0oooo00@000000?ooo`3o
ool0oooo:@3AcJU60?ooo`040000003oool0oooo0?ooobT0dLfYAP3oool010000000oooo0?ooo`3o
oolY0=7=ZDH0oooo00@000000?ooo`3oool0oooo6`3AcJT001X0dLfYA@3oool00`000000oooo0?oo
o`020?ooobT0dLfYA@3oool00`000000oooo0?ooo`020?ooobT0dLfYA@3oool00`000000oooo0?oo
o`020?ooobT0dLfYA@3oool00`000000oooo0?ooo`020?oooa/0dLfY000J0=7=ZDX0oooo:@3AcJU:
0?ooobT0dLfYBP3ooolY0=7=ZDX0oooo6`3AcJT001X0dLfY@`3oool00`000000oooo0?ooo`040?oo
obT0dLfY@`3oool00`000000oooo0?ooo`040?ooobT0dLfY@`3oool00`000000oooo0?ooo`040?oo
obT0dLfY@`3oool00`000000oooo0?ooo`040?oooa/0dLfY000J0=7=ZD80oooo00<000000?ooo`3o
ool01@3ooolY0=7=ZD80oooo00<000000?ooo`3oool01@3ooolY0=7=ZD80oooo00<000000?ooo`3o
ool01@3ooolY0=7=ZD80oooo00<000000?ooo`3oool01@3ooolK0=7=Z@006P3AcJU10?ooo`030000
003oool0oooo00H0oooo:@3AcJU10?ooo`030000003oool0oooo00H0oooo:@3AcJU10?ooo`030000
003oool0oooo00H0oooo:@3AcJU10?ooo`030000003oool0oooo00H0oooo6`3AcJT001X0dLfY@03o
ool00`000000oooo0?ooo`070?ooobT0dLfY@03oool00`000000oooo0?ooo`070?ooobT0dLfY@03o
ool00`000000oooo0?ooo`070?ooobT0dLfY@03oool00`000000oooo0?ooo`070?oooa/0dLfY000J
0=7=ZCl0oooo00<000000?ooo`3oool0203ooolY0=7=ZCl0oooo00<000000?ooo`3oool0203ooolY
0=7=ZCl0oooo00<000000?ooo`3oool0203ooolY0=7=ZCl0oooo00<000000?ooo`3oool0203ooolK
0=7=Z@006P3AcJTn0?ooo`030000003oool0oooo00T0oooo:@3AcJTn0?ooo`030000003oool0oooo
00T0oooo:@3AcJTn0?ooo`030000003oool0oooo00T0oooo:@3AcJTn0?ooo`030000003oool0oooo
00T0oooo6`3AcJT001X0dLfY?@3oool00`000000oooo0?ooo`0:0?ooobT0dLfY?@3oool00`000000
oooo0?ooo`0:0?ooobT0dLfY?@3oool00`000000oooo0?ooo`0:0?ooobT0dLfY?@3oool00`000000
oooo0?ooo`0:0?oooa/0dLfY000J0=7=ZC`0oooo00<000000?ooo`3oool02`3ooolY0=7=ZC`0oooo
00<000000?ooo`3oool02`3ooolY0=7=ZC`0oooo00<000000?ooo`3oool02`3ooolY0=7=ZC`0oooo
00<000000?ooo`3oool02`3ooolK0=7=Z@006P3AcJTj0?ooo`030000003oool0oooo00d0oooo:@3A
cJTj0?ooo`030000003oool0oooo00d0oooo:@3AcJTj0?ooo`030000003oool0oooo00d0oooo:@3A
cJTj0?ooo`030000003oool0oooo00d0oooo6`3AcJT001X0dLfYBP3ooolY0=7=ZDX0oooo:@3AcJU:
0?ooobT0dLfYBP3ooolK0=7=Z@006P3AcJTi0?ooo`030000003oool0oooo00h0oooo:@3AcJTi0?oo
o`030000003oool0oooo00h0oooo:@3AcJTi0?ooo`030000003oool0oooo00h0oooo:@3AcJTi0?oo
o`030000003oool0oooo00h0oooo6`3AcJT001X0dLfY>03oool00`000000oooo0?ooo`0?0?ooobT0
dLfY>03oool00`000000oooo0?ooo`0?0?ooobT0dLfY>03oool00`000000oooo0?ooo`0?0?ooobT0
dLfY>03oool00`000000oooo0?ooo`0?0?oooa/0dLfY000J0=7=ZCL0oooo00<000000?ooo`3oool0
403ooolY0=7=ZCL0oooo00<000000?ooo`3oool0403ooolY0=7=ZCL0oooo00<000000?ooo`3oool0
403ooolY0=7=ZCL0oooo00<000000?ooo`3oool0403ooolK0=7=Z@006P3AcJTf0?ooo`030000003o
ool0oooo0140oooo:@3AcJTf0?ooo`030000003oool0oooo0140oooo:@3AcJTf0?ooo`030000003o
ool0oooo0140oooo:@3AcJTf0?ooo`030000003oool0oooo0140oooo6`3AcJT001X0dLfY=@3oool0
0`000000oooo0?ooo`0B0?ooobT0dLfY=@3oool00`000000oooo0?ooo`0B0?ooobT0dLfY=@3oool0
0`000000oooo0?ooo`0B0?ooobT0dLfY=@3oool00`000000oooo0?ooo`0B0?oooa/0dLfY000J0=7=
ZC@0oooo00<000000?ooo`3oool04`3ooolY0=7=ZC@0oooo00<000000?ooo`3oool04`3ooolY0=7=
ZC@0oooo00<000000?ooo`3oool04`3ooolY0=7=ZC@0oooo00<000000?ooo`3oool04`3ooolK0=7=
Z@006P3AcJTc0?ooo`030000003oool0oooo01@0oooo:@3AcJTc0?ooo`030000003oool0oooo01@0
oooo:@3AcJTc0?ooo`030000003oool0oooo01@0oooo:@3AcJTc0?ooo`030000003oool0oooo01@0
oooo6`3AcJT001X0dLfY<@3oool00`000000oooo0?ooo`0F0?ooobT0dLfY<@3oool00`000000oooo
0?ooo`0F0?ooobT0dLfY<@3oool00`000000oooo0?ooo`0F0?ooobT0dLfY<@3oool00`000000oooo
0?ooo`0F0?oooa/0dLfY000J0=7=ZC00oooo00<000000?ooo`3oool05`3ooolY0=7=ZC00oooo00<0
00000?ooo`3oool05`3ooolY0=7=ZC00oooo00<000000?ooo`3oool05`3ooolY0=7=ZC00oooo00<0
00000?ooo`3oool05`3ooolK0=7=Z@006P3AcJT_0?ooo`030000003oool0oooo01P0oooo:@3AcJT_
0?ooo`030000003oool0oooo01P0oooo:@3AcJT_0?ooo`030000003oool0oooo01P0oooo:@3AcJT_
0?ooo`030000003oool0oooo01P0oooo6`3AcJT001X0dLfYBP3ooolY0=7=ZDX0oooo:@3AcJU:0?oo
obT0dLfYBP3ooolK0=7=Z@006P3AcJT^0?ooo`030000003oool0oooo01T0oooo:@3AcJT^0?ooo`03
0000003oool0oooo01T0oooo:@3AcJT^0?ooo`030000003oool0oooo01T0oooo:@3AcJT^0?ooo`03
0000003oool0oooo01T0oooo6`3AcJT001X0dLfY;@3oool00`000000oooo0?ooo`0J0?ooobT0dLfY
;@3oool00`000000oooo0?ooo`0J0?ooobT0dLfY;@3oool00`000000oooo0?ooo`0J0?ooobT0dLfY
;@3oool00`000000oooo0?ooo`0J0?oooa/0dLfY000J0=7=ZB`0oooo00<000000?ooo`3oool06`3o
oolY0=7=ZB`0oooo00<000000?ooo`3oool06`3ooolY0=7=ZB`0oooo00<000000?ooo`3oool06`3o
oolY0=7=ZB`0oooo00<000000?ooo`3oool06`3ooolK0=7=Z@006P3AcJT[0?ooo`030000003oool0
oooo01`0oooo:@3AcJT[0?ooo`030000003oool0oooo01`0oooo:@3AcJT[0?ooo`030000003oool0
oooo01`0oooo:@3AcJT[0?ooo`030000003oool0oooo01`0oooo6`3AcJT001X0dLfY:P3oool00`00
0000oooo0?ooo`0M0?ooobT0dLfY:P3oool00`000000oooo0?ooo`0M0?ooobT0dLfY:P3oool00`00
0000oooo0?ooo`0M0?ooobT0dLfY:P3oool00`000000oooo0?ooo`0M0?oooa/0dLfY000J0=7=ZBP0
oooo00<000000?ooo`3oool07`3ooolY0=7=ZBP0oooo00<000000?ooo`3oool07`3ooolY0=7=ZBP0
oooo00<000000?ooo`3oool07`3ooolY0=7=ZBP0oooo00<000000?ooo`3oool07`3ooolK0=7=Z@00
6P3AcJTW0?ooo`030000003oool0oooo0200oooo:@3AcJTW0?ooo`030000003oool0oooo0200oooo
:@3AcJTW0?ooo`030000003oool0oooo0200oooo:@3AcJTW0?ooo`030000003oool0oooo0200oooo
6`3AcJT001X0dLfY9P3oool00`000000oooo0?ooo`0Q0?ooobT0dLfY9P3oool00`000000oooo0?oo
o`0Q0?ooobT0dLfY9P3oool00`000000oooo0?ooo`0Q0?ooobT0dLfY9P3oool00`000000oooo0?oo
o`0Q0?oooa/0dLfY000J0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<00000
0?ooo`3oool08P3ooolY0=7=ZBD0oooo00<000000?ooo`3oool08P3ooolY0=7=ZBD0oooo00<00000
0?ooo`3oool08P3ooolK0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3A
cJWI0=7=Z@00o`3AcJWI0=7=Z@00o`3AcJWI0=7=Z@00?P3AcJT2@0000700dLfY0d00001]0=7=Z@E0
00000P3AcJT2@00006X0dLfY1D0000000`3AcJU00000@0000003@00003X0dLfY000m0=7=Z@04@000
003AcJT0dLfY@0000740dLfY00=000000=7=Z@3AcJT0K@3AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00=000000=7=Z@3AcJT0J@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY
03X0dLfY000m0=7=Z@04@000003AcJT0dLfY@0000700dLfY0d00001^0=7=Z@05@000003AcJT0dLfY
0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@1Y0=7=Z@03@000003AcJT0dLfY00<0dLfY00=00000
0=7=Z@3AcJT0>P3AcJT003h0dLfY0T00001`0=7=Z@04@000003AcJT0dLfY@00006h0dLfY00E00000
0=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY06T0dLfY00=000000=7=Z@3AcJT00`3A
cJT00d000000dLfY0=7=Z@0j0=7=Z@00?@3AcJT014000000dLfY0=7=ZD00001_0=7=Z@04@000003A
cJT0dLfY@00006h0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY06T0
dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0j0=7=Z@00?P3AcJT2@0000740dLfY
0d00001]0=7=Z@900000103AcJT2@00006/0dLfY0T0000040=7=Z@900000?03AcJT00?l0dLfYf@3A
cJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3A
cJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3A
cJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3A
cJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3A
cJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3AcJT00?l0dLfYf@3A
cJT00?l0dLfYf@3AcJT00001\
\>"],
  ImageRangeCache->{{{0, 471.813}, {1008.94, 0}} -> {-0.100021, -0.218566, \
0.00890194, 0.00890194}, {{11.1875, 115.688}, {984.375, 932.75}} -> \
{-29.3283, -27.8372, 1.10074, 1.10074}, {{126.125, 230.625}, {984.375, \
932.75}} -> {-155.845, -27.8372, 1.10074, 1.10074}, {{241.125, 345.625}, \
{984.375, 932.75}} -> {-282.431, -27.8372, 1.10074, 1.10074}, {{356.063, \
460.563}, {984.375, 932.75}} -> {-408.947, -27.8372, 1.10074, 1.10074}, \
{{11.1875, 115.688}, {927.563, 876}} -> {-29.4411, -90.518, 1.10252, \
1.10252}, {{126.125, 230.625}, {927.563, 876}} -> {-156.162, -90.518, \
1.10252, 1.10252}, {{241.125, 345.625}, {927.563, 876}} -> {-282.952, \
-90.518, 1.10252, 1.10252}, {{356.063, 460.563}, {927.563, 876}} -> \
{-409.673, -90.518, 1.10252, 1.10252}, {{11.1875, 115.688}, {870.813, \
819.25}} -> {-29.4411, -153.086, 1.10252, 1.10252}, {{126.125, 230.625}, \
{870.813, 819.25}} -> {-156.162, -153.086, 1.10252, 1.10252}, {{241.125, \
345.625}, {870.813, 819.25}} -> {-282.952, -153.086, 1.10252, 1.10252}, \
{{356.063, 460.563}, {870.813, 819.25}} -> {-409.673, -153.086, 1.10252, \
1.10252}, {{11.1875, 115.688}, {814.063, 762.438}} -> {-29.3283, -215.308, \
1.10074, 1.10074}, {{126.125, 230.625}, {814.063, 762.438}} -> {-155.845, \
-215.308, 1.10074, 1.10074}, {{241.125, 345.625}, {814.063, 762.438}} -> \
{-282.431, -215.308, 1.10074, 1.10074}, {{356.063, 460.563}, {814.063, \
762.438}} -> {-408.947, -215.308, 1.10074, 1.10074}, {{11.1875, 115.688}, \
{757.313, 705.688}} -> {-29.3283, -277.775, 1.10074, 1.10074}, {{126.125, \
230.625}, {757.313, 705.688}} -> {-155.845, -277.775, 1.10074, 1.10074}, \
{{241.125, 345.625}, {757.313, 705.688}} -> {-282.431, -277.775, 1.10074, \
1.10074}, {{356.063, 460.563}, {757.313, 705.688}} -> {-408.947, -277.775, \
1.10074, 1.10074}, {{11.1875, 115.688}, {700.563, 648.938}} -> {-29.3283, \
-340.242, 1.10074, 1.10074}, {{126.125, 230.625}, {700.563, 648.938}} -> \
{-155.845, -340.242, 1.10074, 1.10074}, {{241.125, 345.625}, {700.563, \
648.938}} -> {-282.431, -340.242, 1.10074, 1.10074}, {{356.063, 460.563}, \
{700.563, 648.938}} -> {-408.947, -340.242, 1.10074, 1.10074}, {{11.1875, \
115.688}, {643.75, 592.188}} -> {-29.4411, -403.428, 1.10252, 1.10252}, \
{{126.125, 230.625}, {643.75, 592.188}} -> {-156.162, -403.428, 1.10252, \
1.10252}, {{241.125, 345.625}, {643.75, 592.188}} -> {-282.952, -403.428, \
1.10252, 1.10252}, {{356.063, 460.563}, {643.75, 592.188}} -> {-409.673, \
-403.428, 1.10252, 1.10252}, {{11.1875, 115.688}, {587, 535.375}} -> \
{-29.3283, -465.245, 1.10074, 1.10074}, {{126.125, 230.625}, {587, 535.375}} -> \
{-155.845, -465.245, 1.10074, 1.10074}, {{241.125, 345.625}, {587, 535.375}} -> \
{-282.431, -465.245, 1.10074, 1.10074}, {{356.063, 460.563}, {587, 535.375}} -> \
{-408.947, -465.245, 1.10074, 1.10074}, {{11.1875, 115.688}, {530.25, \
478.625}} -> {-29.3283, -527.713, 1.10074, 1.10074}, {{126.125, 230.625}, \
{530.25, 478.625}} -> {-155.845, -527.713, 1.10074, 1.10074}, {{241.125, \
345.625}, {530.25, 478.625}} -> {-282.431, -527.713, 1.10074, 1.10074}, \
{{356.063, 460.563}, {530.25, 478.625}} -> {-408.947, -527.713, 1.10074, \
1.10074}, {{11.1875, 115.688}, {473.5, 421.875}} -> {-29.3283, -590.18, \
1.10074, 1.10074}, {{126.125, 230.625}, {473.5, 421.875}} -> {-155.845, \
-590.18, 1.10074, 1.10074}, {{241.125, 345.625}, {473.5, 421.875}} -> \
{-282.431, -590.18, 1.10074, 1.10074}, {{356.063, 460.563}, {473.5, 421.875}} -> \
{-408.947, -590.18, 1.10074, 1.10074}, {{11.1875, 115.688}, {416.688, \
365.125}} -> {-29.4411, -653.769, 1.10252, 1.10252}, {{126.125, 230.625}, \
{416.688, 365.125}} -> {-156.162, -653.769, 1.10252, 1.10252}, {{241.125, \
345.625}, {416.688, 365.125}} -> {-282.952, -653.769, 1.10252, 1.10252}, \
{{356.063, 460.563}, {416.688, 365.125}} -> {-409.673, -653.769, 1.10252, \
1.10252}, {{11.1875, 115.688}, {359.938, 308.375}} -> {-29.4411, -716.337, \
1.10252, 1.10252}, {{126.125, 230.625}, {359.938, 308.375}} -> {-156.162, \
-716.337, 1.10252, 1.10252}, {{241.125, 345.625}, {359.938, 308.375}} -> \
{-282.952, -716.337, 1.10252, 1.10252}, {{356.063, 460.563}, {359.938, \
308.375}} -> {-409.673, -716.337, 1.10252, 1.10252}, {{11.1875, 115.688}, \
{303.188, 251.563}} -> {-29.3283, -777.65, 1.10074, 1.10074}, {{126.125, \
230.625}, {303.188, 251.563}} -> {-155.845, -777.65, 1.10074, 1.10074}, \
{{241.125, 345.625}, {303.188, 251.563}} -> {-282.431, -777.65, 1.10074, \
1.10074}, {{356.063, 460.563}, {303.188, 251.563}} -> {-408.947, -777.65, \
1.10074, 1.10074}, {{11.1875, 115.688}, {246.438, 194.813}} -> {-29.3283, \
-840.117, 1.10074, 1.10074}, {{126.125, 230.625}, {246.438, 194.813}} -> \
{-155.845, -840.117, 1.10074, 1.10074}, {{241.125, 345.625}, {246.438, \
194.813}} -> {-282.431, -840.117, 1.10074, 1.10074}, {{356.063, 460.563}, \
{246.438, 194.813}} -> {-408.947, -840.117, 1.10074, 1.10074}, {{11.1875, \
115.688}, {189.688, 138.063}} -> {-29.3283, -902.585, 1.10074, 1.10074}, \
{{126.125, 230.625}, {189.688, 138.063}} -> {-155.845, -902.585, 1.10074, \
1.10074}, {{241.125, 345.625}, {189.688, 138.063}} -> {-282.431, -902.585, \
1.10074, 1.10074}, {{356.063, 460.563}, {189.688, 138.063}} -> {-408.947, \
-902.585, 1.10074, 1.10074}, {{11.1875, 115.688}, {132.875, 81.3125}} -> \
{-29.4411, -966.679, 1.10252, 1.10252}, {{126.125, 230.625}, {132.875, \
81.3125}} -> {-156.162, -966.679, 1.10252, 1.10252}, {{241.125, 345.625}, \
{132.875, 81.3125}} -> {-282.952, -966.679, 1.10252, 1.10252}, {{356.063, \
460.563}, {132.875, 81.3125}} -> {-409.673, -966.679, 1.10252, 1.10252}, \
{{11.1875, 115.688}, {76.125, 24.5}} -> {-29.3283, -1027.59, 1.10074, \
1.10074}, {{126.125, 230.625}, {76.125, 24.5}} -> {-155.845, -1027.59, \
1.10074, 1.10074}, {{241.125, 345.625}, {76.125, 24.5}} -> {-282.431, \
-1027.59, 1.10074, 1.10074}, {{356.063, 460.563}, {76.125, 24.5}} -> \
{-408.947, -1027.59, 1.10074, 1.10074}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["THE RULE 01001000", "Subsection"],

Cell["\<\
Despite their simplicity of description, CA defy analysis except in the \
simplest of cases. For example, while we can easily prove that the rule \
01001000 never produces three consecutive 1\.b4s (proof:  a 1 must have been \
a 0 in the previous generation. So 111 must came from a 000 previous \
configuration, but this implies that the middle 0 has to stay 0 #. ) This \
rule also produces no 11 and between two consecutive 1 there are an odd \
number of 0\.b4s;  but this facts are not so easy to prove.

The sequence of number of 1\.b4s at each generation starts as: \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cS = cellularSpace[321];\)\), "\[IndentingNewLine]", 
    \(\(m = 
        evolve[2, cS, {0, 1, 0, 0, 1, 0, 0, 0}, 
          80];\)\), "\[IndentingNewLine]", 
    \(\(\((Plus\  @@ #)\) &\)\  /@ \ m\)}], "Input"],

Cell[BoxData[
    \({1, 2, 2, 4, 2, 4, 4, 8, 2, 4, 4, 8, 4, 8, 8, 16, 2, 4, 4, 8, 4, 8, 8, 
      16, 4, 8, 8, 16, 8, 16, 16, 32, 2, 4, 4, 8, 4, 8, 8, 16, 4, 8, 8, 16, 
      8, 16, 16, 32, 4, 8, 8, 16, 8, 16, 16, 32, 8, 16, 16, 32, 16, 32, 32, 
      64, 2, 4, 4, 8, 4, 8, 8, 16, 4, 8, 8, 16, 8, 16, 16, 32, 4}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[%, PlotJoined \[Rule] True, PlotRange \[Rule] All, 
        AspectRatio \[Rule] Automatic];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .7875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0119048 0.0119048 0.00684524 0.0119048 [
[.25 -0.00565 -6 -9 ]
[.25 -0.00565 6 0 ]
[.4881 -0.00565 -6 -9 ]
[.4881 -0.00565 6 0 ]
[.72619 -0.00565 -6 -9 ]
[.72619 -0.00565 6 0 ]
[.96429 -0.00565 -6 -9 ]
[.96429 -0.00565 6 0 ]
[-0.0006 .12589 -12 -4.5 ]
[-0.0006 .12589 0 4.5 ]
[-0.0006 .24494 -12 -4.5 ]
[-0.0006 .24494 0 4.5 ]
[-0.0006 .36399 -12 -4.5 ]
[-0.0006 .36399 0 4.5 ]
[-0.0006 .48304 -12 -4.5 ]
[-0.0006 .48304 0 4.5 ]
[-0.0006 .60208 -12 -4.5 ]
[-0.0006 .60208 0 4.5 ]
[-0.0006 .72113 -12 -4.5 ]
[-0.0006 .72113 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .7875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25 .00685 m
.25 .0131 L
s
[(20)] .25 -0.00565 0 1 Mshowa
.4881 .00685 m
.4881 .0131 L
s
[(40)] .4881 -0.00565 0 1 Mshowa
.72619 .00685 m
.72619 .0131 L
s
[(60)] .72619 -0.00565 0 1 Mshowa
.96429 .00685 m
.96429 .0131 L
s
[(80)] .96429 -0.00565 0 1 Mshowa
.125 Mabswid
.07143 .00685 m
.07143 .0106 L
s
.13095 .00685 m
.13095 .0106 L
s
.19048 .00685 m
.19048 .0106 L
s
.30952 .00685 m
.30952 .0106 L
s
.36905 .00685 m
.36905 .0106 L
s
.42857 .00685 m
.42857 .0106 L
s
.54762 .00685 m
.54762 .0106 L
s
.60714 .00685 m
.60714 .0106 L
s
.66667 .00685 m
.66667 .0106 L
s
.78571 .00685 m
.78571 .0106 L
s
.84524 .00685 m
.84524 .0106 L
s
.90476 .00685 m
.90476 .0106 L
s
.25 Mabswid
0 .00685 m
1 .00685 L
s
.0119 .12589 m
.01815 .12589 L
s
[(10)] -0.0006 .12589 1 0 Mshowa
.0119 .24494 m
.01815 .24494 L
s
[(20)] -0.0006 .24494 1 0 Mshowa
.0119 .36399 m
.01815 .36399 L
s
[(30)] -0.0006 .36399 1 0 Mshowa
.0119 .48304 m
.01815 .48304 L
s
[(40)] -0.0006 .48304 1 0 Mshowa
.0119 .60208 m
.01815 .60208 L
s
[(50)] -0.0006 .60208 1 0 Mshowa
.0119 .72113 m
.01815 .72113 L
s
[(60)] -0.0006 .72113 1 0 Mshowa
.125 Mabswid
.0119 .03065 m
.01565 .03065 L
s
.0119 .05446 m
.01565 .05446 L
s
.0119 .07827 m
.01565 .07827 L
s
.0119 .10208 m
.01565 .10208 L
s
.0119 .1497 m
.01565 .1497 L
s
.0119 .17351 m
.01565 .17351 L
s
.0119 .19732 m
.01565 .19732 L
s
.0119 .22113 m
.01565 .22113 L
s
.0119 .26875 m
.01565 .26875 L
s
.0119 .29256 m
.01565 .29256 L
s
.0119 .31637 m
.01565 .31637 L
s
.0119 .34018 m
.01565 .34018 L
s
.0119 .3878 m
.01565 .3878 L
s
.0119 .41161 m
.01565 .41161 L
s
.0119 .43542 m
.01565 .43542 L
s
.0119 .45923 m
.01565 .45923 L
s
.0119 .50685 m
.01565 .50685 L
s
.0119 .53065 m
.01565 .53065 L
s
.0119 .55446 m
.01565 .55446 L
s
.0119 .57827 m
.01565 .57827 L
s
.0119 .62589 m
.01565 .62589 L
s
.0119 .6497 m
.01565 .6497 L
s
.0119 .67351 m
.01565 .67351 L
s
.0119 .69732 m
.01565 .69732 L
s
.0119 .74494 m
.01565 .74494 L
s
.0119 .76875 m
.01565 .76875 L
s
.25 Mabswid
.0119 0 m
.0119 .7875 L
s
.5 Mabswid
.02381 .01875 m
.03571 .03065 L
.04762 .03065 L
.05952 .05446 L
.07143 .03065 L
.08333 .05446 L
.09524 .05446 L
.10714 .10208 L
.11905 .03065 L
.13095 .05446 L
.14286 .05446 L
.15476 .10208 L
.16667 .05446 L
.17857 .10208 L
.19048 .10208 L
.20238 .19732 L
.21429 .03065 L
.22619 .05446 L
.2381 .05446 L
.25 .10208 L
.2619 .05446 L
.27381 .10208 L
.28571 .10208 L
.29762 .19732 L
.30952 .05446 L
.32143 .10208 L
.33333 .10208 L
.34524 .19732 L
.35714 .10208 L
.36905 .19732 L
.38095 .19732 L
.39286 .3878 L
.40476 .03065 L
.41667 .05446 L
.42857 .05446 L
.44048 .10208 L
.45238 .05446 L
.46429 .10208 L
.47619 .10208 L
.4881 .19732 L
.5 .05446 L
.5119 .10208 L
.52381 .10208 L
.53571 .19732 L
.54762 .10208 L
.55952 .19732 L
.57143 .19732 L
.58333 .3878 L
.59524 .05446 L
.60714 .10208 L
Mistroke
.61905 .10208 L
.63095 .19732 L
.64286 .10208 L
.65476 .19732 L
.66667 .19732 L
.67857 .3878 L
.69048 .10208 L
.70238 .19732 L
.71429 .19732 L
.72619 .3878 L
.7381 .19732 L
.75 .3878 L
.7619 .3878 L
.77381 .76875 L
.78571 .03065 L
.79762 .05446 L
.80952 .05446 L
.82143 .10208 L
.83333 .05446 L
.84524 .10208 L
.85714 .10208 L
.86905 .19732 L
.88095 .05446 L
.89286 .10208 L
.90476 .10208 L
.91667 .19732 L
.92857 .10208 L
.94048 .19732 L
.95238 .19732 L
.96429 .3878 L
.97619 .05446 L
Mfstroke
0 0 m
1 0 L
1 .7875 L
0 .7875 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 226.75},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000hR000`400?l00000o`00003oo`3AcJTQ
0=7=Z@00C03AcJT4@00000<0dLfY0T00000j0=7=Z@=000000P3AcJT2@00003P0dLfY0d0000040=7=
Z@900000>@3AcJT2@00000@0dLfY0T0000080=7=Z@00C03AcJT00d000000dLfY0=7=Z@030=7=Z@04
@000003AcJT0dLfY@00003X0dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0e
0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000=`3AcJT014000000dLfY
0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000L0dLfY001=0=7=Z@03@000003AcJT0dLfY0080
dLfY00A000000=7=Z@3AcJU00000=`3AcJT5@00000050=7=ZD000000dLfY0=7=ZD000000=`3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00003L0dLfY00A000000=7=Z@3AcJU0
00000P3AcJT014000000dLfY0=7=ZD0000070=7=Z@00CP3AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00=000000=7=Z@3AcJT0=@3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0
dLfY@00003L0dLfY0d0000030=7=Z@04@000003AcJT0dLfY@00003P0dLfY0T0000030=7=Z@04@000
003AcJT0dLfY@00000L0dLfY001<0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3A
cJU00000>03AcJT00d000000dLfY@00000020=7=Z@04@000003AcJT0dLfY@00003P0dLfY00=00000
0=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD00000g0=7=Z@04@000003AcJT0dLfY@0000080dLfY
00A000000=7=Z@3AcJU000001`3AcJT004d0dLfY0T0000040=7=Z@900000>P3AcJT2@00000<0dLfY
0T00000i0=7=Z@=000000`3AcJT2@00003T0dLfY0T0000040=7=Z@900000203AcJT00?l0dLfY8@3A
cJT00?l0dLfY8@3AcJT00?l0dLfY8@3AcJT00100dLfY00<000000=7=Z@3AcJT0o`3AcJT>0=7=Z@00
403AcJT00`000000dLfY0=7=Z@3o0=7=Z@h0dLfY000<0=7=ZOl000004`000001@0000040dLfY000@
0=7=Z@030000003AcJT0dLfY00d0dLfY00=000000=7=Z@3AcJT03@3AcJT00d000000dLfY0=7=Z@0=
0=7=Z@03@000003AcJT0dLfY00h0dLfY00<000000=7=Z@3AcJT03@3AcJT00d000000dLfY0=7=Z@0=
0=7=Z@03@000003AcJT0dLfY00h0dLfY00=000000=7=Z@3AcJT03@3AcJT00`000000dLfY0=7=Z@0=
0=7=Z@03@000003AcJT0dLfY00d0dLfY00=000000=7=Z@3AcJT03P3AcJT00d000000dLfY0=7=Z@0=
0=7=Z@030000003AcJT0dLfY00d0dLfY00=000000=7=Z@3AcJT03@3AcJT00d000000dLfY0=7=Z@0>
0=7=Z@03@000003AcJT0dLfY00d0dLfY00<000000=7=Z@3AcJT02@3AcJT00100dLfY00<000000=7=
Z@3AcJT0?P3AcJT00d000000dLfY0=7=Z@0n0=7=Z@03@000003AcJT0dLfY03h0dLfY00=000000=7=
Z@3AcJT0?P3AcJT00d000000dLfY0=7=Z@090=7=Z@00403AcJT010000000dLfY0=7=Z@00003o0=7=
Z@d0dLfY000@0=7=Z@050000003AcJT0dLfY0=7=Z@000000o`3AcJT<0=7=Z@00403AcJT00`000000
dLfY0=7=Z@020=7=Z@030000003AcJT0dLfY0?l0dLfY2@3AcJT00100dLfY00<000000=7=Z@3AcJT0
0P3AcJT00`000000dLfY0=7=Z@3o0=7=Z@T0dLfY000@0=7=Z@03000004000000dLfY00<0dLfY1000
00060=7=Z@030000003AcJT0dLfY00X0dLfY00<000000=7=Z@3AcJT05`3AcJT00`000000dLfY0=7=
Z@0a0=7=Z@030000003AcJT0dLfY06D0dLfY00<000000=7=Z@3AcJT0>P3AcJT00100dLfY00<00000
0=7=Z@3AcJT01`3AcJT00`000000dLfY0=7=Z@030=7=Z@8000002`3AcJT2000001P0dLfY0P00000b
0=7=Z@800000IP3AcJT2000003/0dLfY000@0=7=Z@030000003AcJT0dLfY00L0dLfY00<000000=7=
Z@3AcJT00P3AcJT00`000000dLfY0000000;0=7=Z@800000603AcJT200000380dLfY0P00001V0=7=
Z@800000>`3AcJT00100dLfY00<000000=7=Z@3AcJT0203AcJT01@000000dLfY0=7=Z@3AcJT00000
0080dLfY00<000000=7=Z@3AcJT0203AcJT00`000000dLfY0000000G0=7=Z@030000003AcJT00000
0340dLfY00<000000=7=Z@000000I@3AcJT00`000000dLfY0000000j0=7=Z@00403AcJT00`000000
dLfY0=7=Z@090=7=Z@030000003AcJT0000000<0dLfY00<000000=7=Z@3AcJT01`3AcJT010000000
dLfY0=7=Z@00000G0=7=Z@030000003AcJT000000340dLfY00<000000=7=Z@000000I@3AcJT00`00
0000dLfY0000000j0=7=Z@00403AcJT00`000000dLfY0=7=Z@090=7=Z@030000003AcJT0000000@0
dLfY00<000000=7=Z@3AcJT01P3AcJT01@000000dLfY0=7=Z@3AcJT0000001H0dLfY00@000000=7=
Z@3AcJT00000<03AcJT010000000dLfY0=7=Z@00001T0=7=Z@040000003AcJT0dLfY000003T0dLfY
000@0=7=Z@03000004000000dLfY00X0dLfY00<000000=7=Z@3AcJT00`3AcJT4000000D0dLfY00@0
00000=7=Z@3AcJT0dLfY100000060=7=Z@030000003AcJT0dLfY00X0dLfY00<000000=7=Z@3AcJT0
1@0000050=7=Z@030000003AcJT0dLfY00X0dLfY00<000000=7=Z@3AcJT05`3AcJT00`000000dLfY
0=7=Z@05000000D0dLfY00<000000=7=Z@3AcJT02P3AcJT00`000000dLfY0=7=Z@0G0=7=Z@030000
003AcJT0dLfY0340dLfY00<000000=7=Z@3AcJT01@0000050=7=Z@030000003AcJT0dLfY00X0dLfY
00<000000=7=Z@3AcJT05`3AcJT00d000000dLfY0=7=Z@060=7=Z@00403AcJT00`000000dLfY0=7=
Z@0C0=7=Z@030000003AcJT0dLfY00<0dLfY00<000000=7=Z@3AcJT0103AcJT00`000000dLfY0=7=
Z@040=7=Z@030000003AcJT0dLfY00X0dLfY00<000000=7=Z@3AcJT0103AcJT00`000000dLfY0=7=
Z@030=7=Z@030000003AcJT0dLfY00X0dLfY00<000000=7=Z@3AcJT05`3AcJT00`000000dLfY0=7=
Z@040=7=Z@030000003AcJT0dLfY00<0dLfY00<000000=7=Z@3AcJT02P3AcJT00`000000dLfY0=7=
Z@0G0=7=Z@030000003AcJT0dLfY0340dLfY00<000000=7=Z@3AcJT0103AcJT00`000000dLfY0=7=
Z@030=7=Z@030000003AcJT0dLfY00X0dLfY00<000000=7=Z@3AcJT05`3AcJT00`000000dLfY0=7=
Z@060=7=Z@00403AcJT00`000000dLfY0=7=Z@0D0=7=Z@030000003AcJT0dLfY0080dLfY00<00000
0=7=Z@3AcJT01@3AcJT00`000000dLfY0=7=Z@030=7=Z@030000003AcJT0dLfY00T0dLfY00<00000
0=7=Z@3AcJT01@3AcJT00`000000dLfY0=7=Z@030=7=Z@030000003AcJT0dLfY00X0dLfY00<00000
0=7=Z@3AcJT05`3AcJT00`000000dLfY0=7=Z@040=7=Z@030000003AcJT0dLfY00<0dLfY00<00000
0=7=Z@3AcJT02P3AcJT00`000000dLfY0=7=Z@0G0=7=Z@030000003AcJT0dLfY0340dLfY00<00000
0=7=Z@3AcJT0103AcJT00`000000dLfY0=7=Z@030=7=Z@030000003AcJT0dLfY00X0dLfY00<00000
0=7=Z@3AcJT05`3AcJT00`000000dLfY0=7=Z@060=7=Z@00403AcJT00`000000dLfY0=7=Z@0D0=7=
Z@030000003AcJT0dLfY0080dLfY00<000000=7=Z@3AcJT01@3AcJT00`000000dLfY0=7=Z@020=7=
Z@030000003AcJT0000000X0dLfY00<000000=7=Z@3AcJT01P3AcJT01`000000dLfY0=7=Z@3AcJT0
00000=7=Z@0000002`3AcJT2000001P0dLfY00<000000=7=Z@3AcJT01@3AcJT01`000000dLfY0=7=
Z@3AcJT000000=7=Z@0000002`3AcJT2000001P0dLfY0P00000b0=7=Z@030000003AcJT0dLfY00D0
dLfY00L000000=7=Z@3AcJT0dLfY0000003AcJT0000000/0dLfY0P00000H0=7=Z@030000003AcJT0
dLfY00H0dLfY000@0=7=Z@030000003AcJT0dLfY01@0dLfY00D000000=7=Z@3AcJT0dLfY00000008
0=7=Z@030000003AcJT0dLfY0080dLfY00<000000=7=Z@0000002P3AcJT00`000000dLfY0=7=Z@06
0=7=Z@070000003AcJT0dLfY0=7=Z@000000dLfY0000000;0=7=Z@800000603AcJT00`000000dLfY
0=7=Z@050=7=Z@070000003AcJT0dLfY0=7=Z@000000dLfY0000000;0=7=Z@800000603AcJT20000
0380dLfY00<000000=7=Z@3AcJT01@3AcJT01`000000dLfY0=7=Z@3AcJT000000=7=Z@0000002`3A
cJT2000001P0dLfY00<000000=7=Z@3AcJT01P3AcJT00100dLfY00<000000=7=Z@3AcJT05@3AcJT0
10000000dLfY0=7=Z@0000090=7=Z@070000003AcJT0dLfY0=7=Z@000000dLfY0000000:0=7=Z@03
0000003AcJT0dLfY00H0dLfY00L000000=7=Z@3AcJT0dLfY0000003AcJT0000000/0dLfY0P00000H
0=7=Z@030000003AcJT0dLfY00D0dLfY00L000000=7=Z@3AcJT0dLfY0000003AcJT0000000/0dLfY
0P00000H0=7=Z@800000<P3AcJT00`000000dLfY0=7=Z@050=7=Z@070000003AcJT0dLfY0=7=Z@00
0000dLfY0000000;0=7=Z@800000603AcJT00`000000dLfY0=7=Z@060=7=Z@00403AcJT00`000000
dLfY0=7=Z@0E0=7=Z@040000003AcJT0dLfY000000T0dLfY00L000000=7=Z@3AcJT0dLfY0000003A
cJT0000000X0dLfY00<000000=7=Z@3AcJT01P3AcJT01`000000dLfY0=7=Z@3AcJT000000=7=Z@00
00002`3AcJT2000001P0dLfY00<000000=7=Z@3AcJT01@3AcJT01`000000dLfY0=7=Z@3AcJT00000
0=7=Z@0000002`3AcJT2000001P0dLfY0P00000b0=7=Z@030000003AcJT0dLfY00D0dLfY00L00000
0=7=Z@3AcJT0dLfY0000003AcJT0000000/0dLfY0P00000H0=7=Z@030000003AcJT0dLfY00H0dLfY
000@0=7=Z@03000004000000dLfY01D0dLfY00@000000=7=Z@3AcJT000002@3AcJT010000000dLfY
0=7=Z@0000030=7=Z@030000003AcJT0dLfY00L0dLfY00<000000=7=Z@3AcJT01`3AcJT00`000000
dLfY000000030=7=Z@030000003AcJT0dLfY00L0dLfY00@000000=7=Z@3AcJT000005`3AcJT00`00
0000dLfY0=7=Z@060=7=Z@030000003AcJT0000000<0dLfY00<000000=7=Z@3AcJT01`3AcJT01000
0000dLfY0=7=Z@00000G0=7=Z@030000003AcJT000000340dLfY00<000000=7=Z@3AcJT01P3AcJT0
0`000000dLfY000000030=7=Z@030000003AcJT0dLfY00L0dLfY00@000000=7=Z@3AcJT000005`3A
cJT00`000000dLfY0=7=Z@060=7=Z@00403AcJT00`000000dLfY0=7=Z@0E0=7=Z@040000003AcJT0
dLfY000000T0dLfY00@000000=7=Z@3AcJT000000`3AcJT00`000000dLfY0=7=Z@070=7=Z@030000
003AcJT0dLfY00L0dLfY00<000000=7=Z@0000000`3AcJT00`000000dLfY0=7=Z@070=7=Z@040000
003AcJT0dLfY000001L0dLfY00<000000=7=Z@3AcJT01P3AcJT00`000000dLfY000000030=7=Z@03
0000003AcJT0dLfY00L0dLfY00@000000=7=Z@3AcJT000005`3AcJT00`000000dLfY0000000a0=7=
Z@030000003AcJT0dLfY00H0dLfY00<000000=7=Z@0000000`3AcJT00`000000dLfY0=7=Z@070=7=
Z@040000003AcJT0dLfY000001L0dLfY00<000000=7=Z@3AcJT01P3AcJT00100dLfY00<000000=7=
Z@3AcJT05P3AcJT00`000000dLfY0000000:0=7=Z@030000003AcJT0000000<0dLfY00<000000=7=
Z@3AcJT01`3AcJT00`000000dLfY0=7=Z@070=7=Z@030000003AcJT0000000<0dLfY00<000000=7=
Z@3AcJT01`3AcJT010000000dLfY0=7=Z@00000G0=7=Z@030000003AcJT0dLfY00H0dLfY00<00000
0=7=Z@0000000`3AcJT00`000000dLfY0=7=Z@070=7=Z@040000003AcJT0dLfY000001L0dLfY00<0
00000=7=Z@000000<@3AcJT00`000000dLfY0=7=Z@060=7=Z@030000003AcJT0000000<0dLfY00<0
00000=7=Z@3AcJT01`3AcJT010000000dLfY0=7=Z@00000G0=7=Z@030000003AcJT0dLfY00H0dLfY
000@0=7=Z@030000003AcJT0dLfY01H0dLfY0P00000;0=7=Z@030000003AcJT0000000<0dLfY00<0
00000=7=Z@3AcJT01`3AcJT00`000000dLfY0=7=Z@070=7=Z@030000003AcJT0000000<0dLfY00<0
00000=7=Z@3AcJT01`3AcJT010000000dLfY0=7=Z@00000G0=7=Z@030000003AcJT0dLfY00H0dLfY
00<000000=7=Z@0000000`3AcJT00`000000dLfY0=7=Z@070=7=Z@040000003AcJT0dLfY000001L0
dLfY00<000000=7=Z@000000<@3AcJT00`000000dLfY0=7=Z@060=7=Z@030000003AcJT0000000<0
dLfY00<000000=7=Z@3AcJT01`3AcJT010000000dLfY0=7=Z@00000G0=7=Z@030000003AcJT0dLfY
00H0dLfY000@0=7=Z@030000003AcJT0dLfY01H0dLfY0P00000;0=7=Z@8000001@3AcJT00`000000
dLfY0=7=Z@060=7=Z@030000003AcJT0dLfY00P0dLfY00<000000=7=Z@3AcJT00`3AcJT00`000000
dLfY0=7=Z@060=7=Z@050000003AcJT0dLfY0=7=Z@0000005@3AcJT00`000000dLfY0=7=Z@080=7=
Z@030000003AcJT0dLfY00<0dLfY00<000000=7=Z@3AcJT01P3AcJT01@000000dLfY0=7=Z@3AcJT0
000001H0dLfY00@000000=7=Z@3AcJT00000<03AcJT00`000000dLfY0=7=Z@070=7=Z@030000003A
cJT0dLfY00<0dLfY00<000000=7=Z@3AcJT01P3AcJT01@000000dLfY0=7=Z@3AcJT0000001H0dLfY
00<000000=7=Z@3AcJT01P3AcJT00100dLfY00<000000=7=Z@3AcJT05`3AcJT00`000000dLfY0=7=
Z@0:0=7=Z@030000003AcJT0dLfY00<0dLfY00<000000=7=Z@3AcJT01P3AcJT00`000000dLfY0=7=
Z@080=7=Z@030000003AcJT0dLfY00<0dLfY00<000000=7=Z@3AcJT01P3AcJT01@000000dLfY0=7=
Z@3AcJT0000001D0dLfY00<000000=7=Z@3AcJT0203AcJT00`000000dLfY0=7=Z@030=7=Z@030000
003AcJT0dLfY00H0dLfY00D000000=7=Z@3AcJT0dLfY0000000F0=7=Z@040000003AcJT0dLfY0000
0300dLfY00<000000=7=Z@3AcJT01`3AcJT00`000000dLfY0=7=Z@030=7=Z@030000003AcJT0dLfY
00H0dLfY00D000000=7=Z@3AcJT0dLfY0000000F0=7=Z@030000003AcJT0dLfY00H0dLfY000@0=7=
Z@03000004000000dLfY01L0dLfY00<000000=7=Z@3AcJT02P3AcJT00`000000dLfY0=7=Z@030=7=
Z@@000001@3AcJT00`000000dLfY0=7=Z@080=7=Z@030000003AcJT0dLfY00<0dLfY1@0000040=7=
Z@040000003AcJT0dLfY0=7=Z@D000001@3AcJT00`000000dLfY0=7=Z@090=7=Z@030000003AcJT0
dLfY00P0dLfY00<000000=7=Z@3AcJT00`3AcJT5000000@0dLfY00@000000=7=Z@3AcJT0dLfY1@00
00050=7=Z@030000003AcJT0dLfY00X0dLfY00<000000=7=Z@3AcJT01@0000050=7=Z@030000003A
cJT0dLfY00X0dLfY00<000000=7=Z@3AcJT05`3AcJT00`000000dLfY0=7=Z@070=7=Z@030000003A
cJT0dLfY00<0dLfY1@0000040=7=Z@040000003AcJT0dLfY0=7=Z@D000001@3AcJT00`000000dLfY
0=7=Z@0:0=7=Z@030000003AcJT0dLfY00H0dLfY000@0=7=Z@030000003AcJT0dLfY02d0dLfY00<0
00000=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@0B0=7=Z@030000003AcJT0dLfY0080dLfY00<0
00000=7=Z@3AcJT01@3AcJT00`000000dLfY0=7=Z@030=7=Z@030000003AcJT0dLfY00T0dLfY00<0
00000=7=Z@3AcJT04P3AcJT00`000000dLfY0=7=Z@020=7=Z@030000003AcJT0dLfY00D0dLfY00<0
00000=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@0:0=7=Z@030000003AcJT0dLfY00@0dLfY00<0
00000=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@0:0=7=Z@030000003AcJT0dLfY01L0dLfY00<0
00000=7=Z@3AcJT04@3AcJT00`000000dLfY0=7=Z@020=7=Z@030000003AcJT0dLfY00D0dLfY00<0
00000=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@0:0=7=Z@030000003AcJT0dLfY00H0dLfY000@
0=7=Z@030000003AcJT0dLfY02d0dLfY00<000000=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@0B
0=7=Z@030000003AcJT0dLfY0080dLfY00<000000=7=Z@3AcJT01@3AcJT00`000000dLfY0=7=Z@03
0=7=Z@030000003AcJT0dLfY00T0dLfY00<000000=7=Z@3AcJT04P3AcJT00`000000dLfY0=7=Z@02
0=7=Z@030000003AcJT0dLfY00D0dLfY00<000000=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@0:
0=7=Z@030000003AcJT0dLfY00@0dLfY00<000000=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@0:
0=7=Z@030000003AcJT0dLfY01L0dLfY00<000000=7=Z@3AcJT04@3AcJT00`000000dLfY0=7=Z@02
0=7=Z@030000003AcJT0dLfY00D0dLfY00<000000=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@0:
0=7=Z@030000003AcJT0dLfY00H0dLfY000@0=7=Z@030000003AcJT0dLfY02d0dLfY00<000000=7=
Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@0B0=7=Z@030000003AcJT0dLfY0080dLfY00<000000=7=
Z@3AcJT01@3AcJT00`000000dLfY0=7=Z@030=7=Z@030000003AcJT0dLfY00T0dLfY00<000000=7=
Z@3AcJT04P3AcJT00`000000dLfY0=7=Z@020=7=Z@030000003AcJT0dLfY00D0dLfY00<000000=7=
Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@090=7=Z@030000003AcJT0dLfY00D0dLfY00<000000=7=
Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@0:0=7=Z@030000003AcJT0dLfY01L0dLfY00<000000=7=
Z@3AcJT04@3AcJT00`000000dLfY0=7=Z@020=7=Z@030000003AcJT0dLfY00D0dLfY00<000000=7=
Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@090=7=Z@030000003AcJT0dLfY00L0dLfY000@0=7=Z@03
0000003AcJT0dLfY02h0dLfY00D000000=7=Z@3AcJT0dLfY0000000E0=7=Z@030000003AcJT0dLfY
0080dLfY00<000000=7=Z@3AcJT01@3AcJT00`000000dLfY0=7=Z@030=7=Z@030000003AcJT0dLfY
00T0dLfY00<000000=7=Z@3AcJT04P3AcJT00`000000dLfY0=7=Z@020=7=Z@030000003AcJT0dLfY
00D0dLfY00<000000=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@090=7=Z@030000003AcJT0dLfY
00D0dLfY00<000000=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@0:0=7=Z@030000003AcJT0dLfY
01L0dLfY00<000000=7=Z@3AcJT04@3AcJT00`000000dLfY0=7=Z@020=7=Z@030000003AcJT0dLfY
00D0dLfY00<000000=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@090=7=Z@030000003AcJT0dLfY
00L0dLfY00000`3AcJU00000@0000003@0000080dLfY0T0000060=7=Z@030000003AcJT0dLfY02h0
dLfY00D000000=7=Z@3AcJT0dLfY0000000F0=7=Z@050000003AcJT0dLfY0=7=Z@000000203AcJT0
1`000000dLfY0=7=Z@3AcJT000000=7=Z@0000002P3AcJT00`000000dLfY0=7=Z@0C0=7=Z@050000
003AcJT0dLfY0=7=Z@000000203AcJT01`000000dLfY0=7=Z@3AcJT000000=7=Z@0000002P3AcJT0
0`000000dLfY0=7=Z@060=7=Z@070000003AcJT0dLfY0=7=Z@000000dLfY0000000;0=7=Z@800000
603AcJT00`000000dLfY0=7=Z@0B0=7=Z@050000003AcJT0dLfY0=7=Z@000000203AcJT01`000000
dLfY0=7=Z@3AcJT000000=7=Z@0000002P3AcJT00`000000dLfY0=7=Z@070=7=Z@000`3AcJT01D00
0000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@0^
0=7=Z@050000003AcJT0dLfY0=7=Z@0000005P3AcJT01@000000dLfY0=7=Z@3AcJT0000000P0dLfY
00L000000=7=Z@3AcJT0dLfY0000003AcJT0000000X0dLfY00<000000=7=Z@3AcJT04`3AcJT01@00
0000dLfY0=7=Z@3AcJT0000000P0dLfY00L000000=7=Z@3AcJT0dLfY0000003AcJT0000000X0dLfY
00<000000=7=Z@3AcJT01P3AcJT01`000000dLfY0=7=Z@3AcJT000000=7=Z@0000002`3AcJT20000
01P0dLfY00<000000=7=Z@3AcJT04P3AcJT01@000000dLfY0=7=Z@3AcJT0000000P0dLfY00L00000
0=7=Z@3AcJT0dLfY0000003AcJT0000000X0dLfY00<000000=7=Z@3AcJT01`3AcJT000<0dLfY00E0
00000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY00<0dLfY00<00000@000003AcJT0
;P3AcJT01@000000dLfY0=7=Z@3AcJT0000001H0dLfY00@000000=7=Z@3AcJT000002@3AcJT01`00
0000dLfY0=7=Z@3AcJT000000=7=Z@0000002P3AcJT00`000000dLfY0=7=Z@0C0=7=Z@040000003A
cJT0dLfY000000T0dLfY00L000000=7=Z@3AcJT0dLfY0000003AcJT0000000X0dLfY00<000000=7=
Z@3AcJT01P3AcJT01`000000dLfY0=7=Z@3AcJT000000=7=Z@0000002`3AcJT2000001P0dLfY00<0
00000=7=Z@3AcJT04P3AcJT010000000dLfY0=7=Z@0000090=7=Z@070000003AcJT0dLfY0=7=Z@00
0000dLfY0000000:0=7=Z@030000003AcJT0dLfY00L0dLfY00030=7=Z@05@000003AcJT0dLfY0=7=
ZD0000000P3AcJT00d000000dLfY0=7=Z@030=7=Z@030000003AcJT0dLfY02h0dLfY00D000000=7=
Z@3AcJT0dLfY0000000F0=7=Z@040000003AcJT0dLfY000000T0dLfY00L000000=7=Z@3AcJT0dLfY
0000003AcJT0000000X0dLfY00<000000=7=Z@3AcJT04`3AcJT010000000dLfY0=7=Z@0000090=7=
Z@070000003AcJT0dLfY0=7=Z@000000dLfY0000000:0=7=Z@030000003AcJT0dLfY00H0dLfY00L0
00000=7=Z@3AcJT0dLfY0000003AcJT0000000/0dLfY0P00000H0=7=Z@030000003AcJT0dLfY0180
dLfY00@000000=7=Z@3AcJT000002@3AcJT01`000000dLfY0=7=Z@3AcJT000000=7=Z@0000002P3A
cJT00`000000dLfY0=7=Z@070=7=Z@000`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=0
00000=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@0^0=7=Z@050000003AcJT0dLfY0=7=Z@000000
5P3AcJT010000000dLfY0=7=Z@0000090=7=Z@070000003AcJT0dLfY0=7=Z@000000dLfY0000000:
0=7=Z@030000003AcJT0dLfY01<0dLfY00@000000=7=Z@3AcJT000002@3AcJT01`000000dLfY0=7=
Z@3AcJT000000=7=Z@0000002P3AcJT00`000000dLfY0=7=Z@060=7=Z@070000003AcJT0dLfY0=7=
Z@000000dLfY0000000;0=7=Z@800000603AcJT00`000000dLfY0=7=Z@0B0=7=Z@040000003AcJT0
dLfY000000T0dLfY00L000000=7=Z@3AcJT0dLfY0000003AcJT0000000X0dLfY00<000000=7=Z@3A
cJT01`3AcJT00080dLfY0T0000040=7=Z@9000001P3AcJT00`000000dLfY0=7=Z@0_0=7=Z@040000
003AcJT0dLfY000001H0dLfY00@000000=7=Z@3AcJT000002@3AcJT01`000000dLfY0=7=Z@3AcJT0
00000=7=Z@0000002P3AcJT00`000000dLfY0=7=Z@0C0=7=Z@040000003AcJT0dLfY000000T0dLfY
00L000000=7=Z@3AcJT0dLfY0000003AcJT0000000X0dLfY00<000000=7=Z@3AcJT01P3AcJT01`00
0000dLfY0=7=Z@3AcJT000000=7=Z@0000002`3AcJT2000001P0dLfY00<000000=7=Z@3AcJT04P3A
cJT010000000dLfY0=7=Z@0000090=7=Z@070000003AcJT0dLfY0=7=Z@000000dLfY0000000:0=7=
Z@030000003AcJT0dLfY00L0dLfY000@0=7=Z@030000003AcJT0dLfY02l0dLfY00@000000=7=Z@3A
cJT000005P3AcJT010000000dLfY0=7=Z@0000090=7=Z@070000003AcJT0dLfY0=7=Z@000000dLfY
0000000:0=7=Z@030000003AcJT0dLfY01<0dLfY00@000000=7=Z@3AcJT000002@3AcJT01`000000
dLfY0=7=Z@3AcJT000000=7=Z@0000002P3AcJT00`000000dLfY0=7=Z@060=7=Z@070000003AcJT0
dLfY0=7=Z@000000dLfY0000000;0=7=Z@800000603AcJT00`000000dLfY0=7=Z@0B0=7=Z@040000
003AcJT0dLfY000000T0dLfY00L000000=7=Z@3AcJT0dLfY0000003AcJT0000000X0dLfY00<00000
0=7=Z@3AcJT01`3AcJT00100dLfY00<000000=7=Z@3AcJT0;`3AcJT010000000dLfY0=7=Z@00000F
0=7=Z@040000003AcJT0dLfY000000T0dLfY00L000000=7=Z@3AcJT0dLfY0000003AcJT0000000X0
dLfY00<000000=7=Z@3AcJT04`3AcJT010000000dLfY0=7=Z@0000090=7=Z@070000003AcJT0dLfY
0=7=Z@000000dLfY0000000:0=7=Z@030000003AcJT0dLfY00H0dLfY00L000000=7=Z@3AcJT0dLfY
0000003AcJT0000000/0dLfY0P00000H0=7=Z@030000003AcJT0dLfY0180dLfY00@000000=7=Z@3A
cJT000002@3AcJT01`000000dLfY0=7=Z@3AcJT000000=7=Z@0000002P3AcJT00`000000dLfY0=7=
Z@070=7=Z@00403AcJT00`00001000000=7=Z@0_0=7=Z@040000003AcJT0dLfY000001L0dLfY00<0
00000=7=Z@0000002P3AcJT010000000dLfY0=7=Z@0000020=7=Z@030000003AcJT0dLfY00L0dLfY
00<000000=7=Z@3AcJT0503AcJT00`000000dLfY0000000:0=7=Z@040000003AcJT0dLfY00000080
dLfY00<000000=7=Z@3AcJT01`3AcJT00`000000dLfY0=7=Z@070=7=Z@040000003AcJT0dLfY0000
0080dLfY00<000000=7=Z@3AcJT0203AcJT00`000000dLfY0000000G0=7=Z@030000003AcJT0dLfY
01<0dLfY00<000000=7=Z@0000002P3AcJT010000000dLfY0=7=Z@0000020=7=Z@030000003AcJT0
dLfY00L0dLfY00<000000=7=Z@3AcJT01`3AcJT00100dLfY00<000000=7=Z@3AcJT0;`3AcJT01000
0000dLfY0=7=Z@00000G0=7=Z@030000003AcJT0000000X0dLfY00<000000=7=Z@0000000`3AcJT0
0`000000dLfY0=7=Z@070=7=Z@030000003AcJT0dLfY01@0dLfY00<000000=7=Z@0000002P3AcJT0
0`000000dLfY000000030=7=Z@030000003AcJT0dLfY00L0dLfY00<000000=7=Z@3AcJT01`3AcJT0
0`000000dLfY000000030=7=Z@030000003AcJT0dLfY00L0dLfY00@000000=7=Z@3AcJT000005`3A
cJT00`000000dLfY0=7=Z@0C0=7=Z@030000003AcJT0000000X0dLfY00<000000=7=Z@0000000`3A
cJT00`000000dLfY0=7=Z@070=7=Z@030000003AcJT0dLfY00L0dLfY000@0=7=Z@030000003AcJT0
dLfY02l0dLfY00@000000=7=Z@3AcJT000005`3AcJT00`000000dLfY0000000:0=7=Z@030000003A
cJT0000000<0dLfY00<000000=7=Z@3AcJT01`3AcJT00`000000dLfY0=7=Z@0D0=7=Z@030000003A
cJT0000000X0dLfY00<000000=7=Z@0000000`3AcJT00`000000dLfY0=7=Z@070=7=Z@030000003A
cJT0dLfY00L0dLfY00<000000=7=Z@0000000`3AcJT00`000000dLfY0=7=Z@070=7=Z@040000003A
cJT0dLfY000001H0dLfY00<000000=7=Z@3AcJT0503AcJT00`000000dLfY0000000:0=7=Z@030000
003AcJT0000000<0dLfY00<000000=7=Z@3AcJT01`3AcJT00`000000dLfY0=7=Z@070=7=Z@00403A
cJT00`000000dLfY0=7=Z@0_0=7=Z@040000003AcJT0dLfY000001L0dLfY00<000000=7=Z@000000
2P3AcJT00`000000dLfY000000030=7=Z@030000003AcJT0dLfY00L0dLfY00<000000=7=Z@3AcJT0
503AcJT00`000000dLfY0000000:0=7=Z@030000003AcJT0000000<0dLfY00<000000=7=Z@3AcJT0
1`3AcJT00`000000dLfY0=7=Z@070=7=Z@030000003AcJT0000000<0dLfY00<000000=7=Z@3AcJT0
1`3AcJT010000000dLfY0=7=Z@00000F0=7=Z@030000003AcJT0dLfY01@0dLfY00<000000=7=Z@00
00002P3AcJT00`000000dLfY000000030=7=Z@030000003AcJT0dLfY00L0dLfY00<000000=7=Z@3A
cJT01`3AcJT00100dLfY00<000000=7=Z@3AcJT0<03AcJT00`000000dLfY0000000G0=7=Z@030000
003AcJT0000000X0dLfY00<000000=7=Z@0000000`3AcJT00`000000dLfY0=7=Z@070=7=Z@030000
003AcJT0dLfY01@0dLfY00<000000=7=Z@0000002P3AcJT00`000000dLfY000000030=7=Z@030000
003AcJT0dLfY00L0dLfY00<000000=7=Z@3AcJT01`3AcJT00`000000dLfY000000030=7=Z@030000
003AcJT0dLfY00L0dLfY00@000000=7=Z@3AcJT000005P3AcJT00`000000dLfY0=7=Z@0D0=7=Z@03
0000003AcJT0000000X0dLfY00<000000=7=Z@0000000`3AcJT00`000000dLfY0=7=Z@070=7=Z@03
0000003AcJT0dLfY00L0dLfY000@0=7=Z@030000003AcJT0dLfY0300dLfY00<000000=7=Z@000000
5`3AcJT00`000000dLfY0000000:0=7=Z@030000003AcJT0000000<0dLfY00<000000=7=Z@3AcJT0
1`3AcJT00`000000dLfY0=7=Z@0D0=7=Z@030000003AcJT0000000X0dLfY00<000000=7=Z@000000
0`3AcJT00`000000dLfY0=7=Z@070=7=Z@030000003AcJT0dLfY00L0dLfY00<000000=7=Z@000000
0`3AcJT00`000000dLfY0=7=Z@070=7=Z@040000003AcJT0dLfY000001H0dLfY00<000000=7=Z@3A
cJT0503AcJT00`000000dLfY0000000:0=7=Z@030000003AcJT0000000<0dLfY00<000000=7=Z@3A
cJT01`3AcJT00`000000dLfY0=7=Z@070=7=Z@00403AcJT00`000000dLfY0=7=Z@0`0=7=Z@800000
603AcJT00`000000dLfY0000000:0=7=Z@030000003AcJT0000000<0dLfY00<000000=7=Z@3AcJT0
1`3AcJT00`000000dLfY0=7=Z@0D0=7=Z@030000003AcJT0000000X0dLfY00<000000=7=Z@000000
0`3AcJT00`000000dLfY0=7=Z@070=7=Z@030000003AcJT0dLfY00L0dLfY00<000000=7=Z@000000
0`3AcJT00`000000dLfY0=7=Z@070=7=Z@040000003AcJT0dLfY000001H0dLfY00<000000=7=Z@3A
cJT0503AcJT00`000000dLfY0000000:0=7=Z@030000003AcJT0000000<0dLfY00<000000=7=Z@3A
cJT01`3AcJT00`000000dLfY0=7=Z@070=7=Z@00403AcJT00`00001000000=7=Z@0`0=7=Z@800000
603AcJT2000000/0dLfY00<000000=7=Z@0000000`3AcJT00`000000dLfY0=7=Z@070=7=Z@030000
003AcJT0dLfY01@0dLfY0P00000;0=7=Z@030000003AcJT0000000<0dLfY00<000000=7=Z@3AcJT0
1`3AcJT00`000000dLfY0=7=Z@070=7=Z@030000003AcJT0000000<0dLfY00<000000=7=Z@3AcJT0
1`3AcJT010000000dLfY0=7=Z@00000F0=7=Z@030000003AcJT0dLfY01@0dLfY0P00000;0=7=Z@03
0000003AcJT0000000<0dLfY00<000000=7=Z@3AcJT01`3AcJT00`000000dLfY0=7=Z@070=7=Z@00
403AcJT00`000000dLfY0=7=Z@0`0=7=Z@800000603AcJT2000000/0dLfY00<000000=7=Z@000000
0`3AcJT00`000000dLfY0=7=Z@070=7=Z@030000003AcJT0dLfY01@0dLfY0P00000;0=7=Z@030000
003AcJT0000000<0dLfY00<000000=7=Z@3AcJT01`3AcJT00`000000dLfY0=7=Z@070=7=Z@030000
003AcJT0000000<0dLfY00<000000=7=Z@3AcJT01`3AcJT010000000dLfY0=7=Z@00000F0=7=Z@03
0000003AcJT0dLfY01@0dLfY0P00000;0=7=Z@030000003AcJT0000000<0dLfY00<000000=7=Z@3A
cJT01`3AcJT00`000000dLfY0=7=Z@070=7=Z@00403AcJT00`000000dLfY0=7=Z@0`0=7=Z@800000
6@3AcJT00`000000dLfY0=7=Z@0:0=7=Z@030000003AcJT0dLfY00<0dLfY00<000000=7=Z@3AcJT0
1P3AcJT00`000000dLfY0=7=Z@0E0=7=Z@030000003AcJT0dLfY00X0dLfY00<000000=7=Z@3AcJT0
0`3AcJT00`000000dLfY0=7=Z@060=7=Z@030000003AcJT0dLfY00P0dLfY00<000000=7=Z@3AcJT0
0`3AcJT00`000000dLfY0=7=Z@060=7=Z@050000003AcJT0dLfY0=7=Z@0000005@3AcJT00`000000
dLfY0=7=Z@0E0=7=Z@030000003AcJT0dLfY00X0dLfY00<000000=7=Z@3AcJT00`3AcJT00`000000
dLfY0=7=Z@060=7=Z@030000003AcJT0dLfY00L0dLfY000@0=7=Z@030000003AcJT0dLfY0340dLfY
00<000000=7=Z@3AcJT05`3AcJT00`000000dLfY0=7=Z@0:0=7=Z@030000003AcJT0dLfY00<0dLfY
00<000000=7=Z@3AcJT01P3AcJT00`000000dLfY0=7=Z@0E0=7=Z@030000003AcJT0dLfY00X0dLfY
00<000000=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@060=7=Z@030000003AcJT0dLfY00P0dLfY
00<000000=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@060=7=Z@050000003AcJT0dLfY0=7=Z@00
00005@3AcJT00`000000dLfY0=7=Z@0E0=7=Z@030000003AcJT0dLfY00X0dLfY00<000000=7=Z@3A
cJT00`3AcJT00`000000dLfY0=7=Z@060=7=Z@030000003AcJT0dLfY00L0dLfY000@0=7=Z@030000
003AcJT0dLfY0340dLfY00<000000=7=Z@3AcJT05`3AcJT00`000000dLfY0=7=Z@0:0=7=Z@030000
003AcJT0dLfY00<0dLfY00<000000=7=Z@3AcJT01P3AcJT00`000000dLfY0=7=Z@0E0=7=Z@030000
003AcJT0dLfY00X0dLfY00<000000=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@060=7=Z@030000
003AcJT0dLfY00P0dLfY00<000000=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@060=7=Z@050000
003AcJT0dLfY0=7=Z@0000005@3AcJT00`000000dLfY0=7=Z@0E0=7=Z@030000003AcJT0dLfY00X0
dLfY00<000000=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@060=7=Z@030000003AcJT0dLfY00L0
dLfY000@0=7=Z@030000003AcJT0dLfY0340dLfY00<000000=7=Z@3AcJT05`3AcJT00`000000dLfY
0=7=Z@0:0=7=Z@030000003AcJT0dLfY00<0dLfY00<000000=7=Z@3AcJT01P3AcJT00`000000dLfY
0=7=Z@0E0=7=Z@030000003AcJT0dLfY00X0dLfY00<000000=7=Z@3AcJT00`3AcJT00`000000dLfY
0=7=Z@060=7=Z@030000003AcJT0dLfY00P0dLfY00<000000=7=Z@3AcJT00`3AcJT00`000000dLfY
0=7=Z@060=7=Z@050000003AcJT0dLfY0=7=Z@0000005@3AcJT00`000000dLfY0=7=Z@0E0=7=Z@03
0000003AcJT0dLfY00X0dLfY00<000000=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@060=7=Z@03
0000003AcJT0dLfY00L0dLfY000@0=7=Z@03000004000000dLfY0340dLfY00<000000=7=Z@3AcJT0
5`3AcJT00`000000dLfY0=7=Z@0:0=7=Z@030000003AcJT0dLfY00<0dLfY1@0000040=7=Z@030000
003AcJT0dLfY01D0dLfY00<000000=7=Z@3AcJT02P3AcJT00`000000dLfY0=7=Z@030=7=Z@D00000
103AcJT00`000000dLfY0=7=Z@080=7=Z@030000003AcJT0dLfY00<0dLfY1@0000040=7=Z@040000
003AcJT0dLfY0=7=Z@D000001@3AcJT00`000000dLfY0=7=Z@090=7=Z@030000003AcJT0dLfY01D0
dLfY00<000000=7=Z@3AcJT02P3AcJT00`000000dLfY0=7=Z@030=7=Z@D00000103AcJT00`000000
dLfY0=7=Z@070=7=Z@00403AcJT00`000000dLfY0=7=Z@1R0=7=Z@030000003AcJT0dLfY0080dLfY
00<000000=7=Z@3AcJT0;03AcJT00`000000dLfY0=7=Z@020=7=Z@030000003AcJT0dLfY0180dLfY
00<000000=7=Z@3AcJT00P3AcJT00`000000dLfY0=7=Z@050=7=Z@030000003AcJT0dLfY00<0dLfY
00<000000=7=Z@3AcJT02@3AcJT00`000000dLfY0=7=Z@0/0=7=Z@030000003AcJT0dLfY0080dLfY
00<000000=7=Z@3AcJT01`3AcJT00100dLfY00<000000=7=Z@3AcJT0HP3AcJT00`000000dLfY0=7=
Z@020=7=Z@030000003AcJT0dLfY02`0dLfY00<000000=7=Z@3AcJT00P3AcJT00`000000dLfY0=7=
Z@0B0=7=Z@030000003AcJT0dLfY0080dLfY00<000000=7=Z@3AcJT01@3AcJT00`000000dLfY0=7=
Z@030=7=Z@030000003AcJT0dLfY00T0dLfY00<000000=7=Z@3AcJT0;03AcJT00`000000dLfY0=7=
Z@020=7=Z@030000003AcJT0dLfY00L0dLfY000@0=7=Z@030000003AcJT0dLfY0680dLfY00<00000
0=7=Z@3AcJT00P3AcJT00`000000dLfY0=7=Z@0/0=7=Z@030000003AcJT0dLfY0080dLfY00<00000
0=7=Z@3AcJT04P3AcJT00`000000dLfY0=7=Z@020=7=Z@030000003AcJT0dLfY00D0dLfY00<00000
0=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@090=7=Z@030000003AcJT0dLfY02`0dLfY00<00000
0=7=Z@3AcJT00P3AcJT00`000000dLfY0=7=Z@070=7=Z@00403AcJT00`000000dLfY0=7=Z@1R0=7=
Z@050000003AcJT0dLfY0=7=Z@000000;`3AcJT00`000000dLfY0=7=Z@020=7=Z@030000003AcJT0
dLfY0180dLfY00<000000=7=Z@3AcJT00P3AcJT00`000000dLfY0=7=Z@050=7=Z@030000003AcJT0
dLfY00<0dLfY00<000000=7=Z@3AcJT02@3AcJT00`000000dLfY0=7=Z@0/0=7=Z@030000003AcJT0
dLfY0080dLfY00<000000=7=Z@3AcJT01`3AcJT00100dLfY00<000000=7=Z@3AcJT0HP3AcJT01@00
0000dLfY0=7=Z@3AcJT0000002l0dLfY00<000000=7=Z@3AcJT00P3AcJT00`000000dLfY0=7=Z@0B
0=7=Z@030000003AcJT0dLfY0080dLfY00<000000=7=Z@3AcJT01@3AcJT00`000000dLfY0=7=Z@03
0=7=Z@030000003AcJT0dLfY00T0dLfY00<000000=7=Z@3AcJT0;03AcJT00`000000dLfY0=7=Z@02
0=7=Z@030000003AcJT0dLfY00L0dLfY000@0=7=Z@030000003AcJT0dLfY0680dLfY00D000000=7=
Z@3AcJT0dLfY0000000_0=7=Z@030000003AcJT0dLfY0080dLfY00<000000=7=Z@3AcJT04P3AcJT0
0`000000dLfY0=7=Z@020=7=Z@030000003AcJT0dLfY00D0dLfY00<000000=7=Z@3AcJT00`3AcJT0
0`000000dLfY0=7=Z@090=7=Z@030000003AcJT0dLfY02`0dLfY00<000000=7=Z@3AcJT00P3AcJT0
0`000000dLfY0=7=Z@070=7=Z@00403AcJT00`00001000000=7=Z@1R0=7=Z@050000003AcJT0dLfY
0=7=Z@000000;`3AcJT01@000000dLfY0=7=Z@3AcJT0000001D0dLfY00<000000=7=Z@3AcJT00P3A
cJT00`000000dLfY0=7=Z@050=7=Z@030000003AcJT0dLfY00<0dLfY00<000000=7=Z@3AcJT02@3A
cJT00`000000dLfY0=7=Z@0/0=7=Z@050000003AcJT0dLfY0=7=Z@0000002P3AcJT00100dLfY00<0
00000=7=Z@3AcJT0HP3AcJT01@000000dLfY0=7=Z@3AcJT0000002l0dLfY00D000000=7=Z@3AcJT0
dLfY0000000E0=7=Z@030000003AcJT0dLfY0080dLfY00<000000=7=Z@3AcJT01@3AcJT00`000000
dLfY0=7=Z@030=7=Z@030000003AcJT0dLfY00T0dLfY00<000000=7=Z@3AcJT0;03AcJT01@000000
dLfY0=7=Z@3AcJT0000000X0dLfY000@0=7=Z@030000003AcJT0dLfY06<0dLfY00@000000=7=Z@3A
cJT00000<03AcJT010000000dLfY0=7=Z@00000F0=7=Z@050000003AcJT0dLfY0=7=Z@000000203A
cJT01`000000dLfY0=7=Z@3AcJT000000=7=Z@0000002P3AcJT00`000000dLfY0=7=Z@0]0=7=Z@04
0000003AcJT0dLfY000000X0dLfY000@0=7=Z@030000003AcJT0dLfY06<0dLfY00@000000=7=Z@3A
cJT00000<03AcJT010000000dLfY0=7=Z@00000F0=7=Z@050000003AcJT0dLfY0=7=Z@000000203A
cJT01`000000dLfY0=7=Z@3AcJT000000=7=Z@0000002P3AcJT00`000000dLfY0=7=Z@0]0=7=Z@04
0000003AcJT0dLfY000000X0dLfY00000`3AcJU00000@0000002@00000<0dLfY0T0000060=7=Z@03
0000003AcJT0dLfY06<0dLfY00@000000=7=Z@3AcJT00000<03AcJT010000000dLfY0=7=Z@00000F
0=7=Z@050000003AcJT0dLfY0=7=Z@000000203AcJT01`000000dLfY0=7=Z@3AcJT000000=7=Z@00
00002P3AcJT00`000000dLfY0=7=Z@0]0=7=Z@040000003AcJT0dLfY000000X0dLfY00000`3AcJU0
00000=7=Z@040=7=Z@04@000003AcJT0dLfY@00000D0dLfY00<000000=7=Z@3AcJT0H`3AcJT01000
0000dLfY0=7=Z@00000`0=7=Z@040000003AcJT0dLfY000001H0dLfY00D000000=7=Z@3AcJT0dLfY
000000080=7=Z@070000003AcJT0dLfY0=7=Z@000000dLfY0000000:0=7=Z@030000003AcJT0dLfY
02d0dLfY00@000000=7=Z@3AcJT000002P3AcJT00080dLfY00=000000=7=Z@3AcJT00P3AcJT01400
0000dLfY0=7=ZD0000050=7=Z@03000004000000dLfY06<0dLfY00@000000=7=Z@3AcJT00000<03A
cJT010000000dLfY0=7=Z@00000F0=7=Z@050000003AcJT0dLfY0=7=Z@000000203AcJT01`000000
dLfY0=7=Z@3AcJT000000=7=Z@0000002P3AcJT00`000000dLfY0=7=Z@0]0=7=Z@040000003AcJT0
dLfY000000X0dLfY00030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=
Z@030=7=Z@030000003AcJT0dLfY06<0dLfY00@000000=7=Z@3AcJT00000<03AcJT010000000dLfY
0=7=Z@00000F0=7=Z@040000003AcJT0dLfY000000T0dLfY00L000000=7=Z@3AcJT0dLfY0000003A
cJT0000000X0dLfY00<000000=7=Z@3AcJT0;@3AcJT010000000dLfY0=7=Z@00000:0=7=Z@0000D0
dLfY@000003AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@00000D0dLfY00<000000=7=Z@3A
cJT0H`3AcJT010000000dLfY0=7=Z@00000`0=7=Z@040000003AcJT0dLfY000001H0dLfY00@00000
0=7=Z@3AcJT000002@3AcJT01`000000dLfY0=7=Z@3AcJT000000=7=Z@0000002P3AcJT00`000000
dLfY0=7=Z@0]0=7=Z@040000003AcJT0dLfY000000X0dLfY00020=7=Z@900000103AcJT2@00000H0
dLfY00<000000=7=Z@3AcJT0H`3AcJT010000000dLfY0=7=Z@00000`0=7=Z@040000003AcJT0dLfY
000001H0dLfY00@000000=7=Z@3AcJT000002@3AcJT01`000000dLfY0=7=Z@3AcJT000000=7=Z@00
00002P3AcJT00`000000dLfY0=7=Z@0]0=7=Z@040000003AcJT0dLfY000000X0dLfY000@0=7=Z@03
0000003AcJT0dLfY06<0dLfY00@000000=7=Z@3AcJT00000<03AcJT010000000dLfY0=7=Z@00000F
0=7=Z@040000003AcJT0dLfY000000T0dLfY00L000000=7=Z@3AcJT0dLfY0000003AcJT0000000X0
dLfY00<000000=7=Z@3AcJT0;@3AcJT010000000dLfY0=7=Z@00000:0=7=Z@00403AcJT00`000000
dLfY0=7=Z@1S0=7=Z@040000003AcJT0dLfY00000300dLfY00@000000=7=Z@3AcJT000005P3AcJT0
10000000dLfY0=7=Z@0000090=7=Z@070000003AcJT0dLfY0=7=Z@000000dLfY0000000:0=7=Z@03
0000003AcJT0dLfY02d0dLfY00@000000=7=Z@3AcJT000002P3AcJT00100dLfY00<000000=7=Z@3A
cJT0H`3AcJT010000000dLfY0=7=Z@00000`0=7=Z@040000003AcJT0dLfY000001H0dLfY00@00000
0=7=Z@3AcJT000002@3AcJT01`000000dLfY0=7=Z@3AcJT000000=7=Z@0000002P3AcJT00`000000
dLfY0=7=Z@0]0=7=Z@040000003AcJT0dLfY000000X0dLfY000@0=7=Z@03000004000000dLfY06<0
dLfY00@000000=7=Z@3AcJT00000<03AcJT010000000dLfY0=7=Z@00000F0=7=Z@040000003AcJT0
dLfY000000T0dLfY00L000000=7=Z@3AcJT0dLfY0000003AcJT0000000X0dLfY00<000000=7=Z@3A
cJT0;@3AcJT010000000dLfY0=7=Z@00000:0=7=Z@00403AcJT00`000000dLfY0=7=Z@1S0=7=Z@04
0000003AcJT0dLfY00000300dLfY00@000000=7=Z@3AcJT000005P3AcJT010000000dLfY0=7=Z@00
00090=7=Z@070000003AcJT0dLfY0=7=Z@000000dLfY0000000:0=7=Z@030000003AcJT0dLfY02d0
dLfY00@000000=7=Z@3AcJT000002P3AcJT00100dLfY00<000000=7=Z@3AcJT0H`3AcJT010000000
dLfY0=7=Z@00000`0=7=Z@040000003AcJT0dLfY000001H0dLfY00@000000=7=Z@3AcJT000002@3A
cJT01`000000dLfY0=7=Z@3AcJT000000=7=Z@0000002P3AcJT00`000000dLfY0=7=Z@0]0=7=Z@04
0000003AcJT0dLfY000000X0dLfY000@0=7=Z@030000003AcJT0dLfY06<0dLfY00@000000=7=Z@3A
cJT00000<03AcJT010000000dLfY0=7=Z@00000F0=7=Z@040000003AcJT0dLfY000000T0dLfY00L0
00000=7=Z@3AcJT0dLfY0000003AcJT0000000X0dLfY00<000000=7=Z@3AcJT0;@3AcJT010000000
dLfY0=7=Z@00000:0=7=Z@00403AcJT00`000000dLfY0=7=Z@1S0=7=Z@040000003AcJT0dLfY0000
0300dLfY00@000000=7=Z@3AcJT000005P3AcJT010000000dLfY0=7=Z@0000090=7=Z@070000003A
cJT0dLfY0=7=Z@000000dLfY0000000:0=7=Z@030000003AcJT0dLfY02d0dLfY00@000000=7=Z@3A
cJT000002P3AcJT00100dLfY00<000000=7=Z@3AcJT0H`3AcJT010000000dLfY0=7=Z@00000`0=7=
Z@040000003AcJT0dLfY000001H0dLfY00@000000=7=Z@3AcJT000002@3AcJT01`000000dLfY0=7=
Z@3AcJT000000=7=Z@0000002P3AcJT00`000000dLfY0=7=Z@0]0=7=Z@040000003AcJT0dLfY0000
00X0dLfY000@0=7=Z@03000004000000dLfY06@0dLfY00<000000=7=Z@000000<@3AcJT00`000000
dLfY0000000G0=7=Z@030000003AcJT0000000X0dLfY00@000000=7=Z@3AcJT000000P3AcJT00`00
0000dLfY0=7=Z@070=7=Z@030000003AcJT0dLfY02h0dLfY00<000000=7=Z@0000002P3AcJT00100
dLfY00<000000=7=Z@3AcJT0I03AcJT00`000000dLfY0000000a0=7=Z@030000003AcJT0000001L0
dLfY00<000000=7=Z@0000002P3AcJT00`000000dLfY000000030=7=Z@030000003AcJT0dLfY00L0
dLfY00<000000=7=Z@3AcJT0;P3AcJT00`000000dLfY0000000:0=7=Z@00403AcJT00`000000dLfY
0=7=Z@1T0=7=Z@030000003AcJT000000340dLfY00<000000=7=Z@0000005`3AcJT00`000000dLfY
0000000:0=7=Z@030000003AcJT0000000<0dLfY00<000000=7=Z@3AcJT01`3AcJT00`000000dLfY
0=7=Z@0^0=7=Z@030000003AcJT0000000X0dLfY000@0=7=Z@030000003AcJT0dLfY06@0dLfY00<0
00000=7=Z@000000<@3AcJT00`000000dLfY0000000G0=7=Z@030000003AcJT0000000X0dLfY00<0
00000=7=Z@0000000`3AcJT00`000000dLfY0=7=Z@070=7=Z@030000003AcJT0dLfY02h0dLfY00<0
00000=7=Z@0000002P3AcJT00100dLfY00<000000=7=Z@3AcJT0I03AcJT00`000000dLfY0000000a
0=7=Z@030000003AcJT0000001L0dLfY00<000000=7=Z@0000002P3AcJT00`000000dLfY00000003
0=7=Z@030000003AcJT0dLfY00L0dLfY00<000000=7=Z@3AcJT0;P3AcJT00`000000dLfY0000000:
0=7=Z@00403AcJT00`000000dLfY0=7=Z@1T0=7=Z@030000003AcJT000000340dLfY00<000000=7=
Z@0000005`3AcJT00`000000dLfY0000000:0=7=Z@030000003AcJT0000000<0dLfY00<000000=7=
Z@3AcJT01`3AcJT00`000000dLfY0=7=Z@0^0=7=Z@030000003AcJT0000000X0dLfY000@0=7=Z@03
0000003AcJT0dLfY06@0dLfY00<000000=7=Z@000000<@3AcJT00`000000dLfY0000000G0=7=Z@03
0000003AcJT0000000X0dLfY00<000000=7=Z@0000000`3AcJT00`000000dLfY0=7=Z@070=7=Z@03
0000003AcJT0dLfY02h0dLfY00<000000=7=Z@0000002P3AcJT00100dLfY00<00000@000003AcJT0
I03AcJT00`000000dLfY0000000a0=7=Z@030000003AcJT0000001L0dLfY00<000000=7=Z@000000
2P3AcJT00`000000dLfY000000030=7=Z@030000003AcJT0dLfY00L0dLfY00<000000=7=Z@3AcJT0
;P3AcJT00`000000dLfY0000000:0=7=Z@00403AcJT00`000000dLfY0=7=Z@1T0=7=Z@030000003A
cJT000000340dLfY00<000000=7=Z@0000005`3AcJT00`000000dLfY0000000:0=7=Z@030000003A
cJT0000000<0dLfY00<000000=7=Z@3AcJT01`3AcJT00`000000dLfY0=7=Z@0^0=7=Z@030000003A
cJT0000000X0dLfY000@0=7=Z@030000003AcJT0dLfY06@0dLfY00<000000=7=Z@000000<@3AcJT0
0`000000dLfY0000000G0=7=Z@030000003AcJT0000000X0dLfY00<000000=7=Z@0000000`3AcJT0
0`000000dLfY0=7=Z@070=7=Z@030000003AcJT0dLfY02h0dLfY00<000000=7=Z@0000002P3AcJT0
0100dLfY00<000000=7=Z@3AcJT0I03AcJT200000380dLfY00<000000=7=Z@0000005`3AcJT00`00
0000dLfY0000000:0=7=Z@030000003AcJT0000000<0dLfY00<000000=7=Z@3AcJT01`3AcJT00`00
0000dLfY0=7=Z@0^0=7=Z@030000003AcJT0000000X0dLfY000@0=7=Z@030000003AcJT0dLfY06@0
dLfY0P00000b0=7=Z@800000603AcJT00`000000dLfY0000000:0=7=Z@030000003AcJT0000000<0
dLfY00<000000=7=Z@3AcJT01`3AcJT00`000000dLfY0=7=Z@0^0=7=Z@8000002`3AcJT00100dLfY
00<000000=7=Z@3AcJT0I03AcJT200000380dLfY0P00000H0=7=Z@030000003AcJT0000000X0dLfY
00<000000=7=Z@0000000`3AcJT00`000000dLfY0=7=Z@070=7=Z@030000003AcJT0dLfY02h0dLfY
0P00000;0=7=Z@00403AcJT00`00001000000=7=Z@1T0=7=Z@800000<P3AcJT2000001P0dLfY00<0
00000=7=Z@0000002P3AcJT00`000000dLfY000000030=7=Z@030000003AcJT0dLfY00L0dLfY00<0
00000=7=Z@3AcJT0;P3AcJT2000000/0dLfY000@0=7=Z@030000003AcJT0dLfY06@0dLfY0P00000b
0=7=Z@800000603AcJT2000000/0dLfY00<000000=7=Z@0000000`3AcJT00`000000dLfY0=7=Z@07
0=7=Z@030000003AcJT0dLfY02h0dLfY0P00000;0=7=Z@00403AcJT00`000000dLfY0=7=Z@1T0=7=
Z@800000<P3AcJT2000001P0dLfY0P00000;0=7=Z@030000003AcJT0000000<0dLfY00<000000=7=
Z@3AcJT01`3AcJT00`000000dLfY0=7=Z@0^0=7=Z@8000002`3AcJT00100dLfY00<000000=7=Z@3A
cJT0I03AcJT200000380dLfY0P00000H0=7=Z@8000002`3AcJT00`000000dLfY000000030=7=Z@03
0000003AcJT0dLfY00L0dLfY00<000000=7=Z@3AcJT0;P3AcJT2000000/0dLfY000@0=7=Z@030000
003AcJT0dLfY06@0dLfY0P00000b0=7=Z@800000603AcJT2000000/0dLfY00<000000=7=Z@000000
0`3AcJT00`000000dLfY0=7=Z@070=7=Z@030000003AcJT0dLfY02h0dLfY0P00000;0=7=Z@000P3A
cJT2@00000@0dLfY0T0000060=7=Z@030000003AcJT0dLfY06D0dLfY00<000000=7=Z@3AcJT0<@3A
cJT00`000000dLfY0=7=Z@0G0=7=Z@030000003AcJT0dLfY00X0dLfY00<000000=7=Z@3AcJT00`3A
cJT00`000000dLfY0=7=Z@060=7=Z@030000003AcJT0dLfY02l0dLfY00<000000=7=Z@3AcJT02@3A
cJT000050=7=ZD000000dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000050=7=Z@030000
003AcJT0dLfY06D0dLfY00<000000=7=Z@3AcJT0<@3AcJT00`000000dLfY0=7=Z@0G0=7=Z@030000
003AcJT0dLfY00X0dLfY00<000000=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@060=7=Z@030000
003AcJT0dLfY02l0dLfY00<000000=7=Z@3AcJT02@3AcJT000<0dLfY00E000000=7=Z@3AcJT0dLfY
@00000020=7=Z@03@000003AcJT0dLfY00<0dLfY00<00000@000003AcJT0I@3AcJT00`000000dLfY
0=7=Z@0a0=7=Z@030000003AcJT0dLfY01L0dLfY00<000000=7=Z@3AcJT02P3AcJT00`000000dLfY
0=7=Z@030=7=Z@030000003AcJT0dLfY00H0dLfY00<000000=7=Z@3AcJT0;`3AcJT00`000000dLfY
0=7=Z@090=7=Z@00103AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00<0dLfY
00<000000=7=Z@3AcJT0I@3AcJT00`000000dLfY0=7=Z@0a0=7=Z@030000003AcJT0dLfY01L0dLfY
00<000000=7=Z@3AcJT02P3AcJT00`000000dLfY0=7=Z@030=7=Z@030000003AcJT0dLfY00H0dLfY
00<000000=7=Z@3AcJT0;`3AcJT00`000000dLfY0=7=Z@090=7=Z@0000D0dLfY@000003AcJT0dLfY
@00000020=7=Z@04@000003AcJT0dLfY@00000D0dLfY00<000000=7=Z@3AcJT0I@3AcJT00`000000
dLfY0=7=Z@0a0=7=Z@030000003AcJT0dLfY01L0dLfY00<000000=7=Z@3AcJT02P3AcJT00`000000
dLfY0=7=Z@030=7=Z@030000003AcJT0dLfY00H0dLfY00<000000=7=Z@3AcJT0;`3AcJT00`000000
dLfY0=7=Z@090=7=Z@000P3AcJT2@00000@0dLfY0T0000060=7=Z@030000003AcJT0dLfY06D0dLfY
00<000000=7=Z@3AcJT0<@3AcJT00`000000dLfY0=7=Z@0G0=7=Z@030000003AcJT0dLfY00X0dLfY
00<000000=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@060=7=Z@030000003AcJT0dLfY02l0dLfY
00<000000=7=Z@3AcJT02@3AcJT00100dLfY00<000000=7=Z@3AcJT0I@3AcJT00`000000dLfY0=7=
Z@0a0=7=Z@030000003AcJT0dLfY01L0dLfY00<000000=7=Z@3AcJT02P3AcJT00`000000dLfY0=7=
Z@030=7=Z@030000003AcJT0dLfY00H0dLfY00<000000=7=Z@3AcJT0;`3AcJT00`000000dLfY0=7=
Z@090=7=Z@00403AcJT00`000000dLfY0=7=Z@1U0=7=Z@030000003AcJT0dLfY0340dLfY00<00000
0=7=Z@3AcJT05`3AcJT00`000000dLfY0=7=Z@0:0=7=Z@030000003AcJT0dLfY00<0dLfY00<00000
0=7=Z@3AcJT01P3AcJT00`000000dLfY0=7=Z@0_0=7=Z@030000003AcJT0dLfY00T0dLfY000@0=7=
Z@03000004000000dLfY06D0dLfY00<000000=7=Z@3AcJT0<@3AcJT00`000000dLfY0=7=Z@0G0=7=
Z@030000003AcJT0dLfY00X0dLfY00<000000=7=Z@3AcJT00`3AcJT5000000@0dLfY00<000000=7=
Z@3AcJT0;`3AcJT00`000000dLfY0=7=Z@090=7=Z@00403AcJT00`000000dLfY0=7=Z@3:0=7=Z@03
0000003AcJT0dLfY0080dLfY00<000000=7=Z@3AcJT0>`3AcJT00100dLfY00<000000=7=Z@3AcJT0
bP3AcJT00`000000dLfY0=7=Z@020=7=Z@030000003AcJT0dLfY03/0dLfY000@0=7=Z@030000003A
cJT0dLfY0<X0dLfY00<000000=7=Z@3AcJT00P3AcJT00`000000dLfY0=7=Z@0k0=7=Z@00403AcJT0
0`000000dLfY0=7=Z@3:0=7=Z@050000003AcJT0dLfY0=7=Z@000000?P3AcJT00100dLfY00<00000
0=7=Z@3AcJT0bP3AcJT01@000000dLfY0=7=Z@3AcJT0000003h0dLfY000@0=7=Z@030000003AcJT0
dLfY0<X0dLfY00D000000=7=Z@3AcJT0dLfY0000000n0=7=Z@00403AcJT00`00001000000=7=Z@3:
0=7=Z@050000003AcJT0dLfY0=7=Z@000000?P3AcJT00100dLfY00<000000=7=Z@3AcJT0bP3AcJT0
1@000000dLfY0=7=Z@3AcJT0000003h0dLfY000@0=7=Z@030000003AcJT0dLfY0<X0dLfY00D00000
0=7=Z@3AcJT0dLfY0000000n0=7=Z@00403AcJT00`000000dLfY0=7=Z@3:0=7=Z@050000003AcJT0
dLfY0=7=Z@000000?P3AcJT00100dLfY00<000000=7=Z@3AcJT0bP3AcJT01@000000dLfY0=7=Z@3A
cJT0000003h0dLfY000@0=7=Z@030000003AcJT0dLfY0<X0dLfY00D000000=7=Z@3AcJT0dLfY0000
000n0=7=Z@00403AcJT00`00001000000=7=Z@3:0=7=Z@050000003AcJT0dLfY0=7=Z@000000?P3A
cJT00100dLfY00<000000=7=Z@3AcJT0bP3AcJT01@000000dLfY0=7=Z@3AcJT0000003h0dLfY000@
0=7=Z@030000003AcJT0dLfY0<X0dLfY00D000000=7=Z@3AcJT0dLfY0000000n0=7=Z@00403AcJT0
0`000000dLfY0=7=Z@3:0=7=Z@050000003AcJT0dLfY0=7=Z@000000?P3AcJT00100dLfY00<00000
0=7=Z@3AcJT0bP3AcJT01@000000dLfY0=7=Z@3AcJT0000003h0dLfY000@0=7=Z@030000003AcJT0
dLfY0</0dLfY00@000000=7=Z@3AcJT00000?P3AcJT00100dLfY00<000000=7=Z@3AcJT0b`3AcJT0
10000000dLfY0=7=Z@00000n0=7=Z@00403AcJT00`00001000000=7=Z@3;0=7=Z@040000003AcJT0
dLfY000003h0dLfY000@0=7=Z@030000003AcJT0dLfY0</0dLfY00@000000=7=Z@3AcJT00000?P3A
cJT00100dLfY00<000000=7=Z@3AcJT0b`3AcJT010000000dLfY0=7=Z@00000n0=7=Z@00403AcJT0
0`000000dLfY0=7=Z@3;0=7=Z@040000003AcJT0dLfY000003h0dLfY00030=7=Z@=000000P3AcJT2
@00000H0dLfY00<000000=7=Z@3AcJT0b`3AcJT010000000dLfY0=7=Z@00000n0=7=Z@00103AcJT0
14000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00<0dLfY00<000000=7=Z@3AcJT0b`3A
cJT010000000dLfY0=7=Z@00000n0=7=Z@0000<0dLfY@000040000000d0000001@3AcJU000000=7=
Z@3AcJU0000000D0dLfY00<00000@000003AcJT0b`3AcJT010000000dLfY0=7=Z@00000n0=7=Z@00
00D0dLfY@000003AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@00000D0dLfY00<000000=7=
Z@3AcJT0b`3AcJT010000000dLfY0=7=Z@00000n0=7=Z@000P3AcJT00d000000dLfY@00000020=7=
Z@04@000003AcJT0dLfY@00000D0dLfY00<000000=7=Z@3AcJT0b`3AcJT010000000dLfY0=7=Z@00
000n0=7=Z@000`3AcJT2@00000<0dLfY0T0000060=7=Z@030000003AcJT0dLfY0</0dLfY00@00000
0=7=Z@3AcJT00000?P3AcJT00100dLfY00<000000=7=Z@3AcJT0b`3AcJT010000000dLfY0=7=Z@00
000n0=7=Z@00403AcJT00`000000dLfY0=7=Z@3;0=7=Z@040000003AcJT0dLfY000003h0dLfY000@
0=7=Z@030000003AcJT0dLfY0</0dLfY00@000000=7=Z@3AcJT00000?P3AcJT00100dLfY00<00000
@000003AcJT0b`3AcJT010000000dLfY0=7=Z@00000n0=7=Z@00403AcJT00`000000dLfY0=7=Z@3;
0=7=Z@040000003AcJT0dLfY000003h0dLfY000@0=7=Z@030000003AcJT0dLfY0</0dLfY00@00000
0=7=Z@3AcJT00000?P3AcJT00100dLfY00<000000=7=Z@3AcJT0b`3AcJT010000000dLfY0=7=Z@00
000n0=7=Z@00403AcJT00`000000dLfY0=7=Z@3;0=7=Z@040000003AcJT0dLfY000003h0dLfY000@
0=7=Z@030000003AcJT0dLfY0</0dLfY00@000000=7=Z@3AcJT00000?P3AcJT00100dLfY00<00000
@000003AcJT0b`3AcJT010000000dLfY0=7=Z@00000n0=7=Z@00403AcJT00`000000dLfY0=7=Z@3;
0=7=Z@040000003AcJT0dLfY000003h0dLfY000@0=7=Z@030000003AcJT0dLfY0</0dLfY00@00000
0=7=Z@3AcJT00000?P3AcJT00100dLfY00<000000=7=Z@3AcJT0b`3AcJT010000000dLfY0=7=Z@00
000n0=7=Z@00403AcJT00`000000dLfY0=7=Z@3;0=7=Z@040000003AcJT0dLfY000003h0dLfY000@
0=7=Z@030000003AcJT0dLfY0</0dLfY00@000000=7=Z@3AcJT00000?P3AcJT00100dLfY00<00000
0=7=Z@3AcJT0b`3AcJT010000000dLfY0=7=Z@00000n0=7=Z@00403AcJT00`00001000000=7=Z@3;
0=7=Z@040000003AcJT0dLfY000003h0dLfY000@0=7=Z@030000003AcJT0dLfY0</0dLfY00@00000
0=7=Z@3AcJT00000?P3AcJT00100dLfY00<000000=7=Z@3AcJT0b`3AcJT010000000dLfY0=7=Z@00
000n0=7=Z@00403AcJT00`000000dLfY0=7=Z@3;0=7=Z@040000003AcJT0dLfY000003h0dLfY000@
0=7=Z@030000003AcJT0dLfY0</0dLfY00@000000=7=Z@3AcJT00000?P3AcJT00100dLfY00<00000
0=7=Z@3AcJT0b`3AcJT010000000dLfY0=7=Z@00000n0=7=Z@00403AcJT00`00001000000=7=Z@3<
0=7=Z@030000003AcJT0000003h0dLfY000@0=7=Z@030000003AcJT0dLfY0<`0dLfY00<000000=7=
Z@000000?P3AcJT00100dLfY00<000000=7=Z@3AcJT0c03AcJT00`000000dLfY0000000n0=7=Z@00
403AcJT00`000000dLfY0=7=Z@3<0=7=Z@030000003AcJT0000003h0dLfY000@0=7=Z@030000003A
cJT0dLfY0<`0dLfY00<000000=7=Z@000000?P3AcJT00080dLfY0T0000040=7=Z@9000001P3AcJT0
0`000000dLfY0=7=Z@3<0=7=Z@030000003AcJT0000003h0dLfY00001@3AcJU000000=7=Z@3AcJU0
00000080dLfY00A000000=7=Z@3AcJU000001@3AcJT00`000000dLfY0=7=Z@3<0=7=Z@030000003A
cJT0000003h0dLfY00040=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00`3A
cJT00`00001000000=7=Z@3<0=7=Z@030000003AcJT0000003h0dLfY00020=7=Z@9000000`3AcJT0
14000000dLfY0=7=ZD0000050=7=Z@030000003AcJT0dLfY0<`0dLfY00<000000=7=Z@000000?P3A
cJT00080dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000050=7=Z@030000003A
cJT0dLfY0<`0dLfY00<000000=7=Z@000000?P3AcJT00080dLfY0d0000030=7=Z@9000001P3AcJT0
0`000000dLfY0=7=Z@3<0=7=Z@030000003AcJT0000003h0dLfY000@0=7=Z@030000003AcJT0dLfY
0<`0dLfY00<000000=7=Z@000000?P3AcJT00100dLfY00<000000=7=Z@3AcJT0c03AcJT00`000000
dLfY0000000n0=7=Z@00403AcJT00`00001000000=7=Z@3<0=7=Z@030000003AcJT0000003h0dLfY
000@0=7=Z@030000003AcJT0dLfY0<`0dLfY00<000000=7=Z@000000?P3AcJT00100dLfY00<00000
0=7=Z@3AcJT0c03AcJT00`000000dLfY0000000n0=7=Z@00403AcJT00`000000dLfY0=7=Z@3<0=7=
Z@030000003AcJT0000003h0dLfY000@0=7=Z@030000003AcJT0dLfY0<`0dLfY00<000000=7=Z@00
0000?P3AcJT00100dLfY00<000000=7=Z@3AcJT0c03AcJT00`000000dLfY0000000n0=7=Z@00403A
cJT00`000000dLfY0=7=Z@3<0=7=Z@800000?`3AcJT00100dLfY00<00000@000003AcJT0c03AcJT2
000003l0dLfY000@0=7=Z@030000003AcJT0dLfY0<`0dLfY0P00000o0=7=Z@00403AcJT00`000000
dLfY0=7=Z@3<0=7=Z@800000?`3AcJT00100dLfY00<000000=7=Z@3AcJT0c03AcJT2000003l0dLfY
000@0=7=Z@030000003AcJT0dLfY0<`0dLfY0P00000o0=7=Z@00403AcJT00`000000dLfY0=7=Z@3<
0=7=Z@800000?`3AcJT00100dLfY00<00000@000003AcJT0c03AcJT2000003l0dLfY000@0=7=Z@03
0000003AcJT0dLfY0<`0dLfY0P00000o0=7=Z@00403AcJT00`000000dLfY0=7=Z@3<0=7=Z@800000
?`3AcJT00100dLfY00<000000=7=Z@3AcJT0c03AcJT2000003l0dLfY000@0=7=Z@030000003AcJT0
dLfY0<`0dLfY0P00000o0=7=Z@00403AcJT00`000000dLfY0=7=Z@3<0=7=Z@800000?`3AcJT00100
dLfY00<000000=7=Z@3AcJT0c03AcJT2000003l0dLfY000@0=7=Z@03000004000000dLfY0<`0dLfY
0P00000o0=7=Z@00403AcJT00`000000dLfY0=7=Z@3<0=7=Z@800000?`3AcJT00100dLfY00<00000
0=7=Z@3AcJT0c@3AcJT00`000000dLfY0=7=Z@0m0=7=Z@00403AcJT00`000000dLfY0=7=Z@3=0=7=
Z@030000003AcJT0dLfY03d0dLfY0000103AcJU00000@000040000040=7=Z@9000001P3AcJT00`00
0000dLfY0=7=Z@3=0=7=Z@030000003AcJT0dLfY03d0dLfY00001@3AcJU000000=7=Z@3AcJU00000
0080dLfY00A000000=7=Z@3AcJU000001@3AcJT00`000000dLfY0=7=Z@3=0=7=Z@030000003AcJT0
dLfY03d0dLfY00001@3AcJU000000=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000001@3A
cJT00`00001000000=7=Z@3=0=7=Z@030000003AcJT0dLfY03d0dLfY0000103AcJU00000@0000400
00030=7=Z@04@000003AcJT0dLfY@00000D0dLfY00<000000=7=Z@3AcJT0c@3AcJT00`000000dLfY
0=7=Z@0m0=7=Z@000P3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@00000D0dLfY
00<000000=7=Z@3AcJT0c@3AcJT00`000000dLfY0=7=Z@0m0=7=Z@000P3AcJT3@00000<0dLfY0T00
00060=7=Z@030000003AcJT0dLfY0<d0dLfY00<000000=7=Z@3AcJT0?@3AcJT00100dLfY00<00000
0=7=Z@3AcJT0c@3AcJT00`000000dLfY0=7=Z@0m0=7=Z@00403AcJT00`000000dLfY0=7=Z@3=0=7=
Z@030000003AcJT0dLfY03d0dLfY000@0=7=Z@030000003AcJT0dLfY0<d0dLfY00<000000=7=Z@3A
cJT0?@3AcJT00100dLfY00<00000@000003AcJT0c@3AcJT00`000000dLfY0=7=Z@0m0=7=Z@00403A
cJT00`000000dLfY0=7=Z@3=0=7=Z@030000003AcJT0dLfY03d0dLfY000@0=7=Z@030000003AcJT0
dLfY0<d0dLfY00<000000=7=Z@3AcJT0?@3AcJT00100dLfY00<000000=7=Z@3AcJT0c@3AcJT00`00
0000dLfY0=7=Z@0m0=7=Z@00403AcJT00`000000dLfY0=7=Z@3=0=7=Z@030000003AcJT0dLfY03d0
dLfY000@0=7=Z@030000003AcJT0dLfY0<d0dLfY00<000000=7=Z@3AcJT0?@3AcJT00100dLfY00<0
0000@000003AcJT0c@3AcJT00`000000dLfY0=7=Z@0m0=7=Z@00403AcJT00`000000dLfY0=7=Z@3o
0=7=Z@h0dLfY000@0=7=Z@030000003AcJT0dLfY0?l0dLfY3P3AcJT00100dLfY00<000000=7=Z@3A
cJT0o`3AcJT>0=7=Z@00403AcJT00`000000dLfY0=7=Z@3o0=7=Z@h0dLfY000@0=7=Z@03@000003A
cJT0dLfY0?l0dLfY3P3AcJT00001\
\>"],
  ImageRangeCache->{{{0, 287}, {225.75, 0}} -> {-4.97895, -3.81637, 0.307382, \
0.307382}}]
}, Open  ]],

Cell[TextData[{
  "We generate this sequence by writing down 1 and proceeding duplicating the \
numbers starting from the beginning of the sequence until reaching the last \
one generated at the previous stage and starting again the whole process from \
the beginning. Denoting this sequence by u we have that u(",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  ")=",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  ". Given n writen in binary, let m be the number obtained by removing \
n\.b4s first digit 1. Then u(n)=2u(m), u(",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  ")=",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  ". For instance, we can compute u(70) through considering the succession \
1000110, 110, 10, u(70)=2 u(6)=4 u(2)=8. In other words, given the binary \
representation of n given as X1",
  Cell[BoxData[
      \(TraditionalForm\`0\^k\ \((ends\ in\ k\ zeroes)\)\)]],
  ", then u(n)=",
  Cell[BoxData[
      \(TraditionalForm\`2\^\(number\ of\ 1  \.b4s\ in\ X + k\)\)]]
}], "Text"],

Cell[BoxData[{
    \(u[n_] := 
      v[IntegerDigits[n, 2]]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(v[{x___, 1, y___}] := 
      2\^\(Plus\  @@ \ {x} + Length[{y}]\)\  /; \ 
        Plus\  @@ \ {y} == 0\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[u[n], {n, 30}]\)], "Input"],

Cell[BoxData[
    \({1, 2, 2, 4, 2, 4, 4, 8, 2, 4, 4, 8, 4, 8, 8, 16, 2, 4, 4, 8, 4, 8, 8, 
      16, 4, 8, 8, 16, 8, 16}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["IRREDUCIBLE CA", "Subsection"],

Cell["\<\
We can monitor all rules used so far and eliminate those that are not \
actually used to obtain the equivalent canonical rule generating the CA. The \
question of how many generations to go through in order to be able to be sure \
no other rules will be used is still unknown and we choose 40 steps in the \
following.\
\>", "Text",
  PageWidth->WindowWidth,
  ShowSpecialCharacters->False],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(b = 2;\)\), "\[IndentingNewLine]", 
    \(\(cS = cellularSpace[161];\)\), "\[IndentingNewLine]", 
    \(\(allRules = 
        Select[IntegerDigits[Range[0, b\^\(b\^3 - 1\) - 1], b, 
            b\^3], #\[LeftDoubleBracket]{b, 1 + b, 
                  1 + b\^2}\[RightDoubleBracket] \[NotEqual] {0, 0, 
                0} &];\)\), "\[IndentingNewLine]", 
    \(\(s = symm[b];\)\), "\[IndentingNewLine]", 
    \(\(allRules = 
        Select[allRules, 
          FromDigits[#] \[LessEqual] 
              FromDigits[#\[LeftDoubleBracket]
                  s\[RightDoubleBracket]] &];\)\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(ans = {};\)\), "\[IndentingNewLine]", 
    \(\(Map[\[IndentingNewLine]\((r = #; \[IndentingNewLine]m = 
              evolve[b, cS, r, 40]; \[IndentingNewLine]pat = 
              IntegerDigits[
                Complement[Range[b\^3], Flatten[Position[r, 0]]] - 1, b, 
                3]; \[IndentingNewLine]p = 
              Union[Flatten[
                  Map[\((j = Partition[#, 3, 1]; \ 
                        Select[j, MemberQ[pat, #] &])\) &, m], 
                  1]]; \[IndentingNewLine]If[p == pat, 
              ans = Flatten[{ans, {r}}, 1]])\) &, 
        allRules];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(allRules = ans;\)\), "\[IndentingNewLine]", 
    \(\(g = 
        Map[showCA[b, cS, #, 40, 1, 40, 120, 2] &, 
          allRules];\)\), "\[IndentingNewLine]", 
    \(\(AppendTo[g, Graphics[{}]];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Partition[g, 4]], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74648 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0177734 0.238095 [
[ 0 0 0 0 ]
[ 1 .74648 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .74648 L
0 .74648 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0177734 0.245293 0.127148 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(122) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF000000
FFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF0000FF
FFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF000000FFFF
FFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF0000FFFFFF
FFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF000000FFFFFFFF
FFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF
00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF
00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.0177734 0.488926 0.127148 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(123) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000FF
FFFFFFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFF
FFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000FFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000
00000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
0000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000
00000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
0000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.0177734 0.732558 0.127148 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(126) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
000000000000000000
FFFFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000
FFFF0000FFFF0000FF
FFFFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFF00000000FFFF
FFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFF0000FFFFFF
FFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000000000FFFFFFFF
FFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF00
00FFFF0000FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF
00000000FFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFF
FF0000FFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF000000000000
0000FFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF00
00FFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF00
00FFFF0000FF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
00000000FFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FF0000FFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
0000FFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00
00FFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFF0000FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.0177734 0.97619 0.127148 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.138086 0.245293 0.24746 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(108) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FF
FFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FFFF
FFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF
FFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF
000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000
00FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.138086 0.488926 0.24746 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(109) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000000000000000000000000000FF000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FF000000000000
000000000000000000
FFFFFF00FF00FF00FF00FF00FF00FF00FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFF000000FF000000FF000000FF0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FF000000FF
000000FF000000FFFF
FFFFFFFFFF00FF0000000000FF00FF000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FF00FF00
00000000FF00FFFFFF
FFFFFFFFFFFF00000000000000FF00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FF0000
0000000000FFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FF000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000FF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000FF00FF0000000000FF00FF0000000000
FF00FF0000000000FF00FF0000000000FF00FF0000000000FF00FF0000000000FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FF00000000000000FF000000000000
00FF00000000000000FF00000000000000FF00000000000000FF00000000000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF000000000000000000FF00FF00FF00
FF000000000000000000FF00FF00FF00FF000000000000000000FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000000000000000000000FF000000FF
0000000000000000000000FF000000FF0000000000000000000000FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000000000000000000000FF00FF00
000000000000000000000000FF00FF00000000000000000000000000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FF0000
00000000000000000000000000FF000000000000000000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF000000
0000000000000000000000000000FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF00000000
000000000000000000000000000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000FF00FF0000000000
00000000000000000000000000000000FF00FF0000000000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FF000000000000
0000000000000000000000000000000000FF00000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00000000000000
000000000000000000000000000000000000FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000000000000000
00000000000000000000000000000000000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000000000000000
0000000000000000000000000000000000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF
000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000
FF00FF0000000000FF00FF0000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
00FF00000000000000FF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF000000000000000000FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
0000000000000000000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
000000000000000000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF0000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.138086 0.732558 0.24746 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(110) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000
FFFFFF00FFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF
FFFFFFFF000000FF00FF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFF
FFFFFFFFFF00FFFFFF0000FF00FF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FFFFFF
FFFFFFFFFFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFFFFFF
FFFFFFFFFFFFFF00FFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FF00FF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF00000000FFFFFF0000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00000000FFFFFF0000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF00000000FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FFFFFF0000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00000000FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF0000
0000FFFFFF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF
00FF00000000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FF0000FF00FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000
0000FFFFFF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
00FF00000000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF0000FF00FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF00000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF00FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.138086 0.97619 0.24746 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(111) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000
FFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF
FFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FFFFFF
FFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FFFFFFFF
FFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF
000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF
000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF00
0000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000
00FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000
FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
0000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.258398 0.245293 0.367773 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(104) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000
00FF000000FF000000
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFF00FFFFFF00FF
FFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFF000000FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FF000000FFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF
000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFF000000FF0000
00FFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFF000000FF000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF0000
00FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000
00FFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.258398 0.488926 0.367773 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(105) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000FF0000FF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000FF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF
000000FF0000FF0000
FFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FF00FFFFFF00FF00FF
FFFFFFFF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
000000FF000000FFFF
FFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF00FFFFFF00FFFFFF
FFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00FF0000FFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00
FF00FFFFFF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFF000000FF000000FFFFFFFFFF
000000FF000000FF000000FFFFFFFFFF000000FF000000FFFFFFFFFF000000FF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF
FF00FFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FF0000FF00FF0000FFFFFFFFFFFFFF
FFFF0000FF00FF0000FFFFFFFFFFFFFFFFFF0000FF00FF0000FF0000FF00FF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF000000FF0000FF0000FF0000
FF0000FF000000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFF00
FF00FFFFFF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FFFFFFFFFF
000000FF000000FF000000FFFFFFFFFF000000FF000000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFF
FF00FFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFF
FFFF0000FF00FF0000FFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF00
00FF0000FF00FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00
FFFFFF00FF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF
FFFFFFFF000000FFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00
00FF0000FF00FF0000FF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000FF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.258398 0.732558 0.367773 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(106) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000000000FFFF00FFFFFF00FF0000FF0000FFFF00FFFF000000FFFF0000FFFFFF
00FF00FF000000FFFF000000FFFF00FFFF00000000FF00FFFF00FF000000FFFF00FF0000
FFFF00000000FF0000
FFFFFF00FFFF00FFFFFFFF00000000FF00FFFFFF00FF0000FF0000FFFF000000FFFFFFFF
FF0000FF00FFFF000000FFFF000000FF0000FFFF00FF00FF0000FF00FFFF000000FF00FF
FFFFFF00FFFF0000FF
FFFFFFFF000000FF00000000FFFF00FF00FF000000FF00FFFFFF00FF0000FFFF00000000
0000FFFFFF000000FFFF000000FFFF0000FFFFFFFF0000FF00FFFFFF000000FFFF0000FF
00000000FF0000FFFF
FFFFFFFFFF00FFFFFF00FFFF000000FF00FF00FFFF0000FF000000FF00FFFFFFFF00FFFF
00FFFFFFFFFF00FFFFFFFF00FFFFFFFF00FF00000000FFFFFF00000000FFFF000000FFFF
FF00FFFF0000FFFFFF
FFFFFFFFFFFF00000000FF0000FFFF0000FF00FF0000FFFFFF00FFFFFF0000000000FF00
00FF0000000000FF00000000FF00000000FF00FFFF00FF000000FFFF00FF0000FFFF0000
0000FF0000FFFFFFFF
FFFFFFFFFFFFFF00FFFF0000FFFFFFFF00FF00FF00FFFFFFFFFF00000000FFFF00FFFFFF
00FF00FFFF00FFFFFF00FFFF0000FFFF00FF00FF0000FF00FFFF000000FF00FFFFFFFF00
FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFF0000FF00FF0000000000FFFF00FF0000FF0000
00FF00FF0000FF000000FF0000FFFFFFFF0000FF00FFFFFF000000FFFF0000FF00000000
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FF00FF00FFFF00FFFFFFFF0000FFFFFF00
FFFFFF0000FFFFFF00FFFFFF00FF00000000FFFFFF00000000FFFF000000FFFFFF00FFFF
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000FF00FF00FF0000FF00000000FFFFFFFFFF
00000000FFFFFFFFFF00000000FF00FFFF00FF000000FFFF00FF0000FFFF00000000FF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFF0000FF00FFFFFF00FFFF0000000000
00FFFF00FF0000000000FFFF00FF00FF0000FF00FFFF000000FF00FFFFFFFF00FFFF0000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FF000000FFFFFF00000000FF0000FFFF00FF
FF000000FF00FFFF00FFFFFFFF0000FF00FFFFFF000000FFFF0000FF00000000FF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFF00000000FFFF00FF00FFFFFFFF00
0000FFFF0000FF0000FF00000000FFFFFF00000000FFFF000000FFFFFF00FFFF0000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00FF0000FFFF00FF0000FF00FF00000000
FFFF000000FFFFFF00FF00FFFF00FF000000FFFF00FF0000FFFF00000000FF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FF00FFFFFFFF0000FFFFFF0000FFFF00
FF0000FFFF00000000FF00FF0000FF00FFFF000000FF00FFFFFFFF00FFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF0000000000FFFFFFFFFF00FF0000
FF00FFFFFFFF00FFFF0000FF00FFFFFF000000FFFF0000FF00000000FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFF00FF0000000000FF00FF
FFFF0000000000FF0000FFFFFF00000000FFFF000000FFFFFF00FFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF0000FF00FFFF00FFFFFF00
000000FFFF00FFFFFF00FF000000FFFF00FF0000FFFF00000000FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF00FF00FF0000FF000000
FFFF00FF0000FF000000FF00FFFF000000FF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF00FF00FFFFFF00FF
FFFFFF0000FFFFFF00FFFFFF000000FFFF0000FF00000000FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF0000FF000000FF
00000000FFFFFFFFFF00000000FFFF000000FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF000000FFFFFF00FFFF
FF00FFFF000000000000FFFF00FF0000FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFF00000000FF00
0000FF0000FFFF00FFFF000000FF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF00FFFF0000
FFFF0000FFFFFFFF000000FFFF0000FF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF000000FF
FFFFFF00FF00000000FFFF000000FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFF00
00000000FF00FFFF00FF0000FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF000000
FFFF00FFFFFF000000FF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FFFF
000000FF000000FFFF0000FF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00
00FFFF0000FFFF000000FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00
FFFFFFFF00FF0000FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000
FF00000000FF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFF00FFFF0000FF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFF000000FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.258398 0.97619 0.367773 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -11 0 ]
[.5 .50633 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(107) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF000000
FFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF
FFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF000000FFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FFFFFF
FFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF000000FFFFFFFF
FFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000
FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF00
0000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000
FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
0000FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
0000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFF0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.37871 0.245293 0.488085 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(61) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF000000FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FF000000FF000000FF000000FF000000FF0000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF000000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.37871 0.488926 0.488085 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(62) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFF00FF0000FF0000000000FF00FFFF0000FFFF0000
00000000FF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFFFFFFFF000000FFFF00FF0000FFFF00000000FFFFFF0000
FF0000FFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFF0000FFFFFF000000FFFFFF0000FF0000000000FF
FF00FFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00000000000000000000FFFFFFFF00FF0000000000FFFF00FF0000FFFF
FF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FF0000FF0000FFFFFFFFFF000000FF0000FFFFFF000000FFFFFF
FF00FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF000000FFFF00FFFFFFFFFFFF0000FFFF00FFFFFFFF0000FFFFFFFF
FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF0000FFFFFF0000000000000000FFFFFF000000000000FFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFF00FF0000FF00FF0000000000FF0000FF000000000000
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFFFF000000FFFF000000FF0000FFFF00FFFF0000FF00FF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFF0000FFFFFF00FF000000FFFFFF00000000FFFF000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000000000000000FFFFFFFF000000FF0000000000FF00FFFFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FF0000FF000000000000FF000000FF0000FFFF0000000000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF000000FFFF00FF0000FF000000FF000000FFFFFF00FF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF0000FFFFFF000000FFFF0000FFFF0000FFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFF00FF00000000FFFFFF00FFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFFFF000000FF00FFFFFFFF00000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFF0000FFFF000000000000FF00FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000000000000000FFFFFF0000FF0000FFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF0000FF00FF0000000000FFFF00FFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF00FFFF000000FF0000FFFFFF0000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00000000FF000000FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FF00FFFF0000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFF00000000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFF0000FF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000000000FFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FF00000000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF000000FF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF0000FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.37871 0.732558 0.488085 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(72) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFF00FFFFFF00FF
FFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFF00FF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.37871 0.97619 0.488085 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(76) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00
FFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
FFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.499022 0.245293 0.608397 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(56) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.499022 0.488926 0.608397 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(58) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF00FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF00FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.499022 0.732558 0.608397 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(59) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
0000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
0000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.499022 0.97619 0.608397 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.619335 0.245293 0.72871 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -5 0 ]
[.5 .50633 5 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.267442 0.619335 0.488926 0.72871 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(32) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.511074 0.619335 0.732558 0.72871 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.754707 0.619335 0.97619 0.72871 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0118708 0.00949668 0.0118708 [
[.5 .50633 -8 0 ]
[.5 .50633 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .49383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50633 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(42) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49383 L
0 .49383 L
closepath
clip
newpath
% Start of gray image
p
.01923 .0095 translate
.96154 .47483 scale
81 string
81 40 8 [81 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{501.688, 374.5},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007e0001MR000`400?l00000o`00003oo`3AcJWf
0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf
0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf
0=7=Z@006`3AcJT20?ooo`<000000240oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool00P0000009@3oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool00`00000Z0=7=Z@80ooooCP00000Z0=7=Z@80oooo4000000^0?oooa000000UP3A
cJT001/0dLfY0`3oool20000000Q0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0080000002D0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0080000000<0oooo0=7=Z@3AcJT0:03AcJT30?oood`0000000<0oooo0=7=Z@3AcJT0
:03AcJT30?ooo`8000000P3oool200000080oooo0P0000020?ooo`800000<03oool200000080oooo
0P0000020?ooo`8000000P3oool2000000030?ooo`3AcJT0dLfY09@0dLfY000K0=7=Z@@0oooo0`00
00007`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool00P0000008`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00<000000P3ooolZ0=7=Z@@0ooooBP00
00020?ooobX0dLfY103oool4000000@0oooo1000000b0?ooo`@00000103oool400000080ooooUP3A
cJT001/0dLfY1@3oool20000000O0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`020000000S0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00P000003
0?ooobX0dLfY1@3ooom8000000<0oooo:P3AcJT50?ooo`8000001P3oool2000003@0oooo0P000006
0?ooo`8000000`3ooonF0=7=Z@006`3AcJT60?ooo`<0000001d0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`020000000Q0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00<00000
103ooolZ0=7=Z@H0ooooAP0000040?ooobX0dLfY1P3oool8000003H0oooo200000040?oooiH0dLfY
000K0=7=Z@L0oooo0P0000007@3oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo008000000240oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool00P0000050?ooobX0dLfY1`3ooom40000
00D0oooo:P3AcJT70?ooo`8000000P3oool2000003P0oooo0P0000020?ooo`8000001@3ooonF0=7=
Z@006`3AcJT80?ooo`<0000001/0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool00P0000007`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool00`0000060?ooobX0dLfY203ooom2000000H0oooo:P3AcJT80?oo
o`@00000>P3oool4000000H0ooooUP3AcJT001/0dLfY2@3oool20000000K0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0080000001l0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo008000001`3ooolZ0=7=
Z@T0oooo@00000070?ooobX0dLfY2@3oool2000003`0oooo0P0000070?oooiH0dLfY000K0=7=Z@X0
oooo0`0000006@3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00P0000007@3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00<00000
203ooolZ0=7=Z@X0oooo?P0000080?ooobX0dLfY2P3oooln000000P0ooooUP3AcJT001/0dLfY2`3o
ool20000000I0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`020000000M0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00P000009
0?ooobX0dLfY2`3oooll000000T0oooo:P3AcJT;0?ooo`8000000P3oool200000080oooo0P000002
0?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool010000000oooo00000000
00020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P00
00020?ooo`8000002@3ooonF0=7=Z@006`3AcJT<0?ooo`<0000001L0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`020000000K0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo00<000002P3ooolZ0=7=Z@`0oooo>P00000:0?ooobX0dLfY303oool4000000@0oooo
100000040?ooo`@00000103oool3000000<0oooo100000040?ooo`@00000103oool4000000@0oooo
1000000:0?oooiH0dLfY000K0=7=Z@d0oooo0P0000005`3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0080000001/0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool00P00000;0?ooobX0dLfY3@3ooolh000000/0oooo:P3AcJT=0?ooo`8000001P3oool2000000H0
oooo0P0000060?ooo`800000103oool2000000H0oooo0P0000060?ooo`8000001P3oool2000000/0
ooooUP3AcJT001/0dLfY3P3oool30000000E0?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000001T0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo00<00000303ooolZ0=7=Z@h0oooo
=P00000<0?ooobX0dLfY3P3oool8000000P0oooo200000060?ooo`P00000203oool8000000`0oooo
UP3AcJT001/0dLfY3`3oool20000000E0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000001T0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo008000003@3ooolZ0=7=Z@l0oooo=000
000=0?ooobX0dLfY3`3oool200000080oooo0P00000:0?ooo`8000000P3oool2000000P0oooo0P00
00020?ooo`8000002P3oool200000080oooo0P00000=0?oooiH0dLfY000K0=7=ZA00oooo0`000000
4`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool00P0000005`3oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00<0
00003P3ooolZ0=7=ZA00oooo<P00000>0?ooobX0dLfY403oool4000000`0oooo1000000:0?ooo`@0
0000303oool4000000h0ooooUP3AcJT001/0dLfY4@3oool20000000C0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`02
0000000G0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool00P00000?0?ooobX0dLfY4@3oool`
000000l0oooo:P3AcJTA0?ooo`8000003P3oool2000000`0oooo0P00000>0?ooo`8000003`3ooonF
0=7=Z@006`3AcJTB0?ooo`<000000140oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`020000000E0?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo00<00000403ooolZ0=7=ZA80oooo;P00000@0?ooobX0dLfY4P3oool@000000h0oooo4000000@
0?oooiH0dLfY000K0=7=ZA<0oooo0P0000004@3oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000001D0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool00P00000A0?ooobX0dLfY4`3oool/00000140oooo:P3AcJTC0?ooo`8000000P3oool2
00000080oooo0P0000020?ooo`800000403oool200000080oooo0P0000020?ooo`8000000P3oool2
00000140ooooUP3AcJT001/0dLfY503oool30000000?0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0080000001<0oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00<0
00004P3ooolZ0=7=ZA@0oooo:P00000B0?ooobX0dLfY503oool4000000@0oooo1000000B0?ooo`@0
0000103oool400000180ooooUP3AcJT001/0dLfY5@3oool20000000?0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000001<0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo008000004`3ooolZ0=7=ZAD0oooo:000000C0?ooobX0dLfY5@3oool2000000H0oooo0P00
000D0?ooo`8000001P3oool2000001<0ooooUP3AcJT001/0dLfY5`3oool20000000=0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`020000000A0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
0P00000E0?ooobX0dLfY5`3ooolT000001D0oooo:P3AcJTG0?ooo`8000000P3oool2000001P0oooo
0P0000020?ooo`8000005@3ooonF0=7=Z@006`3AcJTH0?ooo`<0000000/0oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`020000000?0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00<000005P3ooolZ0=7=ZAP0oooo8P00
000F0?ooobX0dLfY603oool4000001X0oooo1000000F0?oooiH0dLfY000K0=7=ZAT0oooo0P000000
2`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000l0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00P00000G
0?ooobX0dLfY6@3ooolP000001L0oooo:P3AcJTI0?ooo`800000703oool2000001L0ooooUP3AcJT0
01/0dLfY6P3oool3000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo00800000
00d0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00<00000
603ooolZ0=7=ZAX0oooo7P00000H0?ooobX0dLfY6P3ooolN000001P0ooooUP3AcJT001/0dLfY6`3o
ool2000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000d0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo008000006@3ooolZ0=7=
ZA/0oooo7000000I0?ooobX0dLfY6`3oool200000080oooo0P0000020?ooo`8000000P3oool01000
0000oooo0000000000020?ooo`8000000P3oool200000080oooo0P00000I0?oooiH0dLfY000K0=7=
ZA`0oooo0`0000001`3oool000000?ooo`000000oooo0000003oool00P0000002`3oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo00<000006P3ooolZ0=7=ZA`0oooo6P00000J
0?ooobX0dLfY703oool4000000@0oooo0`0000030?ooo`@00000103oool4000001X0ooooUP3AcJT0
01/0dLfY7@3oool2000000070?ooo`000000oooo0000003oool000000?ooo`020000000;0?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool00P00000K0?ooobX0dLfY7@3ooolH
000001/0oooo:P3AcJTM0?ooo`8000001P3oool2000000@0oooo0P0000060?ooo`8000006`3ooonF
0=7=Z@006`3AcJTN0?ooo`<0000000D0oooo0000003oool000000?ooo`02000000090?ooo`000000
oooo0000003oool000000?ooo`000000oooo00<00000703ooolZ0=7=ZAh0oooo5P00000L0?ooobX0
dLfY7P3oool8000000H0oooo2000000L0?oooiH0dLfY000K0=7=ZAl0oooo0P0000001@3oool00000
0?ooo`000000oooo0080000000T0oooo0000003oool000000?ooo`000000oooo0000003oool00P00
000M0?ooobX0dLfY7`3ooolD000001d0oooo:P3AcJTO0?ooo`8000000P3oool2000000P0oooo0P00
00020?ooo`8000007@3ooonF0=7=Z@006`3AcJTP0?ooo`<0000000<0oooo0000003oool00P000000
1`3oool000000?ooo`000000oooo0000003oool00`00000N0?ooobX0dLfY803ooolB000001h0oooo
:P3AcJTP0?ooo`@000002P3oool4000001h0ooooUP3AcJT001/0dLfY8@3oool2000000030?ooo`00
0000oooo0080000000L0oooo0000003oool000000?ooo`000000oooo008000007`3ooolZ0=7=ZB40
oooo4000000O0?ooobX0dLfY8@3oool2000000`0oooo0P00000O0?oooiH0dLfY000K0=7=ZB80oooo
0`000000203oool000000000003oool000000?ooo`000000oooo0`00000P0?ooobX0dLfY8P3oool>
00000200oooo:P3AcJTR0?ooo`h00000803ooonF0=7=Z@006`3AcJTS0?ooo`80000000P0oooo0000
00000000oooo0000003oool000000?ooo`8000008@3ooolZ0=7=ZB<0oooo3000000Q0?ooobX0dLfY
8`3oool200000080oooo00@000000?ooo`00000000000P3oool200000240ooooUP3AcJT001/0dLfY
903oool4000000030?ooo`000000oooo00<000008P3ooolZ0=7=ZB@0oooo2P00000R0?ooobX0dLfY
903oool3000000<0oooo1000000R0?oooiH0dLfY000K0=7=ZBD0oooo0`0000000`3oool000000?oo
o`02000002<0oooo:P3AcJTU0?ooo`P000008`3ooolZ0=7=ZBD0oooo0P0000040?ooo`8000008`3o
oonF0=7=Z@006`3AcJTV0?ooo`80000000@0oooo0000000000000000903ooolZ0=7=ZBH0oooo1P00
000T0?ooobX0dLfY9P3oool6000002@0ooooUP3AcJT001/0dLfY9`3oool010000000oooo00000000
000U0?ooobX0dLfY9`3oool4000002D0oooo:P3AcJTW0?ooo`040000003oool00000000002D0oooo
UP3AcJT001/0dLfY9`3oool3000002H0oooo:P3AcJTW0?ooo`<000009P3ooolZ0=7=ZBL0oooo0`00
000V0?oooiH0dLfY000K0=7=ZBP0oooo00<000000?ooo`3oool09@3ooolZ0=7=ZBP0oooo00<00000
0?ooo`3oool09@3ooolZ0=7=ZBP0oooo00<000000?ooo`3oool09@3ooonF0=7=Z@00o`3AcJWf0=7=
Z@00o`3AcJWf0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf0=7=
Z@00>`3AcJT5@00000030=7=ZD0000100000009000000P3AcJT4@00006X0dLfY1D0000000`3AcJU0
0000@0000002@00000<0dLfY0T00001[0=7=Z@E0000000<0dLfY@000040000000T0000020=7=Z@=0
0000]`3AcJT003d0dLfY00E000000=7=Z@3AcJT0dLfY@00000050=7=Z@03@000003AcJT0dLfY06d0
dLfY00E000000=7=Z@3AcJT0dLfY@00000050=7=Z@04@000003AcJT0dLfY@00006`0dLfY00E00000
0=7=Z@3AcJT0dLfY@00000050=7=Z@04@000003AcJT0dLfY@0000;H0dLfY000m0=7=Z@03@000003A
cJT0dLfY0080dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@1/0=7=Z@03@000003A
cJT0dLfY0080dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@1[0=7=Z@03@000003A
cJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD00002f0=7=Z@00?@3A
cJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0J`3A
cJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT0JP3A
cJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY0=7=Z@=00000]`3AcJT003d0dLfY00E0
00000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3A
cJT0JP3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT0
0d000000dLfY0=7=Z@1Z0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT01D000000dLfY0=7=
Z@3AcJU000000;P0dLfY000l0=7=Z@900000103AcJT2@00000@0dLfY0T00001/0=7=Z@900000103A
cJT2@00000@0dLfY0T00001/0=7=Z@900000103AcJT2@00000@0dLfY0d00002f0=7=Z@00o`3AcJWf
0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf
0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf0=7=Z@006`3AcJT20?ooo`<0000000D0
oooo00000000000000000?ooo`03000000050?ooo`00000000000000003oool00`0000001@3oool0
0000000000000000oooo00<0000000D0oooo00000000000000000?ooo`03000000040?ooo`000000
00000?ooo`<0000000D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000003o
ool00`0000001@3oool00000000000000000oooo00<0000000D0oooo00000000000000000?ooo`03
000000040?ooo`0000000000000002X0dLfY0P3oool?000000030?ooo`000000000002`0000000<0
oooo0000000000003@00000Z0=7=Z@80oooo100000030?ooo`80000000<0oooo0000003oool01000
00030?ooo`80000000<0oooo0000003oool0100000030?ooo`80000000<0oooo0000003oool00`00
0000103oool000000000003oool2000000040?ooo`00000000000?ooo`80000000@0oooo00000000
0000oooo0P000000103oool000000000003oool2000000040?ooo`00000000000?ooo`80000000@0
oooo000000000000oooo0P0000000`3oool000000000000Z0=7=Z@80oooo0`0000001@3oool00000
000000000000oooo00<0000000D0oooo00000000000000000?ooo`02000000050?ooo`0000000000
0000003oool00`0000001@3oool00000000000000000oooo00<0000000D0oooo0000000000000000
0?ooo`03000000050?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo
0080000000D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000003oool00`00
0000103oool0000000000000000M0=7=Z@006`3AcJT30?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01P000000oooo0?ooo`3oool0
00000?ooobX0dLfY0`3oool03P000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo<00000003`3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0Z0=7=Z@<0oooo00<000000?ooo`3oool0100000030?ooo`80
000000<0oooo0000003oool0100000030?ooo`80000000<0oooo0000003oool0100000030?ooo`<0
000000@0oooo000000000000oooo0P000000103oool000000000003oool2000000040?ooo`000000
00000?ooo`80000000@0oooo000000000000oooo0P000000103oool000000000003oool200000004
0?ooo`00000000000?ooo`80000000@0oooo000000000000oooo:P3AcJT30?ooo`030000003oool0
00000080000000D0oooo00000000000000000?ooo`03000000040?ooo`00000000000?ooo`<00000
00D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000003oool00`0000001@3o
ool00000000000000000oooo00<0000000D0oooo00000000000000000?ooo`03000000040?ooo`00
000000000?ooo`<0000000D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000
003oool00`0000000`3oool0dLfY0=7=Z@0K0=7=Z@006`3AcJT40?ooo`<0000000D0oooo00000000
000000000?ooo`03000000050?ooo`00000000000000003oool00`0000001@3oool0000000000000
0000oooo00<0000000D0oooo00000000000000000?ooo`06000000050?ooo`00000000000000003o
ool00`0000001@3oool00000000000000000oooo00<0000000D0oooo00000000000000000?ooo`03
000000050?ooo`00000000000000003oool00`000000103oool000000000000000020?ooobX0dLfY
103oool3000000050?ooo`00000000000000003oool00`0000000`3oool000000000000`00000005
0?ooo`00000000000000003oool00`000000103oool000000000000000020?ooobX0dLfY103oool3
000000030?ooo`000000oooo00@000000`3oool2000000030?ooo`000000oooo00@000000`3oool2
000000030?ooo`000000oooo00@000000P3oool2000000040?ooo`00000000000?ooo`80000000@0
oooo000000000000oooo0P000000103oool000000000003oool2000000040?ooo`00000000000?oo
o`80000000@0oooo000000000000oooo0P000000103oool000000000003oool200000080oooo:P3A
cJT40?ooo`<0000000D0oooo00000000000000000?ooo`03000000030?ooo`000000000000@00000
00D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000003oool00`0000001@3o
ool00000000000000000oooo00<0000000D0oooo00000000000000000?ooo`03000000030?ooo`00
0000000000@0000000D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000003o
ool00`0000020?oooad0dLfY000K0=7=Z@D0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo0?ooobX0dLfY
1@3oool00`000000oooo00000004000000030?ooo`000000oooo03@0000000<0oooo0000003oool0
1@0000000`3oool000000?ooo`020?ooobX0dLfY1@3oool010000000oooo0?ooo`3oool200000003
0?ooo`000000oooo00@000000`3oool2000000030?ooo`000000oooo00@000000`3oool200000003
0?ooo`000000oooo00<0000000@0oooo000000000000oooo0P000000103oool000000000003oool2
000000040?ooo`00000000000?ooo`80000000@0oooo000000000000oooo0P000000103oool00000
0000003oool2000000040?ooo`00000000000?ooo`8000000`3ooolZ0=7=Z@D0oooo00<000000?oo
o`0000000P0000001@3oool00000000000000000oooo00<0000000@0oooo000000000000oooo0`00
00001@3oool00000000000000000oooo00<0000000D0oooo00000000000000000?ooo`0300000005
0?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo00<0000000@0oooo
000000000000oooo0`0000001@3oool00000000000000000oooo00<0000000@0oooo000000000000
00000`3ooolM0=7=Z@006`3AcJT60?ooo`<0000000D0oooo00000000000000000?ooo`0300000005
0?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo00<0000000D0oooo
00000000000000000?ooo`02000000050?ooo`00000000000000003oool00`0000001@3oool00000
000000000000oooo00<0000000D0oooo00000000000000000?ooo`03000000050?ooo`0000000000
0000003oool00`000000103oool000000000000000040?ooobX0dLfY1P3oool7000000030?ooo`00
0000000003@0000000<0oooo0000000000001@0000040?ooobX0dLfY1P3oool4000000<0oooo0P00
00000`3oool000000?ooo`04000000<0oooo0P0000000`3oool000000?ooo`04000000<0oooo0`00
0000103oool000000000003oool2000000040?ooo`00000000000?ooo`80000000@0oooo00000000
0000oooo0P000000103oool000000000003oool2000000040?ooo`00000000000?ooo`80000000@0
oooo000000000000oooo0P0000040?ooobX0dLfY1P3oool3000000050?ooo`00000000000000003o
ool00`000000103oool000000000003oool3000000050?ooo`00000000000000003oool00`000000
1@3oool00000000000000000oooo00<0000000D0oooo00000000000000000?ooo`03000000050?oo
o`00000000000000003oool00`000000103oool000000000003oool3000000050?ooo`0000000000
0000003oool00`000000103oool000000000000000040?oooad0dLfY000K0=7=Z@L0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooobX0
dLfY1`3oool01P000000oooo0000003oool000000?ooocP0000000H0oooo0000003oool000000?oo
o`0000050?ooobX0dLfY1`3oool00`000000oooo0?ooo`04000000<0oooo0P0000000`3oool00000
0?ooo`04000000<0oooo0P0000000`3oool000000?ooo`0400000080oooo0P000000103oool00000
0000003oool2000000040?ooo`00000000000?ooo`80000000@0oooo000000000000oooo0P000000
103oool000000000003oool2000000040?ooo`00000000000?ooo`80000000<0oooo000000000000
1@3ooolZ0=7=Z@L0oooo00<000000?ooo`0000000P0000001@3oool00000000000000000oooo0080
000000D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000003oool00`000000
1@3oool00000000000000000oooo00<0000000D0oooo00000000000000000?ooo`03000000050?oo
o`00000000000000003oool00P0000001@3oool00000000000000000oooo00<0000000D0oooo0000
0000000000000?ooo`03000000D0oooo7@3AcJT001/0dLfY203oool3000000050?ooo`0000000000
0000003oool00`0000001@3oool00000000000000000oooo00<0000000D0oooo0000000000000000
0?ooo`03000000030?ooo`000000000000@0000000D0oooo00000000000000000?ooo`0300000005
0?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo00<0000000D0oooo
00000000000000000?ooo`03000000H0oooo:P3AcJT80?ooo`<0000000<0oooo000000000000>000
0000103oool000000000000000060?ooobX0dLfY203oool3000000030?ooo`000000oooo00@00000
0`3oool2000000030?ooo`000000oooo00@000000`3oool2000000030?ooo`000000oooo00<00000
00@0oooo000000000000oooo0P000000103oool000000000003oool2000000040?ooo`0000000000
0?ooo`80000000@0oooo000000000000oooo0P000000103oool000000000003oool2000000030?oo
o`000000000000H0oooo:P3AcJT80?ooo`<0000000D0oooo00000000000000000?ooo`0600000005
0?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo00<0000000D0oooo
00000000000000000?ooo`03000000050?ooo`00000000000000003oool00`0000000`3oool00000
00000004000000050?ooo`00000000000000003oool00`000000103oool000000000000000060?oo
oad0dLfY000K0=7=Z@T0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`050?ooobX0dLfY2@3oool00`000000oooo0000000k000000030?ooo`00
0000oooo00H0oooo:P3AcJT90?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool0
100000030?ooo`80000000<0oooo0000003oool0100000030?ooo`<0000000@0oooo000000000000
oooo0P000000103oool000000000003oool2000000040?ooo`00000000000?ooo`80000000@0oooo
000000000000oooo0P000000103oool000000000003oool2000000030?ooo`000000000000L0oooo
:P3AcJT90?ooo`030000003oool000000080000000D0oooo00000000000000000?ooo`0200000005
0?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo00<0000000D0oooo
00000000000000000?ooo`03000000050?ooo`00000000000000003oool00`0000001@3oool00000
000000000000oooo0080000000D0oooo00000000000000000?ooo`03000000040?ooo`0000000000
000000L0oooo7@3AcJT001/0dLfY2P3oool3000000050?ooo`00000000000000003oool00`000000
1@3oool00000000000000000oooo00<0000000D0oooo00000000000000000?ooo`03000000040?oo
o`00000000000?ooo`<0000000D0oooo00000000000000000?ooo`03000000050?ooo`0000000000
0000003oool00`0000001@3oool00000000000000000oooo00<0000000@0oooo0000000000000000
203ooolZ0=7=Z@X0oooo?P0000080?ooobX0dLfY2P3oool4000000<0oooo0P0000000`3oool00000
0?ooo`04000000<0oooo0P0000000`3oool000000?ooo`0400000080oooo0P000000103oool00000
0000003oool2000000040?ooo`00000000000?ooo`80000000@0oooo000000000000oooo0P000000
103oool000000000003oool2000000040?ooo`00000000000?ooo`800000203ooolZ0=7=Z@X0oooo
0`0000001@3oool00000000000000000oooo0080000000D0oooo00000000000000000?ooo`030000
00050?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo00<0000000D0
oooo00000000000000000?ooo`03000000050?ooo`00000000000000003oool00P0000001@3oool0
0000000000000000oooo00<0000000@0oooo0000000000000000203ooolM0=7=Z@006`3AcJT;0?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000090?ooobX0dLfY2`3oool06`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0O0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000090?ooobX0dLfY
2`3oool00`000000oooo0?ooo`04000000<0oooo0P0000000`3oool000000?ooo`04000000<0oooo
0P0000000`3oool000000?ooo`03000000040?ooo`00000000000?ooo`80000000@0oooo00000000
0000oooo0P000000103oool000000000003oool2000000040?ooo`00000000000?ooo`80000000@0
oooo000000000000oooo0P0000090?ooobX0dLfY2`3oool00`000000oooo00000002000000040?oo
o`00000000000?ooo`<0000000D0oooo00000000000000000?ooo`03000000050?ooo`0000000000
0000003oool00`0000001@3oool00000000000000000oooo00<0000000D0oooo0000000000000000
0?ooo`03000000040?ooo`00000000000?ooo`<0000000D0oooo00000000000000000?ooo`030000
00T0oooo7@3AcJT001/0dLfY303oool3000000050?ooo`00000000000000003oool00`0000001@3o
ool00000000000000000oooo00<0000000D0oooo00000000000000000?ooo`06000000050?ooo`00
000000000000003oool00`0000001@3oool00000000000000000oooo00<0000000D0oooo00000000
000000000?ooo`03000000040?ooo`0000000000000000X0oooo:P3AcJT<0?ooo`<0000000D0oooo
00000000000000000?ooo`03000000050?ooo`00000000000000003oool00`0000001@3oool00000
000000000000oooo00H0000000D0oooo00000000000000000?ooo`03000000050?ooo`0000000000
0000003oool00`0000001@3oool00000000000000000oooo00<0000000@0oooo0000000000000000
2P3ooolZ0=7=Z@`0oooo0`0000000`3oool000000?ooo`04000000<0oooo0P0000000`3oool00000
0?ooo`04000000<0oooo0`000000103oool000000000003oool2000000040?ooo`00000000000?oo
o`80000000@0oooo000000000000oooo0P000000103oool000000000003oool2000000040?ooo`00
000000000?ooo`8000002P3ooolZ0=7=Z@`0oooo0`0000000`3oool0000000000004000000050?oo
o`00000000000000003oool00`0000001@3oool00000000000000000oooo00<0000000D0oooo0000
0000000000000?ooo`03000000050?ooo`00000000000000003oool00`0000000`3oool000000000
0004000000050?ooo`00000000000000003oool00`00000:0?oooad0dLfY000K0=7=Z@d0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`090?ooobX0dLfY3@3oool00`000000oooo0000000400000003
0?ooo`000000oooo00D0000000<0oooo0000003oool01@0000000`3oool000000?ooo`0400000003
0?ooo`000000oooo00D0000000<0oooo0000003oool01@0000000`3oool000000?ooo`0500000003
0?ooo`000000oooo00X0oooo:P3AcJT=0?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000
003oool0100000030?ooo`80000000<0oooo0000003oool0100000020?ooo`80000000@0oooo0000
00000000oooo0P000000103oool000000000003oool2000000040?ooo`00000000000?ooo`800000
00@0oooo000000000000oooo0P0000000`3oool000000000000;0?ooobX0dLfY3@3oool00`000000
oooo00000002000000040?ooo`00000000000?ooo`<0000000D0oooo00000000000000000?ooo`03
000000050?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo00<00000
00D0oooo00000000000000000?ooo`03000000040?ooo`00000000000?ooo`<0000000@0oooo0000
0000000000002`3ooolM0=7=Z@006`3AcJT>0?ooo`<0000000D0oooo00000000000000000?ooo`03
000000050?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo00800000
00D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000003oool00`0000001@3o
ool00000000000000000oooo00<0000000@0oooo0000000000000000303ooolZ0=7=Z@h0oooo1`00
00000`3oool0000000000005000000030?ooo`000000000000D0000000<0oooo0000000000001000
00000`3oool0000000000005000000030?ooo`000000000000D0000000<0oooo0000000000001@00
000<0?ooobX0dLfY3P3oool4000000<0oooo0P0000000`3oool000000?ooo`04000000<0oooo0P00
00000`3oool000000?ooo`03000000040?ooo`00000000000?ooo`80000000@0oooo000000000000
oooo0P000000103oool000000000003oool2000000040?ooo`00000000000?ooo`80000000<0oooo
000000000000303ooolZ0=7=Z@h0oooo0`000000103oool000000000003oool3000000050?ooo`00
000000000000003oool00`0000001@3oool00000000000000000oooo00<0000000D0oooo00000000
000000000?ooo`03000000050?ooo`00000000000000003oool00`000000103oool000000000003o
ool3000000040?ooo`0000000000000000`0oooo7@3AcJT001/0dLfY3`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000001P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0;0?ooobX0dLfY
3`3oool01P000000oooo0000003oool000000?ooo`T0000000L0oooo0000003oool000000?ooo`00
0000oooo00P0000000L0oooo0000003oool000000?ooo`000000oooo00T0000000H0oooo0000003o
ool000000?ooo`00000=0?ooobX0dLfY3`3oool00`000000oooo0?ooo`04000000<0oooo0P000000
0`3oool000000?ooo`04000000<0oooo0`000000103oool000000000003oool2000000040?ooo`00
000000000?ooo`80000000@0oooo000000000000oooo0P000000103oool000000000003oool20000
00030?ooo`000000000000d0oooo:P3AcJT?0?ooo`050000003oool000000000003oool00`000000
1@3oool00000000000000000oooo00<0000000D0oooo00000000000000000?ooo`03000000050?oo
o`00000000000000003oool00`0000001@3oool00000000000000000oooo00<0000000@0oooo0000
00000000oooo0`000000103oool0000000000000000=0?oooad0dLfY000K0=7=ZA00oooo0`000000
1@3oool00000000000000000oooo00<0000000D0oooo00000000000000000?ooo`03000000030?oo
o`000000000000@0000000D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000
003oool00`0000001@3oool00000000000000000oooo00<000003P3ooolZ0=7=ZA00oooo0`000000
0`3oool0000000000009000000050?ooo`00000000000000003oool02P0000001@3oool000000000
00000000oooo00/0000000@0oooo00000000000000003P3ooolZ0=7=ZA00oooo0`0000000`3oool0
00000?ooo`04000000<0oooo0P0000000`3oool000000?ooo`0400000080oooo0P000000103oool0
00000000003oool2000000040?ooo`00000000000?ooo`80000000@0oooo000000000000oooo0P00
0000103oool000000000003oool2000000h0oooo:P3AcJT@0?ooo`H0000000D0oooo000000000000
00000?ooo`03000000050?ooo`00000000000000003oool00`0000001@3oool00000000000000000
oooo00<0000000D0oooo00000000000000000?ooo`03000000030?ooo`000000000000@0000000@0
oooo00000000000000003P3ooolM0=7=Z@006`3AcJTA0?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00d0oooo:P3AcJTA0?ooo`030000
003oool0000000`0000000<0oooo0000003oool0300000000`3oool000000?ooo`0=000000030?oo
o`000000oooo00h0oooo:P3AcJTA0?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003o
ool0100000030?ooo`80000000<0oooo0000003oool00`000000103oool000000000003oool20000
00040?ooo`00000000000?ooo`80000000@0oooo000000000000oooo0P000000103oool000000000
003oool2000000l0oooo:P3AcJTA0?ooo`050000003oool000000000003oool00`0000001@3oool0
0000000000000000oooo00<0000000D0oooo00000000000000000?ooo`03000000050?ooo`000000
00000000003oool00`0000001@3oool00000000000000000oooo00<0000000@0oooo000000000000
oooo0`00000?0?oooad0dLfY000K0=7=ZA80oooo0`0000001@3oool00000000000000000oooo00<0
000000D0oooo00000000000000000?ooo`03000000040?ooo`00000000000?ooo`<0000000D0oooo
00000000000000000?ooo`03000000050?ooo`00000000000000003oool00`000000103oool00000
00000000000@0?ooobX0dLfY4P3oool?000000030?ooo`000000000000`0000000<0oooo00000000
00003@00000@0?ooobX0dLfY4P3oool4000000<0oooo0P0000000`3oool000000?ooo`04000000<0
oooo0`000000103oool000000000003oool2000000040?ooo`00000000000?ooo`80000000@0oooo
000000000000oooo0P000000103oool000000000003oool200000100oooo:P3AcJTB0?ooo`800000
00D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000003oool00`0000001@3o
ool00000000000000000oooo00<0000000D0oooo00000000000000000?ooo`03000000050?ooo`00
000000000000003oool00P000000103oool0000000000000000@0?oooad0dLfY000K0=7=ZA<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`3oool0oooo0000000A0?ooobX0dLfY4`3oool03P000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo400000003P3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000004@3ooolZ0=7=
ZA<0oooo00<000000?ooo`3oool0100000030?ooo`80000000<0oooo0000003oool0100000020?oo
o`80000000@0oooo000000000000oooo0P000000103oool000000000003oool2000000040?ooo`00
000000000?ooo`80000000<0oooo0000000000004@3ooolZ0=7=ZA@0oooo0`0000001@3oool00000
000000000000oooo00<0000000D0oooo00000000000000000?ooo`03000000050?ooo`0000000000
0000003oool00`0000001@3oool00000000000000000oooo00<0000000@0oooo000000000000oooo
0`00000A0?oooad0dLfY000K0=7=ZA@0oooo0`0000001@3oool00000000000000000oooo00<00000
00D0oooo00000000000000000?ooo`06000000050?ooo`00000000000000003oool00`0000001@3o
ool00000000000000000oooo00<0000000@0oooo00000000000000004P3ooolZ0=7=ZA@0oooo0`00
00001@3oool00000000000000000oooo00<0000000<0oooo000000000000400000001@3oool00000
000000000000oooo00<0000000@0oooo00000000000000004P3ooolZ0=7=ZA@0oooo0`0000000`3o
ool000000?ooo`04000000<0oooo0P0000000`3oool000000?ooo`03000000040?ooo`0000000000
0?ooo`80000000@0oooo000000000000oooo0P000000103oool000000000003oool2000000030?oo
o`00000000000180oooo:P3AcJTC0?ooo`<0000000D0oooo00000000000000000?ooo`0300000005
0?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo00<0000000D0oooo
00000000000000000?ooo`03000000030?ooo`000000000000@000004P3ooolM0=7=Z@006`3AcJTE
0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo0140oooo:P3AcJTE0?ooo`030000003oool0
000000@0000000<0oooo0000003oool0500000000`3oool000000?ooo`05000000030?ooo`000000
oooo0180oooo:P3AcJTE0?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool01000
00030?ooo`<0000000@0oooo000000000000oooo0P000000103oool000000000003oool200000004
0?ooo`00000000000?ooo`80000000<0oooo0000000000004`3ooolZ0=7=ZA@0oooo00<000000?oo
o`0000000P0000001@3oool00000000000000000oooo00<0000000D0oooo00000000000000000?oo
o`03000000050?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo00<0
000000<0oooo0000000000004`3ooolM0=7=Z@006`3AcJTG0?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0C0?ooobX0dLfY5`3o
ool01P000000oooo0000003oool000000?oooaP0000000H0oooo0000003oool000000?ooo`00000E
0?ooobX0dLfY5`3oool00`000000oooo0?ooo`04000000<0oooo0P0000000`3oool000000?ooo`03
000000040?ooo`00000000000?ooo`80000000@0oooo000000000000oooo0P000000103oool00000
0000003oool2000001D0oooo:P3AcJTF0?ooo`030000003oool000000080000000D0oooo00000000
000000000?ooo`03000000050?ooo`00000000000000003oool00`0000001@3oool0000000000000
0000oooo00<0000000D0oooo00000000000000000?ooo`02000001D0oooo7@3AcJT001/0dLfY603o
ool3000000050?ooo`00000000000000003oool00`0000000`3oool0000000000004000000050?oo
o`00000000000000003oool00`0000001@3oool00000000000000000oooo00<000005P3ooolZ0=7=
ZAP0oooo0`0000000`3oool000000000000H000000040?ooo`0000000000000001H0oooo:P3AcJTH
0?ooo`<0000000<0oooo0000003oool0100000030?ooo`<0000000@0oooo000000000000oooo0P00
0000103oool000000000003oool2000000040?ooo`00000000000?ooo`8000005P3ooolZ0=7=ZAL0
oooo0`0000001@3oool00000000000000000oooo00<0000000D0oooo00000000000000000?ooo`03
000000050?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo00<00000
5@3ooolM0=7=Z@006`3AcJTI0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`0E0?ooobX0dLfY6@3oool00`000000oooo0000000K
000000030?ooo`000000oooo01H0oooo:P3AcJTI0?ooo`040000003oool0oooo0?ooo`80000000<0
oooo0000003oool0100000020?ooo`80000000@0oooo000000000000oooo0P000000103oool00000
0000003oool2000000030?ooo`000000000001L0oooo:P3AcJTH0?ooo`030000003oool000000080
000000D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000003oool00`000000
1@3oool00000000000000000oooo00<0000000@0oooo00000000000000005P3ooolM0=7=Z@006`3A
cJTJ0?ooo`<0000000D0oooo00000000000000000?ooo`03000000040?ooo`00000000000?ooo`<0
000000D0oooo00000000000000000?ooo`03000000040?ooo`0000000000000001P0oooo:P3AcJTJ
0?oooah00000603ooolZ0=7=ZAX0oooo100000030?ooo`80000000<0oooo0000003oool00`000000
103oool000000000003oool2000000040?ooo`00000000000?ooo`80000000<0oooo000000000000
603ooolZ0=7=ZAT0oooo0`0000001@3oool00000000000000000oooo00<0000000D0oooo00000000
000000000?ooo`03000000050?ooo`00000000000000003oool00`000000103oool0000000000000
000G0?oooad0dLfY000K0=7=ZA/0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00006@3ooolZ0=7=ZA/0oooo00/000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000020?ooo`0?0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool0000001T0oooo:P3AcJTK0?ooo`030000003oool0oooo00@000000`3oool300000004
0?ooo`00000000000?ooo`80000000@0oooo000000000000oooo0P0000000`3oool000000000000I
0?ooobX0dLfY6P3oool00`000000oooo00000002000000050?ooo`00000000000000003oool00`00
00001@3oool00000000000000000oooo00<0000000D0oooo00000000000000000?ooo`03000001P0
oooo7@3AcJT001/0dLfY703oool3000000050?ooo`00000000000000003oool01P0000001@3oool0
0000000000000000oooo00<0000000@0oooo00000000000000006P3ooolZ0=7=ZA`0oooo0`000000
1@3oool00000000000000000oooo00H0000000D0oooo00000000000000000?ooo`03000000040?oo
o`0000000000000001X0oooo:P3AcJTL0?ooo`<0000000<0oooo0000003oool0100000020?ooo`80
000000@0oooo000000000000oooo0P000000103oool000000000003oool2000001X0oooo:P3AcJTK
0?ooo`<0000000D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000003oool0
0`0000001@3oool00000000000000000oooo00<000006@3ooolM0=7=Z@006`3AcJTM0?ooo`050000
003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`0I0?ooobX0dLfY7@3oool00`000000oooo00000004
000000030?ooo`000000oooo00@0000000<0oooo0000003oool01@0000000`3oool000000?ooo`0J
0?ooobX0dLfY7@3oool010000000oooo0?ooo`3oool2000000030?ooo`000000oooo00<0000000@0
oooo000000000000oooo0P000000103oool000000000003oool2000001/0oooo:P3AcJTL0?ooo`03
0000003oool000000080000000D0oooo00000000000000000?ooo`03000000050?ooo`0000000000
0000003oool00`000000103oool0000000000000000J0?oooad0dLfY000K0=7=ZAh0oooo0`000000
1@3oool00000000000000000oooo0080000000D0oooo00000000000000000?ooo`03000000040?oo
o`0000000000000001`0oooo:P3AcJTN0?ooo`L0000000<0oooo000000000000100000000`3oool0
000000000005000001`0oooo:P3AcJTN0?ooo`@000000`3oool3000000040?ooo`00000000000?oo
o`80000000@0oooo000000000000oooo0P00000L0?ooobX0dLfY7@3oool3000000050?ooo`000000
00000000003oool00`0000001@3oool00000000000000000oooo00<0000000@0oooo000000000000
00006`3ooolM0=7=Z@006`3AcJTO0?ooo`050000003oool0oooo0?ooo`0000001P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool06`3ooolZ0=7=ZAl0oooo00H000000?oo
o`000000oooo0000003oool8000000060?ooo`000000oooo0000003oool000007@3ooolZ0=7=ZAl0
oooo00<000000?ooo`3oool0100000020?ooo`80000000@0oooo000000000000oooo0P0000000`3o
ool000000000000M0?ooobX0dLfY7P3oool00`000000oooo00000002000000050?ooo`0000000000
0000003oool00`0000001@3oool00000000000000000oooo00<00000703ooolM0=7=Z@006`3AcJTP
0?ooo`<0000000<0oooo000000000000100000001@3oool00000000000000000oooo00<000007P3o
oolZ0=7=ZB00oooo0`0000000`3oool0000000000008000000040?ooo`0000000000000001h0oooo
:P3AcJTP0?ooo`<0000000<0oooo0000003oool00`000000103oool000000000003oool200000003
0?ooo`000000000001h0oooo:P3AcJTO0?ooo`<0000000D0oooo00000000000000000?ooo`030000
00050?ooo`00000000000000003oool00`00000M0?oooad0dLfY000K0=7=ZB40oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?oo
o`0M0?ooobX0dLfY8@3oool00`000000oooo0000000;000000030?ooo`000000oooo01h0oooo:P3A
cJTQ0?ooo`040000003oool0oooo0?ooo`<0000000@0oooo000000000000oooo0P0000000`3oool0
00000000000O0?ooobX0dLfY803oool00`000000oooo00000002000000050?ooo`00000000000000
003oool00`000000103oool0000000000000000N0?oooad0dLfY000K0=7=ZB80oooo0`000000103o
ool000000000003oool3000000040?ooo`000000000000000200oooo:P3AcJTR0?ooo`h00000803o
oolZ0=7=ZB80oooo100000020?ooo`80000000@0oooo000000000000oooo0P00000P0?ooobX0dLfY
8@3oool3000000050?ooo`00000000000000003oool00`000000103oool0000000000000000O0?oo
oad0dLfY000K0=7=ZB<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool00000
0240oooo:P3AcJTS0?ooo`030000003oool000000080oooo00L000000?ooo`000000oooo0000003o
ool000000240oooo:P3AcJTS0?ooo`030000003oool0oooo00<0000000@0oooo000000000000oooo
0P00000Q0?ooobX0dLfY8P3oool00`000000oooo00000002000000050?ooo`00000000000000003o
ool00`00000P0?oooad0dLfY000K0=7=ZB@0oooo1P000000103oool0000000000000000R0?ooobX0
dLfY903oool6000000040?ooo`000000000000000280oooo:P3AcJTT0?ooo`@0000000@0oooo0000
00000000oooo0P00000R0?ooobX0dLfY8`3oool3000000050?ooo`00000000000000003oool00`00
000Q0?oooad0dLfY000K0=7=ZBD0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0Q0?ooobX0dLfY9@3oool00`000000oooo00000003000000030?ooo`000000oooo0280oooo:P3A
cJTU0?ooo`030000003oool0oooo0080000000<0oooo0000000000008`3ooolZ0=7=ZB@0oooo00<0
00000?ooo`0000000P000000103oool0000000000000000R0?oooad0dLfY000K0=7=ZBH0oooo0P00
0000103oool0000000000000000T0?ooobX0dLfY9P3oool6000002@0oooo:P3AcJTV0?ooo`<00000
00<0oooo000000000000903ooolZ0=7=ZBD0oooo0`000000103oool0000000000000000S0?oooad0
dLfY000K0=7=ZBX0oooo00<000000?ooo`3oool08`3ooolZ0=7=ZBP0oooo00<000000?ooo`000000
9@3ooolZ0=7=ZBT0oooo0P00000U0?ooobX0dLfY9P3oool00`000000oooo00000002000002@0oooo
7@3AcJT001/0dLfY9`3oool3000002H0oooo:P3AcJTW0?ooo`<000009P3ooolZ0=7=ZBL0oooo0`00
000V0?ooobX0dLfY9`3oool3000002D0oooo7@3AcJT001/0dLfY:03oool00`000000oooo0?ooo`0U
0?ooobX0dLfY:03oool00`000000oooo0?ooo`0U0?ooobX0dLfY:03oool00`000000oooo0?ooo`0U
0?ooobX0dLfY:03oool00`000000oooo0?ooo`0T0?oooad0dLfY003o0=7=ZOH0dLfY003o0=7=ZOH0
dLfY003o0=7=ZOH0dLfY003o0=7=ZOH0dLfY003o0=7=ZOH0dLfY003o0=7=ZOH0dLfY000k0=7=Z@E0
00000P3AcJT2@00000@0dLfY0T00001[0=7=Z@E000000P3AcJT2@00000<0dLfY0d00001[0=7=Z@E0
000000<0dLfY@000040000000d0000020=7=Z@900000J`3AcJT5@00000030=7=ZD000010000000=0
000000<0dLfY@000040000000d00000k0=7=Z@00?@3AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@1Z0=7=Z@05@000003AcJT0dLfY
0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY06/0dLfY00=00000
0=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0JP3A
cJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0>`3A
cJT003d0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY
00=000000=7=Z@3AcJT0JP3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3A
cJT0dLfY0d00001/0=7=Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@0000002
0=7=Z@03@000003AcJT0dLfY06X0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@03
0=7=Z@03@000003AcJT0dLfY03/0dLfY000m0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT0
14000000dLfY0=7=Z@3AcJT2@00006d0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000
003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0JP3AcJT00d000000dLfY0=7=Z@030=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@1Z0=7=Z@03@000003AcJT0dLfY
00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0k0=7=Z@00?@3AcJT01D000000
dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@1Z
0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000
003AcJT0dLfY06X0dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00=000000=7=Z@3AcJT0JP3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0
dLfY00=000000=7=Z@3AcJT0>`3AcJT003`0dLfY0T0000040=7=Z@900000103AcJT2@00006`0dLfY
0T0000040=7=Z@900000103AcJT3@00006/0dLfY0T0000040=7=Z@900000103AcJT2@00006`0dLfY
0T0000040=7=Z@900000103AcJT2@00003d0dLfY003o0=7=ZOH0dLfY003o0=7=ZOH0dLfY003o0=7=
ZOH0dLfY003o0=7=ZOH0dLfY003o0=7=ZOH0dLfY003o0=7=ZOH0dLfY003o0=7=ZOH0dLfY003o0=7=
ZOH0dLfY003o0=7=ZOH0dLfY000K0=7=Z@80oooo0`0000001@3oool00000000000000000oooo00<0
000000@0oooo0000000000000000<03oool3000000050?ooo`00000000000000003oool00`000000
103oool0000000000000000Z0=7=Z@80oooo0P000000103oool000000000003oool3000000040?oo
o`00000000000?ooo`8000004@3oool2000000030?ooo`000000000000<0000000@0oooo00000000
0000oooo0P00000A0?ooo`80000000@0oooo000000000000oooo0`000000103oool000000000003o
ool2000002X0dLfY0P3oool600000080oooo00H000000?ooo`3oool0oooo0000003oool200000003
0?ooo`00000000000080oooo00<000000?ooo`3oool00`0000020?ooo`8000000`3oool00`000000
oooo0000000300000080oooo0`0000020?ooo`030000003oool0oooo00@0000000H0oooo0000003o
ool0oooo0000003oool300000080oooo00@000000?ooo`00000000000P3oool4000000030?ooo`00
0000000002X0dLfY0P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo00<0
00000?ooo`3oool00P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3o
ool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00P00
00020?ooo`8000000P3oool200000080oooo0P0000020?ooo`<000007@3AcJT001/0dLfY0`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000000b0?ooo`050000
003oool0oooo0?ooo`0000000`3oool01P000000oooo0?ooo`3oool000000?ooobX0dLfY0`3oool0
0`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo0000000C0?ooo`030000
003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000001<0oooo00<000000?oo
o`0000000`3oool020000000oooo0?ooo`3oool000000?ooo`000000oooo:P3AcJT30?ooo`040000
003oool0oooo000000@0oooo100000000`3oool000000?ooo`020?ooo`050000003oool000000000
003oool00P0000020?ooo`<000001@3oool300000080oooo0`0000020?ooo`<0000000<0oooo0000
000000000P3oool010000000oooo0000003oool2000000040?ooo`000000oooo0?ooo`<0000000<0
oooo0000003oool00`3oool00`000000oooo0?ooo`02000000030?ooo`3AcJT0dLfY02P0dLfY0`3o
ool00`000000oooo00000002000000050?ooo`00000000000000003oool00`000000103oool00000
0000003oool3000000050?ooo`00000000000000003oool00`0000001@3oool00000000000000000
oooo00<0000000D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000003oool0
0`000000103oool000000000003oool3000000050?ooo`00000000000000003oool00`0000001@3o
ool00000000000000000oooo00<0000000<0oooo0=7=Z@3AcJT06`3AcJT001/0dLfY103oool30000
00D0oooo0`00000d0?ooo`<000001@3oool300000080oooo:P3AcJT40?ooo`<0000000D0oooo0000
0000000000000?ooo`03000001D0oooo1P000000103oool0000000000000000E0?ooo`<0000000D0
oooo00000000000000000?ooo`0300000080oooo:P3AcJT40?ooo`<0000000<0oooo000000000000
0P0000020?ooo`040000003oool000000?ooo`<0000000<0oooo0000003oool00P3oool010000000
oooo0000000000020?ooo`H000000P3oool300000080oooo0`0000020?ooo`800000103oool20000
00030?ooo`000000oooo0080oooo0`0000020?ooo`80000000<0oooo0000000000000P0000000`3o
ool00000000000020?ooobX0dLfY103oool200000080oooo0P0000020?ooo`8000000P3oool20000
00030?ooo`00000000000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?oo
o`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2000000030?ooo`0000000000
0080oooo0P0000020?ooo`8000000P3oool200000080oooo0`0000020?oooad0dLfY000K0=7=Z@D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`3oool0oooo:P3AcJT50?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`0E0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool05@3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool0oooo:P3AcJT50?ooo`05
0000003oool0oooo0?ooo`0000000P3oool3000000040?ooo`000000oooo00000080oooo0P000000
1P3oool00000000000000000oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`0000030?ooo`@0
00000P3oool3000000<0oooo00<000000?ooo`3oool00P0000030?ooobX0dLfY1@3oool00`000000
oooo00000002000000050?ooo`00000000000000003oool00`000000103oool000000000003oool3
000000050?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo00<00000
00D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000003oool00`000000103o
ool000000000003oool3000000050?ooo`00000000000000003oool00`000000103oool000000000
000000030?oooad0dLfY000K0=7=Z@H0oooo0`000000103oool0000000000000000h0?ooo`<00000
00@0oooo0000000000000000103ooolZ0=7=Z@H0oooo0P0000000`3oool000000?ooo`02000001T0
oooo00@000000?ooo`000000oooo0P00000I0?ooo`80000000<0oooo0000003oool00P0000040?oo
obX0dLfY1P3oool4000000030?ooo`00000000000080oooo0P0000000`3oool000000?ooo`020000
00<0oooo00@000000?ooo`3oool0oooo1@000000103oool000000000003oool4000000030?ooo`00
000000000080000000<0oooo0000000000000P0000001P3oool000000?ooo`3oool000000?ooo`<0
00000P3oool010000000oooo0000000000020?ooo`@0000000<0oooo000000000000103ooolZ0=7=
Z@H0oooo0P0000020?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00P0000020?oo
o`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?oo
o`8000000P3oool200000080oooo00<000000?ooo`3oool00P0000020?ooo`8000000P3oool20000
0080oooo0`0000040?oooad0dLfY000K0=7=Z@L0oooo00D000000?ooo`3oool0oooo0000000j0?oo
o`050000003oool0oooo0?ooo`0000001@3ooolZ0=7=Z@L0oooo00D000000?ooo`000000oooo0000
000L0?ooo`030000003oool0000001/0oooo00D000000?ooo`000000oooo000000050?ooobX0dLfY
1`3oool00`000000oooo0?ooo`02000000@0oooo00D000000?ooo`000000oooo000000050?ooo`@0
00000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`030000003o
ool0oooo008000000P3oool010000000oooo0000003oool2000000040?ooo`000000oooo0?ooo`<0
000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`02000000D0oooo:P3AcJT70?ooo`03
0000003oool000000080000000D0oooo00000000000000000?ooo`02000000050?ooo`0000000000
0000003oool00`0000001@3oool00000000000000000oooo00<0000000D0oooo0000000000000000
0?ooo`03000000050?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo
0080000000D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000003oool00`00
00050?oooad0dLfY000K0=7=Z@P0oooo0`00000l0?ooo`<000001P3ooolZ0=7=Z@P0oooo0`00000L
0?ooo`<000007@3oool3000000H0oooo:P3AcJT80?ooo`<000001P3oool2000000030?ooo`000000
oooo00D000000P3oool01@000000oooo000000000000oooo00<0000000D0oooo0000000000000000
0?ooo`03000000030?ooo`000000000000@0oooo0P0000000`3oool000000?ooo`020?ooo`<00000
0P3oool2000000030?ooo`00000000000080000000<0oooo0000000000001P3ooolZ0=7=Z@P0oooo
0P0000020?ooo`8000000P3oool2000000030?ooo`00000000000080oooo0P0000020?ooo`800000
0P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`800000
0P3oool2000000030?ooo`00000000000080oooo0P0000020?ooo`8000000P3oool3000000H0oooo
7@3AcJT001/0dLfY2@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00D0oooo:P3A
cJT90?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`050?ooobX0dLfY2@3oool00`000000oooo0?ooo`060?ooo`050000003oool000000?ooo`000000
0P3oool00`000000oooo0?ooo`020?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00H000000?ooo`3oool0oooo0000003oool4000000<0oooo100000020?ooo`<000000`3oool0
0`000000oooo0?ooo`02000000L0oooo:P3AcJT90?ooo`030000003oool000000080000000D0oooo
00000000000000000?ooo`02000000050?ooo`00000000000000003oool00`0000001@3oool00000
000000000000oooo00<0000000D0oooo00000000000000000?ooo`03000000050?ooo`0000000000
0000003oool00`0000001@3oool00000000000000000oooo0080000000D0oooo0000000000000000
0?ooo`03000000040?ooo`0000000000000000L0oooo7@3AcJT001/0dLfY2P3oool3000000050?oo
o`00000000000000003oool00`0000001@3oool00000000000000000oooo00<0000000D0oooo0000
0000000000000?ooo`03000000040?ooo`00000000000?ooo`<0000000D0oooo0000000000000000
0?ooo`03000000050?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo
00<0000000@0oooo0000000000000000203ooolZ0=7=Z@X0oooo0P000000103oool000000000003o
ool2000000040?ooo`00000000000?ooo`80000000@0oooo000000000000oooo0P000000103oool0
00000000003oool2000000030?ooo`000000000000<0000000@0oooo000000000000oooo0P000000
103oool000000000003oool2000000040?ooo`00000000000?ooo`80000000@0oooo000000000000
oooo0P000000103oool000000000003oool2000000P0oooo:P3AcJT:0?ooo`T0000000D0oooo0000
003oool000000?ooo`02000000030?ooo`0000000000008000001@3oool3000000D0oooo10000000
1P3oool000000?ooo`3oool000000?ooo`<000000P3oool010000000oooo0000000000020?ooo`@0
000000<0oooo000000000000203ooolZ0=7=Z@X0oooo0P0000020?ooo`8000000P3oool00`000000
oooo0?ooo`0200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`80
00000P3oool200000080oooo0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`0200000080
oooo0P0000020?ooo`<00000203ooolM0=7=Z@006`3AcJT;0?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000090?ooobX0dLfY2`3oool00`000000oooo000000030?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool00000
0080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`0000002@3o
oolZ0=7=Z@/0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`3oool200000003
0?ooo`000000oooo0080oooo00<000000?ooo`3oool01P0000030?ooo`D000000P3oool010000000
oooo0000003oool2000000040?ooo`000000oooo0?ooo`<0000000<0oooo0000003oool00`3oool0
0`000000oooo0?ooo`02000000T0oooo:P3AcJT;0?ooo`030000003oool000000080000000@0oooo
000000000000oooo0`0000001@3oool00000000000000000oooo00<0000000D0oooo000000000000
00000?ooo`03000000050?ooo`00000000000000003oool00`0000001@3oool00000000000000000
oooo00<0000000@0oooo000000000000oooo0`0000001@3oool00000000000000000oooo00<00000
2@3ooolM0=7=Z@006`3AcJT<0?ooo`<000001@3oool3000000D0oooo0`0000050?ooo`<00000103o
ool3000000D0oooo0`0000050?ooo`<000001@3oool3000000X0oooo:P3AcJT<0?ooo`<0000000@0
oooo00000000000000001@3oool3000000040?ooo`0000000000000000D0oooo1P000000103oool0
00000000000000050?ooo`<0000000@0oooo00000000000000001@3oool3000000040?ooo`000000
0000000000X0oooo:P3AcJT<0?ooo`<0000000@0oooo000000000000oooo0`0000030?ooo`@00000
00<0oooo0000000000000P3oool00`000000oooo0?ooo`02000000050?ooo`000000oooo0?ooo`00
0000103oool2000000030?ooo`000000oooo0080oooo0`0000020?ooo`80000000<0oooo00000000
00000P0000000`3oool000000000000:0?ooobX0dLfY303oool200000080oooo0P0000000`3oool0
0000000000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080
oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000000`3oool00000000000020?ooo`80
00000P3oool3000000X0oooo7@3AcJT001/0dLfY3@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00T0oooo:P3AcJT=0?ooo`050000003oool0oooo0?ooo`0000001`3oool01@000000
oooo0?ooo`3oool0000000L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`05
0?ooo`050000003oool0oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0000000/0oooo
:P3AcJT=0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`@000000P3oool00`00
0000oooo000000040?ooo`<0000000@0oooo000000000000oooo0P0000000`3oool0000000000002
000000<0oooo100000020?ooo`<000000`3oool00`000000oooo0?ooo`02000000/0oooo:P3AcJT=
0?ooo`030000003oool000000080000000@0oooo000000000000oooo0`0000001@3oool000000000
00000000oooo00<0000000D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000
003oool00`0000001@3oool00000000000000000oooo00<0000000@0oooo000000000000oooo0`00
0000103oool0000000000000000;0?oooad0dLfY000K0=7=Z@h0oooo0`000000103oool000000000
000000090?ooo`<0000000@0oooo0000000000000000203oool3000000040?ooo`00000000000000
00T0oooo0`000000103oool0000000000000000<0?ooobX0dLfY3P3oool2000000030?ooo`000000
oooo0080000000H0oooo000000000000oooo0000003oool2000000T0oooo00@000000?ooo`000000
oooo0P0000090?ooo`80000000<0oooo0000003oool00P0000001P3oool000000000003oool00000
0?ooo`800000303ooolZ0=7=Z@h0oooo100000000`3oool000000?ooo`0200000080oooo00L00000
0?ooo`00000000000?ooo`000000oooo00@000000P3oool2000000<0oooo00<000000?ooo`000000
0P3oool00`000000oooo0000000200000080oooo00@000000?ooo`00000000000P3oool400000003
0?ooo`000000000000`0oooo:P3AcJT>0?ooo`8000000P3oool00`000000oooo0?ooo`0200000080
oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080
oooo0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`0200000080oooo0`00000<0?oooad0
dLfY000K0=7=Z@l0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`050000003oool0oooo0?oo
o`0000002P3oool01@000000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000
000=0?ooobX0dLfY3`3oool01@000000oooo0000003oool0000000<0oooo00D000000?ooo`000000
oooo0000000<0?ooo`030000003oool0000000/0oooo00D000000?ooo`000000oooo000000030?oo
o`050000003oool000000?ooo`0000003@3ooolZ0=7=Z@l0oooo00<000000?ooo`3oool00P000000
0`3oool000000?ooo`030?ooo`8000000`3oool200000080oooo00D000000?ooo`00000000000?oo
o`04000000030?ooo`000000oooo0080000000@0oooo0000003oool0oooo0`0000000`3oool00000
0?ooo`030?ooo`030000003oool0oooo008000003@3ooolZ0=7=Z@l0oooo00D000000?ooo`000000
00000?ooo`03000000050?ooo`00000000000000003oool00`0000001@3oool00000000000000000
oooo00<0000000D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000003oool0
0`000000103oool000000000003oool3000000040?ooo`0000000000000000d0oooo7@3AcJT001/0
dLfY403oool3000000d0oooo0`00000<0?ooo`<000003@3oool3000000h0oooo:P3AcJT@0?ooo`<0
00001@3oool3000000`0oooo0`00000=0?ooo`<000001@3oool3000000h0oooo:P3AcJT@0?ooo`<0
00000`3oool5000000D0oooo00H000000?ooo`00000000000?ooo`0000030?ooo`030000003oool0
oooo0080000000<0oooo0000003oool00P3oool300000080oooo0P0000000`3oool0000000000002
000000030?ooo`000000000000h0oooo:P3AcJT@0?ooo`80000000<0oooo0000000000000P3oool2
00000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2
00000080oooo0P0000020?ooo`80000000<0oooo0000000000000P3oool3000000h0oooo7@3AcJT0
01/0dLfY4@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooobX0dLfY4@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00d0oooo:P3AcJTA0?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool000000?ooo`05000000030?ooo`000000oooo0080oooo100000000`3oool0000000000003
0?ooo`@000000P3oool3000000<0oooo00<000000?ooo`3oool00P00000?0?ooobX0dLfY4@3oool0
1@000000oooo000000000000oooo00<0000000D0oooo00000000000000000?ooo`03000000050?oo
o`00000000000000003oool00`0000001@3oool00000000000000000oooo00<0000000D0oooo0000
0000000000000?ooo`03000000040?ooo`00000000000?ooo`<000003`3ooolM0=7=Z@006`3AcJTB
0?ooo`<0000000D0oooo00000000000000000?ooo`03000000040?ooo`000000000000000100oooo
0`0000001@3oool00000000000000000oooo00<0000000@0oooo0000000000000000403ooolZ0=7=
ZA80oooo0P000000103oool000000000003oool3000000040?ooo`00000000000?ooo`80000000@0
oooo000000000000oooo1@000000103oool000000000003oool2000000040?ooo`00000000000?oo
o`80000000D0oooo00000000000000000?ooo`02000000030?ooo`00000000000100oooo:P3AcJTB
0?ooo`H0000000D0oooo000000000000oooo000000020?ooo`040000003oool0oooo0?ooo`@00000
00<0oooo0000003oool00P3oool00`000000oooo0000000200000080oooo00@000000?ooo`000000
00000P3oool4000000030?ooo`00000000000100oooo:P3AcJTB0?ooo`030000003oool0oooo0080
00000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`80
00000P3oool200000080oooo0P0000020?ooo`030000003oool0oooo00<00000403ooolM0=7=Z@00
6`3AcJTC0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool00000
0180oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000004@3o
oolZ0=7=ZA<0oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo00000003
0?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool000000140oooo
:P3AcJTC0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`000000oooo0P000000103o
ool000000000000000020?ooo`<0000000H0oooo00000000000000000?ooo`0000020?ooo`<00000
00<0oooo0000003oool00`3oool00`000000oooo0?ooo`0200000140oooo:P3AcJTD0?ooo`<00000
00D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000003oool00`0000001@3o
ool00000000000000000oooo00<0000000D0oooo00000000000000000?ooo`03000000040?ooo`00
000000000?ooo`<000004@3ooolM0=7=Z@006`3AcJTD0?ooo`<000001@3oool3000001@0oooo0`00
00050?ooo`<000004P3ooolZ0=7=ZA@0oooo0`0000001@3oool00000000000000000oooo00<00000
1@3oool6000000040?ooo`0000000000000000D0oooo0`0000001@3oool00000000000000000oooo
00<000004P3ooolZ0=7=ZA@0oooo0`000000203oool00000000000000000oooo0000003oool00000
0`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool300000080
oooo0P0000000`3oool0000000000002000000030?ooo`00000000000180oooo:P3AcJTC0?ooo`80
00000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`80
00000P3oool200000080oooo0P0000020?ooo`80000000@0oooo00000000000000004P3ooolM0=7=
Z@006`3AcJTE0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0140oooo:P3AcJTE0?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool04@3o
oolZ0=7=ZAD0oooo00D000000?ooo`3oool0oooo000000030?ooo`80000000D0oooo000000000000
00000?ooo`03000000D0oooo100000020?ooo`<000000`3oool00`000000oooo0?ooo`02000001<0
oooo:P3AcJTD0?ooo`030000003oool000000080000000D0oooo00000000000000000?ooo`030000
00050?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo00<0000000D0
oooo00000000000000000?ooo`03000000030?ooo`000000000001<0oooo7@3AcJT001/0dLfY5`3o
ool01@000000oooo0?ooo`3oool0000001X0oooo00D000000?ooo`3oool0oooo0000000E0?ooobX0
dLfY5`3oool01@000000oooo0000003oool0000000`0oooo00<000000?ooo`0000002`3oool01@00
0000oooo0000003oool0000001D0oooo:P3AcJTG0?ooo`030000003oool0oooo008000000P3oool4
000000060?ooo`00000000000000003oool000000P3oool00`000000oooo0?ooo`03000000030?oo
o`000000oooo00<0oooo00<000000?ooo`3oool00P00000E0?ooobX0dLfY5P3oool00`000000oooo
00000002000000050?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo
00<0000000D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000003oool00P00
000E0?oooad0dLfY000K0=7=ZAP0oooo0`00000L0?ooo`<000005P3ooolZ0=7=ZAP0oooo0`00000<
0?ooo`<000003@3oool3000001H0oooo:P3AcJTH0?ooo`<00000103oool00`000000oooo0?ooo`02
00000080oooo00<000000?ooo`3oool00P3oool300000080oooo0P0000000`3oool0000000000002
000000030?ooo`000000000001H0oooo:P3AcJTG0?ooo`8000000P3oool200000080oooo0P000002
0?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0`00000E
0?oooad0dLfY000K0=7=ZAT0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0E0?oo
obX0dLfY6@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool05@3ooolZ0=7=ZAT0oooo00<000000?ooo`3oool0103oool3000000D0oooo100000020?oo
o`<000000`3oool00`000000oooo0?ooo`02000001L0oooo:P3AcJTH0?ooo`030000003oool00000
0080000000D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000003oool00`00
00001@3oool00000000000000000oooo00<0000000@0oooo00000000000000005P3ooolM0=7=Z@00
6`3AcJTJ0?ooo`<0000000D0oooo00000000000000000?ooo`03000000040?ooo`00000000000?oo
o`<0000000D0oooo00000000000000000?ooo`03000000040?ooo`0000000000000001P0oooo:P3A
cJTJ0?ooo`80000000@0oooo000000000000oooo0P000000203oool000000000003oool000000?oo
o`000000oooo0P000000103oool000000000003oool2000000040?ooo`00000000000?ooo`800000
603ooolZ0=7=ZAX0oooo1`0000020?ooo`@0000000H0oooo0000003oool0oooo0000003oool20000
0080oooo100000000`3oool000000000000H0?ooobX0dLfY6@3oool200000080oooo0P0000020?oo
o`8000000P3oool200000080oooo0P0000020?ooo`8000000P3oool200000080oooo0`00000G0?oo
oad0dLfY000K0=7=ZA/0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000006@3o
oolZ0=7=ZA/0oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0000000I0?ooobX0dLfY6`3o
ool010000000oooo0?ooo`0000020?ooo`<000000P3oool00`000000oooo0?ooo`03000000030?oo
o`000000oooo00<0oooo00<000000?ooo`3oool00P00000I0?ooobX0dLfY6P3oool00`000000oooo
00000002000000050?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo
00<0000000D0oooo00000000000000000?ooo`03000001P0oooo7@3AcJT001/0dLfY703oool30000
00D0oooo0`0000040?ooo`<000001@3oool3000001X0oooo:P3AcJTL0?ooo`<0000000@0oooo0000
000000000000103oool3000000D0oooo0`000000103oool0000000000000000J0?ooobX0dLfY703o
ool3000000030?ooo`00000000000080oooo1P0000020?ooo`80000000<0oooo0000000000000P00
00000`3oool000000000000J0?ooobX0dLfY6`3oool200000080oooo0P0000020?ooo`8000000P3o
ool200000080oooo0P0000020?ooo`8000000P3oool3000001T0oooo7@3AcJT001/0dLfY7@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0I0?ooobX0dLfY7@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<0
00000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000001/0oooo:P3AcJTM0?ooo`060000
003oool0oooo0?ooo`000000oooo0P0000020?ooo`030000003oool0oooo00<000000`3oool00`00
0000oooo0?ooo`02000001/0oooo:P3AcJTL0?ooo`030000003oool000000080000000D0oooo0000
0000000000000?ooo`03000000050?ooo`00000000000000003oool00`000000103oool000000000
0000000J0?oooad0dLfY000K0=7=ZAh0oooo0`000000103oool000000000000000080?ooo`<00000
00@0oooo0000000000000000703ooolZ0=7=ZAh0oooo0P0000000`3oool000000?ooo`0200000005
0?ooo`000000oooo0000003oool00P0000001P3oool000000000003oool000000?ooo`800000703o
oolZ0=7=ZAh0oooo100000000`3oool000000?ooo`020?ooo`040000003oool0000000000080oooo
100000000`3oool000000000000L0?ooobX0dLfY7@3oool200000080oooo0P0000020?ooo`800000
0P3oool200000080oooo0P0000020?ooo`<000006`3ooolM0=7=Z@006`3AcJTO0?ooo`050000003o
ool0oooo0?ooo`0000002P3oool01@000000oooo0?ooo`3oool0000001d0oooo:P3AcJTO0?ooo`05
0000003oool000000?ooo`000000103oool00`000000oooo000000030?ooo`050000003oool00000
0?ooo`0000007@3ooolZ0=7=ZAl0oooo00<000000?ooo`3oool00P0000001P3oool0000000000000
0000oooo000000@0oooo00<000000?ooo`3oool00P00000M0?ooobX0dLfY7P3oool00`000000oooo
00000002000000050?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo
00<00000703ooolM0=7=Z@006`3AcJTP0?ooo`<00000303oool3000001h0oooo:P3AcJTP0?ooo`<0
0000103oool3000000D0oooo0`00000N0?ooobX0dLfY803oool3000000<0oooo00D000000?ooo`00
000000000?ooo`04000000030?ooo`000000000001h0oooo:P3AcJTO0?ooo`8000000P3oool20000
0080oooo0P0000020?ooo`8000000P3oool3000001d0oooo7@3AcJT001/0dLfY8@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo01d0oooo:P3AcJTQ0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0M0?ooobX0dLfY8@3oool00`000000
oooo0?ooo`030?ooo`8000000`3oool00`000000oooo0?ooo`02000001l0oooo:P3AcJTP0?ooo`03
0000003oool000000080000000D0oooo00000000000000000?ooo`03000000040?ooo`0000000000
000001h0oooo7@3AcJT001/0dLfY8P3oool3000000040?ooo`00000000000?ooo`<0000000@0oooo
0000000000000000803ooolZ0=7=ZB80oooo0P0000000`3oool0000000000003000000040?ooo`00
000000000?ooo`800000803ooolZ0=7=ZB80oooo1@0000020?ooo`@0000000<0oooo000000000000
803ooolZ0=7=ZB40oooo0P0000020?ooo`8000000P3oool200000080oooo0`00000O0?oooad0dLfY
000K0=7=ZB<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000240oooo
:P3AcJTS0?ooo`030000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool00000
0240oooo:P3AcJTS0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P00000Q
0?ooobX0dLfY8P3oool00`000000oooo00000002000000050?ooo`00000000000000003oool00`00
000P0?oooad0dLfY000K0=7=ZB@0oooo0`0000040?ooo`<000008P3ooolZ0=7=ZB@0oooo1P000000
103oool0000000000000000R0?ooobX0dLfY903oool7000000030?ooo`00000000000280oooo:P3A
cJTS0?ooo`8000000P3oool200000080oooo0`00000Q0?oooad0dLfY000K0=7=ZBD0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooobX0dLfY9@3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo0240oooo:P3AcJTU0?ooo`040000003oool0oooo00000080oooo
0P00000S0?ooobX0dLfY903oool00`000000oooo00000002000000040?ooo`000000000000000280
oooo7@3AcJT001/0dLfY9P3oool2000000040?ooo`0000000000000002@0oooo:P3AcJTV0?ooo`04
0000003oool000000?ooo`800000903ooolZ0=7=ZBH0oooo0`0000000`3oool000000000000T0?oo
obX0dLfY9@3oool200000080oooo0`00000S0?oooad0dLfY000K0=7=ZBX0oooo00<000000?ooo`3o
ool08`3ooolZ0=7=ZBP0oooo00<000000?ooo`0000009@3ooolZ0=7=ZBT0oooo0P00000U0?ooobX0
dLfY9P3oool00`000000oooo00000002000002@0oooo7@3AcJT001/0dLfY9`3oool3000002H0oooo
:P3AcJTW0?ooo`<000009P3ooolZ0=7=ZBL0oooo0`00000V0?ooobX0dLfY9`3oool3000002D0oooo
7@3AcJT001/0dLfY:03oool00`000000oooo0?ooo`0U0?ooobX0dLfY:03oool00`000000oooo0?oo
o`0U0?ooobX0dLfY:03oool00`000000oooo0?ooo`0U0?ooobX0dLfY:03oool00`000000oooo0?oo
o`0T0?oooad0dLfY003o0=7=ZOH0dLfY003o0=7=ZOH0dLfY003o0=7=ZOH0dLfY003o0=7=ZOH0dLfY
003o0=7=ZOH0dLfY003o0=7=ZOH0dLfY000k0=7=Z@E000000P3AcJT2@00000D0dLfY0d00001Y0=7=
Z@E000000P3AcJT2@00000@0dLfY0T00001[0=7=Z@E000000P3AcJT2@00000<0dLfY0d00001[0=7=
Z@E000000P3AcJT2@00000D0dLfY00=000000=7=Z@3AcJT0>`3AcJT003d0dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0JP3AcJT01D00
0000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=
Z@1Z0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03
@000003AcJT0dLfY06X0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY
0080dLfY00=000000=7=Z@3AcJT0>`3AcJT003d0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=
Z@03@000003AcJT0dLfY00E00000J`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=00000
0=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@1Z0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3A
cJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY06X0dLfY00E000000=7=Z@3AcJT0
dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0>`3AcJT003d0dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=
Z@3AcJT0JP3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJT0dLfY0T00
001]0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@03@00006d0dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3A
cJT0>P3AcJT003d0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@07@000003AcJT0dLfY0=7=
ZD000000dLfY@000001/0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT01D000000dLfY0=7=
Z@3AcJU0000006h0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@05@000003AcJT0dLfY0=7=
ZD000000KP3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3A
cJT00d000000dLfY0=7=Z@0j0=7=Z@00?03AcJT2@00000@0dLfY0T0000050=7=Z@900000J`3AcJT2
@00000@0dLfY0T0000040=7=Z@=00000J`3AcJT2@00000@0dLfY0T0000040=7=Z@=00000J`3AcJT2
@00000@0dLfY0T0000030=7=Z@A00000?03AcJT00?l0dLfYmP3AcJT00?l0dLfYmP3AcJT00?l0dLfY
mP3AcJT00?l0dLfYmP3AcJT00?l0dLfYmP3AcJT00?l0dLfYmP3AcJT00?l0dLfYmP3AcJT00?l0dLfY
mP3AcJT00?l0dLfYmP3AcJT001/0dLfY:03oool4000000050?ooo`00000000000000003oool00`00
00001@3oool00000000000000000oooo00<0000000D0oooo00000000000000000?ooo`0300000005
0?ooo`00000000000000003oool00`000000103oool0000000000000000Z0=7=ZBP0oooo1@000006
0?ooo`050000003oool000000000003oool01@000000103oool000000?ooo`3oool200000080oooo
1P0000000`3oool000000?ooo`02000002X0dLfY0P3oool03`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000000`0?ooo`0?0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000002X0dLfY0P3oool04000
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool20000000U0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`020000000D0?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`00000M0=7=Z@006`3AcJTX0?ooo`030000003oool000000080000000D0oooo0000000000000000
0?ooo`03000000050?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo
00<0000000D0oooo00000000000000000?ooo`03000000030?ooo`000000oooo02X0dLfY:03oool0
10000000oooo0000000000070?ooo`<000000P3oool010000000oooo0000000000020?ooo`@00000
0`3oool2000000030?ooo`00000000000080oooo0`0000000`3oool0dLfY0=7=Z@0X0=7=Z@<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000<P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00H000000?ooo`3oool0oooo0000003ooolZ0=7=Z@<0oooo
00l000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool09@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool050000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo7@3AcJT001/0dLfY:03oool2000000050?ooo`00000000000000003oool00`0000001@3o
ool00000000000000000oooo00<0000000D0oooo00000000000000000?ooo`03000000050?ooo`00
000000000000003oool00`000000103oool000000000000000020?ooobX0dLfY:03oool3000000P0
oooo0P0000030?ooo`<000000`3oool2000000030?ooo`000000000000<000000P3oool010000000
oooo0?ooo`3oool200000080oooo:P3AcJT40?ooo`030000003oool0000000D0oooo00<000000?oo
o`000000=03oool00`000000oooo000000050?ooo`030000003oool000000080oooo:P3AcJT40?oo
o`0>0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool2
0000000U0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`020000000B0?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000P3ooolM
0=7=Z@006`3AcJTX0?ooo`<0000000D0oooo00000000000000000?ooo`03000000050?ooo`000000
00000000003oool00`0000001@3oool00000000000000000oooo00<0000000D0oooo000000000000
00000?ooo`03000000030?ooo`000000oooo0080oooo:P3AcJTX0?ooo`030000003oool0000000T0
0000103oool00`000000oooo0000000400000080oooo00@000000?ooo`00000000000`3oool50000
00<0oooo:P3AcJT50?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`050?ooo`040000003oool0oooo0?ooobX0dLfY1@3oool03@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000000P3oool09@000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000000P3oool04@000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool0000000<0oooo7@3AcJT001/0dLfY:03oool400000005
0?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo00<0000000D0oooo
00000000000000000?ooo`03000000050?ooo`00000000000000003oool00`0000040?ooobX0dLfY
:03oool3000000030?ooo`000000oooo0080000000<0oooo0000000000001@3oool3000000030?oo
o`000000000000<0oooo0`0000040?ooo`040000003oool00000000000@0oooo:P3AcJT60?ooo`07
0000003oool000000?ooo`000000oooo0000000h0?ooo`070000003oool000000?ooo`000000oooo
000000040?ooobX0dLfY1P3oool030000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`80000002D0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo008000000100oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000103o
oolM0=7=Z@006`3AcJTX0?ooo`030000003oool000000080000000D0oooo00000000000000000?oo
o`03000000050?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo00<0
000000H0oooo00000000000000000?ooo`0000050?ooobX0dLfY:03oool200000080oooo0`000002
0?ooo`030000003oool0oooo00@0oooo0P0000020?ooo`030000003oool0oooo0080oooo0P000005
0?ooo`<000001@3ooolZ0=7=Z@L0oooo00D000000?ooo`3oool0oooo0000000j0?ooo`050000003o
ool0oooo0?ooo`0000001@3ooolZ0=7=Z@L0oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000020?ooo`0U0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
00D0oooo7@3AcJT001/0dLfY:03oool2000000050?ooo`00000000000000003oool00`0000001@3o
ool00000000000000000oooo00<0000000D0oooo00000000000000000?ooo`03000000050?ooo`00
000000000000003oool00`0000060?ooobX0dLfY:03oool010000000oooo0?ooo`3oool2000000<0
oooo200000030?ooo`H000001P3oool2000000H0oooo:P3AcJT80?ooo`030000003oool0000003`0
oooo00<000000?ooo`0000001P3ooolZ0=7=Z@P0oooo00X000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0P0000009@3oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00P0000003P3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000001P3ooolM
0=7=Z@006`3AcJTX0?ooo`<0000000D0oooo00000000000000000?ooo`03000000050?ooo`000000
00000000003oool00`0000001@3oool00000000000000000oooo00<0000000H0oooo000000000000
00000?ooo`0000070?ooobX0dLfY:03oool5000000@0oooo00L000000?ooo`00000000000?ooo`00
0000oooo00D0000000@0oooo000000000000oooo200000070?ooobX0dLfY2@3oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo00D0oooo:P3AcJT90?ooo`090000003oool000000?ooo`00
0000oooo0000003oool000000080oooo02D000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo
00d000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0000000L0oooo
7@3AcJT001/0dLfY:03oool4000000050?ooo`00000000000000003oool00`0000001@3oool00000
000000000000oooo00<0000000D0oooo00000000000000000?ooo`03000000040?ooo`0000000000
000000P0oooo:P3AcJTX0?ooo`040000003oool00000000000D0oooo0`0000020?ooo`<0000000<0
oooo0000000000000P3oool00`000000oooo0?ooo`02000000030?ooo`000000oooo00800000203o
oolZ0=7=Z@X0oooo01`000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0P000000803oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool00000203ooolZ0=7=Z@X0oooo00P000000?ooo`000000oooo0000003o
ool000000?ooo`80000002D0oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000`0oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`0000080?oooad0dLfY000K0=7=ZBP0
oooo00<000000?ooo`0000000P0000001@3oool00000000000000000oooo00<0000000D0oooo0000
0000000000000?ooo`03000000050?ooo`00000000000000003oool00`0000000`3oool000000?oo
o`080?ooobX0dLfY:03oool3000000H0oooo0P0000030?ooo`030000003oool00000008000000`3o
ool400000080oooo0`0000090?ooobX0dLfY2`3oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00002@3ooolZ0=7=Z@/0oooo00L000000?ooo`000000oooo0000003oool000000080oooo02D00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000080oooo00/000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo000000090?oooad0dLfY000K0=7=ZBP0oooo0P0000001@3oool0000000000000
0000oooo00<0000000D0oooo00000000000000000?ooo`03000000050?ooo`00000000000000003o
ool00`000000103oool0000000000000000:0?ooobX0dLfY:03oool00`000000oooo000000070000
00@0oooo0`0000000`3oool0000000000003000000030?ooo`000000oooo0080oooo0P00000:0?oo
obX0dLfY303oool00`000000oooo000000050?ooo`030000003oool0000000D0oooo00<000000?oo
o`0000001@3oool00`000000oooo000000040?ooo`030000003oool0000000D0oooo00<000000?oo
o`0000001@3oool00`000000oooo000000050?ooo`030000003oool0000000X0oooo:P3AcJT<0?oo
o`060000003oool000000?ooo`000000oooo0P0000009@3oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool00P0000002P3oool000000?ooo`000000oooo0000003oool000000?ooo`00000:0?oooad0dLfY
000K0=7=ZBP0oooo0`0000001@3oool00000000000000000oooo00<0000000D0oooo000000000000
00000?ooo`03000000050?ooo`00000000000000003oool00`0000000`3oool000000?ooo`0:0?oo
obX0dLfY:03oool3000000030?ooo`000000oooo0080000000<0oooo000000000000100000001@3o
ool00000000000000000oooo008000000P3oool5000000/0oooo:P3AcJT=0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool02@3ooolZ0=7=Z@d0oooo00D000000?ooo`000000oooo0000
00020?ooo`0U0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`090000003oool000000?oo
o`000000oooo0000003oool0000000/0oooo7@3AcJT001/0dLfY:03oool4000000050?ooo`000000
00000000003oool00`0000001@3oool00000000000000000oooo00<0000000D0oooo000000000000
00000?ooo`03000000`0oooo:P3AcJTX0?ooo`8000000P3oool300000080oooo00D000000?ooo`00
000000000?ooo`03000000040?ooo`0000000000000000<0oooo00@000000?ooo`0000000000303o
oolZ0=7=Z@h0oooo00L000000?ooo`000000oooo0000003oool0000000T0oooo00L000000?ooo`00
0000oooo0000003oool0000000P0oooo00L000000?ooo`000000oooo0000003oool0000000T0oooo
00L000000?ooo`000000oooo0000003oool0000000`0oooo:P3AcJT>0?ooo`040000003oool00000
0?ooo`80000002D0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0080000000P0oooo0000003oool0
00000?ooo`000000oooo000000`0oooo7@3AcJT001/0dLfY:03oool00`000000oooo000000020000
00050?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo00<0000000H0
oooo00000000000000000?ooo`00000=0?ooobX0dLfY:03oool010000000oooo0?ooo`3oool20000
00<0oooo0`0000020?ooo`8000000P3oool2000000@0oooo0`00000=0?ooobX0dLfY3`3oool01@00
0000oooo0?ooo`3oool0000000/0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`050000003o
ool0oooo0?ooo`0000002`3oool01@000000oooo0?ooo`3oool0000000d0oooo:P3AcJT?0?ooo`03
0000003oool000000080oooo02D000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000080oooo00L00000
0?ooo`000000oooo0000003oool0000000d0oooo7@3AcJT001/0dLfY:03oool2000000050?ooo`00
000000000000003oool00`0000001@3oool00000000000000000oooo00<0000000D0oooo00000000
000000000?ooo`03000000h0oooo:P3AcJTX0?ooo`D00000103oool00`000000oooo000000030000
00<0oooo00<000000?ooo`3oool00`3oool2000000h0oooo:P3AcJT@0?ooo`030000003oool00000
00d0oooo00<000000?ooo`000000303oool00`000000oooo0000000=0?ooo`030000003oool00000
00h0oooo:P3AcJT@0?ooo`0Y0000003oool000000000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool00P0000001P3oool000000?ooo`000000oooo000000h0oooo7@3AcJT001/0dLfY:03oool30000
00050?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo00<0000000H0
oooo00000000000000000?ooo`00000?0?ooobX0dLfY:03oool010000000oooo0000000000050?oo
o`<0000000<0oooo0000003oool00`3oool7000000l0oooo:P3AcJTA0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00d0oooo:P3AcJTA0?ooo`0X0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080
oooo00D000000?ooo`000000oooo0000000?0?oooad0dLfY000K0=7=ZBP0oooo100000001@3oool0
0000000000000000oooo00<0000000D0oooo00000000000000000?ooo`03000000040?ooo`000000
000000000100oooo:P3AcJTX0?ooo`<000001P3oool200000080oooo1P0000000`3oool000000?oo
o`0200000100oooo:P3AcJTB0?ooo`0?0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000100oooo00l000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000403ooolZ0=7=ZA80oooo0P0000009@3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool00P000000103oool000000?ooo`00000@0?oooad0dLfY000K
0=7=ZBP0oooo00<000000?ooo`0000000P0000001@3oool00000000000000000oooo00<0000000D0
oooo00000000000000000?ooo`03000000030?ooo`000000oooo0100oooo:P3AcJTX0?ooo`030000
003oool0000000L000000`3oool2000000030?ooo`00000000000080oooo0`00000A0?ooobX0dLfY
4`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000000B0?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000140oooo:P3A
cJTD0?ooo`0U0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool000000140
oooo7@3AcJT001/0dLfY:03oool2000000050?ooo`00000000000000003oool00`0000001@3oool0
0000000000000000oooo00<0000000@0oooo00000000000000004P3ooolZ0=7=ZBP0oooo0`000000
1P3oool000000000003oool000000?ooo`D000000P3oool010000000oooo0?ooo`3oool200000180
oooo:P3AcJTD0?ooo`030000003oool0000000D0oooo00<000000?ooo`000000503oool00`000000
oooo000000050?ooo`030000003oool000000180oooo:P3AcJTC0?ooo`0V0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool2000000030?ooo`000000oooo0140oooo7@3AcJT001/0dLfY:03oool3
000000050?ooo`00000000000000003oool00`0000001@3oool00000000000000000oooo00<00000
00<0oooo0000003oool04P3ooolZ0=7=ZBP0oooo0P0000020?ooo`030000003oool0oooo00<00000
00<0oooo0000000000000`3oool5000001<0oooo:P3AcJTE0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo
:P3AcJTD0?ooo`0U0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo
0140oooo7@3AcJT001/0dLfY:03oool4000000050?ooo`00000000000000003oool00`0000001@3o
ool00000000000000000oooo00<00000503ooolZ0=7=ZBP0oooo00@000000?ooo`3oool0oooo1000
0000103oool000000000000000040?ooo`040000003oool00000000001@0oooo:P3AcJTF0?ooo`07
0000003oool000000?ooo`000000oooo0000000H0?ooo`070000003oool000000?ooo`000000oooo
0000000D0?ooobX0dLfY5@3oool090000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`800000503ooolM0=7=
Z@006`3AcJTX0?ooo`030000003oool000000080000000D0oooo00000000000000000?ooo`030000
00060?ooo`00000000000000003oool000005@3ooolZ0=7=ZBP0oooo1@000000103oool000000?oo
o`3oool2000000D0oooo0`00000E0?ooobX0dLfY5`3oool01@000000oooo0?ooo`3oool0000001X0
oooo00D000000?ooo`3oool0oooo0000000E0?ooobX0dLfY5P3oool08`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000001H0oooo7@3AcJT001/0dLfY:03oool2000000050?ooo`00000000000000003oool00`000000
1@3oool00000000000000000oooo00<000005P3ooolZ0=7=ZBP0oooo00@000000?ooo`0000000000
0P3oool4000000H0oooo0P00000F0?ooobX0dLfY603oool00`000000oooo0000000L0?ooo`030000
003oool0000001H0oooo:P3AcJTG0?ooo`0S0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000005@3ooolM0=7=Z@00
6`3AcJTX0?ooo`<0000000D0oooo00000000000000000?ooo`03000000060?ooo`00000000000000
003oool000005`3ooolZ0=7=ZBP0oooo0`0000030?ooo`80000000<0oooo0000000000001P00000G
0?ooobX0dLfY6@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01D0oooo:P3AcJTH
0?ooo`0Q0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool0000001H0oooo7@3AcJT001/0dLfY:03oool4000000050?ooo`0000000000
0000003oool00`000000103oool0000000000000000H0?ooobX0dLfY:03oool00`000000oooo0000
000400000080oooo0P0000000`3oool000000?ooo`02000001P0oooo:P3AcJTJ0?ooo`0<0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0P000000403oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00000H0?ooobX0
dLfY6@3oool07`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000005`3ooolM0=7=Z@006`3AcJTX0?ooo`030000003oool000000080000000D0
oooo00000000000000000?ooo`03000000030?ooo`000000oooo01P0oooo:P3AcJTX0?ooo`<00000
00<0oooo0000003oool0100000020?ooo`<000006@3ooolZ0=7=ZA/0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000006@3ooolZ0=7=ZAX0oooo01d000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000000H0?oooad0dLfY000K0=7=ZBP0oooo
0P0000001@3oool00000000000000000oooo00<0000000@0oooo00000000000000006P3ooolZ0=7=
ZBP0oooo0P0000020?ooo`<0000000<0oooo0000003oool00P3oool2000001X0oooo:P3AcJTL0?oo
o`030000003oool0000000D0oooo00<000000?ooo`000000103oool00`000000oooo000000050?oo
o`030000003oool0000001X0oooo:P3AcJTK0?ooo`0K0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool0000001T0oooo7@3AcJT001/0dLfY:03oool3000000050?ooo`000000
00000000003oool00`0000000`3oool000000?ooo`0J0?ooobX0dLfY:03oool010000000oooo0?oo
o`3oool200000080oooo1@00000K0?ooobX0dLfY7@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooobX0dLfY
703oool06@000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000006P3ooolM0=7=Z@00
6`3AcJTX0?ooo`@0000000D0oooo00000000000000000?ooo`03000001`0oooo:P3AcJTX0?ooo`D0
00000`3oool010000000oooo00000000000L0?ooobX0dLfY7P3oool01`000000oooo0000003oool0
00000?ooo`000000203oool01`000000oooo0000003oool000000?ooo`000000703ooolZ0=7=ZAd0
oooo01L000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000000K0?oooad0dLfY000K0=7=ZBP0oooo
00<000000?ooo`0000000P0000001P3oool00000000000000000oooo000001d0oooo:P3AcJTX0?oo
o`040000003oool00000000000@0oooo0`00000M0?ooobX0dLfY7`3oool01@000000oooo0?ooo`3o
ool0000000X0oooo00D000000?ooo`3oool0oooo0000000M0?ooobX0dLfY7P3oool05@000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000000L0?oooad0dLfY000K0=7=ZBP0oooo0P0000001@3oool0000000000000
0000oooo00<000007P3ooolZ0=7=ZBP0oooo0`0000050?ooo`8000007P3ooolZ0=7=ZB00oooo00<0
00000?ooo`000000303oool00`000000oooo0000000N0?ooobX0dLfY7`3oool04`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000007@3ooolM0=7=Z@006`3AcJTX0?ooo`<0000000H0oooo00000000000000000?ooo`00000O
0?ooobX0dLfY:03oool00`000000oooo00000006000001l0oooo:P3AcJTQ0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool07@3ooolZ0=7=ZB00oooo014000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000000N0?oooad0dLfY
000K0=7=ZBP0oooo10000000103oool0000000000000000P0?ooobX0dLfY:03oool3000000030?oo
o`000000oooo00800000803ooolZ0=7=ZB80oooo00@000000?ooo`000000oooo0P000000203oool0
00000?ooo`000000oooo0000003oool00000803ooolZ0=7=ZB40oooo00l000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000007`3ooolM0=7=Z@006`3A
cJTX0?ooo`030000003oool000000080000000<0oooo0000003oool0803ooolZ0=7=ZBP0oooo0P00
00020?ooo`<000008@3ooolZ0=7=ZB<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?oo
o`3oool000000240oooo:P3AcJTR0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000000P0?oooad0dLfY000K0=7=ZBP0oooo0P000000103oool000000000
0000000R0?ooobX0dLfY:03oool010000000oooo0?ooo`3oool200000280oooo:P3AcJTT0?ooo`03
0000003oool0000000@0oooo00<000000?ooo`0000008P3ooolZ0=7=ZB<0oooo00/000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000000Q0?oooad0dLfY000K0=7=ZBP0oooo0`00
00000`3oool000000?ooo`0R0?ooobX0dLfY:03oool5000002<0oooo:P3AcJTU0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool08@3ooolZ0=7=ZB@0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000008P3ooolM0=7=Z@006`3AcJTX0?ooo`@00000903ooolZ0=7=ZBP0
oooo00@000000?ooo`0000000000903ooolZ0=7=ZBH0oooo0P000000103oool000000?ooo`00000T
0?ooobX0dLfY9@3oool01`000000oooo0000003oool000000?ooo`0000008`3ooolM0=7=Z@006`3A
cJTX0?ooo`030000003oool0000002D0oooo:P3AcJTX0?ooo`<000009@3ooolZ0=7=ZBX0oooo00<0
00000?ooo`3oool08`3ooolZ0=7=ZBH0oooo00D000000?ooo`000000oooo0000000T0?oooad0dLfY
000K0=7=ZBP0oooo0P00000V0?ooobX0dLfY:03oool2000002H0oooo:P3AcJTW0?ooo`030000003o
ool0000002H0oooo:P3AcJTW0?ooo`030000003oool0000002D0oooo7@3AcJT001/0dLfY:03oool0
0`000000oooo0?ooo`0U0?ooobX0dLfY:03oool00`000000oooo0?ooo`0U0?ooobX0dLfY:03oool0
0`000000oooo0?ooo`0U0?ooobX0dLfY:03oool00`000000oooo0?ooo`0T0?oooad0dLfY003o0=7=
ZOH0dLfY003o0=7=ZOH0dLfY003o0=7=ZOH0dLfY003o0=7=ZOH0dLfY003o0=7=ZOH0dLfY000n0=7=
Z@=000000`3AcJT5@00006l0dLfY0d0000030=7=Z@A00000LP3AcJT014000000dLfY0=7=Z@3AcJT4
@0000780dLfY00A000000=7=Z@3AcJT0dLfY0d0000100=7=Z@00?P3AcJT014000000dLfY0=7=ZD00
00040=7=Z@03@000003AcJT0dLfY06l0dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY
0=7=Z@1c0=7=Z@05@000003AcJT0dLfY0=7=ZD000000M@3AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00=000000=7=Z@3AcJT0?@3AcJT003h0dLfY00A000000=7=Z@3AcJU00000103AcJT00d00
0000dLfY0=7=Z@1_0=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT0LP3AcJT0
0d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0780dLfY00E000000=7=Z@3AcJT0dLfY@000
00020=7=Z@03@000003AcJT0dLfY03d0dLfY000n0=7=Z@=000001@3AcJT00d000000dLfY0=7=Z@1_
0=7=Z@=000001@3AcJT00d000000dLfY0=7=Z@1b0=7=Z@03@000003AcJT0dLfY0080dLfY00=00000
0=7=Z@3AcJT0LP3AcJT00d000000dLfY0=7=Z@03@0000400dLfY000o0=7=Z@03@000003AcJT0dLfY
00@0dLfY00=000000=7=Z@3AcJT0L03AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY
@0000700dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00001`0=7=Z@04@000
003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT0?`3AcJT003l0dLfY0d0000030=7=Z@900000
LP3AcJT3@00000<0dLfY0T00001a0=7=Z@A000000`3AcJT2@0000740dLfY140000030=7=Z@=00000
?`3AcJT00?l0dLfYmP3AcJT00?l0dLfYmP3AcJT00?l0dLfYmP3AcJT00?l0dLfYmP3AcJT00?l0dLfY
mP3AcJT00?l0dLfYmP3AcJT00?l0dLfYmP3AcJT00?l0dLfYmP3AcJT00?l0dLfYmP3AcJT001/0dLfY
:03oool09P000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0P00000Z0=7=ZBP0oooo02H00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`800000:P3AcJTX0?ooobP00000:P3AcJTX0?ooo`P0
00005`3oool8000001d0dLfY000K0=7=ZBP0oooo02P000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo:P3AcJTX0?ooo`0T0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0`0000000`3oool0
dLfY0=7=Z@0X0=7=ZBP0oooo9`0000000`3oool0dLfY0=7=Z@0X0=7=ZBP0oooo00L000000?ooo`00
0000oooo0000003oool0000001P0oooo00P000000?ooo`000000oooo0000003oool000000?oooad0
dLfY000K0=7=ZBP0oooo02@000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool200000080oooo:P3AcJTX0?oo
o`0T0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0P0000020?ooobX0dLfY:03ooolV00000080oooo:P3A
cJTX0?ooo`8000000P3oool2000001T0oooo0P0000020?ooo`8000000P3ooolM0=7=Z@006`3AcJTX
0?ooo`0U0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000030?ooobX0dLfY:03oool08P000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool3000000<0oooo:P3AcJTX0?ooobD000000`3ooolZ0=7=ZBP0oooo00D000000?ooo`3o
ool0oooo0000000J0?ooo`050000003oool0oooo0?ooo`0000000`3ooolM0=7=Z@006`3AcJTX0?oo
o`0R0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`800000103ooolZ0=7=ZBP0oooo028000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0P00
00040?ooobX0dLfY:03ooolT000000@0oooo:P3AcJTX0?ooo`@000006`3oool4000000@0oooo7@3A
cJT001/0dLfY:03oool08`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool0000000D0oooo:P3AcJTX0?ooo`0P0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool3000000D0oooo:P3AcJTX0?ooob<000001@3ooolZ0=7=ZBP0oooo00<000000?ooo`000000703o
ool00`000000oooo000000050?oooad0dLfY000K0=7=ZBP0oooo020000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`8000001P3ooolZ
0=7=ZBP0oooo020000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`8000001P3ooolZ0=7=ZBP0oooo8P0000060?ooobX0dLfY:03oool2
000001d0oooo0P0000060?oooad0dLfY000K0=7=ZBP0oooo024000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000001`3ooolZ0=7=
ZBP0oooo01h000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool3000000L0oooo:P3AcJTX0?ooob4000001`3ooolZ0=7=ZBP0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`050?oooad0dLfY000K0=7=ZBP0oooo01h000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool2000000P0oooo:P3A
cJTX0?ooo`0N0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0P0000080?ooobX0dLfY:03ooolP000000P0oooo:P3AcJTX0?oooal00000203ooolM
0=7=Z@006`3AcJTX0?ooo`0O0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000090?ooobX0dLfY:03oool070000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool3000000T0oooo:P3AcJTX0?oooal000002@3o
oolZ0=7=ZBP0oooo014000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo000000020?ooo`0;0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`0000002@3ooolM0=7=Z@006`3AcJTX0?ooo`0L0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`8000002P3ooolZ0=7=ZBP0oooo01`000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0P00000:0?ooobX0dLfY
:03ooolN000000X0oooo:P3AcJTX0?ooo`8000000P3oool200000080oooo0P0000020?ooo`800000
0P3oool2000000030?ooo`00000000000080oooo0P0000020?ooo`8000002P3ooolM0=7=Z@006`3A
cJTX0?ooo`0M0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000002`3ooolZ0=7=ZBP0oooo01X000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`<000002`3ooolZ0=7=ZBP0oooo7@00000;0?ooobX0dLfY:03oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo0000
00<0oooo00D000000?ooo`3oool0oooo0000000;0?oooad0dLfY000K0=7=ZBP0oooo01X000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`800000303ooolZ0=7=ZBP0oooo01X0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`800000303ooolZ0=7=ZBP0
oooo7000000<0?ooobX0dLfY:03oool4000000@0oooo100000040?ooo`<00000103oool4000000`0
oooo7@3AcJT001/0dLfY:03oool06`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000000=0?ooobX0dLfY:03oool060000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`<000003@3ooolZ0=7=ZBP0oooo6`00000=0?ooobX0dLfY:03oool00`000000oooo00000005
0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000=
0?oooad0dLfY000K0=7=ZBP0oooo01P000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool2
000000h0oooo:P3AcJTX0?ooo`0H0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0P00
000>0?ooobX0dLfY:03ooolJ000000h0oooo:P3AcJTX0?ooo`8000001P3oool2000000H0oooo0P00
00050?ooo`8000003P3ooolM0=7=Z@006`3AcJTX0?ooo`0I0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000000?0?ooobX0dLfY:03oool05P000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool3000000l0oooo:P3AcJTX0?oooaT000003`3ooolZ0=7=ZBP0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3o
oolM0=7=Z@006`3AcJTX0?ooo`0F0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`800000403ooolZ
0=7=ZBP0oooo01H000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo0P00000@0?ooobX0dLfY:03ooolH
00000100oooo:P3AcJTX0?ooo`P00000203oool700000100oooo7@3AcJT001/0dLfY:03oool05`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000140oooo:P3AcJTX0?ooo`0D0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool300000140oooo:P3AcJTX0?oooaL000004@3ooolZ0=7=ZBP0oooo00L000000?ooo`00
0000oooo0000003oool0000000T0oooo00H000000?ooo`3oool000000?ooo`00000A0?oooad0dLfY
000K0=7=ZBP0oooo01@000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`8000004P3ooolZ0=7=ZBP0oooo01@00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`8000004P3ooolZ0=7=ZBP0oooo5P00000B0?ooobX0dLfY:03oool20000
0080oooo0P00000:0?ooo`80000000<0oooo0000000000004P3ooolM0=7=Z@006`3AcJTX0?ooo`0E
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool0000001<0oooo:P3AcJTX0?ooo`0B0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0`00000C
0?ooobX0dLfY:03ooolE000001<0oooo:P3AcJTX0?ooo`050000003oool0oooo0?ooo`0000002`3o
ool010000000oooo0?ooo`00000C0?oooad0dLfY000K0=7=ZBP0oooo018000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool20000
01@0oooo:P3AcJTX0?ooo`0B0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0P00000D0?ooobX0dLfY:03ooolD000001@0oooo
:P3AcJTX0?ooo`@00000303oool3000001@0oooo7@3AcJT001/0dLfY:03oool04`000000oooo0000
003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`0000005@3ooolZ0=7=ZBP0oooo010000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000003oool000000?ooo`000000oooo0`00000E0?ooobX0dLfY:03ooolC000001D0oooo:P3A
cJTX0?ooo`030000003oool0000000d0oooo00<000000?ooo`3oool0503ooolM0=7=Z@006`3AcJTX
0?ooo`0@0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`8000005P3ooolZ0=7=ZBP0oooo010000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0P00000F0?ooobX0dLfY:03ooolB0000
01H0oooo:P3AcJTX0?ooo`8000003P3oool2000001D0oooo7@3AcJT001/0dLfY:03oool04@000000
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
000001L0oooo:P3AcJTX0?ooo`0>0000003oool000000?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool3000001L0oooo:P3AcJTX0?oooa4000005`3ooolZ0=7=ZBP0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0D0?oooad0dLfY000K0=7=ZBP0oooo00h00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`800000603o
oolZ0=7=ZBP0oooo00h000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003o
ool000000?ooo`800000603ooolZ0=7=ZBP0oooo4000000H0?ooobX0dLfY:03oool@000001L0oooo
7@3AcJT001/0dLfY:03oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo0000000I0?ooobX0dLfY:03oool030000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000?ooo`<000006@3ooolZ0=7=ZBP0oooo3`00000I0?ooobX0dLfY
:03oool03`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000
oooo0000000H0?oooad0dLfY000K0=7=ZBP0oooo00`000000?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0000003oool2000001X0oooo:P3AcJTX0?ooo`0<0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo0P00000J0?ooobX0dLfY:03oool>000001X0oooo
:P3AcJTX0?ooo`8000000P3oool200000080oooo0P0000020?ooo`8000006@3ooolM0=7=Z@006`3A
cJTX0?ooo`0=0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
000K0?ooobX0dLfY:03oool02P000000oooo0000003oool000000?ooo`000000oooo0000003oool3
000001/0oooo:P3AcJTX0?ooo`d000006`3ooolZ0=7=ZBP0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000006P3ooolM0=7=Z@006`3AcJTX0?ooo`0:0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`800000703ooolZ0=7=ZBP0oooo00X00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo0P00000L0?ooobX0dLfY:03oool<0000
01`0oooo:P3AcJTX0?ooo`@00000103oool4000001/0oooo7@3AcJT001/0dLfY:03oool02`000000
oooo0000003oool000000?ooo`000000oooo0000003oool0000001d0oooo:P3AcJTX0?ooo`080000
003oool000000?ooo`000000oooo0000003oool3000001d0oooo:P3AcJTX0?ooo`/000007@3ooolZ
0=7=ZBP0oooo00<000000?ooo`0000001@3oool00`000000oooo0000000L0?oooad0dLfY000K0=7=
ZBP0oooo00P000000?ooo`000000oooo0000003oool000000?ooo`8000007P3ooolZ0=7=ZBP0oooo
00P000000?ooo`000000oooo0000003oool000000?ooo`8000007P3ooolZ0=7=ZBP0oooo2P00000N
0?ooobX0dLfY:03oool2000000H0oooo0P00000M0?oooad0dLfY000K0=7=ZBP0oooo00T000000?oo
o`000000oooo0000003oool000000?ooo`0000007`3ooolZ0=7=ZBP0oooo00H000000?ooo`000000
oooo0000003oool3000001l0oooo:P3AcJTX0?ooo`T000007`3ooolZ0=7=ZBP0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0L0?oooad0dLfY000K0=7=ZBP0oooo00H000000?ooo`00
0000oooo0000003oool200000200oooo:P3AcJTX0?ooo`060000003oool000000?ooo`000000oooo
0P00000P0?ooobX0dLfY:03oool800000200oooo:P3AcJTX0?ooo`P000007`3ooolM0=7=Z@006`3A
cJTX0?ooo`070000003oool000000?ooo`000000oooo0000000Q0?ooobX0dLfY:03oool010000000
oooo0000003oool300000240oooo:P3AcJTX0?ooo`L000008@3ooolZ0=7=ZBP0oooo00L000000?oo
o`000000oooo0000003oool000000200oooo7@3AcJT001/0dLfY:03oool010000000oooo0000003o
ool200000280oooo:P3AcJTX0?ooo`040000003oool000000?ooo`8000008P3ooolZ0=7=ZBP0oooo
1P00000R0?ooobX0dLfY:03oool200000080oooo0P00000Q0?oooad0dLfY000K0=7=ZBP0oooo00D0
00000?ooo`000000oooo0000000S0?ooobX0dLfY:03oool00`000000oooo00000002000002<0oooo
:P3AcJTX0?ooo`D000008`3ooolZ0=7=ZBP0oooo00D000000?ooo`3oool0oooo0000000R0?oooad0
dLfY000K0=7=ZBP0oooo00@000000?ooo`0000000000903ooolZ0=7=ZBP0oooo00@000000?ooo`00
00000000903ooolZ0=7=ZBP0oooo1000000T0?ooobX0dLfY:03oool4000002<0oooo7@3AcJT001/0
dLfY:03oool00`000000oooo0000000U0?ooobX0dLfY:03oool3000002D0oooo:P3AcJTX0?ooo`<0
00009@3ooolZ0=7=ZBP0oooo00<000000?ooo`000000903ooolM0=7=Z@006`3AcJTX0?ooo`800000
9P3ooolZ0=7=ZBP0oooo0P00000V0?ooobX0dLfY:03oool2000002H0oooo:P3AcJTX0?ooo`800000
9@3ooolM0=7=Z@006`3AcJTX0?ooo`030000003oool0oooo02D0oooo:P3AcJTX0?ooo`030000003o
ool0oooo02D0oooo:P3AcJTX0?ooo`030000003oool0oooo02D0oooo:P3AcJTX0?ooo`030000003o
ool0oooo02@0oooo7@3AcJT00?l0dLfYmP3AcJT00?l0dLfYmP3AcJT00?l0dLfYmP3AcJT00?l0dLfY
mP3AcJT00?l0dLfYmP3AcJT003l0dLfY0T0000030=7=Z@=00000LP3AcJT2@00000@0dLfY0T00001b
0=7=Z@9000000`3AcJT3@0000740dLfY0d0000040=7=Z@900000@03AcJT003h0dLfY00A000000=7=
Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00001`0=7=Z@04@000003AcJT0dLfY@0000080dLfY
00A000000=7=Z@3AcJU00000L03AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY
06l0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000o0=7=Z@00@@3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0740dLfY00A000000=7=Z@3AcJU00000
0P3AcJT00d000000dLfY0=7=Z@1a0=7=Z@04@000003AcJT0dLfY0=7=Z@=00000L03AcJT014000000
dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00003l0dLfY000o0=7=Z@9000000`3AcJT3@000
0780dLfY0T0000040=7=Z@900000LP3AcJT2@00000<0dLfY00A000000=7=Z@3AcJU00000L03AcJT3
@00000<0dLfY00A000000=7=Z@3AcJU00000?`3AcJT003l0dLfY00=000000=7=Z@3AcJT00`3AcJT0
0d000000dLfY0=7=Z@1a0=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU00000L@3A
cJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@0000740dLfY00=000000=7=Z@3AcJT0
0P3AcJT014000000dLfY0=7=ZD00000o0=7=Z@00?`3AcJT3@00000<0dLfY0d00001a0=7=Z@=00000
0`3AcJT2@0000780dLfY0d0000030=7=Z@=00000L@3AcJT3@00000<0dLfY0T0000100=7=Z@00o`3A
cJWf0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf0=7=Z@00o`3A
cJWf0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf0=7=Z@00o`3AcJWf0=7=Z@006`3A
cJU?0?ooo`030000003AcJT0dLfY02P0dLfY:03oool00`000000oooo0?ooo`0U0?ooobX0dLfYCP3o
ool2000002X0dLfYC@3oool2000001d0dLfY000K0=7=ZDh0oooo00<000000?ooo`3AcJT0:@3AcJTX
0?ooo`030000003oool0oooo02D0oooo:P3AcJU>0?ooo`030000003oool0dLfY02T0dLfYC03oool2
000000030?ooo`3AcJT0dLfY01/0dLfY000K0=7=ZDd0oooo00<000000?ooo`3oool0:P3AcJTX0?oo
o`030000003oool0oooo02D0oooo:P3AcJU<0?ooo`8000000P3ooolZ0=7=ZD/0oooo0P0000020?oo
oad0dLfY000K0=7=ZD`0oooo00@000000?ooo`3oool0oooo:P3AcJTX0?ooo`030000003oool0oooo
02D0oooo:P3AcJU<0?ooo`040000003oool0oooo0?ooobX0dLfYBP3oool2000000<0oooo7@3AcJT0
01/0dLfYB`3oool00`000000oooo0?ooo`020?ooobX0dLfY:03oool00`000000oooo0?ooo`0U0?oo
obX0dLfYBP3oool2000000@0oooo:P3AcJU90?ooo`800000103ooolM0=7=Z@006`3AcJU:0?ooo`03
0000003oool0oooo00<0oooo:P3AcJTX0?ooo`030000003oool0oooo02D0oooo:P3AcJU:0?ooo`03
0000003oool0oooo00<0oooo:P3AcJU80?ooo`8000001@3ooolM0=7=Z@006`3AcJU90?ooo`030000
003oool0oooo00@0oooo:P3AcJTX0?ooo`030000003oool0oooo02D0oooo:P3AcJU80?ooo`800000
1P3ooolZ0=7=ZDL0oooo0P0000060?oooad0dLfY000K0=7=ZDP0oooo00<000000?ooo`3oool01@3o
oolZ0=7=ZBP0oooo00<000000?ooo`3oool09@3ooolZ0=7=ZDP0oooo00<000000?ooo`3oool01@3o
oolZ0=7=ZDH0oooo0P0000070?oooad0dLfY000K0=7=ZDL0oooo00<000000?ooo`3oool01P3ooolZ
0=7=ZBP0oooo00<000000?ooo`3oool09@3ooolZ0=7=ZDH0oooo0P0000080?ooobX0dLfYA@3oool2
000000P0oooo7@3AcJT001/0dLfYAP3oool00`000000oooo0?ooo`070?ooobX0dLfY:03oool00`00
0000oooo0?ooo`0U0?ooobX0dLfYAP3oool00`000000oooo0?ooo`070?ooobX0dLfYA03oool20000
00T0oooo7@3AcJT001/0dLfYA@3oool00`000000oooo0?ooo`080?ooobX0dLfY:03oool00`000000
oooo0?ooo`0U0?ooobX0dLfYA03oool2000000X0oooo:P3AcJU30?ooo`8000002P3ooolM0=7=Z@00
6`3AcJU40?ooo`030000003oool0oooo00T0oooo:P3AcJTX0?ooo`030000003oool0oooo02D0oooo
:P3AcJU40?ooo`030000003oool0oooo00T0oooo:P3AcJU20?ooo`8000002`3ooolM0=7=Z@006`3A
cJU30?ooo`030000003oool0oooo00X0oooo:P3AcJTX0?ooo`030000003oool0oooo02D0oooo:P3A
cJU20?ooo`800000303ooolZ0=7=ZD40oooo0P00000<0?oooad0dLfY000K0=7=ZD80oooo00<00000
0?ooo`3oool02`3ooolZ0=7=ZBP0oooo00<000000?ooo`3oool09@3ooolZ0=7=ZD80oooo00<00000
0?ooo`3oool02`3ooolZ0=7=ZD00oooo0P00000=0?oooad0dLfY000K0=7=ZD40oooo00<000000?oo
o`3oool0303ooolZ0=7=ZBP0oooo00<000000?ooo`3oool09@3ooolZ0=7=ZD00oooo0P00000>0?oo
obX0dLfY?`3oool2000000h0oooo7@3AcJT001/0dLfY@03oool00`000000oooo0?ooo`0=0?ooobX0
dLfY:03oool00`000000oooo0?ooo`0U0?ooobX0dLfY@03oool00`000000oooo0?ooo`0=0?ooobX0
dLfY?P3oool2000000l0oooo7@3AcJT001/0dLfY?`3oool00`000000oooo0?ooo`0>0?ooobX0dLfY
:03oool00`000000oooo0?ooo`0U0?ooobX0dLfY?P3oool200000100oooo:P3AcJTm0?ooo`800000
403ooolM0=7=Z@006`3AcJTn0?ooo`030000003oool0oooo00l0oooo:P3AcJTX0?ooo`030000003o
ool0oooo02D0oooo:P3AcJTn0?ooo`030000003oool0oooo00l0oooo:P3AcJTl0?ooo`8000004@3o
oolM0=7=Z@006`3AcJTm0?ooo`030000003oool0oooo0100oooo:P3AcJTX0?ooo`030000003oool0
oooo02D0oooo:P3AcJTl0?ooo`8000004P3ooolZ0=7=ZC/0oooo0P00000B0?oooad0dLfY000K0=7=
ZC`0oooo00<000000?ooo`3oool04@3ooolZ0=7=ZBP0oooo00<000000?ooo`3oool09@3ooolZ0=7=
ZC`0oooo00<000000?ooo`3oool04@3ooolZ0=7=ZCX0oooo0P00000C0?oooad0dLfY000K0=7=ZCX0
oooo00<000000?ooo`3oool04`3ooolZ0=7=ZBP0oooo00<000000?ooo`3oool09@3ooolZ0=7=ZCX0
oooo00<000000?ooo`3oool04`3ooolZ0=7=ZCT0oooo00<000000?ooo`3oool04`3ooolM0=7=Z@00
6`3AcJTi0?ooo`030000003oool0oooo01@0oooo:P3AcJTX0?ooo`030000003oool0oooo02D0oooo
:P3AcJTh0?ooo`8000005P3ooolZ0=7=ZCP0oooo0P00000E0?oooad0dLfY000K0=7=ZCP0oooo00<0
00000?ooo`3oool05@3ooolZ0=7=ZBP0oooo00<000000?ooo`3oool09@3ooolZ0=7=ZCP0oooo00<0
00000?ooo`3oool05@3ooolZ0=7=ZCL0oooo0P00000F0?oooad0dLfY000K0=7=ZCL0oooo00<00000
0?ooo`3oool05P3ooolZ0=7=ZBP0oooo00<000000?ooo`3oool09@3ooolZ0=7=ZCH0oooo0P00000H
0?ooobX0dLfY=P3oool2000001L0oooo7@3AcJT001/0dLfY=P3oool00`000000oooo0?ooo`0G0?oo
obX0dLfY:03oool00`000000oooo0?ooo`0U0?ooobX0dLfY=P3oool00`000000oooo0?ooo`0G0?oo
obX0dLfY=@3oool2000001P0oooo7@3AcJT001/0dLfY=@3oool00`000000oooo0?ooo`0H0?ooobX0
dLfY:03oool00`000000oooo0?ooo`0U0?ooobX0dLfY=03oool2000001X0oooo:P3AcJTd0?ooo`80
00006@3ooolM0=7=Z@006`3AcJTd0?ooo`030000003oool0oooo01T0oooo:P3AcJTX0?ooo`030000
003oool0oooo02D0oooo:P3AcJTd0?ooo`030000003oool0oooo01T0oooo:P3AcJTc0?ooo`800000
6P3ooolM0=7=Z@006`3AcJTc0?ooo`030000003oool0oooo01X0oooo:P3AcJTX0?ooo`030000003o
ool0oooo02D0oooo:P3AcJTb0?ooo`800000703ooolZ0=7=ZC80oooo0P00000K0?oooad0dLfY000K
0=7=ZC80oooo00<000000?ooo`3oool06`3ooolZ0=7=ZBP0oooo00<000000?ooo`3oool09@3ooolZ
0=7=ZC80oooo00<000000?ooo`3oool06`3ooolZ0=7=ZC40oooo0P00000L0?oooad0dLfY000K0=7=
ZC40oooo00<000000?ooo`3oool0703ooolZ0=7=ZBP0oooo00<000000?ooo`3oool09@3ooolZ0=7=
ZC00oooo0P00000N0?ooobX0dLfY<03oool2000001d0oooo7@3AcJT001/0dLfY<03oool00`000000
oooo0?ooo`0M0?ooobX0dLfY:03oool00`000000oooo0?ooo`0U0?ooobX0dLfY<03oool00`000000
oooo0?ooo`0M0?ooobX0dLfY;`3oool2000001h0oooo7@3AcJT001/0dLfY;`3oool00`000000oooo
0?ooo`0N0?ooobX0dLfY:03oool00`000000oooo0?ooo`0U0?ooobX0dLfY;P3oool200000200oooo
:P3AcJT^0?ooo`8000007`3ooolM0=7=Z@006`3AcJT^0?ooo`030000003oool0oooo01l0oooo:P3A
cJTX0?ooo`030000003oool0oooo02D0oooo:P3AcJT^0?ooo`030000003oool0oooo01l0oooo:P3A
cJT]0?ooo`800000803ooolM0=7=Z@006`3AcJT]0?ooo`030000003oool0oooo0200oooo:P3AcJTX
0?ooo`030000003oool0oooo02D0oooo:P3AcJT/0?ooo`8000008P3ooolZ0=7=ZB`0oooo0P00000Q
0?oooad0dLfY000K0=7=ZB`0oooo00<000000?ooo`3oool08@3ooolZ0=7=ZBP0oooo00<000000?oo
o`3oool09@3ooolZ0=7=ZB`0oooo00<000000?ooo`3oool08@3ooolZ0=7=ZB/0oooo0P00000R0?oo
oad0dLfY000K0=7=ZB/0oooo00<000000?ooo`3oool08P3ooolZ0=7=ZBP0oooo00<000000?ooo`3o
ool09@3ooolZ0=7=ZBX0oooo0P00000T0?ooobX0dLfY:P3oool2000002<0oooo7@3AcJT001/0dLfY
:P3oool00`000000oooo0?ooo`0S0?ooobX0dLfY:03oool00`000000oooo0?ooo`0U0?ooobX0dLfY
:P3oool00`000000oooo0?ooo`0S0?ooobX0dLfY:@3oool2000002@0oooo7@3AcJT001/0dLfY:@3o
ool00`000000oooo0?ooo`0T0?ooobX0dLfY:03oool00`000000oooo0?ooo`0U0?ooobX0dLfY:03o
ool2000002H0oooo:P3AcJTX0?ooo`8000009@3ooolM0=7=Z@006`3AcJTX0?ooo`030000003oool0
oooo02D0oooo:P3AcJTX0?ooo`030000003oool0oooo02D0oooo:P3AcJTX0?ooo`030000003oool0
oooo02D0oooo:P3AcJTX0?ooo`030000003oool0oooo02@0oooo7@3AcJT00?l0dLfYmP3AcJT00?l0
dLfYmP3AcJT00?l0dLfYmP3AcJT00?l0dLfYmP3AcJT00?l0dLfYmP3AcJT00?l0dLfYmP3AcJT00480
dLfY0T00001e0=7=Z@9000000`3AcJT4@0000780dLfY0d0000020=7=Z@900000L`3AcJT3@0000003
0=7=ZD000010000000900000?`3AcJT00440dLfY00A000000=7=Z@3AcJU00000L`3AcJT014000000
dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY07@0dLfY00A000000=7=Z@3AcJU000000P3AcJT0
0d000000dLfY0=7=Z@1a0=7=Z@04@000003AcJT0dLfY@0000480dLfY00110=7=Z@04@000003AcJT0
dLfY@00007D0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@1`0=7=Z@E0000000D0
dLfY@000003AcJT0dLfY@000001`0=7=Z@E000000P3AcJT00d000000dLfY0=7=Z@0o0=7=Z@00@P3A
cJT2@00007L0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@1_0=7=Z@04@000003A
cJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000L03AcJT014000000dLfY0=7=ZD0000040=7=
Z@03@000003AcJT0dLfY03h0dLfY00110=7=Z@04@000003AcJT0dLfY@00007<0dLfY00A000000=7=
Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00001a0=7=Z@03@000003AcJU000000080dLfY00A0
00000=7=Z@3AcJU00000L@3AcJT00d000000dLfY@00000020=7=Z@04@000003AcJT0dLfY@00003l0
dLfY00120=7=Z@900000M@3AcJT2@00000@0dLfY0T00001c0=7=Z@9000000`3AcJT2@00007<0dLfY
0T0000030=7=Z@900000@03AcJT00?l0dLfYmP3AcJT00?l0dLfYmP3AcJT00?l0dLfYmP3AcJT00?l0
dLfYmP3AcJT00?l0dLfYmP3AcJT00?l0dLfYmP3AcJT00?l0dLfYmP3AcJT00?l0dLfYmP3AcJT00?l0
dLfYmP3AcJT00?l0dLfYmP3AcJT00?l0dLfYmP3AcJT00001\
\>"],
  ImageRangeCache->{{{0, 500.688}, {373.5, 0}} -> {-0.101445, -0.074664, \
0.00839425, 0.00839425}, {{12.0625, 122.875}, {364.563, 309.875}} -> \
{-28.3262, -9.91755, 1.02012, 1.02012}, {{133.938, 244.75}, {364.563, \
309.875}} -> {-152.653, -9.91755, 1.02012, 1.02012}, {{255.875, 366.688}, \
{364.563, 309.875}} -> {-277.045, -9.91755, 1.02012, 1.02012}, {{377.75, \
488.563}, {364.563, 309.875}} -> {-4.63996, -0.196606, 0.0118663, 0.0192001}, \
{{12.0625, 122.875}, {304.375, 249.625}} -> {-28.2234, -71.2109, 1.0186, \
1.0186}, {{133.938, 244.75}, {304.375, 249.625}} -> {-152.365, -71.2109, \
1.0186, 1.0186}, {{255.875, 366.688}, {304.375, 249.625}} -> {-276.571, \
-71.2109, 1.0186, 1.0186}, {{377.75, 488.563}, {304.375, 249.625}} -> \
{-400.712, -71.2109, 1.0186, 1.0186}, {{12.0625, 122.875}, {244.188, \
189.438}} -> {-28.2234, -132.518, 1.0186, 1.0186}, {{133.938, 244.75}, \
{244.188, 189.438}} -> {-152.365, -132.518, 1.0186, 1.0186}, {{255.875, \
366.688}, {244.188, 189.438}} -> {-276.571, -132.518, 1.0186, 1.0186}, \
{{377.75, 488.563}, {244.188, 189.438}} -> {-400.712, -132.518, 1.0186, \
1.0186}, {{12.0625, 122.875}, {184, 129.25}} -> {-28.2234, -193.825, 1.0186, \
1.0186}, {{133.938, 244.75}, {184, 129.25}} -> {-152.365, -193.825, 1.0186, \
1.0186}, {{255.875, 366.688}, {184, 129.25}} -> {-276.571, -193.825, 1.0186, \
1.0186}, {{377.75, 488.563}, {184, 129.25}} -> {-400.712, -193.825, 1.0186, \
1.0186}, {{12.0625, 122.875}, {123.813, 69.0625}} -> {-28.2234, -255.132, \
1.0186, 1.0186}, {{133.938, 244.75}, {123.813, 69.0625}} -> {-152.365, \
-255.132, 1.0186, 1.0186}, {{255.875, 366.688}, {123.813, 69.0625}} -> \
{-276.571, -255.132, 1.0186, 1.0186}, {{377.75, 488.563}, {123.813, 69.0625}} -> \
{-400.712, -255.132, 1.0186, 1.0186}, {{12.0625, 122.875}, {63.5625, 8.875}} -> \
{-28.3262, -316.974, 1.02012, 1.02012}, {{133.938, 244.75}, {63.5625, 8.875}} -> \
{-152.653, -316.974, 1.02012, 1.02012}, {{255.875, 366.688}, {63.5625, \
8.875}} -> {-277.045, -316.974, 1.02012, 1.02012}, {{377.75, 488.563}, \
{63.5625, 8.875}} -> {-401.372, -316.974, 1.02012, 1.02012}}]
}, Open  ]],

Cell["\<\
We include these definitions on file allRules2. 

Unfortunately, this approach cannot be readily extended to the case b=3. In \
fact, if we change the definition of b to b=3 in the above, we obtain range \
overflow errors that prevent us to proceed with an otherwise possible \
(although unfeasible) computation.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["TOTALISTIC RULES", "Section"],

Cell["\<\
A totalistic rule is one for which the transition depends upon the sum of the \
states of the neighborhood. Every neighborhood possessing a given sum must \
necessarily evolve into the same state.

Although totalistic rules form a special class, they are general enough to be \
representative in the sense that any other rule can be transformed into a \
totalistic rule, although the new rule may have a considerably larger number \
of states. Albert and Cullick [2] have demonstrated this fact.\
\>", "Text"],

Cell[BoxData[
    \(f[li_, val_] := Map[\((# \[Rule] val)\) &, li]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(totalistic[b_] := 
      Module[{u, v, w, x}, \[IndentingNewLine]u = 
          IntegerDigits[Range[0, b\^3 - 1], b, 3]; \[IndentingNewLine]v = 
          Table[{}, {3\ b - 2}]; \[IndentingNewLine]Map[
          AppendTo[
              v\[LeftDoubleBracket]1 + 
                  Plus\  @@ \ #\[RightDoubleBracket], #] &, 
          u]; \[IndentingNewLine]w = 
          IntegerDigits[Range[b\^\(3\ b - 4\), b\^\(3  b - 3\) - 1], b, 
            3  b - 2]; \[IndentingNewLine]x = 
          Map[Flatten[Inner[f, v, #, List]] &, 
            w]; \[IndentingNewLine]Map[\((u\  /. \ #)\) &, x]]\)], "Input",
  InitializationCell->True],

Cell["There are 196608 totalistic tetradic rules", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(b = 4;\)\), "\[IndentingNewLine]", 
    \(\(u = 
        IntegerDigits[Range[0, b\^3 - 1], b, 3];\)\), "\[IndentingNewLine]", 
    \(\(v = Table[{}, {3\ b - 2}];\)\), "\[IndentingNewLine]", 
    \(\(Map[
        AppendTo[
            v\[LeftDoubleBracket]1 + 
                Plus\  @@ \ #\[RightDoubleBracket], #] &, 
        u];\)\), "\[IndentingNewLine]", 
    \(\(w = 
        IntegerDigits[Range[b\^\(3\ b - 4\), b\^\(3  b - 3\) - 1], b, 
          3  b - 2];\)\), "\[IndentingNewLine]", 
    \(Length[w]\)}], "Input"],

Cell[BoxData[
    \(196608\)], "Output"]
}, Open  ]],

Cell["There are only three corresponding to dyadic CA:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(b = 2;\)\), "\[IndentingNewLine]", 
    \(\(cS = cellularSpace[101];\)\), "\[IndentingNewLine]", 
    \(\(ans = {};\)\), "\[IndentingNewLine]", 
    \(\(s = symm[b];\)\), "\[IndentingNewLine]", 
    \(\(allRules = 
        totalistic[b];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Map[\[IndentingNewLine]\((r = #; \[IndentingNewLine]m = 
              evolve[b, cS, r, 50]; \[IndentingNewLine]pat = 
              IntegerDigits[
                Complement[Range[b\^3], Flatten[Position[r, 0]]] - 1, b, 
                3]; \[IndentingNewLine]p = 
              Union[Flatten[
                  Map[\((j = Partition[#, 3, 1]; \ 
                        Select[j, MemberQ[pat, #] &])\) &, m], 
                  1]]; \[IndentingNewLine]If[p == pat, 
              ans = Flatten[{ans, {r}}, 1]])\) &, 
        allRules];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(allRules = ans;\)\), "\[IndentingNewLine]", 
    \(\(g = 
        Map[showCA[b, cS, #, 50, 1, 1, 101, 2] &, 
          allRules];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[g], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1547 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0036834 0.31746 [
[ 0 0 0 0 ]
[ 1 .1547 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .1547 L
0 .1547 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0036834 0.321429 0.15102 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -11 0 ]
[.5 .50755 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(104) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFF
FFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FF000000FFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF
00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF
00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFF
FF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFF
FFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFF
FFFFFF000000FF000000FFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFF00
0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF
FFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF00
0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF
00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FF000000FFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.0036834 0.64881 0.15102 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -11 0 ]
[.5 .50755 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(105) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FFFFFF
FFFFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF
00FF00FFFFFF00FF00FFFFFF00FF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FF
FFFF00FF00FFFFFF00FF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFFFF
FFFFFFFFFF000000FF000000FFFFFFFFFF000000FFFFFFFFFF000000FF000000FFFFFFFF
FF000000FF000000FFFFFFFFFF000000FFFFFFFFFF000000FF000000FFFFFFFFFF000000
FF000000FFFFFFFFFF000000FFFFFFFFFF000000FF000000FFFFFFFFFF
FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFF
FFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FF
FFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF00FF0000FF0000FF00FF0000FF0000FF00FF0000FFFFFFFFFFFF
FFFFFF0000FF00FF0000FF0000FF00FF0000FF0000FF00FF0000FFFFFFFFFFFFFFFFFF00
00FF00FF0000FF0000FF00FF0000FF0000FF00FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
00FF00FF00FFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF0000FF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF0000FF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF0000FF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FF
FFFF00FF00FFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF
00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFF000000
FF000000FFFFFFFFFF000000FF000000FF000000FFFFFFFFFF000000FF000000FFFFFFFF
FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FF
FFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFF
FFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FF0000FF00FF
0000FFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFF0000FF00FF0000FF00
00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFF00FF00FF
00FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFF
00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF000000
FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF000000FF0000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF
FFFF00FF00FFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FFFFFF00FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000
FF000000FFFFFFFFFF000000FF000000FF000000FFFFFFFFFF000000FF000000FF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF
FFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF
0000FFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFF0000FF00FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
00FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFF00FF00FFFFFF00FF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FF000000FFFFFFFFFF000000FFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF00FF0000FF0000FF00FF0000FF0000FF00FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF0000FF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.0036834 0.97619 0.15102 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -11 0 ]
[.5 .50755 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(126) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFF0000000000000000000000000000000000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
0000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00
00FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFF
FFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000000000FFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF00
00FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00000000FFFFFF
FF00000000FFFFFFFF00000000FFFFFF00000000FFFFFFFF00000000FFFFFFFF00000000
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFF
FFFF0000FFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFF0000FF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFF
FFFFFF0000000000000000FFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFF
FFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF00
00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFF0000FFFF0000FFFF0000FF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFF00000000FFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000000000FFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFF0000FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{544.188, 84.1875},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008P0000E2000`400?l00000o`00003oo`3AcJWo
0=7=ZB80dLfY003o0=7=ZOl0dLfY8P3AcJT00?l0dLfYo`3AcJTR0=7=Z@00o`3AcJWo0=7=ZB80dLfY
000P0=7=Z@030?ooo`000000000000800000903oool4000002@0oooo1000000T0?ooo`@0000000<0
oooo0=7=Z@3AcJT0<03AcJT00`3oool000000000000200000100oooo1000000T0?ooo`@00000903o
ool400000100oooo100000000`3oool0dLfY0=7=Z@0`0=7=Z@030?ooo`000000000000<000008`3o
ool500000280oooo1@00000S0?ooo`D0000000<0oooo0=7=Z@3AcJT0803AcJT00200dLfY0`3oool0
0`000000oooo0?ooo`0T0?ooo`8000009P3oool2000002H0oooo0P0000020?oooc80dLfY0`3oool0
0`000000oooo0?ooo`0@0?ooo`8000009P3oool2000002H0oooo0P00000B0?ooo`8000000P3ooolb
0=7=Z@<0oooo0P00000U0?ooo`<00000903oool3000002D0oooo0`0000020?ooob80dLfY000P0=7=
Z@<0oooo00<000000?ooo`3oool0903oool2000002H0oooo0P00000V0?ooo`8000000P3ooolb0=7=
Z@<0oooo00<000000?ooo`3oool0403oool2000002H0oooo0P00000V0?ooo`8000004P3oool20000
0080oooo<P3AcJT30?ooo`8000009@3oool3000002@0oooo0`00000U0?ooo`<000000P3ooolR0=7=
Z@00803AcJT40?ooo`<000000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000080
oooo0`0000020?ooo`<000000P3oool3000002X0oooo0`0000020?ooo`<000000P3oool300000080
oooo0`0000020?ooo`<000000P3oool300000080oooo0`0000020?ooo`<00000103ooolb0=7=Z@@0
oooo0P0000001@3oool00000000000000000oooo00<0000000<0oooo0000000000000P3oool20000
00040?ooo`00000000000?ooo`8000000P3oool2000000050?ooo`00000000000000003oool00`00
00000`3oool00000000000020?ooo`80000000D0oooo00000000000000000?ooo`03000000030?oo
o`00000000000080oooo0P000000103oool000000000003oool200000080oooo0P0000001@3oool0
0000000000000000oooo00<0000000<0oooo0000000000000P3oool2000000050?ooo`0000000000
0000003oool00`0000000`3oool00000000000020?ooo`80000000@0oooo000000000000oooo0P00
00020?ooo`80000000D0oooo00000000000000000?ooo`03000000030?ooo`000000000000@0oooo
<P3AcJT40?ooobP000009P3ooolX000000@0oooo8P3AcJT00200dLfY1@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?oooc80dLfY1@3oool010000000oooo0000000000030?ooo`80000000<0oooo0000003oool0
0`3oool01P000000oooo000000000000oooo000000@0oooo00@000000?ooo`00000000000`3oool2
000000030?ooo`000000oooo00<0oooo00@000000?ooo`00000000000`3oool2000000030?ooo`00
0000oooo00<0oooo00H000000?ooo`00000000000?ooo`0000040?ooo`040000003oool000000000
00<0oooo0P0000000`3oool000000?ooo`030?ooo`040000003oool00000000000<0oooo0P000000
0`3oool000000?ooo`030?ooo`060000003oool000000000003oool00000103oool010000000oooo
0000000000030?ooo`80000000<0oooo0000003oool0103ooolb0=7=Z@D0oooo0P0000030?ooo`80
00000`3oool2000000<0oooo0P0000030?ooo`8000000`3oool2000000<0oooo0P0000030?ooo`80
0000:P3oool2000000<0oooo0P0000030?ooo`8000000`3oool2000000<0oooo0P0000030?ooo`80
00000`3oool2000000<0oooo0P0000050?ooob80dLfY000P0=7=Z@H0oooo100000060?ooo`@00000
1P3oool4000000H0oooo1000000^0?ooo`@000001P3oool4000000H0oooo100000060?ooo`@00000
1P3ooolb0=7=Z@H0oooo100000000`3oool0000000000002000000H0oooo100000060?ooo`@00000
00<0oooo0000000000000P0000060?ooo`@0000000<0oooo0000000000000P0000060?ooo`@00000
1P3oool4000000030?ooo`0000000000008000001P3oool4000000030?ooo`000000000000800000
1P3oool4000000H0oooo100000000`3oool0000000000002000000H0oooo<P3AcJT60?ooo`D00000
1@3oool5000000D0oooo1@0000050?ooo`D00000;03oool5000000D0oooo1@0000050?ooo`D00000
1@3oool5000000H0oooo8P3AcJT00200dLfY1`3oool2000000P0oooo0P0000080?ooo`800000203o
ool200000300oooo0P0000080?ooo`800000203oool2000000P0oooo0P0000070?oooc80dLfY1`3o
ool2000000<0oooo0P0000080?ooo`800000203oool2000000<0oooo0P0000080?ooo`8000000`3o
ool2000000P0oooo0P0000080?ooo`8000000`3oool2000000P0oooo0P0000030?ooo`800000203o
ool2000000P0oooo0P0000030?ooo`8000001`3ooolb0=7=Z@L0oooo0`0000070?ooo`<000001`3o
ool3000000L0oooo0`00000^0?ooo`<000001`3oool3000000L0oooo0`0000070?ooo`<000001`3o
oolR0=7=Z@00803AcJT70?ooo`800000203oool2000000P0oooo0P0000080?ooo`800000<03oool2
000000P0oooo0P0000080?ooo`800000203oool2000000L0oooo<P3AcJT70?ooo`8000000`3oool2
000000P0oooo0P0000080?ooo`8000000`3oool2000000P0oooo0P0000030?ooo`800000203oool2
000000P0oooo0P0000030?ooo`800000203oool2000000<0oooo0P0000080?ooo`800000203oool2
000000<0oooo0P0000070?oooc80dLfY1`3oool3000000L0oooo0`0000070?ooo`<000001`3oool3
000002h0oooo0`0000070?ooo`<000001`3oool3000000L0oooo0`0000070?ooob80dLfY000P0=7=
Z@T0oooo0`0000020?ooo`<00000303oool300000080oooo0`00000d0?ooo`<000000P3oool30000
00`0oooo0`0000020?ooo`<000002@3ooolb0=7=Z@T0oooo0P000000103oool000000000003oool2
00000080oooo0P000000103oool000000000003oool200000080oooo0P000000103oool000000000
003oool2000000`0oooo0P000000103oool000000000003oool200000080oooo0P000000103oool0
00000000003oool200000080oooo0P000000103oool000000000003oool2000000`0oooo0P000000
103oool000000000003oool200000080oooo0P000000103oool000000000003oool200000080oooo
0P000000103oool000000000003oool2000000T0oooo<P3AcJT90?ooo`X000002P3oool:00000300
oooo2P00000:0?ooo`X000002@3ooolR0=7=Z@00803AcJT:0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0203ooolb0=7=Z@X0oooo00H000000?ooo`00000000000?ooo`0000040?oo
o`060000003oool000000000003oool00000103oool01P000000oooo000000000000oooo000000h0
oooo00H000000?ooo`00000000000?ooo`0000040?ooo`060000003oool000000000003oool00000
103oool01P000000oooo000000000000oooo000000h0oooo00H000000?ooo`00000000000?ooo`00
00040?ooo`060000003oool000000000003oool00000103oool01P000000oooo000000000000oooo
000000X0oooo<P3AcJT:0?ooo`8000000`3oool2000000d0oooo0P0000030?ooo`800000=03oool2
000000<0oooo0P00000=0?ooo`8000000`3oool2000000X0oooo8P3AcJT00200dLfY2`3oool40000
0100oooo1000000h0?ooo`@00000403oool4000000/0oooo<P3AcJT;0?ooo`@000001P3oool40000
00H0oooo1000000@0?ooo`@000001P3oool4000000H0oooo1000000@0?ooo`@000001P3oool40000
00H0oooo1000000;0?oooc80dLfY2`3oool5000000l0oooo1@00000f0?ooo`D000003`3oool50000
00/0oooo8P3AcJT00200dLfY303oool200000180oooo0P00000j0?ooo`8000004P3oool2000000`0
oooo<P3AcJT<0?ooo`800000203oool2000000P0oooo0P00000B0?ooo`800000203oool2000000P0
oooo0P00000B0?ooo`800000203oool2000000P0oooo0P00000<0?oooc80dLfY303oool300000140
oooo0`00000h0?ooo`<000004@3oool3000000`0oooo8P3AcJT00200dLfY303oool200000180oooo
0P00000j0?ooo`8000004P3oool2000000`0oooo<P3AcJT<0?ooo`800000203oool2000000P0oooo
0P00000B0?ooo`800000203oool2000000P0oooo0P00000B0?ooo`800000203oool2000000P0oooo
0P00000<0?oooc80dLfY303oool300000140oooo0`00000h0?ooo`<000004@3oool3000000`0oooo
8P3AcJT00200dLfY3P3oool300000080oooo0`0000020?ooo`<000000P3oool3000003h0oooo0`00
00020?ooo`<000000P3oool300000080oooo0`00000>0?oooc80dLfY3P3oool2000000050?ooo`00
000000000000003oool0100000001@3oool00000000000000000oooo008000005P3oool200000005
0?ooo`00000000000000003oool0100000001@3oool00000000000000000oooo008000005P3oool2
000000050?ooo`00000000000000003oool0100000001@3oool00000000000000000oooo00800000
3P3ooolb0=7=Z@h0oooo5000000j0?oooa@000003P3ooolR0=7=Z@00803AcJT?0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03@3ooolb0=7=Z@l0oooo00@000000?ooo`0000000000
0`3oool2000000<0oooo0P0000000`3oool000000?ooo`0G0?ooo`040000003oool00000000000<0
oooo0P0000030?ooo`80000000<0oooo0000003oool05`3oool010000000oooo0000000000030?oo
o`8000000`3oool2000000030?ooo`000000oooo00h0oooo<P3AcJT?0?ooo`8000000`3oool20000
00<0oooo0P0000030?ooo`800000?P3oool2000000<0oooo0P0000030?ooo`8000000`3oool20000
00l0oooo8P3AcJT00200dLfY403oool4000000H0oooo100000120?ooo`@000001P3oool400000100
oooo<P3AcJT@0?ooo`@0000000<0oooo0000000000000P0000000`3oool0000000000002000001X0
oooo100000000`3oool0000000000002000000030?ooo`0000000000008000006P3oool400000003
0?ooo`00000000000080000000<0oooo0000000000000P00000@0?oooc80dLfY403oool5000000D0
oooo1@0000100?ooo`D000001@3oool500000100oooo8P3AcJT00200dLfY4@3oool2000000P0oooo
0P0000140?ooo`800000203oool200000140oooo<P3AcJTA0?ooo`8000000`3oool2000000<0oooo
0P00000L0?ooo`8000000`3oool2000000<0oooo0P00000L0?ooo`8000000`3oool2000000<0oooo
0P00000A0?oooc80dLfY4@3oool3000000L0oooo0`0000120?ooo`<000001`3oool300000140oooo
8P3AcJT00200dLfY4@3oool2000000P0oooo0P0000140?ooo`800000203oool200000140oooo<P3A
cJTA0?ooo`8000000`3oool2000000<0oooo0P00000L0?ooo`8000000`3oool2000000<0oooo0P00
000L0?ooo`8000000`3oool2000000<0oooo0P00000A0?oooc80dLfY4@3oool3000000L0oooo0`00
00120?ooo`<000001`3oool300000140oooo8P3AcJT00200dLfY4`3oool300000080oooo0`000018
0?ooo`<000000P3oool3000001<0oooo<P3AcJTC0?ooo`80000000@0oooo000000000000oooo0P00
000P0?ooo`80000000@0oooo000000000000oooo0P00000P0?ooo`80000000@0oooo000000000000
oooo0P00000C0?oooc80dLfY4`3oool:000004@0oooo2P00000C0?ooob80dLfY000P0=7=ZA@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool04P3ooolb0=7=ZA@0oooo00H000000?ooo`00000000000?ooo`00000R0?oo
o`060000003oool000000000003oool000008P3oool01P000000oooo000000000000oooo000001@0
oooo<P3AcJTD0?ooo`8000000`3oool2000004P0oooo0P0000030?ooo`800000503ooolR0=7=Z@00
803AcJTE0?ooo`@00000C03oool4000001D0oooo<P3AcJTE0?ooo`@00000903oool4000002@0oooo
1000000E0?oooc80dLfY5@3oool5000004X0oooo1@00000E0?ooob80dLfY000P0=7=ZAH0oooo0P00
001>0?ooo`8000005P3ooolb0=7=ZAH0oooo0P00000V0?ooo`8000009P3oool2000001H0oooo<P3A
cJTF0?ooo`<00000C03oool3000001H0oooo8P3AcJT00200dLfY5P3oool2000004h0oooo0P00000F
0?oooc80dLfY5P3oool2000002H0oooo0P00000V0?ooo`8000005P3ooolb0=7=ZAH0oooo0`00001<
0?ooo`<000005P3ooolR0=7=Z@00803AcJTH0?ooo`<000000P3oool300000080oooo0`0000020?oo
o`<000000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000080oooo0`0000020?oo
o`<000000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000080oooo0`0000020?oo
o`<00000603ooolb0=7=ZAP0oooo0P0000001@3oool00000000000000000oooo00<0000000<0oooo
0000000000000P3oool2000000050?ooo`00000000000000003oool00`0000000`3oool000000000
00020?ooo`80000000D0oooo00000000000000000?ooo`04000000050?ooo`00000000000000003o
ool00P0000020?ooo`80000000D0oooo00000000000000000?ooo`03000000030?ooo`0000000000
0080oooo0P0000001@3oool00000000000000000oooo00<0000000<0oooo000000000000603ooolb
0=7=ZAP0ooooCP00000H0?ooob80dLfY000P0=7=ZAT0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3ooolb0=7=
ZAT0oooo00@000000?ooo`00000000000`3oool2000000030?ooo`000000oooo00<0oooo00@00000
0?ooo`00000000000`3oool2000000030?ooo`000000oooo00<0oooo00@000000?ooo`0000000000
0`3oool2000000<0oooo0P0000000`3oool000000?ooo`030?ooo`040000003oool00000000000<0
oooo0P0000000`3oool000000?ooo`030?ooo`040000003oool00000000000<0oooo0P0000000`3o
ool000000?ooo`0H0?oooc80dLfY6@3oool2000000<0oooo0P0000030?ooo`8000000`3oool20000
00<0oooo0P0000030?ooo`8000000`3oool2000000<0oooo0P0000020?ooo`8000000`3oool20000
00<0oooo0P0000030?ooo`8000000`3oool2000000<0oooo0P0000030?ooo`8000000`3oool20000
01T0oooo8P3AcJT00200dLfY6P3oool4000000H0oooo100000060?ooo`@000001P3oool4000000H0
oooo100000060?ooo`@000001P3oool4000000H0oooo1000000J0?oooc80dLfY6P3oool400000003
0?ooo`0000000000008000001P3oool4000000030?ooo`0000000000008000001P3oool400000003
0?ooo`00000000000080000000<0oooo0000000000000P0000060?ooo`@0000000<0oooo00000000
00000P0000060?ooo`@0000000<0oooo0000000000000P00000J0?oooc80dLfY6P3oool5000000D0
oooo1@0000050?ooo`D000001@3oool5000000@0oooo1@0000050?ooo`D000001@3oool5000000D0
oooo1@00000J0?ooob80dLfY000P0=7=ZA/0oooo0P0000080?ooo`800000203oool2000000P0oooo
0P0000080?ooo`800000203oool2000000P0oooo0P0000080?ooo`8000006`3ooolb0=7=ZA/0oooo
0P0000030?ooo`800000203oool2000000<0oooo0P0000080?ooo`8000000`3oool2000000<0oooo
0P0000080?ooo`8000000`3oool2000000P0oooo0P0000030?ooo`8000006`3ooolb0=7=ZA/0oooo
0`0000070?ooo`<000001`3oool3000000L0oooo0`0000060?ooo`<000001`3oool3000000L0oooo
0`0000070?ooo`<000006`3ooolR0=7=Z@00803AcJTK0?ooo`800000203oool2000000P0oooo0P00
00080?ooo`800000203oool2000000P0oooo0P0000080?ooo`800000203oool2000001/0oooo<P3A
cJTK0?ooo`8000000`3oool2000000P0oooo0P0000030?ooo`800000203oool2000000<0oooo0P00
00030?ooo`800000203oool2000000<0oooo0P0000080?ooo`8000000`3oool2000001/0oooo<P3A
cJTK0?ooo`<000001`3oool3000000L0oooo0`0000070?ooo`<000001P3oool3000000L0oooo0`00
00070?ooo`<000001`3oool3000001/0oooo8P3AcJT00200dLfY7@3oool300000080oooo0`00000<
0?ooo`<000000P3oool3000000`0oooo0`0000020?ooo`<00000303oool300000080oooo0`00000M
0?oooc80dLfY7@3oool2000000040?ooo`00000000000?ooo`8000000P3oool2000000040?ooo`00
000000000?ooo`800000303oool2000000040?ooo`00000000000?ooo`800000303oool200000004
0?ooo`00000000000?ooo`8000000P3oool2000000040?ooo`00000000000?ooo`8000007@3ooolb
0=7=ZAd0oooo2P00000:0?ooo`X00000203oool:000000X0oooo2P00000M0?ooob80dLfY000P0=7=
ZAh0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?oooc80dLfY7P3oool01P00
0000oooo000000000000oooo000000@0oooo00H000000?ooo`00000000000?ooo`00000>0?ooo`06
0000003oool000000000003oool000003P3oool01P000000oooo000000000000oooo000000@0oooo
00H000000?ooo`00000000000?ooo`00000N0?oooc80dLfY7P3oool2000000<0oooo0P00000=0?oo
o`8000000`3oool2000000`0oooo0P0000030?ooo`8000003@3oool2000000<0oooo0P00000N0?oo
ob80dLfY000P0=7=ZAl0oooo1000000@0?ooo`@00000403oool400000100oooo1000000O0?oooc80
dLfY7`3oool4000000H0oooo1000000@0?ooo`@00000403oool4000000H0oooo1000000O0?oooc80
dLfY7`3oool5000000l0oooo1@00000>0?ooo`D000003`3oool5000001l0oooo8P3AcJT00200dLfY
7`3oool400000100oooo1000000@0?ooo`@00000403oool4000001l0oooo<P3AcJTO0?ooo`@00000
1P3oool400000100oooo1000000@0?ooo`@000001P3oool4000001l0oooo<P3AcJTO0?ooo`D00000
3`3oool5000000h0oooo1@00000?0?ooo`D000007`3ooolR0=7=Z@00803AcJTP0?ooo`8000004P3o
ool200000180oooo0P00000B0?ooo`800000803ooolb0=7=ZB00oooo0P0000080?ooo`8000004P3o
ool200000180oooo0P0000080?ooo`800000803ooolb0=7=ZB00oooo0`00000A0?ooo`<00000403o
ool300000140oooo0`00000P0?ooob80dLfY000P0=7=ZB80oooo0`0000020?ooo`<000000P3oool3
00000080oooo0`00000F0?ooo`<000000P3oool300000080oooo0`0000020?ooo`<000008P3ooolb
0=7=ZB80oooo0P0000001@3oool00000000000000000oooo00@0000000D0oooo0000000000000000
0?ooo`0200000080oooo0P0000001@3oool00000000000000000oooo00@0000000D0oooo00000000
000000000?ooo`0200000080oooo0P0000001@3oool00000000000000000oooo00@0000000D0oooo
00000000000000000?ooo`0200000280oooo<P3AcJTR0?oooa@000004P3ooolD00000280oooo8P3A
cJT00200dLfY8`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo<P3AcJTS
0?ooo`040000003oool00000000000<0oooo0P0000030?ooo`80000000<0oooo0000003oool00`3o
ool010000000oooo0000000000030?ooo`8000000`3oool2000000030?ooo`000000oooo00<0oooo
00@000000?ooo`00000000000`3oool2000000<0oooo0P0000000`3oool000000?ooo`0R0?oooc80
dLfY8`3oool2000000<0oooo0P0000030?ooo`8000000`3oool2000001H0oooo0P0000030?ooo`80
00000`3oool2000000<0oooo0P00000S0?ooob80dLfY000P0=7=ZB@0oooo100000060?ooo`@00000
6P3oool4000000H0oooo1000000T0?oooc80dLfY903oool4000000030?ooo`000000000000800000
00<0oooo0000000000000P0000060?ooo`@0000000<0oooo0000000000000P0000000`3oool00000
00000002000000H0oooo100000000`3oool0000000000002000000030?ooo`000000000000800000
903ooolb0=7=ZB@0oooo1@0000050?ooo`D00000603oool5000000D0oooo1@00000T0?ooob80dLfY
000P0=7=ZB@0oooo100000060?ooo`@000006P3oool4000000H0oooo1000000T0?oooc80dLfY903o
ool4000000030?ooo`00000000000080000000<0oooo0000000000000P0000060?ooo`@0000000<0
oooo0000000000000P0000000`3oool0000000000002000000H0oooo100000000`3oool000000000
0002000000030?ooo`000000000000800000903ooolb0=7=ZB@0oooo1@0000050?ooo`D00000603o
ool5000000D0oooo1@00000T0?ooob80dLfY000P0=7=ZBD0oooo0P0000080?ooo`800000703oool2
000000P0oooo0P00000U0?oooc80dLfY9@3oool2000000<0oooo0P0000030?ooo`800000203oool2
000000<0oooo0P0000030?ooo`800000203oool2000000<0oooo0P0000030?ooo`8000009@3ooolb
0=7=ZBD0oooo0`0000070?ooo`<000006P3oool3000000L0oooo0`00000U0?ooob80dLfY000P0=7=
ZBL0oooo0`0000020?ooo`<00000803oool300000080oooo0`00000W0?oooc80dLfY9`3oool20000
00040?ooo`00000000000?ooo`800000303oool2000000040?ooo`00000000000?ooo`800000303o
ool2000000040?ooo`00000000000?ooo`8000009`3ooolb0=7=ZBL0oooo2P00000L0?ooo`X00000
9`3ooolR0=7=Z@00803AcJTX0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02H0oooo<P3AcJTX0?ooo`060000003o
ool000000000003oool000003P3oool01P000000oooo000000000000oooo000000h0oooo00H00000
0?ooo`00000000000?ooo`00000X0?oooc80dLfY:03oool2000000<0oooo0P00000P0?ooo`800000
0`3oool2000002P0oooo8P3AcJT00200dLfY:@3oool4000002@0oooo1000000Y0?oooc80dLfY:@3o
ool400000100oooo1000000@0?ooo`@00000:@3ooolb0=7=ZBT0oooo1@00000R0?ooo`D00000:@3o
oolR0=7=Z@00803AcJTY0?ooo`@00000903oool4000002T0oooo<P3AcJTY0?ooo`@00000403oool4
00000100oooo1000000Y0?oooc80dLfY:@3oool500000280oooo1@00000Y0?ooob80dLfY000P0=7=
ZBX0oooo0P00000V0?ooo`800000:P3ooolb0=7=ZBX0oooo0P00000B0?ooo`8000004P3oool20000
02X0oooo<P3AcJTZ0?ooo`<00000903oool3000002X0oooo8P3AcJT00200dLfY;03oool300000080
oooo0`0000020?ooo`<000000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000080
oooo0`00000/0?oooc80dLfY;03oool2000000050?ooo`00000000000000003oool00`0000000`3o
ool00000000000020?ooo`80000000@0oooo000000000000oooo0P0000020?ooo`80000000D0oooo
00000000000000000?ooo`03000000030?ooo`000000000002`0oooo<P3AcJT/0?ooobH00000;03o
oolR0=7=Z@00803AcJT]0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:`3ooolb
0=7=ZBd0oooo00@000000?ooo`00000000000`3oool2000000030?ooo`000000oooo00<0oooo00H0
00000?ooo`00000000000?ooo`0000040?ooo`040000003oool00000000000<0oooo0P0000000`3o
ool000000?ooo`0/0?oooc80dLfY;@3oool2000000<0oooo0P0000030?ooo`8000000`3oool20000
0080oooo0P0000030?ooo`8000000`3oool2000000<0oooo0P00000]0?ooob80dLfY000P0=7=ZBh0
oooo100000060?ooo`@000001P3oool4000000H0oooo1000000^0?oooc80dLfY;P3oool400000003
0?ooo`0000000000008000001P3oool4000000H0oooo100000000`3oool0000000000002000002h0
oooo<P3AcJT^0?ooo`D000001@3oool5000000@0oooo1@0000050?ooo`D00000;P3ooolR0=7=Z@00
803AcJT^0?ooo`@000001P3oool4000000H0oooo100000060?ooo`@00000;P3ooolb0=7=ZBh0oooo
100000000`3oool0000000000002000000H0oooo100000060?ooo`@0000000<0oooo000000000000
0P00000^0?oooc80dLfY;P3oool5000000D0oooo1@0000040?ooo`D000001@3oool5000002h0oooo
8P3AcJT00200dLfY;`3oool2000000P0oooo0P0000080?ooo`800000203oool2000002l0oooo<P3A
cJT_0?ooo`8000000`3oool2000000P0oooo0P0000080?ooo`8000000`3oool2000002l0oooo<P3A
cJT_0?ooo`<000001`3oool3000000H0oooo0`0000070?ooo`<00000;`3ooolR0=7=Z@00803AcJTa
0?ooo`<000000P3oool3000000`0oooo0`0000020?ooo`<00000<@3ooolb0=7=ZC40oooo0P000000
103oool000000000003oool200000080oooo0P000000103oool000000000003oool200000080oooo
0P000000103oool000000000003oool200000340oooo<P3AcJTa0?ooo`X00000203oool:00000340
oooo8P3AcJT00200dLfY<P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0`0?oooc80dLfY<P3oool01P000000oooo
000000000000oooo000000@0oooo00H000000?ooo`00000000000?ooo`0000040?ooo`060000003o
ool000000000003oool00000<P3ooolb0=7=ZC80oooo0P0000030?ooo`800000303oool2000000<0
oooo0P00000b0?ooob80dLfY000P0=7=ZC<0oooo1000000@0?ooo`@00000<`3ooolb0=7=ZC<0oooo
100000060?ooo`@000001P3oool4000003<0oooo<P3AcJTc0?ooo`D000003P3oool5000003<0oooo
8P3AcJT00200dLfY<`3oool400000100oooo1000000c0?oooc80dLfY<`3oool4000000H0oooo1000
00060?ooo`@00000<`3ooolb0=7=ZC<0oooo1@00000>0?ooo`D00000<`3ooolR0=7=Z@00803AcJTd
0?ooo`8000004P3oool2000003@0oooo<P3AcJTd0?ooo`800000203oool2000000P0oooo0P00000d
0?oooc80dLfY=03oool300000100oooo0`00000d0?ooob80dLfY000P0=7=ZCH0oooo0`0000020?oo
o`<000000P3oool300000080oooo0`00000f0?oooc80dLfY=P3oool2000000050?ooo`0000000000
0000003oool0100000001@3oool00000000000000000oooo00800000=P3ooolb0=7=ZCH0oooo4P00
000f0?ooob80dLfY000P0=7=ZCL0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=@3ooolb0=7=ZCL0oooo00@00000
0?ooo`00000000000`3oool2000000<0oooo0P0000000`3oool000000?ooo`0f0?oooc80dLfY=`3o
ool2000000<0oooo0P0000020?ooo`8000000`3oool2000003L0oooo8P3AcJT00200dLfY>03oool4
000000H0oooo1000000h0?oooc80dLfY>03oool4000000030?ooo`00000000000080000000<0oooo
0000000000000P00000h0?oooc80dLfY>03oool5000000@0oooo1@00000h0?ooob80dLfY000P0=7=
ZCP0oooo100000060?ooo`@00000>03ooolb0=7=ZCP0oooo100000000`3oool00000000000020000
00030?ooo`000000000000800000>03ooolb0=7=ZCP0oooo1@0000040?ooo`D00000>03ooolR0=7=
Z@00803AcJTi0?ooo`800000203oool2000003T0oooo<P3AcJTi0?ooo`8000000`3oool2000000<0
oooo0P00000i0?oooc80dLfY>@3oool3000000H0oooo0`00000i0?ooob80dLfY000P0=7=ZC/0oooo
0`0000020?ooo`<00000>`3ooolb0=7=ZC/0oooo0P000000103oool000000000003oool2000003/0
oooo<P3AcJTk0?ooo`P00000>`3ooolR0=7=Z@00803AcJTl0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0>P3ooolb0=7=ZC`0oooo00H000000?ooo`00000000000?ooo`00000l0?oo
oc80dLfY?03oool200000080oooo0P00000l0?ooob80dLfY000P0=7=ZCd0oooo1000000m0?oooc80
dLfY?@3oool4000003d0oooo<P3AcJTm0?ooo`@00000?@3ooolR0=7=Z@00803AcJTm0?ooo`@00000
?@3ooolb0=7=ZCd0oooo1000000m0?oooc80dLfY?@3oool4000003d0oooo8P3AcJT00200dLfY?P3o
ool2000003h0oooo<P3AcJTn0?ooo`800000?P3ooolb0=7=ZCh0oooo0P00000n0?ooob80dLfY003o
0=7=ZOl0dLfY8P3AcJT00?l0dLfYo`3AcJTR0=7=Z@00o`3AcJWo0=7=ZB80dLfY003o0=7=ZOl0dLfY
8P3AcJT00?l0dLfYo`3AcJTR0=7=Z@00o`3AcJWo0=7=ZB80dLfY003o0=7=ZOl0dLfY8P3AcJT005L0
dLfY1D0000020=7=Z@9000001@3AcJT3@00009l0dLfY1D0000020=7=Z@900000103AcJT2@0000:40
dLfY1D0000000`3AcJU00000@0000002@0000080dLfY0d00001J0=7=Z@00F@3AcJT01D000000dLfY
0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@2P0=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0
dLfY0:00dLfY00E000000=7=Z@3AcJT0dLfY@00000050=7=Z@04@000003AcJT0dLfY@00005T0dLfY
001I0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@05@0000:40dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3A
cJT0X03AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3A
cJU00000F@3AcJT005T0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00=000000=7=Z@3AcJT0X03AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A0
00000=7=Z@3AcJT0dLfY0T00002S0=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJT0
dLfY0d00001J0=7=Z@00F@3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00M000000=7=Z@3A
cJT0dLfY@000003AcJU000000:80dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@05@000003A
cJT0dLfY0=7=ZD000000Y03AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00E000000=7=Z@3A
cJT0dLfY@000001K0=7=Z@00F03AcJT2@00000@0dLfY0T0000050=7=Z@900000X@3AcJT2@00000@0
dLfY0T0000040=7=Z@=00000X@3AcJT2@00000@0dLfY0T0000040=7=Z@=00000F@3AcJT00?l0dLfY
o`3AcJTR0=7=Z@00o`3AcJWo0=7=ZB80dLfY003o0=7=ZOl0dLfY8P3AcJT00?l0dLfYo`3AcJTR0=7=
Z@00\
\>"],
  ImageRangeCache->{{{0, 543.188}, {83.1875, 0}} -> {-0.090988, -0.0116052, \
0.00585798, 0.00585798}, {{15.5, 175.563}, {81.1875, 1.9375}} -> {-26.2324, \
-2.6067, 0.803218, 0.803218}, {{191.563, 351.563}, {81.1875, 1.9375}} -> \
{-167.624, -2.6067, 0.803218, 0.803218}, {{367.563, 527.625}, {81.1875, \
1.9375}} -> {-309.015, -2.6067, 0.803218, 0.803218}}]
}, Open  ]],

Cell["\<\
We include the data for these rules in file totallistic2

The following comprises a catalog for the first 50 evolutions of all 99 \
irreducible triadic totalistic CA\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(b = 3;\)\), "\[IndentingNewLine]", 
    \(\(cS = cellularSpace[101];\)\), "\[IndentingNewLine]", 
    \(\(ans = \(profile = {}\);\)\), "\[IndentingNewLine]", 
    \(\(s = symm[b];\)\), "\[IndentingNewLine]", 
    \(\(allRules = 
        totalistic[b];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Map[\[IndentingNewLine]\((r = #; \[IndentingNewLine]m = 
              evolve[b, cS, r, 50]; \[IndentingNewLine]pat = 
              IntegerDigits[
                Complement[Range[b\^3], Flatten[Position[r, 0]]] - 1, b, 
                3]; \[IndentingNewLine]p = 
              Union[Flatten[
                  Map[\((j = Partition[#, 3, 1]; \ 
                        Select[j, MemberQ[pat, #] &])\) &, m], 
                  1]]; \[IndentingNewLine]profile = 
              Flatten[{profile, {Length[ans]}}, 1]; \[IndentingNewLine]If[
              p == pat, ans = Flatten[{ans, {r}}, 1]])\) &, 
        allRules];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(allRules = ans;\)\), "\[IndentingNewLine]", 
    \(\(g = 
        Map[showCA[b, cS, #, 50, 1, 1, 101, 2] &, 
          allRules];\)\), "\[IndentingNewLine]", 
    \(\(AppendTo[g, Graphics[{}]];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Partition[g, 5]], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.0077 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0478024 0.190476 [
[ 0 0 0 0 ]
[ 1 2.0077 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 2.0077 L
0 2.0077 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0478024 0.200176 0.135113 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2518200341576) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FFFFFFFFFFFFFF0000000000FF0000FF00FFFFFFFFFFFFFFFF0000000000000000
FFFF00000000000000000000000000000000000000000000000000FFFF00000000000000
00FFFFFFFFFFFFFFFF00FF0000FF0000000000FFFFFFFFFFFFFF0000FF
FFFF00FF00FFFF00FFFF0000000000FFFFFF000000FF00FFFF00FFFF0000000000000000
FFFF00000000000000000000000000000000000000000000000000FFFF00000000000000
00FFFF00FFFF00FF000000FFFFFF0000000000FFFF00FFFF00FF00FFFF
FFFFFF00FF00FFFFFF0000000000FF00FFFF00FFFFFF0000FF00FF000000000000000000
FFFF00000000000000000000000000000000000000000000000000FFFF00000000000000
0000FF00FF0000FFFFFF00FFFF00FF0000000000FFFFFF00FF00FFFFFF
FFFFFFFF0000FFFF00FFFF00FFFF000000FFFFFF00FFFFFFFFFFFF000000000000000000
FFFF00000000000000000000000000000000000000000000000000FFFF00000000000000
0000FFFFFFFFFFFF00FFFFFF000000FFFF00FFFF00FFFF0000FFFFFFFF
FFFFFFFFFF00FF0000FFFF00FFFF0000FF00FF00FF00FFFFFFFFFF000000000000000000
FFFF000000000000000000000000FF000000000000000000000000FFFF00000000000000
0000FFFFFFFFFF00FF00FF00FF0000FFFF00FFFF0000FF00FFFFFFFFFF
FFFFFFFFFFFF00FF0000FFFFFF00000000FFFFFF0000FFFF00FFFF000000000000000000
FFFF0000000000FF0000000000FF00FF0000000000FF0000000000FFFF00000000000000
0000FFFF00FFFF0000FFFFFF00000000FFFFFF0000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF00FF00FF0000FF00FFFF000000FF00FF00000000000000000000
FFFF000000000000FFFF00FFFF000000FFFF00FFFF000000000000FFFF00000000000000
000000FF00FF000000FFFF00FF0000FF00FF00FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFF0000FFFFFF00000000FFFFFF00000000000000000000
FFFF000000000000FFFF00FFFF000000FFFF00FFFF000000000000FFFF00000000000000
000000FFFFFF00000000FFFFFF0000FFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF00000000FF00FF000000FFFFFF00000000000000000000
FFFF00000000000000FFFFFF0000000000FFFFFF00000000000000FFFF00000000000000
000000FFFFFF000000FF00FF00000000FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000000000FF0000000000FF0000000000
FFFF000000000000FF00FF00FF000000FF00FF00FF000000000000FFFF0000000000FF00
00000000FF0000000000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFF0000000000FFFFFF00FFFF000000000000
FFFF00000000000000FFFFFF0000000000FFFFFF00000000000000FFFF000000000000FF
FF00FFFFFF0000000000FFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF0000000000FF00FFFF00FFFF000000000000
FFFF000000000000FF00FFFF0000FF0000FFFF00FF000000000000FFFF000000000000FF
FF00FFFF00FF0000000000FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF00FFFF000000FFFFFF00000000000000
FFFF000000000000FFFFFF0000FF00FF0000FFFFFF000000000000FFFF00000000000000
FFFFFF000000FFFF00FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFF00FFFF0000FF00FF00FF000000000000
FFFF000000000000FFFF00FFFF000000FFFF00FFFF000000000000FFFF000000000000FF
00FF00FF0000FFFF00FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFF00000000FFFFFF00000000000000
FFFF000000FF000000FF00FFFF000000FFFF00FF000000FF000000FFFF00000000000000
FFFFFF00000000FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF0000FF00FFFF00000000000000
FFFF00000000FFFFFFFFFFFF0000000000FFFFFFFFFFFF00000000FFFF00000000000000
FFFF00FF0000FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF0000FFFFFF0000000000000000
FFFF00000000FFFF0000FF00FF000000FF00FF0000FFFF00000000FFFF00000000000000
00FFFFFF0000FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00000000FF00FF00000000000000
FFFF00000000FFFFFFFFFFFF0000000000FFFFFFFFFFFF00000000FFFF00000000000000
FF00FF00000000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000000000000000
FFFF00000000FFFF00FFFF00FF000000FF00FFFF00FFFF00000000FFFF00000000000000
00FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFF0000000000000000
FFFF00000000FFFF0000FFFFFF000000FFFFFF0000FFFF00000000FFFF00000000000000
00FFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF0000000000FF000000
00FF00FFFF00FF0000FF00FF0000000000FF00FF0000FF00FFFF00FF00000000FF000000
0000FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF00FFFF00000000
00FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF0000000000FFFF00
FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFF00FFFF00000000
00FFFFFFFFFFFF000000FFFF00FFFFFF00FFFF000000FFFFFFFFFFFF0000000000FFFF00
FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFF0000000000
0000FF0000FF0000000000FFFFFF00FFFFFF0000000000FF0000FF00000000000000FFFF
FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00000000
0000FFFFFFFF00000000FF00FF000000FF00FF00000000FFFFFFFF000000000000FF00FF
00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00000000
0000FFFFFFFF0000000000FFFFFF00FFFFFF0000000000FFFFFFFF000000000000FFFFFF
00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000000000
000000FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF0000000000000000FF00
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
00FFFFFF0000FFFF00FFFF0000FFFFFF0000FFFF00FFFF0000FFFFFF00FFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FF
FFFFFFFF000000FFFFFF0000FF00FF00FF0000FFFFFF000000FFFFFFFFFF00FFFF00FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF
0000FF000000FF00FF00FF0000FFFFFF0000FF00FF00FF000000FF0000FFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00
FFFFFF000000FFFFFF00FF00FFFFFFFFFF00FF00FFFFFF000000FFFFFF00FFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000
FFFF0000000000FF00FF00FFFFFFFFFFFFFF00FF00FF0000000000FFFF0000FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
00FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00FF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FF00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFF0000FF00FF000000FF00FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FFFFFF000000FFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF0000FFFFFF000000FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF00FFFF000000FFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF0000000000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.0478024 0.39418 0.135113 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2529451067254) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000000000FF00FFFFFFFFFFFF0000FFFFFFFFFFFF00000000FF00000000FFFF0000FF
FFFFFFFFFFFFFFFF0000FF0000FFFFFF0000FF0000FFFFFFFFFFFFFFFFFF0000FFFF0000
0000FF00000000FFFFFFFFFFFF0000FFFFFFFFFFFF00FF0000000000FF
FFFF00FFFF00FF00FFFF00FF000000FF00FFFF00FF0000FF0000FFFFFFFFFF00FFFFFF00
0000FF0000FFFF00FFFF0000FF00FF00FF0000FFFF00FFFF0000FF000000FFFFFF00FFFF
FFFFFF0000FF0000FF00FFFF00FF000000FF00FFFF00FF00FFFF00FFFF
FFFFFF0000FFFFFF000000FFFFFFFFFFFFFF00FF00FF000000FF00FF00FFFF000000FF00
FFFF0000FF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FF0000FFFF00FF000000FFFF
00FF00FF000000FF00FF00FFFFFFFFFFFFFF000000FFFFFF0000FFFFFF
FFFFFFFF00FF0000FFFFFFFF00FFFFFFFFFF000000FFFFFF00FFFFFF00000000FF0000FF
FFFFFF00FFFFFFFF00FFFF00FF00FF00FF00FFFF00FFFFFFFF00FFFFFFFF0000FF000000
00FFFFFF00FFFFFF000000FFFFFFFFFF00FFFFFFFF0000FF00FFFFFFFF
FFFFFFFFFF0000FF00FFFFFF00000000000000FF000000FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFF0000000000FFFF00FF00FF00FF00FFFF0000000000FFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF000000FF00000000000000FFFFFF00FF0000FFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFF00FFFF0000FFFFFF000000FFFF00FF00
00FF0000FFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFF0000FF0000FF00FFFF0000
00FFFFFF0000FFFF00FFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF00000000000000FF00FF000000FFFFFFFFFFFFFFFF0000FF00FFFFFFFF
FFFF0000FFFF00FF00FFFF00FFFFFFFFFF00FFFF00FF00FFFF0000FFFFFFFFFFFF00FF00
00FFFFFFFFFFFFFFFF000000FF00FF00000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFF00FFFF0000FFFFFFFFFF00FFFF00FFFF00FFFFFF000000FF00
000000FF00FFFFFF000000FFFFFFFFFFFFFF000000FFFFFF00FF00000000FF000000FFFF
FF00FFFF00FFFF00FFFFFFFFFF0000FFFF00FFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFF00FFFF00FFFF0000FFFFFF00FFFFFF00FF00
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF00FF00FFFFFF00
FFFFFF0000FFFF00FFFF00FFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF0000FF00FF00FF00FF00FF00FF0000FFFF000000FF00FF00
FF000000FFFFFF00FFFFFF00FFFF00FFFF00FFFFFF00FFFFFF000000FF00FF00FF000000
FFFF0000FF00FF00FF00FF00FF00FF0000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FFFFFF0000FFFFFF000000FF0000FFFFFF
0000FF0000FF0000FFFF00FF00FFFFFF00FF00FFFF0000FF0000FF0000FFFFFF0000FF00
0000FFFFFF0000FFFFFF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF0000FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF0000FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF00FFFFFF00FF00FFFF0000FF00
00FFFF00FF0000FFFF00FFFFFFFFFFFFFFFFFF00FFFF0000FF00FFFF0000FF0000FFFF00
FF00FFFFFF00FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF0000FFFF000000FFFFFF000000FFFF0000
FF00FFFFFFFF00FF00FF00FFFFFFFFFFFFFF00FF00FF00FFFFFFFF00FF0000FFFF000000
FFFFFF000000FFFF0000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FF00FF0000FFFFFFFFFFFF0000FFFF
00FF00FF0000FFFFFFFF000000000000000000FFFFFFFF0000FF00FF00FFFF0000FFFFFF
FFFFFF0000FF00FF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFF00FF000000000000FF00FFFFFF
FF00FF00FF0000FF000000FF0000FF0000FF000000FF0000FF00FF00FFFFFFFF00FF0000
00000000FF00FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFF000000FF0000FF0000FFFFFFFF
FFFFFF000000FF00FF0000FFFFFFFFFFFFFF0000FF00FF000000FFFFFFFFFFFFFF0000FF
0000FF000000FFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF0000FFFFFFFF00FFFF
00FFFFFFFFFF00FF00FFFF00FFFFFFFFFF00FFFF00FF00FFFFFFFFFF00FFFF00FFFFFFFF
0000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF00FF000000FFFF000000
00FFFF00FFFF000000FFFF00000000000000FFFF000000FFFF00FFFF00000000FFFF0000
00FF00FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF00FF0000FFFFFFFFFF
FFFF0000FFFF00FFFF00FFFFFFFFFFFFFFFFFF00FFFF00FFFF0000FFFFFFFFFFFFFF0000
FF00FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FF0000000000FF
FF00FF000000FFFFFFFF00FFFF00FF00FFFF00FFFFFFFF000000FF00FFFF0000000000FF
00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF0000FFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF000000FFFF00FFFF
FFFFFFFF00FF0000FF0000FFFFFF00FFFFFF0000FF0000FF00FFFFFFFFFFFF00FFFF0000
00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF000000FFFF
0000000000FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF0000000000FFFF000000FFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF00FFFFFF00
FF0000FF00000000FF00000000FFFFFF00000000FF00000000FF0000FF00FFFFFF00FF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF00FF000000
FFFFFFFFFFFFFFFFFF0000FF0000000000FF0000FFFFFFFFFFFFFFFFFF000000FF00FF00
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FF00
0000FFFF00FF00000000FF00FFFFFFFFFF00FF00000000FF00FFFF000000FF0000FFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFF00
00FF00FFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFF00FF0000FFFFFF0000FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFF
FFFF000000FF000000FF00FFFFFFFFFFFFFF00FF000000FF000000FFFFFFFFFF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FF00FFFF00FF00FFFF0000FFFFFFFFFFFFFF0000FFFF00FF00FFFF00FFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00
FFFF00FFFFFF0000FF0000000000000000000000FF0000FFFFFF00FFFF00FFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
0000FF00FFFF0000FFFF0000FFFF00FFFF0000FFFF0000FFFF00FF0000FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF00FF00FFFFFFFF0000FF00FFFFFF00FF0000FFFFFFFF00FF00FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFF000000FFFF00FF00FF00FF00FFFF000000FFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FFFFFFFF00FF00FFFFFF00FF00FFFFFFFF0000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFF00FF00000000FFFFFFFFFFFFFF00000000FF00FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF0000FFFFFFFF00FFFFFF00FFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF00FFFF00FF00FF00FF00FFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFF00FF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000000000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.0478024 0.588183 0.135113 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2530227051424) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000000000FFFF0000FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFF00FF000000FF0000FF
0000FF000000000000FF00FFFFFFFFFFFFFF00FF000000000000FF0000FF0000FF000000
FF00FFFFFFFFFFFFFFFFFFFF00FF0000FFFFFF0000FFFF0000000000FF
FFFF0000FF000000FFFF000000FFFFFF0000000000FF00000000FF00FFFFFFFFFF0000FF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFF
FF00FF00000000FF0000000000FFFFFF000000FFFF000000FF0000FFFF
FFFFFF0000FFFFFFFF00FFFF00000000FFFFFFFFFFFF00FFFF00FFFFFF00000000FFFF00
0000FF00000000FF00FFFFFFFFFFFFFFFFFFFFFF00FF00000000FF000000FFFF00000000
FFFFFF00FFFF00FFFFFFFFFFFF00000000FFFF00FFFFFFFF0000FFFFFF
FFFFFFFF00000000FFFFFFFFFF00FF00FFFF000000FFFFFF00FF00FF00FF00FF00000000
FFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFF00000000FF00FF
00FF00FF00FFFFFF000000FFFF00FF00FFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFF0000FF00FF0000FF00FF00FF00FFFF000000FFFFFFFFFF00FF00FF00FFFF00
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FF00FFFF00FF00FF
00FFFFFFFFFF000000FFFF00FF00FF00FF0000FF00FF0000FFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFF00FFFFFF00FF0000FF000000FF000000FFFFFFFFFF00FF
FFFF00FF00FF0000000000000000000000000000000000FF00FF00FFFFFF00FFFFFFFFFF
000000FF000000FF0000FF00FFFFFF00FFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFF000000FFFFFFFFFFFFFFFF00FFFF0000000000FFFF
FFFFFFFF0000FFFF00FFFF00FFFFFFFFFF00FFFF00FFFF0000FFFFFFFFFFFF0000000000
FFFF00FFFFFFFFFFFFFFFF000000FFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FF000000FFFFFFFF000000FF000000FFFFFF00FF0000FF000000
00000000FFFF00FFFFFFFFFFFF00FF00FFFFFFFFFFFF00FFFF00000000000000FF0000FF
00FFFFFF000000FF000000FFFFFFFF000000FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFF00000000FF000000FF000000FFFFFFFF0000FFFF00
FFFF00FFFFFFFF000000000000FFFFFF000000000000FFFFFFFF00FFFF00FFFF0000FFFF
FFFF000000FF000000FF00000000FFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF0000FF0000FFFFFFFF0000FF00FFFFFFFF
00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF00FF00
00FFFFFFFF0000FF0000FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF00000000FFFFFF00FFFF000000FF00FFFFFFFFFF
FF0000000000000000FFFF00000000000000FFFF0000000000000000FFFFFFFFFFFF00FF
000000FFFF00FFFFFF00000000FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FF00FF00FFFF0000FFFFFFFFFFFF
FFFF00FFFFFFFFFF00FF00FF0000FF0000FF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFF00
00FFFF00FF00FF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF0000FFFFFF0000FF00FFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFF0000FFFFFF0000FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
00FF0000FFFFFF0000FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000FFFF000000FFFFFF0000000000000000
00000000FFFFFF0000000000FFFFFFFFFF0000000000FFFFFF0000000000000000000000
00FFFFFF000000FFFF000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFF00000000FFFFFFFFFFFF00FF
00FFFF0000000000FF0000FFFFFFFFFFFFFF0000FF0000000000FFFF00FF00FFFFFFFFFF
FF00000000FFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FF00FFFF000000FF00FF
00FF0000FFFFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFF0000FF00FF00FF000000FF
FF00FF00FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FF00FF00FF00FFFF000000FF
FFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFF00000000FF00FFFFFFFF000000FFFF00
FF00FF00FF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FFFFFF00FF0000FF0000
FFFF00FFFFFF00FFFF0000FF0000FF0000FF0000FFFF00FFFFFF00FFFF0000FF0000FF00
FFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF000000FFFFFFFFFF00
0000FFFFFFFFFFFF00FFFF00FF000000FF00FFFF00FFFFFFFFFFFF000000FFFFFFFFFF00
0000FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000FFFFFFFF000000FF0000
FF00000000000000FFFFFFFF0000FF0000FFFFFFFF00000000000000FF0000FF000000FF
FFFFFF000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00000000FF000000FF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF000000FF0000
0000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF0000FF0000
FF000000FFFF0000000000000000FF0000000000000000FFFF000000FF0000FF0000FFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00000000FFFFFF00
0000FF000000FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF000000FF000000FFFFFF000000
00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FF00
FFFF0000FF00000000FF00FFFFFFFFFFFFFF00FF00000000FF0000FFFF00FF0000FFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF0000FFFF
FF00FFFF0000FFFFFFFFFF00000000000000FFFFFFFFFF0000FFFF00FFFFFF0000FFFF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000FFFF0000
00FFFFFFFF00FF0000000000FFFFFFFFFF0000000000FF00FFFFFFFF000000FFFF000000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFF
000000000000FFFFFFFFFF00FF000000FF00FFFFFFFFFF000000000000FFFF00FFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FF00FFFFFFFF000000FFFF000000FF000000FFFF000000FFFFFFFF00FFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000
FF00FF00000000FF000000FFFF00FF00FFFF000000FF00000000FF00FF0000FF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFF00000000FF00000000FFFFFFFFFF00000000FF00000000FFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFF000000FFFF00FF000000000000000000FF00FFFF000000FFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFF000000FFFFFF00FFFF00FFFF00FFFFFF000000FFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF00FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000FF00FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FF0000FFFFFF00FFFFFF00FFFFFF0000FF0000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FF000000FF00FFFF0000FF0000FFFF00FF000000FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FF0000FFFFFFFFFFFFFF0000FF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF00FFFF00000000000000FFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFF00FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000000000FF00FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FF0000FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.0478024 0.782187 0.135113 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2541477777104) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000000000FFFFFFFFFFFFFFFF00FFFF00000000FFFF000000FFFFFFFF000000FFFF00
00FFFFFFFFFFFF000000FFFF00FFFFFF00FFFF000000FFFFFFFFFFFF0000FFFF000000FF
FFFFFF000000FFFF00000000FFFF00FFFFFFFFFFFFFFFF0000000000FF
FFFF00FFFFFF0000FF00FF0000FFFFFF000000000000FFFFFFFFFF0000FF00FFFFFF0000
0000FF0000FF0000000000FF00FF00FF00FF0000000000FF0000FF00000000FFFFFF00FF
0000FFFFFFFFFF000000000000FFFFFF0000FF00FF0000FFFFFF00FFFF
FFFFFF0000FFFFFF000000FFFFFF00FFFFFFFFFFFFFF0000FF0000FFFF000000FFFF00FF
FFFF00000000FFFFFF00FFFFFF000000FFFFFF00FFFFFF00000000FFFFFF00FFFF000000
FFFF0000FF0000FFFFFFFFFFFFFF00FFFFFF000000FFFFFF0000FFFFFF
FFFFFFFF00FFFF0000000000FFFF00FF0000FFFF00FF00FFFFFFFF0000FFFF00FF000000
FF00FFFFFFFF00FF000000FF0000000000FF000000FF00FFFFFFFF00FF000000FF00FFFF
0000FFFFFFFF00FF00FFFF0000FF00FFFF0000000000FFFF00FFFFFFFF
FFFFFFFFFF0000FFFF00FFFF0000FFFFFF00FFFF00FF00FF0000FFFFFFFF000000FFFF00
FFFFFF0000FFFFFF00FFFF00000000000000FFFF00FFFFFF0000FFFFFF00FFFF000000FF
FFFFFF0000FF00FF00FFFF00FFFFFF0000FFFF00FFFF0000FFFFFFFFFF
FFFFFFFFFFFF00FF000000FF00FFFFFFFFFF0000FFFFFF00000000FF0000FFFFFFFF0000
00FF00000000FF000000FF00FFFFFFFFFF00FF000000FF00000000FF000000FFFFFFFF00
00FF00000000FFFFFF0000FFFFFFFFFF00FF000000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF0000FF00FFFFFF00000000FFFF00FFFF
00FF00FFFF00FF00FFFF000000FF00FF000000FFFF00FF00FFFF00FF00FFFF00FFFF0000
0000FFFFFF00FF0000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF0000FF0000FF0000FFFF000000FF00FFFFFFFF00FFFFFF00
0000FFFFFFFF000000FF00FFFF000000FFFF00FF000000FFFFFFFF000000FFFFFF00FFFF
FFFF00FF000000FFFF0000FF0000FF0000FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFF00000000FFFF0000FFFF00FFFFFF0000FFFFFF00FFFF
FFFFFFFFFFFFFFFF00FF00FF0000000000FF00FF00FFFFFFFFFFFFFFFFFFFF00FFFFFF00
00FFFFFF00FFFF0000FFFF00000000FFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFF000000000000FFFFFFFF000000FF00000000FF000000FF
0000FF0000FF0000FFFFFF00000000000000FFFFFF0000FF0000FF0000FF000000FF0000
0000FF000000FFFFFFFF000000000000FFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF00FFFF00FFFFFFFFFFFF00FFFF0000000000
FFFF00000000FFFF0000FF00FFFFFFFFFF00FF0000FFFF00000000FFFF0000000000FFFF
00FFFFFFFFFFFF00FFFF00FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF00FF000000FF0000FF000000FFFFFFFFFFFF
FF000000000000FFFFFF000000FF00FF000000FFFFFF000000000000FFFFFFFFFFFFFF00
0000FF0000FF000000FF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF00FFFF00FFFF0000FF00
00FFFFFFFFFFFFFF00FF00FFFF000000FFFF00FF00FFFFFFFFFFFFFF0000FF0000FFFF00
FFFF00FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF0000FFFFFF000000FF00FFFFFF
FF0000FF0000FF000000FFFFFFFF00FFFFFFFF000000FF0000FF0000FFFFFFFF00FF0000
00FFFFFF0000FF00FF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF000000FFFFFF00FFFFFFFF000000FF00
00FFFF00000000FFFFFF0000FF000000FF0000FFFFFF00000000FFFF0000FF000000FFFF
FFFF00FFFFFF000000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000000000FFFF00FF0000FFFFFFFF0000
0000FFFFFFFFFFFF0000FFFF0000000000FFFF0000FFFFFFFFFFFF00000000FFFFFFFF00
00FF00FFFF0000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF0000FFFFFF00FFFF0000FFFF
FF00FFFF0000FF00000000FF00FFFFFF00FF00000000FF0000FFFF00FFFFFF0000FFFF00
FFFFFF0000FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF00FFFFFFFFFF0000FFFF0000
FF00FF00000000FFFFFF00FF00FF00FF00FF00FFFFFF00000000FF00FF0000FFFF0000FF
FFFFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF0000FFFF
000000FFFFFFFFFF0000FFFFFF000000FFFFFF0000FFFFFFFFFF000000FFFF0000FFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF0000FF0000FFFF0000
FFFFFFFF0000FF00000000FF0000000000FF00000000FF0000FFFFFFFF0000FFFF0000FF
0000FF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00000000FFFF0000FFFF
0000FFFF00FFFFFFFFFFFF00000000000000FFFFFFFFFFFF00FFFF0000FFFF0000FFFF00
000000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000000000FFFFFFFF00
000000FF00FF0000FFFF000000000000000000FFFF0000FF00FF00000000FFFFFFFF0000
00000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF00FFFF00FFFF
FFFFFF000000FFFF0000FFFFFFFFFFFFFFFFFF0000FFFF000000FFFFFFFFFF00FFFF00FF
FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF00FF000000FF
0000FFFFFFFFFFFFFFFF0000FFFF00FFFF0000FFFFFFFFFFFFFFFF0000FF000000FF00FF
000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFF00FFFF0000FF0000FFFF00FFFFFF00FFFF0000FF0000FFFF00FFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF00
00FFFFFF00FFFF00000000FFFFFF00FFFFFF00000000FFFF00FFFFFF0000FF00FF0000FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF000000FF
FFFF00FFFFFF000000000000FF000000FF000000000000FFFFFF00FFFFFF000000FFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000000000
FFFF00FF0000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF0000FF00FFFF0000000000FFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF
0000FFFFFF00FF0000FF0000FF000000FF0000FF0000FF00FFFFFF0000FFFF00FFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF
00FFFFFFFFFF00000000FFFF0000000000FFFF00000000FFFFFFFFFF00FF000000FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
0000FF0000FF0000FF0000FFFFFFFFFFFFFF0000FF0000FF0000FF0000FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFF00000000FFFF00000000FFFF00FFFF00000000FFFF00000000FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FF000000000000FFFFFFFF00FF000000FF00FFFFFFFF000000000000FFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFF00FFFF00FFFF0000FFFFFF00FFFFFF0000FFFF00FFFF00FFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF000000FF00FF00000000FF000000FF00000000FF00FF000000FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FFFFFFFFFFFF0000000000FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFF0000FF00FF00000000000000FF00FF0000FFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFF000000FFFFFFFFFFFFFF000000FFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF0000000000FFFF00FFFF0000000000FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF00FFFF00FFFFFF00FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF000000FFFFFF00FFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FF000000FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF0000000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.0478024 0.97619 0.135113 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.143844 0.200176 0.231154 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2224520572159) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FFFFFF000000FFFFFF00FFFFFFFF00FF00FF0000FFFF0000FF0000FFFF000000
000000FFFFFFFF000000000000000000000000000000FFFFFFFF000000000000FFFF0000
FF0000FFFF0000FF00FF00FFFFFFFF00FFFFFF000000FFFFFF000000FF
FFFFFF00FF0000FFFF00FF000000FFFFFF00FF00FF00FF00000000FF00FF00000000FF00
FFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFF00FF00000000FF
00FF00000000FF00FF00FF00FFFFFF000000FF00FFFF0000FF00FFFFFF
FFFFFF000000FF00FFFFFFFFFFFF0000FF00FF00FF00FF00FFFF00FF00FF00FFFFFF0000
FFFF000000FF0000000000000000000000000000000000FF000000FFFF0000FFFFFF00FF
00FF00FFFF00FF00FF00FF00FF0000FFFFFFFFFFFF00FF000000FFFFFF
FFFFFFFFFF00FF00FF000000000000FF00FF00FF00FF00FF00FFFFFFFFFFFFFF00FFFFFF
0000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF0000FFFFFF00FFFFFF
FFFFFFFF00FF00FF00FF00FF00FF000000000000FF00FF00FFFFFFFFFF
FFFFFFFFFF000000FFFFFF00FFFF00FF00FF00FF00FF00FF00FF0000000000FF00FF0000
00FFFFFFFFFF0000000000000000000000000000000000FFFFFFFFFF000000FF00FF0000
000000FF00FF00FF00FF00FF00FF00FFFF00FFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF00FF
FF00000000FF00FFFF00FFFF00FFFFFF00FFFF00FFFF00FF00000000FFFF00FFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF0000FF0000000000FF00FF00FF000000000000000000FF00FF
FF00FFFF00FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00FFFF00FFFF00FF00000000
0000000000FF00FF00FF0000000000FF0000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF
0000FFFF00FF00000000FF0000FFFFFF0000FF00000000FF00FFFF0000FF00FFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFF000000000000FF000000000000000000FFFFFFFFFF
FFFF0000FFFFFFFFFF00FFFFFF000000FFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFF0000
00000000000000FF000000000000FFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF0000FFFF00FFFF00FFFFFF00FFFFFF00FFFF0000FF0000
000000FF00FFFFFFFF00FF000000FF000000FF00FFFFFFFF00FF0000000000FF0000FFFF
00FFFFFF00FFFFFF00FFFF00FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFF0000000000FFFF00FFFFFF00
FFFF00FF00FF0000FF00FFFFFF00FF00FFFFFF00FF0000FF00FF00FFFF00FFFFFF00FFFF
0000000000FFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00000000FF0000FFFFFFFF00FF0000FFFFFF00
000000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FF
00FFFFFFFF0000FF00000000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00FFFFFF00FFFF00FFFFFFFFFF0000FF00
FFFF00FF000000000000FF0000FFFFFF0000FF000000000000FF00FFFF00FF0000FFFFFF
FFFF00FFFF00FFFFFF00FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFF0000FF00FF0000000000FF00FF
00FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF00FF00FF00000000
00FF00FF0000FFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FF0000FF00FF00FF00FFFF00FF00FF
00FF00000000000000000000FFFF00FFFF00000000000000000000FF00FF00FF00FFFF00
FF00FF00FF0000FF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FF00FF00FFFF000000FF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF000000FFFF00
FF00FF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFF0000FFFF00FF
0000000000000000000000FFFFFF00FFFFFF0000000000000000000000FF00FFFF0000FF
FFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFF00FF00000000FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000
0000FF00FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFF00FF00FF0000
000000000000000000000000FFFFFFFFFF0000000000000000000000000000FF00FF00FF
FFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00FFFF00FF00000000
00000000000000000000000000FFFFFF0000000000000000000000000000000000FF00FF
FF00FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FF000000000000
0000000000000000000000000000FF0000000000000000000000000000000000000000FF
0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF0000000000
000000000000000000000000FFFFFFFFFF0000000000000000000000000000000000FFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFF00FFFF
00FF00FFFF00FFFFFF00FFFF0000FF0000FFFF00FFFFFF00FFFF00FF00FFFF00FFFF0000
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFF000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF000000
00FF00000000FF00FF00000000FFFFFF00000000FF00FF00000000FF00000000FF00FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00
FFFFFF00FFFFFF000000FFFFFFFF00FFFFFFFF000000FFFFFF00FFFFFF00FFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000
FFFFFF000000FF00FFFF000000FF00FF000000FFFF00FF000000FFFFFF000000FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00
00FF0000FF000000FFFF0000FFFFFFFFFF0000FFFF000000FF0000FF0000FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FFFFFF00FF00FFFFFFFFFFFF0000000000FFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFF000000FFFFFFFFFFFF0000FF0000FFFFFFFFFFFF000000FFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF0000FFFF00FF0000FF0000FFFFFFFFFF0000FF0000FF00FFFF0000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FF00FFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFF00FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF000000000000FFFF000000FFFF000000000000FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFF00FFFF00FFFFFFFFFFFFFF00FFFF00FFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF000000FFFF0000FF000000FF0000FFFF000000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FF0000FF00FFFFFFFFFFFFFF00FF0000FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFF00000000000000FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFF0000FFFFFF0000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF0000FFFF000000FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF00FFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF000000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.143844 0.39418 0.231154 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2224520591871) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF0000FF
0000FFFFFFFFFFFFFFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFF0000FF0000FFFFFF00
FFFF00FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFF000000FF
FFFFFF00FFFFFFFF000000000000FFFF00000000FF000000000000FFFF000000FF00FFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF000000
FFFF000000000000FF00000000FFFF000000000000FFFFFFFF00FFFFFF
FFFFFF0000000000FFFF00FFFF0000FF00FFFF00FF00FFFF00FFFFFFFFFFFF00FF00FFFF
FF000000000000000000000000FF00FF000000000000000000000000FFFFFF00FF00FFFF
FFFFFFFF00FFFF00FF00FFFF00FF0000FFFF00FFFF0000000000FFFFFF
FFFFFFFFFF00FFFF000000FFFFFFFF0000FFFF0000FFFFFFFF000000000000FFFFFFFFFF
FFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFF0000
00000000FFFFFFFF0000FFFF0000FFFFFFFF000000FFFF00FFFFFFFFFF
FFFFFFFFFF000000FFFF0000000000FFFFFFFFFFFF000000FF00FFFFFFFF00FF00000000
000000FFFFFFFFFFFFFF00000000FF00000000FFFFFFFFFFFFFF00000000000000FF00FF
FFFFFF00FF000000FFFFFFFFFFFF0000000000FFFF000000FFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFF00FFFF000000000000FFFFFF0000FFFFFFFF0000FFFFFFFF
00FFFF000000FF000000FFFF00FFFFFF00FFFF000000FF000000FFFF00FFFFFFFF0000FF
FFFFFF0000FFFFFF000000000000FFFF00FFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFF00FFFF00FF0000FFFFFFFFFFFFFFFF00000000
FFFFFFFF00FFFFFF00FFFFFFFF000000FFFFFFFF00FFFFFF00FFFFFFFF00000000FFFFFF
FFFFFFFFFF0000FF00FFFF00FFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF000000FF0000FFFF0000FFFF0000000000000000FFFFFFFF
000000FF00FFFFFF00FF000000FFFFFF000000FF00FFFFFF00FF000000FFFFFFFF000000
0000000000FFFF0000FFFF0000FF000000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFF0000FFFFFFFFFFFF0000FFFFFFFF00FFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
00FFFFFFFF0000FFFFFFFFFFFF0000FFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF000000000000FFFF00000000FFFFFFFFFF00FFFF
0000FF00000000000000FF00FF000000FF00FF00000000000000FF0000FFFF00FFFFFFFF
FF00000000FFFF000000000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFF00FFFF0000FF00FFFF00FF000000FF00FF00
00FFFFFFFFFF00FFFF00FF00FF00FF00FF00FF00FFFF00FFFFFFFFFF0000FF00FF000000
FF00FFFF00FF0000FFFF00FFFF0000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000FFFFFFFF0000FFFF0000FFFFFFFFFFFFFF
000000FF0000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFF0000FF000000FFFFFFFFFFFFFF
0000FFFF0000FFFFFFFF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000000000FFFFFFFFFFFF00000000FF0000
00FF0000FFFF000000FF00000000FF00000000FF000000FFFF0000FF000000FF00000000
FFFFFFFFFFFF0000000000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFF000000000000FFFFFF00FF00FF
FFFFFFFF0000FFFF00FF00FFFF000000FFFF00FF00FFFF0000FFFFFFFFFF00FF00FFFFFF
000000000000FFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF00FFFF00FF0000FFFFFF00
00000000FFFF0000FFFFFF000000FF000000FFFFFF0000FFFF0000000000FFFFFF0000FF
00FFFF00FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000FF0000FFFF0000FFFF000000FF
FFFF00FFFFFFFFFF000000FFFF000000FFFF000000FFFFFFFFFF00FFFFFF000000FFFF00
00FFFF0000FF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FFFFFFFFFFFF0000FFFFFFFF
FFFFFF000000FF0000FFFF000000FF000000FFFF0000FF000000FFFFFFFFFFFFFF0000FF
FFFFFFFFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF000000000000FFFF0000FF00
0000FF00FF0000FFFFFFFF00FFFFFFFFFF00FFFFFFFF0000FF00FF000000FF0000FFFF00
0000000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF00FFFF0000FF00FFFFFF
00FFFFFFFFFFFF0000000000FFFFFFFFFF0000000000FFFFFFFFFFFF00FFFFFF00FF0000
FFFF00FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000FFFFFFFF0000FFFFFF
00FF0000000000FFFF00FFFFFFFFFFFFFFFFFF00FFFF0000000000FF00FFFFFF0000FFFF
FFFF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000000000FFFFFFFFFF
FFFFFF00FFFF00FF0000FFFFFFFFFFFFFFFFFF0000FF00FFFF00FFFFFFFFFFFFFFFF0000
000000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFF0000000000
0000FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FF00000000000000FFFF
00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF00FFFF
00FFFFFFFFFFFFFF00000000000000000000000000FFFFFFFFFFFFFF00FFFF00FFFFFFFF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000FF0000FFFF
00FF000000000000FFFFFFFFFFFF00FFFFFFFFFFFF000000000000FF00FFFF0000FF0000
00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FFFFFFFF
FFFFFF00FFFFFFFF0000FF0000FF00FF0000FF0000FFFFFFFF00FFFFFFFFFFFFFF0000FF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00000000
0000FF00FF0000FF00FFFFFF00FF00FF00FFFFFF00FF0000FF00FF000000000000FFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF00FF
FF0000FFFFFF00FF00FFFFFF00FF00FF00FFFFFF00FF00FFFFFF0000FFFF00FFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000FF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF000000FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000
000000FFFF00FF00000000000000FF00000000000000FF00FFFF0000000000FFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
00FFFF0000FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF0000FFFF00FFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
000000FF0000FF00FF000000FF00FF00FF000000FF00FF0000FF000000FFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFF0000FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF0000FFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFF0000000000FF00FF0000000000FF00FF0000000000FFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FFFF0000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFF000000000000FF000000FF000000000000FFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFF00FFFF00FF00FF00FF00FFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF000000FF0000000000FF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFF00FF00FFFFFF00FF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FF000000FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF0000FF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.143844 0.588183 0.231154 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2518200302150) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FF00FFFFFFFF0000FFFFFF00000000FF00FFFFFFFF000000FFFF00000000FFFF
00FFFF00FFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFF00FFFF00FFFF00FFFF00000000FF
FF000000FFFFFFFF00FF00000000FFFFFF0000FFFFFFFF00FF000000FF
FFFF00FFFFFF00FF00FF00FFFFFFFFFF00FFFF000000FF00FFFFFF00FF000000000000FF
FFFF000000FFFFFF0000FF000000FF000000FF0000FFFFFF000000FFFFFF000000000000
FF00FFFFFF00FF000000FFFF00FFFFFFFFFF00FF00FF00FFFFFF00FFFF
FFFFFF00FF000000FFFFFFFF0000FF000000FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFF
0000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF0000FFFFFFFFFFFFFF
FFFFFF00FF00FFFFFFFFFF000000FF0000FFFFFFFF000000FF00FFFFFF
FFFFFFFF0000000000FFFF00000000FFFF00FF00FFFF00FFFFFF0000FF0000FF00FFFF00
FFFF00FFFFFFFF0000FFFF00FF00FF00FF00FFFF0000FFFFFFFF00FFFF00FFFF00FF0000
FF0000FFFFFF00FFFF00FF00FFFF00000000FFFF0000000000FFFFFFFF
FFFFFFFFFF00FFFFFFFF000000000000FFFFFFFF0000FFFFFFFFFF00FF00FFFFFF0000FF
FFFFFF0000FF00FFFF00FFFFFF00FF00FFFFFF00FFFF00FF0000FFFFFFFF0000FFFFFF00
FF00FFFFFFFFFF0000FFFFFFFF000000000000FFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFF00FF00FFFFFFFFFFFFFF0000FF00000000FF0000FFFFFFFFFF00FFFFFFFF
00FF00000000FFFFFFFF0000FFFFFFFFFF0000FFFFFFFF00000000FF00FFFFFFFF00FFFF
FFFFFF0000FF00000000FF0000FFFFFFFFFFFFFF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF00FF00FF00FFFF000000000000FFFF0000FFFF000000FFFF00
0000FFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFF000000FFFF000000FF
FF0000FFFF000000000000FFFF00FF00FF00FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF00
FFFFFF000000FF00FFFF0000FF000000FF0000FFFF00FF000000FFFFFF00FF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF0000000000FF0000FFFFFFFF0000FFFF0000FFFFFFFFFFFFFF
FF00FF00FFFF000000FFFFFFFFFF00FFFFFFFFFF000000FFFF00FF00FFFFFFFFFFFFFFFF
0000FFFF0000FFFFFFFF0000FF0000000000FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000000000FFFF0000FF00000000FFFFFFFF0000FF00FF00
00FFFFFFFF0000000000FF00FF000000FF00FF0000000000FFFFFFFF0000FF00FF0000FF
FFFFFF00000000FF0000FFFF00000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000
0000FF00FF00FFFF00FFFFFF0000000000FFFFFF00FFFF00FF00FF00000000FFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF00FFFFFFFF00000000FF00FF000000
000000FFFFFFFF000000FF00000000000000FF000000FFFFFFFF000000000000FF00FF00
000000FFFFFFFF00FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FF000000FF0000FFFF00FFFFFF00000000
00000000FF00FF00FFFF000000000000000000FFFF00FF00FF0000000000000000FFFFFF
00FFFF0000FF000000FF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFF00FFFFFFFF00FF0000000000
0000000000FFFFFFFF0000000000000000000000FFFFFFFF00000000000000000000FF00
FFFFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFF00FFFFFFFFFFFF000000000000
000000000000FF0000FFFFFFFFFFFFFFFFFFFFFF0000FF000000000000000000000000FF
FFFFFFFFFF00FFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF000000FFFF00FF00000000000000
00000000000000FFFFFF00FF00FF00FF00FF00FFFFFF0000000000000000000000000000
FF00FFFF000000FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF000000FFFF00FFFF00FF
FFFFFFFFFFFFFFFF0000FFFFFF000000FFFFFF0000FFFFFFFFFFFFFFFFFF00FFFF00FFFF
000000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF0000FF00FFFFFF00FFFFFFFF00
FF00FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF00FF00FFFFFFFF00FF
FFFF00FF0000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFF0000FFFFFFFFFFFF
000000FF0000FFFFFF00FF0000FF00FF0000FF00FFFFFF0000FF000000FFFFFFFFFFFF00
00FFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00FF00FFFFFFFFFFFFFF
FF00FFFFFF00FFFF000000FFFF000000FFFF000000FFFF00FFFFFF00FFFFFFFFFFFFFFFF
00FF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFF0000FF0000FF
000000FF000000FFFFFFFFFF0000000000FFFFFFFFFF000000FF000000FF0000FF0000FF
FFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF00000000FFFF00
00000000FFFFFFFF00FF0000FFFFFFFFFF0000FF00FFFFFFFF0000000000FFFF00000000
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF000000000000FFFF
FFFFFFFFFF00FF000000FFFF00FF00FF00FFFF000000FF00FFFFFFFFFFFFFF0000000000
00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF0000
FF00FF0000FFFFFF00FFFFFFFF000000FFFFFFFF00FFFFFF0000FF00FF0000FFFFFFFFFF
FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FFFF
000000FFFF00FF00FFFFFFFFFFFF00FFFFFFFFFFFF00FF00FFFF000000FFFF00FF00FF00
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF000000FFFFFF
FFFFFFFFFFFF000000FF0000FFFF00FFFF0000FF000000FFFFFFFFFFFFFFFFFF000000FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000FF00
00FFFFFFFFFFFFFFFF00000000FFFFFF00000000FFFFFFFFFFFFFFFF0000FF0000000000
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FF
FF0000FF0000FF00FFFFFFFFFFFF00FFFFFFFFFFFF00FF0000FF0000FFFF000000000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFF00FFFFFF0000FFFF00FF00FF00FFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF
FFFFFF000000FF00000000FF00FFFFFF00FF00000000FF000000FFFFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00
00FF0000000000FFFF00FFFFFFFF00FFFFFFFF00FFFF0000000000FF0000FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
00FFFFFFFFFFFFFFFFFF00FFFF000000FFFF00FFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
0000FFFFFFFF0000FF000000FFFFFFFFFF000000FF0000FFFFFFFF000000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000FF0000FFFF0000000000FFFFFF0000000000FFFF0000FF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFF00000000000000FF00000000000000FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFF0000FFFF00FFFFFFFFFFFFFFFFFF00FFFF0000FFFF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FF00FFFFFFFFFF00FF00FF00FF00FFFFFFFFFF00FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFF00FF0000FFFFFF00FF00FFFFFF0000FF00FFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF000000FFFF0000FFFFFFFFFF0000FFFF000000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000000000FFFFFFFFFF00FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFF0000FF000000FF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF00FFFFFFFFFF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF00FF000000FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF0000000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00000000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.143844 0.782187 0.231154 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2518200321863) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FF00000000FFFF000000FF00FFFFFFFFFFFF000000FFFFFFFFFFFF000000FFFFFF
0000000000FF00FFFFFFFFFFFF000000FFFFFFFFFFFF00FF0000000000FFFFFF000000FF
FFFFFFFFFF000000FFFFFFFFFFFF00FF000000FFFF00000000FF0000FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFF00FF0000FFFFFFFF00FF
FFFFFFFFFFFF00FFFF0000FF0000000000FF0000FFFF00FFFFFFFFFFFFFF00FFFFFFFF00
00FF00FFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFF00FFFFFFFF0000FF00FF0000FFFFFF000000FF00FF0000FFFFFFFFFFFFFF000000
FF00FF00FFFFFFFF00000000FFFFFFFFFF00000000FFFFFFFF00FF00FF000000FFFFFFFF
FFFFFF0000FF00FF000000FFFFFF0000FF00FF0000FFFFFFFF00FFFFFF
FFFFFFFF0000FF00000000FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF00FF00000000
00FFFFFF0000FFFFFFFFFF00FFFF00FFFF00FFFFFFFFFF0000FFFFFF0000000000FF00FF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFF00000000FF0000FFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF0000FF000000FFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFF000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF000000
FF0000FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFF0000FF000000FFFFFF00FF0000FF00000000FFFF00FFFF00FF
FFFFFFFFFFFF000000FFFF00FFFFFFFFFF00FFFF000000FFFFFFFFFFFFFF00FFFF00FFFF
00000000FF0000FF00FFFFFF000000FF0000FFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF00000000FFFF00FF0000FFFFFF00FFFFFFFFFFFFFFFFFF000000
FFFF00FFFF0000000000FF00FF00FF00FF00FF0000000000FFFF00FFFF000000FFFFFFFF
FFFFFFFFFF00FFFFFF0000FF00FFFF00000000FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFF00FF0000FFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF0000
FF00FFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFF0000FF00FFFFFFFFFFFFFF0000FFFFFFFFFF00FFFFFF
0000000000FF00FF00FF00FF00FFFFFF00FF00FF00FF00FF0000000000FFFFFF00FFFFFF
FFFF0000FFFFFFFFFFFFFF00FF0000FFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00
000000000000FFFFFF000000FFFFFFFFFF000000FFFFFF00000000000000FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FF0000FF00FFFF00000000FFFFFFFFFFFF
FFFF00FF00FFFF00FFFF00FF0000FF0000FF00FFFF00FFFF00FF00FFFFFFFFFFFFFFFF00
000000FFFF00FF0000FF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFF000000FF00FFFFFFFFFFFF00FF00
00FF00FFFFFF000000FFFFFF00FFFFFF00FFFFFF000000FFFFFF00FF0000FF00FFFFFFFF
FFFF00FF000000FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF00
FFFFFF00FF0000000000FF00FFFFFFFFFF00FF0000000000FF00FFFFFF00FFFFFF00FFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FF00FF0000FFFFFF000000FF00FF
FFFFFFFF00000000000000FFFFFFFFFFFFFF00000000000000FFFFFFFFFF00FF000000FF
FFFF0000FF00FF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FF000000FFFFFF00FF0000
FF0000FF0000FFFFFF0000FF0000FF0000FF0000FFFFFF0000FF0000FF0000FF00FFFFFF
000000FF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFF00FF0000FFFFFF00
FFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFF00FFFFFF0000FF
00FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFF
00FFFF00FFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFF00FFFF00FFFFFFFFFF00FF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FF00FFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF00
FF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF0000FFFF0000FFFFFFFFFF0000FFFF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FF0000FF00
FFFF00000000FFFF0000FFFF0000FF0000FFFF0000FFFF00000000FFFF00FF0000FF0000
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFF0000
00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFF000000
00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF00FFFFFFFFFFFF00FFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FF00
FF0000FFFFFF000000FF0000FF000000FF0000FF000000FFFFFF0000FF00FF0000FFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF
FFFFFFFFFF0000000000FFFF0000000000FFFF0000000000FFFFFFFFFFFF00000000FF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00
00FF000000FFFFFFFF00FF00FFFF00FFFF00FF00FFFFFFFF000000FF0000FFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000
0000FFFF00FF0000FF00FFFFFF000000FFFFFF00FF0000FF00FFFF00000000FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFF0000FF00FFFFFFFFFF0000FFFFFF0000FFFFFFFFFF00FF0000FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00000000FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFF0000FF0000FF00FFFFFFFFFF00FF0000FF0000FFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF00000000FFFF000000FFFFFF000000FFFF00000000FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFF0000FFFFFF000000FFFFFF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FF00000000FF0000000000FF00000000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFF00FF00FF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF000000FFFFFF000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.143844 0.97619 0.231154 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2518200341575) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FF0000FFFFFFFFFF0000FF00FF0000FF00000000FFFFFFFF00FFFFFFFFFFFF00FF
00000000000000FFFF00FFFFFFFFFFFFFFFFFF00FFFF00000000000000FF00FFFFFFFFFF
FF00FFFFFFFF00000000FF0000FF00FF0000FFFFFFFFFF0000FF0000FF
FFFF00FFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00
FF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF0000FF00FFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFF00FFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFF
0000FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF0000FFFFFFFFFFFFFF
FFFFFF000000FF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFF0000FF0000FF0000FF00FF00FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FFFF000000000000FF000000000000FFFF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF0000FF00FF00FF0000FF0000FF0000FFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFFFF00FF000000FF0000FF0000FF00
0000FFFFFF00000000FFFF00FFFFFFFFFF00FFFF00000000FFFFFF000000FF0000FF0000
FF000000FF00FFFFFFFFFFFF00FFFFFF00FFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF0000FFFFFFFFFF00000000FF00FF00FFFF00FFFFFFFFFFFFFF00
FFFF00FFFFFFFFFFFFFF0000FFFF00FFFF0000FFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFF
FF00FFFF00FF00FF00000000FFFFFFFFFF0000FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFFFF00FFFFFFFFFF00FF
FFFFFF000000FFFF00FFFFFFFF00FF00FFFFFFFF00FFFF000000FFFFFFFF00FFFFFFFFFF
00FFFFFFFF0000FFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF0000FF0000FFFF
FFFFFFFFFFFFFF0000FFFFFF00FF00FF00FFFFFF0000FFFFFFFFFFFFFFFFFF0000FF0000
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF0000FF00FF00FF00FF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF00FF00000000000000FFFF00FF0000
00FF00000000FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00000000FF000000FF00FFFF00
000000000000FF00FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFF00FF0000FF0000FF00FF00FFFFFF
FFFF0000FF00000000FF00FFFF00FF00FFFF00FF00000000FF0000FFFFFFFFFF00FF00FF
0000FF0000FF00FFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFF0000FF00FF0000FFFFFF00FFFF
FFFF0000FFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF0000FFFFFFFF00FFFFFF00
00FF00FF0000FFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFF0000
FF0000FF00FFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFF00FF0000FF0000FFFFFFFFFF
00FF00FF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF00FF00FF0000FF0000FF00
FFFF000000FF00FFFF00FFFFFFFFFFFFFFFFFF00FFFF00FF000000FFFF00FF0000FF0000
FF00FF00FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF00FFFFFFFFFF00FFFF
FF00FFFF00FF00FFFF0000000000000000000000FFFF00FF00FFFF00FFFFFF00FFFFFFFF
FF00FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFFFF00
0000FFFF00FFFFFFFF0000FF0000FF0000FF0000FFFFFFFF00FFFF000000FFFFFFFFFFFF
00FFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFF00000000FF00FF
0000FFFFFFFF000000FFFF0000FF00FF0000FFFF000000FFFFFFFF0000FF00FF00000000
FFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFF0000
FFFF000000FFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFF000000FFFF0000FFFFFF00FF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF00FF00FFFF
FFFFFFFF00FF00FF00000000FF00FF00FF00000000FF00FF00FFFFFFFFFFFF00FF00FF00
00FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF00FF00
0000000000FFFFFFFF00FFFF00FF00FF00FFFF00FFFFFFFF000000000000FF00FF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFF00FF
0000FF0000FFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFF0000FF0000FF00FFFFFF00FF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFF00
00FF00FF0000FF0000FF00FF00FF00FF00FF00FF0000FF0000FF00FF0000FFFFFFFFFF00
00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
00FF00FF00FFFFFFFFFF00FF00FF00FF00FF00FFFFFFFFFF00FF00FF00FFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF00FFFFFF00FF00FFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000
FF00FF00FF0000FF0000FFFF00FF00FF00FFFF0000FF0000FF00FF00FF0000FF0000FF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FF00FFFFFFFFFF00FF00FF00FF00FF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
00FFFFFF00FFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFF00FFFFFF00FFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000
FFFFFFFFFF00000000FF00FF00FFFFFF00FF00FF00000000FFFFFFFFFF0000FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFF00FFFFFF0000FFFFFFFFFF0000FFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000FF0000FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF0000FF0000FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFF00FF00FF00000000000000FF00FF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFF00FFFFFF00FF0000FF0000FF00FFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF0000FFFFFFFFFF0000FF00FF0000FFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FF0000FF0000FF00FF00FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF0000FFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.239885 0.200176 0.327195 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2223744548564) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FFFFFFFFFF000000FF000000FF000000FFFF00FFFF0000FFFF0000FF0000FFFF
FF00FF000000FF00FFFFFFFF00FFFFFF00FFFFFFFF00FF000000FF00FFFFFF0000FF0000
FFFF0000FFFF00FFFF000000FF000000FF000000FFFFFFFFFF000000FF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFF000000FFFF000000FF000000FFFF000000FFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFF000000FFFF0000FFFFFFFFFF0000FFFFFFFFFFFF00FFFF00FFFFFF000000FFFFFF
00FF0000FFFFFFFF00FFFF00FFFFFFFFFF00FFFF00FFFFFFFF0000FF00FFFFFF000000FF
FFFF00FFFF00FFFFFFFFFFFF0000FFFFFFFFFF0000FFFF000000FFFFFF
FFFFFFFFFFFF00FFFFFF0000FFFF00FFFF00FFFFFFFFFF00FF000000FF0000000000FF00
0000FFFFFFFFFFFF00FFFF00FFFFFFFFFF00FFFF00FFFFFFFFFFFF000000FF0000000000
FF000000FF00FFFFFFFFFF00FFFF00FFFF0000FFFFFF00FFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFF000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF000000FFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFF00FF0000000000FFFF00FFFF0000FFFFFF0000FFFFFFFF
FF00FF00FFFF0000FF00FFFFFFFFFFFFFFFFFF00FF0000FFFF00FF00FFFFFFFFFF0000FF
FFFF0000FFFF00FFFF0000000000FF00FFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFF000000FFFFFFFFFF00FF00FF00000000FF00000000FF0000
FFFFFFFFFF00FFFF000000FF0000FF0000FF000000FFFF00FFFFFFFFFF0000FF00000000
FF00000000FF00FF00FFFFFFFFFF000000FFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF00FF000000FFFFFFFF00FFFFFFFFFF00FFFFFFFF000000FF00FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFF0000FFFFFF00
FF000000FFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFF000000FF00FFFFFF0000FF
FFFF0000FFFFFF00FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFF00000000FF00000000FFFF00
FFFFFFFFFFFF0000FF0000000000FF0000000000FF0000FFFFFFFFFFFF00FFFF00000000
FF00000000FFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00000000FFFF0000FFFFFFFFFF0000FFFF00
000000FFFF00FFFFFFFF0000FFFFFFFFFF0000FFFFFFFF00FFFF00000000FFFF0000FFFF
FFFFFF0000FFFF00000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF0000FFFF00FF00FF00FFFF0000FF
FFFFFFFFFFFF00FFFFFFFFFF0000FF0000FFFFFFFFFF00FFFFFFFFFFFFFF0000FFFF00FF
00FF00FFFF0000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00000000FFFFFFFFFFFFFF00000000
FFFFFFFF00FF00FF0000FF00FFFFFFFFFF00FF0000FF00FF00FFFFFFFF00000000FFFFFF
FFFFFFFF00000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF000000000000FFFFFFFFFF0000000000
00FFFF000000FFFFFFFF000000FFFFFF000000FFFFFFFF000000FFFF000000000000FFFF
FFFFFF000000000000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFF
FF00FFFFFF00FFFFFF0000000000FF0000000000FFFFFF00FFFFFF00FFFFFFFFFFFF00FF
FFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FF000000FFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF000000
FF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FFFFFFFFFF0000FF0000
FF00FF00FF0000FFFF00FFFFFFFF00FFFFFFFF00FFFF0000FF00FF00FF0000FF0000FFFF
FFFFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFF00FFFF00FFFF
000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF000000FFFF00FFFF00FF
FF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF000000FF
FFFF00FFFFFF000000FF00FFFFFF00FFFFFF00FF000000FFFFFF00FFFFFF000000FFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FF0000000000
FFFFFFFFFFFFFFFFFF000000FF000000FF000000FFFFFFFFFFFFFFFFFF0000000000FF00
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF000000FFFFFFFFFF
00FFFFFFFFFFFFFF0000000000FFFFFF0000000000FFFFFFFFFFFFFF00FFFFFFFFFF0000
00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF00
0000FF0000FF0000FFFFFFFF00FF00FF00FFFFFFFF0000FF0000FF000000FFFFFFFF00FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFF00FFFFFFFF00FFFFFFFF00FFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FF000000FFFFFF00FFFF00FFFFFFFFFFFFFF00FFFF00FFFFFF000000FFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FF00
00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000
0000FFFFFFFFFFFFFF00FF000000FF000000FF00FFFFFFFFFFFFFF00000000FFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFF0000FF0000FF000000FFFFFFFFFFFFFF000000FF0000FF0000FFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FF00000000FFFF0000000000FFFFFFFFFF0000000000FFFF00000000FFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
000000000000FFFFFFFFFFFF0000FF0000FFFFFFFFFFFF000000000000FFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFF00FFFFFF0000FFFFFFFF00FFFFFF00FFFFFFFF0000FFFFFF00FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFF00000000FF00FF00FFFFFF00FF00FF00000000FFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFF0000FFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF0000FFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFF0000FFFF00FF0000FF0000FF00FFFF0000FFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF00FF0000FFFFFF0000FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFF000000FFFFFFFFFFFFFF000000FFFF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFF00FF00FF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.239885 0.39418 0.327195 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2223744568276) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FFFF00FF00FF00FF00000000FF00FFFFFFFFFF0000FF000000FFFFFFFFFFFFFF00
0000000000000000FF00FFFFFFFFFFFFFFFFFF00FF000000000000000000FFFFFFFFFFFF
FF000000FF0000FFFFFFFFFF00FF00000000FF00FF00FF00FFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFF000000FFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000
00FFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF0000FF000000FF000000FFFFFFFFFFFF00FF0000FFFFFFFF00FFFF00FF00
000000000000000000FFFF00FFFFFFFFFF00FFFF00000000000000000000FF00FFFF00FF
FFFFFF0000FF00FFFFFFFFFFFF000000FF000000FF0000FF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFF00FF00FFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF00FF00FF000000FF00FFFF00FF00FF0000FF00FFFF0000FF000000
FF00000000000000FF0000FFFFFFFFFFFFFF0000FF00000000000000FF000000FF0000FF
FF00FF0000FF00FF00FFFF00FF000000FF00FF00FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF0000FF000000FF000000FFFF00FF000000FFFF00FFFFFF00FF00
00FF000000000000FF00FFFFFFFFFFFFFFFFFF00FF000000000000FF0000FF00FFFFFF00
FFFF000000FF00FFFF000000FF000000FF0000FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFF0000FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF
FFFFFFFFFFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF00FF00FF00FF00FFFFFF000000000000FFFFFFFFFFFFFF
00000000FF00000000FFFF00FFFFFFFFFF00FFFF00000000FF00000000FFFFFFFFFFFFFF
000000000000FFFFFF00FF00FF00FF00FFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF0000FF000000FF00FF00000000FF0000FFFFFFFFFFFF
0000FFFF00000000FF0000FFFFFFFFFFFFFF0000FF00000000FFFF0000FFFFFFFFFFFF00
00FF00000000FF00FF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFF00FFFF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FF00FF00000000000000FFFF0000FFFFFFFF
FFFF000000000000FF00FFFFFFFFFFFFFFFFFF00FF000000000000FFFFFFFFFFFF0000FF
FF00000000000000FF00FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
00FFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFF00FFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF000000FF00FF00000000FFFFFFFFFF
FF0000FF0000000000FFFF00FFFFFFFFFF00FFFF0000000000FF0000FFFFFFFFFFFF0000
0000FF00FF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF0000FF00
FF00FFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFFFF
FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FF00FF00FF00000000FF00FFFFFF
FFFF000000FF0000FF0000FFFFFFFFFFFFFF0000FF0000FF000000FFFFFFFFFF00FF0000
0000FF00FF00FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FF00FFFFFFFFFFFFFFFF00FFFF000000FFFF00FFFFFFFFFFFFFFFF00FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF000000FF000000FFFFFFFF
FFFF00FF00000000FF00FFFFFFFFFFFFFFFFFF00FF00000000FF00FFFFFFFFFFFF000000
FF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFF
00FF00FFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFF00FF00FFFF00FFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FF00FF000000FF00FFFF
00FF00FF0000000000FFFF00FFFFFFFFFF00FFFF0000000000FF00FF00FFFF00FF000000
FF00FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF000000FF000000
FFFF00FF00000000FF0000FFFFFFFFFFFFFF0000FF00000000FF00FFFF000000FF000000
FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FF00FFFFFFFFFFFFFFFF00FFFF000000FFFF00FFFFFFFFFFFFFFFF00FFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FF00FF00FF00
FFFFFF0000000000FF00FFFFFFFFFFFFFFFFFF00FF0000000000FFFFFF00FF00FF00FF00
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF000000
FF00FF000000000000FFFF00FFFFFFFFFF00FFFF000000000000FF00FF000000FF0000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FF00
FF00000000000000000000FFFFFFFFFFFFFF00000000000000000000FF00FF00FFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFF00FFFF000000FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000
FF000000FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF000000FF0000FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FFFFFFFFFF000000FF000000FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FF00FF00FF00FF0000FFFF00FFFFFFFFFF00FFFF0000FF00FF00FF00FFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF0000FF0000FF000000FFFFFFFFFFFFFF000000FF0000FF0000FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF000000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF0000FF00FF00FFFFFFFFFF00FF00FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF00FF0000FFFFFF0000FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF0000FFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.239885 0.588183 0.327195 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2223744568277) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FFFFFFFF00FFFFFF0000FFFF00FF000000FF00FFFFFFFF00FFFF00FF0000FFFF
00FFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF00FFFF0000FF00FF
FF00FFFFFFFF00FF000000FF00FFFF0000FFFFFF00FFFFFFFF000000FF
FFFFFFFF0000FFFFFFFFFF00000000FF00FF00FFFF000000FF0000FFFFFFFF00000000FF
00FF000000FFFFFF0000FF0000FF00FF0000FF0000FFFFFF000000FF00FF00000000FFFF
FFFF0000FF000000FFFF00FF00FF00000000FFFFFFFFFF0000FFFFFFFF
FFFFFF00000000FF0000FF00FFFFFFFFFFFFFFFF0000000000FFFF0000FF00FFFFFFFF00
0000FFFF00FFFF00000000FFFF000000FFFF00000000FFFF00FFFF000000FFFFFFFF00FF
0000FFFF0000000000FFFFFFFFFFFFFFFF00FF0000FF00000000FFFFFF
FFFFFFFFFFFF00FFFFFFFFFF0000FFFF00FF0000FFFFFFFF00FFFFFFFFFFFF0000FF00FF
FFFFFFFF00FFFF00FFFFFFFF0000000000FFFFFFFF00FFFF00FFFFFFFFFF00FF0000FFFF
FFFFFFFF00FFFFFFFF0000FF00FFFF0000FFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFF000000FF0000FFFFFFFFFFFF00000000FFFF000000FF0000FFFFFF00FFFFFF
0000FF000000FF00FF00FF00000000000000FF00FF00FF000000FF0000FFFFFF00FFFFFF
0000FF000000FFFF00000000FFFFFFFFFFFF0000FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFF0000FF0000FFFFFFFF00FF0000000000FFFFFFFFFF00FFFF00
FFFF00FFFF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FFFF00FFFF00FFFF00FFFFFF
FFFF0000000000FF00FFFFFFFF0000FF0000FFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF0000FFFFFFFF00FFFF
FF000000FFFFFFFF000000FF0000FF0000FF000000FFFFFFFF000000FFFFFF00FFFFFFFF
0000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FF0000000000FFFF0000FFFF0000FFFFFFFF00
FFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFF00FFFFFFFF0000
FFFF0000FFFF0000000000FF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FF00000000FFFFFF00FFFFFFFFFFFF00000000FF00FFFF
FF00FF00FFFFFF00FFFFFF0000FFFFFF0000FFFFFF00FFFFFF00FF00FFFFFF00FF000000
00FFFFFFFFFFFF00FFFFFF00000000FF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF0000FFFFFF0000FF000000000000FFFFFF
FFFF00FFFFFFFFFF0000FFFFFFFF00FFFFFFFF0000FFFFFFFFFF00FFFFFFFFFF00000000
0000FF0000FFFFFF0000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF0000FF00000000FFFF00FFFFFFFFFFFF00FFFFFF00
00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFF00FFFF
FFFFFFFF00FFFF00000000FF0000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000000000FF00FF00FF00FFFFFFFFFF00FF
FFFFFFFFFF00FF0000FF00FFFFFF00FFFFFF00FF0000FF00FFFFFFFFFFFF00FFFFFFFFFF
00FF00FF00FF000000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF00FFFF000000FFFFFFFFFFFF00FFFFFF
0000FFFF000000FFFF000000FF000000FF000000FFFF000000FFFF0000FFFFFF00FFFFFF
FFFFFF000000FFFF00FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FFFF0000FFFFFF00FFFFFFFF
FFFF0000FFFFFFFF0000000000FFFFFF0000000000FFFFFFFF0000FFFFFFFFFFFF00FFFF
FF0000FFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF0000FF00FF00FFFF00FFFF00FF00FFFF
FF00000000FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF00000000FFFFFF00FF00FFFF
00FFFF00FF00FF0000FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF000000FFFFFFFFFF000000FF
000000000000FF0000FFFFFFFF00FF00FFFFFFFF0000FF000000000000FF000000FFFFFF
FFFF000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FFFFFFFFFF00FF0000FFFFFF00
00000000000000FFFF00FFFF00FFFFFF00FFFF00FFFF0000000000000000FFFFFF0000FF
00FFFFFFFFFF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FF0000FFFFFFFF0000FFFF
FFFFFFFFFFFFFFFF000000FF00FFFFFF00FF000000FFFFFFFFFFFFFFFFFFFF0000FFFFFF
FF0000FF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFF0000FF0000
FFFF0000FF00FF0000FF00FFFF00FF00FFFF00FF0000FF00FF0000FFFF0000FF0000FFFF
0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FF00FF00
FFFF00FF00FF00FF00FF00FF0000FF0000FF00FF00FF00FF00FF00FFFF00FF00FF00FFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FF000000FFFFFF
0000FFFFFFFFFFFFFF00FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFF0000FFFFFF000000FF
0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000000000FFFF
FFFFFFFF0000FFFFFF00FF00FF00FF00FF00FF00FFFFFF0000FFFFFFFFFFFF0000000000
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF00FFFFFF
FF00FF00000000FF000000FFFFFF00FFFFFF000000FF00000000FF00FFFFFFFF00FFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00
00FFFFFF00FFFF00FFFFFFFFFF000000FFFFFFFFFF00FFFF00FFFFFF0000FFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF0000FF00
FFFFFF000000FFFFFFFF00FF0000000000FF00FFFFFFFF000000FFFFFF00FF0000FF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
0000FF00FFFF00FFFFFFFF00000000000000FFFFFFFF00FFFF00FF0000FFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FF
FFFFFFFF0000FFFFFFFF000000000000000000FFFFFFFF0000FFFFFFFFFF0000FF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00
00FF0000FFFF0000FFFF00FFFFFFFFFFFFFF00FFFF0000FFFF0000FF0000FFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFF0000FFFF0000FFFFFF00FF00FFFFFF0000FFFF0000FFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFF00000000FFFFFFFF0000FFFFFF0000FFFFFFFF00000000FFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FF000000000000FF0000FFFF00FF00FFFF0000FF000000000000FF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FF0000FF0000FF00FFFFFFFF00FFFFFFFF00FF0000FF0000FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFF00000000FFFFFFFF000000FFFFFFFF00000000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFF00FF00FF0000000000FF00FF00FFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FF0000FF0000FF00FF0000FF0000FF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF0000FFFFFFFFFFFFFF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFF0000FF00FF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.239885 0.782187 0.327195 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2223744587990) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF000000FFFFFF000000000000FFFFFF
000000000000FFFF00FFFFFFFFFF00FFFFFFFFFF00FFFF000000000000FFFFFF00000000
0000FFFFFF000000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFF0000FFFFFFFFFFFF0000FF00000000FF0000FF0000FF0000000000000000FF00
00FF0000FFFFFF000000FFFFFF000000FFFFFF000000FFFFFF0000FF0000FF0000000000
000000FF0000FF0000FF00000000FF0000FFFFFFFFFFFF0000FFFFFFFF
FFFFFF000000FFFF00FFFF00FFFF000000000000FFFFFFFFFF00000000000000000000FF
FFFFFFFF00FF0000FF0000FF0000000000FF0000FF0000FF00FFFFFFFFFF000000000000
00000000FFFFFFFFFF000000000000FFFF00FFFF00FFFF000000FFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFF0000000000000000FFFFFF000000000000000000000000
FFFFFF000000FFFFFFFFFF00000000000000FFFFFFFFFF000000FFFFFF00000000000000
0000000000FFFFFF0000000000000000FFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFF000000FF00FFFFFFFFFF0000FF000000FFFF00FF0000FF0000FF0000000000
00FF0000000000FFFFFF000000000000000000FFFFFF0000000000FF000000000000FF00
00FF0000FF00FFFF000000FF0000FFFFFFFFFF00FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFF000000FF0000FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF
FF00000000000000FF0000FF0000FF0000FF0000FF00000000000000FFFFFFFFFFFF00FF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFF0000FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF00FFFF0000FFFFFF0000FFFF000000FFFFFF000000FFFFFFFF
000000000000000000FFFFFFFFFF00FFFFFFFFFF000000000000000000FFFFFFFF000000
FFFFFF000000FFFF0000FFFFFF0000FFFF00FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFF000000FF00000000FF00FF0000FF0000000000FF0000
FFFF0000000000000000FFFFFF000000FFFFFF0000000000000000FFFF0000FF00000000
00FF0000FF00FF00000000FF000000FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFF00FFFF000000000000FFFFFFFFFF000000FFFF000000
00FFFFFF00000000000000FF0000000000FF00000000000000FFFFFF00000000FFFF0000
00FFFFFFFFFF000000000000FFFF00FFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FF00000000FFFF00FFFFFFFFFF00000000
0000FF00FFFF000000FFFF00000000000000FFFF000000FFFF00FF000000000000FFFFFF
FFFF00FFFF00000000FF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF00FF0000FFFF0000FF00FF0000FF0000
FFFF000000FFFFFFFFFF000000000000000000FFFFFFFFFF000000FFFF0000FF0000FF00
FF0000FFFF0000FF00FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFFFFFFFFFFFF000000FFFFFFFFFF
FF0000FF0000FF00FF0000FF0000FF0000FF0000FF00FF0000FF0000FFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00000000FFFF00FFFFFF0000000000FFFFFF00
00FFFFFFFFFF000000FFFFFFFFFF00FFFFFFFFFF000000FFFFFFFFFF0000FFFFFF000000
0000FFFFFF00FFFF00000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF00FFFF00FF0000FF0000FF0000
0000FFFFFF0000000000FFFFFF000000FFFFFF0000000000FFFFFF00000000FF0000FF00
00FF00FFFF00FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00000000FFFFFFFF00FFFFFFFFFF000000
000000FF00000000000000FF0000000000FF00000000000000FF000000000000FFFFFFFF
FF00FFFFFFFF00000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000FFFF000000FFFFFF0000FF00
00FFFF000000000000FFFF00000000000000FFFF000000000000FFFF0000FF0000FFFFFF
000000FFFF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FF0000FFFFFF000000000000000000FFFFFF0000FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FF0000FFFFFF
0000FFFFFFFFFF00FF0000FF0000FF0000FF0000FF00FFFFFFFFFF0000FFFFFF0000FF00
00FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFF00FFFF00000000FF00
000000FFFFFF000000FFFFFFFFFF00FFFFFFFFFF000000FFFFFF00000000FF00000000FF
FF00FFFF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF000000000000FF
FF000000FF0000000000FFFFFF000000FFFFFF0000000000FF000000FFFF000000000000
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFF0000FF0000
FFFFFFFF00000000000000FF0000000000FF00000000000000FFFFFFFF0000FF0000FFFF
FFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FFFFFFFFFFFF
FFFFFF000000000000FFFF00000000000000FFFF000000000000FFFFFFFFFFFFFFFFFF00
00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFF0000FFFFFF00
00FF0000FF0000FFFFFF000000000000000000FFFFFF0000FF0000FF0000FFFFFF0000FF
FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF000000FF0000
0000FFFFFFFFFF00FF0000FF0000FF0000FF0000FF00FFFFFFFFFF00000000FF000000FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFF000000
000000FFFFFF000000FFFFFFFFFF00FFFFFFFFFF000000FFFFFF000000000000FFFF00FF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF000000
00FF0000FF0000000000FFFFFF000000FFFFFF0000000000FF0000FF00000000FFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFF00000000000000FF0000000000FF00000000000000FFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000
FFFFFF000000000000FFFF00000000000000FFFF000000000000FFFFFF0000FFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000
00FF0000FF0000FFFFFF000000000000000000FFFFFF0000FF0000FF00000000FF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
0000FFFFFFFFFF00FF0000FF0000FF0000FF0000FF00FFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00
000000FFFFFF000000FFFFFFFFFF00FFFFFFFFFF000000FFFFFF00000000FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FF000000FF0000000000FFFFFF000000FFFFFF0000000000FF000000FFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFF00FFFF00FFFF000000FFFF00FFFF00FFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFF00FFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFF00FFFF00FFFF000000FF00FF000000FFFF00FFFF00FFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FF00FFFFFFFFFFFF0000000000FFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FF0000FF00000000000000FF0000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FF00FFFF00000000FF00000000FFFF00FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF000000FFFFFF000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFF00FF00FFFFFF00FF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.239885 0.97619 0.327195 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2224132560362) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FFFF0000000000FFFF00FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFF000000
FF00FFFFFFFF00FFFF0000000000FF0000000000FFFF00FFFFFFFF00FF000000FFFF00FF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFF00FFFF0000000000FFFF0000FF
FFFFFF00FFFFFFFFFFFFFF000000FFFFFFFFFF00FF0000FFFFFFFF0000FFFFFF00FFFF00
FFFFFFFFFFFFFF00FFFFFFFF00FFFFFF00FFFFFFFF00FFFFFFFFFFFFFF00FFFF00FFFFFF
0000FFFFFFFF0000FF00FFFFFFFFFF000000FFFFFFFFFFFFFF00FFFFFF
FFFFFF00FFFF00FFFF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FF0000FFFF000000FF00FF00FFFFFF00FF00FF000000FFFF0000FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FFFF00FFFF00FFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFF00FF00FFFF00FF0000FFFFFF0000FFFFFF00FFFFFF
FFFFFFFF00FFFFFFFFFFFF000000FF000000FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFF
0000FFFFFF0000FF00FFFF00FF00FFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFF0000FFFFFFFFFFFFFFFF00000000FF00000000FF000000FF00
FF0000FFFFFF00FFFF00FF00FFFF00FFFF00FF00FFFF00FFFFFF0000FF00FF000000FF00
000000FF00000000FFFFFFFFFFFFFFFF0000FFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFF00FF0000FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFF0000FFFFFFFF000000FFFFFF000000FFFFFFFF0000FFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFF0000FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFF0000FFFF00FFFF0000FF00FF0000FFFF0000FF00FF00FF00
FF00FF00000000FFFF0000000000FF0000000000FFFF00000000FF00FF00FF00FF00FF00
00FFFF0000FF00FF0000FFFF00FFFF0000FFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF00FFFF0000FFFFFFFFFFFFFF00
FF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF
FF0000FFFF00FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFFFFFFFFFF000000FFFFFFFF0000FF00FFFFFF
FFFFFFFFFFFFFF00FF00FF00FFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFF00FF0000
FFFFFFFF000000FFFFFFFFFFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF00FF00FFFFFFFFFF00FFFF00FFFFFFFF00FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FF00FFFFFFFF00
FFFF00FFFFFFFFFF00FF00FFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFF0000FFFF00FFFFFFFFFF0000FFFF
FFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF0000FFFFFF
FFFF00FFFF0000FFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FF00000000FF00FF0000FF00000000FF
FF00FFFFFF0000FF000000FF0000FF0000FF000000FF0000FFFFFF00FFFF00000000FF00
00FF00FF00000000FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00
FFFFFF00FFFFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFF00FF0000FFFFFF0000FFFF
FF00FFFFFFFFFFFF0000FFFFFF000000FFFFFF0000FFFFFFFFFFFF00FFFFFF0000FFFFFF
0000FF00FFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF00FFFFFFFFFFFFFF00FFFF0000
FFFFFFFF00FF00FFFFFFFF00FFFFFFFFFF00FFFFFFFF00FF00FFFFFFFF0000FFFF00FFFF
FFFFFFFFFF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FF00FFFFFF000000
00FF00FFFFFFFFFF0000FFFFFFFF00FFFFFFFF0000FFFFFFFFFF00FF00000000FFFFFF00
FF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000000000FFFF00FFFFFF00FFFFFF
FFFFFFFFFFFF0000FFFFFFFFFF000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFF00FFFFFF
00FFFF0000000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF000000FFFFFF0000FF
00FF00FF00FFFFFFFF0000FF0000000000FF0000FFFFFFFF00FF00FF00FF0000FFFFFF00
0000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFF00FF00FFFF
FFFF00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF00FFFFFFFF00FF00FFFF
FFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF00FF00FF00
FFFFFFFFFFFFFFFF0000FF0000FF00FF0000FF0000FFFFFFFFFFFFFFFF00FF00FF00FFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF0000FFFFFFFFFFFFFF
FF00FF0000FFFF00000000FFFF000000FFFF00000000FFFF0000FF00FFFFFFFFFFFFFFFF
0000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFF0000FF0000FF
000000FFFF00FFFFFFFFFFFF0000000000FFFFFFFFFFFF00FFFF000000FF0000FF0000FF
FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FFFF00FFFF00
00000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000000000FFFF00FFFF00
00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFF00FFFFFF00FF00FFFF00FFFF00FF00FFFFFF00FFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFFFFFF
FFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFFFFFFFFFF00
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF00FF
00FFFFFF00FF00000000FFFF00FF00FF00FFFF00000000FF00FFFFFF00FF00FFFF00FFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF00FF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00
FF00000000FFFF00FFFF00FF00FF00FF00FF00FFFF00FFFF00000000FF00FFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FF
FFFFFFFFFFFFFFFF00FFFFFFFF000000FFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000
FFFFFFFFFF00FF00FFFFFFFF0000000000FFFFFFFF00FF00FFFFFFFFFF000000FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FF00FF00FFFFFF00FFFFFF00000000000000FFFFFF00FFFFFF00FF00FFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FF000000FF000000000000000000FF000000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFF0000FFFFFFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF00FFFF00FFFFFFFF00FF00FFFFFF00FF00FFFFFFFF00FFFF00FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFF0000FFFF00FF000000FF00FFFF0000FFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF0000FFFF0000FFFFFFFFFFFFFF0000FFFF0000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFF00000000FFFFFFFFFF00000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FF00FF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFF00FFFFFF00FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.335926 0.200176 0.423237 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2212105850512) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FF0000000000FFFF00FFFFFF00FFFF0000000000FF0000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF000000FF000000FF00FFFFFFFFFFFFFFFFFF00FF000000FF000000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFF00FF00FF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFF00FF00FF00FF00FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FFFFFF00FF00FF00FF00FF00FF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFF00FF00FF00FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFF000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF00FFFFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFF00FFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFF00FFFFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.335926 0.39418 0.423237 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2212105850513) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FFFFFF00FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF00FFFFFF0000FF
FFFFFFFF00FFFFFF00FFFFFF00FF0000FFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFF0000FFFFFFFFFF0000FF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFF0000FFFFFF0000FF0000FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFF0000FF0000FFFFFF0000FFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFF0000FFFFFF00FFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFF00FFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FF0000FFFFFFFFFF0000FFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000
FFFFFFFFFF0000FF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FF0000FFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFF0000FF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFF0000FFFFFFFFFF0000FFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000
FFFFFFFFFF0000FFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FF0000FFFFFFFF
FF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFF0000FF
00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FF0000FFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
0000FF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFF0000FFFFFFFF
FF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFF0000FF
FFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF00FF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF
00FF0000FFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFF0000FF00FFFFFF00FFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FF00
00FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF0000FF0000FFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FF
FFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFF00FFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
00FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF00FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFF00FFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFF00FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFF00FFFFFF00FF0000FFFFFFFFFF0000FF00FFFFFF00FFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFF00FFFFFF0000FFFFFFFFFF0000FFFFFF00FFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFF0000FF00FFFFFFFFFF00FF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFF00FFFFFFFFFFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFF0000FF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.335926 0.588183 0.423237 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2212881834681) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00FF000000FFFF00FF00FF00FFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFF000000FF00
FFFFFFFFFFFF0000FFFF00FF00FFFFFF00FF00FFFF0000FFFFFFFFFFFF00FF000000FFFF
FFFFFFFFFFFFFF00FFFFFFFF00FFFFFF00FF00FF00FFFF000000FF00FF
FFFFFFFF00FFFFFFFF00FF00FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00FFFFFF
00FFFFFF00FF00FFFFFFFF0000FFFFFF0000FFFFFFFF00FF00FFFFFF00FFFFFF00FFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FF00FFFFFFFF00FFFFFFFF
FFFFFF00FFFFFFFFFFFF0000FFFFFFFFFFFF00FFFF00FFFFFF00FF00FFFFFF00FFFFFFFF
FF000000FFFFFF00FFFF00FFFF000000FFFF00FFFF00FFFFFF000000FFFFFFFFFF00FFFF
FF00FF00FFFFFF00FFFF00FFFFFFFFFFFF0000FFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFFFF000000FFFFFF000000FFFFFFFFFF
FFFF00FFFFFFFFFF0000FFFFFFFF00FFFFFFFF0000FFFFFFFFFF00FFFFFFFFFFFFFF0000
00FFFFFF000000FFFFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFF00FFFFFF000000FFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFF
FFFFFF00FFFFFF00FFFF00FFFF00FF00FFFF00FFFF00FFFFFF00FFFFFFFFFFFFFFFFFF00
FFFFFFFFFF00FFFFFFFFFFFF000000FFFFFF00FFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFF000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
00FFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFF00000000FF00000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF0000FF000000FF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF000000FF00FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFF0000FF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FF00FFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFF000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF00FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFF00FFFF00FFFF00FFFF00FFFFFF00FFFF00FFFF00FFFF00FFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF
0000FFFFFFFFFFFF0000FFFF0000FF0000FFFF0000FFFFFFFFFFFF0000FFFFFF00FFFFFF
FFFFFFFFFFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF00FFFFFF00FF00FFFFFF0000FF00
00FF00FF0000FF00FF0000FF00FFFFFF00FF0000FF00FF0000FF00FF0000FF0000FFFFFF
00FF00FFFFFF00FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF000000FFFF00FF
0000FFFFFFFFFFFF0000FF00FFFFFFFFFF00FF0000FFFFFFFFFFFF0000FF00FFFF000000
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFF00FFFFFFFFFF00FFFFFFFF00
00FF00FFFFFFFF00FF0000FFFFFFFFFFFFFF0000FF00FFFFFFFF00FF0000FFFFFFFF00FF
FFFFFFFF00FFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFF00FFFFFFFFFFFF
00FF00FF0000FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF0000FF00FF00FFFFFFFFFFFF00
FFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF000000FFFFFFFFFFFFFF
FF00FF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FF00FFFFFFFFFFFFFFFF
000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFFFFFFFFFFFFFFFF
FFFFFF00FF0000FF0000FFFFFFFFFFFFFFFFFF0000FF0000FF00FFFFFFFFFFFFFFFFFFFF
FFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF000000FF00FF00FFFFFF00FF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF00FFFF00FFFF
FF00FFFF000000FF0000FFFFFFFFFFFFFFFFFF0000FF000000FFFF00FFFFFF00FFFF00FF
FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FF0000FF00FFFF0000FF00FFFFFFFFFFFFFF00FF0000FFFF00FF0000FFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF00FF0000FF
0000FF00FFFFFFFF00FF00FF0000000000FF00FF00FFFFFFFF00FF0000FF0000FF00FF00
0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00
FF0000FFFFFFFFFFFF00FF00FFFF00FFFF00FF00FFFFFFFFFFFF0000FF00FF0000FFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF00
FF00FFFFFFFFFFFFFFFF0000FFFF00FFFF0000FFFFFFFFFFFFFFFF00FF00FF00FFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
00FF00FFFF00FF00FFFF00FF0000FF0000FF00FFFF00FF00FFFF00FF00FFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF
FFFFFF0000FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF0000FFFFFFFF00FFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFF00FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
0000FFFFFFFF000000FF0000FFFFFFFFFF0000FF000000FFFFFFFF000000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFF00FFFFFFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFF00FF00FFFF00FFFFFFFFFF00FFFF00FF00FFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF0000FF00FF0000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF00FF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.335926 0.782187 0.423237 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2212881834682) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00FFFF0000FFFFFFFF00FFFFFFFF00FFFFFF00FF00FF00FFFF00FFFFFF00FF00FFFFFF
00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00FF
FFFF00FFFF00FF00FF00FFFFFF00FFFFFFFF00FFFFFFFF0000FFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF00FFFFFF0000FFFF0000FFFFFFFF
FF000000FF00FFFF0000FF0000FFFFFF0000FF0000FFFF00FF000000FFFFFFFFFF0000FF
FF0000FFFFFF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF000000000000FF0000FFFFFFFFFFFFFF0000FFFF0000FF00FF00FFFFFFFFFF
FFFF00FFFFFF000000FF00FF0000FF0000FF00FF000000FFFFFF00FFFFFFFFFFFFFF00FF
00FF0000FFFF0000FFFFFFFFFFFFFF0000FF000000000000FF00FFFFFF
FFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFFFF00FFFF00FF
FF00FFFFFF00FFFF00FF00FF00FFFFFF00FF00FF00FFFF00FFFFFF00FFFF00FFFF00FFFF
FF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFF00FFFFFFFF00FFFF00FFFF00FFFFFF0000FF00FFFF0000FF00FF
0000FFFF0000FFFFFF00FF00FFFFFFFFFF00FF00FFFFFF0000FFFF0000FF00FF0000FFFF
00FF0000FFFFFF00FFFF00FFFF00FFFFFFFF00FFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF0000FF00FF0000FFFFFFFFFFFFFF00FF00FF0000FF00FFFF
FF00FF00FF0000FFFF0000FFFFFFFFFFFFFF0000FFFF0000FF00FF00FFFFFF00FF0000FF
00FF00FFFFFFFFFFFFFF0000FF00FF0000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FFFF00FF00FFFF0000FF00FFFFFFFF00FF00FFFF0000FFFF
00FFFFFF0000FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF0000FFFFFF00FFFF0000FFFF00
FF00FFFFFFFF00FF0000FFFF00FF00FFFF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFF00FF00FFFF0000FFFFFFFF00FF00
00FFFF00FF0000FFFFFF00FFFF00FF00FFFF00FFFFFF0000FF00FFFF0000FF00FFFFFFFF
0000FFFF00FF00FFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF0000FFFF00FFFF0000FFFFFF0000FF00FFFFFFFFFFFF00FF
0000FF00FF00FFFFFFFFFF0000FFFFFF0000FFFFFFFFFF00FF00FF0000FF00FFFFFFFFFF
FF00FF0000FFFFFF0000FFFF00FFFF0000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF0000FF00FFFFFFFFFFFFFFFF00
00FF00FF00FF00FFFFFFFFFF00FFFFFF00FFFFFFFFFF00FF00FF00FF0000FFFFFFFFFFFF
FFFF00FF0000FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF0000000000FF0000FFFFFF00FF00FFFF00FFFFFFFFFFFF
00FF00FF00FF00FF00FFFF00FF00FF00FF00FFFF00FF00FF00FF00FF00FFFFFFFFFFFF00
FFFF00FF00FFFFFF0000FF0000000000FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF00FFFFFFFFFF00FF00FF00FF00FFFFFF00
FFFFFF00FF00FFFFFFFFFF0000FFFFFF0000FFFFFFFFFF00FF00FFFFFF00FFFFFF00FF00
FF00FF00FFFFFFFFFF00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FF00FFFFFFFFFF0000FFFFFF0000FF0000
FFFFFFFF0000FFFF0000FF00FFFFFFFFFF00FF0000FFFF0000FFFFFFFF0000FF0000FFFF
FF0000FFFFFFFFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFF00FFFF000000FFFF00FF00
00FFFFFFFF00FF00FF000000FFFF00FFFF000000FF00FF00FFFFFFFF0000FF00FFFF0000
00FFFF00FFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFF0000FFFFFFFF00FFFFFFFF0000
FF00FF00FFFFFFFF0000FF0000FF00FF0000FF0000FFFFFFFF00FF00FF0000FFFFFFFF00
FFFFFFFF0000FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF00FFFF00FFFFFFFFFFFF00
FF00FFFFFFFFFF00FF0000FFFF00FF00FFFF0000FF00FFFFFFFFFF00FF00FFFFFFFFFFFF
00FFFF00FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFFFF0000FFFFFFFFFFFFFFFF
00FF00FF0000FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF0000FF00FF00FFFFFFFFFFFFFF
FF0000FFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF0000000000FF0000000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000000000FF00FFFF00FFFF00FF
FFFFFFFF00000000FF00FFFF00FFFFFF00FFFF00FF00000000FFFFFFFFFF00FFFF00FFFF
00FF000000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF0000FF00FF
0000FF0000FF0000FFFFFF00FFFFFFFFFF00FFFFFF0000FF0000FF0000FF00FF0000FFFF
FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFF0000
00FF00FF0000FFFF000000FFFFFFFFFFFFFF000000FFFF0000FF00FF000000FFFFFFFFFF
FFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF000000FFFF
00FF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFF00FF00FF00FFFF000000FF00
00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFF00FF0000FFFF
000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF000000FFFF0000FF00FF
FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000
FFFF00FF00000000FFFFFFFF00FFFFFF00FFFFFFFF00000000FF00FFFF0000FFFF0000FF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFF00FFFFFF
FF00FFFFFF00FFFF00FFFFFF0000FF0000FFFFFF00FFFF00FFFFFF00FFFFFFFF00FFFF00
00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FF00FFFF00FFFFFFFF0000FF00FFFFFF00FF0000FFFFFFFF00FFFF00FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000FF00
0000FFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFF000000FF0000000000
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF00
FFFF0000FF00FFFFFF00000000FF00FF00000000FFFFFF00FF0000FFFF00FF00FFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FF
00FFFFFFFF0000FF0000FF0000FFFFFF0000FF0000FF0000FFFFFFFF00FF00FFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF000000FFFF00FF0000FFFF000000FFFF0000FF00FFFF000000FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FFFFFF00FFFFFFFF0000FF00FFFFFFFFFF00FF0000FFFFFFFF00FFFFFF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFF00FFFFFFFFFFFF00FF00FF000000FF00FF00FFFFFFFFFFFF00FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
0000FFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00000000FFFFFF0000FF000000FF000000FF0000FFFFFF00000000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFF00FFFF00FFFFFF00FFFFFF00FFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFF000000FFFF00FFFFFFFFFF00FFFF000000FFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF0000FFFFFFFFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF00FFFFFFFF00FFFFFF00FFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFF0000FF0000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF0000FF0000FF00FF0000FF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00000000FFFFFF00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.335926 0.97619 0.423237 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2212881834683) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00FFFF00FFFF0000FFFFFF000000000000FFFFFFFFFF0000000000FF00FFFF00FF0000
00FFFF0000FFFFFF00000000FFFFFFFFFF00000000FFFFFF0000FFFF000000FF00FFFF00
FF0000000000FFFFFFFFFF000000000000FFFFFF0000FFFF00FFFF00FF
FFFFFFFFFFFF00FF0000FF000000FF0000FF00FFFFFF0000000000FF00FFFFFFFF000000
00FFFF000000FF0000FF0000FFFFFFFFFF0000FF0000FF000000FFFF00000000FFFFFFFF
00FF0000000000FFFFFF00FF0000FF000000FF0000FF00FFFFFFFFFFFF
FFFFFF00FF000000FFFF00FF000000FFFF0000FFFFFF000000000000FFFFFFFFFF000000
0000FF00FFFF00FF0000FFFF0000FF0000FFFF0000FF00FFFF00FF0000000000FFFFFFFF
FF000000000000FFFFFF0000FFFF000000FF00FFFF000000FF00FFFFFF
FFFFFFFFFFFF00FFFFFFFF00000000FFFF000000FF000000FF0000FF00FFFFFF00000000
00FF00FFFFFFFF000000FFFF00FFFFFF00FFFF000000FFFFFFFF00FF0000000000FFFFFF
00FF0000FF000000FF000000FFFF00000000FFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFF0000000000FF00FFFF00FF000000FFFF0000FFFFFF00000000
0000FFFFFFFFFF00000000FFFFFF00FFFFFF00000000FFFFFFFFFF000000000000FFFFFF
0000FFFF000000FF00FFFF00FF0000000000FFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000FF00FFFFFFFF00000000FFFF000000FF000000FF00
00FF00FFFFFF00000000FF00FF000000FF00FF00000000FFFFFF00FF0000FF000000FF00
0000FFFF00000000FFFFFFFF00FF0000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FF0000000000FFFFFFFFFF0000000000FF00FFFF00FF000000FF
FF0000FFFFFF0000000000FFFFFF00FFFFFF0000000000FFFFFF0000FFFF000000FF00FF
FF00FF0000000000FFFFFFFFFF0000000000FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000FF00FFFFFF0000000000FF00FFFFFFFF00000000FF
FF000000FF000000000000FFFF00FF00FFFF000000000000FF000000FFFF00000000FFFF
FFFF00FF0000000000FFFFFF00FF0000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF00FFFF0000FFFFFF000000000000FFFFFFFFFF0000000000
FF00FFFF00FF000000000000FFFFFFFFFF000000000000FF00FFFF00FF0000000000FFFF
FFFFFF000000000000FFFFFF0000FFFF00FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF000000FF0000FF00FFFFFF0000000000FF
00FFFFFFFF00000000FF0000FFFFFFFFFF0000FF00000000FFFFFFFF00FF0000000000FF
FFFF00FF0000FF000000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF000000FFFF00FF000000FFFF0000FFFFFF000000000000
FFFFFFFFFF0000000000FFFF0000FF0000FFFF0000000000FFFFFFFFFF000000000000FF
FFFF0000FFFF000000FF00FFFF000000FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00000000FFFF000000FF000000FF0000FF
00FFFFFF000000000000FFFF00FFFFFF00FFFF000000000000FFFFFF00FF0000FF000000
FF000000FFFF00000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000000000FF00FFFF00FF000000FFFF00
00FFFFFF00000000000000FFFFFF00FFFFFF00000000000000FFFFFF0000FFFF000000FF
00FFFF00FF0000000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF00FFFFFFFF00000000FFFF00
0000FF00000000000000FF00FF000000FF00FF00000000000000FF000000FFFF00000000
FFFFFFFF00FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000000000FFFFFFFFFF0000000000FF00
FFFF00FF00000000000000FFFFFF00FFFFFF00000000000000FF00FFFF00FF0000000000
FFFFFFFFFF0000000000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF00FFFFFF0000000000FF00FF
FFFFFF0000000000000000FFFF00FF00FFFF0000000000000000FFFFFFFF00FF00000000
00FFFFFF00FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF0000FFFFFF000000000000FFFF
FFFFFF000000000000000000FF00FF00FF000000000000000000FFFFFFFFFF0000000000
00FFFFFF0000FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF000000FF0000FF00FF
FFFF000000000000000000FF00FFFFFF00FF000000000000000000FFFFFF00FF0000FF00
0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFF00FF000000FFFF0000FF
FFFF00000000000000FF0000FFFFFFFFFF0000FF00000000000000FFFFFF0000FFFF0000
00FF00FFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00000000FFFF000000
FF000000000000000000FFFF00FFFFFF00FFFF000000000000000000FF000000FFFF0000
0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000000000FF00FFFF
00FF0000000000000000FFFF0000FF0000FFFF0000000000000000FF00FFFF00FF000000
0000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF00FFFFFF
FF00000000000000000000FF00FFFFFF00FF00000000000000000000FFFFFFFF00FF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000000000FFFFFFFF
FF000000000000FF0000FF00FFFFFFFFFF00FF0000FF000000000000FFFFFFFFFF000000
0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF00FFFFFF
0000000000000000FFFF0000FFFF00FFFF0000FFFF0000000000000000FFFFFF00FF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF0000FFFFFF
0000000000000000FFFF000000FF00FF000000FFFF0000000000000000FFFFFF0000FFFF
00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF00
0000FF0000FF000000FF00FFFF00FF00FFFF00FF000000FF0000FF000000FF0000FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFF00FF
000000FFFF00000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFF000000FF00FFFF000000
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00
000000FFFF0000000000FF00FFFFFFFFFF00FF0000000000FFFF00000000FFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00
00000000FF00FFFF00FFFFFF0000FF0000FFFFFF00FFFF00FF0000000000FFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000FF00FFFFFFFF00FFFF00FFFFFF00FFFF00FFFFFFFF00FF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
00000000FFFFFFFFFF0000FFFFFF00FFFFFF0000FFFFFFFFFF0000000000FF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000FF00FFFFFF0000FF00FF000000FF00FF0000FFFFFF00FF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
00FFFF0000FFFFFF000000FFFFFF00FFFFFF000000FFFFFF0000FFFF00FFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF0000FF00000000FFFF00FF00FFFF00000000FF0000FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF000000FFFF00FF00000000FF00FF00FF00000000FF00FFFF000000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFF00000000FF00FFFFFF00FF00000000FFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFF0000000000FFFFFFFFFF0000000000FFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFF00FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF000000000000FF00FF000000000000FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FF00FF00FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF00FFFF00FF00FF00FF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF000000FFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.431968 0.200176 0.519278 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2201243097206) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FF0000FFFFFFFF00FF00FFFF00FF00FFFFFFFF00FFFFFFFFFF00FF0000000000
0000000000FF000000FF000000000000000000FF000000FF00000000000000000000FF00
FFFFFFFFFF00FFFFFFFF00FF00FFFF00FF00FFFFFFFF0000FF000000FF
FFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFFFFFF00FFFFFF0000000000
0000000000FFFFFFFFFF000000000000000000FFFFFFFFFF00000000000000000000FFFF
FF00FFFFFFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFF00FFFFFFFF0000FF00FFFF0000FFFF00FFFFFFFFFFFF00FFFFFFFF000000000000
000000000000FFFFFF0000000000000000000000FFFFFF000000000000000000000000FF
FFFFFF00FFFFFFFFFFFF00FFFF0000FFFF00FF0000FFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF000000000000
000000000000FFFFFF0000000000000000000000FFFFFF000000000000000000000000FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF00FFFFFFFF00FFFFFFFFFFFF00FFFF00FFFF0000FF00000000000000
0000000000FF00FFFF0000000000000000000000FFFF00FF000000000000000000000000
FF0000FFFF00FFFF00FFFFFFFFFFFF00FFFFFFFF00FFFF00FFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFF00FF00FF0000FF000000FF00FF0000FF00FF00000000FF00
000000000000FFFFFF0000FF0000000000FF0000FFFFFF00000000000000FF00000000FF
00FF0000FF00FF000000FF0000FF00FF00FFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFF00FFFFFFFF000000FFFFFF00FFFF0000
FF0000FF0000FFFF00FFFF00000000000000FFFF00FFFF0000FF0000FF0000FFFF00FFFF
FF000000FFFFFFFF00FFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF00FF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFF00FF0000FFFF00000000000000FFFF0000FF00FFFFFF00FFFFFFFFFFFFFF00
FFFFFFFFFFFFFF00FF00FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFF00FF0000FFFFFFFFFF0000FFFFFF000000FFFFFFFFFF
FFFFFF00FFFFFFFF00FF000000000000000000FF00FFFFFFFF00FFFFFFFFFFFFFFFF0000
00FFFFFF0000FFFFFFFFFF0000FF00FFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFF000000FFFFFF00FF
FF00FFFFFFFFFF00FF00FF00000000000000FF00FF00FFFFFFFFFF00FFFF00FFFFFF0000
00FFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFF0000FFFF000000FF0000000000FF000000
FFFFFF00FF0000FFFFFF000000000000000000FFFFFF0000FF00FFFFFF000000FF000000
0000FF000000FFFF0000FFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF0000FFFFFFFFFFFF0000000000FFFFFFFF
FF00FFFFFF0000FFFF00FF00000000000000FF00FFFF0000FFFFFF00FFFFFFFFFF000000
0000FFFFFFFFFFFF0000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FFFF0000FFFFFF00000000000000FFFFFF
00FF00FFFF00FFFFFFFF000000000000000000FFFFFFFF00FFFF00FF00FFFFFF00000000
000000FFFFFF0000FFFF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFF00000000000000FFFFFF
0000FFFFFFFFFF00FFFF000000000000000000FFFF00FFFFFFFFFF0000FFFFFF00000000
000000FFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00000000FF000000000000000000FFFF
0000FFFF00FFFF00FF0000000000000000000000FF00FFFF00FFFF0000FFFF0000000000
00000000FF00000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFF
FFFFFF00FFFFFFFFFF0000000000000000000000FFFFFFFFFF00FFFFFFFFFF0000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF000000000000000000FF00FF
00FFFFFFFFFFFFFF00FF000000000000000000FF00FFFFFFFFFFFFFF00FF00FF00000000
0000000000FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00000000000000000000FFFF
FFFFFFFFFF00FFFFFF0000000000000000000000FFFFFF00FFFFFFFFFFFFFF0000000000
0000000000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000000000FF00000000FFFF
00FF0000FFFFFFFF00FF000000000000000000FF00FFFFFFFF0000FF00FFFF00000000FF
000000000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000FFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF0000000000000000000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFF00FFFFFFFF00FF
FFFFFF00FFFF00FFFF0000000000000000000000FFFF00FFFF00FFFFFFFF00FFFFFFFF00
FFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF00FF00FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFF00FFFF
FF00FFFFFFFFFFFF00000000000000000000000000FFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FF00FF
000000FF0000FF00FF0000000000000000000000FF00FF0000FF000000FF00FF00FFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FFFFFFFFFF
FF00FFFFFFFFFFFF00000000000000000000000000FFFFFFFFFFFF00FFFFFFFFFFFF0000
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
00FF00FFFFFFFF00FF0000000000000000000000FF00FFFFFFFF00FF00FFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FF00
FF00FFFFFFFFFFFF00000000000000000000000000FFFFFFFFFFFF00FF00FF0000FFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFF00FFFF00000000000000000000000000FFFF00FFFF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF
FF00FF00FF00FF000000000000000000000000000000FF00FF00FF00FFFFFFFF00FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
00FF00FFFFFFFF000000000000000000000000000000FFFFFFFF00FF00FFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00
0000FFFFFFFF0000000000000000000000000000000000FFFFFFFF000000FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF00FFFFFF0000FF0000000000000000000000FF0000FFFFFF00FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFF00FF0000FFFF00000000000000000000000000FFFF0000FF00FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFF00000000000000000000000000FFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF00FFFFFFFF000000000000000000000000000000FFFFFFFF00FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFF0000000000FF000000FF0000000000FFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFF00FFFF00FFFF0000FF0000FFFF00FFFF00FFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF0000FFFFFFFF00FFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF00FFFF00FF00FFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.431968 0.39418 0.519278 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2201243116918) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FFFFFFFF00FFFF00FFFFFF0000FFFF00FF00FFFFFFFFFF00000000FFFF0000FFFF
FF00FF00FF00000000FFFF00FF000000FF00FFFF00000000FF00FF00FFFFFF0000FFFF00
000000FFFFFFFFFF00FF00FFFF0000FFFFFF00FFFF00FFFFFFFF0000FF
FFFFFFFFFF0000FFFFFF0000000000FF00FF00FF00FF00000000FFFF00FFFFFFFF00FF00
0000FFFFFFFF00FFFF0000FFFFFF00FFFFFF0000FFFF00FFFFFFFF000000FF00FFFFFFFF
00FFFF00000000FF00FF00FF00FF0000000000FFFFFF0000FFFFFFFFFF
FFFFFF00FF00FFFFFFFF00FFFF00FFFFFF0000FFFFFFFF00FFFF0000FFFFFFFFFFFFFF00
00FF00FFFFFFFF0000FFFF0000FF00FF0000FFFF0000FFFFFFFF00FF0000FFFFFFFFFFFF
FF0000FFFF00FFFFFFFF0000FFFFFF00FFFF00FFFFFFFF00FF00FFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFF000000FFFF00FFFFFFFFFF00FF000000FFFFFFFFFFFF
00FFFFFF00FF0000FF00FFFFFFFFFFFFFFFFFF00FF0000FF00FFFFFF00FFFFFFFFFFFF00
0000FF00FFFFFFFFFF00FFFF000000FFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFF000000FF0000FF00FFFFFFFFFFFF00FF0000FFFFFF00FFFF
0000FFFF000000FF00FFFFFFFFFF00FFFFFFFFFF00FF000000FFFF0000FFFF00FFFFFF00
00FF00FFFFFFFFFFFF00FF0000FF000000FFFFFF0000FF00FFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FF0000FFFFFFFF0000FFFFFFFFFFFFFF0000FFFF00FF00FF
FFFFFFFFFF00FFFFFF000000FF00FF00FF000000FFFFFF00FFFFFFFFFFFF00FF00FFFF00
00FFFFFFFFFFFFFF0000FFFFFFFF0000FF00FFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF00FF00FFFF00FFFFFFFFFFFFFF0000FFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FF0000FFFFFF0000FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFF0000FFFFFFFFFFFFFF00FFFF00FF00FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFF00FFFFFF0000FF00FFFFFF0000FF00FFFF00
000000FFFFFFFF00FFFF00FF0000000000FF00FFFF00FFFFFFFF00000000FFFF00FF0000
FFFFFF00FF0000FFFFFF00FFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF0000FFFFFF0000FFFFFFFFFFFFFF000000FF00FF00FF00
FFFF00FF00FFFF0000FF00FFFFFFFFFFFFFF00FF0000FFFF00FF00FFFF00FF00FF00FF00
0000FFFFFFFFFFFFFF0000FFFFFF0000FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF00FF0000FFFFFF00FFFFFF00FFFFFF00FF00FF
00FFFFFFFF00FFFFFFFF0000FFFF00FFFF0000FFFFFFFF00FFFFFFFF00FF00FF00FFFFFF
00FFFFFF00FFFFFF0000FF00FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FFFF0000FFFFFFFF00FF00FFFFFFFF000000FFFFFF00
FF00FFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF00FF00FFFFFF000000
FFFFFFFF00FF00FFFFFFFF0000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF00FF00FFFFFFFFFFFF0000FFFF00FF000000
FFFFFFFF0000FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF0000FFFFFFFF000000FF00FFFF
0000FFFFFFFFFFFF00FF00FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FF00FF00FF00FFFFFF0000FFFF0000FFFF00
FFFFFF0000FF00FFFF00FFFF00FFFFFF00FFFF00FFFF00FF0000FFFFFF00FFFF0000FFFF
0000FFFFFF00FF00FF00FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF00FFFF000000
FFFFFF0000FFFFFF00FFFFFFFF000000FFFFFFFF00FFFFFF0000FFFFFF000000FFFF00FF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFF0000FF00FFFF
00FFFF00FFFFFFFF000000FF0000FF0000FF000000FFFFFFFF00FFFF00FFFF00FF0000FF
FFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00000000FF0000FFFFFFFFFF0000
00FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFF
0000FF00000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFF0000FF00FFFF0000FFFF
00FFFFFFFF00FFFFFF00FF00FFFFFFFFFF00FF00FFFFFF00FFFFFFFF00FFFF0000FFFF00
FF0000FFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF000000FF00FFFFFFFFFFFFFF
FFFF00FF0000FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFF0000FF00FFFFFFFFFFFFFFFFFF
00FF000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFF0000FF00FFFFFF
FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FFFFFFFF00FF0000
FFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FF00FFFFFF
FFFF0000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FFFF0000FFFFFFFFFF00FF00FF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF0000FFFFFFFF00FF
000000FF00FFFFFF00000000000000000000000000FFFFFF00FF000000FF00FFFFFFFF00
00FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FFFF00FF
00FFFF00FF00FF00FF0000FF0000FF0000FF0000FF00FF00FF00FFFF00FF00FFFF00FFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFF00FF00FF00FF
00FF0000FFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFF0000FF00FF00FF00FF00FF
FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFFFFFF
0000FFFF00FFFFFF00FFFF00FFFFFFFFFF00FFFF00FFFFFF00FFFF0000FFFFFFFF00FF00
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FFFFFFFF00
FF000000FFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFF000000FF00FFFFFFFF00FF
00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFF
FF00FFFF0000000000FFFF00000000000000FFFF0000000000FFFF00FFFFFF00FF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFFFF
FFFFFF00FF0000FF0000FF00FFFF00FFFF00FF0000FF0000FF00FFFFFFFFFFFF0000FF00
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000
FF00FFFFFF0000FFFFFFFF0000FF00FF0000FFFFFFFF0000FFFFFF00FF00000000FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FF
FFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF00FFFF00FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF
FF00FFFF000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF000000FFFF00FFFF0000FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00
FFFFFFFF00FFFF0000000000FF00FF00FF0000000000FFFF00FFFFFFFF00FFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFF0000FF00FFFF00FFFFFFFFFFFFFF00FFFF00FF0000FFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
00FFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFF0000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFF0000FFFF00FF00FFFF00FFFF00FF00FFFF0000FFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FFFFFFFF00FFFF000000FFFF00FFFF000000FFFF00FFFFFFFF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFF00FFFF00FFFFFFFFFF00FFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF0000FFFFFF00FFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FFFFFFFF00FFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FFFF0000FFFF00FF00FF00FFFF0000FFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFF00FFFFFFFFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FFFFFFFF00FFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFF0000FF00FF00FF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.431968 0.588183 0.519278 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2201243116919) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FF00FFFFFFFF00FFFF0000FF00FFFF00FFFF00FF0000FFFFFF00FF00FFFFFF00FF
00FFFF00000000FFFF00FF0000FF00FF0000FF00FFFF00000000FFFF00FF00FFFFFF00FF
00FFFFFF0000FF00FFFF00FFFF00FF0000FFFF00FFFFFFFF00FF0000FF
FFFFFFFF0000FF00FFFFFF0000FF00FFFFFF0000FFFFFFFFFFFFFF000000FFFFFFFFFF00
00FFFF000000FF00FFFFFF0000FFFFFF0000FFFFFF00FF000000FFFF0000FFFFFFFFFF00
0000FFFFFFFFFFFFFF0000FFFFFF00FF0000FFFFFF00FF0000FFFFFFFF
FFFFFF00FFFF0000FFFF0000FF00FFFFFFFF00FFFFFF00FFFFFF0000000000FF0000FF00
FFFFFFFF00FFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFF00FF0000FF0000
000000FFFFFF00FFFFFF00FFFFFFFF00FF0000FFFF0000FFFF00FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF00FFFFFFFF00000000000000FFFF0000
FFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFF0000FFFF000000
00000000FFFFFFFF00FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF000000FF00FF00FFFF00FFFF00FFFFFF000000000000000000FF00FF
FFFFFF00FFFFFFFF00FFFFFFFF000000FFFFFFFF00FFFFFFFF00FFFFFFFF00FF00000000
0000000000FFFFFF00FFFF00FFFF00FF00FF000000FFFF00FFFFFFFFFF
FFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFF0000FFFFFF00000000000000000000FFFF
FFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF0000000000
0000000000FFFFFF0000FFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF00FFFFFFFF00FFFF0000FF00FFFF000000000000000000FF00FF
FFFF00FFFF00FF00FF00FF00FF000000FF00FF00FF00FF00FFFF00FFFFFF00FF00000000
0000000000FFFF00FF0000FFFF00FFFFFFFF00FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF00FFFFFF0000FF00FFFFFF0000000000000000FF00FFFF
FFFFFF00FFFFFF00FF00FFFFFF000000FFFFFF00FF00FFFFFF00FFFFFFFFFF00FF000000
0000000000FFFFFF00FF0000FFFFFF00FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF0000FFFF0000FF00FFFFFFFF00FFFF00FFFF00FFFFFF0000
FF0000FFFFFFFFFFFF0000FFFF000000FFFF0000FFFFFFFFFFFF0000FF0000FFFFFF00FF
FF00FFFF00FFFFFFFF00FF0000FFFF0000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF
FF000000FF0000FFFF0000FFFFFFFFFFFFFF0000FFFF0000FF000000FFFFFFFFFFFFFFFF
00FF00FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF000000FF00FF00FFFF00FFFF00FFFFFFFFFF00FFFFFF
FFFF00FFFFFFFFFFFFFF00FFFF00FF00FFFF00FFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFF
FFFF00FFFF00FFFF00FF00FF000000FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000
FF000000FF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FF000000FF0000FFFFFFFFFF
FFFF0000FFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF00FFFF0000FF00FFFF00FFFF00FF00
00FFFF00FF00FFFFFFFFFFFF00FF00FF00FFFFFFFFFFFF00FF00FFFF0000FF00FFFF00FF
FF00FF0000FFFF00FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFF0000FF00FFFFFF0000FFFFFFFF
FFFFFFFF0000FFFFFF00FFFFFFFF00FFFFFFFF00FFFFFF0000FFFFFFFFFFFFFFFF0000FF
FFFF00FF0000FFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFF0000FF00FFFFFFFF00FFFFFF00FF
FFFF0000FFFF00FFFF00FFFF00FF00FF00FFFF00FFFF00FFFF0000FFFFFF00FFFFFF00FF
FFFFFF00FF0000FFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF00FFFFFF
FF00000000FF00FFFFFFFFFF00FF00FF00FFFFFFFFFF00FF00000000FFFFFFFF00FFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000FF00FF00FFFF00FFFF00FFFFFF
000000000000FFFFFF00FFFFFF000000FFFFFF00FFFFFF000000000000FFFFFF00FFFF00
FFFF00FF00FF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFF0000FFFFFF
00000000000000FF00FF00FF0000000000FF00FF00FF00000000000000FFFFFF0000FFFF
FFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF00FFFF0000FF00FFFF
0000000000000000FFFFFF00000000000000FFFFFF0000000000000000FFFF00FF0000FF
FF00FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFF0000FF00FFFFFF
000000000000000000FF000000000000000000FF000000000000000000FFFFFF00FF0000
FFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFF0000FF00FFFFFFFF
00FFFF00FFFF00FFFF0000FF0000FF0000FF0000FFFF00FFFF00FFFF00FFFFFFFF00FF00
00FFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFF00FF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000FF00FF00FFFF00
FFFF00FFFFFFFFFF00FFFF000000FF000000FFFF00FFFFFFFFFF00FFFF00FFFF00FF00FF
000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFF
FF0000FFFFFFFFFFFFFF000000FF00FF000000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFF00
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF00FFFF
0000FF00FFFF00FFFF00FF0000FFFFFF0000FF00FFFF00FFFF00FF0000FFFF00FFFFFFFF
00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFF00
00FF00FFFFFF0000FFFFFFFFFFFF00FFFFFFFFFFFF0000FFFFFF00FF0000FFFFFF00FF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFF0000
FF00FFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF00FF0000FFFF0000FF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFF00FFFFFFFF000000FFFFFFFF00FFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000FF
00FF00FFFF00FFFF00FFFFFF0000000000FFFFFF00FFFF00FFFF00FF00FF000000FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00
FFFFFFFFFFFFFF0000FFFFFF0000000000FFFFFF0000FFFFFFFFFFFFFF00FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF
FFFFFF00FFFF0000FF00FFFF0000000000FFFF00FF0000FFFF00FFFFFFFF00FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00FFFFFF0000FF00FFFFFF0000FF0000FFFFFF00FF0000FFFFFF00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
0000FFFF0000FF00FFFFFFFF00FFFFFF00FFFFFFFF00FF0000FFFF0000FFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF000000FF00FF00FFFF00FFFF00FFFF00FFFF00FF00FF000000FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FF00FFFFFFFFFFFFFF000000FFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF00FFFFFFFF00FFFF0000000000FFFF00FFFFFFFF00FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FF00FFFFFF00000000000000FFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFF0000FFFF000000000000000000FFFF0000FFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF00000000000000000000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF000000000000000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF00FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.431968 0.782187 0.519278 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2201243136630) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FFFF00FFFFFF00000000FF00000000000000FFFF00FF00FFFFFF00000000FF00
00FF0000FFFF0000FF00FFFF0000FF0000FFFF00FF0000FFFF0000FF0000FF00000000FF
FFFF00FF00FFFF00000000000000FF00000000FFFFFF00FFFF000000FF
FFFFFFFFFF00FFFFFFFF0000FF000000FF0000FF0000FFFF000000FFFFFF0000FF000000
FF00FF00000000FF00FFFFFFFF000000FFFFFFFF00FF00000000FF00FF000000FF0000FF
FFFF000000FFFF0000FF0000FF000000FF0000FFFFFFFF00FFFFFFFFFF
FFFFFF00FFFFFF00FFFFFF000000FF000000FF00FF00000000FF0000000000FF00FF0000
FFFFFF0000FF000000FFFF00FFFFFFFFFF00FFFF000000FF0000FFFFFF0000FF00FF0000
000000FF00000000FF00FF000000FF000000FFFFFF00FFFFFF00FFFFFF
FFFFFFFFFFFFFFFF00FFFF0000FFFFFF0000FFFFFFFFFFFFFFFF0000FFFF000000FFFFFF
FFFFFFFF000000FF00000000FFFF00FFFF00000000FF000000FFFFFFFFFFFFFF000000FF
FF0000FFFFFFFFFFFFFFFF0000FFFFFF0000FFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF00000000FF00FFFF0000FFFFFFFFFF00FFFFFFFFFF00FF0000FFFFFF
FF00FFFF0000FF00FF0000FF00FFFFFF00FF0000FF00FF0000FFFF00FFFFFFFF0000FF00
FFFFFFFFFF00FFFFFFFFFF0000FFFF00FF00000000FFFF00FFFFFFFFFF
FFFFFFFFFFFFFF00FF0000FF00FFFFFFFF00000000000000FFFFFF00FFFFFFFFFFFF00FF
FF00000000FF00FFFFFF000000FFFFFF000000FFFFFF00FF00000000FFFF00FFFFFFFFFF
FF00FFFFFF00000000000000FFFFFFFF00FF0000FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF00FF00FFFF00FF0000FF00FF0000000000FFFFFFFFFF00FFFF
FF0000FF000000FFFF00FF0000FFFFFF0000FF00FFFF000000FF0000FFFFFF00FFFFFFFF
FF0000000000FF00FF0000FF00FFFF00FF00FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFF000000FF00FF00FF0000FF00000000000000FFFF
00FF000000FF00000000FFFFFFFFFFFFFFFFFF00000000FF000000FF00FFFF0000000000
0000FF0000FF00FF00FF000000FFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FF000000FFFFFFFFFFFF0000FF0000FF000000
00FFFFFFFFFF0000FFFF00FFFFFFFFFFFFFF00FFFF0000FFFFFFFFFF00000000FF0000FF
0000FFFFFFFFFFFF000000FF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFFFFFFFF00FFFF00FF000000FF00
00FFFF00FFFF0000FFFF000000000000000000FFFF0000FFFF00FFFF0000FF000000FF00
FFFF00FFFFFFFFFF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF00FF00000000000000FFFF000000FF000000
FF00FFFFFF00FF00000000FF0000FF0000FF00000000FF00FFFFFF00FF000000FF000000
FFFF00000000000000FF00FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF000000FF0000FF0000FFFF00FF000000FF00
0000FFFFFFFF00FF0000FF00FF000000FF00FF0000FF00FFFFFFFF000000FF000000FF00
FFFF0000FF0000FF000000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FF00FF000000FFFFFFFFFF0000FFFFFF
FFFFFF00FFFF000000FF00FFFFFF00FFFFFF00FF000000FFFF00FFFFFFFFFFFF0000FFFF
FFFFFF000000FF00FF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF00FF0000FFFF00FFFF0000FFFF00
FFFFFF00000000FF000000FFFF00FF00FFFF000000FF00000000FFFFFF00FFFF0000FFFF
00FFFF0000FF00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFFFF00000000FFFFFF00000000
FFFFFF0000FF000000FF00FFFF000000FFFF00FF000000FF0000FFFFFF00000000FFFFFF
00000000FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF0000FFFF00FFFF0000FF00
00000000FF00FF0000FFFFFFFFFF00FFFFFFFFFF0000FF00FF0000000000FF0000FFFF00
FFFF0000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000FFFF0000FFFF00000000FF00FF
FF0000FF00FFFFFFFFFF00FFFF00FF00FFFF00FFFFFFFFFF00FF0000FFFF00FF00000000
FFFF0000FFFF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFF00000000FF0000FFFFFF
00FF000000FFFF00FFFFFFFF00FFFFFF00FFFFFFFF00FFFF000000FF00FFFFFF0000FF00
000000FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFF0000FF000000FF00FFFF
000000FF00000000FFFFFF00FFFFFFFFFF00FFFFFF00000000FF000000FFFF00FF000000
FF0000FFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00FF0000FFFFFFFF
0000FF00FFFF0000FFFF00FF00FFFFFF00FF00FFFF0000FFFF00FF0000FFFFFFFF0000FF
00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF000000FF00FFFF00
FF000000FFFF0000FFFFFFFF0000000000FFFFFFFF0000FFFF000000FF00FFFF00FF0000
00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFF00
0000FF00000000FF00FFFFFFFF00FF00FFFFFFFF00FF00000000FF000000FFFFFFFF0000
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFF
00FFFFFF0000FF00FF00FFFF00FF00FF00FFFF00FF00FF0000FFFFFF00FFFFFFFFFFFFFF
FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF00FFFF00
FF00FFFF0000FFFFFF00000000FFFFFF00000000FFFFFF0000FFFF00FF00FFFF00FFFFFF
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFFFFFFFF
FF00000000FF00FFFF00FF0000FFFFFF0000FF00FFFF00FF00000000FFFFFFFFFFFF00FF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF
00FF0000FF00FFFFFFFFFF0000FFFFFF0000FFFFFFFFFF00FF0000FF00FFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
000000FF00FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00FF000000FFFFFFFF00FFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
0000FF00FF00FFFFFF00FFFF0000FF0000FFFF00FFFFFF00FF00FF0000FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000
00FF00FF00FF00FFFF00000000FFFFFF00000000FFFF00FF00FF00FF0000000000FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF
000000FFFFFFFFFF00FF0000FFFFFFFFFF0000FF00FFFFFFFFFF000000FF0000FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00
FF0000FFFFFFFFFF000000FF00FFFFFF00FF000000FFFFFFFFFF0000FF00FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFF00FFFF0000FFFFFFFFFFFFFF0000FFFF00FFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFF00FF000000000000000000FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFF00FFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFF00000000000000FFFFFF00000000000000FFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF00FFFF00FFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF000000FFFFFF00FFFFFF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF0000FFFF00FF00FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.431968 0.97619 0.519278 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2201243136631) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FFFF00000000FFFFFF0000000000FFFF0000FF00FF00FFFF0000FFFFFF000000FF
FFFF000000FFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFF000000FFFFFF000000FFFFFF
0000FFFF00FF00FF0000FFFF0000000000FFFFFF00000000FFFF0000FF
FFFFFFFF00FF0000FFFFFFFFFF0000FF00000000FF00FF00FFFFFFFF0000000000FF0000
000000FF000000000000000000FFFFFF000000000000000000FF0000000000FF00000000
00FFFFFFFF00FF00FF00000000FF0000FFFFFFFFFF0000FF00FFFFFFFF
FFFFFF00FF00FF00000000000000FF00FF0000FFFFFF00FF00FFFF00FF0000FF000000FF
FF00FFFFFF0000FF0000FFFF00FFFFFF00FFFF0000FF0000FFFFFF00FFFF000000FF0000
FF00FFFF00FF00FFFFFF0000FF00FF00000000000000FF00FF00FFFFFF
FFFFFFFFFFFF00FF0000FF0000FF00FFFFFF0000000000FFFFFFFFFFFF00FFFFFF0000FF
FF0000000000FFFFFF00000000FFFFFF00000000FFFFFF0000000000FFFF0000FFFFFF00
FFFFFFFFFFFF0000000000FFFFFF00FF0000FF0000FF00FFFFFFFFFFFF
FFFFFFFFFF00FF00FF000000FF00FF00FFFF0000FF0000FFFFFFFFFFFF0000000000FFFF
FFFF0000FF0000000000FF00FFFFFFFFFF00FF0000000000FF0000FFFFFFFF0000000000
FFFFFFFFFFFF0000FF0000FFFF00FF00FF000000FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFF000000FF000000FFFFFF00FF000000FFFFFFFFFFFFFFFF0000FF000000
000000FF00FF0000FF000000FFFF00FFFF000000FF0000FF00FF000000000000FF0000FF
FFFFFFFFFFFFFF000000FF00FFFFFF000000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF00FFFF00FFFFFF000000FF00000000000000000000FF00FF0000
FF00FFFFFF00FF000000FFFF00FFFFFF00FFFF000000FF00FFFFFF00FF0000FF00FF0000
0000000000000000FF000000FFFFFF00FFFF00FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FFFFFF00FFFF00FFFF0000FF00FF00FF00
0000FFFF00FF00FFFF00000000FFFFFF00000000FFFF00FF00FFFF000000FF00FF00FF00
00FFFF00FFFF00FFFFFF0000FFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFF0000000000FFFF00000000FF00FF00FFFFFF
00FF00FFFFFF00000000FF0000FFFFFF0000FF00000000FFFFFF00FF00FFFFFF00FF00FF
00000000FFFF0000000000FFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000000000FF0000FFFFFFFF0000FF00FF00FF00FFFF
000000FFFFFF00FFFF000000FFFFFFFFFF000000FFFF00FFFFFF000000FFFF00FF00FF00
FF0000FFFFFFFF0000FF00000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF0000FFFF00FFFFFF000000000000FF00FF00FF00FFFFFF
FF0000FFFFFF00000000FF00000000000000FF00000000FFFFFF0000FFFFFFFF00FF00FF
00FF000000000000FFFFFF00FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000000000FF0000FF000000FFFFFF00000000
0000FFFFFFFFFF0000FF00FF0000FF0000FF00FF0000FFFFFFFFFF000000000000FFFFFF
000000FF0000FF0000000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF00FFFFFFFF00FF00FFFFFF00FF0000
FF00000000000000FFFFFF00FF000000FF00FFFFFF00000000000000FF0000FF00FFFFFF
00FF00FFFFFFFF00FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FFFFFFFF000000FFFFFF000000FF
FFFF0000FFFF0000FFFF00FF00FF00FF00FF00FFFF0000FFFF0000FFFFFF000000FFFFFF
000000FFFFFFFF00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFFFFFFFFFF0000FFFF00FF0000FF
FF00FF00000000FFFFFFFF00FF00FF00FF00FFFFFFFF00000000FF00FFFF0000FF00FFFF
0000FFFFFFFFFFFF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000000000FFFFFF000000FFFF
FFFF00FF0000FF00FFFF00FF00FFFFFF00FF00FFFF00FF0000FF00FFFFFFFF000000FFFF
FF0000000000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FF00FF00FFFFFFFF0000FF00FF
FF00FF00FF00FFFFFFFFFFFF0000000000FFFFFFFFFFFF00FF00FF00FFFF00FF0000FFFF
FFFF00FF00FF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FF00FFFFFF0000FFFFFF
FFFFFF000000FFFFFFFFFFFF0000FF0000FFFFFFFFFFFF000000FFFFFFFFFFFF0000FFFF
FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFF00FF00FFFF0000FFFFFF
FFFFFF0000FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFF
00FF00FFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFF00FFFFFFFF
FFFFFFFF00000000000000000000FF00000000000000000000FFFFFFFFFFFFFFFF00FFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFF00FFFFFF0000000000
0000000000FF0000FFFF0000FF000000FF0000FFFF0000FF00000000000000000000FFFF
FF00FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF00FF0000FF00
00FF0000FF00FF00000000FF00FF00FF00FF00000000FF00FF0000FF0000FF0000FF00FF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFF000000FFFFFF
00FFFFFFFF000000FF00FF00FF00FF00FF00FF00FF000000FFFFFFFF00FFFFFF000000FF
FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF00000000
00FFFFFFFF0000FF00FF00FF00FFFFFF00FF00FF00FF0000FFFFFFFF0000000000FFFF00
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00000000FF0000
FFFFFFFFFFFF00FFFFFFFFFF0000000000FFFFFFFFFF00FFFFFFFFFFFF0000FF00000000
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFF00
00000000000000FFFFFFFFFF0000FF0000FFFFFFFFFF0000000000000000FFFFFF0000FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000000000
FF0000FF0000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFF0000FF0000FF0000000000FF00
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF00
0000FFFFFF000000000000000000FF000000000000000000FFFFFF000000FF0000FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF000000
FF0000000000FF0000FFFF0000FF00FF0000FFFF0000FF0000000000FF000000FF00FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00
0000FF0000FF00FF00000000FF00FF00FF00000000FF00FF0000FF000000FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF
FF00FFFFFFFFFF00FF0000FF00FF00FF00FF0000FF00FFFFFFFFFF00FFFF00FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFF00FF00FF000000FFFFFF000000FF00FF00FFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
00FFFFFFFFFFFF00FF00FF0000FFFFFF0000FF00FF00FFFFFFFFFFFF0000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000000000FFFFFF0000FFFFFF0000FFFFFF0000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF0000FFFF00FF00FFFFFF00FFFFFFFFFF00FFFFFF00FF00FFFF0000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFF000000FFFFFF00000000000000FFFFFF000000FFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFF0000FFFFFFFFFF0000FF0000FFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00000000000000FF00FF00000000000000FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FF0000FF0000FF00FF00FF0000FF0000FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF000000FF00FF00FF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFF000000FFFFFF000000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FF00FFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF000000FFFFFF000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00000000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.528009 0.200176 0.615319 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2200855124832) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FFFFFF00FFFFFFFFFFFF00FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF00FFFFFFFFFFFF00FFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF00FF00FFFFFFFFFFFF00FFFFFF0000FF
FFFFFFFFFFFF0000FFFF00FFFFFFFFFFFFFF0000FFFF00FFFFFFFFFFFF00FFFF00FFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF00FFFF00
FFFFFFFFFFFF00FFFF0000FFFFFFFFFFFFFF00FFFF0000FFFFFFFFFFFF
FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF0000FFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF0000FFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF
FFFFFFFFFFFF0000FFFFFF00FF00FF00FFFFFF00FFFFFFFFFFFF00FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFF0000FFFFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF00FFFFFFFFFFFF00FFFFFF00FF00FF00FFFFFF0000FFFFFFFFFFFF
FFFFFFFFFF0000FF00FFFFFFFFFFFF0000000000FFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFF0000FF0000FFFFFF0000FFFFFF0000FFFFFF0000FF0000FFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFF0000000000FFFFFFFFFFFF00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFF00FF00FFFFFFFFFF00
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFF00
FF00FFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFF00FF0000FFFF00FFFFFF00FFFF0000FF00FFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF0000FF
FF000000000000FFFFFFFFFF0000FF0000FFFFFFFFFF000000000000FFFF0000FF00FFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFF0000FF
FFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFF
FFFFFFFFFF000000FFFFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFF00FFFF00FFFF00FFFF00FFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF00FFFF00FF
FF00FFFF00FFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFF00FFFFFFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFF00
FF00FFFFFF00FFFF00FFFFFFFF00FF00FFFFFFFF00FFFF00FFFFFF00FF00FFFFFFFFFFFF
FFFFFF0000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFFFFFFFF00FF00FFFFFFFF
FFFFFF00FFFFFF0000FFFF00FFFFFFFFFF00FFFF0000FFFFFF00FFFFFFFFFFFFFF00FF00
FFFFFFFFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFFFFFF00FFFF
FFFFFF000000FFFFFFFF0000FFFFFFFFFF0000FFFFFFFF000000FFFFFFFFFF00FFFFFFFF
FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFF00
FFFF0000FF000000FFFF0000FFFFFFFFFF0000FFFF000000FF0000FFFF00FFFFFFFFFFFF
FFFFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFF00FF0000FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFF000000FFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF000000FFFF
FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFF000000FFFFFF00FFFFFFFFFFFFFF00FFFFFF000000FFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF0000000000000000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFFFFFF
FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFF00FF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF
0000FFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFF0000FF0000FF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFFFF
0000FFFFFF00FFFFFFFF000000FFFFFF000000FFFFFFFF00FFFFFF0000FFFFFFFF0000FF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFF000000FF0000FF0000FF0000FF0000FF000000FFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFF
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFF00FFFF00FFFF00FF00FFFF00FFFF00FFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FFFF0000FFFFFFFF000000FFFFFFFF0000FFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF000000FFFFFFFFFF00FF0000FF0000FF00FFFFFFFFFF000000FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF00FF00FFFFFFFF00FFFFFFFFFF00FFFFFFFF00FF00FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFF00000000000000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFF00FF00FFFFFF00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.528009 0.39418 0.615319 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2200855124833) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00000000FFFFFFFFFFFFFFFFFF00FF00FFFFFFFF00FF0000FFFF00FFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FF00FFFF0000FF00FFFFFFFF00FF00FFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF00FF0000FFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF0000FF0000FFFFFFFFFF0000FF0000FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF00FFFFFFFFFFFFFFFF0000FF00FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFF0000FFFFFFFFFFFF00FFFFFF00
FFFFFF00FF00FFFFFFFF0000FFFFFFFFFF0000FFFFFFFF00FF00FFFFFF00FFFFFF00FFFF
FFFFFFFF0000FFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFF00FF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF000000
FFFFFF000000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFF0000FF00FFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF0000FFFFFFFFFFFF00FFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
00FFFFFFFFFFFF0000FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFFFF0000FFFFFF00
FFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFF00FFFFFF0000FF
FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF0000FF00FFFFFF00FF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
00FFFF0000FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFF00FF00FFFFFFFFFF0000000000FFFFFFFFFF00FF00FFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFF00FF0000FFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FF00FF
FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFF
0000FF00FFFFFF00FF00FFFF00FFFFFF00FFFF00FF00FFFFFF00FF0000FFFF0000FFFFFF
FFFFFFFFFFFFFFFF0000FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF00FF0000FF0000FF00FFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00
FF0000FF0000FF00FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FF00FF00FFFFFFFF00FFFFFFFF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF00FF00FFFFFF
FF00FFFF0000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FF00FF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
0000FFFF0000FFFF00FFFFFF0000FF0000FFFFFF00FFFF0000FFFF0000FFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF0000FFFFFFFFFFFFFF
0000FFFFFFFFFFFF0000FF00FF000000FF00FF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFF
0000FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFF00FFFFFFFFFFFF000000FF000000FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF00FF0000FFFFFF
FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF0000FF00
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFF00FFFFFFFF00FFFF00FFFF00FFFF00FFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFF0000FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF0000FFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF00
00FFFFFFFFFF00FFFFFFFFFFFF000000FFFFFFFFFFFF00FFFFFFFFFF0000FF00FFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFF0000000000000000FF0000000000000000FFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFF00FF00FFFFFF00FFFFFF00FFFFFF00FF00FFFFFFFF0000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFF00FF0000FFFFFFFFFF00FFFFFFFFFF0000FF00FFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFF00FF0000FFFFFF0000FF00FFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.528009 0.588183 0.615319 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2200855124834) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FFFFFF0000FFFFFF0000000000FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFF0000FF00FF00FF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFF0000FF0000FFFFFF0000000000FFFFFF0000FFFFFF0000FF
FFFFFFFFFFFF0000FFFFFF000000000000FFFF0000FFFFFFFFFFFFFFFFFF00FF00FFFF00
00FFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFF00FF00FF
FFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFF0000FFFFFFFFFFFF
FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF
FFFFFFFFFFFF0000FFFFFFFF00FF00FFFFFF00000000FF00FFFFFF0000FFFFFFFFFFFFFF
00FFFF000000FFFFFF000000FFFF00FFFF000000FFFFFF000000FFFF00FFFFFFFFFFFFFF
0000FFFFFF00FF00000000FFFFFF00FF00FFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00000000FFFFFFFFFFFFFF00FF0000FFFFFF
FF00FFFF00FFFF00FFFF00FFFF000000FFFF00FFFF00FFFF00FFFF00FFFFFFFF0000FF00
FFFFFFFFFFFFFF00000000FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFF0000FFFF0000000000FF00FF00FF0000FFFFFFFFFFFF
0000FFFFFFFFFF0000FFFFFF0000000000FFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFF00
00FF00FF00FF0000000000FFFF0000FFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFF0000000000FFFFFFFFFF0000FFFFFFFFFFFF
0000FFFFFFFF000000FFFFFF0000000000FFFFFF000000FFFFFFFF0000FFFFFFFFFFFF00
00FFFFFFFFFF0000000000FFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFF0000000000FFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFF0000000000FFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000000000FFFF00FFFF0000FFFF00FF00FF
00FFFFFFFFFF000000FFFF00FFFF00FFFF00FFFF000000FFFFFFFFFF00FF00FF00FFFF00
00FFFF00FFFF0000000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFF000000FF0000FFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF
FFFFFF00FFFFFFFF00FFFF0000FFFFFF0000FFFF00FFFFFFFF00FFFFFFFFFFFFFFFF00FF
FF00FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF00FFFFFFFFFFFFFF00FF00FFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FF00
FFFFFFFFFFFFFF00FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFF00FF00FF00FFFFFF
FFFFFFFF00FF00FFFF00FFFFFFFFFFFFFFFFFF00FFFF00FF00FFFFFFFFFFFFFF00FF00FF
00FFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFF0000FFFF00FFFFFF00FFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF00FF00FFFFFF00
FFFFFFFF00FFFFFF0000FFFFFFFF00FFFFFFFF0000FFFFFF00FFFFFFFF00FFFFFF00FF00
FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFF00FFFFFFFFFFFFFF00FF
00FFFF0000FFFFFF0000FFFF00FFFFFF00FFFF0000FFFFFF0000FFFF00FF00FFFFFFFFFF
FFFF00FFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFFFF0000FF00FF00FFFF
FFFF000000FFFF00FF00FFFFFFFFFFFFFFFFFF00FF00FFFF000000FFFFFFFF00FF00FF00
00FFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF0000FFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF00
00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF0000FFFF00FF00FFFF0000FFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF0000FFFFFFFF
FFFF00FFFF00FFFFFF0000FFFFFFFFFFFFFF0000FFFFFF00FFFF00FFFFFFFFFFFF0000FF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFFFF
FFFF0000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF0000FFFFFFFFFFFF0000FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFF00
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FFFFFF0000FF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFF00FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF0000FF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFF0000FF00FFFFFF00FFFFFFFF00FFFFFFFF00FFFFFF00FF0000FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF0000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF00FFFFFFFFFF00FFFF000000FFFF00FFFFFFFFFF00FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFF000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFF00FFFF000000FFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF0000FFFFFFFFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFF0000FFFF00FFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFF000000FFFFFF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.528009 0.782187 0.615319 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2201243097204) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FF00FFFFFF0000FFFF000000FF00FFFF00FFFF00FFFFFFFF0000FFFF00FFFFFF
FFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFF00FFFF00
00FFFFFFFF00FFFF00FFFF00FF000000FFFF0000FFFFFF00FF000000FF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF000000FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFF00FFFFFFFF000000FF000000FF000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFF000000FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FF00FFFF00FFFF
FF00FFFF000000FF00FF0000FFFFFFFFFF0000FF00FF000000FFFF00FFFFFF00FFFF00FF
00000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFF
FFFFFFFFFFFFFF000000FFFFFF00FFFF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFF000000FF00FFFFFF00FF000000FFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFF000000FFFF00FFFF00FFFFFF000000FFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFF00FFFF00FFFF0000
FFFFFFFFFFFF00FF00FFFF0000FFFFFF0000FFFF00FF00FFFFFFFFFFFF0000FFFF00FFFF
00FFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFF000000FFFFFF0000FFFFFF
FF0000FF0000FFFFFFFF00FF0000FF0000FF00FFFFFFFF0000FF0000FFFFFFFF0000FFFF
FF000000FFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFF00FFFF0000FFFFFFFF00FF00FFFFFFFFFF00FFFFFFFF00FF
FFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFFFFFF00FFFFFFFF00
FFFFFFFFFF00FF00FFFFFFFF0000FFFF00FFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFF00FFFFFFFFFFFF00FF00FFFFFF0000FF
FFFF00FFFFFFFF00FF00FFFF00FFFFFF00FFFF00FF00FFFFFFFF00FFFFFF0000FFFFFF00
FF00FFFFFFFFFFFF00FFFFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFF
000000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF000000FFFFFFFFFFFFFF
FF0000FF00FFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFF
0000FF00FF00FFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF00FF00FF0000FFFFFFFF00FFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF000000FF0000000000FFFFFFFFFF00FFFF000000FF00
00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF0000FF000000FFFF
00FFFFFFFFFF0000000000FF000000FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFF00FFFF00FFFFFF0000FF00FF
0000FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF0000FF00FF0000FFFF
FF00FFFF00FFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFF00FFFFFFFF00FF00FFFFFFFFFF0000
00FF00FFFFFF0000FF00FF00000000000000FF00FF0000FFFFFF00FF000000FFFFFFFFFF
00FF00FFFFFFFF00FFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFFFFFF
FFFFFFFF0000FFFF00FF00FF0000FF0000FF00FF00FFFF0000FFFFFFFFFFFFFFFF00FFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFF00FFFFFFFFFF00FF00FF00FF
FFFFFFFF0000FFFF0000FFFFFF00FF00FFFFFF0000FFFF0000FFFFFFFFFF00FF00FF00FF
FFFFFFFF00FFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF000000FFFFFF
0000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000FFFFFF000000FF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFF00FFFF00FFFF00
FF0000FF000000FFFFFFFF00FFFFFFFFFF00FFFFFFFF000000FF0000FF00FFFF00FFFF00
FFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
00FF000000FF0000000000FFFFFFFFFFFFFF0000000000FF000000FF00FFFFFFFFFF00FF
00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFF00FF00FFFFFFFFFFFF
FF00FF0000FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFF00
FF00FFFF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF000000FFFF00FFFFFF
00FF00FFFF00FFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF00FFFF00FF00FFFFFF00FFFF00
0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFF00FF00FFFF
000000FFFF000000000000FFFFFFFFFFFFFF000000000000FFFF000000FFFF00FF00FFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000000000FF000000
FFFFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFF000000FF000000
000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFF00FFFFFF
FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFF00FFFF00
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF00FF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
00FFFF0000FFFF00FFFF000000000000000000FFFF00FFFF0000FFFF00FFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00
FFFFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFF00FFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFF0000FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF0000FFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00
FFFF00FFFF00FFFF00FF000000FFFFFF000000FF00FFFF00FFFF00FFFF00FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFF00000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FFFFFFFF000000000000000000FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFF00000000000000FFFFFF00000000000000FFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFF00FFFF00FF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.528009 0.97619 0.615319 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2201243097205) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FF00FFFF000000FF00FFFF00FFFFFFFFFFFF0000FFFF000000FFFFFFFFFF0000
00FFFF0000FFFF0000FFFFFF00FFFFFF00FFFFFF0000FFFF0000FFFF000000FFFFFFFFFF
000000FFFF0000FFFFFFFFFFFF00FFFF00FF000000FFFF00FF000000FF
FFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFF0000FFFF0000FF00FFFF00FFFFFF
FFFF00FF000000FFFF0000FF00FFFFFF00FF0000FFFF000000FF00FFFFFFFFFF00FFFF00
FF0000FFFF0000FFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFF00FF0000000000FFFF00FF00FFFFFFFF00FFFF0000FFFF00FFFFFF000000FFFFFF
FFFFFFFFFFFFFFFF00FF000000FFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFF000000FF
FFFF00FFFF0000FFFF00FFFFFFFF00FF00FFFF0000000000FF00FFFFFF
FFFFFFFFFFFF00FFFF00FF00FF00FFFFFF00FFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFF00
FFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFF00FFFFFFFFFFFF
00FFFFFFFFFF00FFFFFFFF00FFFFFF00FF00FF00FFFF00FFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFF0000FFFF00FFFFFFFF00FF00FFFF00FF00FFFF00FFFF00FF
00FFFFFF0000FF00FFFF00FFFFFFFFFFFFFF00FFFF00FF0000FFFFFF00FF00FFFF00FFFF
00FF00FFFF00FF00FFFFFFFF00FFFF0000FFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFF00FF00000000FF00FFFFFF00FFFFFFFF00FF0000FFFFFFFFFF000000FF
FFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF000000FFFFFF
FFFF0000FF00FFFFFFFF00FFFFFF00FF00000000FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF0000FFFFFFFF00FF00FFFF00FF00FF0000FFFFFFFFFFFFFFFF
00FFFFFF00FF0000000000FF0000FF0000FF0000000000FF00FFFFFF00FFFFFFFFFFFFFF
FF0000FF00FF00FFFF00FF00FFFFFFFF0000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFFFF00FFFFFFFFFFFFFFFF000000
FFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFF000000FFFFFFFF
FFFFFFFF00FFFFFFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF00FF0000
FFFF00FFFFFFFF00FFFFFFFF00FFFFFF00FFFFFFFF00FFFFFFFF00FFFF0000FF00FFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF00FF00FF
FFFFFF0000000000FFFFFFFF0000FF0000FFFFFFFF0000000000FFFFFFFF00FF00FFFFFF
FFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFFFFFF00FFFFFFFF00FFFFFF000000FF
FF00FFFFFFFFFFFFFF00FF00FF000000FF00FF00FFFFFFFFFFFFFF00FFFF000000FFFFFF
00FFFFFFFF00FFFFFFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFF00FFFF0000FF0000FF0000
FF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FF00FF0000FF0000FF00
00FFFF00FFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFF00FFFFFF00FFFFFF0000FFFFFFFF0000
FFFFFFFF00FFFF0000FFFF00FFFF00FFFF00FFFF0000FFFF00FFFFFFFF0000FFFFFFFF00
00FFFFFF00FFFFFF00FFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFF00FFFF00FFFFFFFF00
FF00000000FFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFF00000000FF00FFFFFFFF00FF
FF00FFFF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFF00FFFF00000000FFFFFF00FFFFFF00FFFFFF00000000FFFF00FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFF00FFFFFFFF00FFFFFFFF
FF00FF00FFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFF00FF00FFFFFFFFFF00FFFF
FFFF00FFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFFFFFFFFFF00FFFFFFFF0000
FFFFFFFFFF00FFFFFFFF0000FF00FF00FF0000FFFFFFFF00FFFFFFFFFF0000FFFFFFFF00
FFFFFFFFFFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFF00FFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFF00FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFF0000FFFFFFFFFF00
FFFF00FFFF00FFFF00FF00FFFFFFFFFFFFFF00FF00FFFF00FFFF00FFFF00FFFFFFFFFF00
00FFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFF0000FFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000000000FFFFFF00FFFF
FFFFFFFF0000FFFF00FFFF0000FFFFFF0000FFFF00FFFF0000FFFFFFFFFFFF00FFFFFF00
000000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFF00FFFF
00FF00FFFFFFFFFF0000FF00FFFFFFFFFF00FF0000FFFFFFFFFF00FF00FFFF00FFFF00FF
FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF000000
FFFFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFFFF000000FFFFFFFF
FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FFFF0000FF
00FFFFFFFFFFFFFFFF00FFFF00FFFFFF00FFFF00FFFFFFFFFFFFFFFF00FF0000FFFF0000
0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FFFFFFFFFF
0000FF0000FFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFF0000FF0000FFFFFFFFFF0000
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
00FFFFFFFFFFFFFFFFFF0000FFFF00FFFF0000FFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFF00
FF00FFFFFFFF00FFFFFF0000FFFF00FFFF0000FFFFFF00FFFFFFFF00FF00FFFFFF000000
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00
FF00FF0000FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF0000FF00FF00FFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00
0000FFFFFFFFFF0000FF000000FFFFFF000000FF0000FFFFFFFFFF000000FFFFFF00FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF
FF00FF00FFFFFF0000FFFFFFFFFF00FFFFFFFFFF0000FFFFFF00FF00FFFF0000FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00
FFFFFFFF0000FFFFFFFF000000FF00FF000000FFFFFFFF0000FFFFFFFF00FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFF0000FFFFFFFF0000FF00FF00FF0000FFFFFFFF0000FFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
0000FFFF00FFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFF00FFFF000000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FFFF00FFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFF00FFFF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF0000FFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFF0000FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FF00FF00FFFF0000FF00FF00FF0000FFFF00FF00FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FF00FFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00000000FF0000FFFFFFFFFF0000FF00000000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF0000FF00FFFFFF00FF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFF0000FF0000FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFF00FFFFFF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF0000FF00FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.624051 0.200176 0.711361 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2200855085406) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FFFFFF000000FF0000FFFF000000FFFFFF000000FF0000FF00FFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFF
FF00FF0000FF000000FFFFFF000000FFFF0000FF000000FFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFF0000FFFFFF00000000FFFFFFFFFFFFFF000000FFFFFF0000FFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00
00FFFFFF000000FFFFFFFFFFFFFF00000000FFFFFF0000FFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF00FFFFFF0000FFFFFF00FF00FFFFFF0000FFFF00FFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FF00FFFF0000FFFFFF00FF00FFFFFF0000FFFFFF00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FF0000FFFFFF00FFFFFF00FF0000FFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFF0000FF00FFFFFF00FFFFFF0000FF00FFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFF000000FF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFF0000FFFFFF0000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF0000FF000000FFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF00
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF00
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFF000000000000FFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFF000000000000FFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFF0000FFFFFFFFFFFFFF0000FFFFFF0000
FFFFFFFFFFFFFFFFFFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000
FFFFFFFFFFFFFF0000FFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF0000FF00FFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFF000000FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFF00FF0000FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF
FFFFFF00FF0000FF00FFFFFFFFFFFFFFFFFFFFFF00FF0000FF00FFFFFFFFFFFFFFFF00FF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF000000FFFFFFFFFFFFFF00FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF
FFFFFFFF000000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF000000FFFFFFFFFF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFF00FFFF000000FFFF
FF00FFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFF00FFFFFF000000FFFF
00FFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF000000FFFFFFFF
FFFFFFFFFFFFFF0000FFFFFF00FFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFF000000
FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFF00FF
000000FFFF0000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000FFFF000000FF00FFFF0000FF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFF0000
00FFFFFFFFFFFF00FFFF00FFFF00FF00FFFF00FFFF00FFFFFFFFFFFF000000FFFF0000FF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFF
FF0000FFFFFF000000000000FFFFFFFFFF000000000000FFFFFF0000FFFFFFFF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FF00FF00000000FFFFFFFF00000000000000FFFFFFFF00000000FF00FF00FFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFF00FFFFFFFF00FFFF00FF00FFFFFF00FF00FFFF00FFFFFFFF00FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF0000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000000000FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF00FF0000FFFF00FFFF00FF00FFFF00FFFF0000FF00FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF0000000000FFFFFFFFFF0000000000FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFF00000000000000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFF00FF00FFFFFF00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.624051 0.39418 0.711361 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2200855085407) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00000000FFFFFFFFFFFF00FFFF000000FFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FF0000FFFFFFFFFF00FFFFFF000000FFFF00FFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFF00000000FF0000FFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF0000
FFFFFFFFFF00FFFFFF0000000000000000000000FFFFFF00FFFFFFFFFF0000FFFFFFFFFF
FF00FF00FFFFFFFFFFFFFFFFFFFF0000FF00000000FFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFF00FFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFF
FFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFF0000FFFFFFFFFFFFFFFF000000FF0000FF00FFFFFFFFFF
FFFFFFFFFFFF00FFFF00FFFFFF00FF00FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF00FF
0000FF000000FFFFFFFFFFFFFFFF0000FFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFF00000000
0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000000000FFFFFF
FFFFFFFFFFFFFF00FF000000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF00FFFFFFFF00
00FFFFFF00FF000000FF0000FFFFFFFFFF0000FF000000FF00FFFFFF0000FFFFFFFF00FF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFF0000FF00FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00
FF00FFFF0000FFFFFF0000FFFFFF00FFFFFF0000FFFFFF0000FFFF00FF00FFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00000000000000FFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFF00000000000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00
00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF00FFFFFF00FF0000FF00FFFFFFFFFF
FFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FF
0000FF00FFFFFF00FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFF000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF000000FFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FFFF000000FFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFF000000FFFF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFF0000FF00FF0000FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF00FFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FF00FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FF00FFFF00FFFFFFFFFFFFFF000000FFFFFFFFFFFFFF00FFFF00FF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00000000FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FF0000FFFF0000FFFFFFFFFFFF00FF00FFFFFFFFFFFF0000FFFF0000FFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFF0000000000FFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFF00FFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00000000
00000000FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF0000000000000000FFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
0000FFFF00FFFF00FFFF00FFFF000000FFFF00FFFF00FFFF00FFFF0000FFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFF00000000FFFFFFFF0000000000FFFFFFFF00000000FFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFF00000000FFFFFF00000000FFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFF0000FF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.624051 0.588183 0.711361 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2200855085408) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FFFFFF000000FF000000FFFF00FF00FFFF00000000000000FFFFFFFFFF00000000
00FFFFFFFF00FF00FFFFFFFF0000FF0000FFFFFFFF00FF00FFFFFFFF0000000000FFFFFF
FFFF00000000000000FFFF00FF00FFFF000000FF000000FFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFF00FFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF
FF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFF0000FFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FF
FF000000FFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFF000000FFFF00FFFF000000
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFF0000FFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFF000000
FFFFFFFFFF00FFFF00000000FFFFFFFFFF00000000FFFF00FFFFFFFFFF000000FFFFFFFF
FFFFFFFFFF00FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF00FFFFFF00FFFFFFFFFFFF00FFFF000000FFFF00FFFFFFFF00000000
00FFFFFFFFFFFF000000000000FFFFFF000000000000FFFFFFFFFFFF0000000000FFFFFF
FF00FFFF000000FFFF00FFFFFFFFFFFF00FFFFFF00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF000000FFFF0000000000
0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000000000FFFF
000000FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FF00FFFFFFFFFFFF0000FFFFFF0000000000FFFFFFFFFFFF
FFFFFFFFFF0000FFFFFF00FFFFFFFFFFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFF0000FFFFFFFFFFFF00FF00FFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFF000000FFFFFFFF00FFFF0000FF00FF0000FF0000FFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000FF0000
FF00FF0000FFFF00FFFFFFFF000000FFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFF00FFFFFFFFFFFF00FF00FFFFFFFFFF0000
0000FF00FFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF00FF00000000FFFFFFFFFF
00FF00FFFFFFFFFFFF00FFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFF00FFFF00FFFF0000FFFFFFFFFFFFFF00
FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF00FFFFFFFFFFFF
FF0000FFFF00FFFF00FFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF00FFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FFFFFFFF00FF
FFFFFFFF00FFFF0000FFFFFF0000FF0000FFFFFF0000FFFF00FFFFFFFFFF00FFFFFFFF00
00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000000000FFFFFFFFFF00FFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFF
FFFF0000000000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFF0000FFFFFFFF0000FFFFFFFFFF0000FFFFFFFF0000FFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFF00FFFFFFFF00FFFF
FF000000FFFF0000FFFFFFFF00FF00FF00FFFFFFFF0000FFFF000000FFFFFF00FFFFFFFF
00FFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFF00FF0000FFFFFF0000FF00FFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFFFFFF
FFFFFF00FF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF00FF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF00FFFFFFFFFF00FFFFFFFFFF000000FFFFFFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF0000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFF
FFFF00FF00FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFF00FFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFF0000FFFFFFFFFFFFFFFFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF00000000FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00000000FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF00FF00FFFFFFFF00FFFFFFFFFF00FFFFFFFF00FF00FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00000000FFFF000000FFFF00000000FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFF00000000000000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFF00FF00FFFFFF00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.624051 0.782187 0.711361 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2200855105119) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FF0000FF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFF00FFFFFFFFFF0000FF00FFFFFFFFFF00FF0000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFF0000FF00FFFFFFFFFF00FF0000FFFFFFFFFF00FFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF0000FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFF00FFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFF00
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFF0000FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFF00FFFFFFFFFF0000000000FFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF0000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF00
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FF0000FF0000FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFF0000FF0000FFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFF00FFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFF0000FFFFFF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000FF00FFFFFFFFFF
00FF0000FFFFFF00FFFF00000000FF00000000FFFF00FFFFFF0000FF00FFFFFFFFFF00FF
0000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00
FF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FF00FFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFF00FFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
00FFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00
FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFF00FF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00
00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFF
00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFF0000FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFF0000FF00FF00FF00FF00FF00FF0000FFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF0000FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFF0000FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.624051 0.97619 0.711361 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2200855105121) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFF00FF00FFFFFFFF00FFFFFFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00
FFFFFFFF00FFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFF00FFFF0000FFFF
FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFFFF00FFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF00
FFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF0000FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF0000FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF0000FFFFFFFFFF
FF0000FFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFF0000FFFFFFFFFFFF0000
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FF00FFFFFF000000FFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFF000000FFFFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF000000FF
FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF000000FFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF0000FFFF00FF00FFFFFFFF00FFFFFF
FFFFFFFF0000FF00FF000000FFFFFFFFFF000000FF00FF0000FFFFFFFFFFFFFF00FFFFFF
FF00FF00FFFF0000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFF00FFFF00FFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFF00FFFF00FFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFF00FF00
00FF0000FFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFF0000FF0000FF00FFFFFFFF
FFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FF00FFFFFF0000FFFFFF00FF
FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFF00FFFFFF0000
FFFFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFF
000000FFFFFFFFFF00FFFF0000FFFFFF0000FFFF00FFFFFFFFFF000000FFFFFFFFFFFFFF
FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF0000FFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFF00FFFF000000FFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFF00FFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
00FFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FF00FFFF
FF00FFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF00FFFFFF00FF00FFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00
FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFF
00FFFF00FFFFFF00FFFF000000FFFFFF000000FFFF00FFFFFF00FFFF00FFFF0000FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF0000FFFF00FFFF0000FFFFFF0000FFFF00FFFF0000FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.720092 0.200176 0.807402 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2200467073610) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FF00FFFFFFFFFF00FFFFFFFFFF00FFFFFF0000000000FFFFFFFF00FFFFFFFFFF
FFFF00FFFF0000FFFFFFFFFFFF00FF00FFFFFFFFFFFF0000FFFF00FFFFFFFFFFFFFF00FF
FFFFFF0000000000FFFFFF00FFFFFFFFFF00FFFFFFFFFF00FF000000FF
FFFFFFFFFFFFFFFF0000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FF000000FFFFFFFF00FFFF00FFFFFFFFFF00FFFF00FFFFFFFF000000FFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFF00FFFF00
FFFFFFFFFF00FFFFFFFF000000FFFFFF000000FFFFFFFF00FFFFFFFFFF00FFFF00FFFFFF
FFFFFFFF00FFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FF00FFFFFFFFFFFFFF0000000000FF0000000000FFFFFFFFFFFFFF00FFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFF000000FF00FFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFF00FFFFFFFF00FFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFF
FF00FFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFF00FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FFFF00FFFFFF000000FFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFF0000FFFFFFFFFF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFF00FFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFF0000FF0000FFFFFF
FF00FFFFFFFF00000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFF00FFFFFFFF0000FF00
00FFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFF00
FFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFF
FFFF0000FFFFFFFFFF00FFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FFFFFFFFFF0000FFFFFFFFFF
FF0000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF0000FFFFFFFFFFFF0000
FFFFFFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF
FF0000FFFFFFFF00FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFF00000000FFFFFFFFFFFF00
00FFFFFFFFFFFFFF0000FF00FFFFFFFFFF00FF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFF
00000000FFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFF00FFFFFFFFFFFF00FFFF00FFFF
FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FFFF00FF
FFFFFFFFFF00FFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFF
FF000000FFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFF000000FFFFFFFFFFFFFFFF
0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF00FFFFFFFF00FFFF0000FF
0000000000FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF0000000000FF0000FFFF00FF
FFFFFF00FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFF00FFFF00FFFF00FFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFF00FF
FF00FFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF00FFFFFFFF0000
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFFFF00
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFF
FF000000FFFFFF00FFFFFFFF0000FF0000FFFFFFFF00FFFFFF000000FFFFFFFFFFFFFFFF
FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFF00FFFFFF00
FFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFF00FFFFFF00FFFF
FFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFF00FFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFF
00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFF00FFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFF00
0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFF00
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFF00FFFFFFFF00FFFF00FFFF00FFFF00FFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00
FFFF000000FFFF000000FFFFFF000000FFFFFF000000FFFF000000FFFF00FFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFF0000FFFFFF00FFFFFFFFFFFFFF00FFFFFF0000FFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFF00FF00FFFFFFFFFFFFFFFFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFF0000FF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.720092 0.39418 0.807402 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2200467093322) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FFFFFFFF00FFFFFF00FFFF00FF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFF000000FF000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF0000FF00FFFF00FFFFFF00FFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000FFFF0000FF00FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFF
000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF0000FF00FFFF0000FFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFF00FFFFFFFFFFFF0000FF0000FFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF00FFFF0000FFFF00FF0000FF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFF00FFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFF
FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFF0000FFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF0000FF00FF0000FFFFFFFFFF0000FF00FF0000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFF0000FFFF0000FFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000FFFF00FFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF
000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF00FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFF0000FF00FFFFFFFF
FFFFFFFFFFFFFFFF0000FF00FFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFF00FF00
00FFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFF00FFFF00FFFFFFFFFFFF0000FF0000FF0000
00FFFFFFFF000000FFFFFFFFFF00FF00FFFFFFFFFF000000FFFFFFFF000000FF0000FF00
00FFFFFFFFFFFF00FFFF00FFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFF00FFFFFFFFFFFF0000FF000000FFFF
FFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFF000000FF00
00FFFFFFFFFFFF00FFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFF000000FF0000FFFFFFFFFF00FFFF
00FFFFFFFFFFFF0000FF000000FFFFFF000000FF0000FFFFFFFFFFFF00FFFF00FFFFFFFF
FF0000FF000000FFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFF00FFFFFFFFFF00FFFF
00FFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFF00FFFF00FFFFFFFF
FF00FFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF00FFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFF00FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFF00000000FFFF
00000000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF00000000FFFF00000000FF
FF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF00FFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFF
FFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF00FF
00FFFF0000FFFFFFFFFF00FF0000FF0000FF00FFFFFFFFFF0000FFFF00FF00FFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFF00FF
FF0000FFFF0000000000FFFF00FFFFFF00FFFF0000000000FFFF0000FFFF00FFFF0000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FF
FF00FFFFFFFF00FF00FFFFFFFF00FF00FFFFFFFF00FF00FFFFFFFF00FFFF00FFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF
FFFF00000000FFFFFF0000FF0000FF0000FF0000FFFFFF00000000FFFFFF00FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFF00FFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF0000FF00FFFFFFFFFFFF0000FF0000FFFFFFFFFFFF00FF0000FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFF0000FFFFFFFF0000FF0000FFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF00FFFFFFFFFF0000FF0000FFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFF0000FF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF0000FFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.720092 0.588183 0.807402 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2200467093323) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FF00FFFFFFFF00FFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00000000
FF00FFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFF00FF00000000FFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFF00FFFFFFFF00FF000000FF
FFFFFFFFFFFFFFFF00FFFFFF0000FFFFFFFFFF00FFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFF00FFFFFF0000000000FF0000000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF00FFFFFFFFFF0000FFFFFF00FFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFF00FFFFFFFF00FFFF000000FFFFFF00FFFFFFFFFFFFFFFF0000FF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFF
FFFFFFFF00FFFFFF000000FFFF00FFFFFFFF00FFFFFFFFFF0000FFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFF
FFFFFFFFFF0000FF00FFFFFF00FFFFFF00FFFFFF00FF0000FFFFFFFFFFFFFFFFFF0000FF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFF000000FF00FFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFF00FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFFFFFFFFFF00FF0000FFFFFFFFFF
FF00000000FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFF00000000FFFFFFFFFFFF0000
FF00FFFFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF000000FFFF0000FFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFF0000FFFF000000FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFF00000000FF00FF00FFFFFFFFFFFF00
00FFFF00FF00FFFFFFFFFF000000FF000000FFFFFFFFFF00FF00FFFF0000FFFFFFFFFFFF
00FF00FF00000000FFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF00FF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFF0000FFFFFF000000FF000000
000000FFFFFFFFFFFF0000FFFF00FF00FFFF0000FFFFFFFFFFFF000000000000FF000000
FFFFFF0000FFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000FFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF00FFFFFF00FFFF00
FF0000FF0000FFFF00FFFFFFFF00FF00FFFFFFFF00FFFF0000FF0000FF00FFFF00FFFFFF
00FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFF0000FFFF00FFFF00
00FFFFFFFFFF00FFFF00000000FFFFFF00000000FFFF00FFFFFFFFFF0000FFFF00FFFF00
00FFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFF00FFFFFFFF000000FFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF000000FFFF
FFFF00FFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFFFFFFFF
0000FFFFFF00FFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF00FFFFFF0000FFFFFFFFFFFF00
00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FFFFFFFF00FFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF
FFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFF00FFFFFF
00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFF00FFFFFF
FFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FF
FFFFFF00FFFFFFFFFFFF00FFFF00FF00FFFF00FFFFFFFFFFFF00FFFFFFFF00FFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFF
FF0000FFFFFF00FFFFFF00FF0000FF0000FF00FFFFFF00FFFFFF0000FFFFFFFFFF00FFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFF00FF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFF00
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
00FF0000FF00FFFFFFFF0000FFFFFFFFFF0000FFFFFFFF00FF0000FF00FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFF00FFFFFF000000FFFFFF0000FF0000FFFFFF000000FFFFFF00FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFF00FFFFFFFF000000FFFFFFFFFF000000FFFFFFFF00FFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFF00FF000000FF0000FFFFFFFFFFFFFF0000FF000000FF00FFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF00FFFFFF00FF00FFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFF00FFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FF00FFFF000000FFFFFFFFFFFFFF000000FFFF00FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFF00FF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF0000FFFFFFFFFFFFFF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFF0000FF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.720092 0.782187 0.807402 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2200467113035) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFF0000FF00FF0000FF00FFFFFF00FF0000FF00FF0000FFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FF000000FF
FFFFFFFFFFFFFFFF00FFFFFF00FF00FFFF00FFFF000000FF0000FFFF00FFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
00FFFF0000FF000000FFFF00FFFF00FF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFF00FFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFF00FFFFFFFF
FFFFFFFF00FFFFFF000000FF0000000000FF000000FFFFFF00FFFFFFFFFFFFFFFF00FFFF
FFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFF00FFFFFFFFFF0000FFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF00FFFFFFFFFFFF
FF0000FFFFFF00FFFFFFFFFF0000FF0000FFFFFFFFFF00FFFFFF0000FFFFFFFFFFFFFF00
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFF0000FFFFFF00FFFF00FFFF000000FFFF0000FFFF00FF00FFFFFFFFFFFF00FF
0000FF00FFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFF00FF0000FF00FFFFFFFFFF
FF00FF00FFFF0000FFFF000000FFFF00FFFF00FFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFF00FFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FF00FFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FF00FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFF00FF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFF00FFFF00FFFFFFFFFFFFFF00FFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFF00FF00FFFFFFFFFF00FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FFFF00FF00FFFF00
00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF0000FFFF00FF00FF
FF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFFFFFFFF0000FFFFFFFF0000FFFFFFFFFF
FFFF00FFFFFFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFF0000
FFFFFFFF0000FFFFFFFFFF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFF00FFFFFFFFFFFF00FF000000FF00FF
FFFF0000FFFFFF00FFFFFFFFFF00FF00FFFFFFFFFF00FFFFFF0000FFFFFF00FF000000FF
00FFFFFFFFFFFF00FFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF0000FFFFFFFFFFFFFF0000
00FFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFF000000FFFFFFFFFF
FFFF0000FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFF00FF00FF0000FFFFFF00FFFFFFFF
FFFF00FFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFF
FF0000FF00FF00FFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF000000FFFFFFFFFFFFFF00FFFF
FFFFFFFF00FFFF00000000FFFFFFFFFFFFFF00000000FFFF00FFFFFFFFFFFF00FFFFFFFF
FFFFFF000000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFFFF00FFFF00FFFFFFFFFF
FF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFF00FF
FF00FFFFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF000000000000
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF000000000000FF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00FF00FF00FFFFFFFFFFFFFF
FFFF0000FFFFFFFFFF00FFFFFF00FF00FFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
00FF00FF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FF0000FF00FF
FFFF00FFFFFF00FFFFFF00000000FF00000000FFFFFF00FFFFFF00FFFFFF00FF0000FF00
00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFF000000
FFFF00FFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFF00FFFF000000FFFFFFFF
FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFF00FF00FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFF0000FFFF
FFFFFFFF00FFFF0000FF00FFFFFFFFFFFFFF00FF0000FFFF00FFFFFFFFFFFF0000FFFF00
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00
FFFFFFFF00FFFF00FFFFFFFFFF00FF00FFFFFFFFFF00FFFF00FFFFFFFF00FFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00
00FFFF0000FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFF0000FFFF0000FFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFF000000000000FF0000FF0000FF000000000000FFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFF0000FFFFFFFF000000FF000000FFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF0000FFFFFF00FFFFFF00FFFFFFFFFF00FFFFFF00FFFFFF0000FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFF00FF00FFFFFFFFFFFFFFFFFF00FF00FFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF0000FF00FFFFFF00FF0000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF0000FFFFFF00FFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFF00FF00FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000000000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.720092 0.97619 0.807402 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2200467113036) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
0000FFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF0000FFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FF000000FF
FFFFFFFFFFFFFFFF000000FFFF00FFFFFF00FF00FFFFFFFFFF0000FFFF00FFFFFFFFFF00
FF0000FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FF0000FF00FFFFFFFFFF00
FFFF0000FFFFFFFFFF00FF00FFFFFF00FFFF000000FFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFF000000FF0000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFF0000FFFFFF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFF0000FF000000FFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFF00FFFFFFFF00000000FFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFF00FFFF
FFFFFF0000FFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFFFF00FFFFFFFF
FFFFFF00FFFF00FFFFFFFFFFFFFF00000000FFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFF000000FF00FFFFFFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFF0000FFFFFF00
FFFF00000000FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00000000FFFF00FFFFFF0000FF
FFFFFFFFFFFFFFFF00FFFF0000FFFFFFFFFFFF00FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFF00FFFF
FF000000000000FFFF00FFFFFF00FF00FFFFFF00FFFF000000000000FFFFFF00FFFFFFFF
FFFFFFFFFF00FF000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FF
FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFF00000000FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFF00FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFFFF00FF00FFFFFFFFFF0000FF
FF0000FFFF00FFFFFFFF00FFFF000000FFFF00FFFFFFFF00FFFF0000FFFF0000FFFFFFFF
FF00FF00FFFFFF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF000000FF0000FFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFF00FFFFFF0000000000FFFFFF00FFFFFFFFFF000000FFFFFFFFFFFFFF
FFFFFF0000FF000000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00000000FFFFFFFFFFFFFF00FFFF00FFFF
FFFFFFFF00FF00FFFFFFFF000000FF000000FFFFFFFF00FF00FFFFFFFFFFFF00FFFF00FF
FFFFFFFFFFFF00000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFF0000FFFF00FFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
00FFFF0000FFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF000000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
0000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF000000FFFFFF00FFFF0000FF0000FFFF00FFFFFF000000FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFFFF00FF00
FFFFFFFFFF00FFFF00000000FFFFFFFFFF00000000FFFF00FFFFFFFFFF00FF00FFFFFF00
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF000000FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000
00FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00000000FFFFFFFFFF
FFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFF0000
0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFF0000FFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFF
FFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00
0000FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF000000FFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFF0000FFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
000000FF0000FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF0000FF000000FFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00
000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00000000FFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFF
FFFFFFFF0000FFFF00FFFFFFFF00FF00FFFFFFFF00FFFF0000FFFFFFFFFFFF00FF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFF00000000FFFFFFFF00FFFFFFFF00000000FFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FF00FFFF0000FFFFFF00FFFF00FF00FF00FFFF00FFFFFF0000FFFF00FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFF00FF00FF00FF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFF00FFFFFF00FF00FF00FF00FFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FF00FFFFFFFF0000FFFFFFFFFF0000FFFFFFFF00FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF0000FFFF000000FFFF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFF0000FF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.816133 0.200176 0.903444 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1895148645568) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF00FFFFFFFF00FFFFFF00FFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFF000000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.816133 0.39418 0.903444 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1895148645569) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000000000FFFFFFFFFF0000000000FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FF00FFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF000000FFFFFF00FFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF00FFFFFFFF00FFFFFF00FFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFF000000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.816133 0.588183 0.903444 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1895536617940) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF0000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.816133 0.782187 0.903444 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1895536637653) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.816133 0.97619 0.903444 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1906787343620) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FF0000FFFFFFFFFFFFFF0000FF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF000000FF000000FFFF0000FF00FF0000FFFF000000FF000000FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFF000000FFFF0000FFFFFF00FFFFFF0000FFFF000000FFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFF00FFFF0000FFFFFFFFFFFFFFFFFF0000FFFF00FFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFFFFFF0000FF0000FFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF0000FFFFFF00FFFFFFFFFF00FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFF00FFFFFF00FFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFF00FF00FFFFFF00FF00FFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFF000000FF000000FF000000FF000000FF000000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFF000000FFFF0000FF0000FFFF000000FFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFF00FFFF0000FFFFFF0000FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF00FFFFFF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFF00FF00FFFFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF000000FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF0000FFFF000000FFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFF00FF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FF00FF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFF000000FF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.912175 0.200176 0.999485 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1883121856867) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.912175 0.39418 0.999485 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1883121856868) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.912175 0.588183 0.999485 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1895148606142) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF0000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF0000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF0000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF0000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.912175 0.782187 0.999485 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1895148606143) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF0000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF0000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF0000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF0000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF0000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.912175 0.97619 0.999485 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1895148645567) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFF0000FF0000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFF000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFF0000FF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF0000FF00FFFFFFFFFF00FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFF000000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.00822 0.200176 1.09553 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1599528836872) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFFFFFFFF00000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFF00FFFF
FFFFFF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000FFFFFF
FFFFFFFF00FFFFFFFF000000000000000000000000000000000000000000000000000000
00000000000000000000000000FFFFFF0000000000000000000000000000000000000000
0000000000000000000000000000000000000000FFFFFFFF00FFFFFFFF
FFFFFFFFFF000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF000000FFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFF000000000000000000000000000000000000000000000000
00000000000000000000000000FFFFFF0000000000000000000000000000000000000000
0000000000000000000000000000000000FFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFF0000000000000000000000000000000000000000000000
0000000000000000000000000000FF000000000000000000000000000000000000000000
00000000000000000000000000000000FFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000000000000000000000000000000000000000
00000000000000000000000000FFFFFF0000000000000000000000000000000000000000
00000000000000000000000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00000000000000000000000000000000000000
00000000000000000000000000FFFFFF0000000000000000000000000000000000000000
000000000000000000000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00000000000000000000000000000000
0000000000000000000000000000FF000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF000000000000000000000000000000
00000000000000000000000000FFFFFF0000000000000000000000000000000000000000
0000000000000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF000000000000000000000000
00000000000000000000000000FFFFFF0000000000000000000000000000000000000000
0000000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000000000000000000000
0000000000000000000000000000FF000000000000000000000000000000000000000000
00000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000000000000000
00000000000000000000000000FFFFFF0000000000000000000000000000000000000000
00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00000000000000
00000000000000000000000000FFFFFF0000000000000000000000000000000000000000
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00000000
0000000000000000000000000000FF000000000000000000000000000000000000FFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF000000
00000000000000000000000000FFFFFF00000000000000000000000000000000FFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
00000000000000000000000000FFFFFF00000000000000000000000000FFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FF00000000000000000000000000FF00000000000000000000000000FFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFF00FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF00FFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFF000000000000000000FFFFFF000000000000000000FFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFF00FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF00FFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFF0000000000000000FFFFFF0000000000000000FFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFF000000000000FF000000000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFF00FFFFFFFF00FF00FFFFFFFF00FFFF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF00000000FFFFFF00000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFF00FFFFFFFFFF00FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFF0000FF0000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFF00FFFFFF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFF000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.00822 0.39418 1.09553 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1599528856586) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFFFFFF00000000FFFF00000000FF0000FF00FFFFFFFFFF00FFFF0000FFFF0000
00FF00FF00FFFF000000000000FF00FF000000000000FFFF00FF00FF000000FFFF0000FF
FF00FFFFFFFFFF00FF0000FF00000000FFFF00000000FFFFFFFF00FFFF
FFFFFF00FF00FFFFFFFFFF0000FFFF00FFFFFF00FF00FF0000FF000000FF00FFFFFFFF00
FFFFFF000000FF00FFFF00FFFF000000FFFF00FFFF00FF000000FFFFFF00FFFFFFFF00FF
000000FF0000FF00FF00FFFFFF00FFFF0000FFFFFFFFFF00FF00FFFFFF
FFFFFFFF000000FF0000FFFFFF0000FFFFFFFFFF000000FFFF0000000000FFFFFFFFFFFF
0000FF00FFFF000000FF00FF0000000000FF00FF000000FFFF00FF0000FFFFFFFFFFFF00
00000000FFFF000000FFFFFFFFFF0000FFFFFF0000FF000000FFFFFFFF
FFFFFFFFFF00FFFFFF00FF0000FFFF0000FF0000FFFF00FF00000000000000FF0000FF00
000000FFFFFFFF00FFFFFF00000000000000FFFFFF00FFFFFFFF00000000FF0000FF0000
0000000000FF00FFFF0000FF0000FFFF0000FF00FFFFFF00FFFFFFFFFF
FFFFFFFFFFFF00FF00FFFFFF00FF00000000FFFF0000FFFFFF00FFFF00FFFF00000000FF
FF00FFFFFFFFFFFF0000FF00FFFF00FFFF00FF0000FFFFFFFFFFFF00FFFF00000000FFFF
00FFFF00FFFFFF0000FFFF00000000FF00FFFFFF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFF00FF00FFFF00FF00000000FF000000FF00FF000000000000
FF00FF0000FF0000FFFF000000FF00FF000000FFFF0000FF0000FF00FF000000000000FF
00FF000000FF00000000FF00FFFF00FF00FFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFF000000FFFFFF00FFFF00FF00FFFFFF00FF00FFFF00FFFF
000000FFFF00000000FF00FFFF000000FFFF00FF00000000FFFF000000FFFF00FFFF00FF
00FFFFFF00FF00FFFF00FFFFFF000000FFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF0000FFFFFF0000FF00FF00FFFF00FF00
00000000FF00FFFF00FF00FF0000000000FF00FF00FFFF00FF0000000000FF00FFFF00FF
00FF0000FFFFFF0000FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FF0000FFFF0000FFFF0000FF00FFFFFF000000FF00FF00
FFFF00FFFFFF0000FFFFFF00000000000000FFFFFF0000FFFFFF00FFFF00FF00FF000000
FFFFFF00FF0000FFFF0000FFFF0000FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00000000FF00FFFFFF0000FFFFFF00FF00FF00
FF000000FF00000000FF000000000000000000FF00000000FF000000FF00FF00FF00FFFF
FF0000FFFFFF00FF00000000FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFF000000FF00000000FF00FFFFFF0000
00FFFF00FF00FFFF00FF00FFFFFFFFFFFFFF00FF00FFFF00FF00FFFF000000FFFFFF00FF
00000000FF000000FFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FF0000000000FFFF00FFFFFF0000FF00FF
FF0000FFFFFF0000FFFFFF0000FF00FF0000FFFFFF0000FFFFFF0000FFFF00FF0000FFFF
FF00FFFF0000000000FF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00000000000000FF00FF0000FFFF000000
FF00FFFFFFFFFF00FF0000FFFF000000FFFF0000FF00FFFFFFFFFF00FF000000FFFF0000
FF00FF00000000000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FFFF000000FFFF0000FFFF00
FF00FF0000FF000000FFFFFF0000000000FFFFFF000000FF0000FF00FF00FFFF0000FFFF
000000FFFF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FFFFFFFFFF00FFFFFFFFFFFF0000
00FFFFFF00FF00FFFF00FF00000000000000FF00FFFF00FF00FFFFFF000000FFFFFFFFFF
FF00FFFFFFFFFF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF0000FF000000FF0000FF000000
0000FF000000FFFFFFFF000000000000000000FFFFFFFF000000FF0000000000FF0000FF
000000FF0000FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFF00000000FFFFFF
FFFF0000000000FF0000FFFF00FFFFFF00FFFF0000FF0000000000FFFFFFFFFF00000000
FFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FF00FFFF00FFFF00FF00FF
0000FFFF00FFFF00000000FFFFFFFFFFFFFF00000000FFFF00FFFF0000FF00FF00FFFF00
FFFF00FF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF000000FF00FF000000FFFF
FF00FF000000FF00FFFF00FF0000FF0000FF00FFFF00FF000000FF00FFFFFF000000FF00
FF000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF0000000000FF
FF00FF00FFFF000000FFFFFFFF00FF00FFFFFFFF000000FFFF00FF00FFFF0000000000FF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FFFF00FFFF00FFFF
FFFF000000FFFFFF00FF0000FF00FF00FF0000FF00FFFFFF000000FFFFFFFF00FFFF00FF
FF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF000000FF00FF00
00FFFFFF00FF0000FFFFFF00FF00FF00FF00FFFFFF0000FF00FFFFFF0000FF00FF000000
FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFF0000
0000FF00FFFFFF00FFFF000000FFFFFF000000FFFF00FFFFFF00FF00000000FFFFFF00FF
FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FF0000FFFF
00FFFFFF0000FF00FF0000000000FF0000000000FF00FF0000FFFFFF00FFFF0000FF00FF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00000000FF
00FFFF00000000FFFFFFFFFFFF00FF00FFFFFFFFFFFF00000000FFFF00FF00000000FFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00
0000FF00FFFF00FF0000FF0000FFFFFF0000FF0000FF00FFFF00FF000000FFFFFFFFFF00
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FFFF
FF00FF00FF000000FFFF00000000FF00000000FFFF000000FF00FF00FFFFFF0000FF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00
00FFFFFFFF00FFFF0000FFFF00FFFFFF00FFFF0000FFFF00FFFFFFFF0000FF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF
00FF0000FF00FF00000000FFFFFF00FFFFFF00000000FF00FF0000FF00FFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
00FF00FFFFFF000000000000FF000000FF000000000000FFFFFF00FF00FFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FF000000FFFF00FFFF00FFFF0000000000FFFF00FFFF00FFFF000000FFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FFFFFFFFFFFFFF00FFFFFF00000000000000FFFFFF00FFFFFFFFFFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FF0000FFFF000000FF000000000000000000FF000000FFFF0000FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FF0000000000FFFF00FFFFFF00FFFF0000000000FF00FFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFF00FFFF00FF00FFFFFFFFFF00FF00FFFF00FFFFFF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFF00FF000000FFFFFFFFFFFFFF000000FF00FFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFF0000000000FFFF00FFFF0000000000FFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FFFFFFFFFF00FF000000FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FF0000FFFFFFFF00FFFFFFFF0000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00FF0000FF00FF0000FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF00FFFFFF00FF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFF00FF00FF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFF000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.00822 0.588183 1.09553 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1599528876298) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000FFFF00000000000000000000FF00FFFFFFFF00FF00000000FF00FF00FF0000FF
FFFF0000FF0000FFFFFF00000000FF00000000FFFFFF0000FF0000FFFFFF0000FF00FF00
FF00000000FF00FFFFFFFF00FF00000000000000000000FFFF0000FFFF
FFFFFF00000000FFFFFF0000FFFFFF00FF00FF000000FFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFF00FF0000FFFF00FFFFFF00FFFF0000FF00FFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFF000000FF00FF00FFFFFF0000FFFFFF00000000FFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00000000000000FF0000000000
FF00000000FF00FF00FFFFFFFF000000FFFFFFFF00FF00FF00000000FF0000000000FF00
000000000000FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFF000000FF00000000FF00000000FFFFFFFF0000FFFFFF0000FFFFFF00FFFFFF
FF00FFFF00FF00FF00FF0000FF00FF00FF0000FF00FF00FF00FFFF00FFFFFFFF00FFFFFF
0000FFFFFF0000FFFFFFFF00000000FF00000000FF000000FFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFF00FFFFFFFF00000000FF00FFFFFFFFFFFFFFFFFFFF000000
0000FFFF00FF00FF00FFFFFFFF000000FFFFFFFF00FF00FF00FFFF0000000000FFFFFFFF
FFFFFFFFFFFF00FF00000000FFFFFFFF00FFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF000000FF00000000FF0000FFFF00
FF00000000FFFFFF000000000000FF000000000000FFFFFF00000000FF00FFFF0000FF00
000000FF000000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFF000000FF00000000000000FF00FF00FFFF00FFFFFF0000FF
FFFF00FF0000000000FF00FFFF000000FFFF00FF0000000000FF00FFFFFF0000FFFFFF00
FFFF00FF00FF00000000000000FF000000FFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFF00FFFFFFFFFFFFFFFFFFFF0000FFFF00000000FFFF00
0000FFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFF000000FFFF00000000
FFFF0000FFFFFFFFFFFFFFFFFFFF00FFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFF00000000000000000000FF00FFFFFFFF00FF0000FF00
FF00FF00000000000000FF00FF000000FF00FF00000000000000FF00FF00FF0000FF00FF
FFFFFF00FF00000000000000000000FFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FFFFFF00FF00FF000000FFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF00
0000FF00FF00FFFFFF0000FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF0000000000
FF0000000000000000000000FF000000FF0000000000000000000000FF0000000000FF00
FF00FF00FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00000000FF00000000FFFFFFFF0000FFFFFF00
0000FF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FF000000FFFFFF0000FF
FFFFFF00000000FF00000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFF00000000FF00FFFFFFFFFF
FFFFFFFF000000000000000000FF00FF000000000000000000FFFFFFFFFFFFFFFFFF00FF
00000000FFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF000000FF0000
000000FF00FFFFFFFF00FF0000FFFFFF0000FF00FFFFFFFF00FF0000000000FF000000FF
FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF000000FF00000000000000FF00FF00FF
FF00FFFFFF00000000FFFFFF0000000000FFFFFF00000000FFFFFF00FFFF00FF00FF0000
0000000000FF000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFFFFFFFFFFFFFFFFFF0000FF
FF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF0000FFFF0000FFFFFFFF
FFFFFFFFFFFF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00000000000000000000FF00FFFF
FFFF00FFFFFFFFFF0000FF00000000000000FF0000FFFFFFFFFF00FFFFFFFF00FF000000
00000000000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FFFFFF00FF00FF00
0000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF000000FF00FF00FFFF
FF0000FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF00FF00
FF00FF000000FF0000FFFFFFFFFFFFFFFFFFFFFF0000FF000000FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00000000FF00000000FFFF
FFFF0000FF0000FFFF000000FF000000FF000000FFFF0000FF0000FFFFFFFF00000000FF
00000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFF000000
00FF00FFFFFF00FF0000FF00FF00FF00FF00FF0000FF00FFFFFF00FF00000000FFFFFFFF
00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF
FFFF000000FF00FF00FFFFFFFF000000FFFFFFFF00FF00FF000000FFFFFFFFFFFFFFFFFF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF000000FF00000000
000000FF00FF00FF00FF00000000FF00000000FF00FF00FF00FF00000000000000FF0000
00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFFFFFFFF
FFFFFFFFFF0000FFFFFF00FFFF000000FFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFF00FF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF000000000000
00000000FF00FFFFFFFFFF000000FF000000FFFFFFFFFF00FF00000000000000000000FF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000
FFFFFF00FF00FF000000FF00FF000000FF00FF000000FF00FF00FFFFFF0000FFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFF00FF00FF0000FFFFFFFFFFFFFF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000
00FF00000000FFFFFFFF00FF0000000000FF00FFFFFFFF00000000FF00000000FF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
00FFFFFFFF00000000FF00FFFFFFFFFFFFFF00FF00000000FFFFFFFF00FFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
000000FF00000000000000FFFFFFFFFFFFFF00000000000000FF000000FFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFF00000000000000000000FF000000FF00000000000000000000FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFF0000FFFFFF00FF00FF00FF00FFFFFF0000FFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FF00000000FF00000000FF00000000FF00000000FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFF00FFFFFFFF000000FFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFF000000FF0000000000FF000000FFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFF00FFFFFFFFFFFFFF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFF000000000000000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.00822 0.782187 1.09553 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1599916848671) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFFFF0000FFFFFFFF0000FFFFFFFFFFFFFFFF00FF00000000FFFFFFFFFF0000FF
FF00FF000000FFFF0000FFFFFF00FF00FFFFFF0000FFFF000000FF00FFFF0000FFFFFFFF
FF00000000FF00FFFFFFFFFFFFFFFF0000FFFFFFFF0000FFFFFF00FFFF
FFFFFF0000FF00FFFFFFFFFFFFFF0000FF00FF0000FF00FF00FFFF00FF00FF00FF00FFFF
FFFF00FFFFFF0000FFFF0000FF00FF00FF0000FFFF0000FFFFFF00FFFFFFFF00FF00FF00
FF00FFFF00FF00FF0000FF00FF0000FFFFFFFFFFFFFF00FF0000FFFFFF
FFFFFFFF00FF00FF0000FF00FF00FFFF000000FFFF000000FFFFFFFF000000FFFFFF0000
FF00FFFFFFFFFFFFFF00000000FFFFFF00000000FFFFFFFFFFFFFF00FF0000FFFFFF0000
00FFFFFFFF000000FFFF000000FFFF00FF00FF0000FF00FF00FFFFFFFF
FFFFFFFFFF000000FFFF00FFFFFF0000FFFFFF0000FFFFFF00FF0000FFFFFF0000FFFFFF
FFFF0000FF0000FF000000000000FF000000000000FF0000FF0000FFFFFFFFFF0000FFFF
FF0000FF00FFFFFF0000FFFFFF0000FFFFFF00FFFF000000FFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFF0000FFFF0000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00FF
00FF00FFFFFF00FF00FFFF00FFFF00FFFF00FFFF00FF00FFFFFF00FF00FF00FFFFFFFFFF
FFFFFFFFFF0000FFFFFFFF0000FFFF0000FFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF00FFFFFFFF00000000FF0000FFFF0000FFFF0000FF00FFFF00FF
00FF00FF00FF00FF00FF000000FFFFFF000000FF00FF00FF00FF00FF00FF00FFFF00FF00
00FFFF0000FFFF0000FF00000000FFFFFFFF00FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFF00FFFFFFFFFF00000000FFFFFF0000FFFF00FFFFFFFF00
0000FFFFFF000000FFFFFF00FFFFFFFFFF00FFFFFF000000FFFFFF000000FFFFFFFF00FF
FF0000FFFFFF00000000FFFFFFFFFF00FFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF00FFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF0000FFFF
FFFF0000FF00FFFF00FF000000FF00FF000000FF00FFFF00FF0000FFFFFFFF0000FFFFFF
FFFF00FF00FFFFFFFFFF00FF00FFFF00FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFFFF0000FF000000FFFFFFFFFFFFFFFF00FF
FF00000000FFFFFFFF00FFFF00FFFFFF00FFFF00FFFFFFFF00000000FFFF00FFFFFFFFFF
FFFFFF000000FF0000FFFFFFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFF0000000000FF0000FF00FF00FFFF
FFFFFFFF00FF0000FFFFFF000000FF000000FFFFFF0000FF00FFFFFFFFFFFF00FF00FF00
00FF0000000000FFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FF00FF00FFFFFFFFFF00000000FFFFFFFF00
00FFFF000000FFFFFF00FFFFFF00FF00FFFFFF00FFFFFF000000FFFF0000FFFFFFFF0000
0000FFFFFFFFFF00FF00FF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFFFF0000FFFF000000000000FF00FFFF
FFFF00FFFF00FF00FFFFFF00FF00FF00FF00FFFFFF00FF00FFFF00FFFFFFFF00FF000000
000000FFFF0000FFFFFF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000FFFF0000FFFFFFFF00FFFFFF00FF
FF00FFFFFFFF000000FF000000FFFFFF000000FF000000FFFFFFFF00FFFF00FFFFFF00FF
FFFFFF0000FFFF0000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF00000000FFFF000000FF00FFFF
FFFF00FF0000FFFFFF0000000000FF0000000000FFFFFF0000FF00FFFFFFFF00FF000000
FFFF00000000FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFFFFFFFFFF00FFFFFF00FFFFFF
FFFFFF00FFFF0000FFFFFF00FFFF00FFFF00FFFFFF0000FFFF00FFFFFFFFFFFF00FFFFFF
00FFFFFFFFFFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFF00FF00FFFFFFFFFFFF00FF00
00FF00FFFFFFFF00FFFF000000FFFFFF000000FFFF00FFFFFFFF00FF0000FF00FFFFFFFF
FFFF00FF00FFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFFFF00FF0000FFFFFFFF
00FFFFFF0000FF00FF0000000000FF0000000000FF00FF0000FFFFFF00FFFFFFFF0000FF
00FFFFFFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFF00FF00
0000FF00000000FFFFFF00FFFF00FF00FFFF00FFFFFF00000000FF000000FF00FFFFFFFF
FFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FF00FF00FF00FFFFFF00
FFFF000000000000FF000000FF00FF00FF000000FF000000000000FFFF00FFFFFF00FF00
FF00FF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFFFF000000FF0000
00FFFFFFFFFFFFFF0000000000FFFFFF0000000000FFFFFFFFFFFFFF000000FF000000FF
FFFF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000FFFF00FF00FF
FF00FFFF00FFFF00000000000000FF00000000000000FFFF00FFFF00FFFF00FF00FFFF00
00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF000000FFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF000000FFFF
FFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFFFFFF0000
FF00FFFFFF0000FFFF00FFFF00FF00FF00FFFF00FFFF0000FFFFFF00FF0000FFFFFFFF00
FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFF0000FFFF
000000FF00000000FF00FFFF00FF00FF00FFFF00FF00000000FF000000FFFF0000FFFF00
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFF0000
FFFFFF000000000000FFFFFFFF000000FFFFFFFF000000000000FFFFFF0000FFFF0000FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFF
0000FF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FF0000FFFF0000FF00FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FF
FFFFFFFFFFFFFF000000FF0000FF00FF0000FF000000FFFFFFFFFFFFFFFF00FFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
00FF00FF00FF0000000000FFFF000000FFFF0000000000FF00FF00FF00FFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF
FFFFFF000000FFFFFFFFFFFF0000000000FFFFFFFFFFFF000000FFFFFFFF00FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FF0000FFFF00FF00FFFF00FFFFFFFFFFFFFF00FFFF00FF00FFFF0000FFFF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FF00FFFFFFFF000000FF00FFFF00FF00FFFF00FF000000FFFFFFFF00FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFF0000FF0000000000FFFFFFFF00FFFFFFFF0000000000FF0000FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF00FFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FF0000FF0000FF00000000FF00000000FF0000FF0000FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFF00000000FFFF00FFFFFF00FFFF00000000FFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF00FFFF00FFFFFFFF00FFFFFFFF00FFFF00FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFF00FF0000FFFFFF0000FF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FF00FFFFFFFFFF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF000000FF00FF000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF00FFFF000000FFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF0000000000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.00822 0.97619 1.09553 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1883121856866) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.10426 0.200176 1.19157 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1587890138820) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFF0000FFFF00FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF0000FFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FF00FFFF0000FFFFFFFFFF
FFFFFF00FF00FFFFFFFFFFFFFFFFFF00FFFFFF000000FF00FFFF00FFFFFFFF000000FF00
FFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFF00FF000000FFFF
FFFF00FFFF00FF000000FFFFFF00FFFFFFFFFFFFFFFFFF00FF00FFFFFF
FFFFFFFFFF000000FF00FFFF00000000FFFFFF0000FF00FF00FFFFFFFFFFFFFFFFFFFF00
0000000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF000000000000FFFFFFFFFFFF
FFFFFFFF00FF00FF0000FFFFFF00000000FFFF00FF000000FFFFFFFFFF
FFFFFFFFFF0000FF00FF00FF00FFFF00FFFF00FFFF00FF00FFFFFFFF00FFFFFFFFFFFF00
00FF0000FF00FFFFFF00FFFF0000FF0000FFFF00FFFFFF00FF0000FF0000FFFFFFFFFFFF
00FFFFFFFF00FF00FFFF00FFFF00FFFF00FF00FF00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF0000FF00FF00FF00FFFFFF00FF0000FFFFFF00FF0000FFFF
FFFFFF00FFFFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFFFF00FFFFFFFFFF0000FF00FF
FFFF0000FF00FFFFFF00FF00FF00FF0000FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFFFF00FF00FF00FFFFFFFFFF000000FF00FFFFFF0000FF00FF
FF0000FFFFFFFF00FFFFFFFF0000FF0000FFFFFFFF00FFFFFFFF0000FFFF00FF0000FFFF
FF00FF000000FFFFFFFFFF00FF00FF00FFFFFF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFF00FF00
FF00FFFFFFFFFFFFFF00FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFF00FF00FF00FFFF0000
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FFFF00FFFFFFFFFFFF00FF00FFFFFFFF00FF
00FF00FFFF00FFFFFFFFFF0000FFFFFF0000FFFFFFFFFF00FFFF00FF00FF00FFFFFFFF00
FF00FFFFFFFFFFFF00FFFF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF0000FFFFFFFFFF00FF0000FFFFFF0000000000FFFF
FFFFFFFF00FF00FFFF00FF00FFFFFFFFFF00FF00FFFF00FF00FFFFFFFFFFFF0000000000
FFFFFF0000FF00FFFFFFFFFF0000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF00000000FFFF000000FF00FFFF00FFFF00FFFFFF
FFFF00FF00FFFFFF00FFFFFF0000FF0000FFFFFF00FFFFFF00FF00FFFFFFFFFF00FFFF00
FFFF00FF000000FFFF00000000FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFF00FFFFFFFF000000FFFFFFFF
FFFFFFFF0000FFFF000000FF00FFFFFF00FF000000FFFF0000FFFFFFFFFFFFFFFF000000
FFFFFFFF00FFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF0000FF00FF00FFFFFF00FFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFF0000FF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF00FF
FFFF00FF00FF0000FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF000000FFFFFFFFFFFF0000000000
FF0000FFFFFFFFFFFF00FFFF00FFFFFF00FFFF00FFFFFFFFFFFF0000FF0000000000FFFF
FFFFFFFF000000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF0000FFFFFFFFFFFFFF00FFFF00
FF00FFFFFFFF00FFFFFFFFFFFF000000FFFFFFFFFFFF00FFFFFFFF00FF00FFFF00FFFFFF
FFFFFFFF0000FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFF0000FF
FFFF000000FFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFF000000FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FFFF000000FF00000000FFFF00
000000FF0000FFFF00FFFFFFFF00FF00FFFFFFFF00FFFF0000FF00000000FFFF00000000
FF000000FFFF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FF00FF0000FF00FFFF
FFFFFFFF00FFFFFFFFFF00FF00FF00FF00FF00FFFFFFFFFF00FFFFFFFFFFFF00FF0000FF
00FF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF00FFFFFFFF00FFFF
00FFFFFFFF000000FFFF000000FFFFFF000000FFFF000000FFFFFFFF00FFFF00FFFFFFFF
00FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FF00FFFF0000FFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF0000FFFF00
FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF00FFFF
FF00000000FF00FF0000FFFF00FFFFFF00FFFF0000FF00FF00000000FFFFFF00FFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFF00000000FFFF
FF0000FF0000FFFFFF00FF00FF00FF00FF00FF00FFFFFF0000FF0000FFFFFF00000000FF
FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FFFF00FFFF
00FFFF00FF00000000FFFFFF00FF00FF00FFFFFF00000000FF00FFFF00FFFF00FFFF00FF
00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF00
FF00FFFFFFFF00FFFF00000000FFFFFF00000000FFFF00FFFFFFFF00FF00FF00FF0000FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FF00
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FF00FFFF
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000
FFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFF0000FFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00
FFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFF00FFFFFFFFFF00
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF0000FF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000
0000FFFF000000FFFF00FF000000FF000000FF00FFFF000000FFFF00000000FF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFF00FFFF00FFFF0000FFFF00FF00FFFF0000FFFF00FFFF00FFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFFFF0000FF00FF00FF000000FFFFFF000000FF00FF00FF0000FFFFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF00FF000000FFFFFFFF00FFFFFFFFFF00FFFFFFFF000000FF00FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FFFFFF00FF0000FFFFFFFFFF0000FF0000FFFFFFFFFF0000FF00FFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FF00FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF00FF00FFFF000000FF0000FFFFFF0000FF000000FFFF00FF00FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFF0000FF00FF0000000000FF00FF0000FFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF00FF00FFFFFFFFFF00FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FFFF0000FF0000FFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF00FF00FF00FFFFFF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF0000FF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.10426 0.39418 1.19157 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1587890138821) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFFFF000000FFFF00FFFF00FFFFFF00FFFF
00FF00FFFFFFFFFFFF00FFFFFF00FF00FFFFFF00FFFFFFFFFFFF00FF00FFFF00FFFFFF00
FFFF00FFFF000000FFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFF
FFFFFF00FF0000FF0000FF00FFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFF000000FFFF
0000FFFFFF00FF000000FFFFFF000000FFFFFF000000FF00FFFFFF0000FFFF000000FFFF
FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFF00FF0000FF0000FF00FFFFFF
FFFFFFFFFF0000FFFFFFFF0000FF0000FF00FFFF00FFFF00FF00FFFFFFFF00FF0000FFFF
FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFF0000FF00FF
FFFFFF00FF00FFFF00FFFF00FF0000FF0000FFFFFFFF0000FFFFFFFFFF
FFFFFFFFFF0000FFFF000000FF00FF0000FFFFFF0000FF00FFFFFFFF00FFFFFFFFFFFFFF
00FF00FF0000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF0000FF00FF00FFFFFFFFFFFFFF
00FFFFFFFF00FF0000FFFFFF0000FF00FF000000FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFF0000FF000000FFFFFFFF00FFFFFFFF0000FFFFFFFF00FFFFFF00FFFF
000000FFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFF000000FFFF00FFFFFF00
FFFFFFFF0000FFFFFFFF00FFFFFFFF000000FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF000000FF000000FFFFFFFF00FFFFFF00FF00FFFF0000000000FFFF
FFFFFFFFFF00FFFFFFFFFF00FF00FF00FF00FFFFFFFFFF00FFFFFFFFFFFFFF0000000000
FFFF00FF00FFFFFF00FFFFFFFF000000FF000000FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFF0000FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF0000FFFFFFFF0000FFFF0000FFFF00FFFF0000
FFFFFFFF00FFFF00FF00FFFF00FF00FF00FFFF00FF00FFFF00FFFFFFFF0000FFFF00FFFF
0000FFFF0000FFFFFFFF0000FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FF00FFFFFFFFFFFF00FF0000FFFFFFFF0000
FFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFF0000FFFFFFFF00
00FF00FFFFFFFFFFFF00FF000000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFF00FFFF00FFFFFF0000FFFFFFFFFFFF
FFFF00FFFFFFFFFFFF00FFFF00FF00FF00FFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFF00
00FFFFFF00FFFF00FFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF000000FFFFFFFFFFFFFFFFFF00FFFF00FF
FFFF000000FF0000FF00FF00FF00FF00FF00FF00FF0000FF000000FFFFFF00FFFF00FFFF
FFFFFFFFFFFFFF000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF00FFFFFF00FF0000FFFF00FF00FF00FF
FFFFFF00FFFFFF00FF00FF00FFFFFFFFFF00FF00FF00FFFFFF00FFFFFFFF00FF00FF00FF
FF0000FF00FFFFFF00FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFF0000FF
FFFF00FF00FFFF0000FFFFFF0000000000FFFFFF0000FFFF00FF00FFFFFF0000FFFFFFFF
FF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF0000FF00FFFFFF00FFFF00FF0000FF00
FFFFFFFF00000000FF00FFFF0000FF0000FFFF00FF00000000FFFFFFFF00FF0000FF00FF
FF00FFFFFF00FF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF000000FF00FF00FF00FF000000
FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF000000FF00FF00
FF00FF000000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF000000FF0000FFFFFF00FF00FFFF00
FFFF00FFFFFFFF0000FFFFFF00FFFFFF00FFFFFF0000FFFFFFFF00FFFF00FFFF00FF00FF
FFFF0000FF000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000FF00FFFF000000FFFF00
00FFFFFF00FFFF0000FFFFFF0000000000FFFFFF0000FFFF00FFFFFF0000FFFF000000FF
FF00FF000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF000000FFFFFF00FFFFFF00
00FFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFF
FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF
FFFF00FFFF00FFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF00FFFF00FFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFF00FFFF00
FFFFFF00FFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF00FFFFFF00FFFF00FFFF00
0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFF000000
FFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFF000000FFFFFF00
00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FFFF00
FFFFFF00FFFFFF0000FFFFFF00FFFFFF00FFFFFF0000FFFFFF00FFFFFF00FFFF0000FFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF00FF0000
FFFFFF00000000FFFF00000000FFFFFF00000000FFFF00000000FFFFFF0000FF00FFFFFF
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
00FFFF0000FF0000FF00FFFF00FFFFFF00FFFF00FF0000FF0000FFFF00FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF0000FF00
FFFFFFFFFFFFFF00FF00FF0000FFFFFF0000FF00FF00FFFFFFFFFFFFFF00FF0000FF0000
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00
00FF00000000FF00FF00FF00FFFFFFFFFF00FF00FF00FF00000000FF0000FFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF000000
FF00FF0000FF00FF00FF00FF00FFFFFF00FF00FF00FF00FF0000FF00FF000000FFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00
0000FFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFF000000FF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000
FF000000FFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFF000000FF000000FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000FF00FFFFFFFFFFFFFF00FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FF000000FF00FFFFFFFF00FFFFFF00FFFFFFFF00FF000000FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF00FF0000FFFFFFFF000000FFFFFF000000FFFFFFFF0000FF00FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFF000000FFFF00FFFFFF00FFFF000000FFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFF00FFFFFFFF000000FFFFFFFF00FFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF0000FF0000FF00FF000000FF00FF0000FF0000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFF000000FF000000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF000000FF000000FF000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FF000000FF000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF000000FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.10426 0.588183 1.19157 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1587890138822) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFF00FF00FFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF000000FFFFFF00FF00
00FF00FF00FFFF00FFFFFFFF00FF00FF00FFFFFFFF00FFFF00FF00FF0000FF00FFFFFF00
0000FFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF00FF00FFFFFFFFFFFFFF
FFFFFF00FF0000FFFFFF0000FF000000FF0000FF0000FFFFFFFFFFFF00FFFFFFFFFF0000
0000FFFFFF0000FFFFFFFFFFFF000000FFFFFFFFFFFF0000FFFFFF00000000FFFFFFFFFF
00FFFFFFFFFFFF0000FF0000FF000000FF0000FFFFFF0000FF00FFFFFF
FFFFFFFFFF000000FF000000FFFFFFFFFF000000FFFF0000FF0000FF00FF0000FF000000
000000FF00000000FF0000FF0000000000FF0000FF00000000FF000000000000FF0000FF
00FF0000FF0000FFFF000000FFFFFFFFFF000000FF000000FFFFFFFFFF
FFFFFFFFFF0000FF00FF0000FFFFFFFFFF00000000FF00FFFFFF00FF00FF00FFFFFF00FF
FF00FFFFFF00FFFF00000000FFFF00FFFF00000000FFFF00FFFFFF00FFFF00FFFFFF00FF
00FF00FFFFFF00FF00000000FFFFFFFFFF0000FF00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000FFFFFF0000FF00FF
000000FF000000FF00FFFF00FF000000FF00FFFF00FF000000FF000000FF00FF0000FFFF
FF000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF0000FF0000FFFF00FFFF00FFFFFF00FFFFFFFFFF00FF00FF
00FFFF0000000000FFFFFFFF0000000000FFFFFFFF0000000000FFFF00FF00FF00FFFFFF
FFFF00FFFFFF00FFFF00FFFF0000FF0000FFFF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF0000FF0000FFFF00FFFF0000FFFF
FF0000FFFF00FFFF0000FF00000000000000FF0000FFFF00FFFF0000FFFFFF0000FFFF00
FFFF0000FF0000FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF0000FFFFFF0000FF00FFFF00FFFFFF00FFFFFFFF00FFFF0000
FF00FFFFFFFF0000FFFF000000000000000000FFFF0000FFFFFFFF00FF0000FFFF00FFFF
FFFF00FFFFFF00FFFF00FF0000FFFFFF0000FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFF000000FF0000FFFFFF00FFFFFFFF00
FF00FF0000FF00FFFFFFFF00FFFF00FFFF00FFFFFFFF00FF0000FF00FF00FFFFFFFF00FF
FFFF0000FF000000FFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFF00FFFFFF00FFFFFFFF0000FF0000
00FFFFFF00FF00FF0000FF00FF000000FF00FF0000FF00FF00FFFFFF000000FF0000FFFF
FFFF00FFFFFF00FFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF0000FF00FF00FFFF000000FFFF
00FF0000FFFFFF00000000FFFFFF00FFFFFF00000000FFFFFF0000FF00FFFF000000FFFF
00FF00FF0000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF0000FF0000FFFF000000FFFFFF00000000FF
00FF00FFFFFFFFFF00FFFF0000FF00FF0000FFFF00FFFFFFFFFF00FF00FF00000000FFFF
FF000000FFFF0000FF0000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFF0000FFFF000000FFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFF00FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFF0000FF000000FF0000FFFF00FFFF
00FFFFFFFFFFFFFFFFFF00FF0000000000FF00FFFFFFFFFFFFFFFFFF00FFFF00FFFF0000
FF000000FF0000FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFF000000FFFFFFFF
0000FF0000FF0000FF000000FFFF00FFFF000000FF0000FF0000FF0000FFFFFFFF000000
FFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFF00000000FFFF00
FFFF00000000FFFF0000000000FF00FF0000000000FFFF00000000FFFF00FFFF00000000
FFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFF00FFFF0000FFFF00FFFF000000FFFF00FFFF0000FFFF00FFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF0000FF0000FFFF00FFFF00FF
0000FF00FF00000000FF00FF0000000000FF00FF00000000FF00FF0000FF00FFFF00FFFF
0000FF0000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF0000
FFFF000000FFFF00FFFFFF00000000000000FFFFFF00FFFF000000FFFF0000FFFFFFFFFF
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFF0000FF00FFFF00FF
FFFFFF00FFFFFFFF0000FF00FFFF00FFFF00FF0000FFFFFFFF00FFFFFFFF00FFFF00FF00
00FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFF000000
FF0000FFFFFFFFFFFF00FF00FF000000FF00FF00FFFFFFFFFFFF0000FF000000FFFFFF00
0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFF00FF
FFFF00FF0000FF0000FFFFFF0000000000FFFFFF0000FF0000FF00FFFFFF00FFFFFFFF00
00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00
00FF00FF00FFFFFF00FF0000FFFF00FFFF0000FF00FFFFFF00FF00FF0000FFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF0000FF0000FF
FF000000FFFFFFFFFF00000000FF00FF00000000FFFFFFFFFF000000FFFF0000FF0000FF
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFF00FFFFFFFFFFFFFF00FFFF000000FFFF00FFFFFFFFFFFFFF00FFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFF0000
FF000000FF0000FF0000FFFFFFFF00FFFFFFFF0000FF0000FF000000FF0000FFFFFF0000
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000
FFFFFFFFFF000000FFFF0000FF000000FF0000FFFF000000FFFFFFFFFF000000FF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000
FFFFFFFFFF00000000FF00FFFFFF00FFFFFF00FF00000000FFFFFFFFFF0000FF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
0000FF0000FFFF00FFFF00FFFFFF00FFFFFF00FFFF00FFFF0000FF0000FFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFFFFFF0000FF000000FF0000FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
00FFFFFF0000FF00FFFF00FFFFFF00FFFFFF00FFFF00FF0000FFFFFF0000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FF000000FFFFFF000000FF000000FF000000FFFFFF000000FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF00FF0000FFFFFFFF00FFFFFF00FFFFFF00FFFFFFFF0000FF00FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFF0000FF0000FFFF000000FFFF0000FF0000FFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFFFFFF00FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF0000FFFFFF0000FF000000FF0000FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF00FF0000FFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF0000FF0000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF0000FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.10426 0.782187 1.19157 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1588278111194) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFF00FF0000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF00FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFF00FFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFF00FFFF00FF00FFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF0000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF0000FF00FFFFFF00FFFFFF00FFFFFF00FF0000FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFF000000FF000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFF0000FF00FF0000FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF0000FFFF000000FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF000000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.10426 0.97619 1.19157 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1588666122991) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFF00FF00FF0000FF0000FFFFFFFFFFFFFF00FF0000FFFFFF000000FF
0000FFFFFFFFFFFF0000FF00FFFF00FFFF00FF0000FFFFFFFFFFFF0000FF000000FFFFFF
0000FF00FFFFFFFFFFFFFF0000FF0000FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FF000000FF00FF
FFFF000000000000FFFFFFFF00FFFFFF00FFFFFFFF000000000000FFFFFF00FF000000FF
00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF00FFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF0000000000FFFFFF00FF00FF
00FFFFFFFFFFFF00FFFFFFFFFF00FF00FFFFFFFFFF00FFFFFFFFFFFF00FF00FF00FFFFFF
0000000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF0000000000FF000000FF00FFFFFFFFFFFF00FFFF0000FFFFFF00FFFF
FF00000000FFFF000000FF0000FFFFFF0000FF000000FFFF00000000FFFFFF00FFFFFF00
00FFFF00FFFFFFFFFFFF00FF000000FF0000000000FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF00FFFF00FFFFFF00000000FF00FF0000FF00FF0000FFFF
00FF0000FF00FF00FFFFFF00FFFFFFFFFF00FFFFFF00FF00FF0000FF00FFFF0000FF00FF
0000FF00FF00000000FFFFFF00FFFF00FFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FF00
FFFFFF0000FFFFFFFF00FF00FF000000FF00FF00FFFFFFFF0000FFFFFF00FF00FFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000000000FF00FFFFFFFFFF00FF
FFFFFFFF0000000000FFFFFF00FF00FF00FFFFFF0000000000FFFFFFFFFF00FFFFFFFFFF
00FF0000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFF00FF0000FF000000FF0000FF00FFFFFFFFFFFFFF00
00FF0000FFFF00FFFFFFFFFF00FF00FF00FFFFFFFFFF00FFFF0000FF0000FFFFFFFFFFFF
FF00FF0000FF000000FF0000FF00FFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF0000FFFF0000FFFFFFFFFF00FFFF
FF00FF00000000FFFF0000FFFFFF00FFFFFF0000FFFF00000000FF00FFFFFF00FFFFFFFF
FF0000FFFF0000FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFF0000FFFFFF00FFFF000000FF00FFFFFF
FF00FF00FFFF00FF00FF000000FFFFFF000000FF00FF00FFFF00FF00FFFFFFFF00FF0000
00FFFF00FFFFFF0000FFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF0000FFFF00FFFF00FFFFFFFF
FFFFFFFFFF00FFFFFF0000FFFF00FF00FFFF0000FFFFFF00FFFFFFFFFFFFFFFFFF00FFFF
00FFFF0000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF00FF000000FFFFFFFFFFFFFF0000FF00
00FFFF00FF00FFFFFFFFFF0000FFFFFF0000FFFFFFFFFF00FF00FFFF0000FF0000FFFFFF
FFFFFFFF000000FF00FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FFFF00FF
000000FFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFF000000FF00FFFF00FFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FF00FF0000FF000000FFFFFFFF00
00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFFFF0000
00FF0000FF00FF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000000000
FFFFFFFF00FF0000FF0000FFFFFFFFFFFFFF0000FF0000FF00FFFFFFFF000000000000FF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000000000FF00FFFF0000FF00FF00FF
FFFFFFFFFF00FFFF00FFFF00FF000000FF00FFFF00FFFF00FFFFFFFFFFFF00FF00FF0000
FFFF00FF0000000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FF00FF00FF
0000FF0000FFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFF0000FF0000FF00FF00FF00FF
FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFF000000FF
FFFF00FF000000000000FFFFFFFFFFFFFFFFFF000000000000FF00FFFFFF000000FFFFFF
FFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FF0000
FFFF0000FFFF00FFFF00FF000000FF000000FF00FFFF00FFFF0000FFFF0000FF0000FFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FF000000FFFFFF00
0000FFFF00FFFFFFFFFF00FFFF000000FFFF00FFFFFFFFFF00FFFF000000FFFFFF000000
FF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF0000FF
FFFFFFFF0000FFFFFFFF00FF0000FF0000FF00FFFFFFFF0000FFFFFFFFFF0000FF00FFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFF0000FF
FF000000FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF000000FFFF0000FFFFFFFF
FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFF00
0000FF00000000FF0000FFFFFFFFFFFFFFFFFF0000FF00000000FF000000FFFF00000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF00FFFF00
00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFF00FFFF00
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FF0000FFFFFFFFFF0000FF000000FF0000FFFFFFFFFF0000FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF0000FF
00FFFFFF00FF0000FF00FF000000FF000000FF00FF0000FF00FFFFFF00FF0000FFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFF0000FFFF00FF00FFFF0000FFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000
FFFF00FFFF00000000FFFFFF00FFFFFF00FFFFFF00000000FFFF00FFFF00000000FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFF00FFFF0000FF00000000FFFFFFFFFF00000000FF0000FFFF00FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00
00FFFFFF0000FFFFFF00FF00000000000000FF00FFFFFF0000FFFFFF0000FFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF00FF00FFFF00FFFF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF0000FF00000000000000FF00FF00FF00000000000000FF0000FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFF0000FF0000FFFFFF0000FF0000FFFF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFF00FF0000FFFFFF0000000000FFFFFF0000FF00FFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF0000FFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000FFFFFFFFFFFFFF000000FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFF000000FF000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.2003 0.200176 1.28761 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1576639393430) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF000000
00FF00FFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFF00FF00000000FFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF0000FFFFFFFFFFFFFF0000FFFF00FFFF00FFFFFFFFFF0000FFFFFFFF
FFFFFFFF0000FF00FF00FFFFFF00FF00FFFFFF00FF00FF0000FFFFFFFFFFFFFFFF0000FF
FFFFFFFF00FFFF00FFFF0000FFFFFFFFFFFFFF0000FF00FFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFF00FFFF00FF00000000FFFFFFFFFFFFFF0000FFFFFFFF00FFFF
FF0000FFFFFFFFFF000000FFFF00FF00FFFF000000FFFFFFFFFF0000FFFFFF00FFFFFFFF
0000FFFFFFFFFFFFFF00000000FF00FFFF00FFFFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFF000000FFFF00FFFFFFFF00FF00FFFFFFFFFFFFFFFFFF00
FFFFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFF
FFFFFF00FF00FFFFFFFF00FFFF000000FFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFF000000FFFFFF00FFFF00FFFF
FFFFFF000000FF0000FFFFFFFFFFFFFFFFFFFFFF0000FF000000FFFFFFFFFF00FFFF00FF
FFFF000000FFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFF
FF00FF00FFFF00000000FFFF0000FF0000FFFF00000000FFFF00FF00FFFFFFFFFF00FFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF0000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00
FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFF0000FF0000FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FF0000FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF00FFFFFFFF00FFFFFFFFFF00FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF0000FF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFF
FFFFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
00FF0000FFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFF00FF00FFFFFFFFFFFFFF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFF00FF00FFFFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFF00FFFF00FFFF00FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF000000FFFFFF00FF0000FFFF0000
FFFF000000FFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFF000000FFFF0000FFFF0000FF
00FFFFFF000000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFF0000FFFFFF00FFFFFFFFFF00FFFFFF0000FFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFF00FF00FF00000000
0000FF00FF00000000FFFFFFFFFFFFFFFFFFFFFF00000000FF00FF000000000000FF00FF
00FFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF0000FFFFFF0000000000
000000FFFFFF00FFFF0000FFFFFFFFFFFFFF0000FFFF00FFFFFF0000000000000000FFFF
FF0000FF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFFFF00FFFF00
FFFF00FFFF00FFFFFFFF00FF0000FF0000FF00FFFFFFFF00FFFF00FFFF00FFFF00FFFFFF
FFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFF00FFFF
FF00FFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF00FF00FFFFFFFFFF00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFF00FFFF00FFFF
00FFFF0000FF00FF000000FFFFFFFFFFFFFF000000FF00FF0000FFFF00FFFF00FFFF00FF
FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF000000FF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF000000FFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF00FF
00FF00FFFFFFFF00FFFFFF0000FF00FF0000FFFFFF00FFFFFFFF00FF00FF00FFFF0000FF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
00FF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FF00FFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FF0000FF00
FFFFFF00FF00FFFFFFFF0000FFFFFFFFFF0000FFFFFFFF00FF00FFFFFF00FF0000FF00FF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF
FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF00FFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
00FFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFF00FFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FF
FFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF00FFFF00FFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFF0000FFFFFFFFFF0000FF00FF00FF0000FFFFFFFFFF0000FFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFFFFFF0000FF00FF00FFFFFF00FF00FFFFFF00FF00FF0000FFFFFFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFF00FF00FF00FF0000FFFFFF0000FF00FF00FF00FFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FF0000FFFF00FFFFFF00FF00FFFFFF00FFFF0000FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFF00000000FFFFFF00FFFFFFFFFF00FFFFFF00000000FFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF00FFFF0000FFFFFF0000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF0000FF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FF00FF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.2003 0.39418 1.28761 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1576639413142) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFF00FFFFFF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF0000FF00FFFF
FF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFF00FF0000FF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF00FFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFF00FFFF00FFFFFF00FFFFFFFFFF00FFFF00FF0000FFFFFF
FF00FFFFFFFF00000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFF00FFFFFFFF0000FF00
FFFF00FFFFFFFFFF00FFFFFF00FFFF00FFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFF00FFFFFF000000FFFFFF00FFFF00FF00FFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FF00FF00FFFF00FFFFFF000000FFFFFF00FFFFFFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFF00FF0000FFFFFFFFFF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FF00FFFFFFFFFF0000FF00FFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FFFF000000FFFFFFFFFFFFFFFF00
FF00000000FF0000FFFFFFFF00FF00FF00FFFFFFFF0000FF00000000FF00FFFFFFFFFFFF
FFFF000000FFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFF00FFFF00FFFF0000FFFFFF00FF0000FF0000FF00FFFF00FFFFFF
00FF0000FF00FFFF0000FF0000FFFFFF0000FF0000FFFF00FF0000FF00FFFFFF00FFFF00
FF0000FF0000FF00FFFFFF0000FFFF00FFFF00FFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF00FFFF0000FFFFFFFF00FF0000FFFF00FF00FFFFFFFF00
FF00FF0000FFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFF0000FF00FF00FFFFFFFF00FF
00FFFF0000FF00FFFFFFFF0000FFFF00FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFF00FFFF000000FFFFFF00FF
FFFFFF0000FFFF00FFFFFF00FFFFFFFFFF00FFFFFF00FFFF0000FFFFFFFF00FFFFFF0000
00FFFF00FFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FF000000FF00FFFFFF00FF0000FFFF00FF00
FFFFFFFF00FF00FF00FFFFFF0000FF0000FFFFFF00FF00FF00FFFFFFFF00FF00FFFF0000
FF00FFFFFF00FF000000FF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF000000
FFFFFFFFFF00FF00FF00FFFF00FFFFFF00FFFF00FF00FF00FFFFFFFFFF000000FFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF0000FFFF00FF0000FF00FFFFFFFF
FF00FFFF00FFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFF00FFFF00FFFFFFFFFF00FF00
00FF00FFFF0000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF00FF00FFFF0000FFFF00FF
0000FFFFFF00FFFFFFFFFFFF0000000000FFFFFFFFFFFF00FFFFFF0000FF00FFFF0000FF
FF00FF00FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFF00FFFF0000FFFF
FF00FF00FFFFFFFF00FFFF00FFFF00FFFF00FFFF00FFFFFFFF00FF00FFFFFF0000FFFF00
FFFFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFF00000000FFFF00FFFF00000000FFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FF00FF00FFFF00000000FFFFFF
FF00FFFF00FFFF00FF0000FF00FFFFFF00FF0000FF00FFFF00FFFF00FFFFFFFF00000000
FFFF00FF00FF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFF00FFFF00FFFF
FF000000FFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFF000000FFFFFF00FFFF00FF
FFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFF00FF00FF
FF0000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF0000FFFF00FF00FFFFFF
FFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF0000000000FFFFFF0000
FF00FFFFFFFFFF0000FF00FFFFFFFFFFFFFF00FF0000FFFFFFFFFF00FF0000FFFFFF0000
000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000FFFF
00FF00FFFFFFFFFFFFFF00FF0000000000FF00FFFFFFFFFFFFFF00FF00FFFF0000FFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFF
FFFFFF00FFFFFFFF00FFFFFF0000FF0000FFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFF00FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF000000
00FFFF0000FF0000FFFFFF00FF000000FF00FFFFFF0000FF0000FFFF00000000FFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
FFFF0000FF00FFFF00FFFFFF0000FF0000FFFFFF00FFFF00FF0000FFFFFFFFFFFFFF00FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFF00FFFFFFFF00FF000000FF00FFFFFFFF00FFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFF00
FFFFFFFFFF00FF00FFFFFFFF0000FF0000FFFFFFFF00FF00FFFFFFFFFF00FFFFFF00FFFF
00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFF00
FFFF00FF00FF00FF00FFFF00FF000000FF00FFFF00FF00FF00FF00FFFF00FFFFFF00FF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FF
FFFFFFFFFFFFFF0000FFFFFFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFF00FFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00
FFFF000000FFFF0000FFFF00FFFF00FFFF00FFFF0000FFFF000000FFFF00FFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF00FFFF00FFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFF00FFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FF00FF00FFFF000000FFFFFF000000FFFF00FF00FF00FFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFFFF0000FFFFFF000000FF0000000000FF000000FFFFFF0000FFFFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF00FF00FFFFFFFFFFFFFF00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FF00FFFF00FFFFFF000000FFFFFFFFFFFFFF000000FFFFFF00FFFF00FFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF00FFFF00FF0000FFFFFFFFFFFFFF0000FF00FFFF00FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFF000000FF00FFFF00FFFF00FF000000FFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFF00FFFFFFFF00FF00FFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFF00FF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFF00FF00FF00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFF000000FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFF00FFFF00FF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.2003 0.588183 1.28761 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1576639413143) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFF00FFFF00FF00FF000000FF0000FF00FFFFFFFFFF00FF00FF0000FF00FF
00000000000000000000FFFF00FFFFFF00FFFF00000000000000000000FF00FF0000FF00
FF00FFFFFFFFFF00FF0000FF000000FF00FF00FFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFF000000FFFFFFFF0000FFFFFF00FF00FFFFFFFFFFFF00
0000000000000000000000FFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
00FF00FFFFFF0000FFFFFFFF000000FFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFF00FF00FF00FF00FFFFFF0000FF00FFFFFF0000FFFFFFFF0000FFFF0000FFFF00
0000000000000000000000FFFFFFFFFFFFFF000000000000000000000000FFFF0000FFFF
0000FFFFFFFF0000FFFFFF00FF0000FFFFFF00FF00FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFF0000FFFFFFFFFFFFFFFF00FFFF000000FFFFFFFF0000
000000000000000000000000FFFF00FFFF0000000000000000000000000000FFFFFFFF00
0000FFFF00FFFFFFFFFFFFFFFF0000FFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFF000000FF00FFFFFFFFFFFFFF00FF0000FFFFFFFF0000
0000000000000000000000FF00FF00FF00FF00000000000000000000000000FFFFFFFF00
00FF00FFFFFFFFFFFFFF00FF000000FFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFF0000FFFF000000FFFFFFFF00FFFFFFFFFFFF0000FFFFFFFF0000
0000000000000000000000FFFFFF00FFFFFF00000000000000000000000000FFFFFFFF00
00FFFFFFFFFFFF00FFFFFFFF000000FFFF0000FFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFF00000000FFFFFF00FF00FFFF0000FFFF0000FF000000
000000000000000000000000FF00FF00FF000000000000000000000000000000FF0000FF
FF0000FFFF00FF00FFFFFF00000000FFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF0000FF0000FFFFFFFF00FF00FFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFF000000000000000000000000000000FFFFFFFF
FFFFFFFF00FF00FFFFFFFF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFFFF00FFFFFF0000FFFFFFFFFFFF00000000
00000000000000FF0000FF0000FFFFFF0000FF0000FF0000000000000000000000FFFFFF
FFFFFF0000FFFFFF00FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF00FF000000FFFFFFFFFFFF00000000
0000000000000000FFFF0000FF00FF00FF0000FFFF000000000000000000000000FFFFFF
FFFFFF000000FF00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF000000FFFFFFFFFFFF00000000
000000FF00000000FFFF00FFFFFFFFFFFFFF00FFFF00000000FF00000000000000FFFFFF
FFFFFF000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFF0000FF00FFFF00FFFF00000000
0000FF00FF00000000FFFFFFFFFF00FFFFFFFFFF00000000FF00FF000000000000FFFF00
FFFF00FF0000FFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF0000FFFFFFFFFFFF00FF000000
00FF00FF00FF0000FF00FF0000FF00FF0000FF00FF0000FF00FF00FF00000000FF00FFFF
FFFFFFFF0000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF000000FF00FFFFFFFFFF000000
00FFFFFFFF0000FF00FF00FFFF00FF00FFFF00FF00FF0000FFFFFFFF00000000FFFFFFFF
FF00FF000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFF000000FFFFFFFF00FFFF000000
00FFFF00FFFFFFFFFF0000FFFF00FF00FFFF0000FFFFFFFFFF00FFFF00000000FFFF00FF
FFFFFF000000FFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00000000FFFFFF00FF00000000
FF00FFFFFF0000FFFF000000FFFFFFFFFF000000FFFF0000FFFFFF00FF00000000FF00FF
FFFF00000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF0000FFFFFFFF00FF000000
FFFFFFFFFF0000FFFFFF00FFFFFFFFFFFFFF00FFFFFF0000FFFFFFFFFF000000FF00FFFF
FFFF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFFFF00FFFFFF000000
00FF00FFFFFF00FF00FFFFFF00FFFFFF00FFFFFF00FF00FFFFFF00FF00000000FFFFFF00
FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF00FF00000000
00FFFFFFFF00FF00FFFFFF00FF00FF00FF00FFFFFF00FF00FFFFFFFF0000000000FF00FF
00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00000000
00FFFFFF00FFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFF00FFFFFF0000000000FFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFF00000000
00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF0000000000FFFFFF
00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00000000
00FFFF0000FFFFFFFF00FF00FFFF00FFFF00FF00FFFFFFFF0000FFFF0000000000FFFF00
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00000000
00FFFF0000FFFF00FFFFFF00FF000000FF00FFFFFF00FFFF0000FFFF0000000000FFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFF00000000
00FFFF000000FFFFFF00FFFFFF000000FFFFFF00FFFFFF000000FFFF0000000000FFFF00
00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00000000
00FFFF0000FF00FF0000FFFFFF000000FFFFFF0000FF00FF0000FFFF0000000000FFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF0000
FF00FFFFFFFFFFFF000000FF0000000000FF000000FFFFFFFFFFFF00FF0000FF0000FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00FF
FFFFFF00FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF00FFFFFFFF00FF00FFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FF00FFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF00FFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFF00FFFF00FFFF00000000000000FFFF00FFFF00FFFF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFF0000FF00FF000000000000000000FF00FF0000FFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FF0000FFFF0000FFFFFF00000000FF00000000FFFFFF0000FFFF0000FFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFF0000FFFFFF000000FF00FF000000FFFFFF0000FFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF0000FF00FFFF0000FF00FF00FF0000FFFF00FF0000FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FF00FF0000FF00FF00FF00FF0000FF00FF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFF000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FF00FF00FFFF00FF00FFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFF0000FF00FF00FF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.2003 0.782187 1.28761 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1577027405228) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFF0000FF000000FFFF00FFFFFF000000000000FF00FF00FF000000FF00FF00FF00
00000000000000000000FF00FF000000FF00FF0000000000000000000000FF00FF00FF00
0000FF00FF00FF000000000000FFFFFF00FFFF000000FF0000FFFFFFFF
FFFFFFFFFF00FFFFFF00FF00FF00FF0000000000000000FFFFFF0000000000FFFFFF0000
0000000000000000000000FFFFFF00FFFFFF00000000000000000000000000FFFFFF0000
000000FFFFFF0000000000000000FF00FF00FF00FFFFFF00FFFFFFFFFF
FFFFFFFF00FF00FF000000FFFFFF00000000000000FF0000FF00000000000000FF0000FF
00FF0000000000FF00FF0000FF000000FF0000FF00FF0000000000FF00FF0000FF000000
00000000FF0000FF00000000000000FFFFFF000000FF00FF00FFFFFFFF
FFFFFFFFFFFFFF0000FF0000FF0000000000000000FFFFFF000000000000000000FFFFFF
00FFFFFF00FFFFFF00FFFFFF0000000000FFFFFF00FFFFFF00FFFFFF00FFFFFF00000000
0000000000FFFFFF0000000000000000FF0000FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF000000000000FF00FF00FF0000000000000000000000FF00
FF00FF000000FF00FF00FF00000000000000FF00FF00FF000000FF00FF00FF0000000000
000000000000FF00FF00FF000000000000FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FF00000000000000FFFFFFFF0000FF00000000000000000000FF
FFFF0000000000FFFFFF000000000000000000FFFFFF0000000000FFFFFF000000000000
00000000FF0000FFFFFFFF00000000000000FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF00000000FF00FF0000FFFFFF0000000000000000FF0000
FF00000000000000FF0000FF0000000000FF0000FF00000000000000FF0000FF00000000
00000000FFFFFF0000FF00FF00000000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00000000FF00FF00FF0000000000FFFFFF
000000000000000000FFFFFF0000000000FFFFFF000000000000000000FFFFFF00000000
00FF00FF00FF00000000FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF000000FF0000FF00FFFFFFFFFFFF00FF00FFFF00FF00
00000000000000000000FF00FF000000FF00FF0000000000000000000000FF00FFFF00FF
00FFFFFFFFFFFF00FF0000FF000000FF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFF00FFFF0000FF00FF00FFFFFFFF0000
0000000000000000000000FFFFFF00FFFFFF00000000000000000000000000FFFFFFFF00
FF00FF0000FFFF00FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFF00000000FFFFFF0000FF0000FF
00FF0000000000FF00FF0000FF000000FF0000FF00FF0000000000FF00FF0000FF0000FF
FFFF00000000FFFFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00000000FFFFFF00FF0000FF00000000FFFFFF
00FFFFFF00FFFFFF00FFFFFF0000000000FFFFFF00FFFFFF00FFFFFF00FFFFFF00000000
FF0000FF00FFFFFF00000000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000FFFF00FFFFFF000000000000FF00
FF00FF000000FF00FF00FF00000000000000FF00FF00FF000000FF00FF00FF0000000000
00FFFFFF00FFFF000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00FF00FF0000000000000000FF
FFFF0000000000FFFFFF000000000000000000FFFFFF0000000000FFFFFF000000000000
0000FF00FF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF000000FFFFFF00000000000000FF0000
FF00000000000000FF0000FF0000000000FF0000FF00000000000000FF0000FF00000000
000000FFFFFF000000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000000000000000FFFFFF
000000000000000000FFFFFF0000000000FFFFFF000000000000000000FFFFFF00000000
00000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF000000000000FF00FF00FF00
00000000000000000000FF00FF000000FF00FF0000000000000000000000FF00FF00FF00
0000000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00000000000000FFFFFFFF0000
FF00000000000000000000FFFFFF00FFFFFF00000000000000000000FF0000FFFFFFFF00
000000000000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF00FF0000FFFF
FF0000000000000000FF0000FF000000FF0000FF0000000000000000FFFFFF0000FF00FF
00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00000000FF
00FF00FF0000000000FFFFFF0000000000FFFFFF0000000000FF00FF00FF00000000FFFF
FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF000000FF0000FF00FFFF
FFFFFFFF00FF00FFFF00FF00000000000000FF00FFFF00FF00FFFFFFFFFFFF00FF0000FF
000000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFF00FFFF
0000FF00FF00FFFFFFFF000000000000000000FFFFFFFF00FF00FF0000FFFF00FFFFFF00
00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFF00
000000FFFFFF0000FF0000FF0000000000FF0000FF0000FFFFFF00000000FFFFFF0000FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00000000FFFFFF
00FF0000FF00000000FFFFFF0000000000FFFFFF00000000FF0000FF00FFFFFF00000000
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000FFFF
00FFFFFF000000000000FF00FF000000FF00FF000000000000FFFFFF00FFFF000000FF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00
FF00FF0000000000000000FFFFFF00FFFFFF0000000000000000FF00FF00FF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF000000FF
FFFF00000000000000FF0000FF000000FF0000FF00000000000000FFFFFF000000FF00FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000
FF0000000000000000FFFFFF0000000000FFFFFF0000000000000000FF0000FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
000000000000FF00FF00FF00000000000000FF00FF00FF000000000000FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
000000000000FFFFFFFFFFFF0000000000FFFFFFFFFFFF00000000000000FF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00000000FF00FF0000FFFF00FF00FF00FFFF0000FF00FF00000000FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFF00000000FFFFFF00FFFFFF00000000FFFFFF00FFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FF000000FF0000FF00FFFFFF000000FFFFFF00FF0000FF000000FF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF0000FFFFFF00FFFF0000000000FFFF00FFFFFF0000FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFF0000FFFFFF00000000000000FFFFFF0000FFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00000000FFFFFF0000000000FFFFFF00000000FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FF000000FFFF0000000000FFFF000000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00FF00FF000000FF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FF000000FFFFFF00FFFFFF000000FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF0000FF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF0000000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FF00000000000000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.2003 0.97619 1.28761 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1587890099396) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFF000000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF0000FF00FF
0000FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFF
0000FFFFFFFFFFFFFF0000FF0000FF0000FF0000FFFFFFFFFFFFFF0000FFFFFF00FF00FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFF00FF00FF0000FF000000FFFFFFFFFF000000FF0000FF00FF00FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000
FFFFFFFF00FFFFFFFF00FFFF0000FF0000FFFF00FFFFFFFF00FFFFFFFF0000FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFF000000FFFF000000FF00FFFFFF00FF000000FFFF000000FFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFF0000FFFF0000FF0000FF000000FFFF
0000FFFFFFFFFF0000000000FFFFFFFFFF0000000000FFFFFFFFFF0000FFFF000000FF00
00FF0000FFFF0000FFFF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF
FFFFFFFFFFFF00000000000000FF00FF00000000000000FFFFFFFFFFFFFFFFFF00FFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF0000FFFFFFFF0000FF00FF0000
FFFF0000FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF0000FFFF0000FF00FF0000
FFFFFFFF0000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
FFFFFFFFFFFFFF00FFFFFFFFFF000000FFFFFFFFFF00FFFFFFFFFFFFFFFF00FF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFFFFFFFFFFFFFF000000FFFF
FFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFF000000FFFF
FFFFFFFFFFFF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF0000FF
00FFFF00FFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFF00FFFF00FF0000FFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFF0000FFFF000000
FFFFFFFF00FFFF00FF0000FFFFFFFFFFFFFF0000FF00FFFF00FFFFFFFF000000FFFF0000
FFFF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00FF00FFFF00FFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FF
FF0000FF00FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF00FF0000FFFF0000FF00FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFF
FFFFFFFF00FFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFF00FFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFF000000FFFF00FFFFFF00FF00FF00FFFFFF00FFFF000000FFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FF0000FFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFF0000FF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00
FFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FF00FFFF00FF00FFFFFFFFFFFFFF00FF00FFFF00FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFF00FFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FFFF00FFFFFF00FFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFF00FFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFF0000FF0000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF0000FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFF00FFFFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.29634 0.200176 1.38365 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1576639373715) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFF00FFFFFFFFFFFFFFFF0000FFFFFF00000000FFFFFF00FF00FFFFFF00FFFFFF
FFFFFFFFFF00FF00FFFF00FF00FFFFFF00FF00FFFF00FF00FFFFFFFFFFFFFFFF00FFFFFF
00FF00FFFFFF00000000FFFFFF0000FFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF000000FF000000FFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF0000
00FF000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFF
FF00FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF00FFFFFFFF00FFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FF00FFFF00000000FFFF000000000000000000FFFF00000000FFFF00FFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFF0000000000FFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00
00FFFFFFFFFF0000FFFFFF0000000000FFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF00FFFF000000FFFF00000000FFFF
FFFFFFFFFF0000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000FFFFFFFFFFFFFF00000000FF
FF000000FFFF00FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFF00FFFF0000FFFF00FFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF00
00FFFF00FFFFFFFFFFFFFF0000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFF00FFFF00FFFFFF00FF
00FFFFFF00FFFF0000FFFF00FFFFFFFFFF00FFFF0000FFFF00FFFFFF00FF00FFFFFF00FF
FF00FFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFF000000FFFFFFFF000000FFFF
FF00FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00FFFFFF000000FFFF
FFFF000000FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFF
FFFF0000FF00FFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF00FF0000FFFFFFFFFF00FFFFFF
FFFFFF00FFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFF00FFFF0000FF00FFFFFFFF
FFFFFF00FFFFFF00FFFFFFFF00FFFFFF00FFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FF00
00FFFF00FFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF0000
0000FFFFFF00FFFFFF000000FFFFFFFFFF000000FFFFFF00FFFFFF00000000FF00FFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFF00FFFFFFFF
FFFFFF0000FFFFFFFF00FFFF00FF00FF00FFFF00FFFFFFFF0000FFFFFFFFFFFFFF00FFFF
FFFF00FFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00000000FFFFFFFFFF
FF0000FFFF00FFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF00FFFF0000FFFFFFFFFFFF0000
0000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFFFFFFFF00FFFF00
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF
FFFFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF00FFFF00FF00FFFFFF
FFFF0000FF0000FF0000FFFFFFFF00FFFFFFFF0000FF0000FF0000FFFFFFFFFF00FF00FF
FF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF000000FFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFF
FFFFFF00FFFFFF00FF000000FFFFFFFFFF000000FF00FFFFFF00FFFFFFFFFFFFFF00FFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFF00FFFF
FF00FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00
FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00000000FF
FFFF00FFFF0000FF00FFFFFF0000FF0000FFFFFF00FF0000FFFF00FFFFFF00000000FFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
00FFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF00FFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF
FF0000FFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFF0000FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000
FFFFFFFF00FFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF0000FFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFF00FFFFFF0000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF0000FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFF0000000000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FF00FF000000FF00FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFF000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFF000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.29634 0.39418 1.38365 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1576639373716) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFF00FF00FFFFFFFFFF00FFFFFF0000FFFFFFFF00000000FFFFFFFFFFFFFFFFFF
00FFFFFF0000FFFFFFFF00FFFFFF00FFFFFF00FFFFFFFF0000FFFFFF00FFFFFFFFFFFFFF
FFFF00000000FFFFFFFF0000FFFFFF00FFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF00FFFFFF00FFFF00FFFF00FFFF00FFFFFFFFFFFFFF00FFFF
FFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFF00FFFFFFFF
FFFFFF00FFFF00FFFF00FFFF00FFFFFF00FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFF00FF0000FFFFFFFFFF00FFFFFF00FFFFFFFFFF00FFFFFF00FF00FFFFFFFF0000
00FFFFFF00FFFFFFFF000000FFFFFFFFFF000000FFFFFFFF00FFFFFF000000FFFFFFFF00
FF00FFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFF0000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFF000000FF00FFFF000000FFFF0000FFFF
FF0000FFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFF0000FFFFFF0000FFFF00
0000FFFF00FF000000FFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF0000FF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FF
0000FF00FFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF00FF0000FF00000000FF00
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF0000FFFF000000FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF000000FFFF0000FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFF000000FFFF0000
FFFFFFFFFF00FFFF000000FFFF00FF00FFFF000000FFFF00FFFFFFFFFF0000FFFF000000
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFF00FFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFF0000FFFFFF00FF000000
FFFFFFFFFFFFFF0000FFFFFFFF00FF00FFFFFFFF0000FFFFFFFFFFFFFF000000FF00FFFF
FF0000FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFF00FFFFFFFF0000FFFFFFFFFF0000FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FF000000FFFF00FFFFFFFFFF
FF00FFFFFFFFFFFF00FFFFFFFF00FF00FFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFF00FF
FF000000FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFF00
FFFFFF00FFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFF00FFFFFF00FFFF00FFFFFF
FFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FF00FFFFFF00FFFFFFFF00FFFF
FFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFF
00FFFFFF00FF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FF00FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF0000FF
FFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF0000FFFFFFFFFFFFFF
0000FF00FF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FF00FF0000FFFFFFFFFFFFFF
0000FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFF000000FF00FF
00FFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFF00FF00FF000000FF
FFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FFFFFFFF
FFFF00FFFF00FF00FFFFFFFFFFFF00FFFFFFFFFFFF00FF00FFFF00FFFFFFFFFFFF00FFFF
FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF00FF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF00FFFF00FFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFF00FFFFFF
FFFFFFFFFF0000FFFFFFFFFF00FFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFF00FFFFFF
FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
00FF000000FFFF00FFFFFF00FFFFFFFFFF00FFFFFF00FFFF000000FF00FFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF00FF
00FFFFFFFFFF00FFFFFFFFFF00FF00FF00FFFFFFFFFF00FFFFFFFFFF00FF00FF00FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFF
FFFF0000FFFFFFFF00FF00FFFFFFFFFFFFFF00FF00FFFFFFFF0000FFFFFFFFFFFF0000FF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFF
00FFFFFFFFFF0000FFFFFF0000FFFFFF0000FFFFFF0000FFFFFFFFFF00FFFF00FFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF
FFFFFF000000FFFF00FFFF00FFFFFFFFFF00FFFF00FFFF000000FFFFFFFFFFFF00FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF
00FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFF00FFFFFF00FFFF0000FFFFFFFFFFFFFF0000FFFF00FFFFFF00FFFFFF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFF0000FFFF0000FFFFFF0000FFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF
FFFFFF00FFFFFFFFFFFF00FFFF000000FFFF00FFFFFFFFFFFF00FFFFFFFF0000FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFF00000000FFFF0000FFFFFFFFFFFFFF0000FFFF00000000FFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFF0000000000FFFFFF00FF00FFFFFF0000000000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF000000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF0000FFFFFFFF00FFFFFF00FFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.29634 0.588183 1.38365 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1576639373717) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFF00FFFFFF0000FF0000FF00FFFFFFFF00FFFF000000FFFFFFFFFFFFFF00FFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFF000000FFFF00FFFFFFFF00FF0000FF0000FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFF0000FFFF00000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF000000FF
00FFFFFFFF00FFFFFFFFFF0000FF00FF0000FFFFFFFFFF00FFFFFFFF00FF000000FFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFF00000000FFFF0000FFFFFFFFFFFFFF
FFFFFFFF00FF00000000FFFFFFFFFFFF00FFFF00FFFFFF00FFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFF000000FFFF00FFFFFFFFFFFFFFFFFF00FFFF000000FFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFF00FFFFFF00FFFF00FFFFFFFFFFFF00000000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF0000FFFFFF00FF00FFFFFFFFFF00FF
FFFFFFFFFF00FFFFFFFFFF00FF00FF00FF00FFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFF
00FF00FFFFFF0000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FF00FF000000FFFFFFFF00FF0000FFFF00FFFF00FF00FFFF
FFFFFF000000FF0000FFFFFFFFFF00FFFFFFFFFF0000FF000000FFFFFFFFFF00FF00FFFF
00FFFF0000FF00FFFFFFFF000000FF00FF00FFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFF0000000000FFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFF
00FF00FFFF00FF00FFFFFF00FFFFFFFFFF00FFFFFF00FF00FFFF00FF00FFFFFFFFFF00FF
FFFFFFFFFFFFFF00FFFF0000000000FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00000000000000FFFFFF00FFFF00FFFFFFFF00FFFFFFFF
FFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF00FFFF
FFFF00FFFF00FFFFFF00000000000000FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFF
FF00FFFFFF00FF00FFFFFF00FFFFFFFFFF00FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFF
FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFF000000FF0000FFFF0000
FFFFFFFFFFFF000000FFFFFF00FF00FF00FFFFFF000000FFFFFFFFFFFF0000FFFF0000FF
000000FFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF00FF
FFFFFFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFF00FF0000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
00FFFFFF00FFFFFF00FF00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF0000FFFFFFFF
0000FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF0000FFFFFFFF0000FF
FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFF00FFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
00FFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFF00FFFF00FFFF00
00FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF00
FFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFF00FFFFFFFF
FFFF00FFFF00FF0000FFFF0000FFFFFF0000FFFF0000FF00FFFF00FFFFFFFFFFFF00FFFF
FFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF00FFFFFFFF00FFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF00FFFFFF
FF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF00FFFFFF00
00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFF00FF00FFFFFF00FFFFFF0000FFFFFF00FF00
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF00FF00
FFFFFFFFFF00FF00FFFFFFFF00FFFFFF00FFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FFFFFF0000FFFFFF
00FF00FF000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF000000FF00FF00FFFFFF0000FFFF
FF00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FF00FFFFFF000000FFFFFF00FF0000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF
00FF00FFFF00FFFF000000FFFFFFFFFFFFFF000000FFFF00FFFF00FF00FFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF0000FFFFFF
FFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFF0000FF00
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF00FFFFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFF00FFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFF00FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000
00FFFFFF00FFFFFF0000FFFFFF00FF00FFFFFF0000FFFFFF00FFFFFF00000000FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFF00FFFF0000FF0000FFFFFFFFFFFFFFFFFF0000FF0000FFFF00FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF0000FFFFFF00FF00FF00FF00FFFFFF0000FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF0000000000FF0000000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF000000FF00FFFF00FF00FFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FF00FF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.29634 0.782187 1.38365 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1576639393428) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF00
FFFFFFFFFF0000FFFFFF0000FF000000FF0000FFFFFF0000FFFFFFFFFF00FFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF0000FFFFFF0000FFFFFF0000FF0000FF0000FFFFFFFFFF00FF00FFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FF00FFFF
FFFFFF0000FF0000FF0000FFFFFF0000FFFFFF0000FF00FFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FF00FF00
FFFFFFFFFF0000FFFF000000FF000000FF000000FFFF0000FFFFFFFFFF00FF00FF00FFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFF000000FFFF0000FFFFFF00FF0000000000FFFFFFFFFF00
FF0000FFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFF0000FF00FFFFFFFFFF00
00000000FF00FFFFFF0000FFFF000000FFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF
FFFF00FF00FFFFFF000000FF00FFFFFF00FF000000FFFFFF00FF00FFFFFF00FFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFF0000000000FF000000FF00FFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFF00
FF000000FF0000000000FFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFF00FF00000000FF
FF00FFFFFFFF00FF000000FF0000000000FF000000FF00FFFFFFFF00FFFF00000000FF00
FFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFFFF0000000000FFFF00FF00FFFFFF00FF
FF0000FFFFFFFFFFFFFFFF00FF000000FF00FFFFFFFFFFFFFFFF0000FFFF00FFFFFF00FF
00FFFF0000000000FFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFF00FFFF00FFFF00FFFFFFFFFF00FFFFFFFFFF00FFFF00FFFF00FFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFF00FFFFFF0000FFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFF0000FFFF00FFFF0000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FF0000FFFFFF00FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFF0000FF00FF00FF
FF00FFFFFF00000000FFFFFFFFFF00FFFFFFFFFF00000000FFFFFF00FFFF00FF00FF0000
FFFFFFFFFFFFFFFF00FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00000000FFFFFFFFFFFF00FF00FF
FFFFFF00FFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFF00FF00FFFFFF
FFFFFF00000000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFF00000000FF00FFFFFF00
FF00FF00FF000000FF00FFFFFF000000FFFFFF00FF000000FF00FF00FF00FFFFFF00FF00
000000FFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFF00
FF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFFFF
FFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF000000FF00FFFFFFFF00
FFFFFFFF0000FFFFFFFFFF00FFFF00FFFF00FFFFFFFFFF0000FFFFFFFF00FFFFFFFF00FF
000000FF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FFFFFF000000FFFF
FFFF0000FFFF00000000FFFFFFFF00FFFFFFFF00000000FFFF0000FFFFFFFF000000FFFF
FF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFF
00FFFFFFFF00FFFF00FFFFFF00FFFFFF00FFFFFF00FFFF00FFFFFFFF00FFFFFFFFFFFFFF
FFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFF00FF
FFFF00FFFF00FF0000FFFFFFFFFFFFFFFFFFFFFF0000FF00FFFF00FFFFFF00FFFFFFFFFF
FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF00FFFFFF00FFFF
FFFFFF00FFFFFFFF00FF00FFFFFFFFFFFFFF00FF00FFFFFFFF00FFFFFFFFFF00FFFFFF00
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFF00
FFFFFFFFFFFFFF00FFFFFF0000FF00FF0000FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FFFF
FF00FF00000000FFFFFFFFFF00FF00FF00FFFFFFFFFF00000000FF00FFFFFF0000FFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFF
FFFF00FF000000FF0000FF0000FFFFFF0000FF0000FF000000FF00FFFFFFFF0000FFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00
00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF0000FFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FF
FF000000FFFFFFFFFFFF00FF0000000000FF00FFFFFFFFFFFF000000FFFF00FFFF00FFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
00FFFFFF0000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFF0000FFFFFF0000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFF000000FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFF000000FFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFF00000000FF00FFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFF00FF000000000000000000FF00FFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFF00FFFFFF00FFFF00FFFF00FFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFF000000FFFFFFFFFF00FFFFFF00FFFFFFFFFF000000FFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF0000FF0000000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.29634 0.97619 1.38365 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1576639393429) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFF00FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF00FFFFFFFF0000FFFFFFFFFF00FFFFFFFFFF00FF0000FF0000FFFF00
FFFFFFFFFFFFFFFFFF0000FFFF00FF00FFFF0000FFFFFFFFFFFFFFFFFF00FFFF0000FF00
00FF00FFFFFFFFFF00FFFFFFFFFF0000FFFFFFFF00FF00FFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFF0000FFFF00FFFFFF00FFFFFF000000FFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF000000FFFFFF00FFFFFF00FFFF0000FFFFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFF0000FF00FFFFFFFF000000FFFFFFFFFFFFFFFF00FFFFFFFF00FFFF00
00FF0000FF0000FF00FFFFFF00FFFFFF00FFFFFF00FF0000FF0000FF0000FFFF00FFFFFF
FF00FFFFFFFFFFFFFFFF000000FFFFFFFF00FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFFFFFFFF
00FFFFFFFFFF00FF00FF0000FFFFFFFFFF0000FF00FF00FFFFFFFFFF00FFFFFFFFFF00FF
00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFF00FFFF00FFFFFF00000000FF00FF00FFFFFFFFFFFFFFFFFF
FF00FFFF00FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFF
FFFF00FF00FF00000000FFFFFF00FFFF00FFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF00FF
00FFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFFFF00FFFFFFFF0000FFFFFF00000000FF
00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FF00000000FFFF
FF0000FFFFFFFF00FFFFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF00FF00FF0000FFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFF0000FF00FF00FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF00FF00FFFFFF00FF00FF
00FFFFFFFF00FF0000FF00FFFFFFFFFFFFFF00FF0000FF00FFFFFFFF00FF00FF00FFFFFF
00FF00FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF0000FFFFFFFFFFFF00FF00FF00FF
FFFF0000FFFFFF00FFFFFF00FFFFFFFFFF00FFFFFF00FFFFFF0000FFFFFF00FF00FF00FF
FFFFFFFFFF0000FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF0000FFFF00FFFFFF00FF00FFFFFFFFFF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFF00FF
00FFFFFF00FFFF0000FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF000000FFFFFF00FFFF00FF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF00FFFF00FFFF
FF000000FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF0000FF00FF00FFFF00FF0000FF0000FF00FFFF00FF00FF0000FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFF00FFFFFF00000000FFFF0000
FFFFFF00FF00FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF00FF00FFFFFF0000FFFF000000
00FFFFFF00FFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFF00
FFFF00FFFFFF00FF00FFFF00FFFFFFFFFF00FFFF00FF00FFFFFF00FFFF00FFFFFFFFFFFF
FFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFFFF0000FFFF00FF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00FFFF0000FF
FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF00FF00FFFFFFFFFF
FFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFF00FF
00FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF00
0000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF000000FFFFFFFFFFFF
00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF000000FF00
FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF00FF000000FFFF
FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF0000FFFF00FFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFF0000
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF00FF
0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FFFFFFFF00
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFF00FFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFF00FF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF
FFFFFFFF000000000000FFFF0000000000FFFF000000000000FFFFFFFFFFFF00FFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFF
FF0000FF00FFFF00FFFF0000FFFF00FFFF0000FFFF00FFFF00FF0000FFFFFFFFFF00FFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FFFFFF00FFFFFF00FFFF00FFFFFF00FFFF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFF000000FFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFF000000FFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF00FFFF0000FF0000FFFF0000FF0000FFFF0000FF0000FFFF00FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFF00FFFF00FF00FF00FFFF00FF00FFFF00FF00FF00FFFF00FFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFF000000FFFF00FFFFFFFFFF00FFFF000000FFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFF00FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFF00FF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.39238 0.200176 1.47969 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1576251381631) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFF00FFFFFF00FF00FFFF00FF00FFFFFF
FF0000FFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFF0000FFFFFFFF00FF00FF
FF00FF00FFFFFF00FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF00FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFF00FF
00FFFF0000FFFFFF0000FF00FF00FF00FF00FF0000FFFFFF0000FFFF00FF00FFFFFFFFFF
FFFFFFFFFF00FFFFFF00FF00FFFFFF00FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFF000000FFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FF000000FFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFF
FFFFFFFFFFFF0000FFFFFF00FF00FF00FF00FFFFFF0000FFFFFFFFFFFFFFFFFFFF0000FF
FF0000FFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFF00FFFFFF00FF00FF00FF00FFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF0000FF0000FF0000FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFF00FF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF0000FF0000FF0000FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF00FFFFFF00FFFFFFFFFF000000FFFF00FF
00FF0000FF0000FF00FFFFFFFF00FF00FFFFFFFF00FF0000FF0000FF00FF00FFFF000000
FFFFFFFFFF00FFFFFF00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFF00FFFF00FFFFFFFFFFFF00FFFFFFFFFF
FFFFFF00FFFFFFFF00FF000000FFFFFF000000FF00FFFFFFFF00FFFFFFFFFFFFFFFF00FF
FFFFFFFFFF00FFFF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF000000FFFF00FFFFFFFFFFFF
FFFFFFFF00FF0000FFFFFF00FFFFFFFFFF00FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFF00
FFFF000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00
00FF0000FFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFF0000FF0000FFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FF00FFFFFFFFFFFFFF
FFFFFFFF0000FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF00
FFFFFF00FFFF000000FFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFFFF00FFFFFFFFFFFF
00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF000000FF0000000000FF0000FF0000
00000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000000000FF0000FF00
00000000FF000000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF00FF00FFFFFF00
FFFF00FFFFFFFFFF00FF00FFFF00FF00FFFF00FF00FFFFFFFFFF00FFFF00FFFFFF00FF00
FFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF00FF0000FF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FF00FFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF000000FF00FFFFFF00FF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF00FF
000000FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF
FFFFFFFFFFFFFFFFFFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFF
FFFF0000FFFF00FFFFFFFFFF0000FF0000FFFFFFFFFF00FFFF0000FFFFFFFFFF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
FFFFFF00FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF00FFFFFFFF00FF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF00FF
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00
FF00FFFFFFFFFF00FFFFFFFF0000000000FFFFFFFF00FFFFFFFFFF00FF00FFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF
FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF00FFFFFF00FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFF000000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFF000000FF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFFFF00FF000000FFFFFFFF00FFFFFF00FFFFFFFF000000FF00FFFFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FFFF000000FF000000FF00FFFF00FFFF00FF000000FF000000FFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFF000000FF0000FF0000FF000000FFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF00FFFFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.39238 0.39418 1.47969 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1576251381632) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF0000FFFFFF00FF00FF0000
FF00FF00FF0000000000000000FF00FF0000000000000000FF00FF00FF0000FF00FF00FF
FFFF0000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF0000FF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF000000FFFF
000000FFFFFF00FFFF00FFFF00FF00FF00FFFF00FFFF00FFFFFF000000FFFF000000FFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFF00FF0000FF00FFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFF00000000FFFFFFFFFFFF00FFFF0000FFFFFFFFFFFFFF00FFFFFF
FF00FFFFFFFFFF0000FFFFFFFF000000FFFFFFFF0000FFFFFFFFFF00FFFFFFFF00FFFFFF
FFFFFFFF0000FFFF00FFFFFFFFFFFF00000000FFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFF00000000FF0000FF0000FFFFFFFF
FFFF0000FF0000FFFF0000FF0000000000FF0000FFFF0000FF0000FFFFFFFFFFFF0000FF
0000FF00000000FFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FF00FF000000000000FFFF00000000FF0000
FF00000000FFFF0000FFFF00000000000000FFFF0000FFFF00000000FF0000FF00000000
FFFF000000000000FF00FF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF00FFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFF00FFFF000000
00FFFF00FFFFFFFF00FF000000000000000000FF00FFFFFFFF00FFFF00000000FFFF00FF
FFFFFF00FFFF00FFFFFFFFFFFFFFFFFF00FFFF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF00FF000000FF0000FFFFFFFF00FF
FF0000FFFFFFFFFFFF0000000000000000000000FFFFFFFFFFFF0000FFFF00FFFFFFFF00
00FF000000FF00FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF00FF00FFFF00000000FF0000FFFF
FFFF00FF0000FF0000FFFF00FFFF00FFFF00FFFF0000FF0000FF00FFFFFFFF0000FF0000
0000FFFF00FF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF0000FFFF00FF00FF00FF000000000000FFFF0000
FF000000FFFF00000000FF00FF000000FF00FF00000000FFFF000000FF0000FFFF000000
000000FF00FF00FF00FFFF0000FFFFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00FFFF00FFFFFFFF00
FF00FFFF0000FFFF00FFFFFF0000000000FFFFFF00FFFF0000FFFF00FF00FFFFFFFF00FF
FF00FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FF0000FFFFFFFF0000FF0000
00FFFFFFFF00FF000000FF00000000000000FF000000FF00FFFFFFFF000000FF0000FFFF
FFFF0000FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF00FF000000FFFF0000FF00000000FFFF
00FF0000FF00FF00FFFF000000000000000000FFFF00FF00FF0000FF00FFFF00000000FF
0000FFFF000000FF00FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF00FFFFFF00FFFF0000
FFFFFF00FF00FF00FF0000000000000000000000FF00FF00FF00FFFFFF0000FFFF00FFFF
FF00FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF00FF0000FFFFFFFF00
FF0000FFFFFF000000FFFF00FFFF00FFFF00FFFF000000FFFFFF0000FF00FFFFFFFF0000
FF00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF000000FF00FF00FF00FFFFFFFFFFFF
00000000FF0000000000FF00FF000000FF00FF0000000000FF00000000FFFFFFFFFFFF00
FF00FF00FF000000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF000000FFFFFFFFFFFFFF
FF00FFFF00000000000000FFFFFF00FFFFFF00000000000000FFFF00FFFFFFFFFFFFFFFF
000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFF0000FF0000FF00
00FFFFFFFF00FFFF00FFFF0000FF00FF0000FFFF00FFFF00FFFFFFFF0000FF0000FF0000
FFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF00000000FFFF0000
0000FF0000FFFFFFFF0000FFFF000000FFFF0000FFFFFFFF0000FF00000000FFFF000000
00FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFF
00FFFFFF00FF0000FF00FFFFFFFF00FFFFFFFF00FF0000FF00FFFFFF00FFFF0000FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00000000FF
00FF0000FFFFFF00FF00FF0000FF00FF0000FF00FF00FFFFFF0000FF00FF00000000FF00
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF000000FFFF00FFFF
FF00000000FF000000FFFFFF00FF00FF00FFFFFF000000FF00000000FFFFFF00FFFF0000
00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000
FF00FFFF00FF00FFFF0000FF00FF00FF00FF0000FFFF00FF00FFFF00FF0000FFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000
00FFFFFFFF000000FF00FFFFFF000000FFFFFF00FF000000FFFFFFFF00000000FF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFFFF00FF
FF0000FF0000000000FFFFFFFFFF00FFFFFFFFFF0000000000FF0000FFFF00FFFFFF00FF
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
00FFFF00000000000000FF0000FF00FF0000FF00000000000000FFFF00FFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FF0000FFFF00FFFF00FFFFFF00FF00FF00FFFFFF00FFFF00FFFF0000FFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF0000
FF00FFFFFFFF0000FFFFFFFFFF000000FFFFFFFFFF0000FFFFFFFF00FF0000FFFFFF00FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF0000FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF0000FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFF0000FF0000FF000000FF0000FF0000FFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFF000000FF00000000FFFF0000000000FFFF00000000FF000000FFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00FFFF0000FFFF00FFFF0000FFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FF00FF00000000FF00FF00000000FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FFFF00000000FFFFFF00FFFF000000FFFF00FFFFFF00000000FFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF0000FF00FF0000000000FF00FF0000FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF000000FFFF00FFFF000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFF00FFFF00FF000000FF00FFFF00FFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF00FF00FF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.39238 0.588183 1.47969 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1576251401343) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFF00FFFFFFFF
FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFF
FFFFFFFFFFFF00FFFF00FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFF0000000000FFFFFFFF000000FF00000000FFFFFFFFFF
FFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFF0000
0000FF000000FFFFFFFF0000000000FFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFF000000FF00FFFF00FFFFFFFFFFFF00FFFFFF00FFFF0000000000
00FF00FFFFFF00FF000000FF0000FF0000FF000000FF00FFFFFF00FF000000000000FFFF
00FFFFFF00FFFFFFFFFFFF00FFFF00FF000000FFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFFFFFFFFFFFF000000FFFFFFFF00FFFF00
FFFFFF000000FFFFFF00FFFFFF00FF00FFFFFF00FFFFFF000000FFFFFF00FFFF00FFFFFF
FF000000FFFFFFFFFFFFFFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF0000FF
FFFFFFFF00FFFFFFFFFF000000FFFFFF000000FFFFFFFFFF00FFFFFFFFFF0000FFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF00FFFFFF000000000000FF000000FFFFFFFFFFFFFFFF00FF
00000000FFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFF00000000FF00FFFFFFFFFF
FFFFFF000000FF000000000000FFFFFF00FFFF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFF00FF00FFFF0000000000000000FFFF
FF00FFFF000000FF000000FFFFFFFFFFFFFF000000FF000000FFFF00FFFFFF0000000000
000000FFFF00FF00FFFF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FFFFFF0000FFFF00FFFF00FFFF0000
00FFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF000000FFFF00FFFF
00FFFF0000FFFFFF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FF000000FF00FFFFFFFF0000FFFFFFFF00
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF00FFFFFFFF0000
FFFFFFFF00FF000000FF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00000000FFFF00000000FF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00000000FFFF
00000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFFFFFF00FFFF00
0000FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF000000FFFF00FFFFFF
FF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FFFFFFFF00000000FFFFFFFF
00FFFFFF00FFFF000000FF000000FF000000FF000000FFFF00FFFFFF00FFFFFFFF000000
00FFFFFFFF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF00FFFFFFFFFF
FF000000FFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF000000FFFFFFFFFFFF00FF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFFFFFFFF
FFFF00FFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFF00
00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00000000FFFFFFFF00FF0000000000
0000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00000000000000FF00
FFFFFFFF00000000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FFFFFF00FFFF00
FFFF0000FF0000000000FFFFFFFFFFFFFFFFFF0000000000FF0000FFFF00FFFF00FFFFFF
00000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFFFF0000FF
FFFFFF00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFF00FF00FFFFFFFF0000FFFFFFFF
FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF000000000000FFFF00
000000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00000000FFFF00000000
0000FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFF
00FFFF000000FFFF000000FF0000FF0000FF000000FFFF000000FFFF00FFFFFFFF00FFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00000000
FFFFFFFF00FFFFFFFF00FFFFFF00FF00FFFFFF00FFFFFFFF00FFFFFFFF00000000FFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF000000FF00FFFF00
FF000000FFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFF000000FF00FFFF00FF0000
00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF
FFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFF0000FFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFF
FFFFFF00000000FF000000FFFFFFFFFFFFFF000000FF00000000FFFFFFFFFF00FF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFFFF0000
000000FFFF00FFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFF00FFFF0000000000FFFFFF00FF
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
00FFFF0000FFFFFFFFFF00000000FF00000000FFFFFFFFFF0000FFFF00FFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FF0000FFFF0000000000FFFF00FFFFFF00FFFF0000000000FFFF0000FFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF
00FF000000FFFF00FFFF0000FFFFFFFFFF0000FFFF00FFFF000000FF00FF00FFFFFF00FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFF0000FFFF0000FF0000FFFF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FF00FFFFFFFF00FF00FFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFFFFFFFF00FFFFFF00000000FFFFFF00000000FFFFFF00FFFFFFFFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFF00FFFFFFFFFF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFF0000FF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FFFF00000000FFFFFFFFFFFF00FF00FFFFFFFFFFFF00000000FFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF000000FF0000FFFFFF0000FF000000FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF00FF00FFFFFFFFFF00FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFF000000FFFFFF000000FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF00FFFFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.39238 0.782187 1.47969 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1576251401344) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FF00FFFFFFFFFF00FFFFFFFF00FFFF00FF00FF
FF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFF00FF00FFFF00
FFFFFFFF00FFFFFFFFFF00FF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF0000FF00FF00FF00000000FFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFF00FF000000FFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFF00000000FF00FF00FF0000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFF00FFFFFF00FF00FF00FF00FFFF00FF00FFFF00FFFFFFFF000000
000000FF0000FFFFFF00FFFFFFFF00FFFFFFFF00FFFFFF0000FF000000000000FFFFFFFF
00FFFF00FF00FFFF00FF00FF00FF00FFFFFF00FFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF0000FFFFFFFFFF00000000FFFF00
FFFF00FF00FFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFF00FF00FFFF00FFFF00000000
FFFFFFFFFF0000FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FFFFFFFFFFFFFF00FFFF00FFFFFFFF
0000FFFFFF00FFFFFFFF0000FFFFFFFFFF0000FFFFFFFF00FFFFFF0000FFFFFFFF00FFFF
00FFFFFFFFFFFFFF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FFFF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF000000FF0000FFFFFFFF0000FF0000
FF00FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF00FF0000FF0000FFFF
FFFF0000FF000000FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF0000FFFF00FF00FFFFFFFF00FFFF00FF00
00FFFFFFFFFF00FFFF000000FFFF00FFFF000000FFFF00FFFFFFFFFF0000FF00FFFF00FF
FFFFFF00FF00FFFF0000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFFFF0000FFFF00FFFFFFFFFF00FFFF0000FFFFFFFF00FF00FFFFFFFFFFFFFF
FFFFFFFF0000FFFF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF0000FF000000000000FF
FFFFFFFFFFFFFFFF00FF0000FFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFF000000000000
FF0000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FF00FFFF00FFFF00
00000000FF0000FF00FFFFFFFFFFFFFFFFFFFFFF00FF0000FF0000000000FFFF00FFFF00
FF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FFFFFF0000FFFFFF0000FFFFFFFF
00FFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFF00FFFFFFFF0000FF
FFFF0000FFFFFF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FF00FFFFFFFFFF
FF0000FFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFF0000FFFFFFFFFFFF00FF
0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFF00FF00FF
FF0000FFFF000000FFFFFFFF0000000000FFFFFFFF000000FFFF0000FFFF00FF00FFFFFF
00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF0000FFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFF0000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF0000FFFF00FFFFFFFF
00000000FF0000FFFF0000FFFFFFFFFFFFFF0000FFFF0000FF00000000FFFFFFFF00FFFF
0000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF0000FFFFFF
00FFFF00FF00FFFFFF0000FFFFFFFFFFFFFF0000FFFFFF00FF00FFFF00FFFFFF0000FFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFF00FFFFFF
00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF00FFFFFF
FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF000000
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF000000FFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FFFF00
FF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FF00FFFF0000FF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFF
00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
000000FFFF000000FF0000FF0000FF0000FF0000FF000000FFFF000000FF00FF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFFFFFFFF
00FFFF0000FFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFF0000FFFF00FFFFFFFFFF00FF
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFF00FF0000FFFFFF0000FFFFFF0000FFFFFF0000FF00FFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00
FF0000FF00FF00FFFFFFFF00FFFFFFFFFF00FFFFFFFF00FF00FF0000FF00FFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF
FFFF00FFFFFFFFFF000000FFFFFFFFFFFFFF000000FFFFFFFFFF00FFFFFF00FFFFFF00FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF00FF00FFFF0000FF0000FFFF00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFF00FFFFFF00FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF00FFFFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.39238 0.97619 1.47969 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1576251401345) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFF0000FF0000FF0000FFFF00FF00FF00FF0000FFFF00FFFFFF00FF00
FFFFFFFFFFFFFFFF0000FF00FF000000FF00FF0000FFFFFFFFFFFFFFFF00FF00FFFFFF00
FFFF0000FF00FF00FF00FFFF0000FF0000FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFF00000000FF00FF00FF00FF00FFFFFFFF0000FF00FF00
FF0000FF0000FF00000000FFFFFF00FFFFFF00000000FF0000FF0000FF00FF00FF0000FF
FFFFFF00FF00FF00FF00FF00000000FFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFF00FFFFFFFF00FFFF000000FFFFFF000000FF0000FFFF000000FF
FFFF00FF00FFFFFF00FFFF0000FF00FF0000FFFF00FFFFFF00FF00FFFFFF000000FFFF00
00FF000000FFFFFF000000FFFF00FFFFFFFF00FFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF000000FF00FFFF0000FF00FFFF00000000FF00FFFF00
00FF00FF00FF0000FFFFFFFF00FF00FF00FFFFFFFF0000FF00FF00FF0000FFFF00FF0000
0000FFFF00FF0000FFFF00FF000000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF000000FF00FFFFFF0000FFFF00FFFFFF0000FF
FF000000FFFFFF00FF0000FF00FF00FF00FF0000FF00FFFFFF000000FFFF0000FFFFFF00
FFFF0000FFFFFF00FF000000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF00FF00FF0000000000FFFFFFFFFF00FF000000FF00000000
FF00FFFF0000FF00FF00FFFFFF000000FFFFFF00FF00FF0000FFFF00FF00000000FF0000
00FF00FFFFFFFFFF0000000000FF00FF00FFFF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFF0000FF0000FFFFFF00FFFFFF00FFFF
000000FF00FFFFFF000000FF0000000000FF000000FFFFFF00FF000000FFFF00FFFFFF00
FFFFFF0000FF0000FFFF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FFFF00000000FF000000FF000000FF
00FFFF000000FF0000000000FFFF00FFFF0000000000FF000000FFFF00FF000000FF0000
00FF00000000FFFF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FF0000FF00FFFF00FF00FFFF0000000000
FFFFFFFF00FFFFFF00FFFF00FF000000FF00FFFF00FFFFFF00FFFFFFFF0000000000FFFF
00FF00FFFF00FF0000FF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF000000FFFFFFFF00FFFF00
FF0000FF00FF0000FFFFFFFF0000000000FFFFFFFF0000FF00FF0000FF00FFFF00FFFFFF
FF000000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FF0000FF00FF0000
00FFFF000000FFFF0000FF00000000000000FF0000FFFF000000FFFF000000FF00FF0000
FF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FFFFFFFF00000000FFFFFF00
FFFFFFFF00FFFFFFFF00FF00FFFF00FFFF00FF00FFFFFFFF00FFFFFFFF00FFFFFF000000
00FFFFFFFF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000000000FF0000
00FF0000FFFFFFFFFFFF000000FF00FF000000FFFFFFFFFFFF0000FF000000FF00000000
0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFF000000
0000FFFF0000FF0000FF00FFFF000000FFFF00FF0000FF0000FFFF0000000000FFFF00FF
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF0000FF000000FFFFFFFF0000FFFF00
FFFF0000FFFF00000000FFFFFFFF00FFFFFFFF00000000FFFF0000FFFF00FFFF0000FFFF
FFFF000000FF0000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF0000FF00000000FF00
FF00000000FF00FFFF00FF0000FF00FF0000FF00FFFF00FF00000000FF00FF00000000FF
0000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFF00FFFF0000
00FFFF00FFFFFF0000FFFFFF00FF00FF00FFFFFF0000FFFFFF00FFFF000000FFFF00FFFF
FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF0000FFFFFFFF00
FFFFFFFF0000FF00FFFFFFFFFF000000FFFFFFFFFF00FF0000FFFFFFFF00FFFFFFFF0000
FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF
0000FF00000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00000000FF0000FFFFFFFFFFFF00
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FF00FF00FFFF00FF0000FF0000FF00FF0000FF0000FF00FFFF00FF00FFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF0000FF0000FF
000000FFFFFFFF00000000FFFF000000FFFF00000000FFFFFFFF000000FF0000FF0000FF
00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF00
00000000FF0000FFFF00FFFFFFFF00FFFFFFFF00FFFF0000FF0000000000FFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FF
FF00FFFF00000000FF00FF0000FF00FF0000FF00FF00000000FFFF00FFFF0000FFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FF00000000
FF00FF000000000000FFFFFF00FF00FF00FFFFFF000000000000FF00FF00000000FF00FF
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
00FFFFFF00FFFF00FFFFFFFFFF000000FFFFFFFFFF00FFFF00FFFFFF000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00
FFFFFFFFFF0000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000FFFFFFFFFF00FFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF
FFFFFFFFFFFF00FF0000FF0000FF00FF0000FF0000FF00FFFFFFFFFFFFFF00FFFFFF00FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF0000FF00FF00FFFFFF00FF00FF00FFFFFF00FF00FF0000FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFF0000FF00FF00FF00FF0000FFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFFFF00FFFF0000FF00FFFFFF000000FFFFFF00FF0000FFFF00FFFFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFF000000FF0000000000FF000000FFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000000000FFFF00FFFF0000000000FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FFFF0000FFFFFF00FFFF00FF000000FF00FFFF00FFFFFF0000FFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF0000FFFFFFFF0000000000FFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFF0000FFFF00FFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFFFFFFFF00FF000000FF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF00FF00FF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.48842 0.200176 1.57573 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1282571631929) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFF00000000FFFFFFFFFF000000FFFFFFFFFFFF00FFFFFFFF0000000000FF
0000FF00FFFF00FF00FFFFFFFFFF00FFFFFFFFFF00FF00FFFF00FF0000FF0000000000FF
FFFFFF00FFFFFFFFFFFF000000FFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF00FFFF00000000000000
FFFF000000FF00FFFFFFFFFFFF000000FFFFFFFFFFFF00FF000000FFFF00000000000000
FFFF00FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FF0000000000FFFFFF0000FF0000000000FF0000FFFFFF0000000000FFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF00FF00FF0000FFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFF00000000000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF0000FFFFFFFFFFFFFF0000FF00FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF00FF00FFFFFFFF00FFFFFF00FF00FF0000FFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF
00FFFFFF00FFFFFFFF00FF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF00FFFFFFFFFF00FF00FFFFFFFF00FFFF0000
FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF0000FFFF00FFFF
FFFF00FF00FFFFFFFFFF00FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF000000FFFF0000FFFFFF00FFFF000000FFFFFF
FFFF000000FFFF0000FFFFFFFFFF00FFFFFFFFFF0000FFFF000000FFFFFFFFFF000000FF
FF00FFFFFF0000FFFF000000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFF00FF0000000000FF00FFFFFFFFFF00FFFFFFFFFF00FF
FF0000000000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFF0000000000FFFF00FFFFFFFFFF
00FFFFFFFFFF00FF0000000000FF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFF00FFFFFFFFFF00
FFFFFFFFFFFFFFFFFF0000FF0000000000FF0000FFFFFFFFFFFFFFFFFF00FFFFFFFFFF00
FFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFF
00FFFFFFFFFFFF0000FFFF00000000000000FFFF0000FFFFFFFFFFFF00FFFFFFFFFFFFFF
FF0000FF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF00FF0000FF0000FF
FFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFF0000FF0000FF
00FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00000000FFFFFF000000FFFF00000000
FF0000FF0000FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFF0000FF0000FF00000000FFFF00
0000FFFFFF00000000FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFF0000000000
00FFFF00000000FF00FFFF00FFFF00FFFF00FFFF00FF00000000FFFF000000000000FFFF
FFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000FFFFFFFF00FFFFFF00FFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF0000FFFF0000FF00FF00FF00
FF00FFFF00FFFF00FFFFFFFF00FFFFFF00FFFFFFFF00FFFF00FFFF00FF00FF00FF00FF00
00FFFF0000FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF000000FF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF000000FFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFF00FFFF0000FFFFFFFFFFFFFF0000FFFF00FFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF0000FFFFFFFFFFFF
FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFF00
00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF00FF00
FFFFFFFF00FFFFFF00FF00FF0000FF0000FF00FF00FFFFFF00FFFFFFFF00FF00FF00FFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF00FF
FFFFFFFF00FF00FFFFFFFF00FFFF00FFFF00FFFFFFFF00FF00FFFFFFFFFF00FFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF000000
FFFF0000FFFFFF00FFFF000000FFFFFF000000FFFF00FFFFFF0000FFFF000000FFFF00FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00000000
00FF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FF0000000000FF00FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
0000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFF0000FF0000FFFFFFFFFFFF00FFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFF00FFFF00FF0000FF000000FF0000FF00FFFF00FFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00000000FFFFFF000000FFFF0000000000FFFF000000FFFFFF00000000FF00FF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FFFFFFFFFF00000000000000FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFF0000FFFFFFFFFFFF00FFFFFFFFFFFF0000FFFFFF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFF00FF0000FFFF0000FF00FF000000FF00FF0000FFFF0000FF00FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFF0000000000FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF00FF0000FFFFFFFFFFFFFFFFFF0000FF00FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFF00FF00FF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFF000000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF00FF0000000000FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.48842 0.39418 1.57573 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1576251361917) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFF00FF0000FF0000FFFF00FFFFFFFF00FFFF000000FFFFFF0000FF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFFFF00
0000FFFF00FFFFFFFF00FFFF0000FF0000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFFFFFF00000000FFFFFFFF00FFFFFFFFFF00FF
000000000000000000FFFF000000FF000000FFFF000000000000000000FF00FFFFFFFFFF
00FFFFFFFF00000000FFFFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFF000000FFFFFF00000000FFFF00FFFFFFFFFFFF0000FF0000FFFF
FF00FFFF00FFFF00FFFFFFFF00FFFFFF00FFFFFFFF00FFFF00FFFF00FFFFFF0000FF0000
FFFFFFFFFFFF00FFFF00000000FFFFFF000000FFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFF0000FFFFFFFFFFFFFFFF00FF00FFFFFF
FFFF0000FFFFFFFF00000000FFFFFFFFFF00000000FFFFFFFF0000FFFFFFFFFF00FF00FF
FFFFFFFFFFFFFF0000FFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFF00FF000000FF000000FFFFFF0000FF
0000FFFF00000000FFFF00FFFFFFFFFFFFFF00FFFF00000000FFFF0000FF0000FFFFFF00
0000FF000000FF00FFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF00FFFFFF00FFFF0000FFFFFF00FFFFFF00FFFFFFFFFF00FF
00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FF00FFFFFFFFFF
00FFFFFF00FFFFFF0000FFFF00FFFFFF00FFFF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF0000FFFFFFFFFF0000FF0000FFFF
FF00000000FFFFFFFF00FF000000FF000000FF00FFFFFFFF00000000FFFFFF0000FF0000
FFFFFFFFFF0000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF00FFFFFF
FFFF00FFFF00000000FFFFFF00FFFFFF00FFFFFF00000000FFFF00FFFFFFFFFF00FF00FF
FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFF000000FF000000FFFFFF000000
0000FFFFFFFF00FFFF000000FFFFFFFFFF000000FFFF00FFFFFFFF0000000000FFFFFF00
0000FF000000FFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFF00FF
FF00FF000000FFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF000000FF00FFFF00FFFFFFFFFF
00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF00
00FFFFFF00FFFFFFFFFFFF000000FF000000FFFFFFFFFFFF00FFFFFF0000FFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
00FF0000FFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000000000
FFFFFF00FF000000FF000000FFFFFFFFFF000000FF000000FF00FFFFFF000000000000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFF
000000FFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFF000000FFFF00FFFF00FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00000000000000FFFFFF0000FFFFFF
FF00FFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF00FFFFFFFF0000FFFF
FF00000000000000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF000000FFFF000000
00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00000000FFFF0000
00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFF00FF
FF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFF00FFFFFFFF00
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF0000FFFFFFFFFFFF00
00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF0000FFFFFFFFFFFF
0000FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF0000FF
FF0000FFFFFFFF00000000FF0000FF0000FF00000000FFFFFFFF0000FFFF0000FF0000FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFF
FFFF00FF000000FFFF00FFFFFF00FF00FFFFFF00FFFF000000FF00FFFFFFFF00FF00FFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF000000FFFFFF0000
0000FFFFFF00FFFFFFFF000000FFFFFF000000FFFFFFFF00FFFFFF00000000FFFFFF0000
00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00
FFFF000000FFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFF000000FFFF00FFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF
FFFFFF00FFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFF00FFFFFFFF0000FF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFFFF00FF
FF0000FFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF00FF
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFF0000FF000000000000FFFFFF000000000000FF0000FFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFF00FFFFFF00FFFF00FFFFFFFFFF00FFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF
00FFFFFFFF000000FFFFFFFF0000FF0000FFFFFFFF000000FFFFFFFF00FF00FFFFFF00FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFF00FF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000000000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FFFF00000000000000FFFFFF00FF00FFFFFF00000000000000FFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF00FFFF000000FFFFFF000000FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFF00FFFFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFF000000FFFFFF000000FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF00FFFFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.48842 0.588183 1.57573 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1576251361918) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF00FF00FFFFFFFF00FF
FF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FFFF00FFFFFFFF00
FF00FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF0000FF0000FF00FFFF00FFFFFFFFFFFFFFFF0000FFFFFF
00FFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFF00FFFFFF0000FFFF
FFFFFFFFFFFF00FFFF00FF0000FF0000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFF0000FFFFFFFFFFFFFFFFFFFF00FFFFFF
FF0000FFFFFFFFFF0000FF0000FFFFFF0000FF0000FFFFFFFFFF0000FFFFFFFF00FFFFFF
FFFFFFFFFFFFFF0000FFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF0000FFFF0000FF0000FFFFFFFFFFFF000000
FF00FFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFF00FF000000FFFFFFFF
FFFF0000FF0000FFFF0000FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FF
FFFF00FFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFF00FFFFFF00FFFFFFFFFF
FFFFFFFFFF00FFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF00FFFFFFFFFF00FF0000FF00FFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFF00FF0000FF00FFFFFFFFFF00FFFF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF00FF00FFFFFF00FF0000FFFF0000FF
FFFFFFFFFFFFFF0000FF00FF00FFFFFF00FF00FF0000FFFFFFFFFFFFFFFF0000FFFF0000
FF00FFFFFF00FF00FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF0000FFFFFF000000FFFFFFFFFFFFFFFFFF
000000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF000000FFFFFFFFFFFFFF
FFFF000000FFFFFF0000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFF00FFFF00FFFF00FF00000000FFFFFFFF
FF00FFFFFFFFFF00FF0000000000FF0000000000FF00FFFFFFFFFF00FFFFFFFFFF000000
00FF00FFFF00FFFF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF00FFFF00FFFFFF00
00FFFFFFFFFFFF00FF00FFFF00FFFFFF00FFFF00FF00FFFFFFFFFFFF0000FFFFFF00FFFF
00FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFF000000FF
FF0000FF000000FFFFFF0000FFFFFFFFFF0000FFFFFF000000FF0000FFFF000000FFFFFF
FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFF00FFFF
FFFF00FFFFFFFFFF00FF00FFFFFFFFFFFFFF00FF00FFFFFFFFFF00FFFFFFFF00FFFFFFFF
FFFF00FFFF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFF00
00FF00FFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFF
FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF000000FF0000000000FFFFFFFFFF0000000000FF000000FFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF0000000000000000FFFFFF000000FF
FFFFFFFF00FFFFFF00FFFF00FF000000FF00FFFF00FFFFFF00FFFFFFFFFF000000FFFFFF
0000000000000000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFF00FFFF00
00FF0000FFFFFFFFFF0000FFFFFF00FFFFFF0000FFFFFFFFFF0000FF0000FFFF00FFFFFF
00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF000000FFFFFFFF
00FF00FFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFF00FF00FFFFFFFF000000
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFF00FF0000FF00FFFFFFFFFFFFFFFFFFFFFF00FF0000FF00FFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF0000FFFFFFFFFFFF0000000000FF0000000000FFFFFFFFFFFF0000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF00
FFFFFFFF00000000FF00FFFF00FFFFFF00FFFF00FF00000000FFFFFFFF00FF000000FF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFF00FFFFFF
00000000FFFF00FFFFFF0000FFFFFFFFFF0000FFFFFF00FFFF00000000FFFFFF00FFFFFF
00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000
FFFF00FFFFFFFF0000FF00FFFFFFFFFFFFFF00FF0000FFFFFFFF00FFFF0000FF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF
FFFFFF00FF00FFFFFFFF00FF0000FF0000FF00FFFFFFFF00FF00FFFFFFFF00FF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFFFFFFFF
00FFFFFFFFFF00000000FFFFFF00FF00FFFFFF00000000FFFFFFFFFF00FFFFFFFFFF00FF
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFF00FFFF0000FF00FF00FF0000FFFF00FFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00
FF000000FF0000FFFFFFFF00FF00FF00FF00FFFFFFFF0000FF000000FF00FFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF
FFFF00FFFFFFFFFF0000FFFFFF00FF00FFFFFF0000FFFFFFFFFF00FFFFFF00FFFFFF00FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFF00FFFFFFFF00FF00FFFFFFFF00FFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFF00FF000000FFFFFF000000FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFFFFFFFF000000FFFFFF00FFFFFFFFFF00FFFFFF000000FFFFFFFFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF00FF0000FFFFFFFFFFFFFF0000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FFFF000000000000FFFFFFFFFFFFFFFFFFFFFF000000000000FFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF00FFFFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.48842 0.782187 1.57573 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1576251361919) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFF0000FF00FF00FF0000FFFFFF00FF0000FFFFFFFFFFFFFFFFFFFF
00FFFFFF0000FF00FFFFFFFF00FF00FF00FFFFFFFF00FF0000FFFFFF00FFFFFFFFFFFFFF
FFFFFF0000FF00FFFFFF0000FF00FF00FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFF00000000FF000000FFFF0000FF0000FF0000FF00
0000FF00000000FFFFFFFFFFFF000000FFFFFFFFFFFF00000000FF000000FF0000FF0000
FF0000FFFF000000FF00000000FFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFF00FFFF0000FF00FFFF00FF00FFFF0000FFFF00000000FFFF0000
000000FFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFF0000000000FFFF000000
00FFFF0000FFFF00FF00FFFF00FF0000FFFF00FFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFF000000FF00FF00FF00000000FF00FFFF00FF000000
00000000FF00FF0000FF0000FF000000FF0000FF0000FF00FF00000000000000FF00FFFF
00FF00000000FF00FF00FF000000FFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000FFFFFF000000000000FFFFFFFF00000000
0000000000FFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFF000000000000000000FFFFFF
FF000000000000FFFFFF0000000000FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF00FF00FFFF00FFFFFFFFFF00FFFF00FFFFFFFFFFFF00FFFF
00FFFF00FFFFFFFFFF000000FF000000FF000000FFFFFFFFFF00FFFF00FFFF00FFFFFFFF
FFFF00FFFF00FFFFFFFFFF00FFFF00FF00FFFF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF0000FF000000FF00FF0000FF0000FFFFFF
FF0000FFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFF0000FFFFFFFF0000FF00
00FF00FF000000FF0000FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00000000FFFF00FF00FF00FFFFFF00FF0000
FF00FFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFF00FF0000FF00FFFFFF
00FF00FF00FFFF00000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF0000FFFF00FFFFFFFF000000FFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FF000000FFFFFFFF00FFFF0000FFFFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FFFF00FF0000FF00000000
0000FF0000FF0000FF0000FF00FF00FF00FF0000FF0000FF0000FF000000000000FF0000
FF00FFFF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FF00FF00FFFFFF00FFFF
00FFFFFF00FF00FFFFFF00FF00FF00FF00FF00FFFFFF00FF00FFFFFF00FFFF00FFFFFF00
FF00FF00000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF0000FFFF00FFFFFF000000FF000000FF
00FF0000FFFFFF0000FF00FF00FF00FF00FF00FF0000FFFFFF0000FF00FF000000FF0000
00FFFFFF00FFFF0000FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FF0000000000FFFF00FF
00FF00FFFFFFFFFF00FF00FF00FF00FF00FF00FF00FFFFFFFFFF00FF00FF00FFFF000000
0000FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF00FFFF0000FFFF
FF000000FF0000FF00FF00FF00FF00FF00FF00FF00FF0000FF000000FFFFFF0000FFFF00
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00000000000000FF00FF00000000FF
0000000000FFFF000000FFFFFF000000FFFFFF000000FFFF0000000000FF00000000FF00
FF00000000000000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF000000FFFF00FFFF
FF00FFFF00FF0000000000FF0000000000FF0000000000FF00FFFF00FFFFFF00FFFF0000
00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFF0000
FF00FF000000FFFF00FFFF00000000000000FFFF00FFFF000000FF00FF0000FFFFFFFF00
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FF0000FF00FF
FFFF0000000000FF00FF000000000000000000FF00FF0000000000FFFFFF00FF0000FF00
FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF000000
FF00000000000000FFFFFF00FFFF00FFFF00FFFFFF00000000000000FF000000FFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF00FFFF
000000000000000000FF000000FF00FF000000FF000000000000000000FFFF00FF000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFF00FF00FF00
00000000000000000000FFFF00FF00FF00FFFF0000000000000000000000FF00FF00FFFF
00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000
0000000000000000000000FF00FF00FF00FF00000000000000000000000000FFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFF
00FFFF00FFFF00FFFF00FFFFFF000000FFFFFF00FFFF00FFFF00FFFF00FFFF0000FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FF00FFFFFF
FF0000FFFFFFFF0000FFFFFFFFFF00FFFFFFFFFF0000FFFFFFFF0000FFFFFFFF00FF00FF
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00
00FFFF0000FF00000000FF0000FF00FF0000FF00000000FF0000FFFF0000FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
00FF00000000FFFF00FFFFFF00FF00FF00FFFFFF00FFFF00000000FF00FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF0000
FFFFFF00FFFF0000FFFFFFFFFF000000FFFFFFFFFF0000FFFF00FFFFFF0000FFFFFF00FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFF00FF0000FF0000000000FF0000FF00FFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFF00000000FFFF00FFFF00000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFF0000FF0000FF00FFFF00FF000000FF00FFFF00FF0000FF0000FFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00FFFFFF0000FFFFFF00FFFFFF0000FFFFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FF00000000FF000000FF00000000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FFFF0000000000FFFF00FFFFFF00FFFFFF00FFFF0000000000FFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF00FF000000FF000000FF000000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFF00FFFFFF00FFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFFFF000000FF000000FF000000FFFFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF00FF00FF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.48842 0.97619 1.57573 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1576251381630) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF00FF0000FFFFFFFF00000000FFFFFF00FFFFFF
FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFF00FFFFFF
00000000FFFFFFFF0000FF00FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFF0000FF00FFFFFFFFFFFFFFFF00FFFF000000FFFFFFFF
FFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF000000
FFFF00FFFFFFFFFFFFFFFF00FF0000FFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFF000000FF00FFFFFF00FF0000FF000000FFFFFFFF00FFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF00FF
FFFFFF000000FF0000FF00FFFFFF00FF000000FFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF000000FFFFFFFFFF00FFFF00000000FFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00
000000FFFF00FFFFFFFFFF000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFF000000FF00FFFFFFFF00FFFF000000000000
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000000000FF
FF00FFFFFFFF00FF000000FFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF00FFFFFF00FFFFFFFFFFFF00000000FFFFFFFF00FFFF00FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF00FFFF
FFFF00000000FFFFFFFFFFFF00FFFFFF00FFFF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF0000FFFF00FFFF00FF000000FFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF0000
00FF00FFFF00FFFF0000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00
FFFFFF0000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FF000000FF00FFFFFFFFFF000000FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000FF
FFFFFFFF00FF000000FF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000000000FFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00
00000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFF0000FFFFFF00
000000FF000000000000FF000000FF000000FF000000000000FF00000000FFFFFF0000FF
FF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FFFFFFFF0000FFFF000000FF
FF00FFFFFF00FFFF00FFFFFF00FFFFFF00FFFFFF00FFFF00FFFFFF00FFFF000000FFFF00
00FFFFFFFF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFF00FFFF
FFFF000000FFFFFFFF000000FFFFFFFFFF000000FFFFFFFF000000FFFFFFFF00FFFFFFFF
00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00000000FFFFFF
FFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFF00000000
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00000000FFFFFFFFFF00FFFF000000
000000FFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFF000000000000FFFF00FF
FFFFFFFF00000000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF00FFFFFFFF00FF
FF00FFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFF00
FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00000000FFFF
FFFF000000000000FF000000FFFFFFFFFF000000FF000000000000FFFFFFFF00000000FF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF000000FFFF00FFFFFF
FFFFFF00FFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFF00FFFFFFFFFFFF00FFFF00
0000FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF000000
000000FFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFF000000000000FFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FF
FF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFF00FFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF000000FF0000FFFF
FFFF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FFFFFFFF0000FF0000
00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00
00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF0000FF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFF
FFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF00FF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFFFF00FF
0000FFFFFF00FF000000FF000000FF000000FF000000FF00FFFFFF0000FF00FFFFFF00FF
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFF0000FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF0000FFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFF00FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF00FFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF
00FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF00FF00FFFFFF00FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FF000000FFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FF0000FF0000FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FFFF00000000FFFF00FFFFFF00FF00FFFFFF00FFFF00000000FFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF00FFFFFF0000FFFFFF0000FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFF00FFFFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFF000000FFFFFF000000FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF00FFFFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.58446 0.200176 1.67177 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1282183639843) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFF0000000000000000000000FF0000FF000000FFFFFF0000000000FF
00FFFFFFFFFFFF00FFFFFF00000000000000FFFFFF00FFFFFFFFFFFF00FF0000000000FF
FFFF000000FF0000FF0000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFF
00FFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF00FFFFFFFFFFFFFF
00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF00FFFFFFFFFFFFFF
00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFFFFFFFF
00FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFF0000FFFFFF0000
FFFFFFFF00FF00FFFFFFFFFF00FF00FF00FFFFFFFFFF00FF00FFFFFFFF0000FFFFFF0000
FFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFF00FF000000000000FFFFFFFF00FFFFFF
FF0000FFFFFFFF00FFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFF0000FFFFFFFF00FFFFFF
FF000000000000FF00FFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF0000FFFFFF00FFFFFF000000FFFFFF00FFFFFF0000FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FF00000000FF00FFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF00
FF00000000FF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FF00FFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFF00000000FFFFFFFFFF0000000000FFFFFFFFFF00000000FFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFF00FF00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF00000000000000FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
00000000000000FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000FF0000FF000000FF0000FF0000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000000000FFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00
00000000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000FF0000FF
0000FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFF0000FF0000FF000000
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFF0000000000FF0000FF00FF0000FF0000000000FFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFF0000FFFF0000FFFFFF
FFFF0000FFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFF
0000FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFF00FF0000
00FF00FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF00FF000000FF00FFFFFF
FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFF
FFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFF000000
00FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FF
0000FFFFFFFFFFFF00FFFF00000000000000FFFF00FFFFFFFFFFFF0000FF0000FFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FF00FFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FF000000
00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF0000
00000000FFFFFFFFFFFF0000FF000000FF0000FFFFFFFFFFFF000000000000FFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FFFFFF
FFFFFFFFFF00FFFF00FF00FFFFFFFFFFFFFF00FF00FFFF00FFFFFFFFFFFFFFFF0000FF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000
0000FF0000FFFFFFFFFFFF00000000000000FFFFFFFFFFFF0000FF00000000FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFF
FFFFFFFF00FF00FF0000FFFFFFFFFFFFFFFFFF0000FF00FF00FFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00000000FFFFFFFFFF00FF00000000000000FF00FFFFFFFFFF00000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
00FFFF0000FF000000FF00FFFFFFFFFFFFFF00FF000000FF0000FFFF0000FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFF00FFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFF000000FF0000FFFFFFFFFFFFFFFFFF0000FF000000FFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF00FF00000000000000FF00FFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF0000000000FFFFFFFFFFFFFFFFFFFFFF0000000000FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFF0000FF000000FF0000FFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FF00FFFFFFFFFFFFFF00FF000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000000000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFF00FFFFFFFFFF00FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFF000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.58446 0.39418 1.67177 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1282183639844) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFF00FF00FFFFFFFF000000FFFFFFFFFFFF0000FFFF0000FFFF0000FF
FF00FF00FFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFF00FF00FFFF0000FFFF0000
FFFF0000FFFFFFFFFFFF000000FFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFF00
FF00FFFFFF0000FFFFFFFF00FF00FF00FF00FFFFFFFF0000FFFFFF00FF00FFFF00FFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFF00FF00
FFFFFFFFFFFFFFFF00FF000000FFFFFF000000FF00FFFFFFFFFFFFFFFF00FF00FFFFFFFF
FFFF000000FF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFF00FF00
FF0000FFFFFFFFFFFF00FFFF00FF00FF00FFFF00FFFFFFFFFFFF0000FF00FF00FFFFFFFF
FFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF0000FFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF0000
00FFFF00FFFFFF00FF00FFFFFF000000FFFFFF00FF00FFFFFF00FFFF000000FFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFF00FFFF0000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFF0000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF000000
0000FFFFFF00FFFFFF00FFFF0000000000FFFF00FFFFFF00FFFFFF0000000000FFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFF0000FFFF0000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF0000FFFF00FFFF00FFFFFFFF
FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFF
00FFFF0000FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFFFFFF
FF00FFFFFF000000FF00FFFFFFFFFFFFFFFFFF00FF000000FFFFFF00FFFFFFFFFFFF0000
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FFFF0000
FF00FFFF00FFFF00FFFFFF0000FFFFFF0000FFFFFF00FFFF00FFFF00FF0000FFFF000000
00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFF00
FF00FF000000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF000000FF00FF00FFFFFFFFFFFF
FFFFFFFF00FFFF00FFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF00
FFFFFFFF00FFFFFFFFFF0000FF000000FF0000FFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF00000000FF00FF00FF0000FF
FFFFFFFF00FFFFFFFF00FFFF0000000000FFFF00FFFFFFFF00FFFFFFFFFF0000FF00FF00
FF00000000FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF
0000FFFF00FFFF00FFFFFF00000000000000FFFFFF00FFFF00FFFF0000FFFFFFFF00FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFF0000FF00FF0000FFFF00
00FF000000FFFFFFFF0000FF0000FF0000FF0000FFFFFFFF000000FF0000FFFF0000FF00
FF0000FFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF00FF00FF00FFFFFFFF
00FF00FFFF0000FFFF00FFFFFF00FF00FFFFFF00FFFF0000FFFF00FF00FFFFFFFF00FF00
FF00FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF00FFFFFF00FF0000
FFFFFFFF00000000FF00FF00FF00FF00FF00FF00FF00000000FFFFFFFF0000FF00FFFFFF
00FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF0000FFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FF0000FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FF
FF0000FFFFFFFFFFFFFF00FFFF00FF00FFFF00FFFFFFFFFFFFFF0000FFFF00FFFFFF00FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF000000
FFFFFFFF00FF0000FFFF00FFFFFF00FFFFFF00FFFF0000FF00FFFFFFFF000000FFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FF00FFFFFFFF
FFFFFF00FFFFFFFFFF00FFFFFF000000FFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFF00FF00
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF0000FF00
00FFFF00FF00FFFFFFFF00FF0000000000FF00FFFFFFFF00FF00FFFF0000FF0000FFFFFF
00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00FF00
FFFFFFFF000000FF00FF00FFFFFFFFFFFFFF00FF00FF000000FFFFFFFF00FF00FFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF00FFFFFF
00FF0000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FFFF0000FF00FFFFFF00FF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FFFFFFFFFF000000FFFFFFFFFF00FF00FFFFFFFFFF000000FFFFFFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FFFFFFFFFFFFFFFFFF0000FFFF00FF00FFFF0000FFFFFFFFFFFFFFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FF
FFFFFF00FF0000FF00000000FF00FF00FF00000000FF0000FF00FFFFFFFF00FFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFFFFFFFFFF00FF00FFFF00FF00FF00FF00FFFF00FF00FFFFFFFFFFFFFF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FF0000FF0000FFFFFFFF000000FFFFFF000000FFFFFFFF0000FF0000FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFF00000000FFFF00FFFF00FF00FF00FFFF00FFFF00000000FFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000FF00FFFFFF000000FFFFFF00FF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF0000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF0000FFFFFFFF00FF0000FF0000FF00FFFFFFFF0000FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FF0000FFFFFF00FF00FFFFFF0000FF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000FFFF00FF00FFFFFF00FF00FFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF000000FFFF00FFFF000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFF00FF000000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.58446 0.588183 1.67177 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1282183659555) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFF0000FF00FFFFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFF000000FF00FFFFFF00FF000000FFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF000000FF00FFFFFFFF00FF0000FFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFF00000000FF00FFFFFFFFFFFFFFFFFFFF00FF
FF00000000FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00000000FFFF00FFFFFFFFFF
FFFFFFFFFF00FF00000000FFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFF00FFFF00FF0000FFFFFFFFFFFFFFFFFFFFFF00FF0000FF0000FF0000FF00FF
FF00FFFF00FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF00FFFF00FFFF00FF0000FF00
00FF0000FF00FFFFFFFFFFFFFFFFFFFFFF0000FF00FFFF00FFFFFFFFFF
FFFFFFFFFFFFFF00FF00FF0000FFFF0000FFFFFFFFFFFF00FFFFFFFF0000FFFFFFFF00FF
FF00FFFFFF000000FFFFFFFF0000FF0000FFFFFFFF000000FFFFFF00FFFF00FFFFFFFF00
00FFFFFFFF00FFFFFFFFFFFF0000FFFF0000FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFF0000FF0000FF000000FFFFFF000000FF0000FF0000FFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFF0000FFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFF00FFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF0000FFFFFF000000FF00FFFFFF00FF000000FFFFFF0000FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFF0000FFFFFF00FFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF00FFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFF
FF00FF00FFFFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFF
FFFF00FFFFFFFF00FFFF00FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FF0000FFFFFFFF0000FF00FFFF00000000000000FF
00FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF00FF000000000000
00FFFF00FF0000FFFFFFFF0000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFF0000FF00FF00FFFFFFFFFFFFFFFFFF
0000FF00FFFFFFFF00FFFF0000FF00FF0000FFFF00FFFFFFFF00FF0000FFFFFFFFFFFFFF
FFFF00FF00FF0000FFFF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFF0000FFFF0000FFFFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFFFF0000FFFF00FF00FF00FFFFFFFF
FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFFFF00FF00
FF00FFFF0000FFFFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF00FF0000FFFFFF00000000FF
00FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF00FF00000000FFFF
FF0000FF00FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
000000FF00FFFFFF000000FFFF000000FFFF000000FFFFFF00FF000000FFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FF00FF00FF0000FF0000FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFFFF0000FF00FFFFFFFF
FFFFFFFFFFFF0000FFFFFF0000FFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFF00FF00
00FFFFFF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFF00000000FF
00FFFFFFFFFFFF00FF00FF00FFFFFFFFFF00FF00FF00FFFFFFFFFFFF00FF00000000FFFF
FFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFFFFFFFFFFFFFFFFFF
00FF0000FFFFFFFF00FF00FFFFFFFFFFFFFF00FF00FFFFFFFF0000FF00FFFFFFFFFFFFFF
FFFFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFF
FF00FF000000FF00FFFFFF00FF000000FF00FFFFFF00FF000000FF00FFFFFFFFFFFFFFFF
FFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FF00FF
00FFFFFFFFFFFF00FF00FF00FFFFFFFFFF00FF00FF00FFFFFFFFFFFF00FF00FF00FFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF0000000000FFFFFF
00FF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FF00FFFFFF00000000
00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FF00FFFFFF
FFFF000000FFFF0000FFFFFF00FF00FF00FFFFFF0000FFFF000000FFFFFFFFFF00FF0000
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF0000FF
FFFFFFFFFFFF00FFFF00FF0000FFFFFF0000FF00FFFF00FFFFFFFFFFFFFF0000FFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FF00FF00
FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FF00FF00FFFF
00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF
00FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF00FFFFFFFF00FF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00
00FFFF00FFFFFFFF0000FFFFFF000000FFFFFF0000FFFFFFFF00FFFF0000FFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF0000
FFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFF0000FF00FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
000000FFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFF000000FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
00FF0000000000FF0000FFFFFFFF00FFFFFFFF0000FF0000000000FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF0000FFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF0000FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFF00FF00000000FFFF00FF00FFFF00000000FF00FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFF00FFFF00FFFFFFFFFF00FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF00FF0000FFFFFFFFFF0000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF0000FFFF00FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.58446 0.782187 1.67177 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1282183659556) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFF0000FF00FFFFFFFF00000000FFFFFFFF00FF00FF00FF00FF00FFFFFFFFFF0000
FFFFFFFF0000FFFFFF0000000000000000000000FFFFFF0000FFFFFFFF0000FFFFFFFFFF
00FF00FF00FF00FF00FFFFFFFF00000000FFFFFFFF00FF0000FFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFF00FF0000FF0000FFFFFFFF00FF00FFFFFFFFFFFFFF0000
FFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFF0000FFFFFFFFFF
FFFF00FF00FFFFFFFF0000FF0000FF00FFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFF00FFFF00FF000000FFFFFFFFFF0000FFFFFFFFFFFF00FFFF00FF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00
FFFF00FFFFFFFFFFFF0000FFFFFFFFFF000000FF00FFFF00FFFFFFFFFF
FFFFFFFFFFFFFF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF0000
00FFFF00FF0000000000FF00FF000000FF00FF0000000000FF00FFFF000000FF0000FFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFF0000FF00FF00FFFFFFFFFF000000FF
00FF0000FFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFF0000FF00FF000000FFFFFF
FFFF00FF00FF0000FFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFF00FF0000FF00FFFF0000FFFFFF00FF00FF000000FF0000
00FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF
00FF00FFFFFF0000FFFF00FF0000FF00FFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF00000000FFFFFFFFFF0000FFFFFFFFFFFF00
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF00FFFFFFFFFFFF
0000FFFFFFFFFF00000000FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF000000FFFF0000FFFFFFFFFFFFFF00
FFFFFFFF0000FF00FF00FF00000000000000FF00FF00FF0000FFFFFFFF00FFFFFFFFFFFF
FF0000FFFF000000FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FF000000FFFFFFFFFFFF00FFFF00FF000000FFFF00
FFFF00FFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFF00FFFF00FFFF000000FF
00FFFF00FFFFFFFFFFFF000000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
00FF00FFFFFFFFFFFFFF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF00
FF00FFFF0000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFF0000FFFF00FF00FFFFFFFFFFFF
FFFF00FF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FF0000FF00FFFFFFFFFF0000FFFF0000
FFFFFF00FFFF0000FFFF0000FF00FF00FF0000FFFF0000FFFF00FFFFFF0000FFFF0000FF
FFFFFFFF00FF0000FF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF0000000000FF00FF00FFFFFF
FFFFFFFF00FF00FF00FFFFFFFF000000FFFFFFFF00FF00FF00FFFFFFFFFFFFFF00FF00FF
0000000000FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF0000FFFFFFFF00FFFF
00FF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFF00FF00FF00FFFF00FFFFFFFF
0000FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF000000FFFFFFFFFFFFFF0000FFFF
00FF00FFFFFFFFFFFF00FF00000000000000FF00FFFFFFFFFFFF00FF00FFFF0000FFFFFF
FFFFFFFF000000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFFFFFFFFFF00FF000000
00FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00000000FF00FFFF
FFFFFFFF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FF0000FF00FFFFFFFFFF
FFFFFFFF00FFFFFF000000FF00FFFFFF00FF000000FFFFFF00FFFFFFFFFFFFFFFFFF00FF
0000FF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF00000000FFFF
FF0000FF00FFFFFFFF0000FFFFFF00FFFFFF0000FFFFFFFF00FF0000FFFFFF00000000FF
FFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF00FF00
00FFFF00FFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFF00FFFF0000FF00FF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF000000FFFFFFFF00
00FFFFFF00FF0000FF00FFFFFFFFFFFFFFFFFF00FF0000FF00FFFFFF0000FFFFFFFF0000
00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFFFFFFFF
00FFFF0000FFFFFFFFFF0000FF000000FF0000FFFFFFFFFF0000FFFF00FFFFFFFFFF0000
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FF0000FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF00FFFF
00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF
00FF00FF00FF0000FF00FFFF00FF00FF00FFFF00FF0000FF00FF00FF00FFFFFFFF00FF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFF00FF00FFFFFFFF0000FF00FFFFFF00FF0000FFFFFFFF00FF00FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF0000
000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000000000FF00FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FFFF00FFFF00FF000000FFFFFFFFFFFFFFFFFF000000FF00FFFF00FFFF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
000000FFFF00FF00FF00FF00FFFFFFFFFF00FF00FF00FF00FFFF000000FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
00FF00000000FFFFFFFF0000FFFF00FFFF0000FFFFFFFF00000000FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF0000FFFFFF00FFFFFFFF00FFFFFF00FFFFFFFF00FFFFFF0000FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFF00FF00000000FFFF00FF00FFFF00000000FF00FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFF00FFFF00FFFFFFFFFF00FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF00FF0000FFFFFFFFFF0000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF0000FFFF00FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.58446 0.97619 1.67177 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1282183659557) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFF0000FF00FFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFF0000000000
000000FFFFFF00FFFFFFFFFF0000000000FFFFFFFFFF00FFFFFF0000000000000000FFFF
00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF00FF0000FFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFF00FFFF00FFFFFF0000FF00FF00FFFF0000FFFF0000000000
00FF00FF0000FFFFFFFFFF00FF000000FF00FFFFFFFFFF0000FF00FF000000000000FFFF
0000FFFF00FF00FF0000FFFFFF00FFFF00FFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFF00FFFF00FF0000FFFFFFFF00FF000000FFFFFF0000FF00FFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFF00FFFFFFFFFFFFFF00FFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FF00FF0000FFFFFF000000FF00FFFFFFFF0000FF00FFFF00FFFFFFFFFF
FFFFFFFFFFFFFF00FF00FF0000FFFF0000FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFF000000000000FF000000FFFF00FFFF000000FF000000000000FFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFF0000FFFF0000FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFF0000FF00FFFFFF00
FF000000FF000000FFFFFFFFFF00FF00FFFFFFFFFF000000FF000000FF00FFFFFF00FF00
00FFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFF00FFFFFF0000FF00FF0000FFFFFF000000FFFFFF00FFFF
FF0000FFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFF0000FFFFFF00FFFFFF00
0000FFFFFF0000FF00FF0000FFFFFF00FFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFF00FFFFFFFFFFFF000000FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFF00FF00FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF00FFFFFF00FFFF
FFFF00FFFF00FFFFFF0000FF0000000000FF0000FFFFFF00FFFF00FFFFFFFF00FFFFFF00
FFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FF0000FFFFFFFFFFFFFF000000FF00FFFF00FF00FF
FF00FFFFFFFF00FF000000FFFFFFFFFFFFFF000000FF00FFFFFFFF00FFFF00FF00FFFF00
FF000000FFFFFFFFFFFFFF0000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFF0000FF0000000000FFFFFFFF00FFFF
FFFF00FF00FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF00FF00FFFFFFFF00FFFFFFFF
0000000000FF0000FFFF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFF000000FF000000FFFF000000FF
FF0000FFFFFF00FFFFFFFFFFFF00FF00FFFFFFFFFFFF00FFFFFF0000FFFF000000FFFF00
0000FF000000FFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFFFF0000FFFFFF0000FFFF00000000
FF00FFFFFFFFFF0000FFFFFF00FFFFFF00FFFFFF0000FFFFFFFFFF00FF00000000FFFF00
00FFFFFF0000FFFFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF00FFFFFF00FFFFFFFFFFFFFF
FF00FFFFFF00FF00FF00FFFF00FF00FF00FFFF00FF00FF00FFFFFF00FFFFFFFFFFFFFFFF
00FFFFFF00FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFF
FFFF00FFFF0000FFFFFFFFFFFF00FF00FFFFFFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFF
FF00FFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF0000FFFFFFFF00FF0000FFFFFF00
FF00FFFFFFFF0000FFFF00FF00FFFFFF00FF00FFFF0000FFFFFFFF00FF00FFFFFF0000FF
00FFFFFFFF0000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFF0000FFFFFFFF00FFFF
FF00FF00FF00FFFF00FFFFFF00FF00FF00FFFFFF00FFFF00FF00FF00FFFFFF00FFFFFFFF
0000FFFF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFF00FFFFFFFFFFFF
FF00FFFFFF00FF00FFFFFFFFFF000000FFFFFFFFFF00FF00FFFFFF00FFFFFFFFFFFFFF00
FFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFFFF0000FF00FFFF00
00FFFFFFFFFF000000FFFFFF0000000000FFFFFF000000FFFFFFFFFF0000FFFF00FF0000
FFFFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF00FF00FFFF00
0000FFFFFF0000000000FF00000000000000FF0000000000FFFFFF000000FFFF00FF00FF
FFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFF
000000FF000000000000FFFFFFFFFFFFFFFFFF000000000000FF000000FFFFFFFFFF00FF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF0000FFFFFFFFFFFF
FF000000FFFF000000FFFFFFFFFFFFFFFFFFFFFF000000FFFF000000FFFFFFFFFFFFFF00
00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFF0000FF
00FFFF00FF00FFFF00FFFFFF00FF00FF00FFFFFF00FFFF00FF00FFFF00FF0000FFFF0000
FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF00FF
00FFFFFF0000FFFFFF0000FF00FFFFFF00FF0000FFFFFF0000FFFFFF00FF00FF00FFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFFFFFF
00FFFF0000FFFFFF00000000FFFFFFFFFF00000000FFFFFF0000FFFF00FFFFFFFF00FFFF
00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF
FFFF00FFFF00FF000000000000FFFFFF000000000000FF00FFFF00FFFFFFFFFFFF00FF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFF00FF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF0000
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FF00FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
FF0000000000FFFFFF0000FFFFFF00FFFFFF0000FFFFFF0000000000FF00FF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
00000000000000FF00000000FF000000FF00000000FF00000000000000FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
00FF0000000000FFFFFFFFFFFF000000FFFFFFFFFFFF0000000000FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF0000FFFFFF0000FF00FF00FFFFFF00FF00FF0000FFFFFF0000FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF0000FF00000000FFFFFFFFFFFFFFFFFF00000000FF0000FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFF00FF00000000FFFF00FF00FFFF00000000FF00FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFF00FFFF00FFFFFFFFFF00FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF00FF0000FFFFFFFFFF0000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF0000FFFF00FFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.68051 0.200176 1.76782 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -38 0 ]
[.5 .50755 38 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(965614446696) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFF000000FF000000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFF
FFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF
00FFFFFFFFFF0000FFFFFFFF00FFFFFF00FFFFFFFF0000FFFFFFFFFF00FFFFFFFFFF00FF
FFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFF000000FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00
FF00FFFFFF00FF0000000000FFFFFFFFFF0000000000FF00FFFFFF00FF00FFFFFF00FF00
FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF000000FFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFF000000FFFFFF000000FFFFFF000000FFFFFF000000FFFFFF00
0000FFFFFF000000FFFF00FFFFFF00FFFFFF00FFFF000000FFFFFF000000FFFFFF000000
FFFFFF000000FFFFFF000000FFFFFF000000FFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FF0000000000FF0000000000FF0000000000FF0000000000
FF0000000000FF000000FFFFFF00FF00FFFFFF000000FF0000000000FF0000000000FF00
00000000FF0000000000FF0000000000FF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFF000000FFFF00FFFFFF00FFFF000000FFFF00FFFFFF00FFFF00
0000FFFF00FFFFFF00FFFFFFFF000000FFFFFFFF00FFFFFF00FFFF000000FFFF00FFFFFF
00FFFF000000FFFF00FFFFFF00FFFF000000FFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFF000000FF000000FFFFFFFFFF000000
FF000000FFFFFFFFFF0000000000FF0000000000FFFFFFFFFF000000FF000000FFFFFFFF
FF000000FF000000FFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFF00FF
FFFF00FFFFFF00FFFFFF00FFFF000000FFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFF
FFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00FF00FFFFFF000000FFFFFFFFFFFFFFFFFF00
0000FFFFFF00FF00FFFFFF000000FF000000FFFFFF00FF00FFFFFF000000FFFFFFFFFFFF
FFFFFF000000FFFFFF00FF00FFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFF000000FFFFFFFF00FFFFFF00FFFFFFFF000000FFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFF000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FF0000000000FFFFFFFFFF0000000000FF0000000000FFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFF000000FFFF00FFFFFFFFFFFFFF00FFFF000000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FF000000FFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFF00FFFFFFFFFF
00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFF00FF
FFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00FF00FFFFFF00FF00FFFFFF00
FF00FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00FF00FFFFFF00FF00
FFFFFF00FF00FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF000000FFFFFF000000FFFFFF00
0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF000000FFFFFF000000
FFFFFF000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF0000000000FF0000000000
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF0000000000FF00
00000000FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000FFFF00FFFFFF00FFFF00
0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000FFFF00FFFFFF
00FFFF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFF000000
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFF
FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FF
FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FF
FFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00FF00FFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00FF00
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF000000FFFFFFFF
00FFFFFFFFFF00FFFFFFFFFFFF000000FFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFF000000
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF0000000000
FFFFFFFFFFFF0000000000000000FF0000000000000000FFFFFFFFFFFF0000000000FF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000FFFF00FF
FFFFFFFFFFFF0000FFFF00FFFF000000FFFF00FFFF0000FFFFFFFFFFFFFF00FFFF000000
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFF
FFFFFFFFFFFF0000FFFFFF000000FF000000FFFFFF0000FFFFFFFFFFFFFFFF000000FF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF
00FFFFFFFFFF0000FFFFFFFF00FFFFFF00FFFFFFFF0000FFFFFFFFFF00FFFFFF00FFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00
FF00FFFFFF00FF0000000000FFFFFFFFFF0000000000FF00FFFFFF00FF00FFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00
0000FFFFFF000000FFFF00FFFFFF00FFFFFF00FFFF000000FFFFFF000000FFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FF0000000000FF000000FFFFFF00FF00FFFFFF000000FF0000000000FF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00
0000FFFF00FFFFFF00FFFFFFFF000000FFFFFFFF00FFFFFF00FFFF000000FFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FF000000FFFFFFFFFF0000000000FF0000000000FFFFFFFFFF000000FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFF00FFFFFF00FFFFFF00FFFF000000FFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFF00FF00FFFFFF000000FF000000FFFFFF00FF00FFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFF000000FFFFFFFF00FFFFFF00FFFFFFFF000000FFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FF0000000000FFFFFFFFFF0000000000FF0000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFF000000FFFF00FFFFFFFFFFFFFF00FFFF000000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FF000000FFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000000000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF00FFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.68051 0.39418 1.76782 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1282183620129) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
0000000000FFFFFFFFFF0000FF00FF00FF0000FFFFFFFFFF0000000000FFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF
00FFFFFFFF0000000000FF00FFFFFFFFFF00FF0000000000FFFFFFFF00FFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000FF
FFFF0000FF00FF00FFFFFFFF00FFFFFF00FFFFFFFF00FF00FF0000FFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFF0000FFFFFFFFFF0000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFF00FFFFFFFFFFFFFF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF00
0000FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF000000FFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFF00FFFF0000FF0000FFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FFFF00FFFFFF00FFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFF00FFFFFF0000FFFFFFFFFF0000FFFFFF00FFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000
00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFF000000000000FFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFF000000FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFF000000000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000000000FFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.68051 0.588183 1.76782 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1282183620130) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FF00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFF0000FFFFFF0000000000FFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFF00000000FF00FFFFFFFFFFFFFF00000000FFFFFF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFF00000000
FFFFFFFFFFFFFF00FF00000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF00
0000000000000000FF00FFFFFF000000FFFFFF00FF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF00FF00FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFF000000FFFFFF00FFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFF00FFFFFF000000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF0000FFFF
FFFFFF00FFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFF00FFFFFFFFFF0000FFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFF
00FFFFFFFFFFFFFFFF0000000000000000000000FFFFFFFFFFFFFFFF00FFFFFFFFFFFF00
00000000000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFF0000FFFFFF000000000000000000000000000000FFFFFF0000FFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF000000FFFFFF000000FFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000
00FFFFFF000000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
000000000000FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF000000000000FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFF000000FFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF00000000FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000
00FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FFFFFFFF00000000000000FFFFFFFFFF00000000000000FFFFFFFF00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FF00FF
FFFF0000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF0000FFFFFF00FF00FFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF000000FFFFFF00FF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFF0000
00FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFF000000FFFFFFFFFF000000FFFFFF000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000
00FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF000000FFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
000000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF00000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000000000FF00FFFFFF00FFFFFF00FF00000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFF000000000000000000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.68051 0.782187 1.76782 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1282183620131) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFF00000000000000FFFF000000FFFFFFFFFFFFFF00FFFFFF00FFFFFF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFF00FFFFFF
00FFFFFFFFFFFFFF000000FFFF00000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
00FFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFF00FF00FF00
FFFFFFFFFFFFFF00FF00FFFF0000FF0000FFFF00FF00FFFFFFFFFFFFFF00FF00FF00FFFF
FF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FF0000FFFFFFFFFFFFFF00FF00FFFFFFFF00FF
FFFFFFFFFFFFFFFF00FFFFFFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFF00
FF00FFFFFFFFFFFFFF0000FF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFF00FFFFFFFFFFFF00FFFFFFFF00FFFF000000
FFFFFFFFFFFFFF000000FFFFFF00FF00FFFFFF000000FFFFFFFFFFFFFF000000FFFF00FF
FFFFFF00FFFFFFFFFFFF00FFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFF00FFFF000000FFFFFFFF
FF0000FF0000FFFFFFFFFF0000FFFFFF0000FFFFFFFFFF0000FF0000FFFFFFFFFF000000
FFFF00FFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF
FF00FFFFFF00FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFF0000FFFFFFFFFF00FF00FFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFF0000FF00
FFFFFFFFFFFFFF00FF0000FF00FFFFFF00FF0000FF00FFFFFFFFFFFFFF00FF0000FFFFFF
FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFF000000FF00FFFF00FFFFFFFF00
FFFFFFFFFFFFFF00FFFFFFFF00FF00FF00FFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF00FF
FF00FF000000FFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FF0000000000FFFFFFFF00FFFFFFFF
FF0000FFFF0000FFFFFFFFFFFF000000FFFFFFFFFFFF0000FFFF0000FFFFFFFFFF00FFFF
FFFF0000000000FF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFF000000FFFFFF
FFFFFFFFFFFF00FF00FFFFFF0000000000FFFFFF00FF00FFFFFFFFFFFFFFFFFF000000FF
FF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFF00FFFF00FFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
00FFFFFFFF00FFFFFFFF000000FFFFFF000000FFFFFFFF00FFFFFFFF00FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FF0000FFFFFFFF
FF00FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF00FFFFFFFFFF0000FF
00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFF00FFFFFFFFFF
FF00FF0000FFFFFFFF00FFFF00FFFFFF00FFFF00FFFFFFFF0000FF00FFFFFFFFFFFF00FF
FFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF
FFFF00000000FFFF000000FFFFFF00FFFFFF000000FFFF00000000FFFFFFFFFFFFFF00FF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF
FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF00FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFF00FFFF00FFFFFFFF0000FFFFFF0000FFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFF00
0000FF00FF000000FF00FFFFFFFFFFFFFFFFFF00FF000000FF00FF000000FFFF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FF0000
000000FFFFFFFFFFFFFF00FFFF00FF00FFFF00FFFFFFFFFFFFFF0000000000FF00FFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00000000FFFF00FFFF000000FF00FF00FF000000FFFF00FFFF00000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
0000000000FFFFFF0000000000FFFFFF0000000000FFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF00FF00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFF000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFF00FF0000FF00FFFF0000000000FFFF00FF0000FF00FFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFF00FFFFFF00FFFFFFFF00000000000000FFFFFFFF00FFFFFF00FFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFF00FF00FF000000FF00FF00FFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF00FFFF00000000000000FFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFF00FF000000000000000000FF00FFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.68051 0.97619 1.76782 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -41 0 ]
[.5 .50755 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1282183639842) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF0000FF00FFFFFFFF00FF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF00FFFFFFFF00
FF0000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00
00000000FFFFFFFF0000FF0000FFFFFF0000FF0000FFFFFFFF0000000000FFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF0000FF00FFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF00FF0000
FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFFFFFF0000
00FF00FFFFFFFF00FFFF00FF0000FF0000FF00FFFF00FFFFFFFF00FF000000FFFFFFFF00
FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000000000000000000000FF0000FFFFFF00FFFF00FFFFFFFFFF00
FFFFFFFFFFFFFF00FFFF00FF00FFFFFF00FF00FFFF00FFFFFFFFFFFFFF00FFFFFFFFFF00
FFFF00FFFFFF0000FF000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000FFFFFFFFFFFF00
FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFF
0000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF0000FF0000FF
FFFFFFFFFFFF00FFFF0000FFFFFFFFFFFFFF0000FFFF00FFFFFFFFFFFFFF0000FF0000FF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFF
0000000000FFFFFF00FFFF00FF000000FF00FFFF00FFFFFF0000000000FFFFFFFF00FFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFF00FFFFFFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FFFFFFFF00FFFFFF0000FF00
00FF00FF00FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFF00FF00FF0000FF0000FFFFFF
00FFFFFFFF00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00
FFFFFF00FFFFFFFF00FF00FFFF00FF00FFFF00FF00FFFFFFFF00FFFFFF00FFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
0000FFFFFF0000FF00FFFFFF00FFFFFF00FFFFFF00FF0000FFFFFF0000FFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF00FF0000FF
FFFFFFFFFFFF00FFFFFFFFFF00FF00FF00FFFFFFFFFF00FFFFFFFFFFFFFF0000FF00FFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFF0000FFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
0000FF00FFFFFFFFFF00FFFF0000FF0000FFFF00FFFFFFFFFF00FF0000FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FF00FF00FFFF
FFFFFF00FFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFF00FFFFFFFFFF00FF00FF00
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFFFFFF0000FF0000FFFFFF00FFFFFF00FFFFFF0000FF0000FFFFFFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FF0000FFFFFFFF00FFFFFFFFFF000000FFFFFFFFFF00FFFFFFFF0000FFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF000000
FF00FFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFF00FF000000FFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFF0000FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFF0000FFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFF00FFFF00FF00FF000000FF00FF00FFFF00FFFF0000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FF00FFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFF0000FFFFFF00FFFFFFFFFFFFFF00FFFFFF0000FFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FFFFFF0000FFFFFF0000FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00000000FFFFFF00FFFFFFFF00FF00FF00FFFFFFFF00FFFFFF0000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFF0000FFFFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF0000000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.77655 0.200176 1.86386 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -38 0 ]
[.5 .50755 38 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(965226434899) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFF0000000000FFFFFF0000000000FFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFF0000000000FFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFF00FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFF0000000000FFFFFF0000000000FFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFF0000000000FFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFF000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFF000000000000FFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFF0000000000FFFFFF0000000000FFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF00000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFF00000000000000FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFF0000000000FFFFFF0000000000FFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF0000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFF0000000000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFF0000000000FFFFFF0000000000FFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFF0000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000FFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFF000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFF0000000000FFFFFF0000000000FFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFF0000FF0000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFF00FF0000000000FFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF0000
000000FF00FFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFF0000000000FFFFFF0000000000FFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFF0000000000FFFFFF0000000000FFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF000000000000FFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF0000
00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFF0000000000FFFFFF0000000000FFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00000000000000FFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF0000
0000000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFF0000000000FFFFFF0000000000FFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000000000FFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF0000
000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFF0000000000FFFFFF0000000000FFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000FFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF0000
00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF0000FF00
00FFFFFFFFFFFFFF0000000000FFFFFF0000000000FFFFFFFFFFFFFF0000FF0000FFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFF
00FF0000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000000000FF00FFFFFFFFFF0000
00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
00FFFFFFFFFFFFFF0000000000FFFFFF0000000000FFFFFFFFFFFFFF00FFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
00FFFFFFFFFFFFFF0000000000FFFFFF0000000000FFFFFFFFFFFFFF00FFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FF000000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF000000000000FFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
00000000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00000000000000FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF0000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000000000FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFF0000000000FFFFFF0000000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF000000FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFF0000FF0000FFFFFF0000FF0000FFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF000000FFFFFFFFFF00FF00FF00FFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFF00FFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFF000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF0000000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.77655 0.39418 1.86386 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -38 0 ]
[.5 .50755 38 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(965226434900) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFF00FFFFFF00FFFF0000FFFF00FFFF000000FFFFFFFF00FFFFFFFFFFFFFFFF00
00FFFF00FFFF0000FFFFFFFF0000000000FFFFFFFF0000FFFF00FFFF0000FFFFFFFFFFFF
FFFF00FFFFFFFF000000FFFF00FFFF0000FFFF00FFFFFF00FFFFFFFFFF
FFFFFFFFFF00FFFFFFFF00FFFFFFFF000000FFFFFFFFFF0000FFFFFF0000FFFF0000FFFF
FFFF000000FFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFF000000FFFFFFFF0000FFFF00
00FFFFFF0000FFFFFFFFFF000000FFFFFFFF00FFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFF0000FFFFFF00FFFF0000000000FFFF00FFFFFFFF00FFFFFFFF00000000FF
FF0000000000FFFF00000000FFFF00FFFF00000000FFFF0000000000FFFF00000000FFFF
FFFF00FFFFFFFF00FFFF0000000000FFFF00FFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFF000000FFFF000000FFFF000000000000
FFFFFFFFFFFFFF000000000000FFFFFF000000000000FFFFFFFFFFFFFF000000000000FF
FF000000FFFF000000FFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFF0000FFFF0000FFFFFFFFFF0000000000FFFFFFFFFFFFFF
FF00FFFF0000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF0000FFFF00FFFFFFFFFFFFFFFF
0000000000FFFFFFFFFF0000FFFF0000FFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF00000000FFFFFFFF00FFFF00000000000000FFFF0000FFFF
000000FFFFFFFF0000FFFF0000FFFFFF0000FFFF0000FFFFFFFF000000FFFF0000FFFF00
000000000000FFFF00FFFFFFFF00000000FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF000000000000000000FFFFFFFF00
00000000FFFF00000000FFFFFFFF00FFFFFFFF00000000FFFF0000000000FFFFFFFF0000
00000000000000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFF000000000000FFFF000000FFFF000000000000FFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF0000FFFFFF00FFFF0000FFFF0000FFFFFFFF00
00FFFF00FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF00FFFF0000FFFFFFFF0000
FFFF0000FFFF00FFFFFF0000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FFFFFF00000000FFFFFFFF0000FFFF
FFFF000000FFFF0000FFFF00000000000000FFFF0000FFFF000000FFFFFFFF0000FFFFFF
FF00000000FFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF000000FF000000000000FFFF00000000FF
FF0000000000FFFFFFFF000000000000000000FFFFFFFF0000000000FFFF00000000FFFF
000000000000FF000000FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFF00FFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF000000000000FF
FFFFFFFFFFFFFF00FFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF0000FFFF00FFFFFFFFFFFFFF
FF0000FFFF00FFFFFFFF0000FFFF00FFFF0000FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFF
00FFFF0000FFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFF000000FFFF00FFFF00
FFFFFFFF000000FFFF00000000FFFFFF00000000FFFF000000FFFFFFFF00FFFF00FFFF00
0000FFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFF0000000000FFFFFF0000
00FFFF0000000000FFFFFFFFFFFF00FFFFFFFFFFFF0000000000FFFF000000FFFFFF0000
000000FFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFF00FFFFFF
FFFF00000000000000FFFF0000FFFFFF0000FFFF00000000000000FFFFFFFFFF00FFFFFF
FFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000FFFF0000FFFFFF00FF
FF000000000000000000FFFFFFFF00FFFFFFFF000000000000000000FFFF00FFFFFF0000
FFFF0000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00000000FFFFFFFF00FFFFFF
0000000000000000000000FFFF000000FFFF0000000000000000000000FFFFFF00FFFFFF
FF00000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FFFFFF
00FFFF00FFFF0000FFFF00FFFFFFFFFFFFFF00FFFF0000FFFF00FFFF00FFFFFF00FFFFFF
FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF0000FFFFFF00FF
FFFF000000FFFFFFFF000000FFFF00FFFF000000FFFFFFFF000000FFFFFF00FFFFFF0000
FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FFFFFF
00FFFFFFFFFF0000FFFFFFFFFF000000FFFFFFFFFF0000FFFFFFFFFF00FFFFFF00FFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF000000FF00
0000FFFF00FFFFFFFF00FFFF0000000000FFFF00FFFFFFFF00FFFF000000FF000000FF00
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFF00FFFF
FFFFFF000000FFFF000000FFFFFFFFFFFFFF000000FFFF000000FFFFFFFFFF00FFFF0000
00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF
0000FFFFFFFFFF0000000000FFFF00FFFF0000000000FFFFFFFFFF0000FFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FF
FFFFFF00FFFF00000000000000FFFFFF00000000000000FFFF00FFFFFFFF00FFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00
FFFF000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF000000FFFF00FFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
00FFFFFFFFFF0000FFFF00FFFF000000FFFF00FFFF0000FFFFFFFFFF00FFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FF0000FFFF00000000FFFFFF0000000000FFFFFF00000000FFFF0000FFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
00000000FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF00000000FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF000000FFFF00FFFF000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFF00FFFFFFFF0000000000FFFFFF0000000000FFFFFFFF00FFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFF00FF0000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000FF00FFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFF00FFFF0000FFFFFF0000FFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FF000000FFFFFFFF00FFFFFFFF000000FF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF000000FFFF00FF0000FFFFFF0000FF00FFFF000000FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00FFFFFFFF00FFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFF00FFFF000000FFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFF00FFFFFFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFF00FF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFF000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF0000000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.77655 0.588183 1.86386 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -38 0 ]
[.5 .50755 38 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(965226454611) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFF0000000000FFFF000000FF000000FFFFFF00FFFFFF000000FF0000FFFF0000
FFFF00FFFFFF0000FF00FF00FFFFFFFFFF00FF00FF0000FFFFFF00FFFF0000FFFF0000FF
000000FFFFFF00FFFFFF000000FF000000FFFF0000000000FFFFFFFFFF
FFFFFFFFFF00FF0000FFFFFF00FF000000FF00FF0000FFFFFFFFFFFFFFFFFF00FFFF0000
FFFF00FF000000FF00FF00FFFFFFFFFFFFFF00FF00FF000000FF00FFFF0000FFFF00FFFF
FFFFFFFFFFFFFF0000FF00FF000000FF00FFFFFF0000FF00FFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFF00FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF00FFFF0000
FFFF000000FF0000FFFFFF00000000000000FFFFFF0000FF000000FFFF0000FFFF00FFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFF00FFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFF00FFFF00FFFF0000FFFFFF000000FFFF00000000FFFF0000
FFFF0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFF0000FFFF000000
00FFFF000000FFFFFF0000FFFF00FFFF00FFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFF00FF0000FFFF00FF00000000FF0000FFFF0000
FFFF0000FFFFFF00000000FF0000FF0000FF00000000FFFFFF0000FFFF0000FFFF0000FF
00000000FF00FFFF0000FF00FFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF000000FFFFFFFFFF00FF00000000FFFFFFFFFFFF0000FFFF0000
FFFF00FFFFFFFFFF0000FFFFFF000000FFFFFF0000FFFFFFFFFF00FFFF0000FFFF0000FF
FFFFFFFFFF00000000FF00FFFFFFFFFF000000FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FF00FFFF00FFFF00FFFF00FF00FF0000FF
00FFFFFFFFFFFF0000FFFFFF0000FF0000FFFFFF0000FFFFFFFFFFFF00FF0000FF00FF00
FFFF00FFFF00FFFF00FF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF00FFFFFF00FF00FFFFFF0000
FFFFFFFFFFFFFFFF0000FFFF00FF00FF00FFFF0000FFFFFFFFFFFFFFFF0000FFFFFF00FF
00FFFFFF00FFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF0000FFFF00FF00FFFFFFFFFF00
0000FFFF0000FFFFFF00000000FFFFFF00000000FFFFFF0000FFFF000000FFFFFFFFFF00
FF00FFFF0000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF00000000FFFFFFFF00FFFFFFFF00FF00
FF00000000FFFFFFFF0000FF0000FF0000FF0000FFFFFFFF00000000FF00FF00FFFFFFFF
00FFFFFFFF00000000FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFF0000FFFFFFFF0000FFFFFFFFFFFFFF
0000FF0000FFFFFFFFFF00FF00FFFFFF00FF00FFFFFFFFFF0000FF0000FFFFFFFFFFFFFF
0000FFFFFFFF0000FFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFF00FF00FFFFFFFFFFFF
FF0000FFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFF0000FFFFFFFFFFFFFF00
FF00FFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFF0000FFFF0000FFFF
00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00FFFF0000FFFF00
00FFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFF0000FF000000000000FFFFFFFFFF000000000000FF0000FFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFF0000FFFFFFFF
FFFFFF00FF00FF0000FF00FFFFFFFFFFFFFF00FF0000FF00FF00FFFFFFFFFFFFFF0000FF
FFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFF0000FFFFFFFFFF
FFFFFFFF0000FFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFF0000
FFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFF0000FFFFFFFF
FFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFF0000FF
FFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000000000
000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFF0000000000000000FFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF0000FF00
00FF00FFFF0000FFFF000000FFFF00FFFF000000FFFF0000FFFF00FF0000FF0000FFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF0000FF00FF
0000FFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFF0000FF00FF0000FFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FF00FF00
FF00FFFFFFFFFF00FFFFFF000000FF000000FFFFFF00FFFFFFFFFF00FF00FF00FF000000
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFF0000FFFF
FF00FFFF000000FFFFFFFF00FF000000FF00FFFFFFFF000000FFFF00FFFFFF0000FFFF00
00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FF
FF00000000FF000000FFFF00FFFFFFFFFF00FFFF000000FF00000000FFFF00FF00FFFFFF
00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
00FF0000FF00FF00FFFFFFFF0000FF0000FFFFFFFF00FF00FF0000FF00FFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFF00
FF00FF0000FFFFFF00FF000000FFFFFF000000FF00FFFFFF0000FF00FF00FFFF0000FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
00FF00FF00FFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFF00FF00FF00FFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00
00FFFFFF00FFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFF00FFFFFF0000FFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
00FFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFF00FFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000
00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF000000FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFF00FF00000000FFFFFFFFFFFFFF00000000FF00FFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFF0000FF00FFFFFFFFFFFFFF00FF0000FFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FF0000FF00FFFFFFFFFFFFFFFFFF00FF0000FF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFF000000FF00FFFFFFFFFFFFFFFFFFFFFF00FF000000FFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF000000FFFFFFFFFF000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FF00000000000000FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFF00FF0000FF0000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FF00FF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.77655 0.782187 1.86386 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -38 0 ]
[.5 .50755 38 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(965226454612) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFF00000000000000FF00FF0000FFFF000000FFFF000000FFFF000000FFFFFF00
00FFFFFFFFFF0000FF0000FFFF000000FFFF0000FF0000FFFFFFFFFF0000FFFFFF000000
FFFF000000FFFF000000FFFF0000FF00FF00000000000000FFFFFFFFFF
FFFFFFFFFF00FF0000FF0000FFFFFF0000FFFF0000FF00FFFFFFFFFF00FF0000FFFF00FF
00000000000000FF00FF00000000FF00000000FF00FF00000000000000FF00FFFF0000FF
00FFFFFFFFFF00FF0000FFFF0000FFFFFF0000FF0000FF00FFFFFFFFFF
FFFFFFFFFFFF0000FF00FF0000000000FF00FFFFFFFF00000000000000FFFFFFFF00FF00
FF0000FF0000FF00FF00FF0000FF00FF0000FF00FF00FF0000FF0000FF00FF00FFFFFFFF
00000000000000FFFFFFFF00FF0000000000FF00FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFF000000000000FF0000FF0000FFFF00FFFFFF00
0000FF00FF000000FFFFFF0000FFFFFF0000FFFFFF000000FF00FF000000FFFFFF00FFFF
0000FF0000FF000000000000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFF00FFFF00FFFF00FF0000FF0000FFFFFFFF0000FFFF0000000000
FF000000FFFFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFFFF000000FF0000000000FFFF
0000FFFFFFFF0000FF0000FF00FFFF00FFFF00FFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFF00000000FFFFFFFF0000FFFF00FFFFFFFF00FF0000FF00
0000FF00000000000000FFFF00FFFFFF00FFFF00000000000000FF000000FF0000FF00FF
FFFFFF00FFFF0000FFFFFFFF00000000FFFF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF0000FFFF00FFFFFFFF00FF00FFFF00FF00FF000000
FF000000FF0000FF0000FFFF0000000000FFFF0000FF0000FF000000FF000000FF00FF00
FFFF00FF00FFFFFFFF00FFFF0000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF000000FF00FFFFFF00FFFF000000FFFF000000FFFFFFFF
FF0000FF00FF000000FF00FFFFFFFFFFFFFF00FF000000FF00FF0000FFFFFFFFFF000000
FFFF000000FFFF00FFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF000000FFFF00FF00FFFFFFFFFF00FF0000FFFF00FF
FF0000FFFFFF0000FF00FF00FFFF00FFFF00FF00FF0000FFFFFF0000FFFF00FFFF0000FF
00FFFFFFFFFF00FF00FFFF000000FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00000000FFFFFF00FFFF00FF00FF00000000FF
FF0000FFFF00FF000000FFFFFF00FF00FFFFFF000000FF00FFFF0000FFFF00000000FF00
FF00FFFF00FFFFFF00000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF0000FF00FFFF00000000FFFFFF0000FF0000
0000FF00FFFFFF0000FF00FFFF000000FFFF00FF0000FFFFFF00FF00000000FF0000FFFF
FF00000000FFFF00FF0000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF00000000FF0000FFFF00FF000000FF
0000FFFFFF00FFFFFFFF00000000FF00000000FFFFFFFF00FFFFFF0000FF000000FF00FF
FF0000FF00000000FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF0000FFFFFFFF00FF00FF0000FF
FFFFFF00FFFFFF00FFFF0000FF000000FF0000FFFF00FFFFFF00FFFFFFFF0000FF00FF00
FFFFFFFF0000FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF00FF000000000000FFFFFF0000FF
FF00FFFFFF00FFFFFF00FF000000FF000000FF00FFFFFF00FFFFFF00FFFF0000FFFFFF00
0000000000FF00FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF0000FF0000FFFF00FF0000
0000FFFF00FF00FFFF000000FF000000FF000000FFFF00FF00FFFF00000000FF00FFFF00
00FF0000FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF0000FFFFFFFF00FF00FF00
00FF00FFFFFF00000000FF000000FF000000FF00000000FFFFFF00FF0000FF00FF00FFFF
FFFF0000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF0000FFFF00FFFFFF000000
FF00FF00FFFF0000FF000000FF000000FF000000FF0000FFFF00FF00FF000000FFFFFF00
FFFF0000FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF0000FFFF0000000000FF00
0000FFFFFF00FF000000FF000000FF000000FF000000FF00FFFFFF000000FF0000000000
FFFF0000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFF00
00FF00FFFF000000FF000000FF000000FF000000FF000000FFFF00FF0000FFFFFFFFFFFF
FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFF00FFFF00FFFF
FFFF00000000FF000000FF000000FF000000FF000000FF00000000FFFFFFFF00FFFF00FF
FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFF000000
000000FF0000FFFFFFFFFF0000FF00FF0000FFFFFFFFFF0000FF000000000000FFFF0000
0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FFFF0000FF
0000FF00FF00000000000000FF00FF00FF00000000000000FF00FF0000FF0000FFFF0000
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF00000000FF00
FF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FF00FF00000000FF
00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF00
0000FF0000000000000000000000FF0000000000000000000000FF000000FFFFFFFFFFFF
00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
FF000000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF000000FF00000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF0000
FFFFFFFFFF0000FFFFFFFF0000FFFFFF0000FFFFFFFF0000FFFFFFFFFF0000FF0000FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00
000000000000FF00FFFF00FF0000000000FF00FFFF00FF00000000000000FF00FF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF
FF00FFFF00FFFF0000FF000000000000000000FF0000FFFF00FFFF00FFFF00FFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FF00000000FFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFF00000000FFFF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FF0000FFFF0000FFFF00FFFF00FFFF00FFFF0000FFFF0000FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF000000FF00FFFFFFFF00FF00FFFFFF00FF00FFFFFFFF00FF000000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FF00FF00FFFF00FFFFFF0000000000FFFFFF00FFFF00FF00FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFF00FF00FFFF0000FF0000FFFF00FF00FFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFFFF00000000FF00FF00000000FFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF0000FFFF00FF0000FF00FF00FF0000FF00FFFF0000FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF000000FF00FF00FF00FF000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF0000FF00FF00FF00FF00FF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFF00FF00FF00FF00FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FF00FF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFF00FF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.77655 0.97619 1.86386 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -38 0 ]
[.5 .50755 38 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(965226454613) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFF00000000000000000000000000000000000000000000000000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFF
FFFFFFFFFF00FF0000000000000000000000000000000000000000000000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
00000000000000000000000000000000000000000000FF00FFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
0000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000000000000000000000000000000000000000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
00000000000000000000000000000000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFF0000000000000000000000000000000000000000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
00000000000000000000000000000000000000FFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF000000000000000000000000000000000000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
0000000000000000000000000000000000FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF0000000000000000000000000000000000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
00000000000000000000000000000000FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
0000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000000000000000000000000000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
00000000000000000000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF000000000000000000000000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
0000000000000000000000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000000000000000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
00000000000000000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000000000000000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
00000000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF000000000000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
0000000000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF000000000000
00000000FFFF0000000000000000000000000000000000FFFF00000000000000000000FF
00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
00000000FFFF0000000000000000000000000000000000FFFF0000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000000000
00000000FFFF0000000000000000000000000000000000FFFF000000000000000000FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
00000000FFFF0000000000000000000000000000000000FFFF00000000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
00000000FFFF0000000000000000000000000000000000FFFF000000000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000
00000000FFFF0000000000000000000000000000000000FFFF000000000000FFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
00000000FFFF0000000000000000000000000000000000FFFF00000000FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFF0000000000000000000000000000000000FFFF0000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF000000FFFF0000000000000000000000000000000000FFFF000000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FF00FF0000FF00000000000000000000000000FF0000FF00FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFF00000000000000000000000000FFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FFFF00000000000000000000000000FFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF0000FFFF00000000000000000000000000FFFF0000FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF00000000000000000000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF00000000000000000000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFF000000000000000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00000000000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFF0000000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFF00000000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.87259 0.200176 1.9599 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -38 0 ]
[.5 .50755 38 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(941560928433) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFF
FFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FF000000FFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FF00
0000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF
00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF
00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFF
FF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFF
FFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFF
FFFFFF000000FF000000FFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFF00
0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF
FFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF00
0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF
00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FF000000FF000000FF000000FF000000FF000000FF000000FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FF000000FFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.87259 0.39418 1.9599 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -38 0 ]
[.5 .50755 38 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(965226415185) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFF0000FFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF0000FF00FF00000000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF00FF
0000FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFF000000FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF00
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFFFF
00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFF
00FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF00FFFFFFFF00FFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFF00FFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FF
FFFFFFFFFFFF0000FFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFF0000FFFFFFFF00FFFF0000FFFFFFFFFFFF0000FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFF
FFFFFFFF0000FFFF00FFFFFFFF0000FFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFF00FF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFFFF
FFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF0000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FFFF0000FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF00FFFFFF00FFFFFFFFFFFFFFFF0000FFFF
FFFF00FFFFFFFFFF00FF0000FFFFFFFFFF0000FF00FFFFFFFFFF00FFFFFFFF0000FFFFFF
FFFFFFFFFF00FFFFFF00FFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FFFFFF00FF00FFFFFFFFFF00FF00
00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF0000FF00FFFFFFFF
FF00FF00FFFFFF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF0000FF00FFFFFF00FF0000FFFFFF
FFFFFF0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFFFFFFFFFF0000FF00
FFFFFF00FF0000FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFF
FFFFFF00FFFFFFFFFF0000FF00FFFFFF00FF0000FFFFFFFFFF00FFFFFFFFFFFFFFFFFF00
FF0000FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000
FFFFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFFFF000000FF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF
FFFFFFFFFF00FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFFFFFF0000FFFFFF
FFFFFF00FF00FFFFFFFFFFFFFF000000FFFFFFFFFFFFFF00FF00FFFFFFFFFFFF0000FFFF
FFFFFFFF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFF00FFFFFFFF000000FFFFFFFFFF000000FFFFFFFF00FFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFF00FFFF0000FF0000FFFF00FFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF0000FF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00
00FFFF00FFFFFFFF00FFFF00FFFFFFFFFF00FFFF00FFFFFFFF00FFFF0000FFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF0000FF
FF00FF00FFFFFFFFFF0000FFFFFFFFFFFFFF0000FFFFFFFFFF00FF00FFFF0000FFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00
00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
00FF00FF00FFFFFF0000FF000000FF000000FF0000FFFFFF00FF00FF00FFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFF00FF00FF0000FFFF00FFFF00FF00FFFF00FFFF0000FF00FF00FFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF
FF00FFFFFF00FFFF0000FFFFFFFF00FFFFFFFF0000FFFF00FFFFFF00FFFF0000FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFF00FF00FFFFFFFF00FF000000FF000000FF00FFFFFFFF00FF00FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFF00FFFF00FF00FFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFF00FFFFFF00FF00FFFFFF00FFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFF0000000000FFFFFFFF00FF00FFFFFFFF0000000000FFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FFFF00FFFFFFFFFFFF00FFFFFFFFFFFF00FFFF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFF00FFFFFFFFFFFFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFF00FF0000FF0000FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FF00FF00FFFFFF00FF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.87259 0.588183 1.9599 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -38 0 ]
[.5 .50755 38 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(965226415186) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFF0000FFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF0000FFFF
00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFFFF00FFFFFFFF00FF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF00FFFFFFFF00
FFFFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFF00FF0000FF00FFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFF00FF0000FF00FFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFF000000FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFF000000FFFFFF000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFF00FFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFF0000FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFF00FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFF0000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000000000FFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFF00FF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000FF00FFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFF00FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFF00FFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF
FF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF00FF00FFFFFFFF0000FF00
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FF0000FFFFFF
FF00FF00FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF00FF0000FFFFFFFF00
FFFFFFFF00FFFFFF00FF00000000FF00000000FF00FFFFFF00FFFFFFFF00FFFFFFFF0000
FF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFF00FFFFFFFFFFFF
00FFFF00FFFFFFFFFF00FFFF00FFFFFF00FFFF00FFFFFFFFFF00FFFF00FFFFFFFFFFFF00
FFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF0000FFFF0000
FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF0000FFFF0000FF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF00FF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF00FFFF00FFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF00
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FF00FFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF00FF00
FFFFFFFFFF0000FFFFFF00FFFFFFFFFFFFFF00FFFFFF0000FFFFFFFFFF00FF00FF00FFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFF00
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFF00FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00
0000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF000000FFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
0000FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF000000FF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFF00FF0000FFFFFFFFFF0000FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF00FFFF00FFFFFFFFFF00FF00FFFFFFFFFF00FFFF00FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFFFF0000FF0000FFFFFF0000FF0000FFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF000000FFFFFFFFFF00FF00FF00FFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFF00FFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFF000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF0000000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.87259 0.782187 1.9599 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -38 0 ]
[.5 .50755 38 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(965226415187) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF0000FF00FFFFFFFF00FF00FF00FF
FF0000FFFFFFFFFF00FFFF000000FF000000FFFF00FFFFFFFFFF0000FFFF00FF00FF00FF
FFFFFF00FF0000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFF00FF00FF00FF00FFFFFFFF00FF00FF00FFFFFF00FFFFFFFF
FFFF00FFFFFFFFFFFF0000FFFF00FF00FFFF0000FFFFFFFFFFFF00FFFFFFFFFFFF00FFFF
FF00FF00FF00FFFFFFFF00FF00FF00FF00FFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFF000000FFFFFF0000FF00FFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFF00FFFF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFF00FF0000FFFFFF000000FFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF000000FFFFFFFFFFFFFFFF
FFFF000000FF00FFFF000000FFFFFFFFFF000000FFFF00FF000000FFFFFFFFFFFFFFFFFF
FF000000FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF00FFFF00FFFFFFFFFFFFFF
FF00FFFF00FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFF
00FFFF00FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF00FFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FF00FF00FF0000FFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FF00FF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FF00FFFFFF000000FFFFFFFFFFFFFFFF00
FF000000FFFF00FFFFFFFF00FFFFFFFFFF00FFFFFFFF00FFFF000000FF00FFFFFFFFFFFF
FFFF000000FFFFFF00FF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
0000000000FF00FFFF0000FFFFFFFFFFFFFF0000FFFF00FF0000000000FFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFF00FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFF00FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF00FFFF00FFFFFF00FF
FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFF00FFFFFF00FF
FF00FFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF00FF00FFFFFFFFFFFFFFFFFF
FFFF0000FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF00FF00FF0000FFFFFFFFFFFFFFFFFF
FFFF00FF00FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFF0000
FFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFF0000FFFFFFFFFF
FFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFF
00FFFFFFFFFF00FF00FF00FFFFFFFFFFFFFF00FF00FF00FFFFFFFFFF00FFFF0000FFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FFFFFFFFFFFFFFFF00FF00FF0000FF0000FF00FF00FFFFFFFFFFFFFFFF00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFF00FF
FFFF00FF00FF0000FFFFFFFF00FFFFFF00FFFFFFFF0000FF00FF00FFFFFF00FFFFFFFFFF
FFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFF0000FFFFFF
0000FFFFFF00000000FFFF00FFFFFFFFFF00FFFF00000000FFFFFF0000FFFFFF0000FFFF
FF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFF00FF0000
FFFF00FF00FFFF00FFFFFFFF00FF00FF00FFFFFFFF00FFFF00FF00FFFF0000FF00FFFFFF
FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FF00FFFFFF00
FFFFFF00FFFFFF00FFFFFFFFFF000000FFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FF00
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF000000FFFFFF
0000FFFFFF0000FFFFFFFFFF0000000000FFFFFFFFFF0000FFFFFF0000FFFFFF000000FF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FF00FFFF00FFFF0000FF00FFFFFFFFFFFFFF00FF0000FFFF00FFFF00FFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFF00FFFFFF00000000FFFFFFFFFFFFFFFFFF00000000FFFFFF00FFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FF000000FF000000000000FFFFFFFFFFFFFF000000000000FF000000FFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF
FFFF00FFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFF00FFFFFFFFFF00FFFF00FFFFFF00FFFF00FFFFFFFFFF00FFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF000000FFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFF000000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFF00FFFF00FF00FF00FFFFFFFFFFFFFF00FF00FF00FFFF00FFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFF00FFFF00FFFF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FF000000FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFF00FFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.87259 0.97619 1.9599 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[.5 .50755 -38 0 ]
[.5 .50755 38 12.875 ]
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .50755 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(965226434898) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF00FFFFFF00FF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFF00FF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFFFF
FFFFFFFFFFFF0000FFFF00FFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFF00FFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF00FFFFFFFF0000000000000000FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000
000000000000FFFFFFFF00FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFF0000FFFF0000FFFFFFFF0000FF0000FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000FF0000FFFFFFFF0000FFFF0000FFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FF00FFFF00FFFFFF00FFFFFFFF0000FFFF
FFFFFF0000FFFF0000FFFF0000FFFFFF0000FFFF0000FFFF0000FFFFFFFFFF0000FFFFFF
FF00FFFFFF00FFFF00FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FFFFFF00FFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFF00FF
00FFFFFFFFFF00FFFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFF00FFFFFFFFFFFF00FF00FF0000FFFF
FFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFF0000FF00FF
00FFFFFFFFFFFF00FFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00FF00FFFFFFFFFFFFFFFF00FFFFFF00FF00
000000FF00FFFF00FF00000000FFFFFF00000000FF00FFFF00FF00000000FF00FFFFFF00
FFFFFFFFFFFFFFFF00FF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFF00FF0000FFFF00FFFF
00FF00FFFFFFFFFF00FF0000FF000000FF0000FF00FFFFFFFFFF00FF00FFFF00FFFF0000
FF00FFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FF
00FF00FFFF000000FFFFFF00FFFFFFFFFF00FFFFFF000000FFFF00FF00FF00FFFFFFFFFF
FFFF00FFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF00FFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF000000FFFFFFFFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFF00FFFF0000000000FFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FF000000FF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FF000000FFFF
FFFF00FFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFF00FFFFFFFF000000FF00
00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF00
0000FFFFFF00FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFF00FFFFFF000000FFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFF
FFFFFFFFFFFF0000FFFF0000FFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFF0000FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FF
FF0000FFFFFFFF00FFFF00FFFFFFFFFFFFFF00FFFF00FFFFFFFF0000FFFF00FFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFF00FFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
00FFFF000000FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF000000FFFF00FFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FF0000FFFF00FFFF000000FFFFFFFFFFFFFF000000FFFF00FFFF0000FFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFF0000FF0000FFFFFFFFFF0000FF0000FFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFF0000FF00FFFFFFFFFFFFFFFFFF00FF0000FFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF000000FFFFFF0000FFFFFFFFFF0000FFFFFF000000FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFF00FFFFFF00FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF0000000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{487.438, 978.438},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007W0003dR000`400?l00000o`00003oo`3AcJWX
0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX
0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX
0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX
0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX
0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@006P3AcJT0
0`000000oooo0?ooo`020?ooo`<0000000<0oooo000000000000103oool5000000030?ooo`000000
000000`0000000<0oooo0000000000000P0000060?ooo`@00000103oool00`000000oooo0=7=Z@0U
0=7=Z@<000001@3oool010000000oooo0?ooo`3oool2000000050?ooo`00000000000?ooo`000000
1@3oool00`000000oooo000000020?ooo`8000001@3oool00`000000oooo0?ooo`05000000<0oooo
00@000000?ooo`3oool0oooo100000000`3oool0dLfY0=7=Z@0U0=7=Z@<0000000D0oooo0000003o
ool0oooo000000080?ooo`<0000000<0oooo000000000000100000050?ooo`<0000000@0oooo0000
00000000oooo0`0000050?ooo`<0000000<0oooo0000003oool00`0000000`3oool0dLfY0=7=Z@0T
0=7=Z@<000001P3oool200000080oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`03
0?ooo`030000003oool0000000<0oooo0P0000030?ooo`040000003oool0000000000080oooo0P00
00001@3oool000000000003oool0000000@0oooo0`0000000`3oool0dLfY0=7=Z@1h0=7=Z@006P3A
cJT00`3oool000000?ooo`020?ooo`@000000`3oool00`000000oooo0?ooo`05000000030?ooo`00
0000000000`0000000<0oooo0000000000001P000000103oool000000?ooo`3oool3000000030?oo
o`000000oooo0080oooo9P3AcJT0103oool000000000003oool2000000H0oooo100000001P3oool0
0000000000000000oooo000000H0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo
0P0000030?ooo`@00000103oool010000000oooo0?ooo`0000020?ooobL0dLfY00<0oooo00000000
00000`3oool3000000<0oooo00@000000?ooo`3oool0oooo0P0000000`3oool00000000000040000
00L0oooo0P0000000`3oool000000?ooo`03000000040?ooo`000000oooo000000<0oooo0P000000
1@3oool000000?ooo`3oool000000080oooo9P3AcJT0103oool000000000003oool2000000H0oooo
00@000000?ooo`000000oooo0P0000030?ooo`800000103oool2000000030?ooo`000000oooo00<0
000000<0oooo0000003oool00P000000103oool000000000000000030?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0NP3AcJT001X0dLfY103oool010000000oooo0?ooo`3oool4
000000<0oooo1@0000000`3oool0000000000004000000030?ooo`000000000000D0000000<0oooo
0000000000000`0000060?ooo`040000003oool000000?ooo`8000000`3ooolV0=7=Z@<0oooo0P00
00000`3oool0000000000002000000030?ooo`0000000000008000001`3oool3000000<0oooo0P00
0000103oool000000000000000090?ooo`H000000`3oool010000000oooo0?ooo`3ooolW0=7=Z@<0
oooo0`0000001@3oool00000000000000000oooo008000000P3oool200000080oooo0P0000020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?oo
o`8000000`3oool200000080oooo00@000000?ooo`3oool0oooo9P3AcJT30?ooo`030000003oool0
oooo0080000000@0oooo0000003oool0oooo0P0000020?ooo`80000000<0oooo0000003oool00P00
00000`3oool000000?ooo`04000000<0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`040000
003oool00000000000<0oooo00D000000?ooo`000000oooo000000030?ooogX0dLfY000J0=7=Z@<0
oooo0P0000020?ooo`8000000P3oool010000000oooo0000003oool5000000030?ooo`0000000000
00D0000000@0oooo000000000000oooo0`0000000`3oool0000000000003000000<0oooo00<00000
0?ooo`0000000P0000000`3oool000000?ooo`040?ooobH0dLfY0`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`00000000000?ooo`02000000030?ooo`00
0000oooo00<0oooo00@000000?ooo`3oool00000103oool2000000<0oooo00H000000?ooo`3oool0
00000?ooo`00000;0?ooobL0dLfY0`3oool01P000000oooo0?ooo`3oool000000?ooo`80000000<0
oooo0000000000000P0000060?ooo`X0000000D0oooo000000000000oooo000000030?ooo`030000
003oool00000008000000`3oool010000000oooo0?ooo`0000040?ooobH0dLfY0`3oool4000000<0
oooo00<000000?ooo`3oool00`0000030?ooo`060000003oool000000000003oool00000103oool8
00000080oooo00@000000?ooo`00000000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00<0ooooNP3AcJT001X0dLfY103oool200000080oooo00<000000?ooo`0000000P000000
0`3oool0000000000004000000070?ooo`00000000000000003oool000000?ooo`0200000080oooo
100000000`3oool000000000000300000080oooo0P0000020?ooo`030000003oool0oooo00H0oooo
9P3AcJT40?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo000000030?ooo`@0
000000<0oooo0000003oool00P0000040?ooo`030000003oool0oooo00<0000000D0oooo00000000
0000oooo000000060?ooo`030000003oool0000000H0oooo9`3AcJT40?ooo`040000003oool00000
00000080oooo00D000000?ooo`00000000000?ooo`07000000030?ooo`000000oooo00<0oooo00<0
00000?ooo`3oool00`3oool3000000030?ooo`000000oooo0080oooo100000020?ooo`<000001@3o
oolV0=7=Z@@0oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`0300000080oooo00@0
00000?ooo`00000000000P3oool3000000030?ooo`00000000000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo0?ooo`80000000D0oooo000000000000oooo00000007
0?ooogX0dLfY000J0=7=Z@D0oooo00<000000?ooo`3oool00P3oool3000000040?ooo`0000000000
0?ooo`<0000000@0oooo00000000000000000`3oool8000000030?ooo`000000000000L00000103o
ool00`000000oooo0?ooo`040?ooobH0dLfY1@3oool700000080oooo00<000000?ooo`0000001@00
00050?ooo`050000003oool000000?ooo`0000000P3oool010000000oooo0?ooo`3oool200000003
0?ooo`000000000000D0oooo00<000000?ooo`3oool01@3ooolW0=7=Z@D0oooo0`0000020?ooo`03
0000003oool000000080oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo008000000P3oool3000000<0oooo0P0000060?ooobH0dLfY1@3oool00`000000
oooo00000002000000<0oooo00L000000?ooo`00000000000?ooo`000000oooo00@000000P3oool4
000000050?ooo`000000oooo0000003oool00`0000000`3oool000000000000200000080oooo1000
00070?ooogX0dLfY000J0=7=Z@H0oooo00@000000?ooo`3oool0oooo100000020?ooo`@0000000@0
oooo00000000000000000P3oool010000000oooo0000003oool5000000060?ooo`00000000000000
003oool000000P3oool3000000030?ooo`000000oooo00L0oooo9P3AcJT60?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02`3oool200000080oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`02000000X0oooo9`3AcJT60?ooo`8000000`3oool01@000000oooo0?ooo`3o
ool0000000P0oooo0`0000000`3oool000000?ooo`040?ooo`030000003oool0oooo0080oooo00H0
00000?ooo`00000000000?ooo`0000030?ooo`030000003oool0oooo00D0oooo9P3AcJT60?ooo`03
0000003oool000000080oooo0`0000000`3oool000000?ooo`030?ooo`@0000000H0oooo00000000
000000000?ooo`0000020?ooo`<00000103oool3000000030?ooo`000000000000<00000203ooomj
0=7=Z@006P3AcJT90?ooo`040000003oool0oooo0?ooo`L0000000L0oooo00000000000000000?oo
o`000000oooo008000000P3oool4000000040?ooo`0000000000000000<0oooo00@000000?ooo`00
0000oooo0P0000080?ooobH0dLfY2@3oool200000080oooo00<000000?ooo`3oool00P0000000`3o
ool00000000000020?ooo`<000002P3oool01@000000oooo000000000000oooo0080000000D0oooo
0000003oool0oooo000000080?ooobL0dLfY203oool3000000040?ooo`00000000000?ooo`L00000
0P3oool2000000<0oooo0`0000020?ooo`H000000P3oool2000000040?ooo`000000oooo000000P0
oooo9P3AcJT:0?ooo`80000000<0oooo0000003oool00P0000030?ooo`050000003oool000000?oo
o`0000000P3oool00`000000oooo0?ooo`0500000080oooo00<000000?ooo`0000000P3oool01P00
0000oooo0?ooo`000000oooo000000P0ooooNP3AcJT001X0dLfY203oool200000080oooo0P000002
0?ooo`@0000000<0oooo0000000000000`0000000`3oool00000000000020?ooo`050000003oool0
00000000003oool0100000001P3oool00000000000000000oooo000000X0oooo9P3AcJT80?ooo`04
0000003oool0oooo0?ooo`800000103oool01@000000oooo0?ooo`3oool000000080oooo1@000002
0?ooo`@0000000<0oooo0000003oool00P3oool01P000000oooo000000000000oooo000000T0oooo
9`3AcJT80?ooo`050000003oool0oooo0000003oool00P0000060?ooo`<0000000<0oooo0000003o
ool00`3oool4000000030?ooo`000000000000<0oooo0P0000040?ooo`030000003oool0oooo00L0
oooo9P3AcJT80?ooo`030000003oool0oooo0080000000@0oooo0000003oool0oooo0`0000001`3o
ool00000000000000000oooo0000003oool00`0000020?ooo`80000000<0oooo0000003oool00P00
00040?ooo`80000000<0oooo0000003oool0203ooomj0=7=Z@006P3AcJT90?ooo`8000000P3oool0
0`000000oooo00000004000000050?ooo`00000000000?ooo`0000000P3oool4000000050?ooo`00
000000000000003oool0100000020?ooo`030000003oool0oooo00/0oooo9P3AcJT90?ooo`060000
003oool0oooo0?ooo`000000oooo0`0000030?ooo`8000000P3oool00`000000oooo0?ooo`020?oo
o`@00000103oool00`000000oooo00000002000000030?ooo`000000000000X0oooo9`3AcJT90?oo
o`040000003oool0oooo000000D0oooo00D000000?ooo`3oool000000?ooo`02000000H0oooo0P00
00030?ooo`80000000<0oooo0000000000001@00000:0?ooobH0dLfY2@3oool01@000000oooo0000
003oool0000000@0oooo00H000000?ooo`000000oooo0000003oool3000000<0oooo100000030?oo
o`050000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`080?ooogX0dLfY000J0=7=
Z@X0oooo00<000000?ooo`3oool00P3oool5000000050?ooo`00000000000?ooo`0000000P3oool3
00000080oooo0`0000000`3oool0000000000002000000@0oooo00<000000?ooo`3oool02@3ooolV
0=7=Z@X0oooo1`0000001P3oool000000000003oool000000?ooo`80000000<0oooo000000000000
0P0000000`3oool000000?ooo`020?ooo`8000000P3oool00`000000oooo0?ooo`03000000/0oooo
9`3AcJT:0?ooo`<000000P3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3o
ool00`0000050?ooo`040000003oool0oooo0?ooo`80000000@0oooo00000000000000002`3ooolV
0=7=Z@X0oooo0`0000050?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P000000
0`3oool000000?ooo`020?ooo`80000000<0oooo0000003oool00`3oool3000000/0ooooNP3AcJT0
01X0dLfY2`3oool010000000oooo0?ooo`3oool5000000@0oooo1@0000020?ooo`80000000D0oooo
00000000000000000?ooo`03000000030?ooo`000000oooo00`0oooo9P3AcJT;0?ooo`8000000P3o
ool4000000040?ooo`000000000000000080oooo00@000000?ooo`3oool000000`3oool200000080
oooo0`0000040?ooo`030000003oool0oooo00X0oooo9`3AcJT;0?ooo`8000000P3oool200000003
0?ooo`000000oooo00<0oooo00<000000?ooo`3oool02P3oool2000000030?ooo`00000000000080
oooo00<000000?ooo`3oool02P3ooolV0=7=Z@/0oooo0P0000000`3oool00000000000020?ooo`05
0000003oool000000?ooo`0000000`3oool4000000<0oooo00H000000?ooo`000000oooo0000003o
ool200000080oooo00<000000?ooo`3oool02P3ooomj0=7=Z@006P3AcJT<0?ooo`030000003oool0
000000<0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<0000000@0oooo
0000003oool0oooo0P00000<0?ooobH0dLfY303oool2000000030?ooo`000000oooo0080oooo0P00
00050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool2000000030?ooo`00
0000oooo00/0oooo9`3AcJT<0?ooo`8000000`3oool00`000000oooo00000002000000030?ooo`00
000000000080000000<0oooo0000000000000P0000020?ooo`030000003oool00000008000000P3o
ool3000000`0oooo9P3AcJT<0?ooo`030000003oool00000008000000P3oool2000000040?ooo`00
000000000?ooo`D0000000<0oooo0000003oool00`0000030?ooo`<0000000<0oooo0000003oool0
2`3ooomj0=7=Z@006P3AcJT=0?ooo`8000000P3oool9000000040?ooo`000000oooo0?ooo`800000
00<0oooo0000003oool0100000000`3oool000000?ooo`0>0?ooobH0dLfY3@3oool010000000oooo
0?ooo`3oool2000000040?ooo`0000000000000000<0oooo00<000000?ooo`3oool0103oool30000
00030?ooo`00000000000140oooo9`3AcJT=0?ooo`030000003oool0oooo0080oooo0P0000000`3o
ool000000?ooo`03000000D0oooo0P0000001@3oool000000?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool0303ooolV0=7=Z@d0oooo10000000103oool000000?ooo`0000040?ooo`050000003o
ool000000?ooo`0000001@3oool300000080oooo00<000000?ooo`3oool03@3ooomj0=7=Z@006P3A
cJT>0?ooo`8000000P3oool300000080oooo0`000000103oool000000?ooo`3oool2000000<0oooo
0`00000B0?ooobH0dLfY3P3oool00`000000oooo0?ooo`03000000D0oooo100000000`3oool00000
0?ooo`040?ooo`040000003oool0000000000100oooo9`3AcJT>0?ooo`060000003oool000000000
003oool00000103oool2000000<0oooo100000020?ooo`80000000@0oooo00000000000000003`3o
oolV0=7=Z@h0oooo00<000000?ooo`0000000`0000020?ooo`060000003oool000000000003oool0
00000P3oool2000000040?ooo`000000oooo00000080oooo00<000000?ooo`3oool03`3ooomj0=7=
Z@006P3AcJT?0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`000000oooo000000020?oo
o`030000003oool0oooo0080000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`0>0?oo
obH0dLfY3`3oool3000000030?ooo`000000oooo00@0oooo0P0000070?ooo`8000000P3oool00`00
0000oooo0?ooo`0?0?ooobL0dLfY3`3oool300000080oooo00<000000?ooo`3oool00P0000000`3o
ool000000?ooo`02000000030?ooo`000000oooo00D0oooo0P00000@0?ooobH0dLfY3`3oool00`00
0000oooo0000000200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`<0000000@0oooo00000000000000004@3ooomj0=7=Z@006P3AcJT@0?ooo`040000003oool0oooo
0?ooo`<000000`3oool00`000000oooo0?ooo`05000000040?ooo`000000oooo00000180oooo9P3A
cJT@0?ooo`060000003oool0oooo0?ooo`000000oooo0P0000000`3oool000000?ooo`030?ooo`04
0000003oool0oooo000001H0oooo9`3AcJT@0?ooo`8000000P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool03`3ooolV0=7=ZA00oooo00<000000?oo
o`000000103oool2000000050?ooo`00000000000000003oool00P0000030?ooo`<000004P3ooomj
0=7=Z@006P3AcJTA0?ooo`040000003oool000000?ooo`8000001P3oool2000000030?ooo`000000
000000<0oooo0P00000A0?ooobH0dLfY4@3oool4000000030?ooo`000000oooo00P0oooo0P000000
0`3oool000000000000200000140oooo9`3AcJTA0?ooo`<0000000<0oooo0000000000000`000003
0?ooo`80000000<0oooo0000000000000P3oool300000140oooo9P3AcJTA0?ooo`<000001P3oool4
000000H0oooo0`00000A0?ooogX0dLfY000J0=7=ZA80oooo0P0000040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooobH0dLfY4P3oool01P00
0000oooo0?ooo`000000oooo000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0A0?ooobL0dLfY4P3oool00`000000oooo0?ooo`02000000030?ooo`000000000000@000000P3o
ool200000080oooo00<000000?ooo`3oool04@3ooolV0=7=ZA80oooo00<000000?ooo`3oool00P00
00001P3oool000000000003oool000000?ooo`80000000H0oooo00000000000000000?ooo`00000C
0?ooogX0dLfY000J0=7=ZA<0oooo0P00000:0?ooo`8000005`3ooolV0=7=ZA<0oooo00@000000?oo
o`3oool000000P3oool2000000<0oooo00<000000?ooo`3oool00`00000D0?ooobL0dLfY4`3oool0
1P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`0000000P3oool4000001@0oooo
9P3AcJTC0?ooo`090000003oool000000?ooo`000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooogX0dLfY000J0=7=ZA@0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0C0?ooobH0dLfY503oool300000080oooo0P0000050?oo
o`<000005@3ooolW0=7=ZA@0oooo0`000000103oool000000?ooo`0000040?ooo`@000005@3ooolV
0=7=ZA@0oooo0`0000030?ooo`<000000`3oool3000001D0ooooNP3AcJT001X0dLfY5@3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool05@3ooolV
0=7=ZAD0oooo0P0000001`3oool000000?ooo`3oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`0D0?ooobL0dLfY5@3oool200000080oooo0P0000060?ooo`030000003oool0oooo01@0oooo
9P3AcJTE0?ooo`80000000<0oooo000000000000103oool010000000oooo0?ooo`00000F0?ooogX0
dLfY000J0=7=ZAH0oooo00<000000?ooo`0000000P3oool4000000030?ooo`000000000001H0oooo
9P3AcJTF0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000001H0oooo
9`3AcJTF0?ooo`80000000<0oooo0000003oool00`3oool4000001H0oooo9P3AcJTF0?ooo`070000
003oool000000000003oool000000?ooo`03000000030?ooo`000000oooo01D0ooooNP3AcJT001X0
dLfY5`3oool200000080oooo0P0000000`3oool000000?ooo`0H0?ooobH0dLfY5`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo9`3AcJTG0?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`0F0?ooobH0dLfY5`3oool3000000050?ooo`000000oooo
0?ooo`0000006@3ooomj0=7=Z@006P3AcJTH0?ooo`D000006`3ooolV0=7=ZAP0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0H0?ooobL0dLfY603oool00`000000oooo000000020?oo
o`8000006@3ooolV0=7=ZAP0oooo00<000000?ooo`0000000P00000K0?ooogX0dLfY000J0=7=ZAT0
oooo00D000000?ooo`000000oooo0000000J0?ooobH0dLfY6@3oool2000000030?ooo`000000oooo
01X0oooo9`3AcJTI0?ooo`80000000<0oooo0000000000006P3ooolV0=7=ZAT0oooo00@000000?oo
o`00000000006`3ooomj0=7=Z@006P3AcJTL0?ooo`8000006P3ooolV0=7=ZAX0oooo0P0000000`3o
ool000000?ooo`0I0?ooobL0dLfY6P3oool010000000oooo0?ooo`00000J0?ooobH0dLfY6P3oool0
10000000oooo0?ooo`00000J0?ooogX0dLfY000J0=7=ZA/0oooo0P00000K0?ooobH0dLfY6`3oool2
000001/0oooo9`3AcJTK0?ooo`8000006`3ooolV0=7=ZA/0oooo0P00000K0?ooogX0dLfY003o0=7=
ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY000@0=7=
Z@A000000`3AcJT2@00000<0dLfY1D0000020=7=Z@9000000`3AcJT4@00000<0dLfY0T0000040=7=
Z@900000103AcJT2@00000D0dLfY0d0000000`3AcJU00000@0000003@0000080dLfY0T0000050=7=
Z@04@000003AcJT0dLfY0=7=Z@=000004`3AcJT4@00000<0dLfY0T0000030=7=Z@A000000P3AcJT3
@00000D0dLfY0d0000020=7=Z@9000000`3AcJT5@0000080dLfY0T0000030=7=Z@=000001@3AcJT0
14000000dLfY0=7=Z@3AcJT4@00000<0dLfY0T0000050=7=Z@=000004P3AcJT4@00000<0dLfY0T00
00040=7=Z@900000103AcJT2@00000<0dLfY140000020=7=Z@A00000103AcJT00d000000dLfY0=7=
Z@020=7=Z@900000103AcJT2@00000<0dLfY1D0000030=7=Z@=0000000<0dLfY@000040000000T00
00040=7=Z@=000004@3AcJT4@00000<0dLfY0T0000050=7=Z@=0000000<0dLfY@000040000000d00
00030=7=Z@=000000`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=0
00000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY0=7=Z@E00000
0P3AcJT2@00000D0dLfY0d00001_0=7=Z@00403AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003A
cJT0dLfY@00000@0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@000
00D0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003A
cJT0dLfY@00000D0dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=
Z@3AcJT0403AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@0000080dLfY00=00000
0=7=Z@3AcJT01@3AcJT00d000000dLfY0=7=Z@040=7=Z@04@000003AcJT0dLfY@0000080dLfY00=0
00000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU0
00000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000001@3AcJT01400
0000dLfY0=7=ZD0000050=7=Z@03@000003AcJT0dLfY0140dLfY00=000000=7=Z@3AcJT00`3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU0
00000P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00D0dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT0
0d000000dLfY0=7=Z@040=7=Z@04@000003AcJT0dLfY@00000P0dLfY00=000000=7=Z@3AcJT0403A
cJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@00000D0dLfY00=000000=7=Z@3AcJT0
0P3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0
0`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0
0`3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000
dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY06h0dLfY000A0=7=Z@03@000003AcJT0dLfY00D0dLfY
00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00E000000=7=Z@3A
cJT0dLfY@00000040=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000103A
cJT014000000dLfY0=7=Z@3AcJT5@00000<0dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY
0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0A0=7=Z@03
@000003AcJT0dLfY00D0dLfY00E000000=7=Z@3AcJT0dLfY@00000050=7=Z@=000000P3AcJT5@000
00@0dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A00000
0=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY00=0
00000=7=Z@3AcJT01@3AcJT00d000000dLfY0=7=Z@05@00001<0dLfY00=000000=7=Z@3AcJT01@3A
cJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT01D000000dLfY
0=7=Z@3AcJU0000000D0dLfY00=000000=7=Z@3AcJT0103AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY
0=7=Z@E000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@E000004P3AcJT00d000000dLfY0=7=Z@05
0=7=Z@03@000003AcJT0dLfY00E000000`3AcJT014000000dLfY0=7=Z@3AcJT5@00000<0dLfY00=0
00000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=0
00000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD000000
0P3AcJT00d000000dLfY0=7=Z@05@00006l0dLfY000B0=7=Z@03@000003AcJT0dLfY0080dLfY0T00
00050=7=Z@03@000003AcJT0dLfY0080dLfY0T0000050=7=Z@05@000003AcJT0dLfY0=7=ZD000000
0P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3A
cJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY0T0000060=7=
Z@03@000003AcJT0dLfY00=000005@3AcJT00d000000dLfY0=7=Z@020=7=Z@9000001@3AcJT01D00
0000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=
Z@3AcJT2@00000D0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY00=0
00001P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY0T0000030=7=Z@04
@000003AcJT0dLfY@00001D0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000H0dLfY00A000000=7=
Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00<0dLfY00=00000
0=7=Z@3AcJT0103AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY0=7=Z@900000
1@3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000
dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT04P3AcJT00d000000dLfY0=7=Z@020=7=
Z@9000000`3AcJT014000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3A
cJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3A
cJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3A
cJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000
dLfY0=7=Z@1^0=7=Z@00403AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00@0
dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A00000
0=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080
dLfY00M000000=7=Z@3AcJT0dLfY@000003AcJU0000000@0dLfY00=000000=7=Z@3AcJT00P3AcJT0
0d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT04P3A
cJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU0
00000P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJU0000000<0dLfY00=000000=7=
Z@3AcJT0103AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00E000000=7=Z@3AcJT0dLfY@000
00040=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000
dLfY0=7=Z@030=7=Z@03@000003AcJU0000001<0dLfY00A000000=7=Z@3AcJU000000`3AcJT00d00
0000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3A
cJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3A
cJU000000P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00@0dLfY00=00000
0=7=Z@3AcJT00P3AcJT00d000000dLfY@00000020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=0
00000=7=ZD0000004P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00<0dLfY
00=000000=7=ZD000000103AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJU000000080dLfY
00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@05@000
003AcJT0dLfY0=7=ZD0000000P3AcJT01d000000dLfY0=7=Z@3AcJU000000=7=ZD000000L03AcJT0
0140dLfY0T0000040=7=Z@=000000`3AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@000
00@0dLfY0T0000040=7=Z@9000001@3AcJT2@00000<0dLfY0T0000040=7=Z@=000000P3AcJT4@000
00<0dLfY0d00000C0=7=Z@900000103AcJT3@00000<0dLfY0T0000040=7=Z@=00000103AcJT2@000
00<0dLfY0d0000030=7=Z@900000103AcJT2@00000@0dLfY0d0000020=7=Z@A000000`3AcJT2@000
00@0dLfY0d0000040=7=Z@900000503AcJT2@00000@0dLfY0d0000030=7=Z@900000103AcJT2@000
00@0dLfY0T0000040=7=Z@9000000`3AcJT4@00000<0dLfY0T0000040=7=Z@=000000`3AcJT2@000
00D0dLfY0T0000030=7=Z@9000001@3AcJT2@00001<0dLfY0T0000040=7=Z@=00000103AcJT2@000
00<0dLfY0T0000050=7=Z@9000000P3AcJT4@0000080dLfY140000020=7=Z@A000000P3AcJT4@000
0080dLfY140000030=7=Z@900000103AcJT2@00000D0dLfY0T00001`0=7=Z@00o`3AcJWX0=7=Z@00
o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00
o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@006P3AcJT200000080oooo00@000000?ooo`3oool00000103o
ool01P000000oooo0000003oool000000?ooo`<000000`3oool800000080oooo0`0000020?ooo`80
000000<0oooo0000000000000P0000020?ooo`040000003oool0000000000080oooo00<000000?oo
o`3AcJT09@3AcJT2000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool00`3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000001P3oool3000000D0oooo0P0000020?ooo`030000003o
ool0oooo00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0dLfY02H0dLfY
0P0000030?ooo`030000003oool0oooo00800000103oool00`000000oooo0000000200000080oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`050000003oool000000000003o
ool00P0000020?ooo`<000000P3oool01`000000oooo0?ooo`000000oooo0000003oool09P3AcJT0
1@000000oooo000000000000oooo00800000103oool2000000<0oooo0P0000020?ooo`@000000`3o
ool2000000@0oooo0`0000000`3oool00000000000030?ooo`8000000`3oool010000000oooo0000
003oool4000000030?ooo`3AcJT0dLfY02@0dLfY00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`0400000080oooo00@000000?ooo`3oool0oooo1@0000000`3oool000000?ooo`060?ooo`<0
000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`02000000030?ooo`00000000000080
00000P3oool3000000030?ooo`3AcJT0dLfY01T0dLfY000J0=7=Z@030?ooo`000000000000D0oooo
100000020?ooo`<000000P3oool00`000000oooo0000000:000000050?ooo`00000000000?ooo`00
00001@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<000000P3ooolV0=7=
Z@080?ooo`00000000000000003oool000000?ooo`0000020?ooo`80000000<0oooo0000003oool0
0P3oool2000000030?ooo`000000000000H0000000<0oooo000000000000100000030?ooo`030000
003oool0oooo00D0oooo0`0000020?ooo`<000000P3ooolW0=7=Z@040?ooo`000000oooo00000080
oooo1000000:0?ooo`040000003oool00000000000T0oooo00<000000?ooo`0000001@3oool20000
00<0oooo00<000000?ooo`0000000P3oool2000000<0oooo9P3AcJT01@3oool000000?ooo`3oool0
00000080oooo00D000000?ooo`3oool000000?ooo`02000000@0oooo100000020?ooo`8000000`3o
ool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000002000000030?ooo`00
00000000008000001@3ooolV0=7=Z@030?ooo`000000oooo00X0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`02000000L0oooo100000060?ooo`<000000`3oool00`000000oooo0?oo
o`060?oooa/0dLfY000J0=7=Z@<0oooo00<000000?ooo`3oool01P3oool500000080oooo00@00000
0?ooo`3oool0oooo2@0000030?ooo`<0000000<0oooo0000000000000P3oool5000000030?ooo`00
0000oooo008000000`3ooolV0=7=Z@<0oooo00<000000?ooo`0000000P0000030?ooo`8000000`3o
ool00`000000oooo00000002000000@0oooo0P0000000`3oool00000000000040?ooo`@000000`3o
ool3000000<0oooo0`0000000`3oool00000000000030?ooobL0dLfY1@3oool400000080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`03000000@0oooo00<000000?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`8000000`3oool00`000000oooo0?ooo`0300000080oooo
00@000000?ooo`3oool0oooo9P3AcJT80?ooo`030000003oool0oooo00<0oooo00@000000?ooo`00
000000002@3oool200000080oooo00<000000?ooo`3oool0103oool3000000/0oooo00@000000?oo
o`3oool0oooo9P3AcJT70?ooo`8000006@3oool00`000000oooo0?ooo`060?ooo`800000203oool0
10000000oooo0?ooo`3ooolK0=7=Z@006P3AcJT50?ooo`030000003oool0oooo00<0oooo0P000007
0?ooo`@000000P3oool01@000000oooo0?ooo`3oool000000080oooo0P0000000`3oool000000?oo
o`050?ooo`800000103oool3000000@0oooo9P3AcJT60?ooo`030000003oool00000008000000P3o
ool00`000000oooo0?ooo`02000000<0oooo0P000000103oool000000?ooo`0000030?ooo`@00000
00D0oooo0000003oool0oooo000000020?ooo`030000003oool0oooo00<00000103oool00`000000
oooo0?ooo`020?ooobL0dLfY0`3oool2000000@0oooo1@0000030?ooo`040000003oool0oooo0?oo
o`8000000P3oool01@000000oooo0?ooo`3oool000000080oooo100000020?ooo`050000003oool0
oooo0000003oool00P0000000`3oool000000?ooo`080?ooobH0dLfY0`3oool01P000000oooo0?oo
o`000000oooo000000<0oooo00H000000?ooo`00000000000?ooo`0000050?ooo`800000103oool0
0`000000oooo000000040?ooo`040000003oool000000?ooo`D0000000D0oooo000000000000oooo
000000060?ooobH0dLfY0`3oool00`000000oooo0?ooo`080?ooo`<0000000@0oooo0000003oool0
00000P3oool2000000030?ooo`000000oooo00<0oooo0`000000103oool000000000003oool20000
00040?ooo`0000000000000000<0oooo00<000000?ooo`0000001`3ooolK0=7=Z@006P3AcJT80?oo
o`030000003oool0oooo00D0oooo00H000000?ooo`3oool0oooo0000003oool3000000040?ooo`00
0000oooo0?ooo`<0000000<0oooo0000003oool00P00000<0?ooo`8000001@3ooolV0=7=Z@H0oooo
0P0000001@3oool000000?ooo`000000oooo00D000000P3oool010000000oooo0000003oool30000
0080oooo00@000000?ooo`3oool0oooo0`0000020?ooo`@000000P3oool00`000000oooo00000002
000000030?ooo`000000oooo00@0oooo9`3AcJT40?ooo`040000003oool00000000000P0oooo1000
00000`3oool00000000000020?ooo`030000003oool000000080000000@0oooo0000000000000000
0`3oool3000000L0oooo0P0000070?ooobH0dLfY103oool00`000000oooo0?ooo`060?ooo`040000
003oool0oooo000000<0oooo0P0000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool2000000@0oooo00<000000?ooo`3oool0203ooolV0=7=Z@@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000@0oooo00H000000?oo
o`3oool0oooo0000003oool200000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`00000:0?oooa/0dLfY000J0=7=Z@L0oooo00<000000?ooo`0000000`3oool01P000000oooo
0000003oool000000?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo000000020000
0080oooo1P0000050?ooo`030000003oool0oooo00<000001P3ooolV0=7=Z@T0oooo0`0000000`3o
ool00000000000030?ooo`030000003oool0000000@000000P3oool7000000030?ooo`000000oooo
00<0oooo0P0000020?ooo`<000000P3oool00`000000oooo0?ooo`040?ooobL0dLfY1@3oool40000
00030?ooo`000000oooo008000000P3oool4000000<0oooo0P0000020?ooo`H000000P3oool01000
0000oooo0?ooo`0000020?ooo`@0000000<0oooo0000000000000P0000060?ooobH0dLfY1@3oool0
10000000oooo0000000000080?ooo`H000000P3oool010000000oooo0?ooo`3oool2000000030?oo
o`00000000000080000000<0oooo0000000000001`3oool4000000H0oooo9P3AcJT50?ooo`<00000
00<0oooo0000000000003P3oool00`000000oooo0?ooo`0300000080oooo00<000000?ooo`3oool0
203oool2000000050?ooo`00000000000?ooo`0000001P3ooolK0=7=Z@006P3AcJT70?ooo`@00000
00@0oooo0000003oool0oooo0`0000000`3oool00000000000060?ooo`8000001@3oool200000080
oooo00@000000?ooo`3oool0oooo100000020?ooo`030000003oool0oooo00D0oooo9P3AcJT70?oo
o`030000003oool0000000<0oooo00<000000?ooo`000000103oool00`000000oooo000000040?oo
o`8000000`3oool4000000@0oooo00<000000?ooo`0000000P3oool2000000030?ooo`000000oooo
00H0oooo9`3AcJT60?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P0000000`3o
ool0000000000002000000<0oooo00<000000?ooo`0000001@0000020?ooo`<0000000@0oooo0000
0000000000001P3oool00`000000oooo0?ooo`060?ooobH0dLfY1P3oool01P000000oooo0?ooo`00
0000oooo00000080oooo0P0000060?ooo`030000003oool0oooo0080000000H0oooo0000003oool0
oooo0000003oool2000000@0oooo0P0000000`3oool000000?ooo`02000000X0oooo9P3AcJT<0?oo
o`80000000<0oooo0000003oool0103oool010000000oooo0000000000020?ooo`030000003oool0
oooo00D000000`3oool5000000<0oooo00@000000?ooo`3oool000001`3ooolK0=7=Z@006P3AcJT8
0?ooo`<000000P3oool5000000P0oooo0`0000060?ooo`D000000P3oool010000000oooo0?ooo`00
000:0?ooobH0dLfY203oool00`000000oooo0?ooo`020?ooo`<000001P3oool01@000000oooo0000
00000000oooo008000000`3oool200000080oooo0P0000020?ooo`<0000000<0oooo0000003oool0
2P3ooolW0=7=Z@d0oooo00@000000?ooo`3oool0oooo1P0000020?ooo`H000000P3oool7000000D0
oooo00<000000?ooo`000000203ooolV0=7=Z@l0oooo00P000000?ooo`000000oooo0000003oool0
00000?ooo`800000103oool4000000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooobH0dLfY3@3oool2000000@0oooo00@000000?ooo`00000000000`3oool01@000000oooo
0?ooo`3oool0000000@0oooo0`0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3ooolK0=7=Z@006P3AcJT80?ooo`<0000000<0oooo0000003oool01`3oool5000000030?oo
o`000000oooo00T0000000<0oooo000000000000100000000`3oool000000?ooo`080?ooobH0dLfY
203oool3000000@0oooo0`0000001P3oool00000000000000000oooo00000080oooo00H000000?oo
o`00000000000?ooo`0000020?ooo`8000000P3oool010000000oooo0?ooo`0000030?ooo`800000
2@3ooolW0=7=Z@P0oooo0`0000050?ooo`L0000000<0oooo0000003oool01@3oool8000000<0oooo
00@000000?ooo`3oool000002P3ooolV0=7=Z@P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0000000000040?ooo`@00000103oool400000080oooo0`0000020?ooo`80000000<0oooo
0000003oool02P3ooolV0=7=Z@P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0000000H0oooo0`00000G0?oooa/0dLfY000J0=7=Z@T0oooo0P0000020?oo
o`030000003oool0oooo008000000P3oool6000000040?ooo`000000oooo0?ooo`L0000000@0oooo
0000003oool0oooo0P0000020?ooo`030000003oool0oooo00P0oooo9P3AcJT90?ooo`80000000<0
oooo0000003oool00P3oool2000000<0oooo0P0000001@3oool000000?ooo`000000oooo00800000
00@0oooo0000000000000000103oool010000000oooo0?ooo`3oool2000000030?ooo`000000oooo
00T0oooo9`3AcJT90?ooo`030000003oool0oooo0080oooo0P0000000`3oool000000?ooo`050?oo
o`030000003oool0oooo0080000000<0oooo0000003oool0103oool01@000000oooo0000003oool0
000000l0oooo9P3AcJT90?ooo`030000003oool0oooo00/0oooo0P00000?0?ooo`030000003oool0
oooo00d0oooo9P3AcJT90?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3o
ool2000000030?ooo`000000000000@00000103oool00`000000oooo0?ooo`030?ooo`8000003P3o
oolK0=7=Z@006P3AcJT:0?ooo`800000103oool00`000000oooo0?ooo`07000000<0oooo2@000004
0?ooo`030000003oool0000000/0oooo9P3AcJT:0?ooo`<0000000@0oooo0000003oool000001`3o
ool2000000<0oooo0`0000030?ooo`050000003oool000000?ooo`0000000P3oool3000000/0oooo
9`3AcJT:0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo
0P000000103oool000000000003oool4000000<0oooo00H000000?ooo`3oool000000?ooo`00000;
0?ooobH0dLfY2P3oool01@000000oooo000000000000oooo00<0000000D0oooo0000003oool0oooo
000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`04000000/0oooo9P3AcJT:0?ooo`<000000`3oool2000000030?ooo`00000000000080oooo
0P0000000`3oool000000?ooo`02000000030?ooo`00000000000080oooo00<000000?ooo`000000
0P0000030?ooo`030000003oool0000000/0oooo6`3AcJT001X0dLfY2`3oool2000000<0oooo00<0
00000?ooo`000000200000020?ooo`T000000P3oool010000000oooo00000000000<0?ooobH0dLfY
2`3oool2000000040?ooo`0000000000000000@0oooo00@000000?ooo`00000000001@3oool00`00
0000oooo0?ooo`060?ooo`80000000<0oooo000000000000303ooolW0=7=Z@/0oooo00<000000?oo
o`0000000P3oool3000000030?ooo`000000oooo008000000P3oool3000000<0oooo1@000000103o
ool000000?ooo`3oool2000000d0oooo9P3AcJT;0?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo0P00
000?0?ooobH0dLfY5`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?oooa/0dLfY000J0=7=Z@h0oooo00<00000
0?ooo`3oool02P3oool2000000/0oooo0`00000=0?ooobH0dLfY3`3oool00`000000oooo00000004
000000030?ooo`000000oooo00H0oooo00@000000?ooo`3oool0oooo100000030?ooo`030000003o
ool0oooo00/0oooo9`3AcJT<0?ooo`<0000000@0oooo000000000000oooo0`0000020?ooo`800000
0`3oool00`000000oooo0?ooo`020?ooo`80000000D0oooo00000000000000000?ooo`03000000`0
oooo9P3AcJT<0?ooo`040000003oool00000000001P0oooo1000000<0?ooobH0dLfY303oool01000
0000oooo0000003oool3000000<0oooo0P000000103oool000000000000000020?ooo`800000203o
ool010000000oooo00000000000=0?oooa/0dLfY000J0=7=ZA40oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`060?ooo`040000003oool00000000000h0oooo9P3AcJT?0?ooo`800000
00@0oooo0000003oool0oooo0`0000030?ooo`040000003oool0oooo0?ooo`D0000000H0oooo0000
003oool000000?ooo`00000>0?ooobL0dLfY3@3oool2000000@0oooo10000000103oool000000?oo
o`3oool2000000@0oooo00@000000?ooo`3oool000004`3ooolV0=7=Z@d0oooo00D000000?ooo`3o
ool000000?ooo`020000000<0?ooo`00000000000?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0`0000020?ooo`030000003oool000000100oooo9P3AcJT=0?ooo`030000003oool0oooo
00<0oooo0P0000000`3oool000000?ooo`020?ooo`8000001P3oool2000000040?ooo`000000oooo
00000140oooo6`3AcJT001X0dLfY403oool00`000000oooo000000070?ooo`080000003oool00000
0?ooo`000000oooo0000003oool2000000<0oooo0P00000?0?ooobH0dLfY4P3oool4000000040?oo
o`00000000000?ooo`800000103oool00`000000oooo0?ooo`0300000080oooo00<000000?ooo`3o
ool03@3ooolW0=7=Z@h0oooo00@000000?ooo`00000000001@3oool3000000060?ooo`000000oooo
0000003oool000001@3oool200000140oooo9P3AcJT>0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000005P3ooolV0=7=Z@h0
oooo00<000000?ooo`3oool00`3oool3000000D0oooo0`00000J0?oooa/0dLfY000J0=7=ZA40oooo
0`0000000`3oool00000000000020?ooo`8000000P3oool8000000030?ooo`00000000000100oooo
9P3AcJTB0?ooo`030000003oool0oooo008000002@3oool200000080oooo0P0000000`3oool00000
0?ooo`0?0?ooobL0dLfY3`3oool4000000040?ooo`000000oooo000000@0oooo00@000000?ooo`3o
ool0oooo100000000`3oool000000000000200000100oooo9P3AcJT?0?ooo`040000003oool00000
000000@0oooo0P0000001@3oool00000000000000000oooo00<000000`3oool400000100oooo9P3A
cJT@0?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo000000020?ooo`80000000<0
oooo0000003oool01P0000000`3oool000000?ooo`0?0?oooa/0dLfY000J0=7=ZA40oooo0`000000
0`3oool00000000000020?ooo`<0000000<0oooo0000003oool00`0000020?ooo`030000003oool0
00000140oooo9P3AcJTA0?ooo`040000003oool0oooo0?ooo`80000000@0oooo0000003oool00000
1P3oool00`000000oooo000000020?ooo`030000003oool0oooo00l0oooo9`3AcJT@0?ooo`030000
003oool0oooo0080oooo0P000000103oool000000000000000030?ooo`@000000`3oool00`000000
oooo0?ooo`0@0?ooobH0dLfY403oool01@000000oooo0?ooo`000000oooo00800000103oool01000
0000oooo0000000000020?ooo`<00000503ooolV0=7=ZA@0oooo00<000000?ooo`0000000`3oool2
000000/0oooo00<000000?ooo`3oool03`3ooolK0=7=Z@006P3AcJTA0?ooo`<0000000H0oooo0000
003oool000000?ooo`0000030?ooo`050000003oool000000000003oool00P0000000`3oool00000
0000000A0?ooobH0dLfY4@3oool3000000<0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`80
00000`3oool300000140oooo9`3AcJTA0?ooo`<0000000@0oooo00000000000000000`3oool01@00
0000oooo0?ooo`000000oooo00@0000000<0oooo0000000000004@3ooolV0=7=ZA40oooo00D00000
0?ooo`00000000000?ooo`02000000<0oooo0P0000001P3oool000000000003oool000000?ooo`@0
00004@3ooolV0=7=ZA40oooo00<000000?ooo`0000000`3oool2000000@0oooo1@0000020?ooo`<0
00004P3ooolK0=7=Z@006P3AcJTB0?ooo`80000000<0oooo0000000000000`3oool00`000000oooo
000000030?ooo`8000000P3oool00`000000oooo0?ooo`0A0?ooobH0dLfY4P3oool2000000030?oo
o`000000oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000C0?ooobL0dLfY
4P3oool300000080oooo00<000000?ooo`0000000`3oool3000000<0oooo00<000000?ooo`3oool0
4P3ooolV0=7=ZA80oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000020?oo
o`030000003oool0000001D0oooo9P3AcJTB0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool05`3ooolK0=7=Z@006P3AcJTC0?ooo`<00000103oool010000000oooo0000000000050?oo
o`030000003oool0oooo0180oooo9P3AcJTC0?ooo`<0000000<0oooo0000003oool00P0000070?oo
o`800000503ooolW0=7=ZA<0oooo00<000000?ooo`3oool00P3oool3000000030?ooo`0000000000
00800000603ooolV0=7=ZA<0oooo00<000000?ooo`3oool01@3oool2000001/0oooo9P3AcJTH0?oo
o`H000000P3oool01@000000oooo0?ooo`3oool0000001@0oooo6`3AcJT001X0dLfY503oool20000
00<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000E0?ooobH0dLfY503oool2
000000050?ooo`00000000000000003oool01@0000020?ooo`030000003oool0oooo01<0oooo9`3A
cJTD0?ooo`8000001P3oool200000080oooo00<000000?ooo`0000005@3ooolV0=7=ZA@0oooo00D0
00000?ooo`00000000000?ooo`0200000080oooo00<000000?ooo`0000000`00000E0?ooobH0dLfY
5@3oool2000000<0oooo00@000000?ooo`00000000000`3oool00`000000oooo0000000E0?oooa/0
dLfY000J0=7=ZAD0oooo0P0000000`3oool00000000000050?ooo`<000005P3ooolV0=7=ZAD0oooo
0`0000070?ooo`<000005P3ooolW0=7=ZAD0oooo00D000000?ooo`000000oooo000000030?ooo`04
0000003oool00000000001L0oooo9P3AcJTE0?ooo`040000003oool0oooo00000080oooo0P000000
0`3oool000000?ooo`0H0?ooobH0dLfY703oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01@0oooo6`3AcJT001X0dLfY6P3oool4000000030?ooo`000000000001L0oooo9P3AcJTH0?oo
o`D0000000@0oooo0000003oool000005`3ooolW0=7=ZAH0oooo0`0000020?ooo`040000003oool0
oooo0?ooo`<000005P3ooolV0=7=ZAH0oooo00<000000?ooo`000000100000000`3oool000000000
0002000001H0oooo9P3AcJTF0?ooo`040000003oool000000?ooo`8000000P3oool4000001L0oooo
6`3AcJT001X0dLfY6@3oool01@000000oooo000000000000oooo00800000603ooolV0=7=ZAl0oooo
00<000000?ooo`3oool05P3ooolW0=7=ZAL0oooo0P0000020?ooo`030000003oool0oooo01X0oooo
9P3AcJTG0?ooo`030000003oool0oooo0080oooo0P00000J0?ooobH0dLfY5`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01T0oooo6`3AcJT001X0dLfY6`3oool4000001T0oooo9P3A
cJTJ0?ooo`050000003oool000000?ooo`0000006@3ooolW0=7=ZAP0oooo00<000000?ooo`000000
0P00000K0?ooobH0dLfY603oool00`000000oooo0?ooo`0M0?ooobH0dLfY7`3oool00`000000oooo
0?ooo`0G0?oooa/0dLfY000J0=7=ZA/0oooo0`00000J0?ooobH0dLfY7@3oool00`000000oooo0?oo
o`0H0?ooobL0dLfY6@3oool5000001X0oooo9P3AcJTI0?ooo`030000003oool0oooo008000006P3o
oolV0=7=ZAX0oooo0`0000000`3oool000000?ooo`0I0?oooa/0dLfY000J0=7=ZAX0oooo00@00000
0?ooo`00000000006P3ooolV0=7=ZAX0oooo1000000J0?ooobL0dLfY7@3oool00`000000oooo0?oo
o`0H0?ooobH0dLfY7@3oool00`000000oooo0?ooo`0H0?ooobH0dLfY6P3oool00`000000oooo0?oo
o`0L0?oooa/0dLfY000J0=7=ZA/0oooo0P00000K0?ooobH0dLfY6`3oool2000001/0oooo9`3AcJTK
0?ooo`8000006`3ooolV0=7=ZA/0oooo0P00000K0?ooobH0dLfY6`3oool2000001`0oooo6`3AcJT0
0?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT0
0100dLfY140000020=7=Z@A000000P3AcJT4@00000@0dLfY0d0000020=7=Z@9000000`3AcJT4@000
00<0dLfY0T0000040=7=Z@9000001@3AcJT014000000dLfY0=7=Z@3AcJT4@0000080dLfY1D000002
0=7=Z@9000000`3AcJT3@00001<0dLfY140000020=7=Z@A000000P3AcJT4@00000@0dLfY0d000002
0=7=Z@9000000`3AcJT4@00000<0dLfY0T0000040=7=Z@9000000`3AcJT3@00000<0dLfY1D000002
0=7=Z@9000001@3AcJT014000000dLfY0=7=Z@3AcJT5@0000180dLfY140000030=7=Z@9000000`3A
cJT5@0000080dLfY0T0000030=7=Z@A000000`3AcJT2@00000@0dLfY0T0000040=7=Z@900000103A
cJT2@00000<0dLfY140000020=7=Z@E000000P3AcJT2@00000@0dLfY0T00000C0=7=Z@A000000`3A
cJT2@00000<0dLfY1D0000020=7=Z@9000000`3AcJT4@00000<0dLfY0T0000040=7=Z@900000103A
cJT2@00000<0dLfY140000020=7=Z@E000000P3AcJT2@00000<0dLfY0d0000040=7=Z@9000004`3A
cJT4@00000<0dLfY0T0000030=7=Z@E000000P3AcJT2@00000<0dLfY140000030=7=Z@900000103A
cJT2@00000@0dLfY0T0000050=7=Z@=0000000<0dLfY@000040000000d0000020=7=Z@9000001@3A
cJT00d000000dLfY0=7=Z@020=7=Z@9000004`3AcJT00100dLfY00=000000=7=Z@3AcJT00`3AcJT0
0d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00H0dLfY00A000000=7=Z@3AcJU000000P3A
cJT014000000dLfY0=7=ZD0000050=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3A
cJU00000103AcJT01D000000dLfY0=7=Z@3AcJU0000000L0dLfY00E000000=7=Z@3AcJT0dLfY@000
00020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT04@3AcJT00d000000dLfY0=7=
Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT01P3AcJT014000000dLfY0=7=
ZD0000020=7=Z@04@000003AcJT0dLfY@00000D0dLfY00A000000=7=Z@3AcJU000000P3AcJT01400
0000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@000
00020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=
Z@0B0=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU00000103AcJT01D000000dLfY
0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000001@3AcJT014000000dLfY0=7=ZD000002
0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00D0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=
Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0403AcJT00d000000dLfY0=7=Z@03
0=7=Z@04@000003AcJT0dLfY@00000@0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000
003AcJT0dLfY@00000D0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD000002
0=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT01@3AcJT01D000000dLfY0=7=
Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=
Z@03@000003AcJT0dLfY0100dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD000004
0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000050=7=Z@04@000
003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD000005
0=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003A
cJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0100dLfY
000A0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=
Z@020=7=Z@E00000103AcJT01D000000dLfY0=7=Z@3AcJU0000000@0dLfY00A000000=7=Z@3AcJU0
00001@3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3A
cJT0103AcJT00d000000dLfY0=7=Z@040=7=Z@04@000003AcJT0dLfY0=7=Z@=000004`3AcJT00d00
0000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT5@000
00@0dLfY00E000000=7=Z@3AcJT0dLfY@00000040=7=Z@04@000003AcJT0dLfY@00000D0dLfY00A0
00000=7=Z@3AcJT0dLfY0d0000040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000
dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT04`3AcJT00d000000
dLfY0=7=Z@050=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=
Z@05@000003AcJT0dLfY0=7=ZD000000103AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003A
cJT0dLfY@00000@0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@05@000003AcJT0dLfY0=7=
ZD0000001P3AcJT00d000000dLfY0=7=Z@040=7=Z@04@000003AcJT0dLfY@0000080dLfY00=00000
0=7=Z@3AcJT04@3AcJT00d000000dLfY0=7=Z@050=7=Z@03@000003AcJT0dLfY0080dLfY00E00000
0=7=Z@3AcJT0dLfY@00000020=7=Z@05@000003AcJT0dLfY0=7=ZD000000103AcJT014000000dLfY
0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT00P3AcJT00d00
0000dLfY0=7=Z@040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD00
00020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT04P3AcJT00d000000dLfY0=7=
Z@050=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@05@000
003AcJT0dLfY0=7=ZD000000103AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@00000@0dLfY00A000000=7=Z@3AcJT0dLfY1D0000030=7=Z@03@000003AcJT0dLfY00@0dLfY00=0
00000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY0100dLfY000B
0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3A
cJU000000080dLfY00A000000=7=Z@3AcJT0dLfY0T0000050=7=Z@05@000003AcJT0dLfY0=7=ZD00
00000P3AcJT014000000dLfY0=7=Z@3AcJT2@00000H0dLfY00=000000=7=Z@3AcJT00P3AcJT00d00
0000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY0T0000030=7=Z@04@000003AcJT0dLfY
@00001@0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0
dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=Z@3AcJT2@00000D0dLfY00E000000=7=Z@3AcJT0
dLfY@00000020=7=Z@04@000003AcJT0dLfY0=7=Z@9000000`3AcJT014000000dLfY0=7=ZD000004
0=7=Z@03@000003AcJT0dLfY0080dLfY0T0000060=7=Z@03@000003AcJT0dLfY0080dLfY00=00000
0=7=Z@3AcJT0503AcJT00d000000dLfY0=7=Z@020=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@02
0=7=Z@9000001@3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU00000
0P3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3A
cJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY0T0000030=7=Z@04
@000003AcJT0dLfY@00001@0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000D0dLfY00=000000=7=
Z@3AcJT00P3AcJT2@00000D0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0
dLfY@0000080dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003A
cJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000<0dLfY0d0000060=7=Z@03@000003A
cJT0dLfY0180dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000D0dLfY00=000000=7=Z@3AcJT00P3A
cJT2@00000D0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080
dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY
0080dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000H0dLfY00A000000=7=Z@3AcJT0dLfY0T00000C
0=7=Z@00403AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A0
00000=7=Z@3AcJU000000`3AcJT00d000000dLfY@00000030=7=Z@03@000003AcJT0dLfY0080dLfY
00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY
0080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003A
cJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD00000B0=7=Z@04@000
003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD000003
0=7=Z@03@000003AcJU0000000<0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD00
00020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY
0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD000002
0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT04P3AcJT014000000dLfY0=7=ZD00
00030=7=Z@03@000003AcJT0dLfY00@0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000
003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD000002
0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000
dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@0000180dLfY00A000000=7=Z@3AcJU000000`3AcJT0
0d000000dLfY0=7=Z@040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=
ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3A
cJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00E000000=7=Z@3AcJT0dLfY@00000040=7=Z@04
@000003AcJT0dLfY@0000180dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@04
0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000
003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD000002
0=7=Z@07@000003AcJT0dLfY0=7=ZD000000dLfY@00000040=7=Z@03@000003AcJT0dLfY0080dLfY
00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY0180
dLfY000A0=7=Z@900000103AcJT2@00000@0dLfY0T0000050=7=Z@9000000`3AcJT3@00000<0dLfY
0T0000040=7=Z@900000103AcJT3@0000080dLfY140000030=7=Z@900000103AcJT2@00000@0dLfY
0d0000030=7=Z@=000004`3AcJT2@00000@0dLfY0T0000040=7=Z@9000001@3AcJT2@00000<0dLfY
0d0000030=7=Z@900000103AcJT2@00000@0dLfY0d0000030=7=Z@=000000`3AcJT2@00000@0dLfY
0T0000030=7=Z@A000000`3AcJT2@00001D0dLfY0T0000040=7=Z@=000000`3AcJT2@00000@0dLfY
0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY
0T0000040=7=Z@900000103AcJT3@00000<0dLfY0T00000D0=7=Z@900000103AcJT3@00000<0dLfY
0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY
0T0000040=7=Z@900000103AcJT2@00000@0dLfY0d0000030=7=Z@900000503AcJT2@00000@0dLfY
0d0000030=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY
0T0000050=7=Z@9000000`3AcJT2@00000@0dLfY0d0000020=7=Z@A000000`3AcJT3@0000180dLfY
003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY
003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY000J0=7=Z@8000000`3oool00`000000
oooo00000003000000090?ooo`000000oooo0000003oool000000?ooo`000000oooo00<000000`3o
ool00`000000oooo0?ooo`020?ooo`<000000`3oool02P000000oooo0000003oool000000?ooo`00
0000oooo0000003oool4000000<0oooo00<000000?ooo`3AcJT09@3AcJT00`000000oooo0?ooo`03
0?ooo`800000103oool00`000000oooo000000040?ooo`D000001P3oool6000000@0oooo10000002
0?ooo`L0000000<0oooo0000003oool09`3AcJT200000080oooo00@000000?ooo`00000000000P3o
ool00`000000oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool01`3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0400000003
0?ooo`000000oooo00@0oooo00<000000?ooo`3AcJT09@3AcJT2000000L0oooo00@000000?ooo`00
000000000P3oool300000080oooo0`0000001@3oool000000?ooo`3oool0000000@0oooo10000000
0`3oool0000000000002000000030?ooo`00000000000080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0=7=Z@0U0=7=Z@030000003oool0oooo00800000203oool00`000000oooo0?ooo`02
0?ooo`8000000`3oool00`000000oooo00000002000000030?ooo`000000000000@0oooo0`000000
1@3oool000000?ooo`3oool0000000H0oooo00<000000?ooo`0000000P0000000`3oool000000?oo
o`0K0=7=Z@006P3AcJT01@3oool000000000003oool0000000<0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0000000000030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00P3oool2000000030?ooo`000000000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`040000003oool0000000000080oooo9P3AcJT01`3oool00000000000000000oooo0000003oool0
0P0000030?ooo`8000000P3oool00`000000oooo00000006000000@0oooo00<000000?ooo`000000
100000050?ooo`030000003oool0000000<0oooo1@000000103oool000000?ooo`3ooolW0=7=Z@03
0?ooo`0000000000008000001P3oool3000000030?ooo`00000000000080oooo0P0000000`3oool0
00000?ooo`02000000040?ooo`00000000000?ooo`80000000@0oooo0000003oool00000103oool0
0`000000oooo00000002000000@0oooo0P0000000`3oool00000000000020?ooobH0dLfY00D0oooo
000000000000oooo000000030?ooo`<000000`3oool5000000<0oooo0P0000000`3oool000000000
0002000000050?ooo`00000000000?ooo`0000000P3oool6000000<0oooo0`000000103oool00000
0?ooo`3oool200000080oooo9P3AcJT0103oool000000?ooo`0000040?ooo`8000002@3oool30000
00030?ooo`000000000000@0oooo100000000`3oool000000?ooo`02000000d0oooo00<000000?oo
o`3oool00`3ooolK0=7=Z@006P3AcJT30?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
0000203oool00`000000oooo0?ooo`0E0?ooo`<00000103oool2000000<0oooo9P3AcJT30?ooo`04
0000003oool0oooo0?ooo`<000000P3oool200000080oooo200000000`3oool000000?ooo`030?oo
o`D0000000D0oooo0000003oool000000?ooo`02000000030?ooo`00000000000080oooo10000000
0`3oool000000?ooo`020?ooobL0dLfY0`3oool00`000000oooo000000030?ooo`8000000P3oool0
0`000000oooo000000040?ooo`<000000`3oool8000000040?ooo`000000oooo00000080oooo0`00
00000`3oool00000000000040?ooo`<000000`3ooolV0=7=Z@<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000030?ooo`80000000D0oooo00000000000000000?ooo`03000000030?oo
o`000000000000<000000P3oool8000000040?ooo`00000000000?ooo`<000000`3oool3000000<0
oooo9P3AcJT30?ooo`040000003oool0oooo000000D0oooo1`0000020?ooo`040000003oool00000
0?ooo`80000000<0oooo0000003oool01@3oool2000000030?ooo`000000oooo0080000000<0oooo
000000000000103oool200000080oooo00@000000?ooo`3oool0oooo6`3AcJT001X0dLfY103oool0
0`000000oooo0?ooo`04000000050?ooo`000000oooo0000003oool00P0000020?ooo`80000000<0
oooo0000003oool01@3oool2000000H0oooo00L000000?ooo`3oool000000?ooo`000000oooo0080
000000<0oooo0000003oool01P3ooolV0=7=ZAT0oooo00@000000?ooo`0000000000203oool00`00
0000oooo0?ooo`0@0?ooobL0dLfY103oool01@000000oooo0000003oool0000000<0oooo0`000004
0?ooo`030000003oool0oooo00P0oooo0`0000001@3oool000000?ooo`3oool0000000<0oooo1000
00020?ooo`030000003oool0000000H0oooo9P3AcJT40?ooo`@000001@3oool010000000oooo0?oo
o`0000030?ooo`@0000000H0oooo000000000000oooo0000003oool5000000d0oooo00<000000?oo
o`0000001@3ooolV0=7=Z@D0oooo00<000000?ooo`3oool00P0000070?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool000000080oooo0P0000040?oooa/0dLfY000J0=7=Z@D0oooo00<000000?oo
o`3oool00P3oool2000000L0oooo00<000000?ooo`3oool00P0000050?ooo`030000003oool0oooo
00<000002@3oool010000000oooo0?ooo`0000080?ooobH0dLfY203oool2000000030?ooo`000000
oooo00<0oooo0P0000000`3oool000000?ooo`050?ooo`040000003oool00000000000P0oooo00<0
00000?ooo`3oool03`3ooolW0=7=Z@D0oooo00D000000?ooo`3oool000000?ooo`03000000040?oo
o`000000oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00@000000?ooo`000000oooo100000020?ooo`030000003oool0oooo
00@0oooo9P3AcJT50?ooo`050000003oool0oooo0000003oool00P0000020?ooo`@0000000<0oooo
0000003oool0100000020?ooo`80000000<0oooo0000000000000`0000000`3oool0000000000002
000000040?ooo`00000000000?ooo`@00000203ooolV0=7=Z@P0oooo0P0000040?ooo`8000002P3o
ool00`000000oooo0?ooo`060?ooo`800000103oool00`000000oooo000000030?ooo`030000003o
ool0oooo00L0oooo6`3AcJT001X0dLfY1P3oool00`000000oooo0?ooo`020?ooo`050000003oool0
00000000003oool00P0000000`3oool000000?ooo`020?ooo`050000003oool000000000003oool0
100000050?ooo`D000003P3ooolV0=7=ZA00oooo00@000000?ooo`3oool000001P3oool2000000P0
oooo0P00000B0?ooobL0dLfY1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`0000000P0000060?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo0000
00020?ooo`D000000P3oool00`000000oooo0?ooo`090?ooobH0dLfY1P3oool2000000030?ooo`00
0000oooo0080000000<0oooo0000003oool00P3oool4000000040?ooo`00000000000?ooo`@00000
00<0oooo0000003oool00P3oool3000000@0oooo100000020?ooo`030000003oool0oooo00D0oooo
9P3AcJT60?ooo`030000003oool000000080oooo00H000000?ooo`3oool000000?ooo`0000020?oo
o`80000000<0oooo0000003oool02@3oool01@000000oooo0000003oool0000000P0oooo00D00000
0?ooo`3oool0oooo000000060?oooa/0dLfY000J0=7=Z@X0oooo0P0000000`3oool000000?ooo`02
0?ooo`040000003oool00000000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool000000000003oool00P0000020?ooo`030000003oool0oooo0080000000<0oooo0000003o
ool01`3ooolV0=7=Z@X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`04
0000003oool00000000000P0oooo00<000000?ooo`3oool0403ooolW0=7=Z@T0oooo1`0000080?oo
o`80000000<0oooo0000003oool00P3oool2000000<0oooo00<000000?ooo`3oool0103oool30000
00030?ooo`000000oooo00L0oooo9P3AcJT:0?ooo`030000003oool0oooo0080oooo0P0000030?oo
o`030000003oool000000080oooo0P0000000`3oool000000?ooo`05000000@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo000000080?ooobH0dLfY203oool010000000oooo0000003oool3
000000030?ooo`0000000000008000000`3oool01P000000oooo0000003oool000000?ooo`<00000
00D0oooo0000003oool000000?ooo`02000000040?ooo`000000oooo0?ooo`<0000000<0oooo0000
003oool0203ooolK0=7=Z@006P3AcJT;0?ooo`<00000103oool200000080oooo0`0000040?ooo`80
00000P3oool00`000000oooo0?ooo`02000000@0oooo0P0000020?ooo`030000003oool0oooo00L0
oooo9P3AcJTA0?ooo`8000001`3oool010000000oooo0000000000050?ooo`040000003oool0oooo
00000140oooo9`3AcJT90?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`0300000080oooo0P0000030?ooo`090000003oool0oooo0?ooo`000000
oooo0000003oool0000000<0oooo00<000000?ooo`3oool01`3ooolV0=7=Z@T0oooo0`0000020?oo
o`80000000<0oooo0000003oool00P0000020?ooo`8000000P3oool2000000040?ooo`0000000000
00000080oooo1@0000020?ooo`030000003oool00000008000002@3ooolV0=7=Z@P0oooo0`000004
0?ooo`040000003oool0oooo000000H0oooo00@000000?ooo`00000000000P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`0000000P0000020?ooo`8000002P3ooolK0=7=Z@00
6P3AcJT80?ooo`80000000@0oooo00000000000000000`3oool3000000030?ooo`00000000000080
oooo0P0000020?ooo`030000003oool0oooo0080000000<0oooo0000000000000P0000020?ooo`@0
000000<0oooo0000003oool0203ooolV0=7=Z@P0oooo00<000000?ooo`0000000P0000020?ooo`80
00000`3oool00`000000oooo00000002000000@0oooo00<000000?ooo`0000000`0000040?ooo`D0
000000<0oooo0000000000002@3ooolW0=7=Z@P0oooo0P0000000`3oool000000?ooo`020?ooo`05
0000003oool000000000003oool00`0000050?ooo`030000003oool0oooo0080oooo0P0000030?oo
o`030000003oool0oooo0080000000@0oooo00000000000000002@3ooolV0=7=Z@P0oooo1@000005
0?ooo`<0000000<0oooo0000000000001@0000000`3oool0000000000005000000<0oooo00<00000
0?ooo`3oool00P0000000`3oool000000?ooo`080?ooobH0dLfY203oool00`000000oooo0?ooo`06
0?ooo`030000003oool000000080oooo0P0000020?ooo`030000003oool0oooo00L0oooo0P000005
0?ooo`800000303ooolK0=7=Z@006P3AcJT90?ooo`8000000`3oool010000000oooo000000000002
0?ooo`030000003oool0oooo00/0oooo0P0000020?ooo`@000000`3oool00`000000oooo0?ooo`08
0?ooobH0dLfY2@3oool00`000000oooo000000030?ooo`800000103oool3000000030?ooo`000000
oooo00<0oooo0P0000000`3oool00000000000020?ooo`030000003oool0000000<000000P3oool0
0`000000oooo0?ooo`080?ooobL0dLfY2@3oool400000080oooo0`0000000`3oool0000000000003
00000080oooo00H000000?ooo`3oool0oooo0000003oool400000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0000000:0?ooobH0dLfY2@3oool2000000X0oooo00@000000?ooo`000000
oooo1@0000020?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool0203ooolV0=7=Z@T0
oooo00<000000?ooo`3oool00P0000090?ooo`8000000P3oool2000000<0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0000003oool3000000030?ooo`000000oooo00T0oooo6`3AcJT001X0
dLfY2P3oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`0000000P0000000`3oool0
00000?ooo`020?ooo`060000003oool0oooo0000003oool000000`3oool300000080oooo00@00000
0?ooo`3oool000002`3ooolV0=7=Z@X0oooo00H000000?ooo`000000oooo0000003oool2000000@0
oooo0P0000060?ooo`D000000`3oool7000000/0oooo9`3AcJT:0?ooo`800000103oool00`000000
oooo0?ooo`070?ooo`040000003oool00000000000T0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`090?ooobH0dLfY2P3oool2000000040?ooo`000000oooo0?ooo`D000000P3oool2
00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`80000000D0oooo000000000000oooo
000000030?ooo`030000003oool0oooo00T0oooo9P3AcJT:0?ooo`030000003oool0000000@0oooo
0P0000020?ooo`80000000<0oooo0000003oool01P3oool00`000000oooo0?ooo`070?ooo`040000
003oool0oooo000000/0oooo6`3AcJT001X0dLfY2`3oool2000000D0oooo00<000000?ooo`3oool0
0P3oool3000000030?ooo`000000oooo0080oooo00D000000?ooo`3oool000000?ooo`02000000@0
oooo0P00000<0?ooobH0dLfY2`3oool2000000<0oooo0`0000030?ooo`<00000103oool00`000000
oooo0000000400000080oooo100000000`3oool000000?ooo`0;0?ooobL0dLfY2`3oool5000000P0
oooo0P00000=0?ooo`80000000<0oooo000000000000303ooolV0=7=Z@/0oooo0P0000040?ooo`03
0000003oool000000080oooo1`0000000`3oool000000000000200000080oooo0`0000020?ooo`<0
0000303ooolV0=7=Z@`0oooo00@000000?ooo`3oool000001P3oool01@000000oooo000000000000
oooo0080000000D0oooo00000000000000000?ooo`02000000@0oooo0P0000020?ooo`030000003o
ool0oooo00X0oooo6`3AcJT001X0dLfY3@3oool010000000oooo0?ooo`3oool3000000D0oooo00<0
00000?ooo`0000000`0000050?ooo`@00000403ooolV0=7=ZAX0oooo0P00000L0?ooobL0dLfY3@3o
ool010000000oooo0?ooo`3oool300000080oooo1@0000000`3oool000000?ooo`030?ooo`800000
0`3oool00`000000oooo0?ooo`0?0?ooobH0dLfY3@3oool3000000D0oooo100000000`3oool00000
00000002000000040?ooo`0000000000000000D0oooo00<000000?ooo`0000003P3ooolV0=7=Z@h0
oooo00<000000?ooo`3oool01@0000050?ooo`<000000`3oool01`000000oooo0000003oool00000
0?ooo`0000000P3oool2000000d0oooo6`3AcJT001X0dLfY3P3oool00`000000oooo000000020?oo
o`D000000P3oool2000000<0oooo00D000000?ooo`000000oooo0000000D0?ooobH0dLfY4@3oool2
000000030?ooo`000000oooo00<0oooo00@000000?ooo`00000000002@3oool00`000000oooo0?oo
o`0?0?ooobL0dLfY3P3oool00`000000oooo00000002000000<0oooo00<000000?ooo`3oool00`3o
ool3000000030?ooo`000000000000<0oooo0`00000@0?ooobH0dLfY3P3oool01@000000oooo0000
00000000oooo00800000103oool2000000030?ooo`000000oooo008000000`3oool400000140oooo
9P3AcJTA0?ooo`8000001P3oool2000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0@0?oooa/0dLfY000J0=7=Z@l0oooo00<000000?ooo`3oool00P3o
ool2000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000E0?ooobH0dLfY
6P3oool010000000oooo00000000000J0?ooobL0dLfY3`3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00P3oool200000080oooo00D000000?ooo`000000oooo00000003
0?ooo`030000003oool0oooo00h0oooo9P3AcJT?0?ooo`030000003oool0oooo0080000000<0oooo
0000003oool00P0000020?ooo`80000000D0oooo00000000000000000?ooo`0300000080oooo00<0
00000?ooo`3oool03P3ooolV0=7=Z@l0oooo00@000000?ooo`000000oooo0P0000000`3oool00000
0000000200000080oooo0P0000000`3oool00000000000040?ooo`050000003oool0oooo0?ooo`00
00003`3ooolK0=7=Z@006P3AcJT@0?ooo`030000003oool0oooo008000001@3oool00`000000oooo
00000002000000@0oooo0P00000C0?ooobH0dLfY4`3oool00`000000oooo0?ooo`040?ooo`800000
703ooolW0=7=ZA00oooo00@000000?ooo`3oool0oooo0P000000103oool000000?ooo`3oool40000
00D0oooo00<000000?ooo`3oool04P3ooolV0=7=ZA00oooo00D000000?ooo`3oool000000?ooo`04
000000030?ooo`00000000000080000000@0oooo00000000000000000P3oool00`000000oooo0?oo
o`0A0?ooobH0dLfY4@3oool010000000oooo0?ooo`3oool2000000030?ooo`000000oooo0080oooo
0`0000000`3oool000000?ooo`03000000030?ooo`000000oooo0140oooo6`3AcJT001X0dLfY503o
ool3000000030?ooo`000000000000<0oooo0`0000000`3oool00000000000020?ooo`030000003o
ool0oooo0100oooo9P3AcJTI0?ooo`040000003oool0000000000080oooo00<000000?ooo`3oool0
5P3ooolW0=7=ZA<0oooo00L000000?ooo`000000oooo0000003oool0000000D0oooo00<000000?oo
o`3oool00P0000000`3oool000000?ooo`0A0?ooobH0dLfY4P3oool3000000@0oooo0P0000000`3o
ool000000?ooo`02000000<0oooo0`00000B0?ooobH0dLfY4@3oool3000000@0oooo00<000000?oo
o`3oool00`0000020?ooo`8000000P3oool2000001<0oooo6`3AcJT001X0dLfY4@3oool200000004
0?ooo`0000000000000000<0oooo00<000000?ooo`0000000`3oool4000000030?ooo`0000000000
0140oooo9P3AcJTA0?ooo`030000003oool0000000800000203oool3000000030?ooo`000000oooo
00<000004@3ooolW0=7=ZA40oooo0P0000030?ooo`030000003oool0000000<0oooo00@000000?oo
o`000000oooo0P0000030?ooo`8000004@3ooolV0=7=ZA40oooo100000020?ooo`8000000P3oool0
1@000000oooo0?ooo`3oool000000080oooo0P0000000`3oool000000000000A0?ooobH0dLfY4@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0000000<000000P3oool010000000oooo0000
0000000E0?oooa/0dLfY000J0=7=ZA80oooo0P0000030?ooo`@00000103oool2000000<0oooo00<0
00000?ooo`3oool04@3ooolV0=7=ZA80oooo00@000000?ooo`00000000000P3oool00`000000oooo
0?ooo`020?ooo`040000003oool00000000000<0oooo00<000000?ooo`3oool04@3ooolW0=7=ZA80
oooo0P0000001P3oool00000000000000000oooo00000080oooo00<000000?ooo`0000001P00000C
0?ooobH0dLfY4P3oool2000000D0oooo00@000000?ooo`00000000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0140oooo9P3AcJTB0?ooo`80000000<0oooo0000000000002P3o
ool3000000030?ooo`000000oooo0180oooo6`3AcJT001X0dLfY4`3oool2000000050?ooo`000000
oooo0?ooo`0000001P3oool2000000030?ooo`000000oooo01<0oooo9P3AcJTC0?ooo`040000003o
ool000000?ooo`<00000103oool010000000oooo0000003oool2000001@0oooo9`3AcJTC0?ooo`D0
00000`3oool00`000000oooo0?ooo`02000000040?ooo`000000oooo000001@0oooo9P3AcJTC0?oo
o`80000000@0oooo0000003oool0oooo0`000000203oool000000?ooo`000000oooo0000003oool0
0000503ooolV0=7=ZAD0oooo00<000000?ooo`3oool01@3oool200000080oooo00@000000?ooo`3o
ool00000503ooolK0=7=Z@006P3AcJTD0?ooo`800000303oool00`000000oooo0?ooo`0C0?ooobH0
dLfY503oool00`000000oooo0?ooo`070?ooo`<0000000<0oooo0000003oool0503ooolW0=7=ZA@0
oooo0P0000020?ooo`D000001@3oool00`000000oooo0?ooo`0C0?ooobH0dLfY503oool2000000@0
oooo0`0000030?ooo`030000003oool0000001D0oooo9P3AcJTE0?ooo`050000003oool0oooo0000
003oool00`0000020?ooo`8000000P3oool00`000000oooo0?ooo`0C0?oooa/0dLfY000J0=7=ZAD0
oooo0P0000000`3oool00000000000040?ooo`040000003oool00000000001H0oooo9P3AcJTE0?oo
o`<000001@3oool3000000030?ooo`000000oooo01D0oooo9`3AcJTE0?ooo`@0000000@0oooo0000
00000000oooo0P0000000`3oool000000000000F0?ooobH0dLfY5@3oool200000080oooo0P000000
103oool000000000003oool3000001H0oooo9P3AcJTI0?ooo`8000000`3oool200000080oooo00<0
00000?ooo`3oool0503ooolK0=7=Z@006P3AcJTG0?ooo`030000003oool0000001h0oooo9P3AcJTL
0?ooo`030000003oool0oooo01T0oooo9`3AcJTG0?ooo`040000003oool0oooo000001d0oooo9P3A
cJTG0?ooo`040000003oool0000000000080oooo00<000000?ooo`3oool0603ooolV0=7=ZA/0oooo
00<000000?ooo`3oool06`3ooolK0=7=Z@006P3AcJTH0?ooo`030000003oool0oooo01d0oooo9P3A
cJTJ0?ooo`800000703ooolW0=7=ZAP0oooo00H000000?ooo`00000000000?ooo`00000J0?ooobH0
dLfY603oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01L0oooo9P3AcJTH0?oo
o`040000003oool00000000000@0oooo00<000000?ooo`3oool05P3ooolK0=7=Z@006P3AcJTI0?oo
o`030000003oool0oooo01`0oooo9P3AcJTJ0?ooo`<000006`3ooolW0=7=ZAT0oooo00D000000?oo
o`3oool0oooo0000000J0?ooobH0dLfY6@3oool00`000000oooo0000000L0?ooobH0dLfY6P3oool0
10000000oooo0?ooo`00000K0?oooa/0dLfY000J0=7=ZAX0oooo00<000000?ooo`3oool06`3ooolV
0=7=ZCP0oooo9`3AcJTJ0?ooo`030000003oool0oooo01/0oooo9P3AcJTJ0?ooo`<000006`3ooolV
0=7=ZAX0oooo0`00000L0?oooa/0dLfY000J0=7=ZAX0oooo00@000000?ooo`00000000006P3ooolV
0=7=ZAX0oooo0P0000000`3oool000000?ooo`0I0?ooobL0dLfY6P3oool010000000oooo00000000
000J0?ooobH0dLfY6P3oool010000000oooo00000000000J0?ooobH0dLfY6P3oool00`000000oooo
0?ooo`0L0?oooa/0dLfY000J0=7=ZA/0oooo0P00000K0?ooobH0dLfY6`3oool2000001/0oooo9`3A
cJTK0?ooo`8000006`3ooolV0=7=ZA/0oooo0P00000K0?ooobH0dLfY6`3oool2000001`0oooo6`3A
cJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03A
cJT00100dLfY140000020=7=Z@A000000P3AcJT4@00000<0dLfY0T0000050=7=Z@03@000003AcJT0
dLfY00<0dLfY0d0000030=7=Z@=000000P3AcJT2@00000D0dLfY0d0000020=7=Z@900000103AcJT2
@00000<0dLfY0d0000050=7=Z@=000004@3AcJT4@0000080dLfY140000020=7=Z@A000000`3AcJT2
@00000D0dLfY00=000000=7=Z@3AcJT00`3AcJT3@00000<0dLfY0d0000020=7=Z@9000000`3AcJT3
@00000@0dLfY0T0000030=7=Z@A00000103AcJT014000000dLfY0=7=Z@3AcJT3@00001@0dLfY1400
00020=7=Z@A000000P3AcJT4@00000<0dLfY0T0000050=7=Z@03@000003AcJT0dLfY00<0dLfY0d00
00030=7=Z@=000000P3AcJT2@00000<0dLfY0d0000040=7=Z@9000000`3AcJT4@00000@0dLfY00=0
00000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0A0=7=Z@A000000P3AcJT4@0000080dLfY1400
00030=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@030=7=Z@=000000`3AcJT3@0000080dLfY0T00
00040=7=Z@9000001@3AcJT014000000dLfY0=7=Z@3AcJT3@00000<0dLfY0d0000040=7=Z@900000
4`3AcJT4@0000080dLfY140000020=7=Z@A00000103AcJT3@00000030=7=ZD000010000000=00000
0P3AcJT2@00000<0dLfY140000030=7=Z@9000000`3AcJT3@00000@0dLfY0T0000040=7=Z@900000
0`3AcJT3@00000<0dLfY1400000B0=7=Z@00403AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003A
cJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000
003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000020=7=Z@03
@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD000002
0=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=
Z@0@0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=
Z@030=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY
0=7=Z@030=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000L0dLfY00E000000=7=Z@3AcJT0dLfY
@00000020=7=Z@03@000003AcJT0dLfY0140dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY
0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU00000103AcJT00d000000
dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU000000P3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000
1`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0140dLfY00=000000=7=Z@3AcJT0
0`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU0
0000103AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3A
cJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00=00000
0=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3A
cJT00d000000dLfY0=7=Z@0@0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3A
cJT00d000000dLfY0=7=Z@060=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY
@00000020=7=Z@04@000003AcJT0dLfY@00000D0dLfY00A000000=7=Z@3AcJU000000P3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000
0P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY01<0dLfY000A0=7=Z@03@000
003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000
003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJT0dLfY1D0000000`3AcJU00000@0000003@00000@0
dLfY00=000000=7=Z@3AcJT01D0000001@3AcJU000000=7=Z@3AcJU0000000D0dLfY00A000000=7=
Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@05@0000180dLfY00=000000=7=Z@3AcJT00`3AcJT0
0d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT00`3AcJT0
14000000dLfY0=7=Z@3AcJT5@00000030=7=ZD000010000000=00000103AcJT014000000dLfY0=7=
ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00E000000=7=Z@3AcJT0dLfY@00000060=7=
Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0B0=7=Z@03@000003AcJT0
dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0
dLfY00<0dLfY00A000000=7=Z@3AcJT0dLfY1D0000000`3AcJU00000@0000003@00000@0dLfY00A0
00000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@05@000003AcJT0dLfY0=7=
ZD0000001P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0180dLfY00=000000=7=
Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=
Z@3AcJT00`3AcJT014000000dLfY0=7=Z@3AcJT5@00000030=7=ZD000010000000=00000103AcJT0
14000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3A
cJT3@00000<0dLfY0d0000020=7=Z@04@000003AcJT0dLfY@00001<0dLfY00=000000=7=Z@3AcJT0
0`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY1D0000030=7=Z@03@000
003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@050=7=Z@04@000
003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=
Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT01D000000dLfY0=7=Z@3AcJU0000001@0dLfY000B
0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@04
0=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=
ZD0000020=7=Z@04@000003AcJT0dLfY0=7=Z@9000000`3AcJT014000000dLfY0=7=ZD0000030=7=
Z@900000103AcJT2@00000<0dLfY0d0000030=7=Z@04@000003AcJT0dLfY@00001@0dLfY00=00000
0=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00@0dLfY00=00000
0=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY
00A000000=7=Z@3AcJT0dLfY0T0000030=7=Z@=00000103AcJT2@00000D0dLfY00=000000=7=Z@3A
cJT0103AcJT00d000000dLfY0=7=Z@03@00001H0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000
dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT00`3AcJT014000000
dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJT0dLfY0T00
00030=7=Z@=00000103AcJT2@00000D0dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=
Z@030=7=Z@03@000003AcJT0dLfY0180dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=
Z@030=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=
ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJT0dLfY0T0000040=7=
Z@9000001P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A0
00000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0B0=7=Z@03@000003AcJT0dLfY00<0dLfY
00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3A
cJT00P3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3A
cJT00P3AcJT2@00000<0dLfY0d0000030=7=Z@04@000003AcJT0dLfY@00000D0dLfY00=000000=7=
Z@3AcJT00d0000050=7=Z@03@000003AcJT0dLfY0140dLfY000@0=7=Z@04@000003AcJT0dLfY@000
0080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003A
cJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY@00000030=7=Z@03
@000003AcJU0000000<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY@00000020=7=Z@04
@000003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=
Z@03@000003AcJU000000180dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000
dLfY0=7=ZD0000030=7=Z@03@000003AcJU0000000<0dLfY00=000000=7=ZD0000000`3AcJT00d00
0000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU000000P3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT0
4`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=
Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000<0dLfY
00=000000=7=ZD0000000`3AcJT00d000000dLfY@00000030=7=Z@03@000003AcJT0dLfY00<0dLfY
00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@000
0080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000B0=7=Z@04@000003A
cJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=
Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY@000
00030=7=Z@03@000003AcJU0000000<0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=
ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000180dLfY00A000000=7=Z@3AcJU00000
0P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=
ZD000000103AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3A
cJT01D000000dLfY0=7=Z@3AcJU0000000D0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT00P3AcJT01400
0000dLfY0=7=ZD00000B0=7=Z@004@3AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@000
00<0dLfY140000040=7=Z@900000103AcJT2@00000<0dLfY0d0000040=7=Z@9000000`3AcJT2@000
00@0dLfY0d0000030=7=Z@=00000103AcJT2@00001<0dLfY0T0000040=7=Z@900000103AcJT2@000
00@0dLfY0T0000030=7=Z@A00000103AcJT2@00000@0dLfY0T0000030=7=Z@=000000`3AcJT3@000
00<0dLfY0T0000040=7=Z@9000000`3AcJT4@00000<0dLfY0d00000D0=7=Z@900000103AcJT2@000
00@0dLfY0T0000040=7=Z@9000000`3AcJT4@00000@0dLfY0T0000040=7=Z@9000000`3AcJT3@000
00<0dLfY0d0000030=7=Z@900000103AcJT2@00000<0dLfY140000020=7=Z@A000004`3AcJT2@000
00@0dLfY0T0000040=7=Z@900000103AcJT2@00000<0dLfY140000040=7=Z@900000103AcJT2@000
00<0dLfY0d0000030=7=Z@9000000`3AcJT4@00000<0dLfY0d0000030=7=Z@=000000`3AcJT2@000
01@0dLfY0T0000040=7=Z@900000103AcJT2@00000D0dLfY0T0000030=7=Z@900000103AcJT2@000
00@0dLfY0T0000040=7=Z@=000000`3AcJT3@00000<0dLfY0T0000040=7=Z@900000103AcJT3@000
00<0dLfY0T00000C0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX
0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@006P3AcJT00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0=7=
Z@0U0=7=Z@040000003oool0oooo000000<0oooo0P0000070?ooo`050000003oool0oooo0?ooo`00
00003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0P0000050?ooo`03
0000003oool0dLfY02H0dLfY0`000000103oool000000000000000040?ooo`030000003oool0oooo
00<0oooo0`0000030?ooo`040000003oool00000000000@0oooo00<000000?ooo`3oool00`3oool2
000000L0oooo00<000000?ooo`3oool00`3oool200000080oooo9P3AcJT00`000000oooo00000002
0?ooo`050000003oool0oooo0000003oool00P0000020?ooo`030000003oool0000000T0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo000000040?ooo`030000003oool0oooo00L0oooo0P00
00020?ooobH0dLfY00D000000?ooo`000000oooo000000020?ooo`<000000`3oool400000080oooo
0P000000103oool000000?ooo`3oool2000000<0oooo0P0000020?ooo`030000003oool000000080
00000P3oool3000000<0oooo0`0000020?ooo`030000003oool000000080oooo6`3AcJT001X0dLfY
00<0oooo0000000000005`3oool3000001P0oooo00<000000?ooo`3oool09P3AcJT01`3oool00000
0000003oool000000?ooo`000000103oool2000000L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`03
0?ooo`8000000P3oool00`000000oooo0?ooo`0W0=7=Z@030?ooo`000000oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo008000000`3oool0
10000000oooo0000000000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`000000
00000`3oool01@000000oooo0?ooo`3oool0000000H0oooo9P3AcJT00`3oool000000?ooo`050000
00<0oooo0P000000103oool000000000000000060?ooo`@0000000D0oooo0000003oool0oooo0000
00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000103oool00`000000oooo0000
0002000000<0oooo9P3AcJT02P3oool000000?ooo`000000oooo0000003oool000000?ooo`000002
0?ooo`@000000P3oool300000080oooo00T000000?ooo`000000oooo0000003oool000000?ooo`00
00000P3oool4000000<0oooo0`0000020?ooo`040000003oool0000000000080oooo0P0000030?oo
oa/0dLfY000J0=7=Z@<0oooo00<000000?ooo`3oool05@3oool3000001H0oooo00@000000?ooo`3o
ool0oooo9P3AcJT30?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P0000030?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo0?ooobL0dLfY1@3oool010000000oooo0?ooo`00000<0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000070?ooo`040000003oool0oooo000000<0oooo0P000003
0?ooo`8000000`3ooolV0=7=Z@D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`02000000070?ooo`000000oooo0?ooo`000000oooo000000060?ooo`80000000@0oooo00000000
0000oooo100000020?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000oooo0?ooo`3o
oolV0=7=Z@H0oooo100000001P3oool00000000000000000oooo00000080oooo0`0000030?ooo`80
00000P3oool00`000000oooo0000000200000080oooo100000001@3oool000000000003oool00000
00@0oooo0`0000020?ooo`040000003oool0oooo0?oooa/0dLfY000J0=7=Z@@0oooo00<000000?oo
o`3oool03`3oool00`000000oooo000000080?ooo`030000003oool0000001@0oooo9P3AcJT40?oo
o`030000003oool0000000@0oooo0P0000070?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool02P3ooolW
0=7=Z@@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0000000H0oooo0P00
00030?ooo`8000000`3oool200000100oooo00<000000?ooo`3oool00`3ooolV0=7=Z@D0oooo1@00
00040?ooo`D0000000L0oooo000000000000oooo0000003oool0000000@0oooo00<000000?ooo`00
00001@3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000L0oooo9P3AcJT50?oo
o`<00000103oool2000000030?ooo`00000000000080000000@0oooo000000000000oooo1P000002
0?ooo`8000000`3oool010000000oooo0000003oool2000000030?ooo`00000000000080oooo1000
00060?oooa/0dLfY000J0=7=Z@D0oooo00<000000?ooo`3oool0303oool200000080oooo0P000000
0`3oool000000?ooo`0K0?ooobH0dLfY1@3oool00`000000oooo0?ooo`030?ooo`8000000`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0?ooo`3oool0000000`0oooo9`3AcJT>0?ooo`030000003oool0oooo00H0oooo00@0
00000?ooo`000000oooo0`00000J0?ooobH0dLfY1@3oool010000000oooo0?ooo`0000030?ooo`80
000000@0oooo0000003oool0oooo0P0000001P3oool000000?ooo`000000oooo00000080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo000000060?ooobH0dLfY1@3oool3000000<0oooo100000020?ooo`<0
000000<0oooo0000003oool00`000000103oool000000?ooo`3oool6000000030?ooo`0000000000
00@0oooo0P0000020?ooo`@000001P3ooolK0=7=Z@006P3AcJT60?ooo`030000003oool0oooo00/0
oooo0P0000080?ooo`030000003oool0oooo01L0oooo9P3AcJT60?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`03000000030?ooo`000000oooo00P0oooo9`3AcJT60?oo
o`040000003oool0oooo00000080oooo0P00000:0?ooo`050000003oool0oooo0?ooo`0000003@3o
ool2000000030?ooo`000000000000T0oooo9P3AcJT90?ooo`<0000000<0oooo000000000000103o
ool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool0103oool3000000H0oooo00@0
00000?ooo`3oool000002P3ooolV0=7=Z@T0oooo0`0000000`3oool00000000000020?ooo`@00000
0P3oool2000000030?ooo`000000oooo0080oooo100000030?ooo`<000000`3oool3000000030?oo
o`000000000000P0oooo6`3AcJT001X0dLfY6@3oool3000000H0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`060?ooobH0dLfY303oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000L0oooo
0P0000030?ooo`030000003oool0oooo00H0oooo9`3AcJT<0?ooo`030000003oool0oooo00X0oooo
00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool0000000X0oooo9P3AcJT90?ooo`80
00001P3oool01@000000oooo0000003oool0000000@0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`030?ooo`@000001@3oool00`000000oooo0?ooo`060?ooobH0dLfY2P3oool3
000000030?ooo`000000000000D0000000<0oooo0000000000000P0000030?ooo`030000003oool0
0000008000000`3oool010000000oooo0000003oool2000000030?ooo`00000000000080oooo00<0
00000?ooo`3oool01P3ooolK0=7=Z@006P3AcJTF0?ooo`030000003oool0000000<000001@3oool2
000000/0oooo00<000000?ooo`3oool01`3ooolV0=7=ZA00oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000090?ooobL0dLfY2@3oool00`000000oooo0?ooo`080?ooo`0;0000003oool0
oooo0?ooo`000000oooo0000003oool000000?ooo`000000103oool00`000000oooo000000060?oo
o`030000003oool0000000T0oooo9P3AcJT<0?ooo`030000003oool0oooo0080000000<0oooo0000
000000001@3oool010000000oooo0000003oool400000080oooo00P000000?ooo`3oool0oooo0000
003oool000000?ooo`<000002P3ooolV0=7=Z@X0oooo100000020?ooo`8000000P3oool00`000000
oooo0000000600000080oooo1P0000000`3oool00000000000040?ooo`<000002P3ooolK0=7=Z@00
6P3AcJT80?ooo`030000003oool0oooo0140oooo1000000>0?ooo`030000003oool0oooo00L0oooo
9P3AcJT80?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001`3oool01@000000oooo0000003oool0
000000T0oooo9`3AcJT80?ooo`060000003oool0oooo0?ooo`000000oooo0P0000020?ooo`800000
0P3oool00`000000oooo0?ooo`02000000<0oooo1P0000000`3oool000000?ooo`040?ooo`030000
003oool0000000X0oooo9P3AcJT80?ooo`<000000P3oool00`000000oooo0?ooo`030?ooo`<00000
0P3oool01@000000oooo000000000000oooo008000001@3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00/0oooo9P3AcJT80?ooo`D000000`3oool300000080oooo1@0000020?oo
o`030000003oool0000000<000000P3oool010000000oooo0000000000030?ooo`<000002`3ooolK
0=7=Z@006P3AcJT90?ooo`030000003oool0oooo0100oooo1@00000<0?ooo`030000003oool0oooo
00P0oooo9P3AcJT90?ooo`040000003oool0oooo000000<0oooo0P0000070?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01@3oool2000000<0oooo00<000000?ooo`0000002P3ooolW
0=7=Z@T0oooo0`0000001@3oool000000?ooo`3oool000000080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`8000000P3oool2000000P0oooo00<000000?ooo`3oool02@3o
oolV0=7=Z@T0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo1P0000040?ooo`050000003oool0oooo0?ooo`0000002`3ooolV0=7=Z@T0oooo
00D000000?ooo`000000oooo000000020?ooo`<000000`3oool600000080oooo1@0000030?ooo`<0
00000P3oool00`000000oooo0?ooo`0;0?oooa/0dLfY000J0=7=Z@X0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`090?ooobH0dLfY2P3oool01P000000oooo0?ooo`000000oooo0000
00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`8000000P3oool00`00
0000oooo0?ooo`090?ooobL0dLfY2P3oool010000000oooo0?ooo`3oool2000000@0oooo0P000000
0`3oool000000000000?0?ooo`030000003oool0oooo00d0oooo9P3AcJT:0?ooo`H0000000<0oooo
0000003oool00`3oool200000080oooo00@000000?ooo`3oool0oooo100000020?ooo`030000003o
ool000000080oooo0`00000<0?ooobH0dLfY2P3oool020000000oooo0000003oool000000?ooo`00
0000oooo0P0000000`3oool0000000000002000000030?ooo`000000oooo0080oooo1@0000020?oo
o`040000003oool0000000000080oooo0`00000;0?oooa/0dLfY000J0=7=Z@/0oooo0P00000N0?oo
o`030000003oool0oooo00X0oooo9P3AcJT;0?ooo`80000000<0oooo0000003oool00P0000020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooobL0dLfY2`3oool0
10000000oooo0?ooo`0000060?ooo`040000003oool00000000000D0oooo00<000000?ooo`000000
2@3oool00`000000oooo0?ooo`0;0?ooobH0dLfY2`3oool010000000oooo0?ooo`0000040?ooo`05
0000003oool0oooo0000003oool00P0000040?ooo`030000003oool0000000@000004`3ooolV0=7=
Z@l0oooo100000000`3oool0000000000004000000050?ooo`000000oooo0000003oool010000004
0?ooo`<000000P3oool00`000000oooo0?ooo`0:0?oooa/0dLfY000J0=7=Z@d0oooo00<000000?oo
o`3oool03@3oool010000000oooo0?ooo`00000G0?ooobH0dLfY3@3oool00`000000oooo00000004
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04`3ooolW0=7=Z@d0oooo00<00000
0?ooo`3oool01P3oool5000000@0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0<
0?ooobH0dLfY3P3oool2000000030?ooo`000000000000<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`03000000040?ooo`000000000000000100oooo9P3AcJT>0?ooo`<00000103o
ool5000000<0oooo1`0000020?ooo`@000003`3ooolK0=7=Z@006P3AcJT>0?ooo`030000003oool0
oooo00T0oooo0P0000030?ooo`8000005`3ooolV0=7=Z@h0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
000E0?ooobL0dLfY4P3oool01P000000oooo0000003oool000000?ooo`8000001@3oool010000000
oooo0000000000020?ooo`030000003oool0oooo0100oooo9P3AcJT>0?ooo`060000003oool00000
0000003oool000000P3oool200000080oooo00<000000?ooo`3oool00P3oool4000000060?ooo`00
0000oooo0000003oool000003`3ooolV0=7=Z@h0oooo0`0000030?ooo`D0000000L0oooo0000003o
ool000000?ooo`000000oooo00@000000P3oool4000000l0oooo6`3AcJT001X0dLfY3`3oool00`00
0000oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`8000006`3ooolV0=7=Z@l0oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool0oooo
0P0000000`3oool000000?ooo`0A0?ooobL0dLfY3`3oool00`000000oooo0?ooo`03000000H0oooo
00@000000?ooo`00000000000`3oool010000000oooo0?ooo`00000B0?ooobH0dLfY4P3oool30000
00040?ooo`000000oooo0?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0140oooo9P3AcJTB0?ooo`040000003oool000000?ooo`<000000P3oool00`000000oooo
0?ooo`03000000050?ooo`00000000000000003oool00P00000A0?oooa/0dLfY000J0=7=ZA00oooo
00<000000?ooo`3oool01`3oool010000000oooo0?ooo`3oool2000001P0oooo9P3AcJT@0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0C0?ooobL0
dLfY703oool2000000D0oooo0P00000C0?ooobH0dLfY403oool01P000000oooo000000000000oooo
000000<0oooo0`0000001`3oool000000000003oool000000?ooo`0000005@3ooolV0=7=ZA@0oooo
0P0000000`3oool0000000000002000000@0oooo0`0000000`3oool00000000000020?ooo`030000
003oool0oooo00l0oooo6`3AcJT001X0dLfY7P3oool2000000D0oooo00<000000?ooo`3oool0403o
oolV0=7=ZAT0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool000000180oooo9`3AcJTB0?ooo`030000003oool0oooo00@0oooo0P000000103oool000000?oo
o`3oool2000000050?ooo`00000000000?ooo`0000004P3ooolV0=7=ZAD0oooo0P0000020?ooo`05
0000003oool000000000003oool00P0000000`3oool0000000000002000001<0oooo9P3AcJTC0?oo
o`@000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo0`00000C0?oooa/0dLfY000J0=7=
ZA40oooo00<000000?ooo`3oool01`3oool3000000L0oooo0P00000A0?ooobH0dLfY4@3oool00`00
0000oooo0?ooo`02000000d0oooo00@000000?ooo`00000000004@3ooolW0=7=ZA40oooo00@00000
0?ooo`3oool0oooo0P0000050?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool00000
0?ooo`00000A0?ooobH0dLfY4@3oool3000000050?ooo`000000oooo0?ooo`000000103oool20000
00L0oooo00<000000?ooo`3oool03`3ooolV0=7=ZA40oooo0P0000000`3oool00000000000030?oo
o`060000003oool0oooo0000003oool000000`3oool3000001@0oooo6`3AcJT001X0dLfY4P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3ooolV
0=7=ZA80oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool2000000<0oooo00<0
00000?ooo`0000004`3ooolW0=7=ZA80oooo0`0000020?ooo`<000000`3oool00`000000oooo0000
00030?ooo`030000003oool0oooo0180oooo9P3AcJTB0?ooo`030000003oool0000000D0oooo00@0
00000?ooo`00000000001@3oool00`000000oooo0?ooo`0B0?ooobH0dLfY4P3oool01@000000oooo
0000003oool000000080oooo00D000000?ooo`3oool000000?ooo`0200000080oooo00<000000?oo
o`3oool0503ooolK0=7=Z@006P3AcJTC0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0B0?ooobH0dLfY4`3oool01P000000oooo0?ooo`000000oooo
000000H0oooo0`0000000`3oool000000?ooo`0C0?ooobL0dLfY4`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000006`3ooolV0=7=ZA<0oooo100000001@3oool000000?oo
o`000000oooo00<000000P3oool2000001D0oooo9P3AcJTE0?ooo`040000003oool000000?ooo`<0
00000P3oool200000080oooo0`00000D0?oooa/0dLfY000J0=7=ZA@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo9P3AcJTD0?ooo`060000
003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01<0oooo9`3AcJTD0?ooo`80000000<0oooo000000000000103oool00`000000oooo0?ooo`0H0?oo
obH0dLfY503oool00`000000oooo0?ooo`02000000@0oooo00<000000?ooo`000000603ooolV0=7=
ZAP0oooo0`0000030?ooo`<000000P3oool00`000000oooo0?ooo`0C0?oooa/0dLfY000J0=7=ZAD0
oooo0P0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503ooolV0=7=ZAD0
oooo0P0000000`3oool000000?ooo`030?ooo`8000000P3oool00`000000oooo0?ooo`0D0?ooobL0
dLfY5@3oool00`000000oooo000000020?ooo`030000003oool0oooo01/0oooo9P3AcJTE0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2000001L0oooo9P3AcJTH0?ooo`<0
000000<0oooo0000000000001@00000F0?oooa/0dLfY000J0=7=ZAL0oooo00<000000?ooo`000000
7P3ooolV0=7=ZAL0oooo00<000000?ooo`3oool07P3ooolW0=7=ZAX0oooo00<000000?ooo`000000
6`3ooolV0=7=ZAL0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo
01H0oooo9P3AcJTG0?ooo`D000000P3oool3000001P0oooo6`3AcJT001X0dLfY603oool00`000000
oooo0?ooo`0M0?ooobH0dLfY603oool00`000000oooo0000000M0?ooobL0dLfY603oool010000000
oooo00000000000L0?ooobH0dLfY6P3oool2000001`0oooo9P3AcJTM0?ooo`8000006P3ooolK0=7=
Z@006P3AcJTI0?ooo`8000007@3ooolV0=7=ZAT0oooo00<000000?ooo`3oool0703ooolW0=7=ZCP0
oooo9P3AcJTI0?ooo`040000003oool00000000001/0oooo9P3AcJTN0?ooo`030000003oool0oooo
01P0oooo6`3AcJT001X0dLfY6P3oool00`000000oooo0000000K0?ooobH0dLfY6P3oool00`000000
oooo0?ooo`0K0?ooobL0dLfY6P3oool3000001/0oooo9P3AcJTK0?ooo`030000003oool0oooo01X0
oooo9P3AcJTi0?oooa/0dLfY000J0=7=ZAX0oooo0P0000000`3oool000000?ooo`0I0?ooobH0dLfY
6P3oool010000000oooo0?ooo`00000J0?ooobL0dLfY6`3oool00`000000oooo0000000J0?ooobH0
dLfY703oool2000001X0oooo9P3AcJTJ0?ooo`030000003oool0000001`0oooo6`3AcJT001X0dLfY
6`3oool2000001/0oooo9P3AcJTK0?ooo`8000006`3ooolW0=7=ZA/0oooo0P00000K0?ooobH0dLfY
6`3oool2000001/0oooo9P3AcJTK0?ooo`800000703ooolK0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX
0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00403AcJT4@0000080dLfY1400
00020=7=Z@E0000000<0dLfY@000040000000T0000020=7=Z@E000000P3AcJT2@00000@0dLfY0T00
00040=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@9000000`3AcJT5@00000030=7=ZD00
00100000009000004P3AcJT4@0000080dLfY140000020=7=Z@E0000000<0dLfY@000040000000T00
00020=7=Z@E000000P3AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T00
00040=7=Z@9000000`3AcJT5@0000080dLfY0T00000D0=7=Z@A000000P3AcJT4@0000080dLfY1D00
00000`3AcJU00000@0000002@00000<0dLfY0T0000040=7=Z@9000000`3AcJT5@0000080dLfY0T00
00040=7=Z@9000001@3AcJT3@00000040=7=ZD0000100000@00000@0dLfY0T0000030=7=Z@E00000
4@3AcJT4@0000080dLfY140000020=7=Z@E0000000<0dLfY@000040000000T0000030=7=Z@900000
103AcJT2@00000<0dLfY1D0000020=7=Z@900000103AcJT2@00000D0dLfY0d000000103AcJU00000
@000040000040=7=Z@9000000`3AcJT4@0000180dLfY140000020=7=Z@A000000P3AcJT5@0000003
0=7=ZD0000100000009000000`3AcJT2@00000@0dLfY0T0000030=7=Z@E000000P3AcJT2@00000@0
dLfY0T0000050=7=Z@=0000000@0dLfY@000040000100000103AcJT2@00000@0dLfY0T00000C0=7=
Z@00403AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00D0dLfY00E000000=7=Z@3A
cJT0dLfY@00000070=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD00
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000
dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT0
1D000000dLfY0=7=Z@3AcJU0000001D0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=
Z@050=7=Z@05@000003AcJT0dLfY0=7=ZD0000001`3AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0
dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03
@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY
0140dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@050=7=Z@05@000003AcJT0dLfY
0=7=ZD0000001@3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000@0dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=
Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=0
00000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0A0=7=Z@03@000003AcJT0dLfY00<0dLfY00=0
00000=7=Z@3AcJT01@3AcJT01D000000dLfY0=7=Z@3AcJU0000000D0dLfY00A000000=7=Z@3AcJU0
00000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU00000
0P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00001D0dLfY00=000000=7=
Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@050=7=Z@05@000003AcJT0dLfY0=7=ZD0000001@3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000@0dLfY00E000000=7=Z@3AcJT0
dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00`3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000
0P3AcJT00d000000dLfY0=7=Z@0@0=7=Z@004@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003A
cJT0dLfY00@0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@040=7=Z@05@000003A
cJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@0000080
dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY
00<0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY
01<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY
0080dLfY00=000000=7=Z@3AcJT0103AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=00000
0=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00<0dLfY00A0
00000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY
00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0C0=7=Z@03@000003AcJT0dLfY00<0dLfY
00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY
00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY
0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY0=7=Z@E0000000D0
dLfY@000003AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3A
cJT04P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3A
cJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=
Z@3AcJU00000103AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3A
cJT014000000dLfY0=7=Z@3AcJT5@00000050=7=ZD000000dLfY0=7=ZD0000000P3AcJT014000000
dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY01<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d00
0000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000@0dLfY00E000000=7=Z@3AcJT0dLfY
@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJT0dLfY1D0000001@3AcJU0
00000=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU00000103AcJT00d000000dLfY0=7=Z@0A
0=7=Z@004P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=
Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT0
14000000dLfY0=7=Z@3AcJT2@00000@0dLfY0T0000040=7=Z@9000000`3AcJT014000000dLfY0=7=
ZD0000030=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY01<0dLfY
00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY
00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3A
cJT0dLfY0T0000040=7=Z@900000103AcJT2@00000<0dLfY00A000000=7=Z@3AcJU000000`3AcJT2
@00000D0dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@0C0=7=Z@03@000003AcJT0
dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0
dLfY0080dLfY0T0000040=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@020=7=Z@9000001P3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00=00000103AcJT2@00000D0dLfY00=0
00000=7=Z@3AcJT04`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=0
00000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@900000103AcJT2@00000D0dLfY00=0
00000=7=Z@3AcJT00P3AcJT2@00000H0dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY
0=7=Z@03@00000@0dLfY0T0000050=7=Z@03@000003AcJT0dLfY01<0dLfY00=000000=7=Z@3AcJT0
0`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0
0P3AcJT2@00000@0dLfY0T0000050=7=Z@03@000003AcJT0dLfY0080dLfY0T0000060=7=Z@04@000
003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00d0000040=7=Z@9000001P3AcJT00d000000
dLfY0=7=Z@0@0=7=Z@00403AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@000
00@0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00E00000
0=7=Z@3AcJT0dLfY@00000020=7=Z@05@000003AcJT0dLfY0=7=ZD000000103AcJT014000000dLfY
0=7=ZD0000030=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d00
0000dLfY0=7=Z@040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0@
0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000103AcJT01D000000dLfY
0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00E000000=7=Z@3AcJT0dLfY@00000040=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=0
00000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00@0dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0140dLfY00A000000=7=Z@3A
cJU000000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3A
cJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3A
cJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT0
1d000000dLfY0=7=Z@3AcJU000000=7=ZD0000000`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000
003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT04@3AcJT014000000dLfY0=7=ZD0000020=7=
Z@04@000003AcJT0dLfY@00000@0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003A
cJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@07@000003AcJT0
dLfY0=7=ZD000000dLfY@00000030=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU0
00000P3AcJT014000000dLfY0=7=ZD00000B0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A00000
0=7=Z@3AcJU00000103AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU0
00000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=
Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00M000000=7=Z@3AcJT0dLfY
@000003AcJU0000000<0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000020=7=
Z@04@000003AcJT0dLfY@0000180dLfY000A0=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=
Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@=000000`3AcJT2@00000@0dLfY0d0000030=7=
Z@900000103AcJT3@00000<0dLfY0T0000040=7=Z@900000503AcJT2@00000@0dLfY0T0000040=7=
Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT3@00000<0dLfY0T0000040=7=
Z@=000000`3AcJT2@00000@0dLfY0d0000030=7=Z@900000103AcJT2@00001D0dLfY0T0000040=7=
Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=
Z@900000103AcJT2@00000D0dLfY0T0000030=7=Z@=000000`3AcJT2@00000@0dLfY0T00000D0=7=
Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=
Z@900000103AcJT2@00000@0dLfY0T0000050=7=Z@9000000`3AcJT3@00000<0dLfY0T0000040=7=
Z@900000503AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=
Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@9000001@3AcJT2@00000<0dLfY0d0000030=7=
Z@900000103AcJT2@00001<0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o
0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY000J
0=7=Z@80000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`070?ooo`d0000000<0oooo
0000003oool01`0000020?ooo`030000003oool0oooo0080000000<0oooo0000000000000P3oool0
10000000oooo0000003ooolV0=7=Z@030000003oool0oooo0080oooo00@000000?ooo`3oool00000
1@3oool200000080oooo00D000000?ooo`00000000000?ooo`0200000080oooo0`0000000`3oool0
0000000000040?ooo`040000003oool00000000000<0oooo0P0000000`3oool000000?ooo`020?oo
o`050000003oool0oooo0000003oool09`3AcJT00`000000oooo000000030?ooo`<000000P3oool0
10000000oooo0000003oool2000000@0oooo0`0000020?ooo`80000000@0oooo000000000000oooo
0P0000000`3oool00000000000050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`00
00000P3oool2000000030?ooo`3AcJT0dLfY02@0dLfY0P0000000`3oool000000?ooo`0700000004
0?ooo`00000000000?ooo`@0000000@0oooo0000003oool000000P3oool010000000oooo0000003o
ool200000080oooo0P0000000`3oool00000000000050?ooo`<0000000<0oooo000000000000103o
ool00`000000oooo0=7=Z@0U0=7=Z@030000003oool0oooo008000000P3oool2000000030?ooo`00
000000000080000000@0oooo0000003oool0oooo0P0000000`3oool00000000000050?ooo`800000
103oool00`000000oooo0?ooo`02000000030?ooo`000000000000<0oooo00<000000?ooo`000000
0P0000020?ooo`80000000<0oooo0000003oool06`3AcJT001X0dLfY00D0oooo0000003oool0oooo
000000030?ooo`030000003oool0oooo00D0oooo1`0000020?ooo`H0000000<0oooo000000000000
1@0000020?ooo`080000003oool0oooo0?ooo`000000oooo0000003oool2000000D0oooo9P3AcJT0
0`3oool000000?ooo`020?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00P000000?ooo`00000000000?ooo`000000oooo0000
0080oooo0P0000040?ooo`030000003oool000000080oooo00@000000?ooo`3oool000000`3oool0
10000000oooo0?ooo`3ooolW0=7=Z@080?ooo`000000oooo0000003oool000000?ooo`0000040?oo
o`030000003oool000000080000000<0oooo0000000000000P3oool00`000000oooo000000020?oo
o`030000003oool0oooo00<0oooo00H000000?ooo`3oool0oooo0000003oool200000080oooo00<0
00000?ooo`0000000P3oool2000000030?ooo`000000oooo00<0oooo9P3AcJT00`3oool000000?oo
o`030?ooo`/000000P3oool00`000000oooo00000003000000@0oooo00D000000?ooo`000000oooo
000000020?ooo`80000000@0oooo000000000000oooo0P0000020?ooo`060000003oool000000000
003oool00000103ooolV0=7=Z@040?ooo`000000oooo0?ooo`H000000P3oool2000000040?ooo`00
000000000?ooo`8000000`3oool00`000000oooo000000030?ooo`080000003oool000000?ooo`00
0000oooo0000003oool3000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool01@000003
0?oooa/0dLfY000J0=7=Z@@0oooo00@000000?ooo`3oool000001P3oool00`000000oooo00000007
000000030?ooo`000000000000@000000P3oool8000000040?ooo`000000oooo000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooobH0dLfY103oool01@000000oooo000000000000oooo0080
00000`3oool200000080oooo00@000000?ooo`000000oooo0`0000020?ooo`030000003oool0oooo
0080oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo00@0oooo0`0000020?oo
o`8000000`3ooolW0=7=Z@@0oooo0`0000020?ooo`040000003oool0oooo0?ooo`D000000`3oool0
10000000oooo0?ooo`0000020?ooo`8000001`3oool600000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo000000030?ooobH0dLfY103oool2000000040?ooo`000000oooo000000L0
oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`8000000`3oool4000000<0oooo0`000002
0?ooo`060000003oool0oooo0?ooo`000000oooo0`0000000`3oool000000?ooo`020?ooobH0dLfY
1@3oool4000000040?ooo`000000oooo000000<0oooo0`0000020?ooo`030000003oool0000000<0
0000103oool4000000<0oooo0P0000040?ooo`<000000`3oool4000000<0oooo6`3AcJT001X0dLfY
103oool00`000000oooo000000020?ooo`<000000P3oool900000080oooo100000000`3oool00000
0?ooo`04000000030?ooo`00000000000080oooo0P0000000`3oool000000?ooo`02000000<0oooo
00<000000?ooo`3oool00P3ooolV0=7=Z@L0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0000000<0oooo0000003oool00P3oool200000003
0?ooo`000000oooo00<0oooo00<000000?ooo`3oool00`0000000`3oool000000?ooo`030?ooobL0
dLfY103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H00000103oool01@000000
oooo0000003oool0000000T0oooo1@0000020?ooo`030000003oool0oooo0080oooo0`0000040?oo
obH0dLfY1@3oool200000080oooo100000070?ooo`@0000000<0oooo0000000000000P3oool01000
0000oooo0?ooo`3oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`0000000`000004
0?ooo`800000103ooolV0=7=Z@@0oooo00D000000?ooo`00000000000?ooo`03000000D0oooo2P00
00001P3oool000000?ooo`000000oooo00000080oooo0`0000000`3oool000000?ooo`030?ooo`80
00000`3oool4000000@0oooo6`3AcJT001X0dLfY1P3oool010000000oooo0?ooo`3oool2000000P0
oooo00H000000?ooo`3oool0oooo0000003oool4000000030?ooo`000000000000H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo000000060?ooobH0dLfY1P3oool3000000<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`800000103oool400000080oooo00<000000?ooo`3oool00P00
00001@3oool000000?ooo`000000oooo00<0000000D0oooo0000003oool0oooo000000070?ooobL0
dLfY1@3oool01@000000oooo0000003oool0000000<0oooo1P0000020?ooo`030000003oool0oooo
00<0oooo0P0000000`3oool00000000000060?ooo`@000000P3oool200000080oooo0P0000060?oo
obH0dLfY1P3oool2000000040?ooo`000000oooo0?ooo`80000000<0oooo0000000000000P000002
0?ooo`@000001@3oool2000000050?ooo`00000000000000003oool01@0000000`3oool000000000
0002000000030?ooo`000000000000H0oooo9P3AcJT50?ooo`<0000000D0oooo0000003oool0oooo
000000030?ooo`<0000000<0oooo0000003oool00P0000000`3oool00000000000020?ooo`800000
103oool2000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`02000000H0oooo
6`3AcJT001X0dLfY2@3oool01P000000oooo0?ooo`3oool000000?ooo`8000000`3oool00`000000
oooo0?ooo`030?ooo`H00000103oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo
0?ooo`0000002@3ooolV0=7=Z@H0oooo00<000000?ooo`0000000P0000020?ooo`030000003oool0
000000T0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<000001P3o
ool010000000oooo0?ooo`0000080?ooobL0dLfY203oool2000000@0oooo0P0000040?ooo`800000
00@0oooo0000003oool00000103oool01@000000oooo0000003oool0000000/0oooo00<000000?oo
o`3oool01`3ooolV0=7=Z@P0oooo0`0000030?ooo`030000003oool0oooo00<0000000D0oooo0000
003oool000000?ooo`05000000030?ooo`000000oooo0080oooo00<000000?ooo`0000000P000004
0?ooo`030000003oool0oooo00T0oooo9P3AcJT70?ooo`<0000000@0oooo0000003oool0oooo1@00
00001P3oool000000000003oool000000?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00D000000?ooo`3oool000000?ooo`04000000L0oooo6`3AcJT001X0
dLfY1`3oool010000000oooo0?ooo`0000040?ooo`<000000P3oool010000000oooo0?ooo`000002
0?ooo`D0000000<0oooo0000003oool0103oool3000000<0oooo00<000000?ooo`3oool00P000007
0?ooobH0dLfY1`3oool2000000H0oooo00<000000?ooo`0000000P0000020?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`050000003oool000000?ooo`000000
0`3oool3000000030?ooo`000000oooo00H0oooo9`3AcJT70?ooo`<00000103oool00`000000oooo
0?ooo`020?ooo`<000001P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo00000004
0?ooo`030000003oool0oooo00<0oooo0P0000070?ooobH0dLfY1`3oool2000000060?ooo`000000
oooo0000003oool000000P3oool400000080oooo0P0000020?ooo`@00000103oool00`000000oooo
00000002000000030?ooo`000000000000<000000P3oool00`000000oooo0?ooo`050?ooobH0dLfY
1`3oool00`000000oooo00000002000000040?ooo`000000000000000080oooo0`0000030?ooo`05
0000003oool0oooo0000003oool0100000020?ooo`@0000000@0oooo000000000000oooo10000000
0`3oool000000?ooo`070?oooa/0dLfY000J0=7=Z@T0oooo00D000000?ooo`00000000000?ooo`04
00000080oooo00<000000?ooo`3oool00P3oool5000000030?ooo`000000oooo0080oooo00<00000
0?ooo`0000000`0000020?ooo`030000003oool0000000X0oooo9P3AcJT@0?ooo`050000003oool0
00000000003oool00P000000103oool000000?ooo`3oool2000000@0oooo00@000000?ooo`3oool0
00001`3oool2000000X0oooo9`3AcJT90?ooo`8000000P3oool2000000030?ooo`000000000000@0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`000000oooo00800000103oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01`3ooolV0=7=Z@T0oooo00<00000
0?ooo`3oool00P0000001`3oool000000?ooo`000000oooo0000003oool01@0000020?ooo`040000
003oool000000?ooo`8000000`3oool200000080oooo00@000000?ooo`00000000002`3ooolV0=7=
Z@X0oooo0P0000020?ooo`8000000P3oool2000000030?ooo`000000oooo008000000`3oool30000
00040?ooo`000000oooo00000080oooo0P0000000`3oool00000000000020?ooo`@000002@3ooolK
0=7=Z@006P3AcJT80?ooo`030000003oool0oooo0080000000<0oooo0000000000000`000000103o
ool000000?ooo`0000020?ooo`L0000000D0oooo0000003oool000000?ooo`08000000/0oooo9P3A
cJT80?ooo`8000001P3oool300000080oooo00<000000?ooo`3oool00`000000103oool000000?oo
o`0000040?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0203ooolW0=7=Z@P0
oooo00D000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000000P3oool200000080oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo0`00
00000`3oool000000?ooo`090?ooobH0dLfY203oool010000000oooo0000000000020?ooo`800000
0P3oool2000000030?ooo`000000000000<0000000<0oooo0000000000000P3oool00`000000oooo
000000020?ooo`8000000P3oool2000000h0oooo9P3AcJT80?ooo`@000000`3oool00`000000oooo
0000000200000080oooo0P0000020?ooo`8000001@3oool3000000040?ooo`000000oooo0?ooo`80
00000`3oool00`000000oooo0?ooo`090?oooa/0dLfY000J0=7=Z@T0oooo00@000000?ooo`3oool0
oooo1@0000060?ooo`H000001@3oool700000080oooo00<000000?ooo`3oool02@3ooolV0=7=Z@T0
oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000002P3oool2000000080?ooo`000000oooo
0?ooo`000000oooo0000003oool2000000030?ooo`000000oooo00`0oooo9`3AcJT90?ooo`030000
003oool0000000<000001@3oool3000000@0oooo0P0000000`3oool000000?ooo`04000000040?oo
o`000000oooo000000<0oooo0P00000;0?ooobH0dLfY2@3oool01`000000oooo000000000000oooo
0000003oool00P0000020?ooo`030000003oool000000080oooo00@000000?ooo`3oool00000103o
ool2000000030?ooo`00000000000080000000<0oooo0000003oool00P00000;0?ooobH0dLfY2@3o
ool2000000040?ooo`000000000000000080oooo00<000000?ooo`0000001`3oool3000000<0oooo
0`0000000`3oool00000000000050?ooo`8000002`3ooolK0=7=Z@006P3AcJT:0?ooo`80000000<0
oooo000000000000100000020?ooo`030000003oool0oooo00H00000103oool2000000040?ooo`00
000000000?ooo`<0000000<0oooo0000003oool02P3ooolV0=7=Z@X0oooo00<000000?ooo`3oool0
0`3oool01@000000oooo0?ooo`3oool0000000T0oooo0P0000050?ooo`050000003oool000000?oo
o`0000000P3oool00`000000oooo0?ooo`090?ooobL0dLfY2P3oool00`000000oooo000000030?oo
o`<0000000<0oooo0000000000000P0000020?ooo`@0000000<0oooo0000000000000`0000020?oo
o`030000003oool000000080oooo0P00000;0?ooobH0dLfY2P3oool200000080oooo00<000000?oo
o`0000000P0000000`3oool000000?ooo`02000000D0oooo00<000000?ooo`000000100000020?oo
o`<0000000@0oooo0000003oool000002`3ooolV0=7=Z@X0oooo0`0000001@3oool000000?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool00P3oool2000000D0oooo00L000000?ooo`3oool0oooo
0000003oool0000000@0oooo00<000000?ooo`3oool02@3ooolK0=7=Z@006P3AcJT;0?ooo`040000
003oool0oooo000000H0oooo00@000000?ooo`000000oooo1P0000050?ooo`040000003oool0oooo
00000100oooo9P3AcJT;0?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0000
003oool700000080oooo100000020?ooo`040000003oool0oooo000000d0oooo9`3AcJT;0?ooo`07
0000003oool000000?ooo`000000oooo000000030?ooo`040000003oool000000?ooo`80000000@0
oooo0000003oool00000103oool00`000000oooo0?ooo`02000000030?ooo`000000oooo00d0oooo
9P3AcJT;0?ooo`040000003oool0oooo0?ooo`8000000P3oool3000000040?ooo`000000oooo0?oo
o`<000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool000000100oooo9P3AcJT=
0?ooo`040000003oool000000?ooo`P0000000T0oooo00000000000000000?ooo`000000oooo0000
003oool01@0000020?ooo`040000003oool00000000000`0oooo6`3AcJT001X0dLfY3`3oool20000
00L0oooo1`0000060?ooo`030000003oool0oooo0100oooo9P3AcJT=0?ooo`050000003oool0oooo
0?ooo`0000000`3oool010000000oooo0?ooo`3oool2000000030?ooo`000000oooo00<000000P3o
ool2000000050?ooo`000000oooo0?ooo`0000003P3ooolW0=7=Z@l0oooo00<000000?ooo`3oool0
103oool01@000000oooo0?ooo`3oool0000000H0oooo0P0000040?ooo`8000003`3ooolV0=7=ZA00
oooo00<000000?ooo`3oool01P0000030?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000
003oool00P3oool2000000l0oooo9P3AcJT=0?ooo`<000000P3oool010000000oooo000000000002
0?ooo`8000000P3oool7000000030?ooo`000000oooo0080000000<0oooo0000000000003P3ooolK
0=7=Z@006P3AcJT>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool=0000
00<0oooo00<000000?ooo`3oool0303ooolV0=7=ZA40oooo00P000000?ooo`3oool000000?ooo`00
0000oooo000000@0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo0P0000000`3o
ool000000?ooo`0=0?ooobL0dLfY3P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo0`0000000`3oool000000?ooo`030?ooo`030000003oool0oooo0080oooo0`00000>0?oo
obH0dLfY4`3oool2000000040?ooo`000000oooo0?ooo`8000000P3oool2000000030?ooo`000000
000000<0oooo00<000000?ooo`3oool00P00000>0?ooobH0dLfY3P3oool010000000oooo0000003o
ool300000080oooo00<000000?ooo`3oool00`3oool3000000040?ooo`000000oooo0?ooo`<00000
0`3oool00`000000oooo0?ooo`0<0?oooa/0dLfY000J0=7=ZA00oooo00<000000?ooo`3oool01P3o
ool700000080oooo0P0000030?ooo`030000003oool0oooo00h0oooo9P3AcJT@0?ooo`<0000000<0
oooo0000003oool00`0000000`3oool0000000000002000000040?ooo`0000000000000000@0oooo
00<000000?ooo`3oool03`3ooolW0=7=Z@l0oooo00D000000?ooo`000000oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0200000080oooo0P00000@0?oo
obH0dLfY4P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`00000000000`3oool00`000000oooo0?ooo`0>0?ooobH0dLfY4@3oool00`000000oooo
0?ooo`04000000<0oooo00<000000?ooo`0000000`3oool400000080oooo0P00000@0?oooa/0dLfY
000J0=7=ZAP0oooo1`0000000`3oool000000?ooo`02000001@0oooo9P3AcJT@0?ooo`030000003o
ool00000008000000P3oool00`000000oooo0?ooo`02000000050?ooo`000000oooo0?ooo`000000
0`3oool200000180oooo9`3AcJTB0?ooo`800000103oool00`000000oooo0?ooo`02000000L0oooo
00<000000?ooo`3oool04@3ooolV0=7=ZA@0oooo0P0000040?ooo`070000003oool000000?ooo`00
0000oooo000000020?ooo`030000003oool000000180oooo9P3AcJTB0?ooo`030000003oool00000
0080oooo1@0000000`3oool0000000000003000000040?ooo`00000000000?ooo`8000004@3ooolK
0=7=Z@006P3AcJTA0?ooo`030000003oool0oooo00@0oooo200000020?ooo`80000000<0oooo0000
000000004@3ooolV0=7=ZA40oooo0P0000000`3oool000000?ooo`02000000<0oooo00<000000?oo
o`3oool00P3oool200000080oooo00<000000?ooo`0000004@3ooolW0=7=ZA40oooo0`0000040?oo
o`030000003oool00000008000000P3oool00`000000oooo0?ooo`030?ooo`8000004@3ooolV0=7=
ZA40oooo0P0000000`3oool000000?ooo`020?ooo`8000000`3oool00`000000oooo0?ooo`020?oo
o`<0000000<0oooo0000003oool0403ooolV0=7=ZA40oooo0P0000000`3oool000000?ooo`020000
00040?ooo`000000000000000080oooo0P0000020?ooo`<0000000<0oooo0000003oool04@3ooolK
0=7=Z@006P3AcJTA0?ooo`@000000P3oool9000000<0oooo00@000000?ooo`00000000004@3ooolV
0=7=ZA40oooo00<000000?ooo`0000000P3oool010000000oooo0000000000020?ooo`@0000000<0
oooo0000003oool00P3oool200000140oooo9`3AcJTA0?ooo`070000003oool0oooo0?ooo`000000
oooo000000020?ooo`<0000000<0oooo000000000000103oool300000140oooo9P3AcJTA0?ooo`@0
00000`3oool3000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`8000004@3ooolV0=7=
ZA40oooo00<000000?ooo`000000103oool200000080oooo0`0000001P3oool000000?ooo`3oool0
00000?ooo`8000004P3ooolK0=7=Z@006P3AcJTB0?ooo`060000003oool0oooo0?ooo`000000oooo
1`000000103oool0000000000000000E0?ooobH0dLfY4P3oool2000000040?ooo`000000oooo0000
00P0oooo00@000000?ooo`3oool00000503ooolW0=7=ZA80oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo0`0000000`3oool000000?ooo`0C0?ooobH0dLfY4P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool05`3o
oolV0=7=ZA80oooo00<000000?ooo`0000000`3oool300000080oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0B0?oooa/0dLfY000J0=7=ZA<0oooo00<000000?ooo`3oool00P3o
ool800000080oooo00<000000?ooo`3oool04`3ooolV0=7=ZA<0oooo0P0000020?ooo`060000003o
ool000000?ooo`000000oooo0P00000I0?ooobL0dLfY4`3oool00`000000oooo0000000300000080
oooo00<000000?ooo`0000000`3oool2000001D0oooo9P3AcJTC0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool04`3ooolV0=7=ZAD0oooo00H000000?ooo`3oool000000?ooo`000005
0?ooo`80000000<0oooo000000000000503ooolK0=7=Z@006P3AcJTD0?ooo`80000000T0oooo0000
003oool0oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0?ooo`0C0?ooobH0dLfY
503oool00`000000oooo0?ooo`020?ooo`030000003oool000000080oooo00D000000?ooo`3oool0
oooo0000000E0?ooobL0dLfY503oool00`000000oooo000000030?ooo`<0000000@0oooo0000003o
ool0oooo0P00000E0?ooobH0dLfY503oool2000000030?ooo`0000000000008000000P3oool30000
0080oooo00<000000?ooo`3oool04`3ooolV0=7=ZAD0oooo00<000000?ooo`0000000`3oool00`00
0000oooo000000030?ooo`030000003oool0000001D0oooo6`3AcJT001X0dLfY5@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo01H0oooo9P3AcJTE0?ooo`050000003oool0oooo0000
003oool00P0000020?ooo`030000003oool0000001L0oooo9`3AcJTE0?ooo`040000003oool00000
0?ooo`D0000000<0oooo0000003oool05`3ooolV0=7=ZAD0oooo00<000000?ooo`3oool01P3oool2
000001P0oooo9P3AcJTH0?ooo`040000003oool0000000000080oooo1@00000F0?oooa/0dLfY000J
0=7=ZAP0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooobH0dLfY5`3oool0
0`000000oooo000000050?ooo`030000003oool0oooo01H0oooo9`3AcJTI0?ooo`H000006@3ooolV
0=7=ZAP0oooo0P00000N0?ooobH0dLfY5`3oool00`000000oooo000000020?ooo`@000006@3ooolK
0=7=Z@006P3AcJTH0?ooo`8000000P3oool010000000oooo0?ooo`00000H0?ooobH0dLfY6@3oool0
0`000000oooo0?ooo`02000000030?ooo`000000oooo01L0oooo9`3AcJTH0?ooo`P00000603ooolV
0=7=ZAT0oooo00D000000?ooo`3oool000000?ooo`02000001P0oooo9P3AcJTH0?ooo`8000000`3o
ool4000001P0oooo6`3AcJT001X0dLfY7@3oool00`000000oooo0?ooo`0H0?ooobH0dLfY>03ooolW
0=7=ZAT0oooo0P0000000`3oool000000000000J0?ooobH0dLfY7@3oool00`000000oooo0?ooo`0H
0?ooobH0dLfY6P3oool01@000000oooo0?ooo`3oool0000001X0oooo6`3AcJT001X0dLfY>03ooolV
0=7=ZAX0oooo00<000000?ooo`3oool06`3ooolW0=7=ZA/0oooo00<000000?ooo`3oool06P3ooolV
0=7=ZCP0oooo9P3AcJTK0?ooo`030000003oool0000001/0oooo6`3AcJT001X0dLfY6`3oool00`00
0000oooo0000000J0?ooobH0dLfY703oool2000001X0oooo9`3AcJTK0?ooo`030000003oool00000
01X0oooo9P3AcJTK0?ooo`030000003oool0000001X0oooo9P3AcJTJ0?ooo`<00000703ooolK0=7=
Z@006P3AcJTK0?ooo`8000006`3ooolV0=7=ZA/0oooo0P00000K0?ooobL0dLfY6`3oool2000001/0
oooo9P3AcJTK0?ooo`8000006`3ooolV0=7=ZA/0oooo0P00000L0?oooa/0dLfY003o0=7=ZNP0dLfY
003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY000@0=7=Z@A00000
0P3AcJT4@00000<0dLfY0T0000030=7=Z@E0000000<0dLfY@000040000000T0000040=7=Z@=00000
0P3AcJT2@00000@0dLfY0T0000030=7=Z@=000001@3AcJT014000000dLfY0=7=Z@3AcJT4@00000<0
dLfY0T0000030=7=Z@=000004`3AcJT4@0000080dLfY140000030=7=Z@9000000`3AcJT5@0000003
0=7=ZD000010000000900000103AcJT3@0000080dLfY0T0000030=7=Z@E0000000<0dLfY@0000400
00000d000000103AcJU00000@000040000030=7=Z@=000000`3AcJT5@0000080dLfY0T00000D0=7=
Z@A000000P3AcJT4@00000<0dLfY0T0000030=7=Z@E0000000<0dLfY@000040000000T0000040=7=
Z@=000000P3AcJT2@00000<0dLfY1D0000000`3AcJU00000@0000003@00000040=7=ZD0000100000
@00000<0dLfY0d0000030=7=Z@E0000000@0dLfY@0000400001000004`3AcJT4@0000080dLfY1400
00030=7=Z@9000000`3AcJT5@00000030=7=ZD000010000000900000103AcJT3@0000080dLfY0T00
00030=7=Z@E000000P3AcJT2@00000<0dLfY0d0000030=7=Z@=00000103AcJT2@00000@0dLfY0T00
000C0=7=Z@A000000P3AcJT4@00000<0dLfY0T0000030=7=Z@E0000000<0dLfY@000040000000T00
00040=7=Z@=000000P3AcJT2@00000<0dLfY1D0000020=7=Z@9000000`3AcJT3@00000<0dLfY0d00
00040=7=Z@9000000`3AcJT5@0000140dLfY000@0=7=Z@03@000003AcJT0dLfY00<0dLfY00=00000
0=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD000000
203AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=
Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000001@3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000180dLfY00=000000=7=Z@3AcJT0
0`3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@00000@0dLfY00E000000=7=Z@3A
cJT0dLfY@00000080=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT0
0d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=
Z@020=7=Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000
003AcJT0dLfY0140dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000
003AcJT0dLfY@00000@0dLfY00E000000=7=Z@3AcJT0dLfY@00000080=7=Z@04@000003AcJT0dLfY
@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0
dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00<0dLfY00=0
00000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0A0=7=Z@03@000003AcJT0dLfY00<0dLfY00=0
00000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD00
0000203AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=
Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000
0P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=
Z@3AcJT0403AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=
Z@3AcJU00000103AcJT01D000000dLfY0=7=Z@3AcJU0000000P0dLfY00A000000=7=Z@3AcJU00000
0P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000
dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3A
cJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0140dLfY000A0=7=Z@03@000003AcJT0
dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003A
cJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT5@00000<0dLfY00E000000=7=Z@3AcJT0dLfY
@00000020=7=Z@04@000003AcJT0dLfY0=7=Z@=00000103AcJT00d000000dLfY0=7=Z@020=7=Z@03
@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000C
0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD00
00040=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT5@00000<0dLfY00=0
00000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD000000
0P3AcJT014000000dLfY0=7=Z@3AcJT3@00000@0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=
Z@03@000003AcJT0dLfY0180dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=
Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@02
0=7=Z@E000000`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00E00000
0=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY0=7=Z@=00000103AcJT00d000000dLfY
0=7=Z@020=7=Z@=000004`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY
00A000000=7=Z@3AcJU00000103AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080
dLfY1D0000030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000
dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@02
0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0A0=7=Z@03@000003A
cJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000
003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT5@00000<0dLfY00=000000=7=Z@3AcJT0
0`3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000
dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00`3AcJT00d00
0000dLfY0=7=Z@0A0=7=Z@004P3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=
ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=
Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU000000P3A
cJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0
0P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00d00000E0=7=Z@03
@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY
0080dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=00000
0=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00<0dLfY00A00000
0=7=Z@3AcJT0dLfY0d0000030=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT0
0P3AcJT2@00001H0dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=
ZD0000000P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=
Z@3AcJT00`3AcJT014000000dLfY0=7=Z@3AcJT3@00000<0dLfY00A000000=7=Z@3AcJU00000103A
cJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT04P3AcJT00d000000dLfY
0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03
@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY
00<0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY
00=000000`3AcJT3@00000H0dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0B
0=7=Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003A
cJT0dLfY0080dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY
00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00@0dLfY
00=000000=7=Z@3AcJT00d0000030=7=Z@=000001P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000
003AcJT0dLfY0140dLfY000@0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU0
00000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT0
1d000000dLfY0=7=Z@3AcJU000000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04
@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000
dLfY0=7=Z@0B0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT0
14000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT01d000000dLfY
0=7=Z@3AcJU000000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0
dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0
dLfY@00000@0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0140dLfY
00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@00000@0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@07@000003AcJT0dLfY0=7=ZD000000
dLfY@00000020=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT00`3AcJT00d00
0000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU00000103AcJT0
1D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0403AcJT014000000dLfY0=7=
ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000103AcJT01D00
0000dLfY0=7=Z@3AcJU000000080dLfY00M000000=7=Z@3AcJT0dLfY@000003AcJU000000080dLfY
00A000000=7=Z@3AcJU00000103AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00E000000=7=
Z@3AcJT0dLfY@00000050=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU000000P3A
cJT014000000dLfY0=7=ZD00000B0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3A
cJU000000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3A
cJT01d000000dLfY0=7=Z@3AcJU000000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000040=7=
Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT01D000000dLfY0=7=Z@3AcJU0000000D0dLfY00=0
00000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY0140dLfY
000A0=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000D0dLfY0T00
00030=7=Z@900000103AcJT2@00000@0dLfY0d0000020=7=Z@A000000`3AcJT2@00000@0dLfY0T00
00040=7=Z@=000004`3AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T00
00050=7=Z@9000000`3AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT3@00000<0dLfY0d00
00030=7=Z@900000103AcJT2@00001D0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T00
00040=7=Z@9000001@3AcJT2@00000<0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0d00
00030=7=Z@=000000`3AcJT2@00000@0dLfY0d00000C0=7=Z@900000103AcJT2@00000@0dLfY0T00
00040=7=Z@900000103AcJT2@00000D0dLfY0T0000030=7=Z@900000103AcJT2@00000@0dLfY0T00
00040=7=Z@=000000`3AcJT3@00000<0dLfY0T0000040=7=Z@900000503AcJT2@00000@0dLfY0T00
00040=7=Z@900000103AcJT2@00000@0dLfY0T0000050=7=Z@9000000`3AcJT2@00000@0dLfY0T00
00040=7=Z@900000103AcJT3@00000<0dLfY0d0000030=7=Z@900000103AcJT2@00001<0dLfY003o
0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o
0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY000J0=7=Z@040000003oool0oooo000000<0
oooo0P0000000`3oool000000?ooo`0:0?ooo`030000003oool0oooo0080oooo00L000000?ooo`3o
ool0oooo0000003oool0000000/0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0=7=
Z@0U0=7=Z@<00000203oool00`000000oooo000000080?ooo`800000203oool2000000H0oooo00<0
00000?ooo`0000000`3oool2000000D0oooo0P0000000`3oool0dLfY0=7=Z@0U0=7=Z@040000003o
ool0oooo00000080oooo0`000000103oool000000?ooo`0000060?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P0000050?ooo`030000003oool0oooo00@0oooo0`0000020?ooo`<0
000000H0oooo0000003oool0oooo0000003ooolV0=7=Z@8000000`3oool00`000000oooo00000002
000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`80000000L0oooo
0000003oool000000?ooo`000000oooo02H0dLfY0P0000020?ooo`8000000P3oool01P000000oooo
0?ooo`3oool000000?ooo`8000000`3oool2000000040?ooo`000000oooo000000@0oooo00L00000
0?ooo`00000000000?ooo`000000oooo008000000P3oool2000000030?ooo`000000oooo00@0oooo
00P000000?ooo`000000oooo0000003oool000000?oooa/0dLfY000J0=7=Z@040?ooo`000000oooo
000000L0oooo0P0000040?ooo`040000003oool0oooo000000H0oooo00@000000?ooo`3oool00000
1P3oool2000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooobH0dLfY
00<0oooo0000003oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000P0oooo
00@000000?ooo`00000000000`3oool01@000000oooo0000003oool0000000l0oooo0P0000050?oo
obL0dLfY00@0oooo0000003oool000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000X0oooo
0P0000050?ooo`030000003oool0oooo0080oooo9P3AcJT0103oool000000?ooo`0000080?ooo`03
0000003oool000000080000000D0oooo0000003oool000000?ooo`04000000<0oooo00<000000?oo
o`3oool00P0000060?ooo`80000000<0oooo0000003oool01@3oool00`000000oooo0?ooo`030?oo
obH0dLfY00<0oooo0000003oool00P0000050?ooo`050000003oool000000?ooo`0000000P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00<000001P3oool2000000<0oooo00<00000
0?ooo`0000000P3oool2000000040?ooo`0000000000000000<0oooo6`3AcJT001X0dLfY0`3oool2
000000<0oooo0`0000030?ooo`8000001@3oool300000080oooo00P000000?ooo`3oool000000?oo
o`000000oooo000000D0oooo0P0000040?ooo`8000001@3oool010000000oooo0?ooo`3ooolV0=7=
Z@<0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`030000003oool0oooo00@0oooo0P000000
0`3oool00000000000040?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`0000000P3oool2000000<0oooo9`3AcJT30?ooo`8000001@3oool2
000000l0oooo0P0000080?ooo`030000003oool0oooo00@0oooo0P0000060?ooo`040000003oool0
oooo0?ooobH0dLfY2@3oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`000000
0`3oool2000000050?ooo`000000oooo0?ooo`0000001P3oool00`000000oooo000000030?ooo`03
0000003oool0oooo00L0oooo00@000000?ooo`3oool0oooo9P3AcJT70?ooo`030000003oool0oooo
00@0oooo00D000000?ooo`3oool000000?ooo`02000000040?ooo`000000oooo000000D0oooo00@0
00000?ooo`00000000000`3oool010000000oooo0?ooo`0000020?ooo`8000000P3oool00`000000
oooo000000020?ooo`8000000`3ooolK0=7=Z@006P3AcJTA0?ooo`8000000P3oool2000000X0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooobH0dLfY1@3oool3000000<0oooo
00L000000?ooo`3oool0oooo0000003oool0000000X0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`<000001@3ooolW0=7=Z@H0oooo00@00000
0?ooo`000000oooo0P0000050?ooo`060000003oool0oooo0000003oool000000P3oool010000000
oooo0000000000020?ooo`030000003oool0000000<0oooo0`0000040?ooo`8000002P3ooolV0=7=
Z@P0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
00000080oooo0P0000000`3oool000000?ooo`020?ooo`<000000P3oool2000000030?ooo`000000
000000T0oooo00<000000?ooo`3oool00P3ooolV0=7=Z@D0oooo0P0000070?ooo`040000003oool0
oooo0?ooo`8000000`3oool00`000000oooo0?ooo`070?ooo`8000000P3oool2000000<0oooo0P00
00020?ooo`030000003oool0000000@00000103ooolK0=7=Z@006P3AcJT50?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`020?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02`3ooolV0=7=Z@H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo000000090?ooo`8000000`3oool00`000000oooo000000080?ooo`030000003oool0
oooo00`0oooo9`3AcJT50?ooo`050000003oool0oooo0000003oool00`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P000000103oool000000000000000020?ooo`050000
003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`3oool3000000030?ooo`000000oooo
00L0oooo9P3AcJT80?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool01000
0000oooo0?ooo`3oool200000080oooo00<000000?ooo`0000000P3oool2000000<0oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooobH0dLfY2P3oool010000000oooo0?ooo`00
00040?ooo`8000000`3oool3000000@0oooo00<000000?ooo`0000000`3oool2000000L0oooo0P00
00000`3oool000000?ooo`070?oooa/0dLfY000J0=7=Z@P0oooo100000060?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo9P3AcJT@0?ooo`030000003oool000000100oooo00<000000?ooo`000000103oool0
0`000000oooo0000000;0?ooobL0dLfY203oool00`000000oooo0000000200000080oooo00<00000
0?ooo`3oool01@3oool200000080oooo00D000000?ooo`000000oooo000000030?ooo`<0000000D0
oooo0000003oool000000?ooo`03000000030?ooo`000000oooo00L0oooo9P3AcJT<0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo00@0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000000203ooolV0=7=Z@/0oooo0P0000060?ooo`030000003oool0oooo00<000000P3oool00`00
0000oooo000000020?ooo`<000000P3oool2000000X0oooo00<000000?ooo`3oool01@3ooolK0=7=
Z@006P3AcJT80?ooo`030000003oool0oooo00X0oooo0`0000070?ooo`030000003oool0000000d0
oooo00<000000?ooo`3oool01P3ooolV0=7=Z@P0oooo00<000000?ooo`3oool02P3oool3000000L0
oooo0`00000F0?ooobL0dLfY203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`060?ooobH0dLfY1`3oool2000000@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo008000001P3oool010000000oooo0?oo
o`3oool4000000030?ooo`000000oooo00@0oooo00<000000?ooo`0000001`3ooolV0=7=Z@L0oooo
0P0000070?ooo`80000000<0oooo0000003oool02P3oool00`000000oooo0?ooo`05000000040?oo
o`000000oooo000000@0oooo00<000000?ooo`3oool01`3ooolK0=7=Z@006P3AcJTG0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`000000603ooolV0=7=Z@T0oooo0`0000020?ooo`030000
003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00@0
oooo00@000000?ooo`3oool0oooo0P00000:0?ooobL0dLfY303oool00`000000oooo0?ooo`020000
00D0oooo0P0000060?ooo`040000003oool0oooo000000<0oooo00H000000?ooo`3oool0oooo0000
003oool2000000/0oooo9P3AcJT>0?ooo`80000000<0oooo0000003oool00`3oool00`000000oooo
00000002000000030?ooo`000000oooo0080oooo0P0000040?ooo`030000003oool0000000l0oooo
9P3AcJT:0?ooo`060000003oool0oooo0000003oool000001@3oool2000000H0oooo0`0000020?oo
o`<000000P3oool010000000oooo0000003oool3000000/0oooo6`3AcJT001X0dLfY203oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0303ooolV0=7=
Z@P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00@000005P3ooolW0=7=Z@P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000
1P3oool00`000000oooo0?ooo`0<0?ooobH0dLfY203oool01P000000oooo0?ooo`000000oooo0000
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?ooo`040000003oool00000
0?ooo`8000000P3oool2000000L0oooo00<000000?ooo`3oool0203ooolV0=7=Z@P0oooo0`000007
0?ooo`050000003oool0oooo0000003oool00P0000040?ooo`030000003oool00000008000002`3o
ool2000000X0oooo6`3AcJT001X0dLfY2@3oool010000000oooo0?ooo`0000040?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000H0oooo
0P0000030?ooo`030000003oool0000000X0oooo9P3AcJT90?ooo`8000001@3oool01`000000oooo
0?ooo`3oool000000?ooo`000000103oool2000000<0oooo0P0000030?ooo`030000003oool0oooo
00@0oooo0P00000:0?ooobL0dLfY2@3oool01P000000oooo0?ooo`000000oooo000000H0oooo0P00
0000103oool000000?ooo`0000030?ooo`050000003oool0oooo0000003oool00P0000050?ooo`80
000000<0oooo0000003oool02@3ooolV0=7=Z@T0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`80000000<0oooo0000000000001@3oool00`000000oooo0?ooo`0300000080
oooo00<000000?ooo`000000403ooolV0=7=Z@T0oooo0P0000000`3oool000000?ooo`020?ooo`04
0000003oool0oooo000000H0oooo0P0000020?ooo`040000003oool0oooo00000080oooo0P000007
0?ooo`030000003oool0oooo00T0oooo6`3AcJT001X0dLfY2P3oool00`000000oooo000000060?oo
o`070000003oool000000?ooo`000000oooo000000030?ooo`060000003oool000000000003oool0
00001`3oool2000000`0oooo9P3AcJT:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool000000080oooo100000040?ooo`030000003oool0oooo
0080oooo0P00000>0?ooobL0dLfY2P3oool00`000000oooo000000020?ooo`040000003oool00000
00000080oooo0P0000070?ooo`80000000<0oooo0000000000000`3oool200000080oooo0P00000<
0?ooobH0dLfY2P3oool2000000030?ooo`000000oooo00D0oooo0`0000030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool2000000<0oooo00<000000?ooo`3oool02@3ooolV
0=7=Z@X0oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool2
000000050?ooo`000000oooo0?ooo`0000000`3oool00`000000oooo0?ooo`03000000/0oooo6`3A
cJT001X0dLfY2`3oool3000000<0oooo0P0000030?ooo`8000002@3oool010000000oooo0?ooo`3o
ool2000000@0oooo00<000000?ooo`3oool02P3ooolV0=7=Z@/0oooo0P0000040?ooo`030000003o
ool0oooo00<000002P3oool010000000oooo0?ooo`3oool300000080oooo0P00000<0?ooobL0dLfY
2`3oool3000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3ooolV0=7=Z@/0oooo00<000000?ooo`3oool0
0`3oool2000000040?ooo`000000oooo0?ooo`<00000103oool3000000030?ooo`00000000000080
oooo00@000000?ooo`3oool000003P3ooolV0=7=Z@d0oooo100000000`3oool000000?ooo`020?oo
o`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000003oool0000000H0oooo1@00
000<0?oooa/0dLfY000J0=7=ZA@0oooo00H000000?ooo`00000000000?ooo`0000060?ooo`800000
5P3ooolV0=7=Z@h0oooo0P0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1P3oool010000000oooo0?ooo`3oool3000000h0oooo9`3AcJT?0?ooo`050000003oool0oooo0?oo
o`0000001@3oool01P000000oooo0?ooo`000000oooo000000@0oooo00<000000?ooo`3oool04P3o
oolV0=7=Z@h0oooo00<000000?ooo`3oool00P00000B0?ooo`8000004@3ooolV0=7=Z@d0oooo00<0
00000?ooo`0000000P3oool010000000oooo0000000000030?ooo`800000103oool00`000000oooo
0?ooo`050?ooo`030000003oool0000000l0oooo6`3AcJT001X0dLfY3P3oool00`000000oooo0?oo
o`080?ooo`L00000603ooolV0=7=Z@l0oooo00<000000?ooo`3oool09P3ooolW0=7=Z@h0oooo00@0
00000?ooo`00000000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo0P0000030?ooo`05
0000003oool0oooo0?ooo`0000004@3ooolV0=7=Z@l0oooo0`00000D0?ooo`040000003oool00000
000000h0oooo9P3AcJT?0?ooo`80000000@0oooo0000000000000000103oool01@000000oooo0?oo
o`3oool0000000L0oooo00<000000?ooo`0000000`00000>0?oooa/0dLfY000J0=7=ZA00oooo0`00
00000`3oool000000?ooo`030?ooo`800000203oool2000000030?ooo`000000oooo0100oooo9P3A
cJTE0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000001@0oooo9`3A
cJT@0?ooo`800000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo9P3A
cJTE0?ooo`8000002P3oool00`000000oooo0?ooo`0D0?ooobH0dLfY503oool00`000000oooo0?oo
o`030?ooo`050000003oool000000?ooo`0000001`3oool00`000000oooo0?ooo`0@0?oooa/0dLfY
000J0=7=ZA00oooo0P0000050?ooo`070000003oool000000000003oool000000?ooo`03000000D0
oooo00<000000?ooo`3oool03`3ooolV0=7=ZA40oooo00<000000?ooo`3oool00`3oool400000003
0?ooo`0000000000008000001P3oool00`000000oooo0?ooo`0?0?ooobL0dLfY403oool2000000@0
oooo00<000000?ooo`3oool01P3oool3000000@0oooo00<000000?ooo`3oool03`3ooolV0=7=ZA40
oooo0P0000020?ooo`8000000P3oool5000000070?ooo`000000oooo0000003oool000000?ooo`02
00000140oooo9P3AcJTF0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool3
00000080oooo00<000000?ooo`3oool03`3ooolK0=7=Z@006P3AcJTM0?ooo`040000003oool0oooo
000001L0oooo9P3AcJTB0?ooo`<000000P3oool2000000030?ooo`000000oooo00L0oooo0P00000C
0?ooobL0dLfY5P3oool00`000000oooo0?ooo`070?ooo`80000000<0oooo0000003oool04`3ooolV
0=7=ZA40oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooobH0dLfY4@3oool3000000@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`80000000D0oooo000000000000oooo0000000C0?oooa/0
dLfY000J0=7=ZA40oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00l0oooo9P3AcJTA0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
3`3ooolW0=7=ZA40oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo00l0oooo9P3AcJTA0?ooo`<00000103oool300000080oooo00H000000?ooo`3o
ool000000?ooo`0000020?ooo`8000004@3ooolV0=7=ZA40oooo0P0000030?ooo`060000003oool0
oooo0?ooo`000000oooo0`0000020?ooo`060000003oool0oooo0000003oool000004P3ooolK0=7=
Z@006P3AcJTB0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo9P3AcJTB0?ooo`8000003`3oool20000
01<0oooo9`3AcJTB0?ooo`040000003oool0oooo000000D0oooo00X000000?ooo`3oool000000?oo
o`000000oooo0000003oool000004`3ooolV0=7=ZA80oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0L0?ooobH0dLfY4P3oool01@000000oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool01P3oool2000001@0oooo6`3AcJT001X0dLfY4`3oool010000000oooo000000000002
0?ooo`80000000<0oooo0000003oool00`3oool2000001D0oooo9P3AcJTC0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000`3oool2000001L0oooo9`3AcJTC0?ooo`030000003o
ool0000000D0oooo0P0000050?ooo`030000003oool0oooo01<0oooo9P3AcJTC0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool04`3ooolV0=7=ZAH0oooo00L000000?ooo`3oool0oooo
0000003oool0000000H0oooo0P00000D0?oooa/0dLfY000J0=7=ZA@0oooo00@000000?ooo`000000
00001@3oool010000000oooo0?ooo`3oool2000001D0oooo9P3AcJTD0?ooo`800000103oool00`00
0000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool04`3ooolW0=7=ZA@0oooo00<000000?oo
o`0000000P3oool010000000oooo0000000000040?ooo`8000005@3ooolV0=7=ZA@0oooo0P000000
0`3oool000000000000200000080oooo0`0000020?ooo`030000003oool0oooo01<0oooo9P3AcJTE
0?ooo`050000003oool0oooo0000003oool00P0000020?ooo`030000003oool0000000<000005@3o
oolK0=7=Z@006P3AcJTE0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool05`3o
oolV0=7=ZAD0oooo00<000000?ooo`3oool0803ooolW0=7=ZAD0oooo00H000000?ooo`3oool0oooo
0000003oool2000001/0oooo9P3AcJTE0?ooo`030000003oool0000000L0oooo00<000000?ooo`3o
ool05P3ooolV0=7=ZAL0oooo0P0000000`3oool000000?ooo`020?ooo`D000005P3ooolK0=7=Z@00
6P3AcJTG0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0603ooolV0=7=ZAP0oooo
00<000000?ooo`3oool07@3ooolW0=7=ZAL0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`0H0?ooobH0dLfY7@3oool00`000000oooo0000000H0?ooobH0dLfY5`3oool00`000000oooo
000000030?ooo`8000006P3ooolK0=7=Z@006P3AcJTh0?ooobH0dLfY>03ooolW0=7=ZAT0oooo0P00
00020?ooo`030000003oool0oooo01P0oooo9P3AcJTI0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool05P3ooolV0=7=ZAP0oooo0P0000060?ooo`030000003oool0oooo01H0oooo
6`3AcJT001X0dLfY6@3oool200000080oooo00<000000?ooo`3oool0603ooolV0=7=ZAd0oooo00<0
00000?ooo`3oool0603ooolW0=7=ZAT0oooo0P0000020?ooo`030000003oool0oooo01P0oooo9P3A
cJTM0?ooo`030000003oool0oooo01P0oooo9P3AcJTK0?ooo`030000003oool0000001/0oooo6`3A
cJT001X0dLfY>03ooolV0=7=ZA`0oooo00<000000?ooo`3oool06@3ooolW0=7=ZCP0oooo9P3AcJTh
0?ooobH0dLfY703oool2000001/0oooo6`3AcJT001X0dLfY7@3oool00`000000oooo0?ooo`0H0?oo
obH0dLfY7@3oool00`000000oooo0?ooo`0H0?ooobL0dLfY7@3oool00`000000oooo0?ooo`0H0?oo
obH0dLfY6`3oool00`000000oooo0000000J0?ooobH0dLfY6P3oool2000001d0oooo6`3AcJT001X0
dLfY6`3oool2000001/0oooo9P3AcJTK0?ooo`8000006`3ooolW0=7=ZA/0oooo0P00000K0?ooobH0
dLfY6`3oool2000001/0oooo9P3AcJTK0?ooo`800000703ooolK0=7=Z@00o`3AcJWX0=7=Z@00o`3A
cJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00403AcJT4@0000080dLfY
140000030=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000<0dLfY
1D0000000`3AcJU00000@0000002@00000@0dLfY0d0000020=7=Z@900000103AcJT2@00000<0dLfY
1400000B0=7=Z@A000000P3AcJT4@00000<0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY
0T0000040=7=Z@9000000`3AcJT5@00000030=7=ZD000010000000900000103AcJT3@0000080dLfY
0T0000040=7=Z@900000103AcJT2@00001@0dLfY140000020=7=Z@A000000`3AcJT2@00000@0dLfY
0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T0000030=7=Z@E0000000<0dLfY@00004000000
0T0000040=7=Z@=000000P3AcJT2@00000@0dLfY0T0000050=7=Z@=000004@3AcJT4@0000080dLfY
140000030=7=Z@9000000`3AcJT5@00000030=7=ZD000010000000900000103AcJT3@0000080dLfY
0T0000040=7=Z@9000000`3AcJT3@00000D0dLfY00A000000=7=Z@3AcJT0dLfY140000030=7=Z@90
00001@3AcJT3@0000140dLfY140000020=7=Z@A000000`3AcJT2@00000<0dLfY1D0000000`3AcJU0
0000@0000002@00000@0dLfY0d0000020=7=Z@900000103AcJT2@00000<0dLfY0d0000050=7=Z@04
@000003AcJT0dLfY0=7=Z@A000000`3AcJT2@00000@0dLfY0T00000C0=7=Z@00403AcJT00d000000
dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU000000P3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000
0P3AcJT014000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD000000203AcJT01400
0000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000
5@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU0
00000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A00000
0=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD00
0000203AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A00000
0=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0A0=7=Z@03@000003AcJT0dLfY00<0dLfY00=0
00000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080
dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0
dLfY@00000@0dLfY00E000000=7=Z@3AcJT0dLfY@00000080=7=Z@04@000003AcJT0dLfY@0000080
dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY
0100dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY
@00000@0dLfY00E000000=7=Z@3AcJT0dLfY@00000080=7=Z@04@000003AcJT0dLfY@0000080dLfY
00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00<0
dLfY00E000000=7=Z@3AcJT0dLfY@00000050=7=Z@04@000003AcJT0dLfY@00000D0dLfY00=00000
0=7=Z@3AcJT0403AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00A00000
0=7=Z@3AcJU00000103AcJT01D000000dLfY0=7=Z@3AcJU0000000P0dLfY00A000000=7=Z@3AcJU0
00000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=
Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU0000000D0dLfY00A000000=7=Z@3AcJU000000P3A
cJT014000000dLfY0=7=ZD00000B0=7=Z@004@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003A
cJT0dLfY0080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04
@000003AcJT0dLfY@00000D0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=
Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT5@00000050=7=ZD000000dLfY
0=7=ZD000000103AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY01<0dLfY00=00000
0=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A0
00000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000050=7=Z@03@000003AcJT0dLfY00<0
dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080
dLfY1D0000001@3AcJU000000=7=Z@3AcJU0000000@0dLfY00=000000=7=Z@3AcJT00`3AcJT00d00
0000dLfY0=7=Z@0C0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000
1@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0
0P3AcJT00d000000dLfY0=7=Z@020=7=Z@E0000000D0dLfY@000003AcJT0dLfY@00000040=7=Z@04
@000003AcJT0dLfY0=7=Z@E000004P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY
0080dLfY00A000000=7=Z@3AcJU00000103AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0
dLfY0080dLfY1D0000030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=
Z@3AcJT3@00000@0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000
003AcJT0dLfY@0000080dLfY1D00000B0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3A
cJT00P3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=
Z@3AcJT00P3AcJT5@00000<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0
dLfY0=7=Z@=00000103AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY00A0
00000=7=Z@3AcJU000001@3AcJT00d000000dLfY0=7=Z@0@0=7=Z@004P3AcJT00d000000dLfY0=7=
Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04
@000003AcJT0dLfY0=7=Z@900000103AcJT2@00000@0dLfY0T0000050=7=Z@03@000003AcJT0dLfY
00<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY0=7=Z@9000001P3A
cJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY01<0dLfY00=000000=7=Z@3AcJT00`3A
cJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000
dLfY0=7=Z@3AcJT2@00000@0dLfY0T0000040=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@030=7=
Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=Z@3AcJT2@00000H0dLfY00=0
00000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0C0=7=Z@03@000003AcJT0dLfY00<0dLfY00E0
00000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3A
cJT0dLfY0T0000040=7=Z@900000103AcJT2@00000D0dLfY00=000000=7=Z@3AcJT00`3AcJT01D00
0000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJT0dLfY0T0000060=7=Z@04@000003A
cJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT04P3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000
003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00<0
dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=
Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00<0dLfY00=0
00000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU0
00000P3AcJT00d000000dLfY0=7=Z@0B0=7=Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00`3AcJT01D00
0000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD00
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY
0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=Z@3AcJT2@000
01<0dLfY000@0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU0
00000`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00@0dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@07@000003AcJT0dLfY0=7=ZD000000dLfY@00000020=7=Z@04@000003A
cJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000B0=7=
Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=
ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d00
0000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00@0dLfY00E000000=7=Z@3AcJT0dLfY@0000002
0=7=Z@07@000003AcJT0dLfY0=7=ZD000000dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080
dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000C0=7=Z@04@000003AcJT0
dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04
@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@03
0=7=Z@03@000003AcJT0dLfY00@0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@07@000003A
cJT0dLfY0=7=ZD000000dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=
Z@3AcJU000000`3AcJT00d000000dLfY@000000B0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A0
00000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=
ZD0000000P3AcJT01d000000dLfY0=7=Z@3AcJU000000=7=ZD0000000P3AcJT014000000dLfY0=7=
ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000
0`3AcJT00d000000dLfY@000000B0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3A
cJU000000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3A
cJT01d000000dLfY0=7=Z@3AcJU000000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=
Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=
ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d00
0000dLfY0=7=Z@0B0=7=Z@004@3AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0
dLfY0T0000040=7=Z@=000000`3AcJT3@00000<0dLfY0T0000040=7=Z@9000001@3AcJT2@00000<0
dLfY0T0000040=7=Z@900000103AcJT2@00001@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0
dLfY0T0000040=7=Z@900000103AcJT3@00000<0dLfY0d0000030=7=Z@900000103AcJT2@00000D0
dLfY0T0000030=7=Z@900000103AcJT2@00000@0dLfY0T00000E0=7=Z@900000103AcJT2@00000@0
dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0d0000030=7=Z@=000000`3AcJT2@00000@0
dLfY0T0000050=7=Z@9000000`3AcJT2@00000@0dLfY0T0000050=7=Z@9000004`3AcJT2@00000@0
dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T0000050=7=Z@9000000`3AcJT2@00000@0
dLfY0T0000040=7=Z@=000000P3AcJT4@00000<0dLfY0T0000040=7=Z@9000001@3AcJT2@00001<0
dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@9000001@3AcJT2@00000<0
dLfY0T0000040=7=Z@900000103AcJT3@0000080dLfY140000030=7=Z@900000103AcJT2@00000@0
dLfY0d00000B0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=
Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@006P3AcJT00`00
0000oooo0?ooo`0300000080oooo00<000000?ooo`3oool00`0000040?ooo`8000001@3oool01000
0000oooo0?ooo`3oool2000000D0oooo00@000000?ooo`3oool0oooo0P000000103oool000000000
003oool2000000040?ooo`000000oooo00000080oooo00<000000?ooo`3AcJT09@3AcJT3000000D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?oo
o`0000003`3oool01P000000oooo0?ooo`3oool000000?ooo`80000000<0oooo0000003oool00P3o
ool2000000030?ooo`3AcJT0dLfY02D0dLfY00<000000?ooo`3oool010000000103oool000000000
003oool4000000<0oooo0P0000060?ooo`030000003oool000000080oooo0P0000020?ooo`<00000
0`3oool4000000@0oooo00<000000?ooo`0000000P3oool00`000000oooo0=7=Z@0U0=7=Z@800000
5P3oool3000000040?ooo`000000oooo000001L0oooo00<000000?ooo`3AcJT09@3AcJT2000000X0
oooo0P0000070?ooo`030000003oool0oooo008000000P3oool01@000000oooo0?ooo`3oool00000
01H0oooo00<000000?ooo`3AcJT06P3AcJT001X0dLfY00@0oooo0000003oool000000P3oool20000
00@0oooo0P0000000`3oool000000?ooo`080?ooo`8000000P3oool00`000000oooo0?ooo`050?oo
o`030000003oool000000080oooo0P0000030?ooo`<0000000<0oooo0000003oool00`3ooolV0=7=
Z@040?ooo`000000oooo0?ooo`80000000<0oooo0000003oool02P3oool00`000000oooo0?ooo`03
0?ooo`H0000000<0oooo0000003oool00P3oool010000000oooo0?ooo`3oool2000000D0oooo1000
00050?ooobL0dLfY00@0oooo0000003oool000000P3oool00`000000oooo000000070?ooo`800000
0P3oool2000000<0oooo00<000000?ooo`3oool00P3oool020000000oooo0?ooo`3oool000000?oo
o`000000oooo0P0000060?ooo`060000003oool0oooo0000003oool00000103ooolV0=7=Z@030?oo
o`000000oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`040000
003oool0oooo00000100oooo9P3AcJT00`3oool000000?ooo`040?ooo`030000003oool0000000L0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`0000001`3oool00`000000oooo000000080?oooa/0dLfY000J0=7=Z@<0
oooo0P000000103oool000000000003oool200000080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00L000000?ooo`3oool0oooo0000003o
ool0000000D0oooo00D000000?ooo`3oool0oooo000000030?ooobH0dLfY0`3oool01@000000oooo
0?ooo`3oool0000000D0oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000T0oooo0`0000040?ooo`8000000P3oool2000000<0oooo9`3AcJT30?oo
o`80000000<0oooo0000003oool00P3oool010000000oooo0000000000040?ooo`800000103oool3
00000080oooo0`0000030?ooo`<000000P3oool010000000oooo0000000000080?ooo`040000003o
ool0oooo0?ooobH0dLfY0`3oool2000000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000X0oooo00<000000?ooo`000000
0`3ooolV0=7=Z@<0oooo0P0000030?ooo`030000003oool0oooo0100oooo0`0000060?ooo`030000
003oool0000000X0oooo00D000000?ooo`000000oooo000000030?oooa/0dLfY000J0=7=Z@L0oooo
00<000000?ooo`3oool00P3oool2000001D0oooo00<000000?ooo`3oool00`3oool01P000000oooo
0000003oool000000?ooo`<0000000<0oooo0000003oool00`3ooolV0=7=Z@H0oooo0P0000050?oo
o`8000006P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000@0oooo9`3AcJT7
0?ooo`050000003oool0oooo0?ooo`0000000P3oool2000000L0oooo00<000000?ooo`0000001P3o
ool00`000000oooo0?ooo`040?ooo`<000000P3oool010000000oooo0?ooo`3oool2000000030?oo
o`000000oooo00<0oooo9P3AcJT:0?ooo`030000003oool0000001h0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`020?ooobH0dLfY303oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool01@3oool2000000@0oooo00D000000?ooo`3oool0oooo0000000<0?oo
o`030000003oool0oooo0080oooo6`3AcJT001X0dLfY5@3oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo01H0oooo9P3AcJT@0?ooo`040000003oool0oooo00000080oooo10000003
0?ooo`070000003oool000000?ooo`000000oooo000000080?ooo`8000002P3ooolW0=7=Z@P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0R0?ooobH0dLfY203oool2000000<0oooo
00<000000?ooo`3oool01@3oool2000000<0oooo00<000000?ooo`000000103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00`0oooo9P3AcJT50?ooo`030000003oool0oooo00800000
0P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000203oool00`000000
oooo0?ooo`090?ooo`800000303ooolK0=7=Z@006P3AcJT>0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo
9P3AcJT@0?ooo`030000003oool0oooo0080000000L0oooo0000003oool0oooo0000003oool00000
0080oooo00@000000?ooo`00000000001@3oool00`000000oooo0?ooo`0>0?ooobL0dLfY4`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000503o
oolV0=7=Z@L0oooo00H000000?ooo`3oool000000?ooo`0000070?ooo`040000003oool0oooo0000
0080oooo0`00000>0?ooo`8000000`3oool00`000000oooo0?ooo`050?ooobH0dLfY1`3oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`07
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3ooolK0=7=Z@006P3AcJT>0?oo
o`030000003oool0oooo00<0oooo0`0000090?ooo`<000001@3oool00`000000oooo0?ooo`0=0?oo
obH0dLfY4`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`0000004P3ooolW0=7=ZAT0oooo00<000000?ooo`3oool0703ooolV0=7=Z@`0oooo0P00000;0?oo
o`8000003`3oool2000000`0oooo9P3AcJTK0?ooo`030000003oool0oooo01/0oooo6`3AcJT001X0
dLfY5P3oool00`000000oooo000000070?ooo`8000005P3ooolV0=7=Z@T0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`02000000<0oooo0`0000040?ooo`8000000P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo9`3AcJTH0?ooo`030000003oool0oooo0080
oooo0`00000H0?ooobH0dLfY303oool2000000d0oooo00<000000?ooo`3oool02`3oool3000000`0
oooo9P3AcJT<0?ooo`<000000`3oool010000000oooo0000000000040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`0;0?oooa/0dLfY000J0=7=ZA00
oooo00<000000?ooo`3oool00P3oool010000000oooo0000000000070?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool03@3ooolV0=7=ZAL0oooo0P0000001P3oool000000000003oool0
00000?ooo`8000005`3ooolW0=7=Z@d0oooo00<000000?ooo`0000001P3oool01`000000oooo0000
003oool000000?ooo`0000000P3oool00`000000oooo000000020?ooo`050000003oool0oooo0000
003oool00P00000=0?ooobH0dLfY5`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00T0oooo0P00000=0?ooobH0dLfY403oool010000000oooo0?ooo`0000020?ooo`<000001`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool000000080oooo0P0000020?ooo`030000003o
ool0oooo00P0oooo6`3AcJT001X0dLfY5@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo01<0oooo9P3AcJTB0?ooo`8000001`3oool2000000<0oooo00<000000?ooo`0000000P00000C
0?ooobL0dLfY5P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo008000000P3o
ool00`000000oooo0?ooo`0A0?ooobH0dLfY2`3oool010000000oooo0?ooo`3oool2000000@0oooo
00@000000?ooo`3oool0oooo0P0000001@3oool000000000003oool000000080oooo0P0000040?oo
o`030000003oool0oooo00d0oooo9P3AcJT?0?ooo`030000003oool0oooo0080oooo0P0000040?oo
o`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo000000`0oooo6`3AcJT001X0dLfY5P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo01@0oooo9P3AcJTB0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3o
ool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0@0?ooobL0
dLfY4`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01<0oooo9P3AcJT@0?ooo`80
000000<0oooo000000000000203oool00`000000oooo0?ooo`050?ooo`8000004@3ooolV0=7=ZA@0
oooo00<000000?ooo`3oool0103oool2000000030?ooo`000000oooo01T0oooo6`3AcJT001X0dLfY
2`3oool3000000030?ooo`000000oooo0080000000<0oooo0000003oool0103oool4000000L0oooo
0P0000040?ooo`030000003oool0oooo00X0oooo9P3AcJT;0?ooo`8000000`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00800000303ooolW0=7=Z@/0oooo0`0000001P3oool00000
0?ooo`3oool000000?ooo`80000000@0oooo0000003oool0oooo0P0000030?ooo`040000003oool0
oooo000000P0oooo00<000000?ooo`3oool02P3ooolV0=7=Z@/0oooo0`0000000`3oool000000?oo
o`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000
000<0?ooobH0dLfY303oool2000000<0oooo00<000000?ooo`3oool01`3oool3000000X0oooo00D0
00000?ooo`000000oooo0000000<0?oooa/0dLfY000J0=7=ZA00oooo0P0000060?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool0103oool3000000030?ooo`000000oooo00`0oooo9P3A
cJT?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
00060?ooo`040000003oool0oooo000000d0oooo9`3AcJT@0?ooo`8000002@3oool00`000000oooo
0?ooo`070?ooo`@0000000<0oooo0000003oool0303ooolV0=7=ZA<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
2`3ooolV0=7=ZA/0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`030000003oool0oooo00/0
oooo6`3AcJT001X0dLfY3P3oool010000000oooo0000000000020?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000002000000050?ooo`000000oooo
0?ooo`0000003P3ooolV0=7=Z@h0oooo0P0000080?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool2000000h0oooo9`3AcJT>0?ooo`030000003oool0000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0303ooolV0=7=Z@h0oooo00<000000?ooo`3oool01`3oool200000080oooo00<00000
0?ooo`0000002@3oool2000000h0oooo9P3AcJT>0?ooo`8000001P3oool01@000000oooo0?ooo`3o
ool0000000H0oooo00<000000?ooo`3oool01@3oool2000000h0oooo6`3AcJT001X0dLfY403oool2
000000030?ooo`000000oooo00@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`3oool2000000040?ooo`000000oooo000000l0oooo9P3AcJTB0?ooo`@000000`3oool00`000000
oooo0?ooo`060?ooo`@000000P3oool00`000000oooo0?ooo`0=0?ooobL0dLfY403oool2000000P0
oooo0`0000000`3oool000000?ooo`060?ooo`030000003oool0000000l0oooo9P3AcJTH0?ooo`80
00000`3oool2000000T0oooo00<000000?ooo`3oool03@3ooolV0=7=Z@l0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool03@3ooolK0=7=Z@006P3AcJT@0?ooo`050000003oool0oooo0?ooo`0000000P3oool3000000<0
oooo0`0000020?ooo`060000003oool0oooo0000003oool00000403ooolV0=7=ZA00oooo0P000002
0?ooo`030000003oool0oooo00l0oooo0P00000@0?ooobL0dLfY403oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool200000080oooo00<00000
0?ooo`000000403ooolV0=7=ZA00oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool000000?ooo`000000403ooolV0=7=ZA00oooo00D000000?ooo`000000oooo
000000030?ooo`030000003oool000000080oooo0P000000103oool000000?ooo`0000030?ooo`80
00004@3ooolK0=7=Z@006P3AcJTA0?ooo`030000003oool0000000@000000P3oool400000080oooo
0P0000040?ooo`030000003oool0oooo00l0oooo9P3AcJTA0?ooo`060000003oool0oooo0000003o
ool000000P3oool010000000oooo0000000000020?ooo`050000003oool000000?ooo`0000000P3o
ool00`000000oooo0?ooo`0?0?ooobL0dLfY4@3oool00`000000oooo000000020?ooo`030000003o
ool0oooo00@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00l0oooo
9P3AcJTA0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0?0?ooobH0dLfY4@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01P0oooo
6`3AcJT001X0dLfY>03ooolV0=7=ZCP0oooo9`3AcJTE0?ooo`80000000<0oooo0000003oool0103o
ool010000000oooo00000000000F0?ooobH0dLfY5@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01D0oooo9P3AcJTC0?ooo`030000003oool0oooo00/0oooo0P0000020?ooo`030000
003oool0oooo0140oooo6`3AcJT001X0dLfY>03ooolV0=7=ZCP0oooo9`3AcJTE0?ooo`8000002P3o
ool00`000000oooo0?ooo`0D0?ooobH0dLfY503oool010000000oooo0?ooo`3oool4000000<0oooo
00<000000?ooo`3oool05P3ooolV0=7=ZAP0oooo00<000000?ooo`3oool01@3oool010000000oooo
0?ooo`00000E0?oooa/0dLfY000J0=7=ZCP0oooo9P3AcJTh0?ooobL0dLfY603oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01L0oooo9P3AcJTI0?ooo`8000000P3oool00`000000oooo
0?ooo`0H0?ooobH0dLfY>@3ooolK0=7=Z@006P3AcJTh0?ooobH0dLfY5`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01D0oooo9`3AcJTH0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool05`3ooolV0=7=ZAT0oooo0P0000000`3oool000000000000J0?ooobH0dLfY
6P3oool2000000030?ooo`000000000001X0oooo6`3AcJT001X0dLfY>03ooolV0=7=ZCP0oooo9`3A
cJTJ0?ooo`<000006`3ooolV0=7=ZAd0oooo00<000000?ooo`3oool0603ooolV0=7=ZAL0oooo00@0
00000?ooo`3oool000007P3ooolK0=7=Z@006P3AcJTh0?ooobH0dLfY>03ooolW0=7=ZCP0oooo9P3A
cJTN0?ooo`030000003oool0oooo01L0oooo9P3AcJTI0?ooo`030000003oool0oooo01d0oooo6`3A
cJT001X0dLfY>03ooolV0=7=ZCP0oooo9`3AcJTh0?ooobH0dLfY>03ooolV0=7=ZCT0oooo6`3AcJT0
01X0dLfY6@3oool2000000040?ooo`000000oooo000001T0oooo9P3AcJTI0?ooo`040000003oool0
oooo0?ooo`8000006@3ooolW0=7=ZAT0oooo0P000000103oool000000?ooo`00000I0?ooobH0dLfY
6@3oool2000000040?ooo`000000oooo000001T0oooo9P3AcJTI0?ooo`040000003oool000000?oo
o`8000006P3ooolK0=7=Z@006P3AcJTM0?ooo`030000003oool0oooo01P0oooo9P3AcJTM0?ooo`03
0000003oool0oooo01P0oooo9`3AcJTM0?ooo`030000003oool0oooo01P0oooo9P3AcJTM0?ooo`03
0000003oool0oooo01P0oooo9P3AcJTJ0?ooo`030000003oool0oooo01`0oooo6`3AcJT001X0dLfY
6`3oool2000001/0oooo9P3AcJTK0?ooo`8000006`3ooolW0=7=ZA/0oooo0P00000K0?ooobH0dLfY
6`3oool2000001/0oooo9P3AcJTK0?ooo`800000703ooolK0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX
0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00403AcJT4
@0000080dLfY140000030=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2
@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000D0dLfY0d0000020=7=Z@9000000`3AcJT3
@00001<0dLfY140000020=7=Z@A000000`3AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2
@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T0000050=7=Z@=000000P3AcJT2
@00000D0dLfY00=000000=7=Z@3AcJT04P3AcJT4@0000080dLfY140000030=7=Z@900000103AcJT2
@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2
@00000D0dLfY0d0000020=7=Z@900000103AcJT2@00001<0dLfY140000020=7=Z@A000000`3AcJT2
@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T0000030=7=Z@E000000P3AcJT2
@00000@0dLfY0T0000030=7=Z@E0000000<0dLfY@000040000000d000000103AcJU00000@0000400
000C0=7=Z@A000000P3AcJT4@00000<0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T00
00040=7=Z@9000000`3AcJT5@0000080dLfY0T0000040=7=Z@9000000`3AcJT5@00000030=7=ZD00
00100000009000000P3AcJT5@0000140dLfY000@0=7=Z@03@000003AcJT0dLfY00<0dLfY00=00000
0=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY
00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000
003AcJT0dLfY@00000D0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD000002
0=7=Z@03@000003AcJT0dLfY0100dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@03
0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU0
00001@3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=
Z@3AcJT04P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=
Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY
00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000050=7=Z@04@000
003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0@0=7=
Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD000002
0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000@0dLfY00E000000=7=Z@3AcJT0dLfY@0000002
0=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=
Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT04@3AcJT00d000000dLfY0=7=
Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT0
14000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000070=7=
Z@03@000003AcJT0dLfY0140dLfY000A0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3A
cJT00P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A00000
0=7=Z@3AcJU000001@3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@0000080dLfY
00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00E0
000000D0dLfY@000003AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@00001<0dLfY00=00000
0=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A0
00000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000050=7=Z@03@000003AcJT0dLfY00<0
dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0
dLfY00<0dLfY00=000000=7=Z@3AcJT01D0000001@3AcJU000000=7=Z@3AcJU0000000@0dLfY00=0
00000=7=Z@3AcJT04`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY00A0
00000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@000
00D0dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0
dLfY@0000080dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@05@00000050=7=ZD00
0000dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD00000C0=7=Z@03@000003AcJT0dLfY00<0
dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00A000000=7=Z@3AcJU000001@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003A
cJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY00<0dLfY
00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY
0d00000C0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000001@3AcJT0
0d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@000
00020=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=
Z@020=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT04@3AcJT00180dLfY00=00000
0=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU00000
0P3AcJT014000000dLfY0=7=Z@3AcJT2@00000@0dLfY0T0000040=7=Z@9000000`3AcJT014000000
dLfY0=7=ZD0000030=7=Z@900000103AcJT2@00000<0dLfY00A000000=7=Z@3AcJU000000P3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@=000005@3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003A
cJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY0=7=
Z@900000103AcJT2@00000@0dLfY0T0000030=7=Z@04@000003AcJT0dLfY@00000<0dLfY0T000004
0=7=Z@9000000`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000D0dLfY
00=000000=7=Z@3AcJT04`3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD00
00000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY0=7=Z@900000103AcJT2
@00000@0dLfY0T0000030=7=Z@04@000003AcJT0dLfY@00000<0dLfY0T0000040=7=Z@9000000`3A
cJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000<0dLfY0T00000E0=7=Z@03
@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00A000000=7=Z@3AcJT0dLfY0T0000040=7=Z@900000103AcJT2@00000D0dLfY00E0
00000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY0=7=Z@9000001@3AcJT00d000000
dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0B0=7=
Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0
dLfY@0000080dLfY00A000000=7=Z@3AcJT0dLfY0T0000040=7=Z@900000103AcJT2@00000D0dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY0=7=Z@9000001@3AcJT00d00
0000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT04@3AcJT00100
dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0
dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03
@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000020=7=
Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY@0000002
0=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT04P3AcJT014000000dLfY0=7=
ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT00`3A
cJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU0
00000`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJU000000080dLfY00A000000=7=Z@3A
cJU000000P3AcJT014000000dLfY0=7=ZD00000C0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A0
00000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@000
0080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0
dLfY0080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000
003AcJT0dLfY00<0dLfY00=000000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04
@000003AcJT0dLfY@0000180dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000
dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0103AcJT01D00
0000dLfY0=7=Z@3AcJU000000080dLfY00E000000=7=Z@3AcJT0dLfY@00000060=7=Z@03@000003A
cJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0100dLfY
00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000
003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0103AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00E000000=7=Z@3AcJT0dLfY@00000060=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT0
0d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0140dLfY000A0=7=Z@900000103AcJT2@000
00@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0d0000030=7=Z@=000000`3AcJT2@000
00@0dLfY0T0000040=7=Z@=00000103AcJT2@00000<0dLfY0T0000040=7=Z@=000004`3AcJT2@000
00@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@=000000`3AcJT3@000
00<0dLfY0T0000040=7=Z@900000103AcJT3@00000@0dLfY0T0000030=7=Z@9000000`3AcJT4@000
01@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT3@000
00<0dLfY0d0000030=7=Z@900000103AcJT2@00000@0dLfY0d0000040=7=Z@9000000`3AcJT2@000
00@0dLfY0T00000D0=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@000
00@0dLfY0d0000030=7=Z@=000000`3AcJT2@00000@0dLfY0T0000040=7=Z@=000000`3AcJT2@000
00@0dLfY0T0000040=7=Z@=000004`3AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@000
00@0dLfY0T0000040=7=Z@=000000`3AcJT3@00000<0dLfY0T0000040=7=Z@900000103AcJT3@000
00<0dLfY0T0000040=7=Z@900000103AcJT2@00001<0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY
003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY
000J0=7=Z@8000001`3oool00`000000oooo0000000200000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000060?ooo`<0
00001@3oool01`000000oooo0?ooo`000000oooo0000003oool09P3AcJT00`000000oooo0?ooo`06
0?ooo`<000003P3oool010000000oooo0000000000020?ooo`030000003oool0oooo00T0oooo00P0
00000?ooo`00000000000?ooo`000000oooo00000080oooo00<000000?ooo`3AcJT09P3AcJT20000
00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`<00000103oool2
00000080oooo00<000000?ooo`3oool0103oool2000000h0oooo00@000000?ooo`000000oooo9P3A
cJT2000000<0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool000000080oooo
0P0000030?ooo`@000004P3oool010000000oooo0000003ooolV0=7=Z@8000000P3oool00`000000
oooo0?ooo`0:0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`000000103oool00`00
0000oooo0?ooo`0=0?ooo`060000003oool000000?ooo`000000oooo6`3AcJT001X0dLfY00<0oooo
000000000000103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00`3oool200000080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09P3AcJT0103oool00000
0000000000020?ooo`8000004P3oool00`000000oooo000000030?ooo`030000003oool0000000T0
oooo00H000000?ooo`000000oooo0000003oool2000000040?ooo`000000oooo0?ooobL0dLfY00<0
oooo0000000000000P3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`00000<0?ooo`030000003oool0000000L0oooo0P0000070?oo
o`030000003oool0oooo02H0dLfY00<0oooo0000000000000P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0000000@0000000D0
oooo0000003oool0oooo000000040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0V0=7=Z@030?ooo`000000000000@0oooo00<000000?ooo`00
00001P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool01`3oool2000000H0oooo0`0000040?ooo`030000003oool0oooo01/0dLfY000J0=7=Z@<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000090?ooo`<000000`3ooolV0=7=
Z@<0oooo00<000000?ooo`0000000P3oool00`000000oooo0000000:0?ooo`030000003oool00000
008000000`3oool010000000oooo0?ooo`00000>0?ooo`030000003oool000000080oooo00@00000
0?ooo`3oool0oooo9`3AcJT30?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool0oooo
0`0000030?ooobH0dLfY0`3oool020000000oooo0000003oool000000?ooo`000000oooo0P000007
0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P000003
0?ooo`80000000<0oooo0000003oool00P0000000`3oool000000?ooo`020?ooo`040000003oool0
oooo0?ooobH0dLfY0`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000D0oooo00@0
00000?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo00@0oooo0P0000001@3oool00000
0?ooo`3oool0000000L0oooo00@000000?ooo`3oool0oooo0`0000030?oooa/0dLfY000J0=7=Z@H0
oooo0P0000020?ooo`040000003oool000000?ooo`8000002@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00D0oooo9P3AcJT=0?ooo`<0000000<0oooo0000003oool04@3oool01`000000oooo0000
003oool000000?ooo`0000003@3ooolW0=7=Z@H0oooo0P0000080?ooo`040000003oool0oooo0?oo
o`<000000P3oool00`000000oooo0?ooo`050?ooo`800000103oool2000000@0oooo00@000000?oo
o`3oool000001`3ooolV0=7=Z@P0oooo0P0000030?ooo`<000002P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203ooolV0=7=Z@X0oooo0P000006
0?ooo`030000003oool0oooo00<0000000@0oooo0000003oool000001@3oool3000000L0oooo0`00
00030?ooo`030000003oool0oooo00D0oooo6`3AcJT001X0dLfY1@3oool010000000oooo0?ooo`00
00020?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0oooo0080
00001@3oool2000000D0oooo0`00000@0?ooobH0dLfY3P3oool010000000oooo0?ooo`3oool20000
01D0oooo00<000000?ooo`3oool0303ooolW0=7=Z@D0oooo00@000000?ooo`3oool000000P3oool5
000000<0oooo00<000000?ooo`000000103oool010000000oooo0000000000020?ooo`040000003o
ool0oooo000000H0oooo0P00000<0?ooobH0dLfY1P3oool2000000D0oooo0P00000:0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000002P3oool010000000oooo0000000000070?oo
obH0dLfY1@3oool00`000000oooo0?ooo`080?ooo`@000000`3oool00`000000oooo0?ooo`090?oo
o`040000003oool0000000000180oooo6`3AcJT001X0dLfY2@3oool00`000000oooo0?ooo`040?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`040000003oool0
oooo000000@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`070?ooobH0dLfY
3@3oool2000002T0oooo9`3AcJT;0?ooo`030000003oool000000080oooo1@0000040?ooo`060000
003oool0oooo0000003oool000000`3oool3000000050?ooo`00000000000?ooo`0000000P3oool0
0`000000oooo000000090?ooobH0dLfY1P3oool2000000030?ooo`000000oooo0080oooo00@00000
0?ooo`3oool000002P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000103oool2000000L0oooo9P3AcJT90?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`040?ooo`80000000T0oooo0000003o
ool0oooo0000003oool000000?ooo`0000000`3oool2000000030?ooo`000000oooo008000002@3o
oolK0=7=Z@006P3AcJT:0?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo0080oooo0P00
00050?ooo`030000003oool0oooo00H0oooo9P3AcJTM0?ooo`8000002P3oool2000000d0oooo9`3A
cJTA0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool01`3oool200000080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooobH0dLfY2P3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000020?oo
o`800000103oool2000000d0oooo9P3AcJT:0?ooo`<000001@3oool010000000oooo0?ooo`3oool2
00000080oooo0P0000000`3oool000000?ooo`080?ooo`030000003oool0oooo0080oooo0P000002
0?ooo`030000003oool0oooo00H0oooo6`3AcJT001X0dLfY2`3oool01@000000oooo0?ooo`3oool0
000000@0oooo0P0000030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00050?ooo`050000003oool0oooo0?ooo`0000002`3ooolV0=7=ZAH0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0D0?ooobL0dLfY2`3oool01@000000oooo0?ooo`3oool0000000<0
oooo0P000000103oool000000?ooo`0000030?ooo`040000003oool0oooo0?ooo`<000000P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo9P3AcJTD0?ooo`030000003oool0
oooo00/0oooo0P0000080?ooo`030000003oool0oooo00T0oooo9P3AcJT;0?ooo`040000003oool0
oooo0?ooo`<000002`3oool00`000000oooo0?ooo`080?ooo`8000003`3ooolK0=7=Z@006P3AcJT8
0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`000000oooo0`0000030?ooo`030000003o
ool0oooo00@0oooo100000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3o
oolV0=7=Z@P0oooo00@000000?ooo`3oool0oooo0`0000030?ooo`030000003oool0oooo00<0oooo
0`0000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo
000000000000oooo008000002@3ooolW0=7=Z@P0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00L0oooo9P3AcJT80?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool01P000000oooo0?ooo`3oool000000?ooo`800000103oool2000000030?ooo`00
0000oooo00H0oooo0P0000030?ooo`030000003oool0oooo00L0oooo9P3AcJT80?ooo`030000003o
ool0oooo00<0oooo0`0000050?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool01@3o
ool2000000D0oooo00<000000?ooo`3oool01`3ooolK0=7=Z@006P3AcJT90?ooo`<00000103oool0
1@000000oooo0000003oool0000000d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00P0oooo9P3AcJT90?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0203oool2000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00020?ooo`030000003oool0oooo00P0oooo9`3AcJT90?ooo`<000000P3oool00`000000oooo0?oo
o`0200000080oooo00<000000?ooo`3oool03@3oool2000000H0oooo00<000000?ooo`3oool0203o
oolV0=7=Z@T0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool03@3oool01P000000oooo0?ooo`000000oooo000000X0oooo9P3AcJT9
0?ooo`8000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo0P00000:
0?ooo`030000003oool00000008000002P3ooolK0=7=Z@006P3AcJT:0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0303oool00`000000oooo000000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02@3ooolV0=7=Z@X0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo00000003
000000/0oooo9`3AcJT:0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool000000100oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooobH0dLfY
2P3oool6000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo000000030?ooo`030000
003oool0oooo00H0oooo0P00000;0?ooobH0dLfY2P3oool2000000@0oooo00<000000?ooo`000000
4`3oool3000000@0oooo00<000000?ooo`3oool02@3ooolK0=7=Z@006P3AcJT;0?ooo`800000103o
ool00`000000oooo000000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`03000000`0oooo9P3AcJT;0?ooo`80000000<0oooo0000003oool00`00
00000`3oool00000000000040?ooo`<000001@3oool2000000050?ooo`00000000000?ooo`000000
0P3oool00`000000oooo0?ooo`0:0?ooobL0dLfY2`3oool2000000X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo000000030?ooo`<00000303ooolV0=7=Z@/0oooo0P0000020?ooo`030000
003oool0000000D0oooo00D000000?ooo`00000000000?ooo`02000000@0oooo00<000000?ooo`00
00000`0000030?ooo`030000003oool0oooo00X0oooo9P3AcJT<0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`0000004@3oool010000000oooo0?ooo`3oool3000000`0oooo6`3AcJT001X0
dLfY3`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0?ooo`8000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo9P3AcJTG0?ooo`030000003oool00000
01h0oooo9`3AcJT?0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000403ooolV0=7=Z@d0oooo0P00
00090?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303ooolV0=7=ZA@0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`030000003oool00000008000000`3oool00`000000oooo
0?ooo`0>0?oooa/0dLfY000J0=7=Z@h0oooo00@000000?ooo`3oool00000303oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000140oooo9P3AcJTG0?ooo`8000007`3ooolW0=7=Z@h0
oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`000000oooo0080000000<0oooo
0000003oool0103oool01@000000oooo0?ooo`3oool000000140oooo9P3AcJTH0?ooo`060000003o
ool0oooo0?ooo`000000oooo0P00000H0?ooobH0dLfY3P3oool00`000000oooo0?ooo`0X0?oooa/0
dLfY000J0=7=ZA80oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooobH0dLfY
>03ooolW0=7=ZAD0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0000
003oool00P0000000`3oool000000?ooo`0A0?ooobH0dLfY4P3oool01@000000oooo0?ooo`3oool0
000000T0oooo0P0000030?ooo`030000003oool0oooo0100oooo9P3AcJTB0?ooo`800000103oool0
0`000000oooo0?ooo`050?ooo`80000000<0oooo0000003oool00P00000B0?oooa/0dLfY000J0=7=
ZA00oooo00D000000?ooo`3oool000000?ooo`02000000040?ooo`000000oooo0?ooo`80000000@0
oooo000000000000oooo0P00000E0?ooobH0dLfY>03ooolW0=7=ZA00oooo00<000000?ooo`3oool0
103oool2000000040?ooo`000000oooo00000080oooo00@000000?ooo`3oool000005@3ooolV0=7=
ZA00oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`060000003oool0
oooo0000003oool000005P3ooolV0=7=ZA@0oooo0P0000080?ooo`030000003oool0oooo0080oooo
0P0000020?ooo`030000003oool0oooo00l0oooo6`3AcJT001X0dLfY503oool01P000000oooo0?oo
o`000000oooo000000H0oooo00@000000?ooo`3oool00000503ooolV0=7=ZCP0oooo9`3AcJTD0?oo
o`030000003oool000000080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`030000003oool0
000001@0oooo9P3AcJTI0?ooo`8000000P3oool00`000000oooo0?ooo`0H0?ooobH0dLfY503oool0
10000000oooo0?ooo`3oool2000000D0oooo0P00000H0?oooa/0dLfY000J0=7=ZA40oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`8000004@3ooolV0=7=ZA40oooo00@00000
0?ooo`3oool0oooo0P0000020?ooo`80000000D0oooo0000003oool000000?ooo`03000000040?oo
o`000000000000000140oooo9`3AcJTA0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02`3oool200000140oooo9P3AcJTA0?ooo`800000103oool4000000030?ooo`000000oooo00<0
00000`3oool300000140oooo9P3AcJTA0?ooo`030000003oool0oooo00<0oooo0`0000020?ooo`03
0000003oool0oooo008000001@3oool00`000000oooo0?ooo`0@0?oooa/0dLfY000J0=7=ZA80oooo
0`0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04@3ooolV0=7=ZA80oooo
00@000000?ooo`3oool00000103oool010000000oooo0000000000060?ooo`030000003oool0oooo
0140oooo9`3AcJTB0?ooo`<000003`3oool00`000000oooo0?ooo`0A0?ooobH0dLfY4P3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0000003oool00P0000020?ooo`050000003oool0
oooo0?ooo`0000004`3ooolV0=7=ZA80oooo0P0000020?ooo`040000003oool0oooo00000080oooo
0P0000030?ooo`030000003oool00000008000004`3ooolK0=7=Z@006P3AcJTC0?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`00000000001@3oool00`000000oooo0?ooo`0B0?ooobH0dLfY
4`3oool00`000000oooo000000040?ooo`030000003oool0000000<0oooo00@000000?ooo`000000
0000503ooolW0=7=ZA<0oooo00<000000?ooo`3oool01`3oool00`000000oooo000000030?ooo`03
0000003oool0oooo0180oooo9P3AcJTC0?ooo`030000003oool0000000L0oooo00<000000?ooo`00
00000P3oool2000001@0oooo9P3AcJTD0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0B0?oooa/0dLfY000J0=7=ZA@0oooo0P0000070?ooo`060000
003oool0oooo0000003oool000005@3ooolV0=7=ZA@0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo000000020?ooo`040000003oool0oooo000001D0oooo9`3AcJTD0?ooo`8000000P3o
ool2000000@0oooo00D000000?ooo`000000oooo0000000E0?ooobH0dLfY503oool2000000P0oooo
0P0000020?ooo`030000003oool0oooo01<0oooo9P3AcJTE0?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000020?ooo`<000005@3ooolK0=7=Z@006P3AcJTE0?ooo`800000
0`3oool00`000000oooo000000040?ooo`030000003oool0oooo01@0oooo9P3AcJTE0?ooo`<00000
0P3oool00`000000oooo000000040?ooo`030000003oool0oooo01@0oooo9`3AcJTE0?ooo`800000
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000001H0oooo9P3AcJTE0?ooo`80
00000P3oool2000000<0oooo00@000000?ooo`3oool000005P3ooolV0=7=ZAH0oooo00<000000?oo
o`3oool01@3oool01@000000oooo0?ooo`3oool0000001H0oooo6`3AcJT001X0dLfY5`3oool00`00
0000oooo0000000N0?ooobH0dLfY>03ooolW0=7=ZAL0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0I0?ooobH0dLfY5`3oool01@000000oooo0000003oool000000080oooo00<00000
0?ooo`3oool05`3ooolV0=7=ZAL0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0J
0?oooa/0dLfY000J0=7=ZCP0oooo9P3AcJTh0?ooobL0dLfY>03ooolV0=7=ZCP0oooo9P3AcJTK0?oo
o`<000006`3ooolK0=7=Z@006P3AcJTI0?ooo`030000003oool0oooo01`0oooo9P3AcJTh0?ooobL0
dLfY6@3oool00`000000oooo0?ooo`0L0?ooobH0dLfY>03ooolV0=7=ZAh0oooo00<000000?ooo`3o
ool0603ooolK0=7=Z@006P3AcJTK0?ooo`030000003oool0oooo01X0oooo9P3AcJTh0?ooobL0dLfY
6`3oool00`000000oooo0?ooo`0J0?ooobH0dLfY6P3oool00`000000oooo0000000K0?ooobH0dLfY
703oool00`000000oooo0?ooo`0J0?oooa/0dLfY000J0=7=ZAX0oooo00@000000?ooo`3oool00000
6P3ooolV0=7=ZAX0oooo0P0000000`3oool000000?ooo`0I0?ooobL0dLfY6P3oool010000000oooo
0?ooo`00000J0?ooobH0dLfY6P3oool2000000030?ooo`000000oooo01T0oooo9P3AcJTJ0?ooo`04
0000003oool0oooo000001/0oooo6`3AcJT001X0dLfY6`3oool2000001/0oooo9P3AcJTK0?ooo`80
00006`3ooolW0=7=ZA/0oooo0P00000K0?ooobH0dLfY6`3oool2000001/0oooo9P3AcJTK0?ooo`80
0000703ooolK0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=
Z@00o`3AcJWX0=7=Z@00403AcJT4@0000080dLfY140000030=7=Z@900000103AcJT2@00000D0dLfY
0d000000103AcJU00000@000040000050=7=Z@03@000003AcJT0dLfY0080dLfY0T0000050=7=Z@03
@000003AcJT0dLfY0080dLfY0T0000030=7=Z@=000000`3AcJT5@0000080dLfY0T00000C0=7=Z@A0
00000P3AcJT4@00000<0dLfY0T0000040=7=Z@9000001@3AcJT3@00000040=7=ZD0000100000@000
00D0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000<0dLfY0d0000040=7=Z@900000103AcJT2@000
00<0dLfY140000020=7=Z@A000004`3AcJT4@0000080dLfY140000030=7=Z@900000103AcJT2@000
00D0dLfY0d000000103AcJU00000@000040000050=7=Z@03@000003AcJT0dLfY0080dLfY0T000003
0=7=Z@=00000103AcJT2@00000@0dLfY0T0000030=7=Z@A000000`3AcJT2@00001<0dLfY14000002
0=7=Z@A000000`3AcJT2@00000@0dLfY0T0000050=7=Z@=0000000@0dLfY@0000400001000001@3A
cJT014000000dLfY0=7=Z@3AcJT5@00000030=7=ZD000010000000=000000P3AcJT2@00000@0dLfY
0T0000040=7=Z@900000103AcJT2@00001<0dLfY140000020=7=Z@A000000`3AcJT2@00000@0dLfY
0T0000050=7=Z@=0000000@0dLfY@0000400001000001@3AcJT014000000dLfY0=7=Z@3AcJT5@000
00030=7=ZD000010000000=000000P3AcJT2@00000@0dLfY0T0000040=7=Z@9000000`3AcJT3@000
01<0dLfY000@0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT014000000
dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000D0dLfY00A000000=7=Z@3AcJU000000P3A
cJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY
0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=
Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0
dLfY0100dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0
dLfY@0000080dLfY00A000000=7=Z@3AcJU000001@3AcJT014000000dLfY0=7=ZD0000020=7=Z@03
@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY
0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A0
00000=7=Z@3AcJU000001@3AcJT00d000000dLfY0=7=Z@0D0=7=Z@03@000003AcJT0dLfY00<0dLfY
00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@000
00D0dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0
dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD000000
0P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000D0dLfY00A000000=7=
Z@3AcJU000004P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00A00000
0=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000050=7=Z@04@000003AcJT0dLfY@0000080
dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0
dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A00000
0=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0100dLfY
00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@0000080
dLfY00A000000=7=Z@3AcJU000001@3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0
dLfY0080dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0
dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080
dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0@0=7=Z@004@3AcJT00d000000
dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU000000P3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@E0000000D0dLfY@000003AcJT0dLfY@00000040=7=Z@05@000003A
cJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00<0dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0140dLfY00=000000=7=Z@3AcJT00`3AcJT00d00
0000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3A
cJT5@00000050=7=ZD000000dLfY0=7=ZD000000103AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00A000000=7=Z@3AcJT0dLfY0d0000040=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=
Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY01@0dLfY00=000000=7=
Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A00000
0=7=Z@3AcJU000000P3AcJT5@00000050=7=ZD000000dLfY0=7=ZD000000103AcJT01D000000dLfY
0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJT0dLfY0d0000040=7=Z@03@000003AcJT0dLfY
00<0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY
0180dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT5@00000050=7=ZD000000dLfY0=7=ZD000000
103AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0
0`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000
dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY0140dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000
dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT5
@00000050=7=ZD000000dLfY0=7=ZD000000103AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003A
cJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY
00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3A
cJT0403AcJT00180dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0
dLfY00=000001P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00<0dLfY00=0
00000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@03@00000D0dLfY00E000000=7=Z@3AcJT0dLfY
@00000020=7=Z@03@000003AcJT0dLfY0180dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY
0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD000002
0=7=Z@03@000003AcJT0dLfY00=000001P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003A
cJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000
003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0D0=7=Z@03@000
003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@000
0080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@03@00000H0dLfY00A00000
0=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00<0dLfY
00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00@0dLfY
00=000000=7=Z@3AcJT04P3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD00
00000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=00000
0=7=Z@3AcJT00d0000060=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00`3AcJT0
0d000000dLfY0=7=Z@040=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00`3A
cJT014000000dLfY0=7=Z@3AcJT2@00001D0dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY
0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD000002
0=7=Z@03@000003AcJT0dLfY00=000001P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0
dLfY00<0dLfY00=000000=7=Z@3AcJT0103AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003A
cJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00d00000C0=7=Z@00403AcJT014000000dLfY0=7=ZD00
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000
dLfY0=7=ZD0000030=7=Z@03@000003AcJU0000000<0dLfY00=000000=7=Z@3AcJT00P3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000
0P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00@0dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0100dLfY00A000000=7=Z@3AcJU000000P3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU0
00000`3AcJT00d000000dLfY@00000030=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3A
cJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A0
00000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@000
0080dLfY00A000000=7=Z@3AcJU000004`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003A
cJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000030=7=
Z@03@000003AcJU0000000<0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD000002
0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT0
14000000dLfY0=7=ZD00000B0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU0
00000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=00000
0=7=ZD0000000`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=0
00000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU0
00000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@05@000003AcJT0dLfY0=7=ZD000000503AcJT0
14000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU0
00000P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJU0000000<0dLfY00=000000=7=
Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY00<0dLfY00E00000
0=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU0
00000P3AcJT01D000000dLfY0=7=Z@3AcJU0000001@0dLfY000A0=7=Z@900000103AcJT2@00000@0
dLfY0T0000040=7=Z@9000001@3AcJT2@00000<0dLfY0d0000020=7=Z@A000000`3AcJT2@00000<0
dLfY140000030=7=Z@900000103AcJT3@00000<0dLfY0T0000040=7=Z@900000503AcJT2@00000@0
dLfY0T0000040=7=Z@900000103AcJT2@00000D0dLfY0T0000030=7=Z@=000000P3AcJT4@00000<0
dLfY0T0000040=7=Z@=000000`3AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00001D0
dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T0000050=7=Z@9000000`3AcJT3@0000080
dLfY140000030=7=Z@900000103AcJT3@00000<0dLfY0T0000040=7=Z@900000103AcJT2@00000@0
dLfY0T00000D0=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@9000001@3AcJT2@00000<0
dLfY0d0000020=7=Z@A000000`3AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0
dLfY0T0000040=7=Z@=000004`3AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000D0
dLfY0T0000030=7=Z@=000000P3AcJT4@00000<0dLfY0T0000040=7=Z@900000103AcJT2@00000@0
dLfY0T0000040=7=Z@900000103AcJT3@0000180dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o
0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o
0=7=ZNP0dLfY000J0=7=ZAL0oooo00D000000?ooo`3oool0oooo0000000L0?ooobH0dLfY603oool2
000000<0oooo1000000G0?ooobL0dLfY>03ooolV0=7=ZA`0oooo00<000000?ooo`3oool06@3ooolV
0=7=ZAP0oooo0P0000040?ooo`050000003oool000000?ooo`0000005P3ooolK0=7=Z@006P3AcJTH
0?ooo`8000000`3oool3000001P0oooo9P3AcJTG0?ooo`<0000000D0oooo0000003oool0oooo0000
000I0?ooobL0dLfY>03ooolV0=7=ZAX0oooo00@000000?ooo`3oool000006P3ooolV0=7=ZAX0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?oooa/0dLfY000J0=7=ZAH0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0000001H0oooo9P3AcJTH0?ooo`800000
0`3oool3000001P0oooo9`3AcJTh0?ooobH0dLfY703oool00`000000oooo0?ooo`0I0?ooobH0dLfY
6P3oool3000001`0oooo6`3AcJT001X0dLfY6@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01L0oooo9P3AcJTK0?ooo`030000003oool0oooo01X0oooo9`3AcJTh0?ooobH0dLfY703o
ool2000001X0oooo9P3AcJTE0?ooo`050000003oool0oooo0?ooo`0000001@3oool01@000000oooo
0000003oool0000001D0oooo6`3AcJT001X0dLfY6`3oool3000001X0oooo9P3AcJTI0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool05`3ooolW0=7=ZCP0oooo9P3AcJTI0?ooo`800000
00<0oooo0000003oool06P3ooolV0=7=ZAD0oooo100000060?ooo`80000000<0oooo0000003oool0
5@3ooolK0=7=Z@006P3AcJTh0?ooobH0dLfY6`3oool3000001X0oooo9`3AcJTh0?ooobH0dLfY703o
ool2000001X0oooo9P3AcJTF0?ooo`<0000000<0oooo0000003oool0103oool00`000000oooo0000
000F0?oooa/0dLfY000J0=7=ZAP0oooo00<000000?ooo`0000007@3ooolV0=7=ZCP0oooo9`3AcJTh
0?ooobH0dLfY6@3oool2000000030?ooo`000000oooo01X0oooo9P3AcJTF0?ooo`8000001@3oool2
00000080oooo00<000000?ooo`3oool05@3ooolK0=7=Z@006P3AcJTJ0?ooo`030000003oool0oooo
01/0oooo9P3AcJTH0?ooo`030000003oool0000001d0oooo9`3AcJTh0?ooobH0dLfY703oool20000
01X0oooo9P3AcJTE0?ooo`030000003oool0000000D0000000<0oooo0000003oool00P00000G0?oo
oa/0dLfY000J0=7=ZAP0oooo0P0000050?ooo`030000003oool0oooo01H0oooo9P3AcJTG0?ooo`05
0000003oool000000?ooo`000000703ooolW0=7=ZCP0oooo9P3AcJTJ0?ooo`040000003oool0oooo
000001X0oooo9P3AcJTO0?ooo`030000003oool0oooo01L0oooo6`3AcJT001X0dLfY7P3oool00`00
0000oooo0?ooo`0G0?ooobH0dLfY603oool2000000D0oooo00<000000?ooo`3oool05P3ooolW0=7=
ZCP0oooo9P3AcJTL0?ooo`030000003oool0oooo01T0oooo9P3AcJTi0?oooa/0dLfY000J0=7=ZCP0
oooo9P3AcJTN0?ooo`030000003oool0oooo01L0oooo9`3AcJTh0?ooobH0dLfY6P3oool010000000
oooo0?ooo`00000J0?ooobH0dLfY5`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01P0oooo6`3AcJT001X0dLfY>03ooolV0=7=ZCP0oooo9`3AcJTh0?ooobH0dLfY703oool00`000000
oooo0?ooo`0I0?ooobH0dLfY>@3ooolK0=7=Z@006P3AcJTO0?ooo`030000003oool0oooo01H0oooo
9P3AcJTG0?ooo`030000003oool0oooo01h0oooo9`3AcJTh0?ooobH0dLfY703oool2000001X0oooo
9P3AcJTG0?ooo`<00000103oool00`000000oooo0000000H0?oooa/0dLfY000J0=7=ZAP0oooo0P00
00000`3oool000000000000K0?ooobH0dLfY7`3oool00`000000oooo0?ooo`0F0?ooobL0dLfY>03o
oolV0=7=ZAT0oooo0P0000000`3oool000000?ooo`0J0?ooobH0dLfY5`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0000001T0oooo6`3AcJT001X0dLfY603oool01@000000oooo0?ooo`3o
ool0000001/0oooo9P3AcJTH0?ooo`80000000<0oooo0000000000006`3ooolW0=7=ZCP0oooo9P3A
cJTL0?ooo`8000006P3ooolV0=7=ZAd0oooo00<000000?ooo`0000006@3ooolK0=7=Z@006P3AcJTI
0?ooo`<000000P3oool00`000000oooo0?ooo`0G0?ooobH0dLfY603oool01@000000oooo0?ooo`3o
ool0000001/0oooo9`3AcJTh0?ooobH0dLfY6@3oool2000000030?ooo`000000oooo01X0oooo9P3A
cJTL0?ooo`030000003oool0oooo01X0oooo6`3AcJT001X0dLfY7@3oool00`000000oooo0?ooo`0H
0?ooobH0dLfY6@3oool300000080oooo00<000000?ooo`3oool05`3ooolW0=7=ZCP0oooo9P3AcJTL
0?ooo`8000006P3ooolV0=7=ZAX0oooo00<000000?ooo`3oool0703ooolK0=7=Z@006P3AcJTH0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3ooolV0=7=ZAl0oooo00<000000?oo
o`3oool05P3ooolW0=7=ZCP0oooo9P3AcJTJ0?ooo`040000003oool0oooo000001X0oooo9P3AcJTH
0?ooo`040000003oool0oooo000000<0oooo0P00000H0?oooa/0dLfY000J0=7=ZAP0oooo00<00000
0?ooo`3oool07@3ooolV0=7=ZAP0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G
0?ooobL0dLfY7@3oool00`000000oooo0?ooo`0H0?ooobH0dLfY703oool00`000000oooo0?ooo`0I
0?ooobH0dLfY6@3oool00`000000oooo0?ooo`04000001T0oooo6`3AcJT001X0dLfY7P3oool00`00
0000oooo0?ooo`0G0?ooobH0dLfY603oool00`000000oooo0?ooo`0M0?ooobL0dLfY6P3oool00`00
0000oooo0?ooo`0K0?ooobH0dLfY6P3oool010000000oooo0?ooo`00000J0?ooobH0dLfY6@3oool0
10000000oooo0000003oool2000001X0oooo6`3AcJT001X0dLfY6@3oool2000001d0oooo9P3AcJTN
0?ooo`030000003oool0oooo01L0oooo9`3AcJTJ0?ooo`040000003oool0oooo000001X0oooo9P3A
cJTL0?ooo`030000003oool0oooo01T0oooo9P3AcJTJ0?ooo`030000003oool0oooo008000006P3o
oolK0=7=Z@006P3AcJTI0?ooo`030000003oool0oooo01`0oooo9P3AcJTI0?ooo`8000007@3ooolW
0=7=ZAT0oooo00D000000?ooo`000000oooo0000000J0?ooobH0dLfY703oool00`000000oooo0?oo
o`0I0?ooobH0dLfY6P3oool2000000040?ooo`000000oooo000001T0oooo6`3AcJT001X0dLfY>03o
oolV0=7=ZAX0oooo00<000000?ooo`0000006`3ooolW0=7=ZAT0oooo00D000000?ooo`000000oooo
0000000J0?ooobH0dLfY6P3oool00`000000oooo0?ooo`0K0?ooobH0dLfY703oool00`000000oooo
0?ooo`0J0?oooa/0dLfY000J0=7=ZCP0oooo9P3AcJTh0?ooobL0dLfY703oool2000001X0oooo9P3A
cJTK0?ooo`<000006P3ooolV0=7=ZCT0oooo6`3AcJT001X0dLfY>03ooolV0=7=ZCP0oooo9`3AcJTJ
0?ooo`030000003oool0oooo01/0oooo9P3AcJTJ0?ooo`800000703ooolV0=7=ZAd0oooo00<00000
0?ooo`3oool06@3ooolK0=7=Z@006P3AcJTK0?ooo`030000003oool0oooo01X0oooo9P3AcJTh0?oo
obL0dLfY6P3oool00`000000oooo0000000K0?ooobH0dLfY6P3oool00`000000oooo0?ooo`0K0?oo
obH0dLfY>@3ooolK0=7=Z@006P3AcJTJ0?ooo`030000003oool0oooo01/0oooo9P3AcJTJ0?ooo`03
0000003oool0oooo01/0oooo9`3AcJTh0?ooobH0dLfY>03ooolV0=7=ZA/0oooo00<000000?ooo`00
00006`3ooolK0=7=Z@006P3AcJTK0?ooo`8000006`3ooolV0=7=ZA/0oooo0P00000K0?ooobL0dLfY
6`3oool2000001/0oooo9P3AcJTK0?ooo`8000006`3ooolV0=7=ZA/0oooo0P00000L0?oooa/0dLfY
003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY
000@0=7=Z@E000000P3AcJT2@00000<0dLfY0d0000040=7=Z@9000000`3AcJT5@00000<0dLfY0d00
00020=7=Z@9000000`3AcJT3@00000D0dLfY0d0000020=7=Z@900000103AcJT2@00000<0dLfY0d00
00040=7=Z@9000004`3AcJT5@0000080dLfY0T0000030=7=Z@=00000103AcJT2@00000<0dLfY1D00
00030=7=Z@=000000P3AcJT2@00000<0dLfY0d0000050=7=Z@=000000P3AcJT2@00000@0dLfY0T00
00030=7=Z@=000000`3AcJT3@00001@0dLfY1D0000020=7=Z@9000000`3AcJT3@00000@0dLfY0T00
00040=7=Z@900000103AcJT2@00000<0dLfY0d0000030=7=Z@=000000`3AcJT5@00000<0dLfY00A0
00000=7=Z@3AcJT0dLfY0d0000050=7=Z@=000000P3AcJT2@00001<0dLfY1D0000020=7=Z@900000
0`3AcJT3@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000<0dLfY0d0000030=7=Z@=00000
103AcJT2@00000D0dLfY00A000000=7=Z@3AcJT0dLfY0d0000040=7=Z@900000103AcJT2@00001<0
dLfY1D000000103AcJU00000@000040000040=7=Z@9000000`3AcJT3@00000D0dLfY00=000000=7=
Z@3AcJT00P3AcJT2@00000D0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000D0dLfY0d0000020=7=
Z@9000000`3AcJT3@00000<0dLfY140000030=7=Z@9000004`3AcJT00180dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@0000002
0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0103AcJT014000000dLfY0=7=ZD00
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY
0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0180dLfY00E000000=7=Z@3AcJT0dLfY
@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03
@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0103AcJT014000000dLfY0=7=ZD0000020=7=
Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD00
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000
dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY01@0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=
Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0
dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04
@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=
Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0103AcJT014000000dLfY0=7=ZD000002
0=7=Z@03@000003AcJT0dLfY0180dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003A
cJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080
dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0
dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000
003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00=000000=7=Z@3AcJT04P3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0
dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU000000P3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000D0dLfY00A000000=7=Z@3AcJU0
00004P3AcJT00180dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY0=7=
Z@=000001@3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY0=7=Z@E0000000D0dLfY
@000003AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY1D0000040=7=Z@03@000
003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=
Z@03@000003AcJT0dLfY0180dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0
dLfY0=7=Z@=000001@3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY0=7=Z@E00000
00D0dLfY@000003AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY1D0000040=7=
Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=Z@3A
cJT3@00001D0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY0=7=Z@=0
00001@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT0
0d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY0d0000020=7=Z@E0000000D0dLfY
@000003AcJT0dLfY@000000D0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY
0=7=Z@3AcJT3@00000D0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0
dLfY0080dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=0
00000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY01<0dLfY00=0
00000=7=Z@3AcJT00P3AcJT3@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=
Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJT0dLfY1D0000030=7=Z@05@000003AcJT0
dLfY0=7=ZD0000000P3AcJT01D000000dLfY0=7=Z@3AcJU0000000@0dLfY00A000000=7=Z@3AcJU0
00004P3AcJT00180dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000<0dLfY00A000000=7=Z@3AcJU0
00000`3AcJT2@00000D0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY
0=7=Z@9000000`3AcJT3@00000<0dLfY00A000000=7=Z@3AcJU000000`3AcJT2@00000@0dLfY0T00
00030=7=Z@=00000103AcJT2@00001D0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000<0dLfY00A0
00000=7=Z@3AcJU000000`3AcJT2@00000D0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04
@000003AcJT0dLfY0=7=Z@9000000`3AcJT3@00000<0dLfY00A000000=7=Z@3AcJU000000`3AcJT2
@00000@0dLfY0T0000030=7=Z@=000000`3AcJT014000000dLfY0=7=ZD00000E0=7=Z@03@000003A
cJT0dLfY0080dLfY0T0000030=7=Z@04@000003AcJT0dLfY@00000<0dLfY0T0000040=7=Z@900000
1P3AcJT00d000000dLfY0=7=Z@03@00000<0dLfY0d0000050=7=Z@03@000003AcJT0dLfY00@0dLfY
00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00=000000=7=Z@3AcJT04P3AcJT00d000000dLfY0=7=Z@020=7=Z@9000000`3AcJT0
14000000dLfY0=7=ZD0000030=7=Z@900000103AcJT2@00000H0dLfY00=000000=7=Z@3AcJT00d00
00030=7=Z@=000001P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00=00000103A
cJT2@00000H0dLfY00=000000=7=Z@3AcJT04P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY
00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@03@00000H0dLfY00A000000=7=Z@3A
cJT0dLfY0T0000060=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU000000P3AcJT0
0d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00=000001@3AcJT01D000000dLfY0=7=Z@3A
cJU000000080dLfY00=000000=7=Z@3AcJT0403AcJT00180dLfY00E000000=7=Z@3AcJT0dLfY@000
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00E000000=7=Z@3AcJT0dLfY@00000060=7=Z@03
@000003AcJT0dLfY0080dLfY00=000000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000030=7=
Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=ZD0000000`3AcJT00d000000dLfY0=7=Z@030=7=
Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD00000D
0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@05@000
003AcJT0dLfY0=7=ZD0000001P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJU000000080
dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJU00000
00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY
0080dLfY00A000000=7=Z@3AcJU000005@3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A0
00000=7=Z@3AcJU000000P3AcJT01D000000dLfY0=7=Z@3AcJU0000000D0dLfY00=000000=7=Z@3A
cJT00P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=
Z@3AcJT0103AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3A
cJT01d000000dLfY0=7=Z@3AcJU000000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD00000D0=7=
Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@05@000003A
cJT0dLfY0=7=ZD0000001@3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@00000<0
dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@000
0080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0
dLfY0080dLfY00A000000=7=Z@3AcJU00000503AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY
00A000000=7=Z@3AcJU000000P3AcJT01D000000dLfY0=7=Z@3AcJU0000000@0dLfY00A000000=7=
Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY
00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY@00000020=7=Z@04@000003AcJT0dLfY@000
00<0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0
dLfY@0000180dLfY000A0=7=Z@900000103AcJT2@00000@0dLfY0d0000030=7=Z@=000000`3AcJT2
@00000D0dLfY0T0000030=7=Z@900000103AcJT3@00000@0dLfY0T0000030=7=Z@=000000`3AcJT3
@00000<0dLfY0d0000030=7=Z@900000503AcJT2@00000@0dLfY0T0000040=7=Z@=000000`3AcJT3
@00000<0dLfY0T0000050=7=Z@9000000`3AcJT2@00000@0dLfY0d0000040=7=Z@9000000`3AcJT3
@00000<0dLfY0d0000030=7=Z@=000000`3AcJT3@00001@0dLfY0T0000040=7=Z@900000103AcJT3
@00000<0dLfY0d0000030=7=Z@=000000`3AcJT2@00000@0dLfY0d0000030=7=Z@=000000`3AcJT2
@00000<0dLfY140000030=7=Z@=00000103AcJT2@00000<0dLfY0T00000D0=7=Z@900000103AcJT2
@00000@0dLfY0d0000030=7=Z@=000000`3AcJT3@00000<0dLfY0T0000040=7=Z@=000000`3AcJT3
@00000<0dLfY0T0000030=7=Z@A000000`3AcJT3@00000<0dLfY0d0000030=7=Z@900000503AcJT2
@00000@0dLfY0d0000030=7=Z@900000103AcJT3@0000080dLfY140000030=7=Z@9000000`3AcJT4
@00000<0dLfY0T0000050=7=Z@9000000`3AcJT2@00000@0dLfY0d0000030=7=Z@900000103AcJT2
@00001<0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o
0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY000J0=7=ZA/0oooo0P00
000K0?ooobH0dLfY>03ooolW0=7=ZAX0oooo0P0000000`3oool000000?ooo`0I0?ooobH0dLfY6@3o
ool00`000000oooo0?ooo`0L0?ooobH0dLfY8@3oool00`000000oooo0?ooo`0E0?oooa/0dLfY000J
0=7=ZA/0oooo0P00000K0?ooobH0dLfY>03ooolW0=7=ZAd0oooo00<000000?ooo`3oool0603ooolV
0=7=ZA/0oooo00<000000?ooo`0000006P3ooolV0=7=ZAL0oooo0`0000060?ooo`030000003oool0
oooo01H0oooo6`3AcJT001X0dLfY6`3oool2000001/0oooo9P3AcJTh0?ooobL0dLfY6P3oool30000
00030?ooo`000000oooo01P0oooo9P3AcJTJ0?ooo`<0000000<0oooo0000003oool0603ooolV0=7=
ZAP0oooo0P0000050?ooo`800000603ooolK0=7=Z@006P3AcJTh0?ooobH0dLfY>03ooolW0=7=ZCP0
oooo9P3AcJTh0?ooobH0dLfY6`3oool00`000000oooo000000030?ooo`030000003oool0oooo01D0
oooo6`3AcJT001X0dLfY>03ooolV0=7=ZCP0oooo9`3AcJTJ0?ooo`030000003oool0000001/0oooo
9P3AcJTJ0?ooo`030000003oool0000001/0oooo9P3AcJTG0?ooo`040000003oool0oooo0?ooo`80
0000703ooolK0=7=Z@006P3AcJTh0?ooobH0dLfY>03ooolW0=7=ZCP0oooo9P3AcJTh0?ooobH0dLfY
5`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo6`3AcJT001X0dLfY>03o
oolV0=7=ZCP0oooo9`3AcJTh0?ooobH0dLfY6`3oool2000001/0oooo9P3AcJTF0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0E0?oooa/0dLfY000J
0=7=ZCP0oooo9P3AcJTh0?ooobL0dLfY>03ooolV0=7=ZCP0oooo9P3AcJTF0?ooo`030000003oool0
oooo00<0oooo0P00000K0?oooa/0dLfY000J0=7=ZA/0oooo0P00000K0?ooobH0dLfY>03ooolW0=7=
ZAX0oooo0`0000000`3oool000000?ooo`0H0?ooobH0dLfY6@3oool00`000000oooo0?ooo`0L0?oo
obH0dLfY>@3ooolK0=7=Z@006P3AcJTK0?ooo`8000006`3ooolV0=7=ZCP0oooo9`3AcJTI0?ooo`03
0000003oool0oooo01`0oooo9P3AcJTI0?ooo`030000003oool0oooo01`0oooo9P3AcJTi0?oooa/0
dLfY000J0=7=ZA/0oooo0P00000K0?ooobH0dLfY>03ooolW0=7=ZAT0oooo00<000000?ooo`3oool0
703ooolV0=7=ZA/0oooo00<000000?ooo`0000006P3ooolV0=7=ZA/0oooo00<000000?ooo`000000
6`3ooolK0=7=Z@006P3AcJTK0?ooo`8000006`3ooolV0=7=ZCP0oooo9`3AcJTJ0?ooo`80000000<0
oooo0000003oool06@3ooolV0=7=ZAX0oooo0`0000000`3oool000000?ooo`0H0?ooobH0dLfY703o
ool2000001/0oooo6`3AcJT001X0dLfY>03ooolV0=7=ZCP0oooo9`3AcJTh0?ooobH0dLfY>03ooolV
0=7=ZAL0oooo00<000000?ooo`3oool07`3ooolK0=7=Z@006P3AcJTh0?ooobH0dLfY>03ooolW0=7=
ZCP0oooo9P3AcJTJ0?ooo`030000003oool0000001/0oooo9P3AcJTH0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool05P3ooolK0=7=Z@006P3AcJTh0?ooobH0dLfY>03ooolW0=7=ZCP0
oooo9P3AcJTh0?ooobH0dLfY6`3oool2000000030?ooo`000000000001T0oooo6`3AcJT001X0dLfY
>03ooolV0=7=ZCP0oooo9`3AcJTJ0?ooo`030000003oool0000001/0oooo9P3AcJTK0?ooo`800000
6`3ooolV0=7=ZA/0oooo00D000000?ooo`3oool0oooo0000000I0?oooa/0dLfY000J0=7=ZCP0oooo
9P3AcJTh0?ooobL0dLfY>03ooolV0=7=ZCP0oooo9P3AcJTI0?ooo`030000003oool0oooo00<00000
6P3ooolK0=7=Z@006P3AcJTK0?ooo`8000006`3ooolV0=7=ZCP0oooo9`3AcJTJ0?ooo`80000000<0
oooo0000003oool06@3ooolV0=7=ZAT0oooo00<000000?ooo`3oool0703ooolV0=7=ZAP0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?oooa/0dLfY000J0=7=ZA/0oooo0P00000K
0?ooobH0dLfY>03ooolW0=7=ZAd0oooo00<000000?ooo`3oool0603ooolV0=7=ZAT0oooo00<00000
0?ooo`3oool0703ooolV0=7=ZAT0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G
0?oooa/0dLfY000J0=7=ZA/0oooo0P00000K0?ooobH0dLfY>03ooolW0=7=ZAX0oooo0`0000000`3o
ool000000?ooo`0H0?ooobH0dLfY6`3oool00`000000oooo0000000J0?ooobH0dLfY7`3oool00`00
0000oooo0?ooo`0G0?oooa/0dLfY000J0=7=ZA/0oooo0P00000K0?ooobH0dLfY>03ooolW0=7=ZAT0
oooo00<000000?ooo`3oool0703ooolV0=7=ZAX0oooo0`0000000`3oool000000?ooo`0H0?ooobH0
dLfY6@3oool00`000000oooo0?ooo`0M0?oooa/0dLfY000J0=7=ZA/0oooo0P00000K0?ooobH0dLfY
>03ooolW0=7=ZAT0oooo00<000000?ooo`3oool0703ooolV0=7=ZAT0oooo00<000000?ooo`3oool0
703ooolV0=7=ZAd0oooo0P00000J0?oooa/0dLfY000J0=7=ZCP0oooo9P3AcJTh0?ooobL0dLfY>03o
oolV0=7=ZAX0oooo00<000000?ooo`0000006`3ooolV0=7=ZA/0oooo00<000000?ooo`0000006`3o
oolK0=7=Z@006P3AcJTh0?ooobH0dLfY>03ooolW0=7=ZCP0oooo9P3AcJTh0?ooobH0dLfY>@3ooolK
0=7=Z@006P3AcJTh0?ooobH0dLfY>03ooolW0=7=ZCP0oooo9P3AcJTh0?ooobH0dLfY>@3ooolK0=7=
Z@006P3AcJTh0?ooobH0dLfY>03ooolW0=7=ZA/0oooo00<000000?ooo`3oool06P3ooolV0=7=ZCP0
oooo9P3AcJTi0?oooa/0dLfY000J0=7=ZA/0oooo0P00000K0?ooobH0dLfY>03ooolW0=7=ZAX0oooo
00<000000?ooo`3oool06`3ooolV0=7=ZAX0oooo00<000000?ooo`3oool06`3ooolV0=7=ZA/0oooo
00<000000?ooo`0000006`3ooolK0=7=Z@006P3AcJTK0?ooo`8000006`3ooolV0=7=ZA/0oooo0P00
000K0?ooobL0dLfY6`3oool2000001/0oooo9P3AcJTK0?ooo`8000006`3ooolV0=7=ZA/0oooo0P00
000L0?oooa/0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY
003o0=7=ZNP0dLfY000@0=7=Z@E000000P3AcJT2@00000@0dLfY0T0000040=7=Z@9000000`3AcJT5
@00000030=7=ZD0000100000009000000P3AcJT5@0000080dLfY0T0000040=7=Z@9000000`3AcJT3
@00000@0dLfY0T0000030=7=Z@=000001@3AcJT00d000000dLfY0=7=Z@0A0=7=Z@E000000P3AcJT2
@00000@0dLfY0T0000040=7=Z@9000000`3AcJT5@00000030=7=ZD0000100000009000000P3AcJT5
@0000080dLfY0T0000040=7=Z@9000000`3AcJT3@00000@0dLfY0T0000030=7=Z@=00000103AcJT2
@00001@0dLfY1D0000020=7=Z@9000000`3AcJT3@00000@0dLfY0T0000030=7=Z@E000000`3AcJT3
@0000080dLfY0T0000030=7=Z@=00000103AcJT2@00000<0dLfY0d0000030=7=Z@E000000`3AcJT3
@00000030=7=ZD0000100000009000004P3AcJT5@0000080dLfY0T0000030=7=Z@=00000103AcJT2
@00000<0dLfY1D0000030=7=Z@=000000P3AcJT2@00000<0dLfY0d0000040=7=Z@9000000`3AcJT3
@00000<0dLfY1D0000030=7=Z@=000000P3AcJT2@00001<0dLfY1D0000020=7=Z@9000000`3AcJT3
@00000@0dLfY0T0000030=7=Z@E000000`3AcJT3@0000080dLfY0T0000030=7=Z@=000001@3AcJT3
@0000080dLfY0T0000040=7=Z@9000000`3AcJT3@00000D0dLfY00=000000=7=Z@3AcJT04@3AcJT0
0180dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A0
00000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD00
00001`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU0
00000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY01<0dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3A
cJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000001`3AcJT01D000000dLfY
0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD000002
0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@03@000003AcJT0dLfY01<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=
Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0
dLfY0080dLfY00=000000=7=Z@3AcJT0103AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003A
cJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=
Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0103AcJT014000000dLfY0=7=ZD00000G
0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003A
cJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00@0dLfY
00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003A
cJT0dLfY00@0dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0B0=7=Z@05@000
003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=
ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00@0dLfY00A000000=7=
Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00<0dLfY00A0
00000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@000
0080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0A0=7=Z@004P3AcJT01D000000
dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@02
0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@04
0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003A
cJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=
Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT04`3AcJT01D000000dLfY0=7=Z@3AcJU0
00000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003A
cJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@040=7=Z@05@000003A
cJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@0000080
dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0
dLfY@0000080dLfY00=000000=7=Z@3AcJT04`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY
00A000000=7=Z@3AcJT0dLfY0d0000050=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3A
cJT0dLfY1D0000001@3AcJU000000=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3A
cJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000@0dLfY00A000000=7=Z@3A
cJT0dLfY1D0000020=7=Z@03@000003AcJT0dLfY01@0dLfY00E000000=7=Z@3AcJT0dLfY@0000002
0=7=Z@04@000003AcJT0dLfY0=7=Z@=000001@3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003A
cJT0dLfY0=7=Z@E0000000D0dLfY@000003AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@000
0080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@04@000003A
cJT0dLfY0=7=Z@E000000`3AcJT00d000000dLfY0=7=Z@0C0=7=Z@05@000003AcJT0dLfY0=7=ZD00
00000P3AcJT014000000dLfY0=7=Z@3AcJT3@00000D0dLfY00=000000=7=Z@3AcJT00P3AcJT01400
0000dLfY0=7=Z@3AcJT5@00000050=7=ZD000000dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=
ZD0000020=7=Z@E00000103AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@0000080
dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0A0=7=Z@004P3AcJT00d000000dLfY
0=7=Z@020=7=Z@900000103AcJT2@00000H0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY
0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000@0dLfY
0T0000030=7=Z@=00000103AcJT2@00000<0dLfY0d0000060=7=Z@03@000003AcJT0dLfY0180dLfY
00=000000=7=Z@3AcJT00P3AcJT2@00000@0dLfY0T0000060=7=Z@03@000003AcJT0dLfY0080dLfY
00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY
0T0000040=7=Z@9000000`3AcJT3@00000@0dLfY0T0000030=7=Z@=00000103AcJT2@00001H0dLfY
00=000000=7=Z@3AcJT00P3AcJT2@00000<0dLfY00A000000=7=Z@3AcJU000000`3AcJT2@00000D0
dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY0=7=Z@9000000`3AcJT3
@00000<0dLfY00A000000=7=Z@3AcJU000000P3AcJT3@00000D0dLfY00E000000=7=Z@3AcJT0dLfY
@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT04`3AcJT00d000000dLfY
0=7=Z@020=7=Z@9000000`3AcJT014000000dLfY0=7=ZD0000030=7=Z@9000001@3AcJT01D000000
dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJT0dLfY0T0000030=7=Z@=000000`3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@=000001@3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY
00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0B0=7=Z@03@000003AcJT0dLfY0080dLfY
0T0000030=7=Z@04@000003AcJT0dLfY@00000<0dLfY0T0000050=7=Z@05@000003AcJT0dLfY0=7=
ZD0000000P3AcJT014000000dLfY0=7=Z@3AcJT2@00000<0dLfY0d0000030=7=Z@04@000003AcJT0
dLfY@00000<0dLfY0T0000040=7=Z@9000000`3AcJT3@00000H0dLfY00=000000=7=Z@3AcJT0403A
cJT00180dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY
00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=
ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT0
1D000000dLfY0=7=Z@3AcJU0000000D0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=
ZD0000030=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU00000503AcJT01D000000
dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00
00020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000
003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@05@000003AcJT0dLfY0=7=
ZD0000001@3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=00000
0=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD00000E0=7=Z@05@000003AcJT0dLfY0=7=ZD000000
0P3AcJT014000000dLfY0=7=ZD0000020=7=Z@05@000003AcJT0dLfY0=7=ZD0000001P3AcJT00d00
0000dLfY0=7=Z@020=7=Z@03@000003AcJU000000080dLfY00A000000=7=Z@3AcJU000000`3AcJT0
0d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT0103A
cJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJU000000080dLfY00A000000=7=Z@3AcJU00000
503AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT01D00
0000dLfY0=7=Z@3AcJU0000000H0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY@0000002
0=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=
ZD0000030=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY
@00000020=7=Z@04@000003AcJT0dLfY@00001@0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=
Z@04@000003AcJT0dLfY@0000080dLfY00E000000=7=Z@3AcJT0dLfY@00000060=7=Z@03@000003A
cJT0dLfY0080dLfY00=000000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000
003AcJT0dLfY00<0dLfY00=000000=7=ZD0000000`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000
003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD00000B0=7=Z@00
4@3AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000
103AcJT2@00000@0dLfY0T0000040=7=Z@=000000`3AcJT3@00000<0dLfY0T0000040=7=Z@=00000
0P3AcJT4@00001<0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000
103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT3@00000<0dLfY0d0000030=7=Z@900000
103AcJT3@00000<0dLfY0T00000E0=7=Z@900000103AcJT2@00000@0dLfY0d0000030=7=Z@=00000
0`3AcJT2@00000D0dLfY0T0000030=7=Z@900000103AcJT3@00000<0dLfY0T0000040=7=Z@=00000
0`3AcJT2@00000D0dLfY0T0000030=7=Z@900000503AcJT2@00000@0dLfY0T0000040=7=Z@=00000
0`3AcJT3@00000<0dLfY0T0000050=7=Z@9000000`3AcJT2@00000@0dLfY0d0000030=7=Z@900000
103AcJT3@00000<0dLfY0T0000050=7=Z@9000000`3AcJT2@00001@0dLfY0T0000040=7=Z@900000
103AcJT3@00000<0dLfY0d0000030=7=Z@9000001@3AcJT2@00000<0dLfY0T0000040=7=Z@=00000
103AcJT2@00000<0dLfY0d0000030=7=Z@=000000`3AcJT3@0000080dLfY1400000B0=7=Z@00o`3A
cJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3A
cJWX0=7=Z@00o`3AcJWX0=7=Z@006P3AcJT40?oooaL0000000<0oooo0000000000005@0000030?oo
o`030000003oool0dLfY02D0dLfY103oool2000000040?ooo`00000000000?ooo`800000103oool2
000000060?ooo`000000oooo0?ooo`000000oooo100000001@3oool00000000000000000oooo00@0
000000@0oooo0000003oool00000103oool4000000030?ooo`00000000000080oooo00<000000?oo
o`3AcJT09P3AcJT00`3oool000000?ooo`0700000080oooo0`0000020?ooo`8000000P3oool01000
0000oooo0000003oool2000000030?ooo`00000000000080oooo00H000000?ooo`000000oooo0000
003oool4000000030?ooo`000000oooo0080oooo1@0000020?ooo`030000003oool0dLfY02D0dLfY
0`3oool00`000000oooo0?ooo`02000000@0oooo0`0000030?ooo`030000003oool0000000800000
00<0oooo0000003oool00P3oool010000000oooo0000003oool200000080oooo00@000000?ooo`3o
ool0oooo0P0000000`3oool000000?ooo`030?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3AcJT09@3AcJTi0?oooa/0dLfY000J0=7=Z@80oooo00<000000?ooo`3oool05P0000020?oo
oaH000000P3oool00`000000oooo0?ooo`0V0=7=Z@80oooo0`0000020?ooo`040000003oool0oooo
0?ooo`80000000<0oooo000000000000103oool2000000030?ooo`000000000000@000000P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo0`0000000`3oool00000000000020?ooo`80000000<0
oooo0000003oool00P0000020?ooobL0dLfY0P3oool00`000000oooo0?ooo`040?ooo`<0000000D0
oooo00000000000000000?ooo`0800000080oooo0P0000040?ooo`80000000<0oooo000000000000
1@0000090?ooo`8000000P3ooolV0=7=Z@80oooo0`0000020?ooo`040000003oool000000?ooo`80
00000P3oool200000080oooo0P0000040?ooo`8000000P3oool2000000D0oooo00@000000?ooo`3o
ool000000P3oool2000000040?ooo`00000000000?ooo`<000000P3oool00`000000oooo0?ooo`0V
0=7=ZCT0oooo6`3AcJT001X0dLfY0`3oool00`000000oooo0?ooo`0E00000080oooo500000070?oo
obH0dLfY0`3oool2000000030?ooo`000000oooo0080000000<0oooo0000003oool00P3oool01P00
0000oooo000000000000oooo000000<0oooo00D000000?ooo`3oool000000?ooo`02000000D0oooo
0`0000020?ooo`050000003oool0oooo0000003oool00P0000080?ooobL0dLfY0`3oool010000000
oooo0?ooo`0000020?ooo`80000000<0oooo0000003oool0103oool3000000040?ooo`0000000000
00000080oooo0P0000040?ooo`040000003oool00000000000H0oooo0`0000050?ooo`030000003o
ool0oooo0080oooo9P3AcJT30?ooo`030000003oool0oooo0080000000D0oooo0000003oool0oooo
0000000:0?ooo`8000000P3oool00`000000oooo000000040?ooo`<000001@3oool200000080oooo
00<000000?ooo`0000001`3ooolV0=7=ZCT0oooo6`3AcJT001X0dLfY103oool00`000000oooo0000
000[0?ooo`800000103ooolV0=7=Z@@0oooo00<000000?ooo`0000000P3oool?0000000:0?ooo`00
000000000000003oool000000?ooo`000000oooo00000080oooo0`0000020?ooo`040000003oool0
000000000080oooo00<000000?ooo`3oool00P0000040?ooobL0dLfY103oool2000000H0oooo1000
00000`3oool000000?ooo`04000000050?ooo`00000000000000003oool00`0000020?ooo`800000
0P3oool4000000030?ooo`000000000000D0oooo0`0000040?ooobH0dLfY103oool200000080oooo
0P000000203oool000000?ooo`000000oooo0000003oool00000103oool500000080oooo00@00000
0?ooo`3oool0oooo100000001@3oool000000000003oool000000080oooo0`0000040?ooo`030000
003oool0oooo0080oooo9P3AcJTi0?oooa/0dLfY000J0=7=Z@D0oooo00@000000?ooo`3oool00000
4`3oool00`000000oooo0?ooo`0B0?ooo`8000001@3ooolV0=7=Z@/0oooo00<000000?ooo`3oool0
0`0000000`3oool000000000000200000080oooo1@0000030?ooo`040000003oool00000000000D0
oooo00@000000?ooo`3oool00000103oool2000000D0oooo9`3AcJT50?ooo`030000003oool0oooo
00H0oooo00D000000?ooo`00000000000?ooo`02000000D0oooo00@000000?ooo`00000000001@3o
ool00`000000oooo00000002000000030?ooo`000000oooo00@0oooo00@000000?ooo`0000000000
1@3ooolV0=7=Z@D0oooo00<000000?ooo`0000001@3oool2000000<0oooo00@000000?ooo`3oool0
00000P3oool4000000070?ooo`000000oooo0?ooo`000000oooo000000020?ooo`030000003oool0
oooo00D0oooo0P000000103oool000000000000000050?ooobH0dLfY>@3ooolK0=7=Z@006P3AcJT6
0?ooo`8000004`3oool200000140oooo00@000000?ooo`00000000001P3ooolV0=7=Z@P0oooo0`00
0000103oool000000?ooo`0000020?ooo`D0000000<0oooo0000000000001@0000001@3oool00000
0000003oool0000000<0oooo00<000000?ooo`0000000P3oool3000000<0oooo00<000000?ooo`3o
ool0103ooolW0=7=Z@H0oooo0P0000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool0oooo0P0000050?ooo`040000003oool00000000000D0oooo00@000000?ooo`3oool0oooo1000
00020?ooo`030000003oool00000008000001P3ooolV0=7=Z@H0oooo00<000000?ooo`3oool00`3o
ool4000000030?ooo`000000000000<0oooo0P0000020?ooo`080000003oool000000000003oool0
00000?ooo`0000040?ooo`80000000@0oooo00000000000000000`3oool00`000000oooo00000006
0?ooobH0dLfY>@3ooolK0=7=Z@006P3AcJT70?ooo`80000000<0oooo0000003oool08`3oool20000
00L0oooo9P3AcJT70?ooo`8000000P3oool3000000<0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`02000000040?ooo`000000oooo00000080oooo00<000000?ooo`0000000P00
00000`3oool000000?ooo`04000000030?ooo`000000000000L0oooo9`3AcJT70?ooo`@0000000<0
oooo0000000000000P3oool2000000040?ooo`0000000000000000D0oooo00<000000?ooo`3oool0
1@3oool010000000oooo0?ooo`0000020?ooo`D0000000<0oooo0000000000001`3ooolV0=7=Z@L0
oooo0P0000030?ooo`030000003oool0000000@000002@3oool2000000050?ooo`00000000000?oo
o`0000000`3oool3000000060?ooo`00000000000?ooo`000000oooo0P0000070?ooobH0dLfY>@3o
oolK0=7=Z@006P3AcJT80?ooo`8000004P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
000000T0oooo9P3AcJT80?ooo`800000103oool2000000030?ooo`000000oooo00H0000000@0oooo
00000000000000000P3oool00`000000oooo000000030?ooo`80000000@0oooo0000003oool00000
3@3ooolW0=7=Z@P0oooo0`0000050?ooo`80000000D0oooo000000000000oooo000000030?ooo`03
0000003oool0oooo008000000P3oool6000000H0oooo0P0000090?ooobH0dLfY203oool00`000000
oooo0?ooo`020?ooo`80000000@0oooo00000000000000000`3oool00`000000oooo0?ooo`020000
00050?ooo`00000000000000003oool00`0000030?ooo`80000000<0oooo0000000000000P3oool2
000000T0oooo9P3AcJTi0?oooa/0dLfY000J0=7=Z@/0oooo400000020?ooo`l000000P3oool00`00
0000oooo0?ooo`070?ooobH0dLfY2@3oool00`000000oooo000000070?ooo`030000003oool0oooo
008000000P3oool500000080oooo00@000000?ooo`00000000000`3oool010000000oooo0?ooo`3o
ool3000000T0oooo9`3AcJT90?ooo`030000003oool0000000D000000`3oool00`000000oooo0?oo
o`02000000040?ooo`000000000000000080oooo0P0000030?ooo`80000000D0oooo000000000000
00000?ooo`02000000030?ooo`000000oooo00P0oooo9P3AcJT;0?ooo`050000003oool0oooo0?oo
o`0000001@3oool00`000000oooo000000030?ooo`050000003oool000000?ooo`0000001@3oool0
0`000000oooo0?ooo`050?ooo`8000002@3ooolV0=7=ZCT0oooo6`3AcJT001X0dLfY3@3oool>0000
0080oooo3@0000030?ooo`030000003oool0oooo00P0oooo9P3AcJT=0?ooo`80000000<0oooo0000
000000000`3oool4000000030?ooo`000000oooo0080oooo00<000000?ooo`0000000P0000020?oo
o`<00000103oool2000000X0oooo9`3AcJT:0?ooo`030000003oool0000000H000001@3oool00`00
0000oooo00000004000000<0oooo00@000000?ooo`3oool0oooo1P0000000`3oool000000?ooo`09
0?ooobH0dLfY303oool00`000000oooo0?ooo`03000000@0oooo00<000000?ooo`3oool00P000000
0`3oool0000000000004000000050?ooo`000000oooo0?ooo`0000000`3oool2000000030?ooo`00
0000oooo00T0oooo9P3AcJTi0?oooa/0dLfY000J0=7=Z@h0oooo3@0000000`3oool000000000000<
00000080oooo00<000000?ooo`3oool02@3ooolV0=7=Z@h0oooo00<000000?ooo`3oool00P000000
103oool000000000000000020?ooo`80000000@0oooo0000003oool0oooo0`0000030?ooo`D00000
0P3oool00`000000oooo0?ooo`090?ooobL0dLfY2`3oool00`000000oooo0?ooo`040?ooo`D00000
00<0oooo0000003oool01@3oool3000000X0oooo00<000000?ooo`3oool02@3ooolV0=7=Z@`0oooo
0P0000030?ooo`040000003oool000000?ooo`<0000000@0oooo0000003oool0oooo1`0000030?oo
o`@0000000<0oooo0000000000002`3ooolV0=7=ZCT0oooo6`3AcJT001X0dLfY303oool00`000000
oooo0?ooo`0<00000080oooo2`0000030?ooo`030000003oool0oooo00X0oooo9P3AcJT<0?ooo`<0
000000@0oooo0000003oool000000P3oool2000000030?ooo`00000000000080oooo0P0000030?oo
o`8000001@3oool010000000oooo00000000000<0?ooobL0dLfY303oool010000000oooo0?ooo`00
00020?ooo`8000000`3oool2000000<0oooo0`0000030?ooo`<000001@3oool2000000`0oooo9P3A
cJT<0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`000000oooo0`0000000`3oool0
000000000002000000040?ooo`000000oooo0?ooo`80000000<0oooo0000003oool00P3oool00`00
0000oooo0?ooo`0:0?ooobH0dLfY>@3ooolK0=7=Z@006P3AcJT=0?ooo`030000003oool0000000/0
oooo0P00000<0?ooo`8000003@3ooolV0=7=ZA00oooo100000020?ooo`800000103oool200000006
0?ooo`000000oooo0000003oool000000P3oool3000000030?ooo`000000oooo00`0oooo9`3AcJT=
0?ooo`8000001P3oool400000080oooo0P0000040?ooo`8000001@3oool3000000d0oooo9P3AcJT=
0?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool03@3oool2000000<0oooo00<00000
0?ooo`3oool02`3ooolV0=7=ZCT0oooo6`3AcJT001X0dLfY3P3oool010000000oooo0?ooo`00000D
0?ooo`040000003oool00000000000h0oooo9P3AcJT>0?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`02000000030?ooo`000000000000@0000000@0oooo0000003oool0
00000P3oool2000000h0oooo9`3AcJT>0?ooo`030000003oool0000000H0oooo00@000000?ooo`00
0000oooo0P0000030?ooo`030000003oool0oooo00D0oooo0P00000>0?ooobH0dLfY3P3oool02000
0000oooo0?ooo`3oool000000?ooo`000000oooo0P0000020?ooo`8000000P3oool6000000030?oo
o`000000oooo00<000003P3ooolV0=7=ZCT0oooo6`3AcJT001X0dLfY3`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`00000000003`3ooolV0=7=ZA<0oooo
0`0000001@3oool000000000003oool000000080oooo0P0000040?ooo`040000003oool0oooo0?oo
o`8000003`3ooolW0=7=Z@l0oooo0P0000020?ooo`030000003oool000000080oooo00<000000?oo
o`3oool01P0000030?ooo`030000003oool0oooo008000003`3ooolV0=7=Z@l0oooo0P0000080?oo
o`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`0=0?ooobH0dLfY>@3ooolK
0=7=Z@006P3AcJT@0?ooo`80000000<0oooo0000003oool01P3oool2000000T0oooo0P00000@0?oo
obH0dLfY4P3oool2000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`000000403ooolW0=7=ZA00oooo100000000`3oool0000000000002
0?ooo`@000000`3oool5000000030?ooo`00000000000100oooo9P3AcJT@0?ooo`8000001P3oool0
1@000000oooo000000000000oooo00<00000103oool010000000oooo00000000000@0?ooobH0dLfY
>@3ooolK0=7=Z@006P3AcJTA0?ooo`800000403oool010000000oooo00000000000A0?ooobH0dLfY
4@3oool2000000@0oooo0`0000000`3oool000000000000300000080oooo0P0000000`3oool00000
0000000A0?ooobL0dLfY4@3oool3000000D0oooo1@0000060?ooo`<000004@3ooolV0=7=ZA40oooo
00@000000?ooo`3oool0oooo0P0000030?ooo`<000000`3oool200000080oooo0`00000A0?ooobH0
dLfY>@3ooolK0=7=Z@006P3AcJTD0?ooo`L0000000<0oooo0000000000001@0000020?ooo`030000
003oool0oooo0100oooo9P3AcJTD0?ooo`80000000@0oooo0000003oool0oooo0`0000000`3oool0
00000?ooo`020?ooo`040000003oool0oooo00000180oooo9`3AcJTB0?ooo`040000003oool00000
0?ooo`@00000103oool6000000030?ooo`000000oooo0140oooo9P3AcJTD0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00`3oool2000000030?ooo`000000oooo008000004P3ooolV
0=7=ZCT0oooo6`3AcJT001X0dLfY5P3oool500000080oooo1@0000020?ooo`030000003oool0oooo
0140oooo9P3AcJTC0?ooo`040000003oool000000?ooo`L0000000@0oooo0000003oool0oooo0`00
000C0?ooobL0dLfY4`3oool00`000000oooo00000004000000030?ooo`000000000000H0000000<0
oooo0000003oool04P3ooolV0=7=ZAD0oooo00@000000?ooo`00000000000P3oool00`000000oooo
0?ooo`03000000040?ooo`000000oooo000001<0oooo9P3AcJTi0?oooa/0dLfY000J0=7=ZAL0oooo
100000020?ooo`@000000P3oool00`000000oooo0?ooo`0B0?ooobH0dLfY5`3oool00`000000oooo
0?ooo`030?ooo`8000000`3oool2000001@0oooo9`3AcJTD0?ooo`030000003oool0oooo00@0oooo
0P0000060?ooo`030000003oool0oooo0180oooo9P3AcJTF0?ooo`030000003oool0000000800000
00@0oooo000000000000oooo1@00000D0?ooobH0dLfY>@3ooolK0=7=Z@006P3AcJTH0?ooo`<00000
00@0oooo00000000000000000`3oool00`000000oooo0?ooo`0C0?ooobH0dLfY603oool200000003
0?ooo`000000oooo00<000000P3oool00`000000oooo0?ooo`0C0?ooobL0dLfY5@3oool010000000
oooo0?ooo`0000020?ooo`8000001@3oool00`000000oooo0?ooo`0C0?ooobH0dLfY6P3oool01000
0000oooo0000000000040?ooo`030000003oool0oooo01<0oooo9P3AcJTi0?oooa/0dLfY000J0=7=
ZAH0oooo00<000000?ooo`3oool00P0000020?ooo`8000000P3oool00`000000oooo0?ooo`0D0?oo
obH0dLfY5P3oool300000080oooo00D000000?ooo`3oool000000?ooo`02000001H0oooo9`3AcJTF
0?ooo`030000003oool0000000@0000000<0oooo0000003oool00P00000F0?ooobH0dLfY5P3oool2
00000080oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo01@0oooo9P3AcJTi
0?oooa/0dLfY000J0=7=ZAL0oooo00<000000?ooo`3oool00`3oool010000000oooo00000000000G
0?ooobH0dLfY6P3oool2000000050?ooo`00000000000?ooo`0000005`3ooolW0=7=ZAL0oooo00<0
00000?ooo`0000001@3oool2000001L0oooo9P3AcJTG0?ooo`030000003oool0oooo00<0oooo1000
000G0?ooobH0dLfY>@3ooolK0=7=Z@006P3AcJTH0?ooo`030000003oool0000000<0oooo0P00000H
0?ooobH0dLfY603oool010000000oooo0000000000020?ooo`800000603ooolW0=7=ZAP0oooo0P00
00040?ooo`800000603ooolV0=7=ZAP0oooo0P0000000`3oool00000000000020?ooo`030000003o
ool0oooo01H0oooo9P3AcJTi0?oooa/0dLfY000J0=7=ZAT0oooo00@000000?ooo`3oool0oooo0P00
000I0?ooobH0dLfY7@3oool2000001T0oooo9`3AcJTI0?ooo`030000003oool0000000<000006@3o
oolV0=7=ZAT0oooo00@000000?ooo`3oool0oooo0P00000I0?ooobH0dLfY>@3ooolK0=7=Z@006P3A
cJTJ0?ooo`040000003oool00000000001X0oooo9P3AcJTM0?ooo`030000003oool0oooo01P0oooo
9`3AcJTJ0?ooo`@000006P3ooolV0=7=ZAX0oooo0P0000000`3oool000000?ooo`0I0?ooobH0dLfY
>@3ooolK0=7=Z@006P3AcJTJ0?ooo`030000003oool0oooo01/0oooo9P3AcJTJ0?ooo`800000703o
oolW0=7=ZAX0oooo00<000000?ooo`0000006`3ooolV0=7=ZAX0oooo0P00000L0?ooobH0dLfY>@3o
oolK0=7=Z@006P3AcJTh0?ooobH0dLfY>03ooolW0=7=ZCP0oooo9P3AcJTh0?ooobH0dLfY6`3oool2
000001`0oooo6`3AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03A
cJT00?l0dLfYj03AcJT00100dLfY1D0000020=7=Z@9000000`3AcJT3@00000<0dLfY0d0000040=7=
Z@9000000`3AcJT4@00000<0dLfY0T0000040=7=Z@900000103AcJT2@00000<0dLfY0d0000040=7=
Z@9000001@3AcJT014000000dLfY0=7=Z@3AcJT4@0000180dLfY1D0000020=7=Z@9000000`3AcJT3
@00000<0dLfY0d0000040=7=Z@9000000`3AcJT4@00000<0dLfY0T0000040=7=Z@900000103AcJT2
@00000<0dLfY0d0000040=7=Z@900000103AcJT2@00000<0dLfY0d00000D0=7=Z@E000000P3AcJT2
@00000<0dLfY0d0000030=7=Z@=00000103AcJT2@00000<0dLfY140000030=7=Z@900000103AcJT2
@00000D0dLfY00A000000=7=Z@3AcJT0dLfY0d0000030=7=Z@A000000P3AcJT3@00000@0dLfY0T00
000C0=7=Z@E000000P3AcJT2@00000<0dLfY0d0000030=7=Z@=000000`3AcJT3@00000<0dLfY1D00
0000103AcJU00000@000040000040=7=Z@9000001@3AcJT3@0000080dLfY0T0000030=7=Z@=00000
1@3AcJT014000000dLfY0=7=Z@3AcJT5@0000140dLfY1D0000020=7=Z@900000103AcJT2@00000@0
dLfY0T0000030=7=Z@E0000000<0dLfY@000040000000T0000020=7=Z@E000000P3AcJT2@00000@0
dLfY0T0000030=7=Z@=00000103AcJT2@00000<0dLfY0d0000030=7=Z@=000004`3AcJT00180dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3A
cJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000001@3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU0
00000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000@0dLfY00E00000
0=7=Z@3AcJT0dLfY@000000G0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY
0=7=Z@020=7=Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04
@000003AcJT0dLfY@00000D0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000
dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000005@3A
cJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY
0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000050=7=
Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000103AcJT01D000000dLfY0=7=
Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000001`3AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00=000000=7=Z@3AcJT04P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=00000
0=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=00000
0=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU00000
0P3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3A
cJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=
Z@3AcJT04`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3A
cJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0
dLfY@00000070=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD000002
0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0403AcJT00180
dLfY00=000000=7=Z@3AcJT0103AcJT014000000dLfY0=7=Z@3AcJT3@00000<0dLfY0d0000050=7=
Z@05@000003AcJT0dLfY0=7=ZD000000103AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003A
cJT0dLfY@00000@0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@000
0080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY
01@0dLfY00=000000=7=Z@3AcJT0103AcJT014000000dLfY0=7=Z@3AcJT3@00000<0dLfY0d000005
0=7=Z@05@000003AcJT0dLfY0=7=ZD000000103AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000
003AcJT0dLfY@00000D0dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@030=7=
Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=
Z@0C0=7=Z@03@000003AcJT0dLfY00@0dLfY00A000000=7=Z@3AcJT0dLfY0d0000030=7=Z@=00000
1@3AcJT01D000000dLfY0=7=Z@3AcJU0000000@0dLfY00A000000=7=Z@3AcJU000000P3AcJT01400
0000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT01D000000dLfY0=7=
Z@3AcJU0000000D0dLfY0d0000020=7=Z@04@000003AcJT0dLfY@00001@0dLfY00=000000=7=Z@3A
cJT0103AcJT014000000dLfY0=7=Z@3AcJT3@00000<0dLfY0d0000030=7=Z@=00000103AcJT01D00
0000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=
Z@05@00000050=7=ZD000000dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@03
@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT04`3AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0
dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@040=7=Z@05@000003AcJT0
dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@0000080dLfY
00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00=000000=7=Z@3AcJT0403AcJT00180dLfY00=000000=7=Z@3AcJT00P3AcJT2@000
00<0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000030=7=Z@9000001@3A
cJT00d000000dLfY0=7=Z@020=7=Z@900000103AcJT2@00000H0dLfY00=000000=7=Z@3AcJT00d00
00040=7=Z@9000001P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY01<0dLfY00=0
00000=7=Z@3AcJT00P3AcJT2@00000<0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD0000030=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@020=7=Z@900000103AcJT2@00000@0
dLfY0T0000030=7=Z@=00000103AcJT2@00000@0dLfY0T0000030=7=Z@=000005P3AcJT00d000000
dLfY0=7=Z@020=7=Z@9000000`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@00000<0dLfY0T0000050=7=Z@03@000003AcJT0dLfY0080dLfY0T0000040=7=Z@9000001P3AcJT0
0d000000dLfY0=7=Z@03@00000D0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003A
cJT0dLfY0=7=Z@9000005@3AcJT00d000000dLfY0=7=Z@020=7=Z@9000000`3AcJT014000000dLfY
0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000103AcJT0
14000000dLfY0=7=Z@3AcJT3@00000@0dLfY0T0000030=7=Z@04@000003AcJT0dLfY@00000<0dLfY
0T0000030=7=Z@=000001P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY01<0dLfY
00=000000=7=Z@3AcJT00P3AcJT2@00000@0dLfY0T0000060=7=Z@03@000003AcJT0dLfY0080dLfY
00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY
0T0000040=7=Z@9000000`3AcJT3@00000@0dLfY0T0000030=7=Z@=000000`3AcJT3@00001<0dLfY
000B0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=
ZD0000020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000
dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3A
cJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU0
00000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00001@0dLfY00=00000
0=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A0
00000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@0000080
dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0
dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0
dLfY@00000<0dLfY00=000000=7=Z@3AcJT05@3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003A
cJT0dLfY0080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03
@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD000002
0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY
0=7=Z@020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT01400
0000dLfY0=7=ZD00000D0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU0
0000103AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3A
cJU000000`3AcJT00d000000dLfY@00000020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=00000
0=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY01<0dLfY00E0
00000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3A
cJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT0
0d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT01D000000dLfY0=7=
Z@3AcJU0000000D0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03
@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT04P3AcJT00140dLfY0T0000040=7=Z@=00000
0`3AcJT3@00000<0dLfY0d0000030=7=Z@=000000`3AcJT2@00000@0dLfY0T0000040=7=Z@900000
103AcJT2@00000@0dLfY0d0000030=7=Z@9000000`3AcJT4@00000<0dLfY0T00000D0=7=Z@900000
103AcJT3@00000<0dLfY0d0000030=7=Z@=000000`3AcJT3@00000<0dLfY0T0000040=7=Z@900000
103AcJT2@00000@0dLfY0d0000030=7=Z@=000000`3AcJT3@00000<0dLfY0T0000040=7=Z@=00000
503AcJT2@00000@0dLfY0d0000030=7=Z@=000000`3AcJT3@00000<0dLfY0d0000030=7=Z@900000
103AcJT2@00000@0dLfY0T0000030=7=Z@A000000`3AcJT3@00000<0dLfY0T0000040=7=Z@=00000
0`3AcJT2@00001@0dLfY0T0000040=7=Z@=000000`3AcJT3@00000<0dLfY0d0000030=7=Z@=00000
0`3AcJT2@00000@0dLfY0d0000030=7=Z@9000001@3AcJT2@00000<0dLfY0T0000040=7=Z@=00000
0P3AcJT4@00000<0dLfY0T00000D0=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000
103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0d0000030=7=Z@=00000
0`3AcJT2@00000@0dLfY0d0000030=7=Z@=000004P3AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT0
0?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT0
0?l0dLfYj03AcJT001X0dLfY0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`0000002`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool01P3oool01P000000oooo000000000000oooo000000<0oooo9P3AcJT50?ooo`800000103o
ool2000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0000
00030?ooo`8000000`3oool00`000000oooo0?ooo`02000000H0oooo00<000000?ooo`3oool00`3o
oolW0=7=Z@`0oooo00@000000?ooo`3oool000000P3oool200000080oooo00@000000?ooo`3oool0
oooo0P0000030?ooo`030000003oool00000008000000`3oool200000080oooo00D000000?ooo`3o
ool0oooo000000020?ooo`800000103ooolV0=7=Z@@0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0H0?ooobH0dLfY1P3oool2000000030?ooo`000000oooo00@0oooo00<000000?oo
o`3oool00`0000040?ooo`80000000D0oooo0000003oool0oooo000000030?ooo`050000003oool0
00000000003oool00`0000040?ooo`80000000<0oooo0000000000001@3ooolK0=7=Z@006P3AcJT3
0?ooo`030000003oool0oooo00<0000000<0oooo0000003oool00P0000050?ooo`@0000000<0oooo
0000003oool01`3oool3000000L0oooo0P0000020?ooo`80000000@0oooo00000000000000000`3o
oolV0=7=Z@<0oooo00D000000?ooo`3oool000000?ooo`02000000H0oooo00@000000?ooo`000000
oooo0`0000090?ooo`8000000`3oool010000000oooo0?ooo`3oool2000000070?ooo`000000oooo
0?ooo`000000oooo000000020?ooo`040000003oool0oooo0?ooobL0dLfY0`3oool00`000000oooo
000000030?ooo`80000000<0oooo0000003oool01`000000103oool000000000003oool400000003
0?ooo`000000000000D0000000@0oooo0000003oool0oooo0`0000000`3oool000000?ooo`020?oo
o`@000000`3ooolV0=7=ZAX0oooo00<000000?ooo`0000006`3ooolV0=7=Z@/0oooo1@0000030?oo
o`8000000`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo0P000000
203oool00000000000000000oooo0000003oool000002P3ooolK0=7=Z@006P3AcJT40?ooo`030000
003oool0000000@000000`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3o
ool00`00000:0?ooo`040000003oool0oooo0?ooo`8000001@3oool00`000000oooo0?ooo`050?oo
obH0dLfY103oool010000000oooo0000000000050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000070?ooo`8000000`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00<000001@3ooolW0=7=Z@@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo000000020?ooo`050000003oool0oooo0000003oool00`0000020?ooo`<00000
0P3oool7000000030?ooo`000000000000800000303ooolV0=7=Z@D0oooo00@000000?ooo`3oool0
00004@3oool2000001`0oooo9P3AcJT50?ooo`030000003oool0000000<0oooo0P0000020?ooo`05
0000003oool0oooo0000003oool00P0000020?ooo`030000003oool0000000D0oooo0`0000030?oo
o`L000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo6`3AcJT001X0dLfY1`3oool30000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000000P3oool01@000000oooo0?ooo`000000oooo00<0000000@0oooo0000000000000000
1@3oool010000000oooo0000000000040?ooobH0dLfY1@3oool010000000oooo0000000000040?oo
o`80000000@0oooo00000000000000002@3oool200000080oooo00<000000?ooo`3oool00P3oool3
000000@0oooo00<000000?ooo`3oool01@0000040?ooobL0dLfY1P3oool3000000060?ooo`000000
oooo0000003oool000001P3oool300000080oooo0`0000020?ooo`<0000000@0oooo000000000000
00001@3oool01`000000oooo0?ooo`000000oooo0000003oool00P0000040?ooobH0dLfY1@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo0`0000040?ooobH0dLfY103oool0
0`000000oooo000000090?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool010000005
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3oool2000000030?ooo`000000
oooo00<0oooo6`3AcJT001X0dLfY2@3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`0000000P0000020?ooo`8000000`3oool00`000000oooo0?ooo`02
0?ooo`8000001@3ooolV0=7=Z@T0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo000000020?ooo`040000003oool0oooo0?ooo`8000000P3oool20000000;0?ooo`000000
oooo0?ooo`000000oooo0000003oool000000?ooo`0000000P3oool010000000oooo0?ooo`3oool2
000000D0oooo9`3AcJT60?ooo`030000003oool0oooo0080000000@0oooo0000003oool000000P3o
ool010000000oooo0000000000020?ooo`030000003oool0000000@0000000<0oooo0000003oool0
0`3oool00`000000oooo000000040?ooo`040000003oool0oooo00000080oooo0P0000050?ooobH0
dLfY<@3oool2000000D0oooo9P3AcJT50?ooo`030000003oool0oooo0080000000H0oooo00000000
000000000?ooo`0000040?ooo`80000000<0oooo0000003oool00`3oool2000000@0oooo00<00000
0?ooo`000000103oool2000000040?ooo`000000oooo000000@0oooo00<000000?ooo`3oool00`3o
oolK0=7=Z@006P3AcJT60?ooo`030000003oool0oooo0080000000@0oooo00000000000000001`3o
ool01`000000oooo0000003oool000000?ooo`000000103oool200000080oooo00<000000?ooo`00
00000P3oool2000000060?ooo`00000000000000003oool000001P3ooolV0=7=Z@H0oooo00X00000
0?ooo`3oool000000?ooo`000000oooo0000003oool000002P3oool200000080oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00@0oooo0P0000000`3oool000000?ooo`05
0?ooobL0dLfY1P3oool010000000oooo0?ooo`0000020?ooo`030000003oool000000080oooo00<0
00000?ooo`0000000P3oool300000080oooo100000020?ooo`030000003oool0000000<00000103o
ool00`000000oooo0?ooo`02000000030?ooo`000000oooo00D0oooo9P3AcJT70?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool00`0000060?ooobH0dLfY1P3oool00`000000oooo0000
00020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`0000020?ooo`<000000P3oool200000080oooo0`000000103oool000000?ooo`0000030?ooo`<0
00001P3ooolK0=7=Z@006P3AcJT70?ooo`8000000P3oool4000000030?ooo`000000oooo00@0oooo
00L000000?ooo`3oool0oooo0000003oool0000000<0oooo0P0000090?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01@3ooolV0=7=Z@L0oooo0P0000040?ooo`80000000<0oooo0000
003oool00`3oool00`000000oooo0?ooo`050?ooo`<00000103oool200000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo00D0oooo9`3AcJT70?ooo`80000000H0oooo
00000000000000000?ooo`0000020?ooo`8000001@3oool01P000000oooo000000000000oooo0000
00@0oooo1@0000001`3oool000000000003oool000000?ooo`0000000P3oool00`000000oooo0?oo
o`050?ooobH0dLfY1`3oool300000280oooo0P0000020?ooo`030000003oool0oooo00D0oooo9P3A
cJT70?ooo`040000003oool000000?ooo`<00000103oool00`000000oooo000000050?ooo`040000
003oool0oooo000000<0oooo0P000000103oool000000?ooo`0000040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01P3ooolK0=7=Z@006P3AcJT80?ooo`80000000@0oooo0000003o
ool000001@3oool200000080oooo00@000000?ooo`3oool0oooo0P0000080?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02`3ooolV0=7=Z@P0oooo0P0000000`3oool000000?ooo`03
0?ooo`040000003oool0000000000080oooo0P0000020?ooo`040000003oool000000?ooo`@00000
0`3oool01`000000oooo0?ooo`000000oooo0000003oool00P00000:0?ooobL0dLfY203oool20000
0080oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo100000060?ooo`040000003o
ool0oooo0?ooo`D0000000<0oooo0000003oool02@3ooolV0=7=Z@P0oooo0`00000@0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0203ooolV0=7=Z@P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo000000030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`000000
0P3oool2000000040?ooo`000000000000000080oooo00<000000?ooo`3oool01`3ooolK0=7=Z@00
6P3AcJT90?ooo`<000001P3oool00`000000oooo0?ooo`02000000H0oooo00@000000?ooo`3oool0
oooo0P0000000`3oool000000?ooo`070?ooo`030000003oool0oooo00P0oooo9P3AcJT90?ooo`05
0000003oool0oooo0?ooo`0000000`3oool3000000040?ooo`000000oooo000000`0oooo00<00000
0?ooo`000000100000020?ooo`030000003oool0oooo00P0oooo9`3AcJT90?ooo`@000000`3oool2
00000080oooo100000001@3oool000000?ooo`000000oooo00<0000000@0oooo0000003oool00000
0P3oool200000080oooo0P0000000`3oool000000?ooo`090?ooobH0dLfY2`3oool2000000h0oooo
0P00000>0?ooo`030000003oool0oooo00X0oooo9P3AcJT>0?ooo`80000000@0oooo000000000000
00000P3oool4000000@0oooo00<000000?ooo`0000000`3oool6000000l0oooo6`3AcJT001X0dLfY
3P3oool5000000<0oooo00<000000?ooo`3oool00`0000050?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`090?ooobH0dLfY2`3oool00`000000
oooo000000020?ooo`80000000P0oooo0000003oool0oooo0000003oool000000?ooo`<000000P3o
ool01P000000oooo0000003oool000000?ooo`80000000H0oooo00000000000000000?ooo`00000;
0?ooobL0dLfY5@3oool01P000000oooo0000003oool000000?ooo`8000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3ooolV0=7=Z@d0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0H0?ooobH0dLfY303oool00`000000oooo
0?ooo`040?ooo`80000000D0oooo0000003oool0oooo000000040?ooo`040000003oool0oooo0?oo
o`80000000@0oooo00000000000000000P3oool00`000000oooo0000000<0?oooa/0dLfY000J0=7=
Z@d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000002@3oool01P000000oooo000000000000oooo000000d0oooo9P3AcJT@0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo000000020?ooo`030000
003oool0oooo0100oooo9`3AcJTC0?ooo`040000003oool00000000000<0oooo100000000`3oool0
00000?ooo`02000000030?ooo`000000oooo0080oooo0P00000>0?ooobH0dLfY6P3oool00`000000
oooo0000000K0?ooobH0dLfY3P3oool02`000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo00<0000000<0oooo0000003oool00`3oool00`000000oooo0000000200000180oooo
6`3AcJT001X0dLfY3@3oool00`000000oooo0?ooo`03000000040?ooo`000000oooo000000D0oooo
0`000000103oool000000000000000020?ooo`80000000@0oooo00000000000000003@3ooolV0=7=
Z@d0oooo00<000000?ooo`0000000`3oool00`000000oooo000000040?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`0000000`00000=0?ooobL0dLfY3@3oool00`000000oooo000000020?oo
o`<000001P3oool4000000<0oooo00<000000?ooo`0000000P3oool4000000d0oooo9P3AcJT>0?oo
o`040000003oool0oooo000000P0oooo0P00000:0?ooo`030000003oool0oooo00l0oooo9P3AcJTA
0?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0000000000080oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00h0oooo6`3AcJT001X0dLfY3@3o
ool4000000060?ooo`000000oooo0?ooo`000000oooo0P0000000`3oool00000000000030?ooo`80
00000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo9P3AcJT=0?ooo`<0
00000P3oool2000000D0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000003@3ooolW0=7=Z@d0oooo0`0000060?ooo`040000003oool0
00000?ooo`<000000P3oool4000000050?ooo`000000oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0;0?ooobH0dLfY3P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
0`00000=0?ooobH0dLfY3@3oool300000080oooo0P0000000`3oool000000?ooo`040?ooo`030000
003oool0oooo00@0oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0000000d0oooo
6`3AcJT001X0dLfY4@3oool3000000/0oooo0P0000050?ooo`040000003oool00000000000h0oooo
9P3AcJTC0?ooo`030000003oool000000080000000<0oooo0000000000000P3oool2000000030?oo
o`00000000000080oooo0P0000020?ooo`8000003P3ooolW0=7=ZA00oooo0`0000000`3oool00000
000000030?ooo`<0000000<0oooo0000000000000`3oool01P000000oooo0000003oool000000?oo
o`8000003P3ooolV0=7=ZBP0oooo0P00000>0?ooobH0dLfY3P3oool00`000000oooo000000030?oo
o`030000003oool0000000X0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003o
ool0oooo00`0oooo6`3AcJT001X0dLfY4`3oool01@000000oooo0?ooo`3oool0000000L0oooo00@0
00000?ooo`3oool00000103oool2000000l0oooo9P3AcJT@0?ooo`040000003oool00000000000H0
oooo00<000000?ooo`3oool00`0000050?ooo`040000003oool00000000000l0oooo9`3AcJT@0?oo
o`030000003oool0oooo00<0000000<0oooo0000000000000P3oool02P000000oooo0?ooo`000000
oooo0000003oool000000?ooo`0000020?ooo`8000003`3ooolV0=7=ZA00oooo00<000000?ooo`3o
ool0403oool010000000oooo0?ooo`3oool2000000l0oooo9P3AcJT?0?ooo`030000003oool0oooo
00<0000000<0oooo000000000000100000001@3oool000000?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool00P00000?0?oooa/0dLfY000J0=7=ZA00oooo00<000000?ooo`3oool00P0000000`3o
ool00000000000020?ooo`030000003oool000000080000000@0oooo000000000000oooo0`000000
0`3oool000000?ooo`0?0?ooobH0dLfY403oool00`000000oooo00000008000000H0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0>0?ooobL0dLfY403oool010000000oooo0?oo
o`0000030?ooo`<0000000<0oooo0000003oool00P3oool2000000<0oooo0P0000000`3oool00000
0?ooo`0?0?ooobH0dLfY4@3oool200000100oooo0P0000000`3oool000000000000@0?ooobH0dLfY
403oool01`000000oooo000000000000oooo0000003oool00P0000040?ooo`030000003oool00000
008000000P3oool400000140oooo6`3AcJT001X0dLfY4@3oool200000080oooo1P0000020?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0?0?ooobH0dLfY4@3oool50000
00<0oooo0P0000070?ooo`050000003oool000000?ooo`0000004@3ooolW0=7=ZA40oooo0P000000
103oool000000000000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo
000000020?ooo`030000003oool0oooo00l0oooo9P3AcJTA0?ooo`<000001`3oool00`000000oooo
0?ooo`060?ooo`030000003oool000000140oooo9P3AcJTA0?ooo`060000003oool0oooo0000003o
ool000000P3oool5000000<0oooo00H000000?ooo`3oool000000?ooo`00000B0?oooa/0dLfY000J
0=7=ZA<0oooo00<000000?ooo`3oool00P0000050?ooo`030000003oool0oooo00@00000503ooolV
0=7=ZAP0oooo0P0000050?ooo`8000005`3ooolW0=7=ZA@0oooo0P0000030?ooo`030000003oool0
0000008000006P3ooolV0=7=ZA@0oooo00<000000?ooo`3oool0103oool2000000D0oooo00<00000
0?ooo`3oool04`3ooolV0=7=ZAL0oooo100000000`3oool000000?ooo`020?ooo`030000003oool0
oooo01H0oooo6`3AcJT001X0dLfY4`3oool3000000H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0B0?ooobH0dLfY4`3oool4000000<0oooo00<000000?ooo`3oool00P3oool30000
00030?ooo`000000oooo01<0oooo9`3AcJTC0?ooo`@000000P3oool00`000000oooo000000030000
00050?ooo`00000000000?ooo`000000503ooolV0=7=ZAH0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo9P3AcJTJ0?ooo`040000003o
ool0oooo000001/0oooo6`3AcJT001X0dLfY603oool500000080oooo00@000000?ooo`3oool00000
5@3ooolV0=7=ZAP0oooo00<000000?ooo`0000000`3oool200000080oooo00<000000?ooo`3oool0
4`3ooolW0=7=ZAX0oooo0P0000000`3oool000000?ooo`030?ooo`030000003oool0oooo01<0oooo
9P3AcJTI0?ooo`80000000<0oooo0000003oool06P3ooolV0=7=ZAH0oooo00<000000?ooo`3oool0
0P0000020?ooo`040000003oool000000?ooo`8000005P3ooolK0=7=Z@006P3AcJTG0?ooo`030000
003oool0oooo00<0oooo0P0000000`3oool000000?ooo`0F0?ooobH0dLfY6@3oool2000000040?oo
o`000000oooo000001T0oooo9`3AcJTK0?ooo`030000003oool0oooo00800000603ooolV0=7=ZAL0
oooo00D000000?ooo`3oool000000?ooo`02000001X0oooo9P3AcJTJ0?ooo`040000003oool0oooo
0?ooo`8000006@3ooolK0=7=Z@006P3AcJTG0?ooo`070000003oool0oooo0000003oool000000?oo
o`03000001L0oooo9P3AcJTG0?ooo`050000003oool0oooo0000003oool00P0000020?ooo`030000
003oool0oooo01D0oooo9`3AcJTG0?ooo`030000003oool0000000<0oooo1000000G0?ooobH0dLfY
7P3oool00`000000oooo0?ooo`0G0?ooobH0dLfY6P3oool2000000030?ooo`000000oooo01X0oooo
6`3AcJT001X0dLfY5`3oool4000000D0oooo00<000000?ooo`3oool05@3ooolV0=7=ZAL0oooo00@0
00000?ooo`000000oooo100000000`3oool000000?ooo`0F0?ooobL0dLfY5`3oool3000000<0oooo
00@000000?ooo`3oool000005`3ooolV0=7=ZAX0oooo0P0000000`3oool000000?ooo`02000001L0
oooo9P3AcJTG0?ooo`030000003oool0000000@0oooo0P0000000`3oool000000?ooo`0F0?oooa/0
dLfY000J0=7=ZA`0oooo00@000000?ooo`0000000000603ooolV0=7=ZAT0oooo00<000000?ooo`00
00001000000H0?ooobL0dLfY6P3oool010000000oooo0000003oool2000001P0oooo9P3AcJTI0?oo
o`050000003oool000000000003oool00P00000H0?ooobH0dLfY603oool01`000000oooo00000000
0000oooo0000003oool00P00000H0?oooa/0dLfY000J0=7=ZAd0oooo0P00000I0?ooobH0dLfY7@3o
ool2000001T0oooo9`3AcJTJ0?ooo`030000003oool0oooo008000006@3ooolV0=7=ZA/0oooo1000
000I0?ooobH0dLfY6@3oool01P000000oooo000000000000oooo000001X0oooo6`3AcJT001X0dLfY
6P3oool2000000030?ooo`000000oooo01T0oooo9P3AcJTJ0?ooo`80000000<0oooo0000003oool0
6@3ooolW0=7=ZAX0oooo0P0000000`3oool000000?ooo`0I0?ooobH0dLfY6`3oool3000001X0oooo
9P3AcJTJ0?ooo`040000003oool00000000001/0oooo6`3AcJT001X0dLfY6`3oool00`000000oooo
0?ooo`0J0?ooobH0dLfY6`3oool00`000000oooo0?ooo`0J0?ooobL0dLfY6`3oool00`000000oooo
0?ooo`0J0?ooobH0dLfY>03ooolV0=7=ZA/0oooo00<000000?ooo`3oool06`3ooolK0=7=Z@006P3A
cJTh0?ooobH0dLfY>03ooolW0=7=ZCP0oooo9P3AcJTh0?ooobH0dLfY>@3ooolK0=7=Z@00o`3AcJWX
0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00403AcJT5
@0000080dLfY0T0000040=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@020=7=Z@9000000`3AcJT3
@00000@0dLfY0T0000030=7=Z@E000000P3AcJT2@00000@0dLfY0T0000040=7=Z@9000000`3AcJT4
@00000<0dLfY0T00000C0=7=Z@E000000P3AcJT2@00000@0dLfY0T0000050=7=Z@03@000003AcJT0
dLfY0080dLfY0T0000030=7=Z@=00000103AcJT2@00000<0dLfY1D0000020=7=Z@900000103AcJT2
@00000@0dLfY0T0000030=7=Z@A000000P3AcJT5@0000180dLfY1D0000020=7=Z@900000103AcJT2
@00000D0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000<0dLfY0d0000040=7=Z@9000000`3AcJT5
@0000080dLfY0T0000040=7=Z@900000103AcJT2@00000<0dLfY140000020=7=Z@A000004P3AcJT5
@0000080dLfY0T0000040=7=Z@900000103AcJT2@00000<0dLfY140000040=7=Z@03@000003AcJT0
dLfY0080dLfY0T0000030=7=Z@E0000000<0dLfY@000040000000d0000000`3AcJU00000@0000003
@00000030=7=ZD000010000000=0000000@0dLfY@0000400001000001@3AcJT3@0000140dLfY1D00
00020=7=Z@900000103AcJT2@00000@0dLfY0T0000030=7=Z@=000000`3AcJT3@00000<0dLfY0d00
00030=7=Z@E0000000<0dLfY@000040000000T0000020=7=Z@A000000P3AcJT3@00000<0dLfY0d00
00030=7=Z@E000004@3AcJT00180dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003A
cJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=
Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3A
cJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000D0dLfY00A000000=7=Z@3A
cJU00000503AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3A
cJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY
0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0
dLfY@0000080dLfY00A000000=7=Z@3AcJU000001`3AcJT00d000000dLfY0=7=Z@0D0=7=Z@05@000
003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY
0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00E00000
0=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY
@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT01400
0000dLfY0=7=ZD0000050=7=Z@03@000003AcJT0dLfY01D0dLfY00E000000=7=Z@3AcJT0dLfY@000
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000
dLfY0=7=ZD0000070=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@02
0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@03
0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@0B
0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000
003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD000002
0=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=
Z@3AcJU0000000D0dLfY00=000000=7=Z@3AcJT01@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000
003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT04@3AcJT00180dLfY00=000000=7=Z@3AcJT0103A
cJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0
dLfY@00000020=7=Z@04@000003AcJT0dLfY0=7=Z@=000000P3AcJT014000000dLfY0=7=ZD000004
0=7=Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003A
cJT0dLfY@0000080dLfY00E000000=7=Z@3AcJT0dLfY@00000040=7=Z@04@000003AcJT0dLfY@000
01@0dLfY00=000000=7=Z@3AcJT0103AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0
dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY0=7=Z@=00000
0P3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00E000000=7=Z@3AcJT0dLfY@000
00060=7=Z@03@000003AcJT0dLfY01@0dLfY00=000000=7=Z@3AcJT0103AcJT014000000dLfY0=7=
ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04
@000003AcJT0dLfY0=7=Z@=000000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0
dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY
00E000000=7=Z@3AcJT0dLfY@00000050=7=Z@03@000003AcJT0dLfY01@0dLfY00=000000=7=Z@3A
cJT0103AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00E00000
0=7=Z@3AcJT0dLfY@00000060=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY
0=7=Z@020=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY
0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY0d0000020=7=Z@E000004`3AcJT00d000000dLfY
0=7=Z@040=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000
0P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0
0`3AcJT00d000000dLfY0=7=Z@030=7=Z@=000000`3AcJT3@00000@0dLfY00=000000=7=Z@3AcJT0
4@3AcJT00180dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000@0dLfY0T0000060=7=Z@04@000003A
cJT0dLfY0=7=Z@9000000`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@000
00@0dLfY00=000000=7=Z@3AcJT0103AcJT014000000dLfY0=7=Z@3AcJT2@00000@0dLfY0T000005
0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0B0=7=Z@03@000003A
cJT0dLfY0080dLfY0T0000040=7=Z@9000001P3AcJT014000000dLfY0=7=Z@3AcJT2@00000<0dLfY
00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY
00@0dLfY00A000000=7=Z@3AcJT0dLfY0T0000040=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@03
0=7=Z@03@000003AcJT0dLfY01@0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000@0dLfY0T000006
0=7=Z@04@000003AcJT0dLfY0=7=Z@9000000`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000
003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT0103AcJT014000000dLfY0=7=Z@3AcJT2@000
00@0dLfY0T0000050=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT04`3AcJT00d00
0000dLfY0=7=Z@020=7=Z@900000103AcJT2@00000@0dLfY0T0000050=7=Z@03@000003AcJT0dLfY
00@0dLfY00A000000=7=Z@3AcJT0dLfY0T0000050=7=Z@03@000003AcJT0dLfY00<0dLfY00=00000
0=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3A
cJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0180dLfY00=000000=7=Z@3AcJT0
0P3AcJT2@00000@0dLfY0T0000040=7=Z@9000000`3AcJT3@00000<0dLfY0d0000030=7=Z@=00000
1@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0
dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d00
0000dLfY0=7=Z@0A0=7=Z@004P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080
dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0
dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0
dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03
@000003AcJT0dLfY0180dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@04
@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000103AcJT01D000000
dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY
0=7=Z@0D0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000@0dLfY00E000000=7=Z@3AcJT0
dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0
4P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU0
00000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A00000
0=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY00<0dLfY
00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD00
00000P3AcJT01d000000dLfY0=7=Z@3AcJU000000=7=ZD000000503AcJT00d000000dLfY0=7=Z@02
0=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=
ZD0000030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY
0=7=Z@040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=
Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=
Z@020=7=Z@03@000003AcJT0dLfY0140dLfY000A0=7=Z@900000103AcJT3@00000<0dLfY0T000003
0=7=Z@A000000`3AcJT2@00000@0dLfY0d0000030=7=Z@900000103AcJT2@00000@0dLfY0T000004
0=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000503AcJT2@00000@0dLfY0d000003
0=7=Z@9000000`3AcJT4@00000<0dLfY0T0000040=7=Z@=000000`3AcJT2@00000@0dLfY0T000004
0=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00001D0dLfY0T000004
0=7=Z@=000000`3AcJT2@00000<0dLfY140000030=7=Z@900000103AcJT3@00000<0dLfY0T000004
0=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T00000D
0=7=Z@900000103AcJT3@00000<0dLfY0T0000040=7=Z@900000103AcJT2@00000<0dLfY14000003
0=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0d000004
0=7=Z@9000004`3AcJT2@00000@0dLfY0d0000030=7=Z@900000103AcJT2@00000@0dLfY0d000003
0=7=Z@=000000`3AcJT3@00000<0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0d000003
0=7=Z@=000000`3AcJT2@00001<0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY
003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY
000J0=7=Z@D0oooo0P0000070?ooo`040000003oool0oooo0?ooo`8000001P3oool00`000000oooo
0?ooo`050?ooo`<000004`3ooolV0=7=Z@<0oooo00@000000?ooo`00000000002@3oool300000005
0?ooo`000000oooo0?ooo`0000002P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<00000
0?ooo`3oool0203ooolW0=7=Z@D0oooo0P0000000`3oool000000?ooo`02000000D0oooo00<00000
0?ooo`3oool01@0000000`3oool000000?ooo`020?ooo`/00000103oool3000000<0oooo00<00000
0?ooo`3oool00P3ooolV0=7=Z@80oooo00D000000?ooo`000000oooo000000020?ooo`<000000`3o
ool00`000000oooo0000000700000080oooo2@0000020?ooo`D0000000@0oooo0000000000000000
0`3oool400000080oooo9P3AcJT30?ooo`8000000`3oool00`000000oooo0?ooo`040?ooo`040000
003oool0oooo000000`0oooo00<000000?ooo`3oool0103oool4000000D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?oooa/0dLfY000J0=7=Z@80oooo0P0000050?ooo`800000
103oool01P000000oooo0?ooo`000000oooo000000<0oooo0P0000020?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<0000000<0oooo0000
003oool00P3oool00`000000oooo0?ooo`0V0=7=Z@80oooo0P0000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo0P0000000`3oool000000?ooo`02000000H0oooo00<000000?ooo`3oool09`3AcJT2
0?ooo`@000000P3oool2000000030?ooo`00000000000080oooo00@000000?ooo`000000oooo1`00
00040?ooo`H0000000D0oooo000000000000oooo000000020?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`000000oooo0?ooo`0V0=7=Z@80oooo100000020?ooo`<0000000<0oooo0000003o
ool01@0000020?ooo`D0000000@0oooo00000000000000000P3oool5000000030?ooo`0000000000
00P000000P3oool010000000oooo0?ooo`0000020?ooobH0dLfY1P3oool2000000P0oooo0P00000;
0?ooo`800000203oool00`000000oooo0?ooo`060?ooo`040000003oool00000000000D0oooo6`3A
cJT001X0dLfY2P3oool00`000000oooo0?ooo`02000000040?ooo`000000oooo00000080oooo0P00
00000`3oool000000?ooo`050?ooo`<000001`3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo000000D0oooo9P3AcJT80?ooo`050000003oool0oooo0000003oool00P0000040?ooo`D0
00000P3oool2000000<0oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00H0oooo9`3AcJT50?ooo`040000003oool0oooo000000D0oooo0P000003
0?ooo`T000000P3oool700000080oooo00<000000?ooo`3oool00`3oool3000000030?ooo`000000
oooo00D0oooo9P3AcJT40?ooo`030000003oool0000000D0000000<0oooo00000000000020000003
0?ooo`P000000`3oool6000000<0oooo0`0000070?ooobH0dLfY1@3oool2000000X0oooo00<00000
0?ooo`0000000P3oool020000000oooo0?ooo`000000oooo0000003oool000001P3oool3000000X0
oooo0P0000060?oooa/0dLfY000J0=7=Z@H0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`02000000080?ooo`00000000000?ooo`000000oooo0000003oool2000000H0oooo00@00000
0?ooo`3oool000002@3oool00`000000oooo0?ooo`020?ooobH0dLfY1@3oool020000000oooo0000
003oool000000?ooo`000000oooo0P0000060?ooo`060000003oool0oooo0000003oool000000P3o
ool2000000030?ooo`000000oooo0080000000<0oooo0000003oool00P0000000`3oool000000?oo
o`020?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3ooolW0=7=Z@D0oooo00@0
00000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo1`000000103oool0
00000?ooo`3oool700000080oooo00<000000?ooo`3oool0103oool2000000040?ooo`000000oooo
000000@0oooo9P3AcJT60?ooo`@000000P3oool00`000000oooo0000000400000080oooo0`000000
0`3oool000000000000300000080oooo0`0000000`3oool000000000000600000080oooo1P000004
0?ooobH0dLfY103oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000000<0oooo0`00
00000`3oool00000000000030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3o
oolK0=7=Z@006P3AcJT60?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001`3oool3
000000D0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`8000000`3oool00`000000oooo0?oo
o`040?ooobH0dLfY2@3oool00`000000oooo0?ooo`030?ooo`800000103oool2000000H0oooo00D0
00000?ooo`000000oooo000000020?ooo`060000003oool0oooo0000003oool00000103oool01000
0000oooo0?ooo`0000060?ooobL0dLfY1`3oool00`000000oooo000000020?ooo`800000103oool8
000000<0oooo200000060?ooo`030000003oool0oooo00@000001P3ooolV0=7=Z@P0oooo00<00000
0?ooo`0000001`0000020?ooo`D0000000@0oooo00000000000000000P3oool5000000040?ooo`00
00000000000000<0oooo0P0000040?ooo`030000003oool0oooo00@0oooo9P3AcJT50?ooo`040000
003oool0oooo000000h0oooo100000000`3oool0000000000003000000D0oooo00<000000?ooo`00
00002P3oool00`000000oooo0?ooo`030?oooa/0dLfY000J0=7=Z@X0oooo0P00000<0?ooo`800000
203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo9P3AcJT80?ooo`030000
003oool0oooo00D0oooo00@000000?ooo`00000000001P3oool010000000oooo0?ooo`3oool30000
00<0oooo00@000000?ooo`3oool00000403ooolW0=7=Z@X0oooo0P0000000`3oool000000?ooo`03
0?ooo`H0000000@0oooo0000003oool0oooo0P0000000`3oool0000000000005000000<0oooo0P00
00030?ooo`030000003oool0oooo00L0oooo9P3AcJT70?ooo`070000003oool000000?ooo`000000
oooo000000050?ooo`L0000000@0oooo0000003oool0oooo1`0000020?ooo`<00000103oool30000
00L0oooo9P3AcJT60?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool00P3oool3000000T0oooo0P0000060?oo
oa/0dLfY000J0=7=Z@L0oooo0P0000050?ooo`030000003oool0oooo00@0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000h0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`05
0?ooobH0dLfY1`3oool2000000L0oooo0P0000020?ooo`030000003oool0oooo00<0oooo0`000003
0?ooo`030000003oool0oooo0080000000<0oooo0000003oool00P0000060?ooo`030000003oool0
oooo00D0oooo9`3AcJT70?ooo`@000000P3oool2000000<0oooo100000000`3oool0000000000002
0?ooo`040000003oool0oooo0?ooo`8000000P3oool3000000050?ooo`000000oooo0?ooo`000000
1@3oool00`000000oooo0?ooo`050?ooobH0dLfY1`3oool400000080oooo0P0000000`3oool00000
000000040?ooo`040000003oool000000?ooo`<00000103oool010000000oooo0000003oool40000
00<0oooo0P0000020?ooo`030000003oool0oooo00D0oooo9P3AcJT70?ooo`040000003oool0oooo
00000140oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`040000003oool0
oooo000000P0oooo6`3AcJT001X0dLfY4P3oool2000000<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo000000030?ooo`8000001@3oool010000000oooo0?ooo`00000:0?ooobH0dLfY3@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P0000000`3oool000000?oo
o`02000001T0oooo9`3AcJT:0?ooo`040000003oool0oooo000000@0oooo0P0000030?ooo`<00000
0P3oool01@000000oooo0?ooo`3oool000000080oooo0P0000030?ooo`<0000000<0oooo0000003o
ool02P3ooolV0=7=Z@T0oooo00<000000?ooo`0000000`3oool400000080oooo0`0000000`3oool0
00000000000300000080oooo0`0000000`3oool0000000000005000000d0oooo9P3AcJT80?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo6`3AcJT001X0dLfY2`3oool010000000oooo0?ooo`3oool200000003
0?ooo`00000000000080000000<0oooo0000000000001P3oool200000080oooo0`0000080?ooo`03
0000003oool0oooo00L0oooo9P3AcJT:0?ooo`030000003oool000000080000000<0oooo00000000
00000P3oool00`000000oooo000000020?ooo`8000000`3oool2000000030?ooo`000000oooo0080
oooo0`0000030?ooo`040000003oool0oooo000000T0oooo9`3AcJT:0?ooo`040000003oool0oooo
00000080oooo00H000000?ooo`00000000000?ooo`0000030?ooo`060000003oool0oooo0000003o
ool00000103oool2000000@0oooo0P000000103oool000000?ooo`0000090?ooobH0dLfY2`3oool2
000000030?ooo`00000000000080000000<0oooo0000000000000`0000000`3oool0000000000002
000000030?ooo`000000000000<0000000<0oooo0000000000000`0000020?ooo`@000002@3ooolV
0=7=Z@h0oooo00@000000?ooo`000000oooo0P0000020?ooo`040000003oool00000000000@0oooo
00<000000?ooo`0000000`3oool2000000040?ooo`000000oooo0?ooo`<00000303ooolK0=7=Z@00
6P3AcJT;0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool200000003
0?ooo`000000oooo0080oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00T0oooo9P3AcJTD0?ooo`030000003oool0000000P0oooo00D000000?ooo`00
000000000?ooo`02000000<0oooo00@000000?ooo`3oool000002`3ooolW0=7=Z@`0oooo00<00000
0?ooo`0000000P3oool3000000<0oooo00<000000?ooo`0000001P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000P3oool4000000/0oooo9P3AcJT=0?ooo`<0000000<0oooo000000000000
1P0000020?ooo`T000000P3oool400000080oooo00<000000?ooo`3oool02@3ooolV0=7=Z@`0oooo
0P0000030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00/0oooo6`3AcJT001X0dLfY5`3oool00`000000oooo0?oo
o`030?ooo`8000006@3ooolV0=7=Z@d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`@000001@3oool2000000030?ooo`000000oooo0140oooo9`3AcJT?0?ooo`80000000<0
oooo000000000000203oool2000000030?ooo`00000000000080oooo0`0000030?ooo`030000003o
ool0oooo00`0oooo9P3AcJT<0?ooo`030000003oool000000080000000<0oooo0000003oool01P00
00001@3oool00000000000000000oooo00@000000P3oool00`000000oooo0?ooo`04000000`0oooo
9P3AcJT?0?ooo`8000005P3oool010000000oooo00000000000>0?oooa/0dLfY000J0=7=Z@`0oooo
0P0000040?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`02000000D0
oooo00<000000?ooo`3oool02P3ooolV0=7=Z@`0oooo0P0000040?ooo`80000000@0oooo00000000
000000000`3oool3000000050?ooo`000000oooo0000003oool00P0000060?ooo`030000003oool0
oooo00X0oooo9`3AcJT<0?ooo`@000000P3oool2000000030?ooo`000000oooo00T0oooo00<00000
0?ooo`3oool00`0000050?ooo`030000003oool0oooo00X0oooo9P3AcJT<0?ooo`L000000`3oool2
00000080oooo1@0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`0:0?ooobH0dLfY3P3oool2000000d0oooo00<000000?ooo`3oool0203oool2
000000l0oooo6`3AcJT001X0dLfY3P3oool010000000oooo0000000000080?ooo`80000000@0oooo
0000003oool000000P3oool3000000040?ooo`000000oooo000000l0oooo9P3AcJT?0?ooo`800000
103oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000oooo0000000E
0?ooobL0dLfY4P3oool2000000030?ooo`000000000000@0oooo00@000000?ooo`00000000000P3o
ool00`000000oooo00000002000000030?ooo`000000000000l0oooo9P3AcJT>0?ooo`8000000P3o
ool010000000oooo0000000000030?ooo`D000000P3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0000000h0oooo9P3AcJT=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0000000:0?ooo`030000003oool0oooo00/0oooo6`3AcJT001X0dLfY
403oool01P000000oooo000000000000oooo000000<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000>0?ooobH0dLfY3`3o
ool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000P3oool2000000D0oooo
00@000000?ooo`3oool000003P3ooolW0=7=Z@l0oooo00<000000?ooo`3oool00P0000000`3oool0
0000000000040?ooo`80000000<0oooo0000003oool00P000000203oool00000000000000000oooo
0000003oool000003P3ooolV0=7=ZA00oooo0P0000030?ooo`050000003oool000000000003oool0
0`0000020?ooo`80000000@0oooo000000000000oooo1@00000>0?ooobH0dLfY3P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00@000000?ooo`00000000002P3oool0
0`000000oooo0?ooo`0<0?oooa/0dLfY000J0=7=ZA00oooo00<000000?ooo`3oool00P3oool01000
0000oooo00000000000:0?ooo`050000003oool0oooo0?ooo`000000403ooolV0=7=ZAP0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000100
oooo9`3AcJTA0?ooo`040000003oool00000000000<0oooo1@0000000`3oool000000?ooo`040?oo
o`@00000403ooolV0=7=ZA80oooo20000000103oool000000?ooo`3oool4000000D0oooo00<00000
0?ooo`3oool03P3ooolV0=7=Z@l0oooo00<000000?ooo`3oool01P3oool2000000030?ooo`000000
00000080oooo0P0000070?ooo`8000003`3ooolK0=7=Z@006P3AcJTE0?ooo`8000000P3oool00`00
0000oooo0?ooo`02000000<0oooo00<000000?ooo`000000503ooolV0=7=ZA80oooo00D000000?oo
o`000000oooo000000020?ooo`8000001P3oool00`000000oooo0?ooo`0D0?ooobL0dLfY503oool0
0`000000oooo0?ooo`030?ooo`@000001P3oool00`000000oooo0?ooo`0A0?ooobH0dLfY4@3oool0
0`000000oooo00000005000000040?ooo`000000000000000080oooo10000000103oool000000000
0000000A0?ooobH0dLfY403oool00`000000oooo0?ooo`060?ooo`030000003oool0000000P0oooo
00@000000?ooo`3oool000004@3ooolK0=7=Z@006P3AcJTA0?ooo`8000000`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0000000<00000103oool00`000000oooo0?ooo`0?0?ooobH0dLfY
4@3oool200000080oooo0P0000000`3oool0000000000003000000050?ooo`000000oooo0?ooo`00
0000103oool00`000000oooo0?ooo`0?0?ooobL0dLfY4@3oool4000000D0oooo100000080?ooo`03
0000003oool0oooo00l0oooo9P3AcJTA0?ooo`H000000`3oool3000000<0oooo100000020?ooo`03
0000003oool0oooo00l0oooo9P3AcJTA0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0@0?oooa/0dLfY000J0=7=ZA<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0400000080oooo00<000000?ooo`3oool04P3ooolV0=7=ZA@0oooo
0P0000080?ooo`030000003oool0oooo01L0oooo9`3AcJTH0?ooo`030000003oool0000000<00000
0P3oool010000000oooo00000000000D0?ooobH0dLfY4`3oool6000000030?ooo`00000000000080
oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`0B0?ooobH0dLfY7P3oool200000004
0?ooo`0000000000000001D0oooo6`3AcJT001X0dLfY5`3oool2000000D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0A0?ooobH0dLfY503oool010000000oooo0000003oool20000
00@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0A0?ooobL0dLfY503oool0
1@000000oooo0?ooo`000000oooo0080000000<0oooo0000000000000P3oool01@000000oooo0000
003oool0000001<0oooo9P3AcJTE0?ooo`<000000`3oool2000000040?ooo`00000000000?ooo`@0
00004`3ooolV0=7=ZAD0oooo0P0000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0503ooolK0=7=Z@006P3AcJTE0?ooo`030000003oool0000000@0oooo00L000000?ooo`000000
oooo0000003oool0000001D0oooo9P3AcJTH0?ooo`050000003oool0oooo0000003oool00`000002
0?ooo`030000003oool0oooo01<0oooo9`3AcJTF0?ooo`040000003oool0oooo00000080oooo0P00
00000`3oool0000000000002000001D0oooo9P3AcJTG0?ooo`030000003oool0oooo00@0000000D0
oooo0000003oool0oooo0000000E0?ooobH0dLfY603oool2000000<0oooo00<000000?ooo`3oool0
0P00000G0?oooa/0dLfY000J0=7=ZA`0oooo00<000000?ooo`3oool06@3ooolV0=7=ZAL0oooo00<0
00000?ooo`3oool00P00000L0?ooobL0dLfY6`3oool200000080oooo00<000000?ooo`3oool05P3o
oolV0=7=ZAH0oooo00@000000?ooo`000000oooo0`0000000`3oool0000000000002000001H0oooo
9P3AcJTG0?ooo`8000000P3oool010000000oooo0000003oool2000001P0oooo6`3AcJT001X0dLfY
5P3oool3000000P0oooo00<000000?ooo`3oool0503ooolV0=7=ZAH0oooo0P0000030?ooo`800000
103oool00`000000oooo0?ooo`0D0?ooobL0dLfY5P3oool400000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0D0?ooobH0dLfY5P3oool4000000050?ooo`000000oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0D0?ooobH0dLfY6@3oool200000080oooo00<000000?ooo`3o
ool06@3ooolK0=7=Z@006P3AcJTH0?ooo`050000003oool000000?ooo`0000006`3ooolV0=7=ZAT0
oooo0P0000000`3oool000000?ooo`0J0?ooobL0dLfY7@3oool2000001T0oooo9P3AcJTH0?ooo`80
000000H0oooo00000000000000000?ooo`00000H0?ooobH0dLfY5`3oool010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo01D0oooo6`3AcJT001X0dLfY703oool2000000030?ooo`000000
oooo01L0oooo9P3AcJTI0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool05P3o
oolW0=7=ZAT0oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`0G0?ooobH0dLfY6P3o
ool6000001P0oooo9P3AcJTH0?ooo`050000003oool0oooo0?ooo`0000000P3oool2000001P0oooo
6`3AcJT001X0dLfY7@3oool00`000000oooo0?ooo`0H0?ooobH0dLfY7@3oool00`000000oooo0?oo
o`0H0?ooobL0dLfY7@3oool00`000000oooo0?ooo`0H0?ooobH0dLfY6`3oool00`000000oooo0000
000J0?ooobH0dLfY6@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo6`3A
cJT001X0dLfY>03ooolV0=7=ZCP0oooo9`3AcJTh0?ooobH0dLfY6`3oool2000001/0oooo9P3AcJTJ
0?ooo`040000003oool0oooo000001/0oooo6`3AcJT001X0dLfY>03ooolV0=7=ZCP0oooo9`3AcJTh
0?ooobH0dLfY6`3oool00`000000oooo0?ooo`0J0?ooobH0dLfY>@3ooolK0=7=Z@006P3AcJTh0?oo
obH0dLfY>03ooolW0=7=ZCP0oooo9P3AcJTh0?ooobH0dLfY>@3ooolK0=7=Z@00o`3AcJWX0=7=Z@00
o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00403AcJT5@0000080
dLfY0T0000050=7=Z@04@000003AcJT0dLfY0=7=Z@=000000`3AcJT3@00000@0dLfY0T0000030=7=
Z@=00000103AcJT2@00000<0dLfY0d0000040=7=Z@9000001@3AcJT3@0000080dLfY0T0000040=7=
Z@9000004`3AcJT5@0000080dLfY0T0000050=7=Z@04@000003AcJT0dLfY0=7=Z@=000000`3AcJT3
@00000@0dLfY0T0000030=7=Z@=000001@3AcJT3@00000030=7=ZD000010000000=000000P3AcJT2
@00000<0dLfY1D0000030=7=Z@=0000000<0dLfY@000040000000T00000C0=7=Z@E000000P3AcJT2
@00000D0dLfY00A000000=7=Z@3AcJT0dLfY0d0000030=7=Z@=00000103AcJT2@00000<0dLfY0d00
00050=7=Z@=0000000<0dLfY@000040000000d0000020=7=Z@9000000`3AcJT5@00000<0dLfY0d00
00020=7=Z@9000004`3AcJT5@0000080dLfY0T0000050=7=Z@03@000003AcJT0dLfY00<0dLfY00=0
00000=7=Z@3AcJT00P3AcJT2@00000<0dLfY140000040=7=Z@03@000003AcJT0dLfY00<0dLfY0d00
00020=7=Z@900000103AcJT2@00000<0dLfY140000020=7=Z@A000000`3AcJT2@00001<0dLfY1D00
00020=7=Z@900000103AcJT2@00000D0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000<0dLfY0d00
00040=7=Z@900000103AcJT2@00000<0dLfY0d0000030=7=Z@=00000103AcJT2@00000<0dLfY0d00
00030=7=Z@=000004`3AcJT00180dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003A
cJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080
dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY
0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3A
cJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU0
00000P3AcJT00d000000dLfY0=7=Z@0B0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d00
0000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD00
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY
0=7=Z@040=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03
@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0103AcJT014000000dLfY0=7=ZD00000H0=7=
Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0
dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080
dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY0080
dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=
Z@3AcJT0103AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0180dLfY00E00000
0=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00`3A
cJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000001`3AcJT00d000000
dLfY0=7=Z@040=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT0
14000000dLfY0=7=ZD0000050=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU00000
503AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d00
0000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@02
0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000
003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=
Z@3AcJT0403AcJT00180dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@020=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0
dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT3@00000@0dLfY00=000000=7=Z@3AcJT00P3AcJT3
@00000@0dLfY00A000000=7=Z@3AcJT0dLfY1D0000030=7=Z@05@000003AcJT0dLfY0=7=ZD000000
0P3AcJT00d000000dLfY0=7=Z@0B0=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT0
0P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d00
0000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY0d0000020=7=Z@E000000`3AcJT00d00
0000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJT0dLfY1D000002
0=7=Z@03@000003AcJT0dLfY01D0dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@02
0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000
003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT3@0000080dLfY1D0000030=7=Z@03@000
003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=Z@3AcJT5@00000<0
dLfY00=000000=7=Z@3AcJT04`3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY0080
dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00E000000=7=
Z@3AcJT0dLfY@00000060=7=Z@04@000003AcJT0dLfY0=7=Z@E0000000D0dLfY@000003AcJT0dLfY
@00000050=7=Z@05@000003AcJT0dLfY0=7=ZD0000001@3AcJT00d000000dLfY0=7=Z@020=7=Z@04
@000003AcJT0dLfY@00001@0dLfY00=000000=7=Z@3AcJT0103AcJT014000000dLfY0=7=ZD000002
0=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003A
cJT0dLfY0=7=Z@=000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@000
00<0dLfY0d0000030=7=Z@=00000103AcJT00d000000dLfY0=7=Z@020=7=Z@=000000P3AcJT01400
0000dLfY0=7=ZD00000B0=7=Z@004P3AcJT00d000000dLfY0=7=Z@020=7=Z@9000001P3AcJT00d00
0000dLfY0=7=Z@03@00000<0dLfY0d0000060=7=Z@04@000003AcJT0dLfY@0000080dLfY00=00000
0=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00<0dLfY00A0
00000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@0000080
dLfY00=000000=7=Z@3AcJT04P3AcJT00d000000dLfY0=7=Z@020=7=Z@9000001P3AcJT00d000000
dLfY0=7=Z@03@00000<0dLfY0d0000060=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=
Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00@0dLfY00=00000
0=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3A
cJT00d000000dLfY0=7=Z@0D0=7=Z@03@000003AcJT0dLfY0080dLfY0T0000060=7=Z@03@000003A
cJT0dLfY00=000000`3AcJT3@00000H0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0103AcJT00d000000
dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@030=7=
Z@03@000003AcJT0dLfY0180dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000H0dLfY00=000000=7=
Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00=00000
0=7=Z@3AcJT0103AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY
00A000000=7=Z@3AcJT0dLfY0T0000050=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3A
cJT00P3AcJT2@00001D0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000@0dLfY0T0000060=7=Z@04
@000003AcJT0dLfY0=7=Z@9000000`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0
dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04
@000003AcJT0dLfY@00000D0dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@03
@00001<0dLfY000B0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT01400
0000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU0
00000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=00000
0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00001@0dLfY
00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@00000<0
dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@000
0080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY@00000040=7=Z@05@000003AcJT0
dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY00=0
00000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD00000E0=7=Z@03@000003AcJT0dLfY0080dLfY
00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00<0
dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@00000<0dLfY00=000000=7=ZD000000103AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=0
00000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJU000000080dLfY00A0
00000=7=Z@3AcJU00000503AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY
00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000
003AcJU000000080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@020=7=Z@04
@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00
000D0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=
ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000
0P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=
Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY0180dLfY000A
0=7=Z@900000103AcJT3@0000080dLfY140000030=7=Z@=000000`3AcJT3@00000<0dLfY0T000004
0=7=Z@=000000`3AcJT2@00000@0dLfY0d0000030=7=Z@9000001@3AcJT2@00000<0dLfY0T000004
0=7=Z@900000503AcJT2@00000@0dLfY0d0000020=7=Z@A000000`3AcJT3@00000<0dLfY0d000003
0=7=Z@900000103AcJT3@00000@0dLfY0T0000030=7=Z@900000103AcJT2@00000@0dLfY0T000005
0=7=Z@9000000`3AcJT2@00001D0dLfY0T0000040=7=Z@=000000P3AcJT4@00000<0dLfY0d000003
0=7=Z@=000000`3AcJT2@00000@0dLfY0d0000040=7=Z@9000000`3AcJT2@00000@0dLfY0T000004
0=7=Z@9000001@3AcJT2@00000<0dLfY0T00000D0=7=Z@900000103AcJT3@0000080dLfY14000002
0=7=Z@A000000`3AcJT2@00000@0dLfY0T0000030=7=Z@A00000103AcJT2@00000<0dLfY0T000004
0=7=Z@=000000`3AcJT2@00000@0dLfY0T0000040=7=Z@900000503AcJT2@00000@0dLfY0d000003
0=7=Z@9000000`3AcJT4@00000<0dLfY0T0000040=7=Z@=000000`3AcJT2@00000@0dLfY0T000004
0=7=Z@=000000`3AcJT3@00000<0dLfY0T0000040=7=Z@=000000`3AcJT3@0000180dLfY003o0=7=
ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=
ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY000J0=7=Z@P0oooo00<000000?ooo`0000000P00
00000`3oool00000000000090?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool00`3o
ool200000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3ooolV0=7=Z@L0oooo
00<000000?ooo`0000000`3oool2000000L0oooo00H000000?ooo`3oool000000?ooo`0000040?oo
o`80000000<0oooo0000003oool0103oool200000080oooo00@000000?ooo`3oool000000P3oool2
000000<0oooo9`3AcJT50?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000T0oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo0080oooo00D00000
0?ooo`000000oooo000000030?ooobH0dLfY1@3oool00`000000oooo0?ooo`070?ooo`050000003o
ool0oooo0?ooo`0000000`3oool010000000oooo0000003oool300000080oooo00<000000?ooo`3o
ool0103oool2000000l0oooo9P3AcJT40?ooo`8000000`3oool010000000oooo0?ooo`0000070?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?oo
oa/0dLfY000J0=7=Z@80oooo0P0000060?ooo`030000003oool0oooo00@000000`3oool00`000000
oooo0?ooo`0;0?ooo`8000000`3oool00`000000oooo000000090?ooo`030000003oool000000080
oooo9P3AcJT20?ooo`8000000`3oool00`000000oooo000000090?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`040000003oool0000000000080oooo0P00
00000`3oool000000?ooo`040?ooo`060000003oool0oooo0000003oool000000P3ooolW0=7=Z@80
oooo0`0000050?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo0P0000060?oo
o`040000003oool00000000000P0oooo00D000000?ooo`3oool0oooo000000030?ooo`80000000@0
oooo0000003oool0oooo9P3AcJT20?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`<00000
0`3oool010000000oooo0000003oool4000000030?ooo`000000oooo00@0oooo00<000000?ooo`3o
ool0203oool01@000000oooo0?ooo`3oool000000080oooo9P3AcJT20?ooo`8000000P3oool01@00
0000oooo0000003oool000000080oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?oo
o`0<0?ooo`80000000<0oooo0000003oool00P3oool2000000<0oooo00<000000?ooo`3oool06`3A
cJT001X0dLfY503oool01@000000oooo000000000000oooo00D0000000@0oooo0000000000000000
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo9P3AcJT90?ooo`030000
003oool000000080000000L0oooo0000003oool0oooo0000003oool000000080oooo00<000000?oo
o`000000203oool01@000000oooo0?ooo`000000oooo008000000P3oool200000080oooo00<00000
0?ooo`0000001P3ooolW0=7=Z@/0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`00
000:0?ooo`<000002P3oool010000000oooo0?ooo`0000060?ooobH0dLfY4@3oool00`000000oooo
0?ooo`020?ooo`030000003oool00000008000000`3oool00`000000oooo0?ooo`02000000040?oo
o`000000oooo000000P0oooo00@000000?ooo`3oool000001@3ooolV0=7=Z@d0oooo00<000000?oo
o`3oool0103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0?ooo`8000001`3o
ool2000000X0oooo00<000000?ooo`3oool00`3ooolK0=7=Z@006P3AcJT50?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01<0oooo9P3AcJT50?ooo`040000003oool0oooo000000P0oooo0P0000000`3oool000000000
00040?ooo`030000003oool0oooo00H0oooo1@00000@0?ooobL0dLfY1@3oool00`000000oooo0?oo
o`02000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool02P3oool01@000000oooo0000
00000000oooo008000002@3oool3000000P0oooo9P3AcJT50?ooo`030000003oool0oooo00800000
1`3oool2000000040?ooo`000000oooo0?ooo`H0000000<0oooo0000003oool0103oool4000000L0
oooo00<000000?ooo`3oool01P3ooolV0=7=Z@D0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo00P0oooo0P0000060?ooo`030000003oool0oooo00@0oooo0P00000@0?oo
oa/0dLfY000J0=7=Z@P0oooo00P000000?ooo`3oool0oooo0000003oool000000?ooo`<00000103o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool2000000050?oo
o`00000000000?ooo`0000001@3oool00`000000oooo0?ooo`040?ooobH0dLfY2P3oool00`000000
oooo00000002000000d0oooo00<000000?ooo`3oool02@3oool02P000000oooo000000000000oooo
0000003oool000000?ooo`0000060?ooobL0dLfY1`3oool4000000<0oooo00@000000?ooo`3oool0
0000103oool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool000000080oooo1@0000060?ooobH0dLfY1P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000H0oooo
9P3AcJT60?ooo`030000003oool0000000D0oooo0P0000000`3oool000000000000200000080oooo
00<000000?ooo`3oool01`3oool010000000oooo0?ooo`3oool200000080oooo00@000000?ooo`3o
ool00000103oool2000000H0oooo6`3AcJT001X0dLfY403oool00`000000oooo0?ooo`030?ooo`03
0000003oool0000000@0oooo00H000000?ooo`000000oooo0000003oool2000000<0oooo00<00000
0?ooo`000000103oool00`000000oooo0?ooo`060?ooobH0dLfY503oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool010000000oooo0?oo
o`3oool2000000P0oooo9`3AcJT:0?ooo`040000003oool0oooo0?ooo`@0000000<0oooo0000003o
ool00P3oool2000000030?ooo`000000000000<0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0000003oool0000000H0oooo00<000000?ooo`3oool01P3ooolV0=7=Z@X0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`0000000P3oool200000140oooo9P3AcJT90?ooo`8000000`3oool00`000000oooo0?ooo`02
0?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`@000000`3oool2000000030?ooo`000000
oooo00<0oooo00<000000?ooo`3oool02@3ooolK0=7=Z@006P3AcJT70?ooo`800000303oool01@00
0000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`0000001`3ooolV0=7=Z@L0oooo0P0000020?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`0000002`3oool00`000000oooo000000070?ooobL0dLfY1`3oool3000000<0oooo
00<000000?ooo`0000002@3oool4000000P0oooo00<000000?ooo`3oool0103oool3000000030?oo
o`000000oooo00H0oooo9P3AcJT70?ooo`8000001`3oool01@000000oooo0?ooo`3oool000000080
oooo0P0000020?ooo`040000003oool0oooo0?ooo`8000000`3oool2000000030?ooo`000000oooo
00<0oooo00D000000?ooo`3oool0oooo000000070?ooobH0dLfY1`3oool200000080oooo00<00000
0?ooo`0000001P3oool00`000000oooo0000000:0?ooo`030000003oool0000000<0oooo0P000003
0?ooo`030000003oool0oooo00X0oooo6`3AcJT001X0dLfY3@3oool00`000000oooo0?ooo`030?oo
o`800000103oool010000000oooo0?ooo`3oool2000000040?ooo`000000oooo0?ooo`<000004P3o
oolV0=7=Z@h0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`8000000P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3o
oolW0=7=Z@d0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`8000002@3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000/0oooo9P3AcJT>0?ooo`800000
00<0oooo0000003oool00`0000000`3oool000000?ooo`020?ooo`80000000@0oooo000000000000
00001@3oool3000000050?ooo`000000oooo0?ooo`0000002P3ooolV0=7=ZA@0oooo0P0000020?oo
o`050000003oool0oooo0000003oool00P000000103oool0000000000000000;0?ooo`030000003o
ool0oooo00P0oooo6`3AcJT001X0dLfY2P3oool00`000000oooo0?ooo`020?ooo`8000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000103oool2
000000l0oooo9P3AcJT:0?ooo`030000003oool0oooo0080000000<0oooo0000000000002P3oool0
10000000oooo0?ooo`0000060?ooo`030000003oool0oooo00l0oooo9`3AcJT:0?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`050000
003oool000000?ooo`000000403ooolV0=7=Z@X0oooo00<000000?ooo`3oool0100000020?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`0000000P3oool2000000H0oooo00<000000?oo
o`0000003@3ooolV0=7=Z@X0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool02@3ooolK0=7=Z@006P3AcJT:0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool010000000oooo0000000000020?ooo`080000003oool0
oooo0000003oool000000?ooo`0000020?ooo`030000003oool0oooo008000003P3ooolV0=7=Z@X0
oooo00<000000?ooo`3oool00`3oool2000000L0oooo00D000000?ooo`3oool0oooo000000050?oo
o`@000000P3oool00`000000oooo0?ooo`0<0?ooobL0dLfY2P3oool00`000000oooo0?ooo`0B0?oo
o`800000103oool00`000000oooo0?ooo`02000000h0oooo9P3AcJT:0?ooo`030000003oool00000
00/0oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`0000050?ooo`030000003oool0
000000`0oooo9P3AcJT:0?ooo`030000003oool0000000X0oooo00<000000?ooo`000000203oool0
0`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`090?oooa/0dLfY000J0=7=
Z@h0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo0`00
00060?ooo`030000003oool0oooo00l0oooo9P3AcJT?0?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`050000003oool000000?ooo`000000
3`3ooolW0=7=Z@h0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`030000003oool0oooo0080
oooo0P0000080?ooo`030000003oool0oooo00`0oooo9P3AcJT=0?ooo`8000002@3oool00`000000
oooo0?ooo`040?ooo`80000000@0oooo0000003oool000000`3oool00`000000oooo0?ooo`0=0?oo
obH0dLfY3@3oool200000080oooo0P0000020?ooo`040000003oool00000000000L0oooo00L00000
0?ooo`000000oooo0000003oool000000180oooo6`3AcJT001X0dLfY303oool2000000@0oooo00<0
00000?ooo`0000001P3oool2000000`0oooo00<000000?ooo`000000303ooolV0=7=Z@`0oooo0P00
00090?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00P3oool01`000000oooo
0?ooo`3oool000000?ooo`000000303ooolW0=7=Z@`0oooo0`0000020?ooo`030000003oool0oooo
0080oooo0P0000030?ooo`030000003oool0oooo0080oooo10000000103oool000000000003oool2
000000030?ooo`000000oooo00/0oooo9P3AcJT<0?ooo`800000103oool010000000oooo0?ooo`00
00020?ooo`8000003@3oool01@000000oooo0?ooo`3oool0000000`0oooo9P3AcJT<0?ooo`800000
0P3oool00`000000oooo000000040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3`3ooolK0=7=Z@006P3AcJTH0?ooo`030000003oool0oooo01d0oooo9P3AcJTG0?ooo`030000003o
ool0oooo008000001`3oool3000000030?ooo`000000oooo00l0oooo9`3AcJTB0?ooo`030000003o
ool0oooo00<0oooo0P0000040?ooo`040000003oool000000?ooo`8000000`3oool00`000000oooo
0?ooo`0>0?ooobH0dLfY4P3oool00`000000oooo0000000300000080oooo0P0000040?ooo`800000
0`3oool010000000oooo0?ooo`00000?0?ooobH0dLfY3`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00T0oooo0P0000050?ooo`030000003oool0oooo00d0oooo6`3AcJT001X0dLfY
3`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
4P3ooolV0=7=Z@l0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000020?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool04P3ooolW0=7=Z@l0oooo00D000000?oo
o`3oool0oooo000000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403ooolV
0=7=Z@l0oooo00@000000?ooo`3oool000000`3oool3000000040?ooo`000000oooo0?ooo`800000
00@0oooo00000000000000000P3oool00`000000oooo0?ooo`0@0?ooobH0dLfY503oool00`000000
oooo0?ooo`0<0?ooo`8000000`3oool00`000000oooo0?ooo`0>0?oooa/0dLfY000J0=7=Z@l0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0?ooo`8000001@3oool01000
0000oooo0?ooo`00000C0?ooobH0dLfY3`3oool00`000000oooo0?ooo`080?ooo`8000001`3oool2
000001<0oooo9`3AcJT?0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool0oooo0P00
000H0?ooobH0dLfY3`3oool00`000000oooo000000020?ooo`8000000`3oool4000000D0oooo00D0
00000?ooo`000000oooo0000000A0?ooobH0dLfY4@3oool010000000oooo0?ooo`3oool20000000:
0?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0>0?oooa/0dLfY000J0=7=ZA<0oooo0P0000020?ooo`040000003o
ool0oooo000000L0oooo00<000000?ooo`3oool04`3ooolV0=7=ZA@0oooo00L000000?ooo`3oool0
oooo0000003oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0B0?oo
obL0dLfY4`3oool00`000000oooo0?ooo`070?ooo`080000003oool0oooo0000003oool000000?oo
o`00000C0?ooobH0dLfY4P3oool200000080oooo00<000000?ooo`3oool00P3oool2000000<0oooo
0P0000000`3oool000000?ooo`0C0?ooobH0dLfY4P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0180oooo6`3AcJT001X0dLfY5@3oool2000000T0oooo1000000D0?ooobH0dLfY8`3o
ool00`000000oooo0?ooo`0B0?ooobL0dLfY5@3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool04`3ooolV0=7=ZA<0oooo00H000000?ooo`000000
00000?ooo`0000070?ooo`80000000<0oooo0000003oool04`3ooolV0=7=ZA@0oooo0P000000303o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo00000080oooo00<000000?oo
o`3oool04P3ooolK0=7=Z@006P3AcJTH0?ooo`030000003oool00000008000000P3oool00`000000
oooo0?ooo`0F0?ooobH0dLfY603oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0000
01D0oooo9`3AcJTM0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04`3ooolV0=7=
ZAT0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooobH0dLfY503oool00`00
0000oooo0?ooo`0R0?oooa/0dLfY000J0=7=ZA@0oooo00<000000?ooo`3oool0103oool4000001T0
oooo9P3AcJTD0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06@3ooolW0=7=ZA@0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0G0?ooobH0dLfY503oool010000000
oooo0?ooo`3oool600000080oooo00<000000?ooo`3oool05@3ooolV0=7=ZAX0oooo00@000000?oo
o`3oool000001@3oool00`000000oooo0?ooo`0C0?oooa/0dLfY000J0=7=ZA@0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0F0?ooobH0dLfY503oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01/0oooo9`3AcJTD0?ooo`030000003oool0oooo0080oooo0P0000020?oo
o`030000003oool0oooo01P0oooo9P3AcJTD0?ooo`040000003oool0000000000080oooo00<00000
0?ooo`3oool00`3oool2000001H0oooo9P3AcJTF0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?oooa/0dLfY000J0=7=ZAP0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0H0?ooobH0dLfY6P3oool00`000000oooo000000020000
01T0oooo9`3AcJTO0?ooo`030000003oool0oooo01H0oooo9P3AcJTG0?ooo`030000003oool00000
00<0000000<0oooo000000000000603ooolV0=7=ZAL0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0G0?oooa/0dLfY000J0=7=ZAd0oooo0P00000I0?ooobH0dLfY703oool00`000000
oooo0?ooo`0I0?ooobL0dLfY>03ooolV0=7=ZAP0oooo00<000000?ooo`0000007@3ooolV0=7=ZAT0
oooo00<000000?ooo`0000000P3oool2000001T0oooo6`3AcJT001X0dLfY703oool010000000oooo
0?ooo`00000H0?ooobH0dLfY703oool010000000oooo0?ooo`00000H0?ooobL0dLfY703oool20000
00030?ooo`000000oooo01L0oooo9P3AcJTL0?ooo`040000003oool0oooo000001P0oooo9P3AcJTH
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool05P3ooolK0=7=Z@006P3AcJTM
0?ooo`030000003oool0oooo01P0oooo9P3AcJTM0?ooo`030000003oool0oooo01P0oooo9`3AcJTM
0?ooo`030000003oool0oooo01P0oooo9P3AcJTM0?ooo`030000003oool0oooo01P0oooo9P3AcJTJ
0?ooo`030000003oool0oooo01`0oooo6`3AcJT001X0dLfY6@3oool00`000000oooo0?ooo`0L0?oo
obH0dLfY6@3oool00`000000oooo0?ooo`0L0?ooobL0dLfY6@3oool00`000000oooo0?ooo`0L0?oo
obH0dLfY6@3oool00`000000oooo0?ooo`0L0?ooobH0dLfY7P3oool00`000000oooo0?ooo`0H0?oo
oa/0dLfY000J0=7=ZCP0oooo9P3AcJTh0?ooobL0dLfY>03ooolV0=7=ZCP0oooo9P3AcJTi0?oooa/0
dLfY000J0=7=ZCP0oooo9P3AcJTh0?ooobL0dLfY>03ooolV0=7=ZCP0oooo9P3AcJTi0?oooa/0dLfY
003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY
003o0=7=ZNP0dLfY000@0=7=Z@E000000P3AcJT2@00000D0dLfY00A000000=7=Z@3AcJT0dLfY0d00
00030=7=Z@=00000103AcJT2@00000<0dLfY0d0000040=7=Z@9000001@3AcJT00d000000dLfY0=7=
Z@020=7=Z@9000001@3AcJT014000000dLfY0=7=Z@3AcJT5@0000080dLfY0T00000C0=7=Z@E00000
0P3AcJT2@00000D0dLfY00A000000=7=Z@3AcJT0dLfY0d0000030=7=Z@=00000103AcJT2@00000<0
dLfY0d0000040=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@020=7=Z@9000001@3AcJT014000000
dLfY0=7=Z@3AcJT5@00000040=7=ZD0000100000@00001@0dLfY1D0000020=7=Z@9000001@3AcJT0
14000000dLfY0=7=Z@3AcJT3@00000<0dLfY0d0000040=7=Z@9000000`3AcJT3@00000@0dLfY0T00
00050=7=Z@03@000003AcJT0dLfY0080dLfY0T0000050=7=Z@04@000003AcJT0dLfY0=7=Z@E00000
0`3AcJT00d000000dLfY0=7=Z@0A0=7=Z@E000000P3AcJT2@00000D0dLfY00A000000=7=Z@3AcJT0
dLfY0d0000030=7=Z@=00000103AcJT2@00000<0dLfY0d0000040=7=Z@9000000`3AcJT3@00000@0
dLfY0T0000050=7=Z@=0000000<0dLfY@000040000000T0000030=7=Z@9000004`3AcJT5@0000080
dLfY0T0000050=7=Z@04@000003AcJT0dLfY0=7=Z@=000000`3AcJT3@00000@0dLfY0T0000030=7=
Z@=00000103AcJT2@00000<0dLfY0d0000040=7=Z@9000001@3AcJT3@00000030=7=ZD0000100000
009000000P3AcJT3@00001<0dLfY000B0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d00
0000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD00
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY
0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY
0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0B0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3A
cJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D00
0000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3A
cJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003A
cJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0C0=7=Z@05@000003AcJT0dLfY0=7=ZD00
00000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3A
cJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY
0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@03
@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT04`3AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A00000
0=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU000001@3AcJT0
14000000dLfY0=7=ZD00000D0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY
0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=
Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3A
cJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY
00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000070=7=Z@03@000003AcJT0dLfY0140
dLfY000B0=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY
0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=
Z@03@000003AcJT0dLfY0080dLfY0d0000040=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=
Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=
Z@3AcJT0103AcJT00d000000dLfY0=7=Z@0B0=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=
Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3A
cJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY0d0000040=7=Z@03@000003A
cJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003A
cJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY01<0dLfY
00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD00
00000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=
Z@3AcJT00P3AcJT3@00000@0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=
Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=
Z@03@000003AcJT0dLfY01<0dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@020=7=
Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003A
cJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT3@00000@0dLfY00=000000=7=Z@3AcJT00P3A
cJT3@00000@0dLfY00A000000=7=Z@3AcJT0dLfY1D0000020=7=Z@03@000003AcJT0dLfY0080dLfY
00A000000=7=Z@3AcJU00000503AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY0080
dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=00000
0=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@=00000103AcJT00d000000dLfY0=7=Z@02
0=7=Z@=00000103AcJT014000000dLfY0=7=Z@3AcJT5@0000080dLfY00=000000=7=Z@3AcJT00`3A
cJT3@0000180dLfY000B0=7=Z@03@000003AcJT0dLfY0080dLfY0T0000060=7=Z@03@000003AcJT0
dLfY00=000000`3AcJT3@00000H0dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=
Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=
Z@030=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT2@00001D0dLfY00=0
00000=7=Z@3AcJT00P3AcJT2@00000H0dLfY00=000000=7=Z@3AcJT00d0000030=7=Z@=000001P3A
cJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0
0`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0
0P3AcJT014000000dLfY0=7=Z@3AcJT3@00001H0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000H0
dLfY00=000000=7=Z@3AcJT00d0000030=7=Z@=000001P3AcJT014000000dLfY0=7=ZD0000020=7=
Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=
Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@040=7=
Z@03@000003AcJT0dLfY0180dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000H0dLfY00=000000=7=
Z@3AcJT00d0000030=7=Z@=000001P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0
dLfY00<0dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003A
cJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@900000
5@3AcJT00d000000dLfY0=7=Z@020=7=Z@9000001P3AcJT00d000000dLfY0=7=Z@03@00000<0dLfY
0d0000060=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00`3AcJT014000000
dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU000000P3AcJT0
0d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=
Z@0@0=7=Z@004P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY00A00000
0=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY00A0
00000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@000
0080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003A
cJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0D0=7=Z@03@000
003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03
@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000020=7=
Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=
ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000103AcJT00d00
0000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY01D0dLfY00=000000=7=Z@3AcJT00P3AcJT00d00
0000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT00`3AcJT0
0d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000
0P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=
Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD000000
0P3AcJT00d000000dLfY0=7=Z@0B0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0
0P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3A
cJT00P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A00000
0=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000<0
dLfY00=000000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@00001@0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0
dLfY@00000<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003A
cJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=
Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY@000
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000004P3AcJT00140dLfY
0T0000040=7=Z@=000000P3AcJT4@00000<0dLfY0d0000030=7=Z@=000000`3AcJT2@00000@0dLfY
0d0000030=7=Z@9000000`3AcJT4@00000<0dLfY0T0000030=7=Z@A000000`3AcJT2@00000@0dLfY
0d00000C0=7=Z@900000103AcJT3@0000080dLfY140000030=7=Z@=000000`3AcJT3@00000<0dLfY
0T0000040=7=Z@=000000`3AcJT2@00000<0dLfY140000030=7=Z@9000000`3AcJT4@00000<0dLfY
0T0000040=7=Z@=00000503AcJT2@00000@0dLfY0d0000020=7=Z@A000000`3AcJT3@00000<0dLfY
0d0000030=7=Z@900000103AcJT3@00000<0dLfY0T0000030=7=Z@A000000`3AcJT2@00000<0dLfY
140000030=7=Z@9000000`3AcJT4@00001<0dLfY0T0000040=7=Z@=000000P3AcJT4@00000<0dLfY
0d0000030=7=Z@=000000`3AcJT2@00000@0dLfY0d0000030=7=Z@900000103AcJT3@00000<0dLfY
0T0000050=7=Z@9000000`3AcJT2@00000@0dLfY0T00000D0=7=Z@900000103AcJT3@0000080dLfY
140000030=7=Z@=000000`3AcJT3@00000<0dLfY0T0000040=7=Z@=000000`3AcJT2@00000@0dLfY
0d0000030=7=Z@9000001@3AcJT2@00000<0dLfY0T0000040=7=Z@=000004P3AcJT00?l0dLfYj03A
cJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03A
cJT00?l0dLfYj03AcJT001X0dLfY1`3oool01@000000oooo0000003oool0000000@0oooo00D00000
0?ooo`3oool0oooo000000070?ooo`800000103oool010000000oooo0?ooo`0000020?ooo`800000
103oool3000000L0oooo9P3AcJT>0?ooo`030000003oool000000080oooo0`0000000`3oool00000
00000003000000030?ooo`0000000000008000000`3oool2000000<0oooo00D000000?ooo`3oool0
oooo0000000:0?ooobL0dLfY1@3oool00`000000oooo000000020?ooo`030000003oool0000000@0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooobH0dLfY3@3oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0oooo0P00
00000`3oool000000?ooo`040?ooo`8000000`3oool00`000000oooo0?ooo`030?ooobH0dLfY1@3o
ool01P000000oooo000000000000oooo000000<0oooo00D000000?ooo`000000oooo000000060?oo
o`@000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo100000001P3o
ool000000?ooo`000000oooo000000D0oooo6`3AcJT001X0dLfY0P3oool2000000050?ooo`000000
oooo0?ooo`0000001@3oool00`000000oooo00000002000000T0oooo0P0000070?ooo`80000000<0
oooo0000000000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02H0dLfY0P3o
ool2000000040?ooo`0000000000000000D0oooo00<000000?ooo`3oool0103oool01@000000oooo
0?ooo`3oool000000080oooo0P0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo000000030?ooo`8000000`3oool00`000000oooo0?ooo`0W0=7=Z@80
oooo0P0000000`3oool00000000000020?ooo`080000003oool0oooo0?ooo`000000oooo0000003o
ool3000000<0oooo10000000103oool000000?ooo`0000030?ooo`D00000203oool00`000000oooo
000000030?ooo`030000003oool0oooo02H0dLfY0P3oool2000000030?ooo`000000oooo00P0oooo
00<000000?ooo`3oool00`0000000`3oool000000?ooo`030?ooo`050000003oool0oooo0000003o
ool01@0000040?ooo`80000000<0oooo0000000000000P0000050?ooo`030000003oool0oooo02H0
dLfY0P3oool2000000060?ooo`000000oooo0?ooo`000000oooo0P0000001P3oool000000000003o
ool000000?ooo`80000000<0oooo0000000000000`3oool01P000000oooo000000000000oooo0000
00D0oooo0P000000103oool000000?ooo`0000020?ooo`8000001`3oool00`000000oooo0?ooo`0K
0=7=Z@006P3AcJT60?ooo`030000003oool0oooo00D0oooo00@000000?ooo`00000000001@3oool0
0`000000oooo0?ooo`020?ooo`80000000<0oooo0000003oool01@3oool00`000000oooo00000005
0?ooo`800000203ooolV0=7=Z@H0oooo0P0000000`3oool0000000000004000000040?ooo`000000
00000?ooo`@0000000<0oooo0000003oool0100000000`3oool000000?ooo`02000000030?ooo`00
000000000080000000@0oooo0000000000000000103oool00`000000oooo0?ooo`050?ooobL0dLfY
1P3oool3000000D0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080
00000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`050?ooobH0dLfY1P3oool00`000000oooo0?ooo`060?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`@00000203ooolV0=7=Z@T0oooo0P00
00030?ooo`040000003oool000000?ooo`80000000@0oooo0000003oool0oooo0P0000020?ooo`<0
000000<0oooo0000003oool00P0000000`3oool000000?ooo`030?ooo`030000003oool000000080
000000<0oooo0000000000001`3ooolK0=7=Z@006P3AcJT60?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool01@3oool2000000050?ooo`000000oooo0?ooo`0000003`3oool2000000@0
oooo9P3AcJT60?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool0oooo0000003oool2
000000040?ooo`000000oooo0?ooo`H000001@3oool2000000@0oooo00<000000?ooo`0000001P3o
ool2000000@0oooo9`3AcJT60?ooo`030000003oool0oooo00<0000000<0oooo0000003oool01@3o
ool2000000L0oooo00<000000?ooo`3oool00P3oool3000000@0oooo0P000000103oool000000000
000000030?ooo`800000103ooolV0=7=Z@H0oooo00<000000?ooo`3oool01`3oool010000000oooo
0?ooo`3oool3000000X0oooo00<000000?ooo`3oool0203oool2000000@0oooo0P0000040?ooobH0
dLfY2@3oool300000080oooo00@000000?ooo`000000oooo0P0000020?ooo`050000003oool00000
0000003oool00P0000030?ooo`80000000<0oooo000000000000100000040?ooo`D0000000<0oooo
000000000000103ooolK0=7=Z@006P3AcJT90?ooo`8000001@3oool2000000<0oooo00@000000?oo
o`00000000000`3oool01P000000oooo0?ooo`3oool000000?ooo`<0000000<0oooo000000000000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo9P3AcJT<0?ooo`800000
00D0oooo000000000000oooo000000030?ooo`030000003oool000000080oooo00@000000?ooo`00
0000oooo100000020?ooo`040000003oool0000000000080oooo0P0000020?ooo`030000003oool0
oooo00H0oooo9`3AcJT:0?ooo`0:0000003oool0oooo0000003oool000000?ooo`000000oooo0000
00X0oooo00<000000?ooo`0000000P3oool2000000050?ooo`000000oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000080?ooobH0dLfY2@3oool2000000D0oooo00@000000?ooo`0000000000
0`3oool01P000000oooo0000003oool000000?ooo`800000103oool00`000000oooo0?ooo`030?oo
o`80000000D0oooo0000003oool0oooo000000080?ooobH0dLfY2P3oool2000000060?ooo`000000
00000?ooo`000000oooo0`0000000`3oool000000?ooo`03000000030?ooo`000000oooo00D00000
0P3oool4000000050?ooo`00000000000?ooo`0000000P3oool00`000000oooo0?ooo`060?oooa/0
dLfY000J0=7=Z@d0oooo0P0000070?ooo`8000001@3oool01@000000oooo0000003oool0000000D0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`080?ooobH0dLfY2`3oool2000000<0
oooo00<000000?ooo`3oool00P0000001@3oool000000?ooo`000000oooo00<000000`3oool20000
00H0oooo00@000000?ooo`0000000000303ooolW0=7=Z@/0oooo00<000000?ooo`3oool00P000000
0`3oool000000000000<0?ooo`030000003oool0oooo0080oooo0`0000000`3oool000000000000>
0?ooobH0dLfY2P3oool01P000000oooo0?ooo`3oool000000?ooo`<000001@3oool2000000<0oooo
00<000000?ooo`3oool0103oool5000000l0oooo9P3AcJT>0?ooo`8000001@3oool400000080oooo
0`0000020?ooo`030000003oool0oooo0080000000@0oooo0000003oool0oooo1000000<0?oooa/0
dLfY000J0=7=Z@L0oooo0P0000020?ooo`030000003oool000000100oooo00@000000?ooo`3oool0
oooo0P0000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3ooolV0=7=Z@L0
oooo0P0000030?ooo`80000000<0oooo0000000000000P0000020?ooo`040000003oool0oooo0?oo
o`D0000000@0oooo000000000000oooo0P0000001P3oool000000000003oool000000?ooo`<00000
0`3oool00`000000oooo0?ooo`050?ooobL0dLfY1`3oool2000000H0oooo0`0000040?ooo`060000
003oool000000?ooo`000000oooo10000000103oool000000?ooo`0000020?ooo`8000000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo9P3AcJT70?ooo`8000000P3oool0
1@000000oooo0?ooo`000000oooo008000000`3oool010000000oooo0?ooo`00000:0?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooobH0
dLfY1`3oool2000000L0oooo0P0000040?ooo`030000003oool0oooo0080000000<0oooo0000003o
ool01P3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool02`3ooolK0=7=Z@00
6P3AcJTO0?ooo`030000003oool0oooo01H0oooo9P3AcJT<0?ooo`050000003oool0oooo0?ooo`00
00000P3oool200000080oooo0P0000020?ooo`050000003oool000000?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`<0000000<0oooo0000003oool02`3ooolW0=7=Z@l0oooo00<000000?oo
o`3oool01`3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0000000>0?ooobH0dLfY3`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo00000080oooo0`0000020?ooo`80000000<0oooo0000003oool00P0000040?ooo`030000003o
ool0oooo00/0oooo9P3AcJT?0?ooo`030000003oool0oooo00<0000000@0oooo0000003oool00000
0P3oool2000000030?ooo`00000000000080000000L0oooo00000000000000000?ooo`000000oooo
008000003P3ooolK0=7=Z@006P3AcJT;0?ooo`80000000H0oooo000000000000oooo0000003oool3
000000030?ooo`000000oooo00T0oooo2P0000000`3oool00000000000090?ooobH0dLfY2`3oool2
000000L0oooo0P0000000`3oool00000000000020?ooo`H0000000<0oooo0000000000000`3oool5
000000030?ooo`000000000000T0oooo9`3AcJT;0?ooo`<000000`3oool4000000@0oooo00<00000
0?ooo`3oool01`3oool500000080oooo0P0000000`3oool00000000000090?ooobH0dLfY2`3oool2
000000<0oooo0P0000050?ooo`030000003oool0oooo00/0oooo0`0000030?ooo`040000003oool0
0000000000T0oooo9P3AcJT<0?ooo`<000000P3oool01P000000oooo0?ooo`3oool000000?ooo`<0
00000P3oool00`000000oooo0?ooo`02000000060?ooo`000000oooo0000003oool000000`3oool0
10000000oooo0000003oool2000000T0oooo6`3AcJT001X0dLfY3@3oool010000000oooo0?ooo`3o
ool200000080oooo00<000000?ooo`3oool0303oool00`000000oooo000000030?ooo`030000003o
ool0oooo00/0oooo9P3AcJT=0?ooo`80000000<0oooo0000003oool00P0000040?ooo`060000003o
ool000000000003oool000000P3oool020000000oooo0?ooo`000000oooo0000003oool000000P3o
ool00`000000oooo0?ooo`0;0?ooobL0dLfY3@3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`0000003@3ooolV0=7=Z@d0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`000000103oool00`000000oooo000000020?ooo`040000003oool0
000000000080oooo0P00000=0?ooobH0dLfY3@3oool01P000000oooo0000003oool000000?ooo`80
00000`3oool010000000oooo0?ooo`3oool2000000060?ooo`00000000000?ooo`000000oooo0P00
00030?ooo`<000003@3ooolK0=7=Z@006P3AcJTA0?ooo`030000003oool0oooo00L0oooo0`000006
0?ooo`<000004@3ooolV0=7=ZA80oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003o
ool0oooo0080000000P0oooo0000003oool000000?ooo`000000oooo00000100oooo9`3AcJT?0?oo
o`030000003oool0000000<0oooo0P0000002@3oool00000000000000000oooo0000003oool00000
0?ooo`02000000050?ooo`000000oooo0?ooo`0000004@3ooolV0=7=ZA80oooo0P0000030?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00l0oooo9P3AcJT?0?ooo`8000000`3oool010000000oooo0000000000040?ooo`030000003oool0
oooo0080oooo0`0000050?ooo`030000003oool0oooo00d0oooo6`3AcJT001X0dLfY303oool20000
00050?ooo`000000oooo0?ooo`0000004P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00X0oooo9P3AcJT<0?ooo`80000000H0oooo000000000000oooo0000003oool5000000030?oo
o`000000000000<0oooo00@000000?ooo`0000000000103oool01@000000oooo0?ooo`3oool00000
00`0oooo9`3AcJT<0?ooo`80000000<0oooo0000000000000P3oool3000000<0oooo0P0000020?oo
o`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003o
ool0oooo00X0oooo9P3AcJT<0?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo0?oo
o`0>0?ooo`8000001@3oool00`000000oooo0?ooo`0:0?ooobH0dLfY303oool2000000<0oooo1@00
00020?ooo`80000000@0oooo000000000000oooo0`0000020?ooo`040000003oool000000?ooo`80
0000403ooolK0=7=Z@006P3AcJT@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
0P3oool00`000000oooo000000050?ooo`060000003oool0oooo0000003oool00000403ooolV0=7=
ZA<0oooo0P000000103oool000000000003oool300000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`00000@0?ooobL0dLfY4P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0>0?ooobH0dLfY
403oool00`000000oooo0?ooo`020?ooo`8000002P3oool00`000000oooo0?ooo`02000000030?oo
o`000000oooo00l0oooo9P3AcJT@0?ooo`8000000P3oool2000000040?ooo`000000oooo00000080
oooo00<000000?ooo`3oool00P3oool4000000030?ooo`00000000000140oooo6`3AcJT001X0dLfY
403oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000001@3oool2000000H0
oooo0P00000>0?ooobH0dLfY403oool01P000000oooo0?ooo`3oool000000?ooo`<000000P3oool0
10000000oooo0?ooo`3oool4000000030?ooo`000000oooo0080oooo0P00000>0?ooobL0dLfY403o
ool00`000000oooo0?ooo`02000000T0oooo00@000000?ooo`000000oooo0`0000030?ooo`800000
3P3ooolV0=7=ZA00oooo00<000000?ooo`3oool00P3oool2000000D0oooo00P000000?ooo`000000
00000?ooo`000000oooo000000@0oooo0P00000>0?ooobH0dLfY3`3oool00`000000oooo0?ooo`02
00000080oooo0`0000030?ooo`80000000<0oooo0000000000001`0000000`3oool000000000000>
0?oooa/0dLfY000J0=7=ZA<0oooo0P0000050?ooo`<000000P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0100oooo9P3AcJTD0?ooo`060000003oool0oooo0?ooo`000000oooo0P00
00040?ooo`030000003oool000000080oooo00<000000?ooo`3oool0403ooolW0=7=ZA@0oooo00<0
00000?ooo`3oool00P0000000`3oool000000?ooo`020?ooo`<0000000D0oooo0000003oool0oooo
0000000B0?ooobH0dLfY4`3oool2000000030?ooo`000000000000D0oooo00@000000?ooo`3oool0
oooo0P0000020?ooo`030000003oool0oooo0100oooo9P3AcJTG0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo00000180oooo6`3AcJT0
01X0dLfY603oool2000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?oo
obH0dLfY503oool4000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?oo
obL0dLfY5@3oool02P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00000I0?ooobH0
dLfY503oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01L0oooo9P3AcJTF0?ooo`80
0000103oool2000000040?ooo`000000oooo0?ooo`8000005@3ooolK0=7=Z@006P3AcJTA0?ooo`80
00000P3oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo0P0000050?ooo`03
0000003oool0oooo00l0oooo9P3AcJTA0?ooo`8000000P3oool4000000050?ooo`00000000000000
003oool00P0000000`3oool00000000000030?ooo`030000003oool0oooo00l0oooo9`3AcJTA0?oo
o`8000001P3oool200000080oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo
00l0oooo9P3AcJTA0?ooo`8000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool03`3ooolV0=7=ZA40oooo0P0000040?ooo`<0000000<0oooo0000
000000000`3oool00`000000oooo0000000F0?oooa/0dLfY000J0=7=ZAT0oooo00<000000?ooo`3o
ool0703ooolV0=7=ZAD0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo
0000000H0?ooobL0dLfY5`3oool2000000@0oooo00<000000?ooo`000000603ooolV0=7=ZAH0oooo
0P0000080?ooo`8000005P3ooolV0=7=ZAH0oooo00D000000?ooo`3oool000000?ooo`0500000003
0?ooo`000000oooo01H0oooo6`3AcJT001X0dLfY5@3oool2000000060?ooo`000000oooo0?ooo`00
0000oooo1@0000000`3oool000000000000C0?ooobH0dLfY5@3oool3000000030?ooo`000000oooo
008000000`3oool2000000030?ooo`000000000001<0oooo9`3AcJTE0?ooo`<00000103oool01000
0000oooo0?ooo`3oool2000000030?ooo`000000000001<0oooo9P3AcJTE0?ooo`8000002P3oool0
10000000oooo00000000000C0?ooobH0dLfY4`3oool2000000030?ooo`000000oooo0080oooo0`00
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool04@3ooolK0=7=Z@006P3A
cJTG0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3ooolV0=7=ZAL0oooo00H0
00000?ooo`000000oooo0000003oool2000000030?ooo`000000oooo01H0oooo9`3AcJTG0?ooo`03
0000003oool0oooo00<0oooo0P0000000`3oool000000?ooo`0F0?ooobH0dLfY5`3oool010000000
oooo0?ooo`0000040?ooo`8000005`3ooolV0=7=ZAL0oooo0P0000001`3oool000000?ooo`000000
oooo0000003oool00P00000G0?oooa/0dLfY000J0=7=ZA`0oooo00<000000?ooo`3oool06@3ooolV
0=7=ZAT0oooo00<000000?ooo`000000703ooolW0=7=ZAT0oooo0P0000000`3oool000000?ooo`0J
0?ooobH0dLfY703oool00`000000oooo0000000I0?ooobH0dLfY6@3oool01P000000oooo0?ooo`00
0000oooo000001X0oooo6`3AcJT001X0dLfY5P3oool2000000030?ooo`000000oooo00H0oooo00<0
00000?ooo`3oool0503ooolV0=7=ZAH0oooo0P000000103oool000000?ooo`0000050?ooo`030000
003oool0oooo01@0oooo9`3AcJTF0?ooo`80000000<0oooo0000000000000P3oool01@000000oooo
0?ooo`3oool0000001H0oooo9P3AcJTF0?ooo`80000000<0oooo0000003oool01P3oool00`000000
oooo0?ooo`0D0?ooobH0dLfY5P3oool2000000@0oooo00<000000?ooo`0000006P3ooolK0=7=Z@00
6P3AcJTJ0?ooo`040000003oool0oooo000001X0oooo9P3AcJTJ0?ooo`80000000<0oooo0000003o
ool06@3ooolW0=7=ZAd0oooo00<000000?ooo`3oool0603ooolV0=7=ZAX0oooo00@000000?ooo`3o
ool000006P3ooolV0=7=ZAX0oooo00@000000?ooo`00000000006`3ooolK0=7=Z@006P3AcJTJ0?oo
o`040000003oool0oooo0?ooo`800000603ooolV0=7=ZAX0oooo0P0000020?ooo`800000603ooolW
0=7=ZAX0oooo00@000000?ooo`3oool0oooo0P00000H0?ooobH0dLfY6P3oool010000000oooo0?oo
o`3oool2000001P0oooo9P3AcJTH0?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool0
5P3ooolK0=7=Z@006P3AcJTK0?ooo`030000003oool0oooo01X0oooo9P3AcJTK0?ooo`030000003o
ool0oooo01X0oooo9`3AcJTK0?ooo`030000003oool0oooo01X0oooo9P3AcJTK0?ooo`030000003o
ool0oooo01X0oooo9P3AcJTL0?ooo`030000003oool0oooo01X0oooo6`3AcJT001X0dLfY>03ooolV
0=7=ZCP0oooo9`3AcJTh0?ooobH0dLfY>03ooolV0=7=ZCT0oooo6`3AcJT001X0dLfY>03ooolV0=7=
ZCP0oooo9`3AcJTh0?ooobH0dLfY>03ooolV0=7=ZCT0oooo6`3AcJT001X0dLfY>03ooolV0=7=ZCP0
oooo9`3AcJTh0?ooobH0dLfY>03ooolV0=7=ZCT0oooo6`3AcJT00?l0dLfYj03AcJT00?l0dLfYj03A
cJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00100dLfY1D0000020=7=Z@900000
1@3AcJT014000000dLfY0=7=Z@3AcJT3@00000<0dLfY140000030=7=Z@9000000`3AcJT5@0000080
dLfY0T0000040=7=Z@9000000`3AcJT5@00000040=7=ZD0000100000@00000@0dLfY0T0000030=7=
Z@E000004@3AcJT5@0000080dLfY0T0000050=7=Z@04@000003AcJT0dLfY0=7=Z@=000000`3AcJT4
@00000<0dLfY0T0000030=7=Z@E000000P3AcJT2@00000@0dLfY0T0000030=7=Z@E0000000@0dLfY
@000040000100000103AcJT2@00000<0dLfY1400000C0=7=Z@E000000P3AcJT2@00000D0dLfY00A0
00000=7=Z@3AcJT0dLfY0d0000030=7=Z@A000000`3AcJT2@00000<0dLfY1D0000030=7=Z@=00000
0P3AcJT2@00000<0dLfY1D0000020=7=Z@9000001@3AcJT3@0000080dLfY0T00000C0=7=Z@E00000
0P3AcJT2@00000D0dLfY00A000000=7=Z@3AcJT0dLfY0d0000030=7=Z@A000000`3AcJT2@00000<0
dLfY1D0000030=7=Z@=000000P3AcJT2@00000<0dLfY1D0000020=7=Z@9000001@3AcJT3@00000<0
dLfY0d00000A0=7=Z@E000000P3AcJT2@00000D0dLfY00A000000=7=Z@3AcJT0dLfY0d0000030=7=
Z@A000000`3AcJT2@00000<0dLfY1D0000030=7=Z@=000000P3AcJT2@00000<0dLfY1D0000020=7=
Z@9000001@3AcJT3@0000080dLfY0T00000C0=7=Z@004P3AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A00000
0=7=Z@3AcJU000001@3AcJT014000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD00
00000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=
Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3A
cJT00d000000dLfY0=7=Z@0C0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY
0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000050=7=
Z@04@000003AcJT0dLfY@00000@0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003A
cJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000H0=7=Z@05@000003AcJT0
dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD000000
0P3AcJT014000000dLfY0=7=ZD0000050=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=
Z@3AcJT0103AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00E00000
0=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU00000
0P3AcJT00d000000dLfY0=7=Z@0B0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000
dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD000005
0=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT0103AcJT014000000dLfY0=7=
ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03
@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0B0=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY
0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000050=7=Z@04@000003AcJT0dLfY@00000@0dLfY
00=000000=7=Z@3AcJT0103AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080
dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=
Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0@0=7=Z@004P3AcJT00d000000dLfY0=7=Z@040=7=
Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@05@000003AcJT0
dLfY0=7=ZD0000001`3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00<0dLfY00E0
00000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0
dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000
dLfY0=7=Z@0C0=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000
dLfY0=7=Z@3AcJU000000080dLfY00E000000=7=Z@3AcJT0dLfY@00000070=7=Z@03@000003AcJT0
dLfY0080dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=0
00000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0
0P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY01D0dLfY00=000000=7=Z@3AcJT0
103AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT01D000000
dLfY0=7=Z@3AcJU0000000L0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=Z@3AcJT5
@00000050=7=ZD000000dLfY0=7=ZD000000103AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003A
cJT0dLfY0=7=Z@E000000`3AcJT00d000000dLfY0=7=Z@0C0=7=Z@03@000003AcJT0dLfY00@0dLfY
00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00E000000=7=Z@3A
cJT0dLfY@00000070=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJT0dLfY1D000000
1@3AcJU000000=7=Z@3AcJU0000000@0dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=
Z@3AcJT5@00000030=7=ZD000010000000=000004`3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000
003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@05@000003AcJT0dLfY0=7=
ZD0000001`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY0=7=Z@E0000000D0dLfY
@000003AcJT0dLfY@00000040=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJT0dLfY
1D0000040=7=Z@03@000003AcJT0dLfY0100dLfY000B0=7=Z@03@000003AcJT0dLfY0080dLfY0T00
00060=7=Z@03@000003AcJT0dLfY00=000001@3AcJT00d000000dLfY0=7=Z@020=7=Z@9000001@3A
cJT00d000000dLfY0=7=Z@040=7=Z@04@000003AcJT0dLfY0=7=Z@9000001@3AcJT014000000dLfY
0=7=Z@3AcJT3@00000H0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0C0=7=Z@03
@000003AcJT0dLfY0080dLfY0T0000060=7=Z@03@000003AcJT0dLfY00=000001@3AcJT00d000000
dLfY0=7=Z@020=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@040=7=Z@04@000003AcJT0dLfY0=7=
Z@9000001@3AcJT014000000dLfY0=7=Z@3AcJT3@00000H0dLfY00=000000=7=Z@3AcJT00P3AcJT0
0d000000dLfY0=7=Z@0D0=7=Z@03@000003AcJT0dLfY0080dLfY0T0000060=7=Z@03@000003AcJT0
dLfY00=000001@3AcJT00d000000dLfY0=7=Z@020=7=Z@9000001@3AcJT01D000000dLfY0=7=Z@3A
cJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000
003AcJT0dLfY00@0dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@030=7=Z@03
@000003AcJT0dLfY0180dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000H0dLfY00=000000=7=Z@3A
cJT00d0000050=7=Z@03@000003AcJT0dLfY0080dLfY0T0000050=7=Z@05@000003AcJT0dLfY0=7=
ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00=00000
0=7=Z@3AcJT0103AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY
00=000000=7=Z@3AcJT04P3AcJT00d000000dLfY0=7=Z@020=7=Z@9000001P3AcJT00d000000dLfY
0=7=Z@03@00000D0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000D0dLfY00E000000=7=Z@3AcJT0
dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d00
0000dLfY0=7=Z@040=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJT0dLfY0T00
000C0=7=Z@004P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY00A00000
0=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@00000<0dLfY
00=000000=7=Z@3AcJT0103AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3A
cJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=
Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY01<0dLfY00=00000
0=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=0
00000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00@0dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=
Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=
Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000E0=7=Z@03@000003AcJT0dLfY0080dLfY00=0
00000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY0080dLfY
00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY0080
dLfY00=000000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY
0=7=ZD0000000P3AcJT01d000000dLfY0=7=Z@3AcJU000000=7=ZD0000000P3AcJT014000000dLfY
0=7=ZD00000D0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT014000000
dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU000000`3AcJT0
0d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=ZD0000000P3AcJT0
14000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT01d000000dLfY
0=7=Z@3AcJU000000=7=ZD0000000`3AcJT00d000000dLfY@000000D0=7=Z@03@000003AcJT0dLfY
0080dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0
dLfY0080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003A
cJT0dLfY0080dLfY00=000000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@05@000
003AcJT0dLfY0=7=ZD0000000P3AcJT01d000000dLfY0=7=Z@3AcJU000000=7=ZD0000000`3AcJT0
0d000000dLfY0=7=Z@0B0=7=Z@004@3AcJT2@00000@0dLfY0d0000020=7=Z@A000000`3AcJT3@000
00<0dLfY0T0000040=7=Z@=000000`3AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@000
00@0dLfY0d0000030=7=Z@900000103AcJT2@00001@0dLfY0T0000040=7=Z@=000000P3AcJT4@000
00<0dLfY0d0000030=7=Z@900000103AcJT3@00000<0dLfY0T0000040=7=Z@900000103AcJT2@000
00@0dLfY0T0000040=7=Z@=000000`3AcJT2@00000@0dLfY0T00000E0=7=Z@900000103AcJT3@000
0080dLfY140000030=7=Z@=000000`3AcJT2@00000@0dLfY0d0000030=7=Z@9000001@3AcJT2@000
00<0dLfY0T0000040=7=Z@900000103AcJT2@00000D0dLfY0T0000030=7=Z@900000503AcJT2@000
00@0dLfY0d0000020=7=Z@A000000`3AcJT3@00000<0dLfY0T0000040=7=Z@=000000`3AcJT2@000
00D0dLfY0T0000030=7=Z@900000103AcJT2@00000@0dLfY0T0000050=7=Z@900000103AcJT2@000
01<0dLfY0T0000040=7=Z@=000000P3AcJT4@00000<0dLfY0d0000030=7=Z@900000103AcJT3@000
00<0dLfY0T0000050=7=Z@9000000`3AcJT2@00000@0dLfY0T0000040=7=Z@9000001@3AcJT2@000
00<0dLfY0d00000B0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX
0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@006P3AcJT4
0?ooo`8000000`3oool00`000000oooo0?ooo`040?ooo`<0000000@0oooo000000000000oooo0P00
00020?ooo`030000003oool0oooo00D0oooo100000020?ooo`040000003oool0oooo0?ooo`800000
0`3oool2000000@0oooo9P3AcJT50?ooo`@0000000L0oooo0000003oool0oooo0000003oool00000
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P0000050?ooo`030000003oool0000000L0oooo9`3AcJT:0?oo
o`<000001`3oool00`000000oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000000P3o
ool2000000040?ooo`0000000000000000/0oooo9P3AcJT50?ooo`030000003oool0000000800000
0P3oool2000000P0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`<0000000<0oooo0000003o
ool0103oool01@000000oooo0000003oool000000080oooo0P0000060?ooobH0dLfY1@3oool01000
0000oooo0000003oool300000080oooo0P0000050?ooo`040000003oool00000000000L0oooo1000
00020?ooo`030000003oool00000008000000P3oool00`000000oooo0?ooo`090?oooa/0dLfY000J
0=7=ZA@0oooo0`0000020?ooo`@0000000<0oooo0000003oool00`0000050?ooo`030000003oool0
oooo00d0oooo9P3AcJT20?ooo`80000000<0oooo0000000000000P3oool2000000030?ooo`000000
oooo0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000030?ooo`030000003oool0000000<0oooo00@000000?ooo`000000
00000P3oool01@000000oooo0?ooo`3oool000000080oooo9`3AcJT20?ooo`80000000<0oooo0000
003oool0103oool00`000000oooo0?ooo`060?ooo`070000003oool0oooo0?ooo`000000oooo0000
00020?ooo`8000000`3oool010000000oooo0?ooo`0000060?ooo`040000003oool00000000000D0
oooo00<000000?ooo`3oool09P3AcJT20?ooo`80000000@0oooo0000003oool000000P3oool20000
00030?ooo`000000oooo00<0000000<0oooo0000000000001P3oool00`000000oooo0?ooo`020?oo
o`030000003oool000000080000000D0oooo000000000000oooo000000040?ooo`<00000103oool0
0`000000oooo0?ooo`0V0=7=Z@80oooo0P0000000`3oool00000000000040?ooo`030000003oool0
000000P0oooo00<000000?ooo`3oool0203oool2000000@0oooo00<000000?ooo`3oool00`000000
0`3oool000000?ooo`03000000<0oooo00<000000?ooo`3oool06`3AcJT001X0dLfY203oool30000
0080oooo00H000000?ooo`00000000000?ooo`0000060?ooo`D000001`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00<0oooo9P3AcJT60?ooo`<000000P3oool01@000000oooo0000
003oool000000080oooo00@000000?ooo`000000oooo0P0000000`3oool000000?ooo`040?ooo`<0
000000<0oooo0000000000000P3oool4000000<0oooo00<000000?ooo`0000001`3ooolW0=7=Z@H0
oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`3oool200000080oooo0P000000103o
ool000000?ooo`0000050?ooo`030000003oool0oooo00<00000203ooolV0=7=Z@H0oooo00@00000
0?ooo`00000000000P3oool3000000<0oooo1@0000001@3oool000000000003oool0000000D0oooo
1@0000020?ooo`@0000000@0oooo0000000000000000203ooolV0=7=Z@L0oooo0P000000103oool0
00000000000000020?ooo`030000003oool000000080000000<0oooo0000003oool02`3oool60000
00030?ooo`000000oooo0080oooo0P0000020?ooo`030000003oool0oooo00D0oooo6`3AcJT001X0
dLfY103oool2000000L0oooo0P0000020?ooo`030000003oool000000080000000<0oooo0000003o
ool01`3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo9P3AcJT60?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo000000080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3o
ool2000000L0oooo00<000000?ooo`0000000`3oool2000000@0oooo9`3AcJT60?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool0303oool010000000oooo0000000000040?ooo`800000103ooolV0=7=Z@H0
oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool000000080oooo00H00000
0?ooo`3oool0oooo0000003oool4000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00800000103ooolV0=7=Z@d0oooo0P0000020?ooo`050000
003oool000000?ooo`0000003`3oool00`000000oooo0?ooo`020?ooo`8000000`3oool010000000
oooo0000003oool2000000@0oooo6`3AcJT001X0dLfY1@3oool010000000oooo0?ooo`3oool20000
00050?ooo`000000oooo0?ooo`000000103oool3000000@0oooo0P0000030?ooo`<0000000<0oooo
0000003oool01@3oool5000000P0oooo9P3AcJT<0?ooo`050000003oool0oooo0?ooo`0000001P3o
ool2000000030?ooo`000000oooo00<0oooo0P0000001@3oool000000?ooo`3oool0000000D0oooo
00D000000?ooo`3oool0oooo000000080?ooobL0dLfY2@3oool200000080oooo0P0000050?ooo`03
0000003oool0000000P0oooo1@0000050?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool01P3ooolV0=7=Z@X0oooo0P000000103oool000000000000000030?ooo`8000001@3oool2
000000030?ooo`000000oooo00D0oooo0P0000060?ooo`80000000<0oooo0000003oool01`3ooolV
0=7=Z@d0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01P3ooolK0=7=Z@006P3AcJT60?ooo`8000001@3oool2
000000T0oooo00<000000?ooo`0000000`0000000`3oool000000?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`050?ooobH0dLfY3@3oool0
0`000000oooo000000040?ooo`<000000P3oool00`000000oooo0?ooo`040?ooo`8000000P3oool0
0`000000oooo0?ooo`0A0?ooobL0dLfY2P3oool00`000000oooo0?ooo`020?ooo`050000003oool0
00000?ooo`0000001P3oool010000000oooo0?ooo`3oool2000000<0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`080?ooobH0dLfY2P3oool2000000060?ooo`000000oooo0?oo
o`000000oooo1P000000103oool000000000000000020?ooo`80000000<0oooo0000003oool00`00
00001`3oool000000000003oool000000?ooo`0000002`3ooolV0=7=Z@h0oooo0`0000020?ooo`03
0000003oool0oooo00l0oooo0P0000001P3oool00000000000000000oooo000000`0oooo6`3AcJT0
01X0dLfY2`3oool200000080oooo00<000000?ooo`3oool00`000000103oool000000?ooo`000007
0?ooo`<0000000@0oooo000000000000oooo0P0000000`3oool0000000000004000000P0oooo9P3A
cJT70?ooo`8000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool2000000`0oooo00<000000?ooo`3oool01@3ooolW0=7=Z@L0oooo0P00
00050?ooo`050000003oool0oooo0?ooo`0000001@3oool2000000P0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo9P3AcJT70?ooo`800000
0P3oool010000000oooo0000003oool2000000050?ooo`000000oooo0?ooo`0000000P3oool40000
00<0oooo00<000000?ooo`3oool0100000000`3oool000000?ooo`030?ooo`050000003oool0oooo
0?ooo`0000001`3ooolV0=7=Z@L0oooo0P0000070?ooo`040000003oool00000000000T0oooo00P0
00000?ooo`000000oooo0000003oool000000?ooo`80000000D0oooo0000003oool0oooo0000000=
0?oooa/0dLfY000J0=7=Z@T0oooo00D000000?ooo`3oool0oooo000000070?ooo`<000000P3oool0
0`000000oooo0?ooo`020?ooo`@000002P3oool2000000T0oooo9P3AcJT?0?ooo`80000000@0oooo
0000003oool000000P3oool00`000000oooo000000080?ooo`800000503ooolW0=7=ZA<0oooo00D0
00000?ooo`00000000000?ooo`02000000<0oooo1@00000F0?ooobH0dLfY303oool3000000<0oooo
00D000000?ooo`00000000000?ooo`05000000@0oooo00<000000?ooo`0000000P3oool010000000
oooo0000003oool3000000`0oooo9P3AcJT@0?ooo`800000303oool01@000000oooo0?ooo`3oool0
000000<0oooo0P0000020?ooo`030000003oool0oooo00`0oooo6`3AcJT001X0dLfY303oool00`00
0000oooo0000000:0?ooo`030000003oool000000080oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`02000000/0oooo9P3AcJT;0?ooo`@000000P3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`80000000<0oooo0000000000000P000000
0`3oool00000000000090?ooobL0dLfY2`3oool500000080oooo00L000000?ooo`3oool0oooo0000
003oool000000080oooo0`0000030?ooo`030000003oool0oooo008000000P3oool4000000030?oo
o`000000000000T0oooo9P3AcJT;0?ooo`@000000P3oool2000000060?ooo`00000000000000003o
ool000000P3oool2000000040?ooo`00000000000?ooo`/0000000<0oooo0000000000002@3ooolV
0=7=Z@`0oooo0P0000040?ooo`@00000103oool2000000030?ooo`000000oooo00@0oooo0`000000
0`3oool000000?ooo`020?ooo`80000000<0oooo0000000000002@3ooolK0=7=Z@006P3AcJT=0?oo
o`8000000`3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo0?ooo`8000000`3oool2
000000d0oooo9P3AcJT=0?ooo`030000003oool0oooo00@0oooo100000070?ooo`@0000000D0oooo
0000003oool0oooo000000020?ooo`030000003oool0oooo00/0oooo9`3AcJT=0?ooo`030000003o
ool0oooo008000001`3oool2000000L0oooo0P0000020?ooo`8000000P3oool00`000000oooo0?oo
o`0;0?ooobH0dLfY3@3oool00`000000oooo0?ooo`030?ooo`@0000000<0oooo0000003oool01000
00020?ooo`8000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00/0oooo
9P3AcJT=0?ooo`040000003oool0oooo0?ooo`8000000P3oool6000000<0oooo00<000000?ooo`00
00000P0000030?ooo`8000000`3oool00`000000oooo0?ooo`0;0?oooa/0dLfY000J0=7=ZAl0oooo
00<000000?ooo`3oool05P3ooolV0=7=Z@l0oooo100000000`3oool000000?ooo`020?ooo`<00000
00<0oooo0000003oool00P0000020?ooo`050000003oool000000?ooo`0000004@3ooolW0=7=ZA<0
oooo0P0000040?ooo`80000000@0oooo00000000000000000`3oool00`000000oooo0?ooo`0C0?oo
obH0dLfY3`3oool2000000030?ooo`000000000000@000000`3oool010000000oooo0000003oool4
000000050?ooo`000000oooo0?ooo`000000403ooolV0=7=ZA80oooo100000020?ooo`8000001@3o
ool200000080oooo0`0000020?ooo`030000003oool0oooo00h0oooo6`3AcJT001X0dLfY4@3oool3
00000080oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`030?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000003P3ooolV0=7=Z@`0oooo0P0000000`3oool000000000
00020?ooo`800000103oool200000080oooo00@000000?ooo`3oool000000P3oool200000080oooo
00D000000?ooo`3oool0oooo0000000<0?ooobL0dLfY303oool2000000030?ooo`000000oooo00<0
oooo0P000000103oool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo0P0000000`3o
ool000000?ooo`040?ooo`030000003oool0oooo00X0oooo9P3AcJT<0?ooo`80000000<0oooo0000
003oool0200000000`3oool00000000000020?ooo`H000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo9P3AcJT<0?ooo`8000000P3oool00`000000oooo000000020?oo
o`040000003oool00000000000L0oooo0`0000030?ooo`<00000403ooolK0=7=Z@006P3AcJT=0?oo
o`8000001`3oool2000000<0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00`0oooo9P3AcJTC0?ooo`040000003oool00000000000H0oooo00@0
00000?ooo`3oool0oooo0P0000040?ooo`030000003oool0oooo00h0oooo9`3AcJT@0?ooo`040000
003oool0oooo000000@0oooo0P0000050?ooo`050000003oool0oooo0000003oool00P0000000`3o
ool000000?ooo`0?0?ooobH0dLfY403oool00`000000oooo0?ooo`0900000080oooo1`0000020?oo
o`030000003oool0oooo00h0oooo9P3AcJT@0?ooo`040000003oool000000?ooo`80000000<0oooo
0000003oool02`3oool00`000000oooo0?ooo`0B0?oooa/0dLfY000J0=7=Z@h0oooo00@000000?oo
o`000000oooo0P0000040?ooo`040000003oool0oooo000000H0oooo1000000B0?ooobH0dLfY403o
ool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo
000000030?ooo`8000003P3ooolW0=7=ZA00oooo00<000000?ooo`3oool0103oool2000000<0oooo
00@000000?ooo`00000000000`3oool00`000000oooo0?ooo`020?ooo`8000003P3ooolV0=7=ZA00
oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000<0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`02000000h0oooo9P3AcJT?0?ooo`040000003o
ool0oooo0?ooo`8000000`3oool4000000030?ooo`000000oooo00<0000000L0oooo0000003oool0
00000?ooo`000000oooo008000003P3ooolK0=7=Z@006P3AcJT?0?ooo`030000003oool0oooo00<0
oooo0`0000030?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`030000003oool0
oooo00h0oooo9P3AcJTF0?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo0100oooo9`3AcJTC0?ooo`<0000000<0oooo0000003oool00`3o
ool200000080oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0@0?ooobH0dLfY5@3o
ool2000000030?ooo`000000oooo00800000103oool4000000030?ooo`000000oooo0140oooo9P3A
cJTI0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
403ooolK0=7=Z@006P3AcJT@0?ooo`040000003oool0oooo0?ooo`8000000P3oool00`000000oooo
00000002000000030?ooo`00000000000080oooo1000000B0?ooobH0dLfY5`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01T0oooo9`3AcJTD0?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo9P3AcJTD0?ooo`03
0000003oool0oooo0080oooo100000000`3oool00000000000020?ooo`030000003oool0oooo01<0
oooo9P3AcJTF0?ooo`040000003oool00000000000D0oooo1000000F0?oooa/0dLfY000J0=7=ZA80
oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo008000004P3ooolV0=7=
ZA40oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0?0?ooobL0dLfY4@3oool2000000@0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0000000000050?ooo`030000003oool0oooo00l0oooo9P3AcJTA0?ooo`8000000P3oool0
10000000oooo0000000000020?ooo`<000000P3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00l0oooo9P3AcJTA0?ooo`800000103oool2000000L0oooo0P00000G0?oooa/0dLfY000J
0=7=ZAL0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00800000503o
oolV0=7=ZAT0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooobL0dLfY5P3o
ool010000000oooo0?ooo`0000040?ooo`80000000<0oooo0000003oool05@3ooolV0=7=ZAD0oooo
00L000000?ooo`3oool0oooo0000003oool000000080oooo00<000000?ooo`0000005`3ooolV0=7=
ZAL0oooo00<000000?ooo`3oool07`3ooolK0=7=Z@006P3AcJTE0?ooo`<000000P3oool3000000<0
oooo0P00000F0?ooobH0dLfY5@3oool4000000<0oooo00<000000?ooo`0000000`0000000`3oool0
00000000000C0?ooobL0dLfY5@3oool4000000H0oooo0`0000000`3oool000000000000C0?ooobH0
dLfY5@3oool3000000040?ooo`000000oooo000000<0oooo0`0000000`3oool000000000000C0?oo
obH0dLfY4`3oool2000000070?ooo`00000000000?ooo`000000oooo000000050?ooo`8000000P3o
ool00`000000oooo0?ooo`0A0?oooa/0dLfY000J0=7=ZCP0oooo9P3AcJTG0?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000005`3ooolW0=7=ZAL0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0E0?ooobH0dLfY5`3oool01@000000oooo0000003oool0000000@0oooo
00<000000?ooo`3oool05@3ooolV0=7=ZAL0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`0E0?oooa/0dLfY000J0=7=ZA`0oooo0P0000020?ooo`030000003oool0oooo01D0oooo
9P3AcJTI0?ooo`80000000<0oooo0000003oool06P3ooolW0=7=ZA`0oooo00<000000?ooo`3oool0
6@3ooolV0=7=ZAT0oooo00<000000?ooo`000000703ooolV0=7=ZA/0oooo00@000000?ooo`000000
00006P3ooolK0=7=Z@006P3AcJTH0?ooo`80000000<0oooo0000000000006`3ooolV0=7=ZAH0oooo
0P0000000`3oool00000000000020?ooo`050000003oool0oooo0?ooo`0000005P3ooolW0=7=ZAH0
oooo0P0000000`3oool000000?ooo`060?ooo`030000003oool0oooo01@0oooo9P3AcJTF0?ooo`80
000000@0oooo0000003oool000001@3oool00`000000oooo0?ooo`0D0?ooobH0dLfY5P3oool20000
0080oooo00<000000?ooo`3oool00P00000J0?oooa/0dLfY000J0=7=ZAL0oooo00<000000?ooo`00
00000`00000K0?ooobH0dLfY7@3oool00`000000oooo0?ooo`0H0?ooobL0dLfY6P3oool010000000
oooo0?ooo`00000J0?ooobH0dLfY6P3oool2000000030?ooo`000000oooo01T0oooo9P3AcJTJ0?oo
o`030000003oool0oooo01`0oooo6`3AcJT001X0dLfY603oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01L0oooo9P3AcJTJ0?ooo`040000003oool0oooo0?ooo`800000603ooolW0=7=
ZAX0oooo00@000000?ooo`3oool0oooo0P00000H0?ooobH0dLfY6P3oool200000080oooo0P00000H
0?ooobH0dLfY603oool2000000<0oooo00@000000?ooo`3oool00000603ooolK0=7=Z@006P3AcJTI
0?ooo`<00000703ooolV0=7=ZA/0oooo00<000000?ooo`3oool06P3ooolW0=7=ZA/0oooo00<00000
0?ooo`3oool06P3ooolV0=7=ZA/0oooo00<000000?ooo`3oool06P3ooolV0=7=ZA`0oooo00<00000
0?ooo`3oool06P3ooolK0=7=Z@006P3AcJTJ0?ooo`<000006`3ooolV0=7=ZCP0oooo9`3AcJTh0?oo
obH0dLfY>03ooolV0=7=ZCT0oooo6`3AcJT001X0dLfY>03ooolV0=7=ZCP0oooo9`3AcJTh0?ooobH0
dLfY>03ooolV0=7=ZCT0oooo6`3AcJT001X0dLfY>03ooolV0=7=ZCP0oooo9`3AcJTh0?ooobH0dLfY
>03ooolV0=7=ZCT0oooo6`3AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0
dLfYj03AcJT00?l0dLfYj03AcJT00100dLfY1D0000000`3AcJU00000@0000002@00000<0dLfY0T00
00030=7=Z@A000000`3AcJT2@00000D0dLfY00A000000=7=Z@3AcJT0dLfY1D000000103AcJU00000
@000040000040=7=Z@9000000`3AcJT5@00000040=7=ZD0000100000@00000<0dLfY140000020=7=
Z@=000004`3AcJT5@0000080dLfY0T0000050=7=Z@04@000003AcJT0dLfY0=7=Z@=000000`3AcJT4
@00000<0dLfY0T0000030=7=Z@E000000P3AcJT2@00000<0dLfY0d0000030=7=Z@E0000000@0dLfY
@0000400001000000`3AcJT5@00000<0dLfY00=000000=7=Z@3AcJT04P3AcJT5@0000080dLfY0T00
00050=7=Z@04@000003AcJT0dLfY0=7=Z@=000000`3AcJT4@00000<0dLfY0T0000030=7=Z@E00000
0P3AcJT2@00000<0dLfY0d0000030=7=Z@E0000000@0dLfY@0000400001000000`3AcJT5@0000080
dLfY0T00000C0=7=Z@E000000P3AcJT2@00000D0dLfY00A000000=7=Z@3AcJT0dLfY0d0000030=7=
Z@A000000`3AcJT2@00000<0dLfY1D0000020=7=Z@9000000`3AcJT3@00000<0dLfY1D000000103A
cJU00000@000040000030=7=Z@E0000000@0dLfY@0000400001000004`3AcJT5@0000080dLfY0T00
00050=7=Z@04@000003AcJT0dLfY0=7=Z@=000000`3AcJT4@00000<0dLfY0T0000030=7=Z@E00000
0P3AcJT2@00000@0dLfY0T0000030=7=Z@E0000000@0dLfY@000040000100000103AcJT2@00000@0
dLfY0T00000C0=7=Z@004P3AcJT01D000000dLfY0=7=Z@3AcJU0000000D0dLfY00A000000=7=Z@3A
cJU000000P3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=00000
0=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU00000
0P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0
dLfY@00000070=7=Z@03@000003AcJT0dLfY01<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=
Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0
dLfY@00000D0dLfY00A000000=7=Z@3AcJU00000103AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY
00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY
01@0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00E00000
0=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@00000D0dLfY00A000000=7=Z@3AcJU0
0000103AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT0
0d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT0
1D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT04P3AcJT01D000000dLfY0=7=
Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00A000000=7=Z@3AcJU000001@3AcJT014000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0
dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY
00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY
00=000000=7=Z@3AcJT04`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3A
cJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000001@3AcJT0
14000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=
Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=
Z@0@0=7=Z@004P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY00A00000
0=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@050=7=Z@03@000003AcJT0dLfY0080dLfY00=0
00000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0
0P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY0d0000030=7=Z@03@000
003AcJT0dLfY00<0dLfY0d00000D0=7=Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT0
0P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00E000000=7=Z@3AcJT0dLfY@00000070=7=
Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU0
00000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@=00000103AcJT0
0d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY01@0dLfY00=000000=7=Z@3AcJT0103AcJT0
0d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT01D000000dLfY0=7=
Z@3AcJU0000000L0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000
003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080
dLfY0d0000040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0B0=7=
Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU0
00000080dLfY00E000000=7=Z@3AcJT0dLfY@00000070=7=Z@03@000003AcJT0dLfY0080dLfY00=0
00000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0
0P3AcJT00d000000dLfY0=7=Z@020=7=Z@=00000103AcJT00d000000dLfY0=7=Z@020=7=Z@=00000
503AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0
dLfY@00000020=7=Z@05@000003AcJT0dLfY0=7=ZD0000001`3AcJT00d000000dLfY0=7=Z@020=7=
Z@03@000003AcJT0dLfY00<0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0
dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00E0
00000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0100dLfY000B0=7=Z@03@000003A
cJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000D0dLfY00=000000=7=Z@3AcJT00P3A
cJT2@00000H0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=Z@3AcJT3@00000H0dLfY
00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3A
cJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT04P3AcJT00d00
0000dLfY0=7=Z@020=7=Z@9000001P3AcJT00d000000dLfY0=7=Z@03@00000D0dLfY00=000000=7=
Z@3AcJT00P3AcJT2@00000D0dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@03@000
00D0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00=00000
0=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@0C0=7=Z@03@000003AcJT0dLfY0080dLfY0T000006
0=7=Z@03@000003AcJT0dLfY00=000001@3AcJT00d000000dLfY0=7=Z@020=7=Z@9000001@3AcJT0
0d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY00=000001@3AcJT01D000000dLfY0=7=Z@3A
cJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@9000005@3A
cJT00d000000dLfY0=7=Z@020=7=Z@9000001P3AcJT00d000000dLfY0=7=Z@03@00000D0dLfY00=0
00000=7=Z@3AcJT00P3AcJT2@00000D0dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=
Z@03@00000D0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0180dLfY00=000000=7=Z@3A
cJT00P3AcJT2@00000H0dLfY00=000000=7=Z@3AcJT00d0000050=7=Z@03@000003AcJT0dLfY0080
dLfY0T0000050=7=Z@03@000003AcJT0dLfY00@0dLfY00A000000=7=Z@3AcJT0dLfY0T0000050=7=
Z@04@000003AcJT0dLfY0=7=Z@=000001P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003A
cJT0dLfY0100dLfY000B0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=
ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00E000000=7=Z@3AcJT0dLfY@00000040=7=
Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@02
0=7=Z@04@000003AcJT0dLfY@00000@0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000
003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0B0=7=
Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD000003
0=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=
Z@040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT01D000000dLfY0=7=Z@3AcJU0000000H0
dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=
Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY01<0dLfY00=000000=7=Z@3AcJT00P3AcJT0
0d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT00P3A
cJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00@0dLfY00E000000=7=Z@3AcJT0
dLfY@00000020=7=Z@05@000003AcJT0dLfY0=7=ZD0000001P3AcJT01D000000dLfY0=7=Z@3AcJU0
00000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=0
00000=7=Z@3AcJT04P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY00A0
00000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@00000<0
dLfY00=000000=7=Z@3AcJT0103AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00E000000=7=
Z@3AcJT0dLfY@00000060=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=
Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0B0=7=Z@03@000
003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03
@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@040=7=
Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003A
cJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003A
cJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000004P3AcJT00140dLfY0T0000040=7=Z@900000
103AcJT2@00000@0dLfY0T0000040=7=Z@=000000P3AcJT4@00000<0dLfY0T0000040=7=Z@=00000
0`3AcJT2@00000@0dLfY0T0000040=7=Z@=000000`3AcJT2@00000@0dLfY0d00000C0=7=Z@900000
103AcJT3@0000080dLfY140000030=7=Z@=000000`3AcJT2@00000@0dLfY0d0000030=7=Z@900000
103AcJT2@00000@0dLfY0d0000030=7=Z@900000103AcJT3@00000<0dLfY0T0000030=7=Z@A00000
503AcJT2@00000@0dLfY0d0000020=7=Z@A000000`3AcJT3@00000<0dLfY0T0000040=7=Z@=00000
0`3AcJT2@00000@0dLfY0T0000040=7=Z@=000000`3AcJT2@00000@0dLfY0d0000030=7=Z@900000
103AcJT2@00001@0dLfY0T0000040=7=Z@=000000P3AcJT4@00000<0dLfY0d0000030=7=Z@900000
103AcJT3@00000<0dLfY0T0000040=7=Z@900000103AcJT3@00000<0dLfY0T0000040=7=Z@=00000
0`3AcJT2@00000@0dLfY0d00000C0=7=Z@900000103AcJT3@0000080dLfY140000030=7=Z@=00000
0`3AcJT2@00000@0dLfY0d0000030=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000
103AcJT3@00000<0dLfY0T0000040=7=Z@9000004`3AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT0
0?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT0
0?l0dLfYj03AcJT001X0dLfY1@3oool:000000040?ooo`0000000000000000L0oooo100000000`3o
ool000000?ooo`020?ooo`@000000P3oool010000000oooo0000003oool6000000D0oooo9P3AcJT9
0?ooo`030000003oool0oooo0080oooo00H000000?ooo`000000oooo0000003oool2000000H0oooo
0P0000060?ooo`060000003oool0oooo0000003oool000000`3oool200000080oooo0P0000050?oo
obL0dLfY0P3oool01`000000oooo0?ooo`3oool000000?ooo`0000003@3oool00`000000oooo0000
0002000000<0oooo00@000000?ooo`00000000002`3oool3000000<0oooo0`0000020?ooobH0dLfY
0P3oool010000000oooo0?ooo`3oool3000000<0oooo100000030?ooo`040000003oool0oooo0000
0080oooo1P0000000`3oool00000000000020?ooo`030000003oool0oooo00@0oooo0P0000020?oo
o`8000000P3oool300000080oooo9P3AcJT20?ooo`030000003oool0oooo00`0oooo1@0000000`3o
ool000000?ooo`020?ooo`<000001@3oool4000000030?ooo`000000oooo00D0oooo00<000000?oo
o`0000000P3oool300000080oooo6`3AcJT001X0dLfY0`3oool00`000000oooo0?ooo`060?ooo`@0
00001@3oool2000000X0oooo00<000000?ooo`0000001@3oool3000000L0oooo0P0000030?ooobH0
dLfY0`3oool00`000000oooo000000060?ooo`<000000`3oool2000000@0oooo0`0000020?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`000000203oool010000000oooo0?ooo`3ooolW0=7=
Z@@0oooo0P0000080?ooo`80000000L0oooo0000003oool0oooo0000003oool0000000@0oooo0P00
00040?ooo`030000003oool0oooo00@0000000<0oooo0000000000001P3oool010000000oooo0?oo
o`0000030?ooobH0dLfY103oool3000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`80
00004@3oool4000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
0?ooobH0dLfY103oool3000000<0oooo0P000000103oool000000?ooo`0000060?ooo`8000001P3o
ool00`000000oooo0?ooo`02000000H0oooo0P0000020?ooo`<000000P3oool010000000oooo0?oo
o`0000030?oooa/0dLfY000J0=7=Z@H0oooo00<000000?ooo`0000000`3oool3000000D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo000000020?ooo`040000003oool0oooo00000080oooo
1@00000;0?ooobH0dLfY1@3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3o
ool0103oool00`000000oooo000000050?ooo`80000000<0oooo0000000000000`3oool2000000H0
oooo00@000000?ooo`3oool0oooo100000050?ooobL0dLfY103oool00`000000oooo0?ooo`020?oo
o`040000003oool00000000000T0oooo00<000000?ooo`0000000P0000020?ooo`030000003oool0
00000080000000<0oooo0000003oool01P3oool01@000000oooo0000003oool0000000P0oooo9P3A
cJT40?ooo`030000003oool0oooo00@0oooo100000030?ooo`040000003oool0oooo000000H0oooo
0P0000040?ooo`@000001@3oool00`000000oooo0000000:0?ooobH0dLfY103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`040000003oool0000000000080
oooo00<000000?ooo`3oool00P3oool5000000<0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`060?oooa/0dLfY000J0=7=Z@@0oooo0P0000030?ooo`8000002`3oool00`000000oooo
0?ooo`020?ooo`80000000<0oooo0000003oool00`00000:0?ooo`8000000P3oool2000000D0oooo
9P3AcJT40?ooo`<0000000<0oooo0000003oool0203oool3000000D0oooo0`000000103oool00000
0?ooo`0000020?ooo`8000001@3oool01@000000oooo0?ooo`3oool000000080oooo0P0000050?oo
obL0dLfY103oool2000000050?ooo`000000oooo0000003oool00P0000070?ooo`<0000000@0oooo
00000000000000000`3oool010000000oooo0?ooo`0000090?ooo`030000003oool000000080oooo
00<000000?ooo`3oool01@3ooolV0=7=Z@@0oooo0P0000000`3oool00000000000020?ooo`800000
00<0oooo0000000000000P0000000`3oool000000?ooo`060?ooo`8000001P3oool4000000@0oooo
00H000000?ooo`00000000000?ooo`0000070?ooobH0dLfY103oool2000000050?ooo`000000oooo
0000003oool00P0000020?ooo`80000000L0oooo0000003oool0oooo0000003oool0000000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`80000000D0oooo0000003oool0
oooo0000000:0?oooa/0dLfY000J0=7=Z@T0oooo0`0000040?ooo`030000003oool0oooo0080oooo
0`0000020?ooo`<000000`3oool2000000/0oooo0`0000080?ooobH0dLfY403oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool3000000H0oooo00<000000?ooo`00
00003P3ooolW0=7=Z@/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo000000060?ooobH0dLfY2P3oool30000
00030?ooo`000000oooo00<0oooo00@000000?ooo`3oool000000`3oool8000000H0oooo00@00000
0?ooo`00000000001@3oool00`000000oooo0?ooo`040?ooobH0dLfY1P3oool00`000000oooo0?oo
o`050?ooo`050000003oool000000?ooo`0000000P3oool01P000000oooo0?ooo`3oool000000?oo
o`@000000P3oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000001P3ooolK
0=7=Z@006P3AcJT80?ooo`<000002@3oool6000000050?ooo`00000000000000003oool010000009
0?ooo`030000003oool0000000T0oooo9P3AcJT;0?ooo`030000003oool0000000D0oooo10000004
0?ooo`030000003oool0oooo0080oooo0P00000;0?ooo`<00000203ooolW0=7=Z@L0oooo0`000000
0`3oool0000000000002000000D0oooo0P0000020?ooo`060000003oool000000000003oool00000
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
1@3ooolV0=7=Z@L0oooo0`0000040?ooo`800000503oool00`000000oooo0?ooo`060?ooo`040000
003oool0oooo000000L0oooo9P3AcJT70?ooo`<000000P3oool400000080oooo00<000000?ooo`3o
ool00`0000040?ooo`030000003oool0oooo00T0oooo0`000000103oool000000?ooo`00000:0?oo
oa/0dLfY000J0=7=Z@P0oooo0`00000?0?ooo`<00000403oool3000000P0oooo9P3AcJT80?ooo`80
00000`3oool200000080oooo0P0000030?ooo`040000003oool0oooo0?ooo`<0000000D0oooo0000
003oool0oooo000000020?ooo`030000003oool0000000<000000`3oool3000000P0oooo9`3AcJT:
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool2000000L0oooo00<0
00000?ooo`000000103oool3000000030?ooo`000000oooo0080oooo0P0000080?ooobH0dLfY2P3o
ool400000080oooo0P000000203oool000000?ooo`000000oooo0000003oool000000P3oool20000
00030?ooo`000000oooo00<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`020000
00P0oooo9P3AcJT:0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`0000000000103o
ool00`000000oooo0?ooo`020?ooo`040000003oool0000000000080oooo10000000203oool00000
0?ooo`3oool000000?ooo`000000oooo0P0000080?oooa/0dLfY000J0=7=ZA80oooo00D000000?oo
o`000000oooo0000000:0?ooo`030000003oool0oooo01@0oooo9P3AcJT;0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooobL0dLfY2@3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00@000000?ooo`000000oooo0P0000001@3oool00000
0000003oool000000080oooo0`00000D0?ooobH0dLfY2@3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030000
00@0oooo0P00000>0?ooobH0dLfY2@3oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3o
ool00`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0=0?oooa/0dLfY000J0=7=Z@T0oooo0P0000080?ooo`040000003oool0
oooo0?ooo`80000000@0oooo000000000000oooo100000020?ooo`800000203oool00`000000oooo
0?ooo`080?ooobH0dLfY2@3oool01P000000oooo0?ooo`000000oooo00000080oooo00@000000?oo
o`000000oooo0P0000020?ooo`80000000@0oooo0000003oool000000P3oool3000000030?ooo`00
000000000080000000D0oooo000000000000oooo0000000:0?ooobL0dLfY2@3oool010000000oooo
0?ooo`0000090?ooo`D0000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`060?ooo`<0
00002`3ooolV0=7=Z@T0oooo00<000000?ooo`3oool00P0000040?ooo`030000003oool0oooo00D0
oooo1@0000030?ooo`80000000<0oooo0000003oool00`3oool3000000/0oooo9P3AcJT90?ooo`04
0000003oool00000000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P000000103o
ool000000?ooo`3oool200000080oooo0P0000020?ooo`030000003oool0oooo00/0oooo6`3AcJT0
01X0dLfY3@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0P0000050?oo
o`@000000P3oool00`000000oooo0?ooo`0=0?ooobH0dLfY2`3oool200000080oooo00D000000?oo
o`3oool0oooo000000020?ooo`800000103oool600000080oooo0P0000040?ooo`800000303ooolW
0=7=Z@h0oooo00<000000?ooo`3oool00P00000:0?ooo`<000000`3oool4000000D0oooo00<00000
0?ooo`3oool02@3ooolV0=7=ZA00oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3ooolV0=7=Z@/0oooo00H00000
0?ooo`3oool000000?ooo`0000070?ooo`030000003oool0oooo008000000`3oool2000000030?oo
o`000000oooo01@0oooo6`3AcJT001X0dLfY3P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000`3oool00`000000oooo00000003000000D0oooo0P0000040?ooo`030000003oool0oooo00`0
oooo9P3AcJT>0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000050?ooo`030000003oool0000001<0oooo9`3AcJT<0?ooo`030000003oool0oooo
00D0oooo0`0000040?ooo`<0000000@0oooo00000000000000001`3oool3000000`0oooo9P3AcJT<
0?ooo`040000003oool0oooo0?ooo`<0000000@0oooo0000003oool000000P3oool00`000000oooo
000000020?ooo`030000003oool0oooo008000000P3oool200000080oooo0`00000<0?ooobH0dLfY
303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0000000D0oooo000000000000
00000?ooo`02000000030?ooo`00000000000080oooo0P00000=0?oooa/0dLfY000J0=7=Z@d0oooo
00<000000?ooo`3oool00`3oool3000000<0oooo00<000000?ooo`0000000P0000040?ooo`<00000
103oool2000000d0oooo9P3AcJT=0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`030?ooo`80000000<0oooo0000003oool01P3oool200000080oooo00<000000?ooo`3o
ool02`3ooolW0=7=Z@h0oooo100000060?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool0oooo0P000000103oool000000000000000020?ooo`030000003oool0oooo00/0oooo9P3AcJT>
0?ooo`<000000P3oool00`000000oooo0?ooo`02000000H0oooo0P000000103oool000000?ooo`00
00030?ooo`040000003oool0oooo000000d0oooo9P3AcJT>0?ooo`030000003oool0000000@0oooo
00@000000?ooo`00000000001P3oool2000000030?ooo`000000000000@0oooo00@000000?ooo`3o
ool000003@3ooolK0=7=Z@006P3AcJT?0?ooo`030000003oool0000000H0oooo0P0000060?ooo`03
0000003oool0oooo0080oooo1000000?0?ooobH0dLfY3P3oool200000080oooo0P0000000`3oool0
00000?ooo`020?ooo`@000000`3oool01P000000oooo0?ooo`000000oooo00000180oooo9`3AcJT@
0?ooo`030000003oool0oooo0080oooo0P0000000`3oool000000?ooo`02000000<0oooo00@00000
0?ooo`00000000000P3oool00`000000oooo00000002000000h0oooo9P3AcJT@0?ooo`030000003o
ool0oooo0080oooo0P0000020?ooo`030000003oool00000008000000`3oool00`000000oooo0000
00030?ooo`<000003P3ooolV0=7=Z@l0oooo0P000000103oool000000000000000070?ooo`800000
00<0oooo0000003oool00P0000020?ooo`040000003oool000000?ooo`8000003P3ooolK0=7=Z@00
6P3AcJT>0?ooo`@00000103oool3000000D0oooo00@000000?ooo`3oool00000103oool3000000l0
oooo9P3AcJT>0?ooo`<00000103oool010000000oooo0000000000090?ooo`80000000<0oooo0000
003oool00P00000?0?ooobL0dLfY3P3oool2000000040?ooo`0000000000000000X0oooo0P000006
0?ooo`030000003oool0oooo00l0oooo9P3AcJT>0?ooo`80000000<0oooo000000000000403oool2
000000030?ooo`000000oooo0100oooo9P3AcJT>0?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`0000000P3oool2000000<0oooo0P0000020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool03P3ooolK0=7=Z@006P3AcJTG0?ooo`8000001P3oool2000001L0oooo9P3AcJTB
0?ooo`8000001@3oool01P000000oooo0?ooo`000000oooo000001T0oooo9`3AcJTC0?ooo`030000
003oool000000080oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`030?ooo`050000
003oool0oooo0?ooo`000000403ooolV0=7=ZAH0oooo00<000000?ooo`3oool00P0000030?ooo`03
0000003oool0oooo00800000103oool00`000000oooo0?ooo`0>0?ooobH0dLfY403oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0080oooo0P00000F0?oooa/0dLfY000J0=7=ZA80oooo
0P0000000`3oool0000000000003000000D0oooo00D000000?ooo`000000oooo0000000D0?ooobH0
dLfY5`3oool2000000<0oooo0P0000060?ooo`8000004P3ooolW0=7=ZA40oooo0`0000050?ooo`80
00000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00l0oooo9P3AcJTA0?ooo`<0
0000103oool00`000000oooo0?ooo`030?ooo`<0000000<0oooo0000003oool00P3oool00`000000
oooo0?ooo`0?0?ooobH0dLfY4@3oool200000080oooo0P0000020?ooo`060000003oool0oooo0000
003oool000000P3oool4000001@0oooo6`3AcJT001X0dLfY4P3oool200000080oooo0`0000050?oo
o`040000003oool0000000000080oooo0P00000B0?ooobH0dLfY4P3oool2000000040?ooo`000000
000000000080oooo0P0000020?ooo`050000003oool000000000003oool00`00000B0?ooobL0dLfY
5@3oool400000080oooo00D000000?ooo`3oool000000?ooo`0600000180oooo9P3AcJTE0?ooo`80
00000P3oool01@000000oooo0000003oool000000080oooo1P00000B0?ooobH0dLfY4`3oool50000
00<0oooo0P0000040?ooo`8000000P3oool200000180oooo6`3AcJT001X0dLfY503oool00`000000
oooo0?ooo`030?ooo`D000000`3oool00`000000oooo0?ooo`0C0?ooobH0dLfY5@3oool3000000<0
oooo0P0000000`3oool0000000000003000001D0oooo9`3AcJTC0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140
oooo9P3AcJTC0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0140oooo9P3AcJTC0?ooo`030000003oool0oooo00h0
oooo0P00000C0?oooa/0dLfY000J0=7=ZA<0oooo0P0000040?ooo`030000003oool0000000800000
1@3oool00`000000oooo0?ooo`0B0?ooobH0dLfY4`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool04P3ooolW0=7=ZA<0oooo00<000000?ooo`000000
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01<0oooo9P3AcJTC0?ooo`030000
003oool0000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000E0?ooobH0
dLfY5@3oool010000000oooo0?ooo`0000040?ooo`@0000000@0oooo0000003oool00000503ooolK
0=7=Z@006P3AcJTJ0?ooo`@000006P3ooolV0=7=ZAD0oooo100000030?ooo`040000003oool00000
0?ooo`8000005P3ooolW0=7=ZAP0oooo0P0000020?ooo`030000003oool000000080000000<0oooo
0000003oool0503ooolV0=7=ZAP0oooo0P0000020?ooo`030000003oool000000080000000<0oooo
0000003oool0503ooolV0=7=ZAD0oooo00<000000?ooo`3oool00P000000103oool000000?ooo`3o
ool4000001L0oooo6`3AcJT001X0dLfY>03ooolV0=7=ZAT0oooo00@000000?ooo`3oool0oooo0P00
000I0?ooobL0dLfY5P3oool00`000000oooo000000040?ooo`030000003oool0oooo008000005P3o
oolV0=7=ZAH0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`02000001H0oooo9P3A
cJTF0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0000000G0?oooa/0dLfY
000J0=7=ZAL0oooo00<000000?ooo`3oool00`3oool010000000oooo00000000000G0?ooobH0dLfY
5`3oool01P000000oooo0000003oool000000?ooo`80000000<0oooo0000003oool05P3ooolW0=7=
ZAP0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooobH0dLfY603oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo9P3AcJTO0?ooo`030000003oool00000
01L0oooo6`3AcJT001X0dLfY6`3oool2000000030?ooo`000000oooo01P0oooo9P3AcJTH0?ooo`03
0000003oool0oooo00<000006P3ooolW0=7=ZAd0oooo00<000000?ooo`000000603ooolV0=7=ZAd0
oooo00<000000?ooo`000000603ooolV0=7=ZAP0oooo00<000000?ooo`0000001@3oool00`000000
oooo0?ooo`0F0?oooa/0dLfY000J0=7=ZAP0oooo0P0000030?ooo`8000006@3ooolV0=7=ZAP0oooo
0P0000030?ooo`8000006@3ooolW0=7=ZAP0oooo0P00000N0?ooobH0dLfY603oool2000001h0oooo
9P3AcJTN0?ooo`8000006@3ooolK0=7=Z@006P3AcJTK0?ooo`030000003oool0oooo01X0oooo9P3A
cJTK0?ooo`030000003oool0oooo01X0oooo9`3AcJTJ0?ooo`80000000<0oooo0000003oool06@3o
oolV0=7=ZAX0oooo0P0000000`3oool000000?ooo`0I0?ooobH0dLfY6P3oool010000000oooo0000
0000000K0?oooa/0dLfY000J0=7=ZCP0oooo9P3AcJTh0?ooobL0dLfY>03ooolV0=7=ZCP0oooo9P3A
cJTi0?oooa/0dLfY000J0=7=ZCP0oooo9P3AcJTh0?ooobL0dLfY>03ooolV0=7=ZCP0oooo9P3AcJTi
0?oooa/0dLfY000J0=7=ZCP0oooo9P3AcJTh0?ooobL0dLfY>03ooolV0=7=ZCP0oooo9P3AcJTi0?oo
oa/0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=
ZNP0dLfY000@0=7=Z@E0000000<0dLfY@000040000000T0000030=7=Z@9000000`3AcJT4@0000080
dLfY1D0000020=7=Z@900000103AcJT2@00000<0dLfY0d0000040=7=Z@9000000`3AcJT3@00000@0
dLfY0T0000050=7=Z@=000000P3AcJT2@00001<0dLfY1D0000000`3AcJU00000@0000002@00000<0
dLfY0T0000030=7=Z@A000000P3AcJT5@0000080dLfY0T0000040=7=Z@9000000`3AcJT3@00000@0
dLfY0T0000030=7=Z@=00000103AcJT2@00000D0dLfY0d0000030=7=Z@=000004P3AcJT5@0000003
0=7=ZD0000100000009000000`3AcJT2@00000<0dLfY140000020=7=Z@E000000P3AcJT2@00000@0
dLfY0T0000030=7=Z@=00000103AcJT2@00000<0dLfY0d0000040=7=Z@900000103AcJT2@00000@0
dLfY0T00000C0=7=Z@E0000000<0dLfY@000040000000T0000030=7=Z@9000000`3AcJT4@0000080
dLfY1D0000020=7=Z@900000103AcJT2@00000<0dLfY0d0000040=7=Z@9000000`3AcJT3@00000@0
dLfY0T0000040=7=Z@9000000`3AcJT3@00001<0dLfY1D0000000`3AcJU00000@0000002@00000<0
dLfY0T0000030=7=Z@A000000P3AcJT5@0000080dLfY0T0000040=7=Z@9000000`3AcJT3@00000@0
dLfY0T0000030=7=Z@=00000103AcJT2@00000@0dLfY0T0000050=7=Z@03@000003AcJT0dLfY0140
dLfY000B0=7=Z@05@000003AcJT0dLfY0=7=ZD0000001@3AcJT014000000dLfY0=7=ZD0000020=7=
Z@03@000003AcJT0dLfY00D0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0
dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03
@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY
00<0dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0B0=7=Z@05@000003AcJT0
dLfY0=7=ZD0000001@3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00D0dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=
Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00E0
00000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0
0`3AcJT00d000000dLfY0=7=Z@0C0=7=Z@05@000003AcJT0dLfY0=7=ZD0000001@3AcJT014000000
dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00D0dLfY00E000000=7=Z@3AcJT0dLfY@0000002
0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=
Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=
Z@0B0=7=Z@05@000003AcJT0dLfY0=7=ZD0000001@3AcJT014000000dLfY0=7=ZD0000020=7=Z@03
@000003AcJT0dLfY00D0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000
003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@000
0080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0B0=7=Z@05@000003AcJT0
dLfY0=7=ZD0000001@3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00D0dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=
Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00E0
00000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3A
cJT00P3AcJT00d000000dLfY0=7=Z@0A0=7=Z@004P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000
003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@040=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY
0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY0d000002
0=7=Z@04@000003AcJT0dLfY@0000080dLfY1D0000030=7=Z@03@000003AcJT0dLfY01<0dLfY00=0
00000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@00000<0dLfY
00=000000=7=Z@3AcJT0103AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3A
cJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d00
0000dLfY0=7=Z@020=7=Z@=000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@E0000000<0dLfY
@000040000000d00000D0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT0
14000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00@0dLfY00E000000=7=Z@3AcJT0dLfY
@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03
@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJT0dLfY0d0000050=7=Z@03@000003AcJT0dLfY
00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0B0=7=Z@03@000003AcJT0dLfY
0080dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0
dLfY00@0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00E0
00000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJT0
dLfY0d0000050=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU000000P3AcJT00d00
0000dLfY0=7=Z@0B0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT01400
0000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00@0dLfY00E000000=7=Z@3AcJT0dLfY@000
00020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000
003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJT0dLfY0d0000050=7=Z@03@000003AcJT0dLfY00<0
dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0A0=7=Z@004P3AcJT00d000000dLfY
0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY0T0000050=7=Z@03@000003AcJT0dLfY00<0dLfY
00=000000=7=Z@3AcJT00P3AcJT2@00000H0dLfY00=000000=7=Z@3AcJT00d0000060=7=Z@04@000
003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJT0dLfY0T0000030=7=Z@04@000003AcJT0dLfY
@00000D0dLfY00=000000=7=Z@3AcJT04P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0
dLfY0080dLfY0T0000050=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT2
@00000H0dLfY00=000000=7=Z@3AcJT00d0000060=7=Z@04@000003AcJT0dLfY@0000080dLfY00A0
00000=7=Z@3AcJT0dLfY0T0000030=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3A
cJU000005@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY0T0000050=7=
Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000H0dLfY00=000000=7=
Z@3AcJT00d0000040=7=Z@9000000`3AcJT014000000dLfY0=7=ZD0000030=7=Z@900000103AcJT2
@00000@0dLfY0T00000E0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT2
@00000D0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@9000001P3AcJT0
0d000000dLfY0=7=Z@03@00000@0dLfY0T0000030=7=Z@04@000003AcJT0dLfY@00000<0dLfY0T00
00040=7=Z@9000000`3AcJT3@00001D0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=
Z@020=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY0T00
00060=7=Z@03@000003AcJT0dLfY00=00000103AcJT2@00000<0dLfY00A000000=7=Z@3AcJU00000
0`3AcJT2@00000@0dLfY0T0000060=7=Z@03@000003AcJT0dLfY0100dLfY000B0=7=Z@05@000003A
cJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@000
0080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A00000
0=7=Z@3AcJU000000P3AcJT01D000000dLfY0=7=Z@3AcJU0000000@0dLfY00A000000=7=Z@3AcJU0
00000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=00000
0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD00000D0=7=Z@05@000003AcJT0dLfY0=7=ZD000000
0P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=
Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3A
cJT01D000000dLfY0=7=Z@3AcJU0000000@0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000
dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=ZD0000000`3AcJT0
0d000000dLfY@000000E0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=
ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000
dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT01D000000dLfY0=7=Z@3A
cJU0000000D0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000
003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0D0=7=Z@05@000
003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A0
00000=7=Z@3AcJU000000P3AcJT01D000000dLfY0=7=Z@3AcJU0000000D0dLfY00=000000=7=Z@3A
cJT00P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=
Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0D0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0
0P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT01D00
0000dLfY0=7=Z@3AcJU0000000D0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD00
00030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=
ZD00000B0=7=Z@004@3AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T00
00040=7=Z@900000103AcJT2@00000@0dLfY0d0000030=7=Z@900000103AcJT3@00000<0dLfY0T00
00050=7=Z@9000000`3AcJT2@00001@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T00
00040=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@=000000`3AcJT2@00000@0dLfY0d00
00030=7=Z@9000001@3AcJT2@00000@0dLfY0T00000D0=7=Z@900000103AcJT2@00000@0dLfY0T00
00040=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT3@00000<0dLfY0d00
00030=7=Z@=000000`3AcJT3@00000<0dLfY0d0000030=7=Z@=000004`3AcJT2@00000@0dLfY0T00
00040=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0d00
00030=7=Z@=000000`3AcJT3@00000<0dLfY0d0000030=7=Z@=000000`3AcJT3@00001<0dLfY0T00
00040=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T00
00040=7=Z@=000000`3AcJT3@00000<0dLfY0d0000030=7=Z@=000000`3AcJT3@0000080dLfY1400
000B0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3A
cJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@006P3AcJT01@3oool000000000003oool00000
0180oooo00D000000?ooo`3oool000000?ooo`02000000030?ooo`000000oooo0140oooo10000002
0?ooobH0dLfY1P3oool2000000L0oooo00<000000?ooo`3oool00P3oool300000080oooo00<00000
0?ooo`3oool00P0000030?ooo`<00000103oool00`000000oooo0?ooo`040?ooo`8000001`3ooolW
0=7=Z@`0oooo0`0000060?ooo`050000003oool0oooo0?ooo`0000003P3oool2000000030?ooo`00
0000oooo00/0oooo9P3AcJT50?ooo`@0000000<0oooo0000003oool00`3oool00`000000oooo0?oo
o`020?ooo`<000002@3oool300000080oooo00<000000?ooo`3oool0103oool2000000030?ooo`00
00000000008000001@3ooolV0=7=Z@/0oooo0P000000103oool000000000000000020?ooo`050000
003oool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?oo
o`3oool00000303ooolK0=7=Z@006P3AcJT30?ooo`060000003oool0oooo0?ooo`000000oooo0P00
00060?ooo`040000003oool00000000000<0oooo0P0000030?ooo`@000001@3oool2000000030?oo
o`000000000000D0oooo0P0000000`3oool00000000000030?ooobH0dLfY0`3oool00`000000oooo
0?ooo`040?ooo`800000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo
00@000000?ooo`3oool0oooo9`3AcJT30?ooo`030000003oool0oooo00<0oooo0`0000040?ooo`80
00000P3oool3000000T0oooo0`0000020?ooo`<000001@3oool2000000D0oooo00@000000?ooo`3o
ool0oooo9P3AcJT30?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool00000503oool0
0`000000oooo0000000;0?ooo`040000003oool0oooo0?ooobH0dLfY0`3oool2000000P0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000T0oooo
00D000000?ooo`3oool0oooo000000090?ooo`8000000`3ooolK0=7=Z@006P3AcJT40?ooo`800000
00<0oooo00000000000010000000103oool000000000003oool6000000030?ooo`000000oooo0080
oooo00<000000?ooo`000000100000000`3oool0000000000007000000030?ooo`000000000000@0
0000103ooolV0=7=Z@H0oooo0P0000060?ooo`8000001`3oool2000000@0oooo100000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool2000000H0oooo9`3AcJT60?ooo`80
0000103oool00`000000oooo0?ooo`040?ooo`D000000`3oool2000000030?ooo`000000000000@0
00001`3oool200000080oooo0`0000060?ooobH0dLfY1P3oool01@000000oooo0?ooo`3oool00000
00d0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00800000103oool2
00000080oooo00<000000?ooo`3oool0103ooolV0=7=Z@d0oooo0P000000103oool000000?ooo`3o
ool300000080oooo00D000000?ooo`3oool000000?ooo`02000000030?ooo`000000oooo0080oooo
0P00000C0?oooa/0dLfY000J0=7=Z@@0oooo00@000000?ooo`00000000001@3oool00`000000oooo
000000030?ooo`80000000@0oooo0000003oool000000P3oool2000000@0oooo00D000000?ooo`00
0000oooo000000030?ooo`80000000D0oooo0000003oool000000?ooo`02000000H0oooo9P3AcJT4
0?ooo`030000003oool0oooo00D0oooo0P00000?0?ooo`030000003oool0oooo00X0oooo0P000006
0?ooo`030000003oool0oooo00<0oooo9`3AcJT40?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00H0
00000?ooo`3oool0oooo0000003oool2000000<0oooo00<000000?ooo`3oool00`3ooolV0=7=Z@@0
oooo00<000000?ooo`3oool02@3oool010000000oooo0000000000040?ooo`060000003oool0oooo
0?ooo`000000oooo0P0000040?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo00<000000?ooo`3oool00`3ooolV0=7=Z@@0oooo1`0000001P3oool0
00000?ooo`000000oooo000000L0oooo00<000000?ooo`3oool00P3oool2000000030?ooo`000000
oooo0080oooo00<000000?ooo`3oool01@3oool8000000D0oooo6`3AcJT001X0dLfY1@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0000000P0oooo00@000000?ooo`000000oooo0P000005
0?ooo`030000003oool0000000H0oooo00D000000?ooo`000000oooo000000080?ooobH0dLfY203o
ool00`000000oooo0?ooo`050?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo0P0000000`3oool000000?ooo`04000000H0oooo0P0000080?ooobL0dLfY203o
ool3000000P0oooo0P0000020?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`030000003o
ool0oooo00H0oooo100000080?ooobH0dLfY203oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00D0oooo0P0000040?ooo`800000203ooolV0=7=Z@d0oooo00@000000?ooo`3oool0oooo
0`0000030?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo
000000020?ooo`8000003@3ooolK0=7=Z@006P3AcJT60?ooo`030000003oool0oooo008000000P3o
ool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000@0oooo0P0000020?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0203ooolV0=7=Z@/0oooo0P00000<0?ooo`030000
003oool0oooo00<0oooo0P0000090?ooo`800000303ooolW0=7=ZB00oooo00@000000?ooo`3oool0
0000503ooolV0=7=Z@d0oooo00<000000?ooo`3oool00P3oool2000000D0oooo0P0000030?ooo`80
00001@3oool010000000oooo0?ooo`00000?0?ooobH0dLfY3@3oool010000000oooo0?ooo`000008
0?ooo`8000003@3oool00`000000oooo0?ooo`0>0?oooa/0dLfY000J0=7=Z@T0oooo0P0000000`3o
ool000000?ooo`090?ooo`030000003oool0000000D0oooo0P0000000`3oool000000?ooo`070?oo
o`050000003oool000000?ooo`000000203ooolV0=7=Z@P0oooo00<000000?ooo`3oool0103oool2
00000080oooo0`0000080?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00070?ooo`030000003oool0oooo00H0oooo9`3AcJT80?ooo`040000003oool0oooo0?ooo`800000
00D0oooo000000000000oooo0000000A0?ooo`040000003oool0oooo00000080oooo0P0000030?oo
o`030000003oool0oooo00H0oooo9P3AcJT80?ooo`040000003oool0oooo0?ooo`<000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo
000000030?ooo`030000003oool0oooo00@000000P3oool00`000000oooo0?ooo`060?ooobH0dLfY
203oool5000000D0oooo00<000000?ooo`0000000P0000040?ooo`030000003oool0oooo00H0oooo
00D000000?ooo`000000oooo000000020?ooo`H00000203ooolK0=7=Z@006P3AcJT=0?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`000000203oool00`000000oooo000000080?ooo`03
0000003oool0000000T0oooo9P3AcJT;0?ooo`8000002P3oool010000000oooo0?ooo`0000030?oo
o`<000002P3oool2000000/0oooo9`3AcJT;0?ooo`@000002@3oool00`000000oooo0?ooo`020000
00030?ooo`000000000000@0oooo00<000000?ooo`3oool00P3oool4000000/0oooo9P3AcJT;0?oo
o`D000001`3oool00`000000oooo0000000>0?ooo`D000002`3ooolV0=7=ZA40oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`030?ooo`070000003oool000000?ooo`000000oooo
0000000E0?oooa/0dLfY000J0=7=Z@T0oooo0P0000060?ooo`040000003oool0000000000080oooo
00<000000?ooo`3oool01@3oool2000000D0oooo0P0000000`3oool00000000000020?ooo`030000
003oool0oooo00P0oooo9P3AcJT90?ooo`030000003oool0oooo00D0oooo0P0000040?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool01@3oool2000000H0oooo00<000000?ooo`3oool0
203ooolW0=7=Z@T0oooo00<000000?ooo`3oool00`3oool4000001<0oooo0P0000050?ooo`030000
003oool0oooo00P0oooo9P3AcJT90?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000020?ooo`8000002`3oool00`000000oooo0?ooo`080?ooobH0dLfY
2@3oool3000000D0oooo0`0000030?ooo`030000003oool0oooo0080oooo0P0000070?ooo`030000
003oool0oooo00D0oooo0P00000:0?oooa/0dLfY000J0=7=Z@X0oooo0`000000103oool000000000
003oool6000000T0oooo0`0000000`3oool0000000000007000000/0oooo9P3AcJT=0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`800000
3@3ooolW0=7=Z@d0oooo0P0000060?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`040000
003oool00000000000<0oooo0P00000=0?ooobH0dLfY3@3oool00`000000oooo0000000200000080
oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo0000000=0?ooobH0dLfY4`3oool2000000@0oooo00D000000?ooo`000000oooo0000
00040?ooo`80000000<0oooo0000003oool04P3ooolK0=7=Z@006P3AcJT;0?ooo`80000000<0oooo
0000003oool00P3oool4000000`0oooo00<000000?ooo`0000000`3oool4000000`0oooo9P3AcJT@
0?ooo`8000001`3oool3000000030?ooo`000000oooo00H0oooo0P00000A0?ooobL0dLfY503oool3
00000080oooo00@000000?ooo`3oool0oooo0P0000000`3oool0000000000002000001@0oooo9P3A
cJT@0?ooo`030000003oool0oooo0080oooo0P0000001@3oool000000000003oool000000080oooo
00<000000?ooo`0000000P0000050?ooo`030000003oool0oooo00d0oooo9P3AcJTA0?ooo`800000
0`3oool00`000000oooo000000040?ooo`030000003oool00000008000005`3ooolK0=7=Z@006P3A
cJT=0?ooo`060000003oool0oooo0?ooo`000000oooo0P0000070?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P0000000`3oool000000000000=0?ooobH0dLfY3@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo9`3AcJT=0?ooo`030000003oool0oooo00<0
oooo1@0000070?ooo`H000001@3oool00`000000oooo0?ooo`0;0?ooobH0dLfY3@3oool00`000000
oooo0?ooo`020?ooo`8000001`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0
oooo9P3AcJT=0?ooo`8000000`3oool2000000D0oooo0P0000030?ooo`030000003oool0oooo0080
oooo0`0000040?ooo`8000003@3ooolK0=7=Z@006P3AcJT=0?ooo`030000003oool0oooo00800000
1@3oool010000000oooo0?ooo`3oool2000000H0oooo00<000000?ooo`3oool00P00000@0?ooobH0
dLfY4P3oool200000080oooo0`0000050?ooo`@000000P3oool00`000000oooo0?ooo`0A0?ooobL0
dLfY6@3oool010000000oooo0?ooo`3oool2000001T0oooo9P3AcJTE0?ooo`030000003oool00000
0080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0B0?ooobH0dLfY4`3oool0
10000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0A0?oooa/0dLfY000J0=7=Z@h0oooo00@000000?ooo`00000000001@3oool010000000oooo
0000003oool200000080oooo00<000000?ooo`3oool00P3oool010000000oooo00000000000@0?oo
obH0dLfY3P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00d0oooo9`3AcJT>0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P0000070?ooo`<0000000<0oooo0000
000000000`3oool00`000000oooo0?ooo`0=0?ooobH0dLfY3P3oool00`000000oooo0?ooo`020?oo
o`800000103oool010000000oooo0?ooo`0000050?ooo`@000000P3oool00`000000oooo0?ooo`0=
0?ooobH0dLfY3P3oool5000000@0oooo0`0000050?ooo`8000001@3oool4000000l0oooo6`3AcJT0
01X0dLfY3`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000@0oooo00L00000
0?ooo`3oool0oooo0000003oool000000180oooo9P3AcJTB0?ooo`030000003oool0oooo00l0oooo
0P00000B0?ooobL0dLfY4P3oool3000000H0oooo0P0000050?ooo`@000004P3ooolV0=7=ZA80oooo
1@000000103oool000000000000000020?ooo`8000000P3oool500000180oooo9P3AcJTH0?ooo`<0
00001@3oool00`000000oooo0?ooo`0F0?oooa/0dLfY000J0=7=ZA00oooo00<000000?ooo`3oool0
0P0000020?ooo`050000003oool000000?ooo`0000000`3oool200000080oooo00<000000?ooo`3o
ool04P3ooolV0=7=ZAD0oooo1@0000040?ooo`@000005P3ooolW0=7=ZAX0oooo1000000J0?ooobH0
dLfY6`3oool2000000030?ooo`000000oooo01P0oooo9P3AcJTF0?ooo`060000003oool000000000
003oool00000103oool00`000000oooo0?ooo`0F0?oooa/0dLfY000J0=7=ZA<0oooo0P000000103o
ool000000?ooo`0000020?ooo`800000103oool01@000000oooo0000003oool000000180oooo9P3A
cJTB0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403ooolW0=7=ZA80oooo00@0
00000?ooo`3oool0oooo0P0000080?ooo`8000000`3oool00`000000oooo0?ooo`0@0?ooobH0dLfY
4P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@00000103oool010000000oooo
0?ooo`00000B0?ooobH0dLfY4P3oool400000080oooo00@000000?ooo`3oool0oooo0P0000020?oo
o`030000003oool0000000@000004P3ooolK0=7=Z@006P3AcJTB0?ooo`@000000`3oool200000004
0?ooo`0000000000000000<0oooo00<000000?ooo`0000004`3ooolV0=7=ZAL0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0F0?ooobL0dLfY6@3oool2000001d0oooo9P3AcJTE0?oo
o`030000003oool000000200oooo9P3AcJTH0?ooo`030000003oool0000000<0oooo00<000000?oo
o`000000603ooolK0=7=Z@006P3AcJTC0?ooo`8000001@3oool01@000000oooo000000000000oooo
008000000P3oool00`000000oooo0?ooo`0B0?ooobH0dLfY4`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0180oooo9`3AcJTC0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0B0?ooobH0dLfY4`3oool00`000000oooo0?ooo`050?oo
o`@00000103oool00`000000oooo0?ooo`0B0?ooobH0dLfY503oool200000080oooo0P0000050?oo
o`8000000P3oool2000001@0oooo6`3AcJT001X0dLfY503oool3000000030?ooo`000000000000<0
oooo1P00000E0?ooobH0dLfY5`3oool00`000000oooo0?ooo`050?ooo`8000005`3ooolW0=7=ZAL0
oooo0P0000060?ooo`8000005`3ooolV0=7=ZAL0oooo0P0000000`3oool000000000000200000080
oooo00<000000?ooo`3oool05@3ooolV0=7=ZAl0oooo00<000000?ooo`3oool05`3ooolK0=7=Z@00
6P3AcJTE0?ooo`80000000<0oooo0000003oool0103oool4000001H0oooo9P3AcJTh0?ooobL0dLfY
>03ooolV0=7=ZAT0oooo1P00000I0?ooobH0dLfY6@3oool00`000000oooo00000003000001X0oooo
6`3AcJT001X0dLfY5`3oool00`000000oooo0?ooo`050?ooo`8000005`3ooolV0=7=ZAL0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooobL0dLfY5`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01D0oooo9P3AcJTG0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool05@3ooolV0=7=ZAL0oooo0P0000060?ooo`<000005`3ooolK0=7=Z@006P3AcJTG
0?ooo`040000003oool0oooo000001d0oooo9P3AcJTh0?ooobL0dLfY>03ooolV0=7=ZCP0oooo9P3A
cJTK0?ooo`800000703ooolK0=7=Z@006P3AcJTH0?ooo`030000003oool0000001d0oooo9P3AcJTH
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool05`3ooolW0=7=ZAP0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0G0?ooobH0dLfY603oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo01L0oooo9P3AcJTI0?ooo`8000000`3oool2000001T0
oooo6`3AcJT001X0dLfY6@3oool2000001d0oooo9P3AcJTK0?ooo`030000003oool0oooo01X0oooo
9`3AcJTK0?ooo`030000003oool0oooo01X0oooo9P3AcJTK0?ooo`030000003oool0oooo01X0oooo
9P3AcJTL0?ooo`030000003oool0oooo01X0oooo6`3AcJT001X0dLfY6P3oool3000001/0oooo9P3A
cJTh0?ooobL0dLfY>03ooolV0=7=ZCP0oooo9P3AcJTi0?oooa/0dLfY000J0=7=ZA`0oooo00<00000
0?ooo`3oool06@3ooolV0=7=ZCP0oooo9`3AcJTh0?ooobH0dLfY>03ooolV0=7=ZCT0oooo6`3AcJT0
01X0dLfY>03ooolV0=7=ZCP0oooo9`3AcJTh0?ooobH0dLfY>03ooolV0=7=ZCT0oooo6`3AcJT00?l0
dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT001<0
dLfY0d0000030=7=Z@=00000103AcJT2@00000<0dLfY0d0000030=7=Z@E000000`3AcJT3@00000<0
dLfY0d0000030=7=Z@=0000000@0dLfY@0000400001000000`3AcJT3@00000<0dLfY0d0000030=7=
Z@=000005P3AcJT5@00000030=7=ZD0000100000009000000`3AcJT2@00000<0dLfY140000020=7=
Z@E000000P3AcJT2@00000@0dLfY0T0000030=7=Z@=000000`3AcJT4@00000<0dLfY0T0000030=7=
Z@E0000000<0dLfY@000040000000T0000020=7=Z@=00000503AcJT5@00000030=7=ZD0000100000
009000000`3AcJT2@00000<0dLfY140000020=7=Z@E000000P3AcJT2@00000@0dLfY0T0000030=7=
Z@=000000`3AcJT4@00000<0dLfY0T0000030=7=Z@E000000P3AcJT2@00000@0dLfY0T00000C0=7=
Z@E0000000<0dLfY@000040000000T0000030=7=Z@9000000`3AcJT4@0000080dLfY1D0000020=7=
Z@900000103AcJT2@00000<0dLfY0d0000030=7=Z@A000000`3AcJT2@00000<0dLfY1D0000020=7=
Z@9000000`3AcJT5@0000140dLfY1D0000000`3AcJU00000@0000002@00000<0dLfY0T0000030=7=
Z@A000000P3AcJT5@0000080dLfY0T0000040=7=Z@9000000`3AcJT3@00000@0dLfY0T0000030=7=
Z@=00000103AcJT2@00000D0dLfY0d0000000`3AcJU00000@0000002@0000180dLfY000E0=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0
dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003A
cJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000
003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00=000000=7=Z@3AcJT05@3AcJT01D000000dLfY0=7=Z@3AcJU0000000D0dLfY00A00000
0=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@050=7=Z@05@000003AcJT0dLfY0=7=ZD000000
0P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=
Z@3AcJU000001@3AcJT014000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD000000
1`3AcJT00d000000dLfY0=7=Z@0D0=7=Z@05@000003AcJT0dLfY0=7=ZD0000001@3AcJT014000000
dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00D0dLfY00E000000=7=Z@3AcJT0dLfY@0000002
0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD0000050=7=Z@04@000003AcJT0dLfY@00000@0dLfY00E000000=7=Z@3AcJT0dLfY@0000002
0=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT04P3AcJT01D000000dLfY0=7=
Z@3AcJU0000000D0dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@050=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0
dLfY@0000080dLfY00A000000=7=Z@3AcJU000001@3AcJT014000000dLfY0=7=ZD0000040=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY
01<0dLfY00E000000=7=Z@3AcJT0dLfY@00000050=7=Z@04@000003AcJT0dLfY@0000080dLfY00=0
00000=7=Z@3AcJT01@3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU0
00000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=00000
0=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00`3A
cJT014000000dLfY0=7=ZD00000E0=7=Z@00503AcJT3@0000080dLfY00A000000=7=Z@3AcJU00000
1@3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3A
cJT0dLfY1D0000000`3AcJU00000@0000003@00000030=7=ZD000010000000=0000000D0dLfY@000
003AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@00000<0dLfY0d0000020=7=Z@04@000003A
cJT0dLfY@00001L0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000
003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT0103AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00E00000
0=7=Z@3AcJT0dLfY@00000040=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT0
0P3AcJT00d000000dLfY0=7=Z@030=7=Z@=000005@3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000
003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@040=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY
0=7=ZD0000000P3AcJT01D000000dLfY0=7=Z@3AcJU0000000@0dLfY00A000000=7=Z@3AcJU00000
103AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000
dLfY0=7=Z@0B0=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT014000000
dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00@0dLfY00E000000=7=Z@3AcJT0dLfY@0000002
0=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@05@000003A
cJT0dLfY0=7=ZD000000103AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY00<0
dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0C0=7=Z@03@000003AcJT0dLfY0080
dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY
00@0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00E00000
0=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3A
cJT3@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT5@0000080dLfY00=000000=7=Z@3AcJT0
4P3AcJT001<0dLfY00A000000=7=Z@3AcJU000000P3AcJT3@00000@0dLfY0T0000030=7=Z@=00000
1@3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00=000000`3AcJT3@00000<0dLfY00A00000
0=7=Z@3AcJU000000P3AcJT3@00001P0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=
Z@020=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY0T00
00060=7=Z@03@000003AcJT0dLfY00=000001@3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY
00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD00
00000P3AcJT00d000000dLfY0=7=Z@0C0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3A
cJT00P3AcJT2@00000D0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@90
00001P3AcJT00d000000dLfY0=7=Z@03@00000D0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=
Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0103AcJT014000000dLfY0=7=ZD000002
0=7=Z@03@000003AcJT0dLfY0180dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@02
0=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY0T000006
0=7=Z@03@000003AcJT0dLfY00=000001@3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=0
00000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY0080dLfY00=0
00000=7=Z@3AcJT04`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY0T00
00050=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000H0dLfY00=0
00000=7=Z@3AcJT00d0000060=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJT0
dLfY0T0000030=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT04@3AcJT001<0
dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY
00<0dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJU00000
00<0dLfY00=000000=7=ZD0000000`3AcJT00d000000dLfY@00000030=7=Z@03@000003AcJT0dLfY
00<0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0
dLfY01L0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY
00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=
ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@05@000003AcJT0dLfY0=7=ZD000000103A
cJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000@0dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT04`3AcJT0
1D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=
Z@04@000003AcJT0dLfY@0000080dLfY00E000000=7=Z@3AcJT0dLfY@00000040=7=Z@04@000003A
cJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000103AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0B0=7=Z@05@000003AcJT0
dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080
dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=
Z@3AcJU000000P3AcJT01D000000dLfY0=7=Z@3AcJU0000000@0dLfY00A000000=7=Z@3AcJU00000
0P3AcJT014000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d00
0000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY01<0dLfY00E000000=7=Z@3AcJT0dLfY@0000002
0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY
0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=
Z@05@000003AcJT0dLfY0=7=ZD000000103AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003A
cJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY@00000020=7=Z@04
@000003AcJT0dLfY@0000180dLfY000D0=7=Z@=000000`3AcJT3@00000<0dLfY0d0000030=7=Z@=0
00000`3AcJT2@00000D0dLfY0T0000040=7=Z@900000103AcJT2@00000<0dLfY0d0000030=7=Z@=0
00000`3AcJT3@00000<0dLfY0d00000F0=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@90
0000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT3@00000<0dLfY0T0000040=7=Z@90
0000103AcJT2@00000@0dLfY0T0000040=7=Z@=00000503AcJT2@00000@0dLfY0T0000040=7=Z@90
0000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0d0000030=7=Z@90
0000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00001@0dLfY0T0000040=7=Z@90
0000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@=0
00000`3AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T00000D0=7=Z@90
0000103AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@90
0000103AcJT3@00000<0dLfY0T0000040=7=Z@=000000`3AcJT2@00000D0dLfY0T0000030=7=Z@90
00004`3AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0
dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT001X0dLfY1P3oool00`00
0000oooo0?ooo`020?ooo`<00000103oool2000000@0oooo0`0000020?ooo`800000103oool30000
00@0oooo0`0000070?ooo`040000003oool0oooo0?ooobH0dLfY1P3oool200000080oooo0P000002
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000020?ooo`<000000P3o
ool01@000000oooo0?ooo`3oool0000000P0oooo00T000000?ooo`000000oooo0000003oool00000
0?ooo`0000000`3ooolW0=7=Z@<0oooo0P0000001@3oool000000000003oool000000080oooo00<0
00000?ooo`0000000`0000000`3oool000000?ooo`020?ooo`030000003oool0oooo00<0oooo0`00
00020?ooo`070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0
000000@0oooo00000000000000000`3ooolV0=7=Z@<0oooo0`000000103oool000000000003oool2
000000040?ooo`00000000000?ooo`80000000<0oooo0000003oool00P3oool010000000oooo0000
003oool2000000030?ooo`000000000000<0oooo00<000000?ooo`3oool00P000000203oool00000
0?ooo`3oool000000?ooo`000000oooo1@0000030?ooobH0dLfY0`3ooolC000000030?ooo`000000
000000P0000000<0oooo0000000000004P0000030?oooa/0dLfY000J0=7=Z@<0oooo00@000000?oo
o`3oool00000103oool3000000@0oooo0P0000040?ooo`<000000P3oool2000000@0oooo0`000004
0?ooo`<000001P3oool00`000000oooo0?ooo`020?ooobH0dLfY0`3oool00`000000oooo0?ooo`02
0?ooo`80000000D0oooo0000003oool0oooo000000020?ooo`80000000D0oooo0000000000000000
0?ooo`02000000030?ooo`000000oooo0080000000D0oooo00000000000000000?ooo`03000000H0
oooo0`000000103oool000000?ooo`0000040?ooobL0dLfY0`3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`000000oooo0`0000020?ooo`@0000000<0
oooo0000003oool00P000000103oool000000?ooo`0000050?ooo`8000001@3oool00`000000oooo
0?ooo`020?ooobH0dLfY0`3oool00`000000oooo0?ooo`0400000080oooo100000020?ooo`<00000
00<0oooo0000003oool00P3oool2000000030?ooo`000000000000@000001@3oool4000000<0oooo
1@0000040?ooobH0dLfY0`3ooolC000000030?ooo`000000000000P0000000<0oooo000000000000
4@0000040?oooa/0dLfY000J0=7=Z@/0oooo0`0000040?ooo`800000103oool300000080oooo0P00
00040?ooo`<00000103oool3000000H0oooo00<000000?ooo`3oool00P3ooolV0=7=Z@L0oooo00<0
00000?ooo`0000000`3oool3000000@0oooo00<000000?ooo`000000103oool00`000000oooo0?oo
o`020?ooo`8000001P3oool2000000<0oooo00@000000?ooo`00000000000P3oool00`000000oooo
0?ooo`020?ooobL0dLfY1`3oool010000000oooo0000000000030?ooo`@0000000@0oooo0000003o
ool000000P3oool3000000030?ooo`000000oooo008000000P3oool01P000000oooo0000003oool0
00000?ooo`<0000000<0oooo0000003oool00P3oool010000000oooo0?ooo`0000040?ooobH0dLfY
1@3oool00`000000oooo000000020?ooo`<000000P3oool00`000000oooo00000004000000D0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo00000002000000060?ooo`000000oooo0?oo
o`000000oooo0P0000001@3oool000000?ooo`3oool0000000@0oooo9P3AcJT50?oooa40000000<0
oooo000000000000200000000`3oool000000000000?000000030?ooo`000000oooo00<0oooo6`3A
cJT001X0dLfY103oool00`000000oooo00000003000000@0oooo0`0000040?ooo`<000000`3oool0
0`000000oooo0?ooo`020?ooo`<00000103oool2000000@0oooo100000070?ooobH0dLfY103oool0
0`000000oooo00000002000000@0oooo0`0000020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool00`000000oooo000000020?ooo`80000000<0oooo0000003oool010000000
103oool000000?ooo`3oool2000000L0oooo9`3AcJT40?ooo`<00000103oool2000000<0oooo0P00
00000`3oool000000?ooo`030?ooo`030000003oool0oooo0080000000<0oooo0000003oool00P3o
ool01@000000oooo0000003oool0000000<0oooo100000030?ooo`030000003oool0oooo00@0oooo
9P3AcJT40?ooo`80000000<0oooo0000000000000P3oool2000000<0oooo00<000000?ooo`000000
1P0000000`3oool000000?ooo`020?ooo`@0000000@0oooo0000003oool000000`3oool00`000000
oooo000000020?ooo`<000001`3ooolV0=7=Z@@0oooo0P0000000`3oool000000000000=00000003
0?ooo`000000000000P0000000<0oooo0000000000003P0000070?oooa/0dLfY000J0=7=Z@H0oooo
00@000000?ooo`0000000000103oool3000000@0oooo0`0000030?ooo`030000003oool0oooo0080
oooo0`0000040?ooo`800000103oool3000000030?ooo`000000oooo00D0oooo9P3AcJT60?ooo`03
0000003oool0000000T0oooo00<000000?ooo`3oool00P3oool3000000040?ooo`00000000000?oo
o`<00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103ooolW0=7=Z@X0oooo00D000000?ooo`3oool000000?ooo`0200000080oooo00<00000
0?ooo`3oool00P3oool010000000oooo0000000000020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooobH0dLfY1`3oool3000000030?ooo`00
0000oooo0080000000<0oooo0000000000000P3oool00`000000oooo00000003000000D0oooo00@0
00000?ooo`00000000000`3oool2000000030?ooo`000000oooo00@0oooo0`0000060?ooobH0dLfY
1P3oool@000000030?ooo`000000000000P0000000<0oooo0000000000003@0000000`3oool00000
0?ooo`050?oooa/0dLfY000J0=7=Z@L0oooo00<000000?ooo`000000103oool3000000@0oooo0`00
00030?ooo`030000003oool0oooo0080oooo0`0000040?ooo`800000103oool4000000L0oooo9P3A
cJT70?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`030000003oool0oooo0080000000<0
oooo0000003oool0100000000`3oool000000?ooo`0200000080oooo00<000000?ooo`3oool00P00
00020?ooo`030000003oool0oooo008000001`3ooolW0=7=Z@L0oooo0`0000000`3oool000000000
00020?ooo`030000003oool0oooo00D000000P3oool2000000040?ooo`000000oooo00000080oooo
0P0000070?ooo`L000001`3ooolV0=7=Z@L0oooo100000020?ooo`040000003oool0oooo0?ooo`80
000000<0oooo0000003oool00P3oool01P000000oooo0?ooo`3oool000000?ooo`<0000000<0oooo
0000003oool01@0000030?ooo`80000000<0oooo0000000000001`3ooolV0=7=Z@L0oooo3`000000
0`3oool0000000000008000000030?ooo`000000000000d00000203ooolK0=7=Z@006P3AcJT90?oo
o`040000003oool0oooo0?ooo`@00000103oool3000000<0oooo00<000000?ooo`3oool00P3oool3
000000@0oooo0P0000040?ooo`<00000203ooolV0=7=Z@T0oooo00<000000?ooo`000000103oool4
000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`<000001P3oool3
000000P0oooo9`3AcJT<0?ooo`8000001P3oool00`000000oooo0?ooo`060?ooo`060000003oool0
oooo0000003oool00000103oool200000080oooo00<000000?ooo`3oool00P0000080?ooobH0dLfY
2`3oool4000000060?ooo`000000oooo0000003oool00000103oool2000000030?ooo`0000000000
0080oooo00<000000?ooo`3oool00`0000020?ooo`040000003oool0000000000080oooo0P000008
0?ooobH0dLfY2P3oool<000000030?ooo`000000000000P0000000<0oooo0000000000003@000008
0?oooa/0dLfY000J0=7=Z@T0oooo00<000000?ooo`3oool00P3oool3000000@0oooo0`0000030?oo
o`030000003oool0oooo0080oooo0`0000040?ooo`8000003`3ooolV0=7=Z@T0oooo00@000000?oo
o`3oool000000P3oool01@000000oooo0?ooo`3oool000000080oooo0P0000000`3oool000000000
00020?ooo`80000000<0oooo0000000000000`3oool010000000oooo0000000000020?ooo`030000
003oool0oooo00X0oooo9`3AcJT90?ooo`800000103oool010000000oooo0?ooo`0000030?ooo`80
0000203oool4000000040?ooo`000000oooo000000@0oooo00<000000?ooo`3oool02@3ooolV0=7=
Z@T0oooo0P0000000`3oool000000000000200000080oooo00<000000?ooo`0000001@3oool00`00
0000oooo00000002000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool00`0000000`3o
ool000000000000;0?ooobH0dLfY2@3oool=000000030?ooo`000000000000P0000000<0oooo0000
000000002P00000;0?oooa/0dLfY000J0=7=Z@X0oooo00@000000?ooo`3oool00000103oool20000
00@0oooo0`0000020?ooo`800000103oool3000000L0oooo00<000000?ooo`3oool0203ooolV0=7=
Z@X0oooo00@000000?ooo`3oool0oooo0`0000020?ooo`030000003oool00000008000000`3oool0
10000000oooo0?ooo`3oool3000000030?ooo`00000000000080oooo0P0000001@3oool000000?oo
o`3oool0000000X0oooo9`3AcJT:0?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`D00000
0`3oool3000000030?ooo`000000oooo0080oooo0`0000050?ooo`030000003oool0oooo00P0oooo
9P3AcJT:0?ooo`8000000P3oool2000000<0oooo0P0000001P3oool000000000003oool000000?oo
o`@000000P3oool00`000000oooo00000002000000030?ooo`000000oooo008000000P3oool00`00
0000oooo0?ooo`080?ooobH0dLfY2P3oool<000000030?ooo`000000000000P0000000<0oooo0000
000000002`00000:0?oooa/0dLfY000J0=7=Z@X0oooo00<000000?ooo`3oool01@3oool2000000@0
oooo0`0000020?ooo`800000103oool300000180oooo9P3AcJT:0?ooo`070000003oool0oooo0?oo
o`000000oooo000000030?ooo`D000000P3oool00`000000oooo0?ooo`05000000070?ooo`000000
oooo0?ooo`000000oooo0000000>0?ooobL0dLfY2P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000001P3oool2000000D0oooo00<000000?ooo`00
00003P3ooolV0=7=Z@X0oooo00D000000?ooo`000000oooo000000030?ooo`@0000000D0oooo0000
003oool000000?ooo`05000000@0oooo00P000000?ooo`3oool000000?ooo`000000oooo000000`0
oooo9P3AcJT:0?ooo`030000003oool0000000T0000000<0oooo000000000000200000000`3oool0
000000000008000000030?ooo`000000oooo00X0oooo6`3AcJT001X0dLfY4P3oool2000000@0oooo
0`0000020?ooo`800000103oool300000180oooo9P3AcJT@0?ooo`030000003oool0oooo00L0oooo
0`0000070?ooo`040000003oool0oooo00000100oooo9`3AcJTA0?ooo`@000000P3oool2000000H0
oooo00<000000?ooo`3oool01@0000030?ooo`030000003oool0oooo00/0oooo9P3AcJT=0?ooo`03
0000003oool0oooo00<0oooo00P000000?ooo`3oool0oooo0000003oool000000?ooo`H0000000<0
oooo000000000000103oool3000000d0oooo9P3AcJT=0?ooo`T0000000<0oooo0000000000002000
00000`3oool0000000000008000000d0oooo6`3AcJT001X0dLfY3@3oool00`000000oooo0?ooo`02
0?ooo`800000103oool300000080oooo0P0000040?ooo`<000004P3ooolV0=7=Z@d0oooo00@00000
0?ooo`3oool00000103oool200000080oooo00@000000?ooo`000000oooo0P0000020?ooo`800000
00@0oooo0000003oool0oooo0P00000?0?ooobL0dLfY3@3oool01@000000oooo0?ooo`3oool00000
0080oooo00H000000?ooo`3oool000000?ooo`0000090?ooo`@000000P3oool00`000000oooo0?oo
o`0<0?ooobH0dLfY3@3oool01@000000oooo000000000000oooo00<0000000<0oooo0000003oool0
0P3oool2000000040?ooo`000000oooo0?ooo`D000000P3oool3000000h0oooo9P3AcJT=0?ooo`T0
000000<0oooo000000000000200000000`3oool0000000000007000000h0oooo6`3AcJT001X0dLfY
3P3oool3000000@0oooo0`0000030?ooo`030000003oool0oooo0080oooo0`0000040?ooo`030000
003oool0000000h0oooo9P3AcJT>0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool0
oooo0P0000020?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0
oooo00`0oooo9`3AcJT>0?ooo`L000001@3oool01P000000oooo000000000000oooo000000H0oooo
1000000>0?ooobH0dLfY3P3oool01P000000oooo0000003oool000000?ooo`80000000@0oooo0000
0000000000000P3oool500000080oooo0P0000020?ooo`<000003P3ooolV0=7=Z@h0oooo20000000
0`3oool0000000000008000000030?ooo`000000000000L000003P3ooolK0=7=Z@006P3AcJT>0?oo
o`<00000103oool3000000<0oooo00<000000?ooo`3oool00P3oool4000000<0oooo00<000000?oo
o`3oool03P3ooolV0=7=Z@h0oooo0`000000103oool000000?ooo`3oool2000000030?ooo`000000
000000@0oooo00@000000?ooo`00000000001@3oool00`000000oooo0?ooo`0>0?ooobL0dLfY3P3o
ool2000000@0oooo1@0000040?ooo`040000003oool000000?ooo`80000000<0oooo000000000000
4P3ooolV0=7=Z@h0oooo0P0000030?ooo`P0000000<0oooo000000000000100000000`3oool00000
0?ooo`0C0?ooobH0dLfY3P3oool00`000000oooo0?ooo`05000000030?ooo`000000000000P00000
00<0oooo0000000000001@00000@0?oooa/0dLfY000J0=7=ZAD0oooo0`0000030?ooo`030000003o
ool0oooo0080oooo0`0000040?ooo`030000003oool0oooo00h0oooo9P3AcJTE0?ooo`030000003o
ool0000000<000000P3oool3000000@0oooo00@000000?ooo`3oool00000403ooolW0=7=ZA40oooo
00<000000?ooo`0000000`000000103oool000000000000000020?ooo`050000003oool0oooo0?oo
o`0000000`3oool300000100oooo9P3AcJTA0?ooo`030000003oool0000000<0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`@00000403ooolV0=7=ZA00oooo1P00
00000`3oool0000000000008000000030?ooo`000000000000<000004P3ooolK0=7=Z@006P3AcJTA
0?ooo`030000003oool0oooo00@000000`3oool00`000000oooo0?ooo`020?ooo`<000000`3oool0
0`000000oooo0?ooo`0?0?ooobH0dLfY4@3oool00`000000oooo0?ooo`030?ooo`040000003oool0
00000?ooo`8000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
3`3ooolW0=7=ZA40oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`080000
003oool0oooo0?ooo`000000oooo0000003oool200000140oooo9P3AcJTA0?ooo`8000001@3oool2
000000@0oooo0P0000050?ooo`8000004@3ooolV0=7=ZA40oooo1@0000000`3oool0000000000008
000000030?ooo`000000000000<000004P3ooolK0=7=Z@006P3AcJTD0?ooo`@000000`3oool00`00
0000oooo0?ooo`020?ooo`@0000000<0oooo0000003oool04@3ooolV0=7=ZA@0oooo0P0000030?oo
o`030000003oool0oooo00H0oooo0P0000000`3oool000000?ooo`0A0?ooobL0dLfY4`3oool01000
0000oooo00000000000:0?ooo`030000003oool00000008000004P3ooolV0=7=ZA@0oooo0`000000
0`3oool000000?ooo`050?ooo`050000003oool000000000003oool00P00000B0?ooobH0dLfY4`3o
ool3000000030?ooo`000000000000P0000000@0oooo000000000000oooo0P00000B0?oooa/0dLfY
000J0=7=ZAP0oooo0`0000020?ooo`8000006@3ooolV0=7=ZAL0oooo00H000000?ooo`000000oooo
0000003oool2000000030?ooo`000000oooo01H0oooo9`3AcJTC0?ooo`030000003oool0oooo0080
00001`3oool3000001H0oooo9P3AcJTC0?ooo`@0000000d0oooo0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool0000001@0oooo9P3AcJTD0?ooo`80000000<0oooo00000000
000020000000103oool0000000000000000D0?oooa/0dLfY000J0=7=ZAP0oooo0`0000020?ooo`80
0000103oool00`000000oooo0?ooo`0B0?ooobH0dLfY5@3oool00`000000oooo000000030?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000503ooolW0=7=ZA@0oooo00@000000?oo
o`3oool0oooo0P0000050?ooo`050000003oool0oooo0?ooo`000000503ooolV0=7=ZA@0oooo0P00
00020?ooo`030000003oool00000008000000`3oool010000000oooo0?ooo`00000D0?ooobH0dLfY
503oool01@000000oooo0?ooo`000000oooo00L0000000@0oooo00000000000000005@3ooolK0=7=
Z@006P3AcJTD0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`8000006@3ooolV
0=7=ZA@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<000005`3o
oolW0=7=ZA@0oooo00<000000?ooo`0000000P0000070?ooo`8000005P3ooolV0=7=ZA@0oooo00<0
00000?ooo`3oool00P3oool3000000050?ooo`00000000000?ooo`0000005`3ooolV0=7=ZAT0oooo
1`000000103oool000000?ooo`00000E0?oooa/0dLfY000J0=7=ZAX0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0E0?ooobH0dLfY6`3oool01P000000oooo0?ooo`000000oooo0000
01L0oooo9`3AcJTG0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3ooolV0=7=
ZAP0oooo100000020?ooo`030000003oool0000001L0oooo9P3AcJTI0?ooo`L0000000<0oooo0000
003oool05P3ooolK0=7=Z@006P3AcJTG0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool05P3ooolV0=7=ZAL0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000H0?oo
obL0dLfY5`3oool2000000030?ooo`000000000000@00000603ooolV0=7=ZAL0oooo00<000000?oo
o`0000000P0000030?ooo`030000003oool0oooo01H0oooo9P3AcJTG0?ooo`80000000<0oooo0000
000000000`0000000`3oool000000?ooo`0G0?oooa/0dLfY000J0=7=ZA/0oooo0P0000020?ooo`03
0000003oool0oooo01H0oooo9P3AcJTJ0?ooo`8000000`3oool00`000000oooo0?ooo`0F0?ooobL0
dLfY6@3oool2000000050?ooo`000000oooo0?ooo`000000603ooolV0=7=ZA`0oooo0P0000000`3o
ool000000?ooo`0G0?ooobH0dLfY603oool00`000000oooo0000000300000080oooo00<000000?oo
o`3oool05P3ooolK0=7=Z@006P3AcJTH0?ooo`030000003oool00000008000006`3ooolV0=7=ZAP0
oooo00<000000?ooo`0000000P00000K0?ooobL0dLfY603oool00`000000oooo0000000M0?ooobH0
dLfY603oool01@000000oooo0?ooo`3oool0000001/0oooo9P3AcJTJ0?ooo`@0000000<0oooo0000
003oool0603ooolK0=7=Z@006P3AcJTJ0?ooo`80000000<0oooo0000003oool06@3ooolV0=7=ZAX0
oooo0P0000000`3oool000000?ooo`0I0?ooobL0dLfY6P3oool010000000oooo00000000000J0?oo
obH0dLfY6P3oool010000000oooo00000000000J0?ooobH0dLfY6P3oool2000000030?ooo`000000
oooo01X0oooo6`3AcJT001X0dLfY703oool00`000000oooo0?ooo`0I0?ooobH0dLfY703oool00`00
0000oooo0?ooo`0I0?ooobL0dLfY703oool00`000000oooo0?ooo`0I0?ooobH0dLfY703oool00`00
0000oooo0?ooo`0I0?ooobH0dLfY6`3oool00`000000oooo0?ooo`0K0?oooa/0dLfY000J0=7=ZA`0
oooo00<000000?ooo`3oool06@3ooolV0=7=ZA`0oooo00<000000?ooo`3oool06@3ooolW0=7=ZA`0
oooo00<000000?ooo`3oool06@3ooolV0=7=ZA`0oooo00<000000?ooo`3oool06@3ooolV0=7=ZA/0
oooo00<000000?ooo`3oool06`3ooolK0=7=Z@006P3AcJTh0?ooobH0dLfY>03ooolW0=7=ZCP0oooo
9P3AcJTh0?ooobH0dLfY>@3ooolK0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=
Z@00o`3AcJWX0=7=Z@00o`3AcJWX0=7=Z@004`3AcJT3@00000<0dLfY0d0000040=7=Z@9000000`3A
cJT4@0000080dLfY140000020=7=Z@=000001@3AcJT3@0000080dLfY0T0000050=7=Z@=000000P3A
cJT2@00000<0dLfY0d0000030=7=Z@=000006@3AcJT3@00000<0dLfY0d0000040=7=Z@9000000`3A
cJT4@0000080dLfY140000020=7=Z@=000001@3AcJT3@0000080dLfY0T0000050=7=Z@=0000000@0
dLfY@000040000100000103AcJT2@00000@0dLfY0T00000J0=7=Z@=000000`3AcJT3@00000@0dLfY
0T0000030=7=Z@A000000P3AcJT4@0000080dLfY0d0000050=7=Z@=000000P3AcJT2@00000D0dLfY
0d000000103AcJU00000@000040000030=7=Z@E0000000<0dLfY@000040000000d00000G0=7=Z@=0
00000`3AcJT3@00000@0dLfY0T0000030=7=Z@A000000P3AcJT4@0000080dLfY0d0000050=7=Z@=0
00000P3AcJT2@00000D0dLfY0d000000103AcJU00000@000040000030=7=Z@E0000000<0dLfY@000
040000000T00000H0=7=Z@=000000`3AcJT3@00000@0dLfY0T0000030=7=Z@A000000P3AcJT4@000
0080dLfY0d0000050=7=Z@=000000P3AcJT2@00000D0dLfY0d000000103AcJU00000@00004000003
0=7=Z@E000000P3AcJT2@00001H0dLfY000E0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000D0dLfY00=000000=7=Z@3AcJT0
0`3AcJT014000000dLfY0=7=ZD0000050=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=
Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00=00000
0=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@0I0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3A
cJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000D0dLfY00=000000=7=Z@3A
cJT00`3AcJT014000000dLfY0=7=ZD0000050=7=Z@04@000003AcJT0dLfY@0000080dLfY00=00000
0=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3A
cJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY01T0dLfY00E000000=7=Z@3AcJT0
dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000001@3AcJT0
0d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@00000D0dLfY00A000000=7=Z@3AcJU00000
0P3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3A
cJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY01T0dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000001@3A
cJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@00000D0dLfY00A000000=7=Z@3AcJU0
00000P3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=
Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU0000001d0dLfY00E000000=7=Z@3AcJT0dLfY@000
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000001@3AcJT00d000000
dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@00000D0dLfY00A000000=7=Z@3AcJU000000P3AcJT0
0d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3A
cJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT04`3AcJT001@0dLfY0d00
00020=7=Z@04@000003AcJT0dLfY@00000D0dLfY00E000000=7=Z@3AcJT0dLfY@00000050=7=Z@03
@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU000000P3AcJT5@00000<0dLfY00A000000=7=
Z@3AcJT0dLfY1D0000001@3AcJU000000=7=Z@3AcJU0000000<0dLfY0d0000030=7=Z@=000006@3A
cJT3@0000080dLfY00A000000=7=Z@3AcJU000001@3AcJT01D000000dLfY0=7=Z@3AcJU0000000D0
dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000020=7=Z@E000000`3AcJT01400
0000dLfY0=7=Z@3AcJT5@0000080dLfY0d0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A0
00000=7=Z@3AcJU000006P3AcJT3@0000080dLfY00A000000=7=Z@3AcJU000001@3AcJT01D000000
dLfY0=7=Z@3AcJU0000000D0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD000002
0=7=Z@E00000103AcJT00d000000dLfY0=7=Z@05@00000050=7=ZD000000dLfY0=7=ZD000000103A
cJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY01P0dLfY0d0000020=7=Z@04@000003A
cJT0dLfY@00000D0dLfY00E000000=7=Z@3AcJT0dLfY@00000050=7=Z@03@000003AcJT0dLfY0080
dLfY00A000000=7=Z@3AcJU000000P3AcJT5@00000@0dLfY00=000000=7=Z@3AcJT01D0000001@3A
cJU000000=7=Z@3AcJU0000000@0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@0I
0=7=Z@=000000P3AcJT014000000dLfY0=7=ZD0000050=7=Z@05@000003AcJT0dLfY0=7=ZD000000
1@3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@0000080dLfY1D0000040=7=Z@03
@000003AcJT0dLfY00E0000000D0dLfY@000003AcJT0dLfY@00000040=7=Z@03@000003AcJT0dLfY
00<0dLfY00=000000=7=Z@3AcJT0503AcJT001<0dLfY00A000000=7=Z@3AcJU000000P3AcJT3@000
00@0dLfY0T0000050=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJT0dLfY0d000003
0=7=Z@04@000003AcJT0dLfY@00000D0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=Z@3AcJT2@00000<0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000H
0=7=Z@04@000003AcJT0dLfY@0000080dLfY0d0000040=7=Z@9000001@3AcJT00d000000dLfY0=7=
Z@030=7=Z@04@000003AcJT0dLfY0=7=Z@=000000`3AcJT014000000dLfY0=7=ZD0000050=7=Z@04
@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT05`3AcJT014000000dLfY
0=7=ZD0000020=7=Z@=00000103AcJT2@00000D0dLfY00=000000=7=Z@3AcJT00`3AcJT014000000
dLfY0=7=Z@3AcJT3@00000<0dLfY00A000000=7=Z@3AcJU000000`3AcJT2@00000<0dLfY00A00000
0=7=Z@3AcJU000000P3AcJT3@00000D0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=
Z@0G0=7=Z@04@000003AcJT0dLfY@0000080dLfY0d0000040=7=Z@9000001@3AcJT00d000000dLfY
0=7=Z@030=7=Z@04@000003AcJT0dLfY0=7=Z@=000000`3AcJT014000000dLfY0=7=ZD0000030=7=
Z@9000000`3AcJT014000000dLfY0=7=ZD0000020=7=Z@=000001@3AcJT00d000000dLfY0=7=Z@03
0=7=Z@03@000003AcJT0dLfY01L0dLfY00A000000=7=Z@3AcJU000000P3AcJT3@00000@0dLfY0T00
00050=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJT0dLfY0d0000030=7=Z@04@000
003AcJT0dLfY@00000<0dLfY0T0000030=7=Z@04@000003AcJT0dLfY@0000080dLfY0d0000050=7=
Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT04`3AcJT001<0dLfY00A000000=7=Z@3A
cJU000000`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=
Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00<0dLfY00=0
00000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJU000000080dLfY
00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@00001P0dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003A
cJT0dLfY0080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03
@000003AcJT0dLfY00<0dLfY00=000000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000030=7=
Z@03@000003AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00
00020=7=Z@04@000003AcJT0dLfY@00001T0dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000
dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU000000P3AcJT01400
0000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=ZD0000000`3AcJT0
0d000000dLfY0=7=Z@030=7=Z@03@000003AcJU0000000<0dLfY00=000000=7=Z@3AcJT0103AcJT0
0d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY01L0dLfY00A000000=7=Z@3AcJU000000`3A
cJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU00000
0P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=ZD00
00000`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJU0000000<0dLfY00=000000=7=Z@3A
cJT0103AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT05P3AcJT01400
0000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT0
0`3AcJT00d000000dLfY@00000030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=ZD000000
0`3AcJT00d000000dLfY0=7=Z@040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000
dLfY0=7=Z@0C0=7=Z@00503AcJT3@00000<0dLfY0d0000030=7=Z@=000000`3AcJT2@00000@0dLfY
0T0000040=7=Z@=00000103AcJT2@00000<0dLfY0T0000050=7=Z@9000000`3AcJT2@00000@0dLfY
0d0000030=7=Z@=000006@3AcJT3@00000<0dLfY0d0000030=7=Z@=000000`3AcJT2@00000@0dLfY
0T0000040=7=Z@=00000103AcJT2@00000<0dLfY0T0000050=7=Z@9000000`3AcJT3@00000<0dLfY
0T0000040=7=Z@9000006`3AcJT3@00000<0dLfY0d0000030=7=Z@=000000`3AcJT2@00000@0dLfY
0T0000040=7=Z@=00000103AcJT2@00000<0dLfY0d0000040=7=Z@9000000`3AcJT3@00000<0dLfY
0T0000040=7=Z@9000006P3AcJT3@00000<0dLfY0d0000030=7=Z@=000000`3AcJT2@00000@0dLfY
0T0000040=7=Z@=00000103AcJT2@00000<0dLfY0d0000040=7=Z@9000000`3AcJT3@00000<0dLfY
0T0000040=7=Z@9000006P3AcJT3@00000<0dLfY0d0000030=7=Z@=000000`3AcJT2@00000@0dLfY
0T0000040=7=Z@=00000103AcJT2@00000<0dLfY0d0000040=7=Z@9000000`3AcJT3@00000<0dLfY
0T0000040=7=Z@9000005P3AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0
dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT001X0
dLfY0P00000@0?ooo`800000403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0dLfY02D0
dLfY0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000002T0oooo00@000000?ooo`3o
ool0oooo9`3AcJTN0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000;
0?ooo`040000003oool0oooo0?ooobH0dLfY303oool01@000000oooo0?ooo`3oool0000000<0oooo
00P000000?ooo`3oool0oooo0000003oool000000?ooo`800000103oool010000000oooo00000000
00030?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooobH0dLfY
2P3oool2000000L0oooo00@000000?ooo`3oool000003P3oool00`000000oooo000000040?ooo`<0
00001P3oool010000000oooo0?ooo`3ooolK0=7=Z@006P3AcJT01P3oool000000000003oool00000
0?ooo`H0000000D0oooo0000003oool000000?ooo`0200000180oooo1P0000001@3oool000000?oo
o`000000oooo00H000000P3ooolV0=7=Z@<0oooo0`0000090?ooo`040000003oool0oooo0?ooo`80
0000403oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3ooolW0=7=Z@<0oooo00<000000?ooo`3oool00P0000050?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000
003oool000001P3oool010000000oooo0?ooo`0000040?ooobH0dLfY0`3oool010000000oooo0?oo
o`3oool2000000060?ooo`000000oooo0000003oool000001P3oool010000000oooo0000003oool2
00000100oooo0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`020?ooobH0dLfY0`3oool0
0`000000oooo000000030?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000001@3oool0
0`000000oooo0?ooo`020?oooa/0dLfY000J0=7=Z@<0oooo00@000000?ooo`3oool0oooo0P000002
0?ooo`8000000`3oool2000001@0oooo0P0000020?ooo`8000000`3oool200000080oooo0P000003
0?ooobH0dLfY2`3oool2000000<0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?oo
o`040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3ooolW0=7=Z@P0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo
9P3AcJT?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P0000050?ooo`030000
003oool0oooo0080oooo9P3AcJT;0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo6`3AcJT001X0dLfY
0`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000006P3oool01@000000
oooo0?ooo`3oool0000000P0oooo9P3AcJT40?ooo`050000003oool0oooo0?ooo`000000103oool0
1@000000oooo0?ooo`3oool000000180oooo0`0000030?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool01P3ooolW0=7=Z@@0oooo00@000000?ooo`00000000004@3oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo000000T0oooo00@000000?ooo`00000000001`3ooolV0=7=
Z@@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00@0oooo0P0000040?ooo`030000003oool0oooo00<0oooo100000000`3oool000000?ooo`090?oo
obH0dLfY103oool01P000000oooo0?ooo`000000oooo000000<0oooo1000000F0?ooo`050000003o
ool000000?ooo`0000000P3oool00`000000oooo000000080?oooa/0dLfY000J0=7=Z@@0oooo00<0
00000?ooo`0000001P3oool00`000000oooo0000000X0?ooobH0dLfY1P3oool3000000030?ooo`00
0000000000L0oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`080?ooo`040000003o
ool00000000000H0oooo9`3AcJT60?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0
203oool200000080oooo00@000000?ooo`3oool000002`3oool01P000000oooo0?ooo`000000oooo
000000H0oooo9P3AcJT60?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`<0000000<0oooo
0000003oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P0000030?ooo`030000003oool0oooo00@0oooo9P3AcJT60?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo000000070?ooo`030000003oool0
oooo00@0oooo0P0000050?ooo`030000003oool0oooo008000001P3ooolK0=7=Z@006P3AcJT50?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool09`3ooolV0=7=Z@L0oooo0P0000020?oo
o`030000003oool0oooo00@0oooo0P0000040?ooo`800000203oool2000000@0oooo0P0000060?oo
o`030000003oool0oooo00D0oooo9`3AcJT70?ooo`030000003oool0oooo00@0oooo0P0000090?oo
o`040000003oool0oooo000000/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooobH0dLfY1`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0203oool020000000oooo0?ooo`000000oooo0000003oool000001`3ooolV0=7=Z@L0
oooo00D000000?ooo`3oool0oooo000000040?ooo`040000003oool000000?ooo`<0000000@0oooo
00000000000000000P3oool2000000040?ooo`000000oooo0?ooo`8000002@3oool00`000000oooo
000000080?oooa/0dLfY000J0=7=Z@H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0000000T0oooo9P3AcJT>0?ooo`030000003oool0oooo00@0oooo00@0
00000?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo00H0oooo0P0000060?ooo`030000
003oool0oooo00H0oooo9`3AcJT;0?ooo`030000003oool0000000<00000303oool00`000000oooo
0?ooo`070?ooo`8000001P3oool00`000000oooo0?ooo`060?ooobH0dLfY403oool00`000000oooo
0?ooo`0<0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`00
0000203ooolV0=7=Z@T0oooo00<000000?ooo`3oool00`3oool2000000030?ooo`000000oooo0080
0000103oool3000000030?ooo`000000000000L0oooo00<000000?ooo`000000103oool3000000P0
oooo6`3AcJT001X0dLfY303oool00`000000oooo0?ooo`0L0?ooo`050000003oool0oooo0?ooo`00
0000203ooolV0=7=Z@T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000C0?ooobL0dLfY2@3oool30000
0080oooo00@000000?ooo`00000000002`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00l0oooo9P3AcJT90?ooo`8000000P3oool2000000H0oooo00<000000?ooo`3oool01P3oool3
000000030?ooo`000000oooo01@0oooo9P3AcJT90?ooo`030000003oool0oooo00h0oooo0P000006
0?ooo`030000003oool0000001@0oooo6`3AcJT001X0dLfY203oool400000200oooo00<000000?oo
o`0000002@3ooolV0=7=Z@d0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo00<0oooo0P0000030?ooo`030000003oool0oooo0080oooo0P0000030?ooo`040000003oool0
oooo000000X0oooo9`3AcJTA0?ooo`030000003oool0000000H0oooo0`0000090?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool0203ooolV0=7=ZA<0oooo00L000000?ooo`3oool0oooo
0000003oool0000000P0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool00000
00X0oooo9P3AcJT:0?ooo`030000003oool0oooo00L0oooo0P0000040?ooo`8000001`3oool00`00
0000oooo0?ooo`070?ooo`8000002P3ooolK0=7=Z@006P3AcJT90?ooo`8000008P3oool00`000000
oooo0?ooo`080?ooobH0dLfY2P3oool00`000000oooo000000050?ooo`030000003oool0oooo00D0
oooo00D000000?ooo`000000oooo000000050?ooo`8000001@3oool00`000000oooo0?ooo`0:0?oo
obL0dLfY2P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`0000000P0000000`3oool00000000000030?ooo`030000003oool0oooo00<0oooo0`00000>
0?ooobH0dLfY2P3oool00`000000oooo0?ooo`050?ooo`800000103oool3000000030?ooo`000000
oooo01X0oooo9P3AcJT:0?ooo`030000003oool0oooo00/0oooo0`0000030?ooo`030000003oool0
000000`0oooo00<000000?ooo`3oool02@3ooolK0=7=Z@006P3AcJT:0?ooo`80000000D0oooo0000
003oool000000?ooo`06000000050?ooo`000000oooo0000003oool01P0000000`3oool000000?oo
o`06000000030?ooo`000000oooo00X0oooo9P3AcJT=0?ooo`030000003oool0oooo008000002P3o
ool2000000P0oooo00D000000?ooo`000000oooo0000000=0?ooobL0dLfY403oool2000000030?oo
o`000000oooo00P0oooo0P0000050?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
2`3ooolV0=7=Z@h0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02000000@0
oooo00@000000?ooo`00000000000P3oool020000000oooo000000000000oooo0000003oool00000
3@3ooolV0=7=ZAT0oooo00<000000?ooo`0000000P0000030?ooo`030000003oool0oooo01D0oooo
6`3AcJT001X0dLfY2`3oool2000000<0oooo0P0000020?ooo`8000000`3oool010000000oooo0?oo
o`3oool2000000<0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`800000303ooolV0=7=Z@d0
oooo100000070?ooo`8000000`3oool2000000P0oooo00<000000?ooo`0000003P3ooolW0=7=Z@d0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0
oooo00D000000?ooo`3oool0oooo0000000>0?ooobH0dLfY3@3oool02@000000oooo0?ooo`3oool0
00000?ooo`000000oooo000000050?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`800000
00<0oooo0000003oool03@3ooolV0=7=Z@d0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0000000L0?oooa/0dLfY000J0=7=Z@`0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooobH0dLfY
503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
303ooolW0=7=ZA80oooo0P00000:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
303ooolV0=7=ZA00oooo0P0000020?ooo`040000003oool0oooo00000080oooo0`0000030?ooo`05
0000003oool0oooo0000003oool00P0000020?ooo`030000003oool0oooo00`0oooo9P3AcJT>0?oo
o`030000003oool0000000`0oooo00<000000?ooo`3oool01`3oool2000000030?ooo`000000oooo
00d0oooo6`3AcJT001X0dLfY3@3oool00`000000oooo000000060?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool0503ooolV0=7=Z@h0oooo00H000000?ooo`3oool0oooo0000003oool2
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0140oooo9`3AcJT>0?ooo`030000003oool000000080oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0E0?ooobH0dLfY3P3oool00`000000oooo0?ooo`060?ooo`8000001@3oool2
00000080oooo00<000000?ooo`3oool04`3ooolV0=7=Z@h0oooo00<000000?ooo`0000000P000002
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0000000@
0?oooa/0dLfY000J0=7=Z@h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0N0?oo
obH0dLfY403oool2000000@0oooo00H000000?ooo`000000oooo0000003oool300000080oooo0`00
00020?ooo`800000403ooolW0=7=ZA00oooo00<000000?ooo`3oool01`3oool010000000oooo0?oo
o`0000070?ooo`030000003oool000000100oooo9P3AcJT@0?ooo`030000003oool0000000L0oooo
0P0000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3ooolV0=7=ZA00oooo
00<000000?ooo`000000103oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`000000
1@3oool00`000000oooo0?ooo`0@0?oooa/0dLfY000J0=7=Z@l0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`080?ooo`050000003oool000000?ooo`0000004P3ooolV0=7=ZA40oooo
0P0000000`3oool000000?ooo`020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`00
00000`3oool00`000000oooo0000000A0?ooobL0dLfY4@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00l0oooo9P3AcJTA0?ooo`050000003oool0oooo0?ooo`000000403oool00`00
0000oooo0?ooo`0?0?ooobH0dLfY4@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0B0?oooa/0dLfY000J0=7=ZA00
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooobH0dLfY5P3oool01P000000
oooo0?ooo`3oool000000?ooo`<000000P3oool200000080oooo00<000000?ooo`3oool0403ooolW
0=7=ZAH0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000180oooo9P3A
cJTE0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000060?ooo`030000
003oool0oooo0100oooo9P3AcJTE0?ooo`050000003oool0oooo0?ooo`000000103oool200000004
0?ooo`000000oooo00000080oooo00<000000?ooo`3oool0403ooolK0=7=Z@006P3AcJTA0?ooo`@0
00003P3oool010000000oooo00000000000A0?ooobH0dLfY5@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool06@3ooolW0=7=ZCP0oooo9P3AcJTI0?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`0C0?ooobH0dLfY5`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01<0oooo6`3AcJT001X0dLfY4P3oool200000100oooo00<00000
0?ooo`3oool04@3ooolV0=7=ZAX0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B
0?ooobL0dLfY603oool2000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0B
0?ooobH0dLfY5@3oool00`000000oooo00000002000000T0oooo00<000000?ooo`3oool04P3ooolV
0=7=ZA@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0H0?oooa/0dLfY000J0=7=
ZA<0oooo100000001@3oool000000?ooo`000000oooo00H0000000<0oooo0000003oool04`3ooolV
0=7=ZA@0oooo00<000000?ooo`0000000P0000030?ooo`030000003oool0oooo00<000005P3ooolW
0=7=ZA@0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo0P00000I0?ooobH0dLfY
503oool00`000000oooo0?ooo`080?ooo`8000005`3ooolV0=7=ZAP0oooo0P0000060?ooo`040000
003oool0oooo000001D0oooo6`3AcJT001X0dLfY503oool2000000<0oooo00@000000?ooo`3oool0
oooo0P0000030?ooo`030000003oool0oooo01<0oooo9P3AcJTG0?ooo`030000003oool0000000H0
oooo00<000000?ooo`3oool05@3ooolW0=7=ZAX0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0E0?ooobH0dLfY803oool00`000000oooo0?ooo`0E0?ooobH0dLfY6P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo6`3AcJT001X0dLfY5@3oool2000000030?oo
o`000000oooo00@0oooo1000000F0?ooobH0dLfY5`3oool4000000@0oooo00<000000?ooo`3oool0
5P3ooolW0=7=ZAL0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0F0?ooobH0
dLfY5`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000000H0?ooobH0dLfY5`3o
ool2000000@0oooo00@000000?ooo`3oool00000603ooolK0=7=Z@006P3AcJTF0?ooo`030000003o
ool0000000P0oooo00<000000?ooo`3oool0503ooolV0=7=ZAd0oooo00<000000?ooo`000000603o
oolW0=7=ZA/0oooo0P0000020?ooo`030000003oool0oooo01H0oooo9P3AcJTK0?ooo`<0000000<0
oooo0000003oool05`3ooolV0=7=ZAP0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0F0?oooa/0dLfY000J0=7=ZAL0oooo00<000000?ooo`3oool07P3ooolV0=7=ZAP0oooo00@00000
0?ooo`3oool00000703ooolW0=7=ZAP0oooo00<000000?ooo`0000000P00000K0?ooobH0dLfY603o
ool01P000000oooo0?ooo`000000oooo000001X0oooo9P3AcJTK0?ooo`<0000000<0oooo0000003o
ool0603ooolK0=7=Z@006P3AcJTH0?ooo`030000003oool0000001d0oooo9P3AcJTJ0?ooo`040000
003oool00000000001X0oooo9`3AcJTJ0?ooo`040000003oool00000000001X0oooo9P3AcJTJ0?oo
o`040000003oool00000000001X0oooo9P3AcJTJ0?ooo`040000003oool00000000001/0oooo6`3A
cJT001X0dLfY6@3oool00`000000oooo0?ooo`0L0?ooobH0dLfY703oool00`000000oooo0?ooo`0I
0?ooobL0dLfY703oool00`000000oooo0?ooo`0I0?ooobH0dLfY703oool00`000000oooo0?ooo`0I
0?ooobH0dLfY6`3oool00`000000oooo0?ooo`0K0?oooa/0dLfY000J0=7=ZAX0oooo00@000000?oo
o`00000000006P3ooolV0=7=ZA`0oooo00<000000?ooo`3oool06@3ooolW0=7=ZA`0oooo00<00000
0?ooo`3oool06@3ooolV0=7=ZA`0oooo00<000000?ooo`3oool06@3ooolV0=7=ZA/0oooo00<00000
0?ooo`3oool06`3ooolK0=7=Z@006P3AcJTK0?ooo`8000006`3ooolV0=7=ZCP0oooo9`3AcJTh0?oo
obH0dLfY>03ooolV0=7=ZCT0oooo6`3AcJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT00?l0dLfYj03A
cJT00?l0dLfYj03AcJT00?l0dLfYj03AcJT001<0dLfY0d0000050=7=Z@=0000000<0dLfY@0000400
00000d0000020=7=Z@9000000`3AcJT3@00000@0dLfY0T0000030=7=Z@=000000`3AcJT4@00000<0
dLfY0T0000050=7=Z@=000000P3AcJT2@00000@0dLfY0T00000I0=7=Z@=000000`3AcJT3@00000@0
dLfY0T0000030=7=Z@A000000P3AcJT4@0000080dLfY0d0000050=7=Z@=0000000<0dLfY@0000400
00000d0000020=7=Z@9000000`3AcJT5@0000080dLfY0T0000040=7=Z@9000006P3AcJT3@00000<0
dLfY0d0000040=7=Z@9000000`3AcJT4@0000080dLfY140000020=7=Z@=000001@3AcJT3@0000003
0=7=ZD000010000000=000000P3AcJT2@00000<0dLfY1D0000020=7=Z@9000000`3AcJT3@00001T0
dLfY0d0000030=7=Z@=00000103AcJT2@00000<0dLfY140000020=7=Z@A000000P3AcJT3@00000D0
dLfY0d0000000`3AcJU00000@0000003@0000080dLfY0T0000030=7=Z@E000000P3AcJT2@00000D0
dLfY00=000000=7=Z@3AcJT05`3AcJT3@00000<0dLfY0d0000040=7=Z@9000000`3AcJT4@0000080
dLfY140000020=7=Z@=000001@3AcJT3@0000080dLfY0T0000050=7=Z@=000000P3AcJT2@00000<0
dLfY0d0000040=7=Z@9000005P3AcJT001D0dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY
0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=
Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3A
cJU0000000D0dLfY00A000000=7=Z@3AcJU000001@3AcJT014000000dLfY0=7=ZD0000020=7=Z@04
@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0603AcJT01D000000dLfY0=7=Z@3AcJU0
00000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000050=7=Z@03@000
003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJU000001@3AcJT00d000000dLfY0=7=Z@020=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY
0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY01T0dLfY00E0
00000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3A
cJU000001@3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@00000D0dLfY00=00000
0=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00P3A
cJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000
dLfY0=7=Z@0H0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD000002
0=7=Z@04@000003AcJT0dLfY@00000D0dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=
ZD0000050=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03
@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY
0080dLfY00=000000=7=Z@3AcJT06@3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A00000
0=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000050=7=Z@03@000003AcJT0dLfY00<0dLfY
00A000000=7=Z@3AcJU000001@3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY
00<0dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0
dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0C0=7=Z@00503AcJT3@0000080dLfY1D000003
0=7=Z@03@000003AcJT0dLfY00@0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=
ZD0000020=7=Z@04@000003AcJT0dLfY0=7=Z@=000000`3AcJT00d000000dLfY0=7=Z@020=7=Z@04
@000003AcJT0dLfY@0000080dLfY1D0000030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=
Z@3AcJT0603AcJT3@0000080dLfY00A000000=7=Z@3AcJU000001@3AcJT01D000000dLfY0=7=Z@3A
cJU0000000D0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000020=7=Z@E00000
0`3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0
dLfY@00000020=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0603AcJT3@0000080
dLfY00A000000=7=Z@3AcJU000001@3AcJT01D000000dLfY0=7=Z@3AcJU0000000D0dLfY00=00000
0=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000020=7=Z@E000000`3AcJT00d000000dLfY0=7=
Z@040=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000
003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT05`3AcJT3@0000080dLfY00A000000=7=Z@3A
cJU000001@3AcJT01D000000dLfY0=7=Z@3AcJU0000000D0dLfY00=000000=7=Z@3AcJT00P3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@E000000`3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003A
cJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY
00=000000=7=Z@3AcJT0603AcJT3@0000080dLfY00A000000=7=Z@3AcJU000001@3AcJT01D000000
dLfY0=7=Z@3AcJU0000000D0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD000002
0=7=Z@E000000`3AcJT014000000dLfY0=7=Z@3AcJT5@00000050=7=ZD000000dLfY0=7=ZD000000
0`3AcJT3@0000080dLfY00A000000=7=Z@3AcJU000005@3AcJT001<0dLfY00A000000=7=Z@3AcJU0
00000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY0080dLfY0T0000030=7=
Z@=000000`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=0
00000=7=Z@3AcJT00P3AcJT2@00000<0dLfY00A000000=7=Z@3AcJU000001@3AcJT00d000000dLfY
0=7=Z@030=7=Z@03@000003AcJT0dLfY01H0dLfY00A000000=7=Z@3AcJU000000P3AcJT3@00000@0
dLfY0T0000050=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=Z@3AcJT0dLfY0d0000030=7=
Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000D0dLfY00=00000
0=7=Z@3AcJT00P3AcJT2@00000@0dLfY0T00000J0=7=Z@04@000003AcJT0dLfY@0000080dLfY0d00
00040=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY0=7=Z@=00000
0`3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY0080dLfY0T0000050=7=Z@03
@000003AcJT0dLfY0080dLfY0T0000030=7=Z@=000006@3AcJT014000000dLfY0=7=ZD0000020=7=
Z@=00000103AcJT2@00000D0dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=Z@3AcJT3
@00000<0dLfY00A000000=7=Z@3AcJU00000103AcJT00d000000dLfY0=7=Z@020=7=Z@9000001@3A
cJT00d000000dLfY0=7=Z@020=7=Z@9000001P3AcJT00d000000dLfY0=7=Z@0F0=7=Z@04@000003A
cJT0dLfY@0000080dLfY0d0000040=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000
003AcJT0dLfY0=7=Z@=000000`3AcJT014000000dLfY0=7=ZD0000050=7=Z@04@000003AcJT0dLfY
@0000080dLfY00A000000=7=Z@3AcJT0dLfY0T0000030=7=Z@04@000003AcJT0dLfY@00000<0dLfY
0T00000F0=7=Z@004`3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJU0000000@0dLfY
00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY
00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY@00000020=7=Z@04@000003A
cJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000603AcJT014000000dLfY0=7=ZD0000030=7=
Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD000002
0=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY@000
00040=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0103AcJT01D000000dLfY0=7=
Z@3AcJU000000080dLfY00E000000=7=Z@3AcJT0dLfY@000000K0=7=Z@04@000003AcJT0dLfY@000
00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003A
cJU0000000@0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@040=7=Z@05@000003A
cJT0dLfY0=7=ZD0000000P3AcJT01D000000dLfY0=7=Z@3AcJU0000001X0dLfY00A000000=7=Z@3A
cJU000000`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=
Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00<0dLfY00=0
00000=7=ZD000000103AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00@0dLfY00E0
00000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3A
cJT05P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=
Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=0
00000=7=Z@3AcJT00`3AcJT00d000000dLfY@00000020=7=Z@04@000003AcJT0dLfY@00000<0dLfY
00=000000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@000
0080dLfY00A000000=7=Z@3AcJU000005@3AcJT001@0dLfY0d0000040=7=Z@9000000`3AcJT2@000
00@0dLfY0d0000030=7=Z@=000000`3AcJT2@00000@0dLfY0d0000030=7=Z@900000103AcJT2@000
00D0dLfY0T0000030=7=Z@900000103AcJT2@00001X0dLfY0d0000030=7=Z@=000000`3AcJT3@000
00<0dLfY0T0000040=7=Z@900000103AcJT3@00000@0dLfY0T0000030=7=Z@900000103AcJT3@000
00<0dLfY0T0000040=7=Z@900000103AcJT3@00001X0dLfY0d0000030=7=Z@=000000`3AcJT3@000
00<0dLfY0T0000040=7=Z@900000103AcJT3@00000@0dLfY0T0000030=7=Z@900000103AcJT3@000
00<0dLfY0T0000040=7=Z@900000103AcJT3@00001T0dLfY0d0000030=7=Z@=000000`3AcJT3@000
00<0dLfY0T0000040=7=Z@900000103AcJT3@00000@0dLfY0T0000030=7=Z@900000103AcJT3@000
00<0dLfY0T0000040=7=Z@9000000`3AcJT4@00001T0dLfY0d0000030=7=Z@=000000`3AcJT3@000
00<0dLfY0T0000040=7=Z@900000103AcJT3@00000@0dLfY0T0000030=7=Z@9000001@3AcJT2@000
00<0dLfY0T0000040=7=Z@=000000`3AcJT2@00001H0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY
003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY
003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY
003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY
003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY
003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY003o0=7=ZNP0dLfY0000\
\>"],
  ImageRangeCache->{{{0, 486.438}, {977.438, 0}} -> {-0.125026, -0.255424, \
0.0107929, 0.0107929}, {{11.5625, 97.375}, {953.75, 911.25}} -> {-47.5228, \
-43.6287, 1.79962, 1.79962}, {{105.938, 191.688}, {953.75, 911.25}} -> \
{-217.305, -43.6287, 1.79962, 1.79962}, {{200.313, 286.063}, {953.75, \
911.25}} -> {-387.144, -43.6287, 1.79962, 1.79962}, {{294.688, 380.438}, \
{953.75, 911.25}} -> {-556.983, -43.6287, 1.79962, 1.79962}, {{389.063, \
474.813}, {953.75, 911.25}} -> {-6.09531, -0.610228, 0.0152691, 0.024706}, \
{{11.5625, 97.375}, {907, 864.563}} -> {-47.73, -128.029, 1.80342, 1.80342}, \
{{105.938, 191.688}, {907, 864.563}} -> {-217.871, -128.029, 1.80342, \
1.80342}, {{200.313, 286.063}, {907, 864.563}} -> {-388.069, -128.029, \
1.80342, 1.80342}, {{294.688, 380.438}, {907, 864.563}} -> {-558.267, \
-128.029, 1.80342, 1.80342}, {{389.063, 474.813}, {907, 864.563}} -> \
{-728.465, -128.029, 1.80342, 1.80342}, {{11.5625, 97.375}, {860.313, \
817.813}} -> {-47.5228, -211.78, 1.79962, 1.79962}, {{105.938, 191.688}, \
{860.313, 817.813}} -> {-217.305, -211.78, 1.79962, 1.79962}, {{200.313, \
286.063}, {860.313, 817.813}} -> {-387.144, -211.78, 1.79962, 1.79962}, \
{{294.688, 380.438}, {860.313, 817.813}} -> {-556.983, -211.78, 1.79962, \
1.79962}, {{389.063, 474.813}, {860.313, 817.813}} -> {-726.821, -211.78, \
1.79962, 1.79962}, {{11.5625, 97.375}, {813.563, 771.125}} -> {-47.73, \
-296.536, 1.80342, 1.80342}, {{105.938, 191.688}, {813.563, 771.125}} -> \
{-217.871, -296.536, 1.80342, 1.80342}, {{200.313, 286.063}, {813.563, \
771.125}} -> {-388.069, -296.536, 1.80342, 1.80342}, {{294.688, 380.438}, \
{813.563, 771.125}} -> {-558.267, -296.536, 1.80342, 1.80342}, {{389.063, \
474.813}, {813.563, 771.125}} -> {-728.465, -296.536, 1.80342, 1.80342}, \
{{11.5625, 97.375}, {766.875, 724.375}} -> {-47.5228, -379.932, 1.79962, \
1.79962}, {{105.938, 191.688}, {766.875, 724.375}} -> {-217.305, -379.932, \
1.79962, 1.79962}, {{200.313, 286.063}, {766.875, 724.375}} -> {-387.144, \
-379.932, 1.79962, 1.79962}, {{294.688, 380.438}, {766.875, 724.375}} -> \
{-556.983, -379.932, 1.79962, 1.79962}, {{389.063, 474.813}, {766.875, \
724.375}} -> {-726.821, -379.932, 1.79962, 1.79962}, {{11.5625, 97.375}, \
{720.125, 677.688}} -> {-47.73, -465.043, 1.80342, 1.80342}, {{105.938, \
191.688}, {720.125, 677.688}} -> {-217.871, -465.043, 1.80342, 1.80342}, \
{{200.313, 286.063}, {720.125, 677.688}} -> {-388.069, -465.043, 1.80342, \
1.80342}, {{294.688, 380.438}, {720.125, 677.688}} -> {-558.267, -465.043, \
1.80342, 1.80342}, {{389.063, 474.813}, {720.125, 677.688}} -> {-728.465, \
-465.043, 1.80342, 1.80342}, {{11.5625, 97.375}, {673.438, 630.938}} -> \
{-47.5228, -548.083, 1.79962, 1.79962}, {{105.938, 191.688}, {673.438, \
630.938}} -> {-217.305, -548.083, 1.79962, 1.79962}, {{200.313, 286.063}, \
{673.438, 630.938}} -> {-387.144, -548.083, 1.79962, 1.79962}, {{294.688, \
380.438}, {673.438, 630.938}} -> {-556.983, -548.083, 1.79962, 1.79962}, \
{{389.063, 474.813}, {673.438, 630.938}} -> {-726.821, -548.083, 1.79962, \
1.79962}, {{11.5625, 97.375}, {626.688, 584.25}} -> {-47.73, -633.55, \
1.80342, 1.80342}, {{105.938, 191.688}, {626.688, 584.25}} -> {-217.871, \
-633.55, 1.80342, 1.80342}, {{200.313, 286.063}, {626.688, 584.25}} -> \
{-388.069, -633.55, 1.80342, 1.80342}, {{294.688, 380.438}, {626.688, \
584.25}} -> {-558.267, -633.55, 1.80342, 1.80342}, {{389.063, 474.813}, \
{626.688, 584.25}} -> {-728.465, -633.55, 1.80342, 1.80342}, {{11.5625, \
97.375}, {580, 537.5}} -> {-47.5228, -716.235, 1.79962, 1.79962}, {{105.938, \
191.688}, {580, 537.5}} -> {-217.305, -716.235, 1.79962, 1.79962}, {{200.313, \
286.063}, {580, 537.5}} -> {-387.144, -716.235, 1.79962, 1.79962}, {{294.688, \
380.438}, {580, 537.5}} -> {-556.983, -716.235, 1.79962, 1.79962}, {{389.063, \
474.813}, {580, 537.5}} -> {-726.821, -716.235, 1.79962, 1.79962}, {{11.5625, \
97.375}, {533.313, 490.813}} -> {-47.5228, -800.254, 1.79962, 1.79962}, \
{{105.938, 191.688}, {533.313, 490.813}} -> {-217.305, -800.254, 1.79962, \
1.79962}, {{200.313, 286.063}, {533.313, 490.813}} -> {-387.144, -800.254, \
1.79962, 1.79962}, {{294.688, 380.438}, {533.313, 490.813}} -> {-556.983, \
-800.254, 1.79962, 1.79962}, {{389.063, 474.813}, {533.313, 490.813}} -> \
{-726.821, -800.254, 1.79962, 1.79962}, {{11.5625, 97.375}, {486.563, \
444.063}} -> {-47.5228, -884.386, 1.79962, 1.79962}, {{105.938, 191.688}, \
{486.563, 444.063}} -> {-217.305, -884.386, 1.79962, 1.79962}, {{200.313, \
286.063}, {486.563, 444.063}} -> {-387.144, -884.386, 1.79962, 1.79962}, \
{{294.688, 380.438}, {486.563, 444.063}} -> {-556.983, -884.386, 1.79962, \
1.79962}, {{389.063, 474.813}, {486.563, 444.063}} -> {-726.821, -884.386, \
1.79962, 1.79962}, {{11.5625, 97.375}, {439.875, 397.375}} -> {-47.5228, \
-968.406, 1.79962, 1.79962}, {{105.938, 191.688}, {439.875, 397.375}} -> \
{-217.305, -968.406, 1.79962, 1.79962}, {{200.313, 286.063}, {439.875, \
397.375}} -> {-387.144, -968.406, 1.79962, 1.79962}, {{294.688, 380.438}, \
{439.875, 397.375}} -> {-556.983, -968.406, 1.79962, 1.79962}, {{389.063, \
474.813}, {439.875, 397.375}} -> {-726.821, -968.406, 1.79962, 1.79962}, \
{{11.5625, 97.375}, {393.125, 350.688}} -> {-47.73, -1054.76, 1.80342, \
1.80342}, {{105.938, 191.688}, {393.125, 350.688}} -> {-217.871, -1054.76, \
1.80342, 1.80342}, {{200.313, 286.063}, {393.125, 350.688}} -> {-388.069, \
-1054.76, 1.80342, 1.80342}, {{294.688, 380.438}, {393.125, 350.688}} -> \
{-558.267, -1054.76, 1.80342, 1.80342}, {{389.063, 474.813}, {393.125, \
350.688}} -> {-728.465, -1054.76, 1.80342, 1.80342}, {{11.5625, 97.375}, \
{346.438, 303.938}} -> {-47.5228, -1136.56, 1.79962, 1.79962}, {{105.938, \
191.688}, {346.438, 303.938}} -> {-217.305, -1136.56, 1.79962, 1.79962}, \
{{200.313, 286.063}, {346.438, 303.938}} -> {-387.144, -1136.56, 1.79962, \
1.79962}, {{294.688, 380.438}, {346.438, 303.938}} -> {-556.983, -1136.56, \
1.79962, 1.79962}, {{389.063, 474.813}, {346.438, 303.938}} -> {-726.821, \
-1136.56, 1.79962, 1.79962}, {{11.5625, 97.375}, {299.688, 257.25}} -> \
{-47.73, -1223.27, 1.80342, 1.80342}, {{105.938, 191.688}, {299.688, 257.25}} -> \
{-217.871, -1223.27, 1.80342, 1.80342}, {{200.313, 286.063}, {299.688, \
257.25}} -> {-388.069, -1223.27, 1.80342, 1.80342}, {{294.688, 380.438}, \
{299.688, 257.25}} -> {-558.267, -1223.27, 1.80342, 1.80342}, {{389.063, \
474.813}, {299.688, 257.25}} -> {-728.465, -1223.27, 1.80342, 1.80342}, \
{{11.5625, 97.375}, {253, 210.5}} -> {-47.5228, -1304.71, 1.79962, 1.79962}, \
{{105.938, 191.688}, {253, 210.5}} -> {-217.305, -1304.71, 1.79962, 1.79962}, \
{{200.313, 286.063}, {253, 210.5}} -> {-387.144, -1304.71, 1.79962, 1.79962}, \
{{294.688, 380.438}, {253, 210.5}} -> {-556.983, -1304.71, 1.79962, 1.79962}, \
{{389.063, 474.813}, {253, 210.5}} -> {-726.821, -1304.71, 1.79962, 1.79962}, \
{{11.5625, 97.375}, {206.25, 163.813}} -> {-47.73, -1391.78, 1.80342, \
1.80342}, {{105.938, 191.688}, {206.25, 163.813}} -> {-217.871, -1391.78, \
1.80342, 1.80342}, {{200.313, 286.063}, {206.25, 163.813}} -> {-388.069, \
-1391.78, 1.80342, 1.80342}, {{294.688, 380.438}, {206.25, 163.813}} -> \
{-558.267, -1391.78, 1.80342, 1.80342}, {{389.063, 474.813}, {206.25, \
163.813}} -> {-728.465, -1391.78, 1.80342, 1.80342}, {{11.5625, 97.375}, \
{159.563, 117.063}} -> {-47.5228, -1472.86, 1.79962, 1.79962}, {{105.938, \
191.688}, {159.563, 117.063}} -> {-217.305, -1472.86, 1.79962, 1.79962}, \
{{200.313, 286.063}, {159.563, 117.063}} -> {-387.144, -1472.86, 1.79962, \
1.79962}, {{294.688, 380.438}, {159.563, 117.063}} -> {-556.983, -1472.86, \
1.79962, 1.79962}, {{389.063, 474.813}, {159.563, 117.063}} -> {-726.821, \
-1472.86, 1.79962, 1.79962}, {{11.5625, 97.375}, {112.813, 70.375}} -> \
{-47.73, -1560.28, 1.80342, 1.80342}, {{105.938, 191.688}, {112.813, 70.375}} -> \
{-217.871, -1560.28, 1.80342, 1.80342}, {{200.313, 286.063}, {112.813, \
70.375}} -> {-388.069, -1560.28, 1.80342, 1.80342}, {{294.688, 380.438}, \
{112.813, 70.375}} -> {-558.267, -1560.28, 1.80342, 1.80342}, {{389.063, \
474.813}, {112.813, 70.375}} -> {-728.465, -1560.28, 1.80342, 1.80342}, \
{{11.5625, 97.375}, {66.125, 23.625}} -> {-47.5228, -1641.01, 1.79962, \
1.79962}, {{105.938, 191.688}, {66.125, 23.625}} -> {-217.305, -1641.01, \
1.79962, 1.79962}, {{200.313, 286.063}, {66.125, 23.625}} -> {-387.144, \
-1641.01, 1.79962, 1.79962}, {{294.688, 380.438}, {66.125, 23.625}} -> \
{-556.983, -1641.01, 1.79962, 1.79962}, {{389.063, 474.813}, {66.125, \
23.625}} -> {-726.821, -1641.01, 1.79962, 1.79962}}]
}, Open  ]],

Cell["\<\
We include the data for these rules in file totallistic3.

In searching through the data corresponding to the totalistic ones we \
obtained the following profile. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[profile];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00195963 0.0147151 0.00594549 [
[.21977 .00222 -9 -9 ]
[.21977 .00222 9 0 ]
[.41574 .00222 -9 -9 ]
[.41574 .00222 9 0 ]
[.6117 .00222 -9 -9 ]
[.6117 .00222 9 0 ]
[.80766 .00222 -9 -9 ]
[.80766 .00222 9 0 ]
[.01131 .13362 -12 -4.5 ]
[.01131 .13362 0 4.5 ]
[.01131 .25253 -12 -4.5 ]
[.01131 .25253 0 4.5 ]
[.01131 .37144 -12 -4.5 ]
[.01131 .37144 0 4.5 ]
[.01131 .49035 -12 -4.5 ]
[.01131 .49035 0 4.5 ]
[.01131 .60926 -18 -4.5 ]
[.01131 .60926 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21977 .01472 m
.21977 .02097 L
s
[(100)] .21977 .00222 0 1 Mshowa
.41574 .01472 m
.41574 .02097 L
s
[(200)] .41574 .00222 0 1 Mshowa
.6117 .01472 m
.6117 .02097 L
s
[(300)] .6117 .00222 0 1 Mshowa
.80766 .01472 m
.80766 .02097 L
s
[(400)] .80766 .00222 0 1 Mshowa
.125 Mabswid
.063 .01472 m
.063 .01847 L
s
.10219 .01472 m
.10219 .01847 L
s
.14139 .01472 m
.14139 .01847 L
s
.18058 .01472 m
.18058 .01847 L
s
.25897 .01472 m
.25897 .01847 L
s
.29816 .01472 m
.29816 .01847 L
s
.33735 .01472 m
.33735 .01847 L
s
.37654 .01472 m
.37654 .01847 L
s
.45493 .01472 m
.45493 .01847 L
s
.49412 .01472 m
.49412 .01847 L
s
.53331 .01472 m
.53331 .01847 L
s
.57251 .01472 m
.57251 .01847 L
s
.65089 .01472 m
.65089 .01847 L
s
.69008 .01472 m
.69008 .01847 L
s
.72928 .01472 m
.72928 .01847 L
s
.76847 .01472 m
.76847 .01847 L
s
.84685 .01472 m
.84685 .01847 L
s
.88605 .01472 m
.88605 .01847 L
s
.92524 .01472 m
.92524 .01847 L
s
.96443 .01472 m
.96443 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13362 m
.03006 .13362 L
s
[(20)] .01131 .13362 1 0 Mshowa
.02381 .25253 m
.03006 .25253 L
s
[(40)] .01131 .25253 1 0 Mshowa
.02381 .37144 m
.03006 .37144 L
s
[(60)] .01131 .37144 1 0 Mshowa
.02381 .49035 m
.03006 .49035 L
s
[(80)] .01131 .49035 1 0 Mshowa
.02381 .60926 m
.03006 .60926 L
s
[(100)] .01131 .60926 1 0 Mshowa
.125 Mabswid
.02381 .04444 m
.02756 .04444 L
s
.02381 .07417 m
.02756 .07417 L
s
.02381 .1039 m
.02756 .1039 L
s
.02381 .16335 m
.02756 .16335 L
s
.02381 .19308 m
.02756 .19308 L
s
.02381 .22281 m
.02756 .22281 L
s
.02381 .28226 m
.02756 .28226 L
s
.02381 .31199 m
.02756 .31199 L
s
.02381 .34172 m
.02756 .34172 L
s
.02381 .40117 m
.02756 .40117 L
s
.02381 .4309 m
.02756 .4309 L
s
.02381 .46063 m
.02756 .46063 L
s
.02381 .52008 m
.02756 .52008 L
s
.02381 .54981 m
.02756 .54981 L
s
.02381 .57954 m
.02756 .57954 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02577 .01472 Mdot
.02773 .02066 Mdot
.02969 .02066 Mdot
.03165 .02066 Mdot
.03361 .02066 Mdot
.03557 .02066 Mdot
.03753 .02066 Mdot
.03949 .02066 Mdot
.04145 .02066 Mdot
.04341 .02066 Mdot
.04537 .02066 Mdot
.04733 .02066 Mdot
.04928 .02066 Mdot
.05124 .02066 Mdot
.0532 .02066 Mdot
.05516 .02066 Mdot
.05712 .02066 Mdot
.05908 .02066 Mdot
.06104 .02066 Mdot
.063 .02066 Mdot
.06496 .02066 Mdot
.06692 .02066 Mdot
.06888 .02066 Mdot
.07084 .02066 Mdot
.0728 .02066 Mdot
.07476 .02066 Mdot
.07672 .02066 Mdot
.07868 .02066 Mdot
.08064 .02066 Mdot
.0826 .02066 Mdot
.08456 .02066 Mdot
.08652 .02066 Mdot
.08848 .02066 Mdot
.09044 .02066 Mdot
.0924 .02066 Mdot
.09436 .02066 Mdot
.09632 .02066 Mdot
.09828 .02066 Mdot
.10024 .02066 Mdot
.10219 .02066 Mdot
.10415 .02066 Mdot
.10611 .02066 Mdot
.10807 .02066 Mdot
.11003 .02066 Mdot
.11199 .02066 Mdot
.11395 .02066 Mdot
.11591 .02066 Mdot
.11787 .02066 Mdot
.11983 .02066 Mdot
.12179 .02066 Mdot
.12375 .02066 Mdot
.12571 .02066 Mdot
.12767 .02066 Mdot
.12963 .02066 Mdot
.13159 .02066 Mdot
.13355 .02066 Mdot
.13551 .02066 Mdot
.13747 .02066 Mdot
.13943 .02066 Mdot
.14139 .02066 Mdot
.14335 .02066 Mdot
.14531 .02066 Mdot
.14727 .02066 Mdot
.14923 .02066 Mdot
.15119 .02661 Mdot
.15315 .03255 Mdot
.1551 .0385 Mdot
.15706 .04444 Mdot
.15902 .05039 Mdot
.16098 .05633 Mdot
.16294 .06228 Mdot
.1649 .06822 Mdot
.16686 .07417 Mdot
.16882 .07417 Mdot
.17078 .07417 Mdot
.17274 .07417 Mdot
.1747 .08012 Mdot
.17666 .08012 Mdot
.17862 .08012 Mdot
.18058 .08012 Mdot
.18254 .08012 Mdot
.1845 .08012 Mdot
.18646 .08012 Mdot
.18842 .08012 Mdot
.19038 .08012 Mdot
.19234 .08012 Mdot
.1943 .08012 Mdot
.19626 .08012 Mdot
.19822 .08012 Mdot
.20018 .08012 Mdot
.20214 .08012 Mdot
.2041 .08012 Mdot
.20606 .08012 Mdot
.20801 .08012 Mdot
.20997 .08012 Mdot
.21193 .08012 Mdot
.21389 .08012 Mdot
.21585 .08012 Mdot
.21781 .08012 Mdot
.21977 .08012 Mdot
.22173 .08012 Mdot
.22369 .08012 Mdot
.22565 .08012 Mdot
.22761 .08012 Mdot
.22957 .08012 Mdot
.23153 .08012 Mdot
.23349 .08012 Mdot
.23545 .08012 Mdot
.23741 .08012 Mdot
.23937 .08012 Mdot
.24133 .08012 Mdot
.24329 .08012 Mdot
.24525 .08012 Mdot
.24721 .08012 Mdot
.24917 .08012 Mdot
.25113 .08012 Mdot
.25309 .08012 Mdot
.25505 .08012 Mdot
.25701 .08012 Mdot
.25897 .08012 Mdot
.26092 .08012 Mdot
.26288 .08012 Mdot
.26484 .08012 Mdot
.2668 .08012 Mdot
.26876 .08012 Mdot
.27072 .08012 Mdot
.27268 .08012 Mdot
.27464 .08012 Mdot
.2766 .08012 Mdot
.27856 .08012 Mdot
.28052 .08012 Mdot
.28248 .08012 Mdot
.28444 .08012 Mdot
.2864 .08012 Mdot
.28836 .08012 Mdot
.29032 .08012 Mdot
.29228 .08606 Mdot
.29424 .09201 Mdot
.2962 .09795 Mdot
.29816 .1039 Mdot
.30012 .10984 Mdot
.30208 .11579 Mdot
.30404 .12173 Mdot
.306 .12768 Mdot
.30796 .13362 Mdot
.30992 .13362 Mdot
.31188 .13362 Mdot
.31383 .13957 Mdot
.31579 .13957 Mdot
.31775 .13957 Mdot
.31971 .13957 Mdot
.32167 .13957 Mdot
.32363 .13957 Mdot
.32559 .13957 Mdot
.32755 .13957 Mdot
.32951 .13957 Mdot
.33147 .13957 Mdot
.33343 .13957 Mdot
.33539 .13957 Mdot
.33735 .13957 Mdot
.33931 .13957 Mdot
.34127 .13957 Mdot
.34323 .13957 Mdot
.34519 .14552 Mdot
.34715 .15146 Mdot
.34911 .15741 Mdot
.35107 .16335 Mdot
.35303 .1693 Mdot
.35499 .17524 Mdot
.35695 .18119 Mdot
.35891 .18713 Mdot
.36087 .19308 Mdot
.36283 .19903 Mdot
.36479 .20497 Mdot
.36675 .21092 Mdot
.3687 .21686 Mdot
.37066 .22281 Mdot
.37262 .22875 Mdot
.37458 .22875 Mdot
.37654 .2347 Mdot
.3785 .24064 Mdot
.38046 .24064 Mdot
.38242 .24064 Mdot
.38438 .24064 Mdot
.38634 .24064 Mdot
.3883 .24064 Mdot
.39026 .24659 Mdot
.39222 .24659 Mdot
.39418 .24659 Mdot
.39614 .24659 Mdot
.3981 .24659 Mdot
.40006 .24659 Mdot
.40202 .25253 Mdot
.40398 .25253 Mdot
.40594 .25253 Mdot
.4079 .25253 Mdot
.40986 .25848 Mdot
.41182 .26443 Mdot
.41378 .27037 Mdot
.41574 .27037 Mdot
.4177 .27037 Mdot
.41966 .27632 Mdot
.42161 .27632 Mdot
.42357 .27632 Mdot
.42553 .27632 Mdot
.42749 .27632 Mdot
.42945 .27632 Mdot
.43141 .27632 Mdot
.43337 .27632 Mdot
.43533 .28226 Mdot
.43729 .28226 Mdot
.43925 .28226 Mdot
.44121 .28226 Mdot
.44317 .28226 Mdot
.44513 .28226 Mdot
.44709 .28226 Mdot
.44905 .28226 Mdot
.45101 .28226 Mdot
.45297 .28821 Mdot
.45493 .28821 Mdot
.45689 .28821 Mdot
.45885 .28821 Mdot
.46081 .29415 Mdot
.46277 .29415 Mdot
.46473 .3001 Mdot
.46669 .3001 Mdot
.46865 .3001 Mdot
.47061 .3001 Mdot
.47257 .30604 Mdot
.47452 .30604 Mdot
.47648 .30604 Mdot
.47844 .30604 Mdot
.4804 .30604 Mdot
.48236 .30604 Mdot
.48432 .30604 Mdot
.48628 .30604 Mdot
.48824 .30604 Mdot
.4902 .30604 Mdot
.49216 .30604 Mdot
.49412 .30604 Mdot
.49608 .30604 Mdot
.49804 .30604 Mdot
.5 .30604 Mdot
.50196 .30604 Mdot
.50392 .31199 Mdot
.50588 .31794 Mdot
.50784 .32388 Mdot
.5098 .32388 Mdot
.51176 .32388 Mdot
.51372 .32388 Mdot
.51568 .32388 Mdot
.51764 .32388 Mdot
.5196 .32388 Mdot
.52156 .32388 Mdot
.52352 .32388 Mdot
.52548 .32388 Mdot
.52743 .32388 Mdot
.52939 .32388 Mdot
.53135 .32388 Mdot
.53331 .32388 Mdot
.53527 .32388 Mdot
.53723 .32388 Mdot
.53919 .32388 Mdot
.54115 .32388 Mdot
.54311 .32388 Mdot
.54507 .32388 Mdot
.54703 .32388 Mdot
.54899 .32388 Mdot
.55095 .32388 Mdot
.55291 .32388 Mdot
.55487 .32388 Mdot
.55683 .32388 Mdot
.55879 .32388 Mdot
.56075 .32388 Mdot
.56271 .32388 Mdot
.56467 .32388 Mdot
.56663 .32388 Mdot
.56859 .32388 Mdot
.57055 .32388 Mdot
.57251 .32388 Mdot
.57447 .32388 Mdot
.57643 .32983 Mdot
.57839 .33577 Mdot
.58034 .33577 Mdot
.5823 .33577 Mdot
.58426 .33577 Mdot
.58622 .34172 Mdot
.58818 .34766 Mdot
.59014 .35361 Mdot
.5921 .35361 Mdot
.59406 .35955 Mdot
.59602 .35955 Mdot
.59798 .35955 Mdot
.59994 .3655 Mdot
.6019 .3655 Mdot
.60386 .3655 Mdot
.60582 .3655 Mdot
.60778 .3655 Mdot
.60974 .3655 Mdot
.6117 .3655 Mdot
.61366 .3655 Mdot
.61562 .3655 Mdot
.61758 .3655 Mdot
.61954 .3655 Mdot
.6215 .3655 Mdot
.62346 .3655 Mdot
.62542 .3655 Mdot
.62738 .3655 Mdot
.62934 .3655 Mdot
.6313 .37144 Mdot
.63325 .37144 Mdot
.63521 .37144 Mdot
.63717 .37144 Mdot
.63913 .37144 Mdot
.64109 .37144 Mdot
.64305 .37144 Mdot
.64501 .37144 Mdot
.64697 .37144 Mdot
.64893 .37144 Mdot
.65089 .37144 Mdot
.65285 .37144 Mdot
.65481 .37144 Mdot
.65677 .37144 Mdot
.65873 .37144 Mdot
.66069 .37144 Mdot
.66265 .37144 Mdot
.66461 .37144 Mdot
.66657 .37739 Mdot
.66853 .37739 Mdot
.67049 .38334 Mdot
.67245 .38928 Mdot
.67441 .38928 Mdot
.67637 .39523 Mdot
.67833 .40117 Mdot
.68029 .40712 Mdot
.68225 .41306 Mdot
.68421 .41901 Mdot
.68617 .42495 Mdot
.68812 .42495 Mdot
.69008 .4309 Mdot
.69204 .43685 Mdot
.694 .44279 Mdot
.69596 .44874 Mdot
.69792 .45468 Mdot
.69988 .46063 Mdot
.70184 .46657 Mdot
.7038 .46657 Mdot
.70576 .47252 Mdot
.70772 .47846 Mdot
.70968 .48441 Mdot
.71164 .49035 Mdot
.7136 .49035 Mdot
.71556 .49035 Mdot
.71752 .49035 Mdot
.71948 .49035 Mdot
.72144 .49035 Mdot
.7234 .49035 Mdot
.72536 .49035 Mdot
.72732 .49035 Mdot
.72928 .4963 Mdot
.73124 .50225 Mdot
.7332 .50225 Mdot
.73516 .50225 Mdot
.73712 .50225 Mdot
.73908 .50225 Mdot
.74103 .50225 Mdot
.74299 .50225 Mdot
.74495 .50225 Mdot
.74691 .50225 Mdot
.74887 .50225 Mdot
.75083 .50819 Mdot
.75279 .51414 Mdot
.75475 .52008 Mdot
.75671 .52008 Mdot
.75867 .52008 Mdot
.76063 .52008 Mdot
.76259 .52008 Mdot
.76455 .52008 Mdot
.76651 .52008 Mdot
.76847 .52008 Mdot
.77043 .52008 Mdot
.77239 .52603 Mdot
.77435 .52603 Mdot
.77631 .53197 Mdot
.77827 .53792 Mdot
.78023 .53792 Mdot
.78219 .53792 Mdot
.78415 .54386 Mdot
.78611 .54386 Mdot
.78807 .54386 Mdot
.79003 .54981 Mdot
.79199 .54981 Mdot
.79394 .54981 Mdot
.7959 .54981 Mdot
.79786 .54981 Mdot
.79982 .54981 Mdot
.80178 .54981 Mdot
.80374 .54981 Mdot
.8057 .55575 Mdot
.80766 .55575 Mdot
.80962 .5617 Mdot
.81158 .5617 Mdot
.81354 .5617 Mdot
.8155 .5617 Mdot
.81746 .5617 Mdot
.81942 .5617 Mdot
.82138 .5617 Mdot
.82334 .5617 Mdot
.8253 .5617 Mdot
.82726 .5617 Mdot
.82922 .5617 Mdot
.83118 .5617 Mdot
.83314 .5617 Mdot
.8351 .5617 Mdot
.83706 .5617 Mdot
.83902 .5617 Mdot
.84098 .5617 Mdot
.84294 .56765 Mdot
.8449 .56765 Mdot
.84685 .56765 Mdot
.84881 .57359 Mdot
.85077 .57359 Mdot
.85273 .57954 Mdot
.85469 .58548 Mdot
.85665 .58548 Mdot
.85861 .58548 Mdot
.86057 .58548 Mdot
.86253 .58548 Mdot
.86449 .58548 Mdot
.86645 .58548 Mdot
.86841 .58548 Mdot
.87037 .58548 Mdot
.87233 .58548 Mdot
.87429 .58548 Mdot
.87625 .58548 Mdot
.87821 .58548 Mdot
.88017 .58548 Mdot
.88213 .58548 Mdot
.88409 .58548 Mdot
.88605 .58548 Mdot
.88801 .59143 Mdot
.88997 .59143 Mdot
.89193 .59143 Mdot
.89389 .59143 Mdot
.89585 .59143 Mdot
.89781 .59143 Mdot
.89976 .59143 Mdot
.90172 .59143 Mdot
.90368 .59143 Mdot
.90564 .59143 Mdot
.9076 .59143 Mdot
.90956 .59143 Mdot
.91152 .59737 Mdot
.91348 .59737 Mdot
.91544 .59737 Mdot
.9174 .59737 Mdot
.91936 .59737 Mdot
.92132 .59737 Mdot
.92328 .59737 Mdot
.92524 .59737 Mdot
.9272 .59737 Mdot
.92916 .59737 Mdot
.93112 .59737 Mdot
.93308 .59737 Mdot
.93504 .59737 Mdot
.937 .59737 Mdot
.93896 .59737 Mdot
.94092 .59737 Mdot
.94288 .59737 Mdot
.94484 .59737 Mdot
.9468 .59737 Mdot
.94876 .60332 Mdot
.95072 .60332 Mdot
.95267 .60332 Mdot
.95463 .60332 Mdot
.95659 .60332 Mdot
.95855 .60332 Mdot
.96051 .60332 Mdot
.96247 .60332 Mdot
.96443 .60332 Mdot
.96639 .60332 Mdot
.96835 .60332 Mdot
.97031 .60332 Mdot
.97227 .60332 Mdot
.97423 .60332 Mdot
.97619 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3AcJTQ
0=7=Z@00@`3AcJT5@0000080dLfY0T0000040=7=Z@9000009P3AcJT4@00000<0dLfY0T0000040=7=
Z@9000009`3AcJT2@00000@0dLfY0T0000040=7=Z@9000009`3AcJT3@0000080dLfY0T0000040=7=
Z@900000<03AcJT004D0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00=000000=7=Z@3AcJT08`3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0
dLfY@0000080dLfY00A000000=7=Z@3AcJU000009@3AcJT014000000dLfY0=7=ZD0000020=7=Z@04
@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000009`3AcJT014000000dLfY0=7=ZD00
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0;@3AcJT004D0dLfY00E0
00000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3A
cJT0903AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=
Z@3AcJU000009`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU00000
0P3AcJT00d000000dLfY0=7=Z@0R0=7=Z@E0000000D0dLfY@000003AcJT0dLfY@00000020=7=Z@04
@000003AcJT0dLfY@00002l0dLfY00150=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY02D0dLfY00E000000=7=Z@3AcJT0dLfY@000
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT09P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT08P3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000
;`3AcJT004D0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080
dLfY00=000000=7=Z@3AcJT08`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00A000000=7=Z@3AcJU000009@3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000
003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000009@3AcJT00d000000dLfY@00000020=7=
Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000;`3AcJT004@0dLfY0T000004
0=7=Z@900000103AcJT2@00002L0dLfY0T0000040=7=Z@900000103AcJT2@00002L0dLfY0T000004
0=7=Z@900000103AcJT2@00002L0dLfY0T0000030=7=Z@900000103AcJT2@0000300dLfY003o0=7=
ZB40dLfY000F0=7=Z@030000003AcJT0dLfY0?l0dLfY203AcJT001H0dLfY00<000000=7=Z@3AcJT0
o`3AcJT80=7=Z@005P3AcJT00`000000dLfY0=7=Z@3o0=7=Z@P0dLfY000F0=7=Z@030000003AcJT0
dLfY0?l0dLfY203AcJT00100dLfYo`00000>0000005000000@3AcJT10=7=Z@005P3AcJTR000000P0
dLfY00=000000=7=Z@3AcJT0203AcJT00`000000dLfY0=7=Z@080=7=Z@03@000003AcJT0dLfY00L0
dLfY00=000000=7=Z@3AcJT0203AcJT00d000000dLfY0=7=Z@070=7=Z@03@000003AcJT0dLfY00P0
dLfY00<000000=7=Z@3AcJT01`3AcJT00d000000dLfY0=7=Z@080=7=Z@03@000003AcJT0dLfY00L0
dLfY00=000000=7=Z@3AcJT0203AcJT00d000000dLfY0=7=Z@080=7=Z@030000003AcJT0dLfY00L0
dLfY00=000000=7=Z@3AcJT0203AcJT00d000000dLfY0=7=Z@070=7=Z@03@000003AcJT0dLfY00P0
dLfY00=000000=7=Z@3AcJT01`3AcJT00`000000dLfY0=7=Z@080=7=Z@03@000003AcJT0dLfY00L0
dLfY00=000000=7=Z@3AcJT0203AcJT00d000000dLfY0=7=Z@080=7=Z@03@000003AcJT0dLfY00T0
dLfY000F0=7=ZB<000004P3AcJT00d000000dLfY0=7=Z@0b0=7=Z@03@000003AcJT0dLfY0380dLfY
00=000000=7=Z@3AcJT0<@3AcJT00d000000dLfY0=7=Z@0d0=7=Z@005P3AcJT00`000000dLfY0=7=
Z@0O0=7=Z@030000003AcJT0dLfY0>D0dLfY000F0=7=Z@030000003AcJT0dLfY01l0dLfY0P00003V
0=7=Z@005P3AcJT00`000000dLfY0=7=Z@0P0=7=Z@800000i@3AcJT001H0dLfY00<000000=7=Z@3A
cJT0803AcJT00`000000dLfY0=7=Z@3T0=7=Z@005P3AcJT00`000000dLfY0=7=Z@0P0=7=Z@800000
i@3AcJT001H0dLfY00<00000@000003AcJT08@3AcJT200000>@0dLfY000F0=7=Z@030000003AcJT0
dLfY0240dLfY00<000000=7=Z@3AcJT0h`3AcJT001H0dLfY00<000000=7=Z@3AcJT08@3AcJT20000
0>@0dLfY000F0=7=Z@030000003AcJT0dLfY0280dLfY00<000000=7=Z@3AcJT0hP3AcJT001H0dLfY
00<000000=7=Z@3AcJT08P3AcJT200000><0dLfY000F0=7=Z@030000003AcJT0dLfY0280dLfY0P00
003S0=7=Z@005P3AcJT00`000000dLfY0=7=Z@0S0=7=Z@030000003AcJT0dLfY0>40dLfY000F0=7=
Z@030000003AcJT0dLfY02<0dLfY0`00003Q0=7=Z@005P3AcJT00`00001000000=7=Z@0S0=7=Z@@0
0000h03AcJT001H0dLfY00<000000=7=Z@3AcJT09@3AcJTP00000<80dLfY000F0=7=Z@030000003A
cJT0dLfY02D0dLfY8@0000310=7=Z@005P3AcJT00`000000dLfY0=7=Z@150=7=Z@030000003AcJT0
dLfY0;l0dLfY000F0=7=Z@030000003AcJT0dLfY04D0dLfY0P0000300=7=Z@005P3AcJT00`000000
dLfY0=7=Z@160=7=Z@800000_`3AcJT001H0dLfY00<000000=7=Z@3AcJT0AP3AcJT00`000000dLfY
0=7=Z@2n0=7=Z@005P3AcJT00`000000dLfY0=7=Z@160=7=Z@800000_`3AcJT001H0dLfY00<00000
@000003AcJT0A`3AcJT200000;h0dLfY000F0=7=Z@030000003AcJT0dLfY04L0dLfY00<000000=7=
Z@3AcJT0_@3AcJT001H0dLfY00<000000=7=Z@3AcJT0A`3AcJT200000;h0dLfY000F0=7=Z@030000
003AcJT0dLfY04P0dLfY00<000000=7=Z@3AcJT0_03AcJT001H0dLfY00<000000=7=Z@3AcJT0B03A
cJT200000;d0dLfY000F0=7=Z@030000003AcJT0dLfY04P0dLfY0P00002m0=7=Z@00203AcJT4@000
00<0dLfY0T0000050=7=Z@030000003AcJT0dLfY04T0dLfY00<000000=7=Z@3AcJT0^`3AcJT000P0
dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000040=7=Z@030000003AcJT0dLfY
04T0dLfY0P00002l0=7=Z@002@3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@000
00@0dLfY0P0000000d000000dLfY0=7=Z@170=7=Z@800000_03AcJT000X0dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00<000000=7=Z@3AcJT0B@3AcJT;0000
0;<0dLfY00080=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000103AcJT0
0`000000dLfY0=7=Z@1;0=7=Z@X00000/P3AcJT000T0dLfY0T0000040=7=Z@9000001@3AcJT00`00
0000dLfY0=7=Z@1C0=7=Z@030000003AcJT0dLfY0;40dLfY000F0=7=Z@030000003AcJT0dLfY05<0
dLfY0P00002b0=7=Z@005P3AcJT00`000000dLfY0=7=Z@1D0=7=Z@800000/@3AcJT001H0dLfY00<0
00000=7=Z@3AcJT0E03AcJT00`000000dLfY0=7=Z@2`0=7=Z@005P3AcJT00`000000dLfY0=7=Z@1D
0=7=Z@800000/@3AcJT001H0dLfY00<00000@000003AcJT0E@3AcJT00`000000dLfY0=7=Z@2_0=7=
Z@005P3AcJT00`000000dLfY0=7=Z@1E0=7=Z@800000/03AcJT001H0dLfY00<000000=7=Z@3AcJT0
E@3AcJT200000;00dLfY000F0=7=Z@030000003AcJT0dLfY05H0dLfY00<000000=7=Z@3AcJT0[P3A
cJT001H0dLfY00<000000=7=Z@3AcJT0EP3AcJT200000:l0dLfY000F0=7=Z@030000003AcJT0dLfY
05H0dLfY0P00002_0=7=Z@005P3AcJT00`000000dLfY0=7=Z@1G0=7=Z@030000003AcJT0dLfY0:d0
dLfY000F0=7=Z@030000003AcJT0dLfY05L0dLfY0P00002^0=7=Z@005P3AcJT00`00001000000=7=
Z@1G0=7=Z@030000003AcJT0dLfY0:d0dLfY000F0=7=Z@030000003AcJT0dLfY05L0dLfY0P00002^
0=7=Z@005P3AcJT00`000000dLfY0=7=Z@1H0=7=Z@800000[@3AcJT001H0dLfY00<000000=7=Z@3A
cJT0F@3AcJT00`000000dLfY0=7=Z@2[0=7=Z@005P3AcJT00`000000dLfY0=7=Z@1I0=7=Z@800000
[03AcJT001H0dLfY00<000000=7=Z@3AcJT0F@3AcJT200000:`0dLfY000F0=7=Z@030000003AcJT0
dLfY05X0dLfY00<000000=7=Z@3AcJT0ZP3AcJT001H0dLfY00<000000=7=Z@3AcJT0FP3AcJT20000
0:/0dLfY000F0=7=Z@03000004000000dLfY05X0dLfY00<000000=7=Z@3AcJT0ZP3AcJT001H0dLfY
00<000000=7=Z@3AcJT0FP3AcJT200000:/0dLfY000F0=7=Z@030000003AcJT0dLfY05/0dLfY0P00
002Z0=7=Z@005P3AcJT00`000000dLfY0=7=Z@1L0=7=Z@030000003AcJT0dLfY0:P0dLfY000F0=7=
Z@030000003AcJT0dLfY05`0dLfY1000002W0=7=Z@005P3AcJT00`000000dLfY0=7=Z@1L0=7=Z@D0
0000YP3AcJT000X0dLfY0d0000020=7=Z@9000001@3AcJT00`000000dLfY0=7=Z@1O0=7=Z@@00000
Y03AcJT000/0dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@030000
003AcJT0dLfY05l0dLfY1@00002S0=7=Z@00203AcJT5@00000050=7=ZD000000dLfY0=7=ZD000000
103AcJT200000003@000003AcJT0dLfY0640dLfY0P00002R0=7=Z@00203AcJT014000000dLfY0=7=
ZD0000020=7=Z@04@000003AcJT0dLfY@00000@0dLfY00<000000=7=Z@3AcJT0H`3AcJT300000:40
dLfY00090=7=Z@03@000003AcJU000000080dLfY00A000000=7=Z@3AcJU00000103AcJT00`000000
dLfY0=7=Z@1U0=7=Z@800000X03AcJT000X0dLfY0T0000030=7=Z@9000001@3AcJT00`000000dLfY
0=7=Z@1U0=7=Z@030000003AcJT0dLfY09l0dLfY000F0=7=Z@030000003AcJT0dLfY06D0dLfY0`00
002O0=7=Z@005P3AcJT00`000000dLfY0=7=Z@1V0=7=Z@<00000WP3AcJT001H0dLfY00<000000=7=
Z@3AcJT0I`3AcJT5000009/0dLfY000F0=7=Z@030000003AcJT0dLfY06L0dLfY1P00002J0=7=Z@00
5P3AcJT00`00001000000=7=Z@1/0=7=Z@D00000UP3AcJT001H0dLfY00<000000=7=Z@3AcJT0K03A
cJT7000009@0dLfY000F0=7=Z@030000003AcJT0dLfY0700dLfY1000002C0=7=Z@005P3AcJT00`00
0000dLfY0=7=Z@1b0=7=Z@800000T`3AcJT001H0dLfY00<000000=7=Z@3AcJT0LP3AcJT400000940
dLfY000F0=7=Z@030000003AcJT0dLfY07<0dLfY1000002@0=7=Z@005P3AcJT00`000000dLfY0=7=
Z@1f0=7=Z@P00000R@3AcJT001H0dLfY00<000000=7=Z@3AcJT0MP3AcJT9000008P0dLfY000F0=7=
Z@03000004000000dLfY07h0dLfY00<000000=7=Z@3AcJT0QP3AcJT001H0dLfY00<000000=7=Z@3A
cJT0OP3AcJT2000008L0dLfY000F0=7=Z@030000003AcJT0dLfY07l0dLfY0P0000260=7=Z@005P3A
cJT00`000000dLfY0=7=Z@1o0=7=ZA<00000M@3AcJT001H0dLfY00<000000=7=Z@3AcJT0O`3AcJTD
000007@0dLfY000F0=7=Z@030000003AcJT0dLfY0940dLfY0P00001d0=7=Z@005P3AcJT00`000000
dLfY0=7=Z@2B0=7=Z@<00000LP3AcJT001H0dLfY00<000000=7=Z@3AcJT0TP3AcJT400000740dLfY
000F0=7=Z@03000004000000dLfY09@0dLfY00<000000=7=Z@3AcJT0L03AcJT001H0dLfY00<00000
0=7=Z@3AcJT0U03AcJT200000740dLfY000F0=7=Z@030000003AcJT0dLfY09D0dLfY0P00001`0=7=
Z@005P3AcJT00`000000dLfY0=7=Z@2E0=7=Z@800000L03AcJT001H0dLfY00<000000=7=Z@3AcJT0
U@3AcJT3000006l0dLfY000F0=7=Z@030000003AcJT0dLfY09H0dLfY0`00001^0=7=Z@00203AcJT3
@00000@0dLfY0T0000050=7=Z@030000003AcJT0dLfY09P0dLfY2@00001V0=7=Z@00203AcJT01400
0000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000@0dLfY00<000000=7=Z@3AcJT0V03A
cJT:000006D0dLfY00080=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000
103AcJT200000003@000003AcJT0dLfY09h0dLfY2P00001M0=7=Z@00203AcJT3@00000<0dLfY00A0
00000=7=Z@3AcJU00000103AcJT00`000000dLfY0=7=Z@2P0=7=Z@/00000G03AcJT000T0dLfY00=0
00000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000040=7=Z@030000003AcJT0dLfY0:X0dLfY
0P00001K0=7=Z@002@3AcJT3@00000<0dLfY0T0000050=7=Z@030000003AcJT0dLfY0:/0dLfY00<0
00000=7=Z@3AcJT0F@3AcJT001H0dLfY00<000000=7=Z@3AcJT0Z`3AcJT2000005X0dLfY000F0=7=
Z@030000003AcJT0dLfY0:/0dLfY0`00001I0=7=Z@005P3AcJT00`000000dLfY0=7=Z@2/0=7=Z@03
0000003AcJT0dLfY05P0dLfY000F0=7=Z@030000003AcJT0dLfY0:`0dLfY0P00001I0=7=Z@005P3A
cJT00`00001000000=7=Z@2]0=7=Z@030000003AcJT0dLfY05L0dLfY000F0=7=Z@030000003AcJT0
dLfY0:d0dLfY0P00001H0=7=Z@005P3AcJT00`000000dLfY0=7=Z@2]0=7=Z@800000F03AcJT001H0
dLfY00<000000=7=Z@3AcJT0[P3AcJT00`000000dLfY0=7=Z@1F0=7=Z@005P3AcJT00`000000dLfY
0=7=Z@2^0=7=Z@800000E`3AcJT001H0dLfY00<000000=7=Z@3AcJT0[`3AcJT2000005H0dLfY000F
0=7=Z@030000003AcJT0dLfY0:l0dLfY0P00001F0=7=Z@005P3AcJT00`000000dLfY0=7=Z@2_0=7=
Z@<00000E@3AcJT001H0dLfY00<00000@000003AcJT0/03AcJT00`000000dLfY0=7=Z@1D0=7=Z@00
5P3AcJT00`000000dLfY0=7=Z@2`0=7=Z@800000E@3AcJT001H0dLfY00<000000=7=Z@3AcJT0/@3A
cJT2000005@0dLfY000F0=7=Z@030000003AcJT0dLfY0;40dLfY00<000000=7=Z@3AcJT0D`3AcJT0
01H0dLfY00<000000=7=Z@3AcJT0/@3AcJT2000005@0dLfY000F0=7=Z@030000003AcJT0dLfY0;80
dLfY0P00001C0=7=Z@005P3AcJT00`000000dLfY0=7=Z@2b0=7=Z@030000003AcJT0dLfY0580dLfY
000F0=7=Z@030000003AcJT0dLfY0;80dLfY0P00001C0=7=Z@005P3AcJT00`00001000000=7=Z@2c
0=7=Z@030000003AcJT0dLfY0540dLfY000F0=7=Z@030000003AcJT0dLfY0;<0dLfY0P00001B0=7=
Z@005P3AcJT00`000000dLfY0=7=Z@2c0=7=Z@<00000D@3AcJT001H0dLfY00<000000=7=Z@3AcJT0
]03AcJT00`000000dLfY0=7=Z@1@0=7=Z@005P3AcJT00`000000dLfY0=7=Z@2d0=7=Z@800000D@3A
cJT001H0dLfY00<000000=7=Z@3AcJT0]@3AcJT200000500dLfY00090=7=Z@900000103AcJT2@000
00D0dLfY00<000000=7=Z@3AcJT0]@3AcJT00`000000dLfY0=7=Z@1?0=7=Z@00203AcJT014000000
dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000@0dLfY00<000000=7=Z@3AcJT0]@3AcJT2
00000500dLfY00080=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000103A
cJT200000003@000003AcJT0dLfY0;@0dLfY1@00001<0=7=Z@002@3AcJT2@00000<0dLfY00A00000
0=7=Z@3AcJU00000103AcJT00`000000dLfY0=7=Z@2f0=7=Z@H00000B`3AcJT000P0dLfY00A00000
0=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@030000003AcJT0dLfY0;/0dLfY
0P00001:0=7=Z@002@3AcJT2@00000@0dLfY0T0000050=7=Z@030000003AcJT0dLfY0;/0dLfY1P00
00160=7=Z@005P3AcJT00`000000dLfY0=7=Z@2k0=7=Z@L00000A@3AcJT001H0dLfY00<000000=7=
Z@3AcJT0`03AcJT2000004D0dLfY000F0=7=Z@030000003AcJT0dLfY0<40dLfY00<000000=7=Z@3A
cJT0@`3AcJT001H0dLfY00<000000=7=Z@3AcJT0`@3AcJT2000004@0dLfY000F0=7=Z@0300000400
0000dLfY0<80dLfY1@0000100=7=Z@005P3AcJT00`000000dLfY0=7=Z@320=7=Z@H00000?`3AcJT0
01H0dLfY00<000000=7=Z@3AcJT0aP3AcJT3000003h0dLfY000F0=7=Z@030000003AcJT0dLfY0<L0
dLfY00<000000=7=Z@3AcJT0?@3AcJT001H0dLfY00<000000=7=Z@3AcJT0a`3AcJT3000003d0dLfY
000F0=7=Z@030000003AcJT0dLfY0<P0dLfY0`00000l0=7=Z@005P3AcJT00`000000dLfY0=7=Z@39
0=7=Z@800000?03AcJT001H0dLfY00<000000=7=Z@3AcJT0b@3AcJT3000003/0dLfY000F0=7=Z@03
000004000000dLfY0</0dLfY1@00000g0=7=Z@005P3AcJT00`000000dLfY0=7=Z@3;0=7=Z@H00000
=P3AcJT001H0dLfY00<000000=7=Z@3AcJT0c`3AcJT3000003D0dLfY000F0=7=Z@030000003AcJT0
dLfY0=00dLfY2P00000]0=7=Z@005P3AcJT00`000000dLfY0=7=Z@3@0=7=Z@/00000;03AcJT001H0
dLfY00<000000=7=Z@3AcJT0f@3AcJT3000002/0dLfY000F0=7=Z@030000003AcJT0dLfY0=/0dLfY
00<000000=7=Z@3AcJT0:@3AcJT001H0dLfY00<000000=7=Z@3AcJT0f`3AcJT2000002X0dLfY000F
0=7=Z@03000004000000dLfY0=`0dLfY00<000000=7=Z@3AcJT0:03AcJT001H0dLfY00<000000=7=
Z@3AcJT0g03AcJT:00000240dLfY000F0=7=Z@030000003AcJT0dLfY0=`0dLfY2`00000P0=7=Z@00
5P3AcJT00`000000dLfY0=7=Z@3U0=7=Z@L000006`3AcJT001H0dLfY00<000000=7=Z@3AcJT0i@3A
cJTA00000140dLfY000F0=7=Z@030000003AcJT0dLfY0>`0dLfY2`00000@0=7=Z@000P3AcJT5@000
0080dLfY0T0000040=7=Z@9000001@3AcJT00`000000dLfY0=7=Z@3f0=7=Z@P000002@3AcJT000@0
dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=00000
0=7=Z@3AcJT00P3AcJT00`000000dLfY0=7=Z@3f0=7=Z@T00000203AcJT000@0dLfY00E000000=7=
Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3A
cJT200000003@000003AcJT0dLfY0?l0dLfY1P3AcJT000@0dLfY00E000000=7=Z@3AcJT0dLfY@000
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT00`000000dLfY
0=7=Z@3o0=7=Z@P0dLfY00040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0o`3AcJT80=7=Z@00
0`3AcJT2@00000@0dLfY0T0000040=7=Z@900000o`3AcJT@0=7=Z@00o`3AcJTQ0=7=Z@00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-43.1592, -7.72456, 1.89538, \
0.624716}}]
}, Open  ]],

Cell["\<\
Any one of the previous CA can be singled out for processing:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(r = IntegerDigits[2201243097206, 3, 27];\)\), "\[IndentingNewLine]", 
    \(\(Show[showCA[3, cellularSpace[301], r, 150, 1, 1, 301, 0], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input",
  CellLabel->"In[25]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49834 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00319448 0.00958344 0.00319448 [
[ 0 0 0 0 ]
[ 1 .49834 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49834 L
0 .49834 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00958 translate
.96154 .47918 scale
301 string
301 150 8 [301 0 0 150 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0080FFFF8000808000FF0080FF0000000000000080808000FFFF0080FFFF00FF000000
808000000080FFFFFF800000000000000000000000000000FFFFFF000000FFFFFF000000
000000FF00FFFFFF00FF00000080FF8000000080FF800000000000FFFF0000FFFFFF00FF
FFFFFF80800000800000808080008000800000000000000000000000000080FF8000FFFF
FF00FFFFFF000000FFFFFF00FFFFFF0080FF800000000000000000000000000080008000
80808000008000008080FFFFFFFF00FFFFFF0000FFFF000000000080FF8000000080FF80
000000FF00FFFFFF00FF000000000000FFFFFF000000FFFFFF0000000000000000000000
00000080FFFFFF800000008080000000FF00FFFF8000FFFF0080808000000000000000FF
8000FF0080800080FFFF8000FF
FFFF80808080FFFF00FF008080FF000000FF000000FFFF00FF0080FFFF0080FFFFFF80FF
FF00FF0000FFFFFFFFFF0000000000000000000000000000008000000000008000000000
00000000808080808000000000FFFFFF000000FFFFFF00000000000080FFFF8000008080
80808080FF80FFFF0000FFFF00FF00FF00FF000000000000000000000000FFFFFF000080
00000080000000000080000000800000FFFFFF000000000000000000000000FF00FF00FF
00FFFF0000FFFF80FF808080808080000080FFFF80000000000000FFFFFF000000FFFFFF
000000008080808080000000000000000080000000000080000000000000000000000000
000000FFFFFFFFFF0000FF00FFFF80FFFFFF8000FFFF8000FF00FFFF000000FF000000FF
808000FF00FFFF80808080FFFF
FFFFFF00FFFF0080FFFFFF8080FF0000FF00808000800000FF80FF800000FFFFFFFFFF00
800080FFFF8000008000FF00000000000000000000000000FF00FF000000FF00FF000000
00000000FFFF00FFFF000000000080FF000000FF8000000000000000FFFFFFFF0000FFFF
00FFFF00FF80808080008000FF0080808000FF000000000000FF0000FF000080000000FF
FF80FFFF0000000000FFFF80FFFF000000800000FF0000FF000000000000FF0080808000
FF00800080808080FF00FFFF00FFFF0000FFFFFFFF0000000000000080FF000000FF8000
00000000FFFF00FFFF00000000000000FF00FF000000FF00FF0000000000000000000000
0000FF0080000080FFFF80008000FFFFFFFFFF000080FF80FF00008000808000FF0000FF
8080FFFFFF8000FFFF00FFFFFF
FFFFFFFF800000FFFFFFFFFF00FF80FFFFFF8080FFFF0000FF808080FFFF8000FF800000
FFFF80808080FFFF80800000000000000000000000000000008080800080808000000000
0000000000800080000000FF0000FFFFFF80FFFFFF0000FF000000000080FF00808000FF
80FF00808080FF8080FFFF00008080FF8080000000000000000080800000FF00FF000000
80FF800000000000000080FF80000000FF00FF0000808000000000000000008080FF8080
0000FFFF8080FF80808000FF80FF00808000FF800000000000FF0000FFFFFF80FFFFFF00
00FF00000080008000000000000000000080808000808080000000000000000000000000
0000008080FFFF80808080FFFF000080FF0080FFFF808080FF0000FFFF8080FFFFFF80FF
00FFFFFFFFFF000080FFFFFFFF
FFFFFFFFFF00000080000080FFFFFF008000FFFF008000808080FF80808080FFFFFF0000
0080FF8080FF8000FFFF0000FF000000000000000000000000FFFF00FF00FFFF00000000
00000000FF00FF00FF0000008080000080FF8000008080000000000000FFFFFF8080FFFF
FF008080FF808080FF800000FF00FFFFFF00FF00000000000000FFFF0000FF80FF000000
FFFFFF00000000000000FFFFFF000000FF80FF0000FFFF00000000000000FF00FFFFFF00
FF000080FF808080FF808000FFFFFF8080FFFFFF0000000000008080000080FF80000080
80000000FF00FF00FF0000000000000000FFFF00FF00FFFF000000000000000000000000
FF0000FFFF0080FF8080FF80000000FFFFFF80808080FF808080008000FFFF008000FFFF
FF80000080000000FFFFFFFFFF
FFFFFFFFFFFF80FFFF0000FFFFFFFFFF808000008080FFFF00FFFFFF00FFFF0080000000
00FFFFFF00FF808000008080000000000000000000000000000080FFFFFF800000000000
000000FF0080808000FF0000FFFF0000FFFFFF0000FFFF0000000000FF008000FFFF0080
00FF00FFFFFF00FFFFFF000000808080808000000000000000FF008000808080FF000000
FF8000000000000000000080FF000000FF808080008000FF000000000000008080808080
000000FFFFFF00FFFFFF00FF008000FFFF008000FF0000000000FFFF0000FFFFFF0000FF
FF0000FF0080808000FF000000000000000080FFFFFF8000000000000000000000000000
00808000008080FF00FFFFFF000000008000FFFF00FFFFFF00FFFF808000008080FFFFFF
FFFF0000FFFF80FFFFFFFFFFFF
FFFFFFFFFFFFFF0080FFFF8000008000FFFF0000FFFF0080FFFFFFFFFF800000FFFF80FF
FF800000808080FF80FFFF00FF00000000000000000000FF0000FFFFFFFFFF0000FF0000
000000008080FF808000000000800080808080800080000000000000008080FFFFFFFF80
80000000800000008000000000FFFF00FFFF000000000000FF008080FFFF00FFFFFF80FF
FFFF0000FF000000FF0000FFFFFF80FFFFFF00FFFF808000FF000000000000FFFF00FFFF
0000000080000000800000008080FFFFFFFF808000000000000000800080808080800080
000000008080FF8080000000000000FF0000FFFFFFFFFF0000FF00000000000000000000
FF00FFFF80FF808080000080FFFF80FFFF000080FFFFFFFFFF8000FFFF0000FFFF008000
0080FFFF8000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF80808080FFFF808000FF80FFFFFFFF80808080808080FFFF8000FFFF
FFFF0000FFFF00FF8080808000000000000000000000000080800000800000808000FF00
000000FF00FFFFFF00FF000000FFFF8080FF8080FFFF000000000000FF00FFFFFFFFFFFF
00FF0000FFFF80FFFF000000000080008000FF0000FF0000FF80FF80808080000080FF80
0000808000000000008080000080FF80000080808080FF80FF0000FF0000FF0080008000
00000000FFFF80FFFF0000FF00FFFFFFFFFFFF00FF000000000000FFFF8080FF8080FFFF
000000FF00FFFFFF00FF00000000FF008080000080000080800000000000000000000000
0080808080FF00FFFF0000FFFFFFFF0080FFFF80808080808080FFFFFFFF80FF008080FF
FF80808080FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF0080FF808000FFFFFFFFFFFF00FFFF00FFFF0080FF80FF00
80FF00000080FFFFFF00FFFF000000000000000000000000FFFF0000FFFF80FF80800000
00FF0000808080808000FF00000080FF808080FF80000000000000000080808080808080
800000000080FF80000000FF0000FFFF808000000000808000FFFFFF00FFFF0000FFFFFF
0000FFFF0000000000FFFF0000FFFFFF0000FFFF00FFFFFF008080000000008080FFFF00
00FF00000080FF80000000008080808080808080000000000000000080FF808080FF8000
0000FF0080808080800000FF0000008080FF80FFFF0000FFFF0000000000000000000000
00FFFF00FFFFFF80000000FF8000FF80FF8000FFFF00FFFF00FFFFFFFFFFFF008080FF80
00FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF800000FFFFFF00FF00800000800000008000800000FFFFFF0080
80FF000000FFFFFFFFFF800000000000000000000000000000800080808080FF00FFFF80
FFFFFF80FF8080FF808000000000FFFFFF00FFFFFF0000000000000000FFFF00FFFF00FF
FF00000000FFFFFF000000FF80FFFFFFFF00FF000000FFFF00008000FF00800080808080
8000800000000000000080008080808080008000FF00800000FFFF000000FF00FFFFFFFF
80FF000000FFFFFF00000000FFFF00FFFF00FFFF0000000000000000FFFFFF00FFFFFF00
0000008080FF8080FF80FFFFFF80FFFF00FF808080800080000000000000000000000000
000080FFFFFFFFFF000000FF808000FFFFFF00008000800000008000008000FF00FFFFFF
000080FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000800000008080FFFF8080008080FFFF0000008000FF00
FFFFFF80FFFFFFFFFFFFFF0000000000000000000000000000FFFF8080FF80808000FF80
80808080FF00FFFFFF00FF0000000080000000800000000000000000000080FFFFFFFF80
00000000000080FF000000FF8080808080800000FF000080FFFF80800000FFFF8080FF80
80FFFF00000000000000FFFF8080FF8080FFFF00008080FFFF800000FF00008080808080
80FF000000FF8000000000000080FFFFFFFF800000000000000000000080000000800000
0000FF00FFFFFF00FF8080808080FF00808080FF8080FFFF000000000000000000000000
0000FFFFFFFFFFFFFF80FFFFFF00FF0080000000FFFF8080008080FFFF80800000008000
0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF80FFFF0000FF00FFFFFFFF00FF00FFFFFFFF80FFFF000080
80808080FF008000008000FF000000000000000000000000000080FF808080FF808000FF
FF00FFFF0080808080800000000000FFFF80FFFF00000000000000000000FFFFFFFFFFFF
000000000000FFFFFF80FFFFFF00FFFF00FFFF80FF0000FFFFFFFF00FF000080FF808080
FF8000000000000000000080FF808080FF800000FF00FFFFFFFF0000FF80FFFF00FFFF00
FFFFFF80FFFFFF000000000000FFFFFFFFFFFF00000000000000000000FFFF80FFFF0000
000000808080808000FFFF00FFFF008080FF808080FF8000000000000000000000000000
00FF008000008000FF80808080800000FFFF80FFFFFFFF00FF00FFFFFFFF00FF0000FFFF
80FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0080FFFF800080000080FFFFFF80000080FF80000000FF
FF00FFFF008080FFFF8080000000000000000000000000000000FFFFFF00FFFFFF00FF00
8000800000FFFF00FFFF00000000000080FF8000000000000000000000FF008000FF8000
0000000000FF008000FFFFFFFFFF8000FF0080FF8000808080808080000000FFFFFF00FF
FFFF000000000000000000FFFFFF00FFFFFF0000008080808080800080FF8000FF0080FF
FFFFFFFF008000FF00000000000080FF008000FF0000000000000000000080FF80000000
000000FFFF00FFFF000080008000FF00FFFFFF00FFFFFF00000000000000000000000000
00008080FFFF808000FFFF00FFFF00000080FF80000080FFFFFF800000800080FFFF8000
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF80808080FFFF0000FFFFFFFFFF0000FFFFFF00000000
80008000FF00FFFFFFFF00FF00000000000000000000000000FF008000FF008000000080
80FFFF00000080008000FF0000FF0000FFFFFF0000FF0000FF00000000008080FFFFFF00
0000000000008080FFFFFFFFFFFFFF00008080FF00FF00FFFF00FFFF0000000080000000
800000000000000000000000800000008000000000FFFF00FFFF00FF00FF80800000FFFF
FFFFFFFFFF808000000000000000FFFFFF80800000000000FF0000FF0000FFFFFF0000FF
0000FF00800080000000FFFF80800000008000FF008000FF000000000000000000000000
00FF00FFFFFFFF00FF0080008000000000FFFFFF0000FFFFFFFFFF0000FFFF80808080FF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0080FFFF80000080FF0000008000000000FF
00FF00FF008080808080800000000000000000000000000000008080FFFFFF8080008080
FF80000000FF00FF00FF00808000FF000080FF0000008080000000000000FFFF00800000
0000000000FF00FFFFFFFFFFFFFFFFFF80FF8080800000008000800000000000FFFF80FF
FF0000000000000000000000FFFF80FFFF0000000000800080000000808080FF80FFFFFF
FFFFFFFFFFFF00FF000000000000008000FFFF0000000000008080000000FF800000FF00
808000FF00FF00FF00000080FF8080008080FFFFFF808000000000000000000000000000
000080808080808000FF00FF00FF0000000080000000FF80000080FFFF8000FFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800000FFFFFFFF0000FFFFFF80FFFF000000FF00
80808000FF00FFFF00FFFF0000000000000000000000000000FF00FFFFFFFFFF00FF00FF
FFFF0000000080808000FF00FFFF80008080FF000000FFFF0000000000FF0080FFFF0000
0000000000008080808080808080808080FF00FFFF0000FF00FF00FF000000FF0080FF80
0000000000000000000000000080FF8000FF000000FF00FF00FF0000FFFF00FF80808080
808080808080800000000000000000FFFF8000FF0000000000FFFF000000FF80800080FF
FF00FF0080808000000000FFFFFF00FF00FFFFFFFFFF00FF000000000000000000000000
0000FFFF00FFFF00FF0080808000FF000000FFFF80FFFFFF0000FFFFFFFF000080FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000008000008080000080FF80000000000080
80FF808000000080008000FF000000000000000000000000000080808080808080000000
800000000000FFFF00FF0080808080FFFF00FF80FFFF80000000FF0000FF80FF80000000
0000FF0000FF00FFFF00FFFF00FFFF00FFFFFF8000000000808080000000FF008080FF00
FF0000000000000000000000FF00FF808000FF0000008080800000000080FFFFFF00FFFF
00FFFF00FFFF00FF0000FF000000000080FF80FF0000FF00000080FFFF80FF00FFFF8080
808000FF00FFFF0000000000800000008080808080808000000000000000000000000000
00FF008000800000008080FF8080000000000080FF8000008080000080000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFF0000FFFF0000FFFFFF00000000FF00
FFFFFF00FF0000FFFF808000000000FF00000000000000000000FFFF00FFFF00FFFF80FF
FF00000000000080FFFFFF8080FF8080808000FFFFFFFF00000000808000FFFFFF000000
000000808000FF0080008000000080FFFFFFFFFF000000FF00FFFF000000FF80FF808080
00FF000000000000000000FF00808080FF80FF000000FFFF00FF000000FFFFFFFFFF8000
000080008000FF008080000000000000FFFFFF00808000000000FFFFFFFF0080808080FF
8080FFFFFF80000000000000FFFF80FFFF00FFFF00FFFF00000000000000000000FF0000
00008080FFFF0000FF00FFFFFF00FF00000000FFFFFF0000FFFF0000FFFF80FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0080FFFF80000000008000000000000080
808080800000000080FF808000808000000000000000000000000080008000000080FF80
00000000000000FFFFFFFFFF00FF8080FF808000FF800000000000FFFF00008000FF0000
000000FFFF00008080FFFF000000FFFFFFFFFFFFFF80FFFFFF8000000000FF808080FF80
8000000000000000000000008080FF808080FF0000000080FFFFFF80FFFFFFFFFFFFFF00
0000FFFF80800000FFFF0000000000FF00800000FFFF000000000080FF008080FF8080FF
00FFFFFFFFFF0000000000000080FF800000008000800000000000000000000000008080
008080FF80000000008080808080000000000000800000000080FFFF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80808080FFFF80FFFF000000000000FF
FF00FFFF000000FF00FF8080FFFF00FF0000FF00000000000000FF00FF00FF0000FFFFFF
000000000000000080FF0080FFFFFF00FF8080FFFFFF00000000000080FFFF8080000000
0000000080008080FF80000000FF008000008000FF8080808080FFFF80FFFFFF00FFFFFF
00FF000000000000000000FF00FFFFFF00FFFFFF80FFFF8080808080FF008000008000FF
00000080FF80800080000000000000008080FFFF80000000000000FFFFFF8080FF00FFFF
FF8000FF800000000000000000FFFFFF0000FF00FF00FF00000000000000FF0000FF00FF
FF8080FF00FF000000FFFF00FFFF000000000000FFFF80FFFF80808080FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0080FF80000000000000FF00
8000800000000000808080FF8000FF008080000000000000000000808080000000008000
0000FF0000FF0000FFFFFF808080808000FFFF00800000FF00000000FFFFFFFF00FF0000
00000000FFFF8080FF00FF0000008080FFFF808000FFFF00FFFF0080FF80000080808080
8000000000000000000000008080808080000080FF8000FFFF00FFFF008080FFFF808000
0000FF00FF8080FFFF000000000000FF00FFFFFFFF00000000FF00008000FFFF00808080
8080FFFFFF0000FF0000FF0000008000000000808080000000000000000000808000FF00
80FF808080000000000080008000FF00000000000080FF8000FFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800000FFFFFF0000000000FF0080
80FFFF0000000000FFFF00FF80800000FFFF0000000000000000FF00FFFF000000FF00FF
0000008080000000008000FFFF00FFFF000080FFFF000000808000808080808080000000
000000FF0080FF808080000000FF00FFFFFFFF00FF008000800000FFFFFF0000FFFF00FF
FF0000000000000000000000FFFF00FFFF0000FFFFFF000080008000FF00FFFFFFFF00FF
000000808080FF8000FF000000000000808080808080008080000000FFFF800000FFFF00
FFFF0080000000008080000000FF00FF000000FFFF00FF0000000000000000FFFF000080
80FF00FFFF0000000000FFFF808000FF0000000000FFFFFF000080FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000080000000000000008080
FF8000000000000000800080FF80800080FF0000FF000000000000808080800080808000
000000FFFF000000FF00FF00800080000000FFFFFFFF80FFFF00FF00FFFF00FFFF000000
000000008080FF00FFFF0000000080808080808000FF00FF00FF0000800000FF00800080
0000000000000000000000000080008000FF0000800000FF00FF00FF0080808080808000
000000FFFF00FF808000000000000000FFFF00FFFF00FF00FFFF80FFFFFFFF0000008000
8000FF00FF000000FFFF000000008080800080808080000000000000FF0000FF80008080
FF8000800000000000000080FF80800000000000000080000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFF0000FF000000FF00FF
FFFF000000000000FF00FF00FF8080FFFF008080000000FF0000FF00FFFF00FF00FFFF00
00000000800080800000008080FFFF000000FF8000FF8080808000FF0080008000000000
000000FF00FFFFFF8000FF000000FFFF00FFFF00FF008080800000FF00FF00008080FFFF
00000000000000000000000000FFFF80800000FF00FF000080808000FF00FFFF00FFFF00
0000FF0080FFFFFF00FF0000000000000080008000FF0080808080FF0080FF000000FFFF
8080000000808000800000000000FFFF00FF00FFFF00FF0000FF000000808000FFFF8080
FF00FF00FF000000000000FFFFFF00FF000000FF0000FFFF80FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0080FFFF8000808000FF00
80FF0000000000000080808000FFFF0080FFFF00FF000000808000000080FFFFFF800000
00000000FFFF8080FFFF80FF8080808000808080FFFFFF00FFFF00008080FFFF00000000
000000008080808080FFFFFF80FFFFFFFF800000008080FF808000800080008080FF8000
000000000000000000000000000080FF808000800080008080FF808000000080FFFFFFFF
80FFFFFF80808080800000000000000000FFFF80800000FFFF00FFFFFF80808000808080
80FF80FFFF8080FFFF00000000000080FFFFFF800000008080000000FF00FFFF8000FFFF
0080808000000000000000FF8000FF0080800080FFFF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80808080FFFF00FF0080
80FF000000FF000000FFFF00FF0080FFFF0080FFFFFF80FFFF00FF0000FFFFFFFFFF0000
000000000080FF80808080FF00FFFF00FF00FFFF008000000080008080FF800000000000
00000000FFFF00FFFF008000FFFFFFFFFFFF0000FF00FFFFFF00FF00FF00FF00FFFFFF00
0000000000000000000000000000FFFFFF00FF00FF00FF00FFFFFF00FF0000FFFFFFFFFF
FF008000FFFF00FFFF00000000000000000080FF808000800000008000FFFF00FF00FFFF
00FF80808080FF8000000000000000FFFFFFFFFF0000FF00FFFF80FFFFFF8000FFFF8000
FF00FFFF000000FF000000FF808000FF00FFFF80808080FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0080FFFFFF80
80FF0000FF00808000800000FF80FF800000FFFFFFFFFF00800080FFFF8000008000FF00
0000000000FFFFFF00FFFF008080808000000080FFFF0000FF00FF00FFFFFF0000000000
00000000008000800000FFFF800000800000808000000080000000808080000000800000
000000000000000000000000000000800000008080800000008000000080800000800000
80FFFF000080008000000000000000000000FFFFFF00FF00FF0000FFFF80000000808080
8000FFFF00FFFFFF000000000000FF0080000080FFFF80008000FFFFFFFFFF000080FF80
FF00008000808000FF0000FF8080FFFFFF8000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800000FFFFFFFFFF
00FF80FFFFFF8080FFFF0000FF808080FFFF8000FF800000FFFF80808080FFFF80800000
0000000000008000000080FFFF00FFFF0000FF00FF800080808000000080000000000000
00000000FF00FF00FF000080FF80FFFF0000FFFF000000FFFF80FFFF00FFFF80FFFF0000
000000000000000000000000000000FFFF80FFFF00FFFF80FFFF000000FFFF0000FFFF80
FF800000FF00FF00FF00000000000000000000800000008080800080FF00FF0000FFFF00
FFFF800000008000000000000000008080FFFF80808080FFFF000080FF0080FFFF808080
FF0000FFFF8080FFFFFF80FF00FFFFFFFFFF000080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000080000080
FFFFFF008000FFFF008000808080FF80808080FFFFFF00000080FF8080FF8000FFFF0000
FF0000000000FFFF80FFFF00800080FF000000808080FFFF00FFFF80FFFF000000000000
00000000008080800000FF00FF808080800080000000000080FF8000000080FF80000000
0000000000000000000000000000000080FF8000000080FF800000000000800080808080
FF00FF00008080800000000000000000000000FFFF80FFFF00FFFF808080000000FF8000
8000FFFF80FFFF0000000000FF0000FFFF0080FF8080FF80000000FFFFFF80808080FF80
8080008000FFFF008000FFFFFF80000080000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFF0000FF
FFFFFFFF808000008080FFFF00FFFFFF00FFFF008000000000FFFFFF00FF808000008080
0000000000000080FF8000FF00FF00FF80FFFF8080FF8000000080FF8000000000000000
0000000000FFFF00FF0000808080FF8080FFFF0000000000FFFFFF000000FFFFFF000000
00000000000000000000000000000000FFFFFF000000FFFFFF0000000000FFFF8080FF80
80800000FF00FFFF00000000000000000000000080FF8000000080FF8080FFFF80FF00FF
00FF0080FF8000000000000000808000008080FF00FFFFFF000000008000FFFF00FFFFFF
00FFFF808000008080FFFFFFFFFF0000FFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0080FFFF80
00008000FFFF0000FFFF0080FFFFFFFFFF800000FFFF80FFFF800000808080FF80FFFF00
FF000000000000FFFFFF000080808000FFFFFFFF00FF8080008080FF00FF000000000000
000000000000800080008080FF808080FF800000000000000080FF000000FF8000000000
000000000000000000000000000000000080FF000000FF800000000000000080FF808080
FF808000800080000000000000000000000000FF00FF8080008080FF00FFFFFFFF008080
800000FFFFFF000000000000FF00FFFF80FF808080000080FFFF80FFFF000080FFFFFFFF
FF8000FFFF0000FFFF0080000080FFFF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80808080
FFFF808000FF80FFFFFFFF80808080808080FFFF8000FFFFFFFF0000FFFF00FF80808080
000000000000000080000000FFFF00FF00800000808080FF80FF80808000FF0000000000
0000000000FF00FF00FF00FFFFFF00FFFFFF00000000FF0000FFFFFF80FFFFFF0000FF00
0000000000000000000000000000FF0000FFFFFF80FFFFFF0000FF00000000FFFFFF00FF
FFFF00FF00FF00FF00000000000000000000FF00808080FF80FF80808000008000FF00FF
FF00000080000000000000000080808080FF00FFFF0000FFFFFFFF0080FFFF8080808080
8080FFFFFFFF80FF008080FFFF80808080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
0080FF808000FFFFFFFFFFFF00FFFF00FFFF0080FF80FF0080FF00000080FFFFFF00FFFF
00000000000000FF00FF0000FF800080FFFF0000FFFF00FF808080FF8080000000000000
00000000FF0080808000FF0080000000800000000000008080000080FF80000080800000
0000000000000000000000000000008080000080FF800000808000000000000080000000
8000FF0080808000FF000000000000000000008080FF808080FF00FFFF0000FFFF800080
FF0000FF00FF00000000000000FFFF00FFFFFF80000000FF8000FF80FF8000FFFF00FFFF
00FFFFFFFFFFFF008080FF8000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
00FFFFFF00FF00800000800000008000800000FFFFFF008080FF000000FFFFFFFFFF8000
00000000000000008080800080FF80FF8000FF000080FFFFFF00FFFFFF00FF0000000000
00000000008080FF80800000FFFF80FFFF000000000000FFFF0000FFFFFF0000FFFF0000
000000000000000000000000000000FFFF0000FFFFFF0000FFFF000000000000FFFF80FF
FF00008080FF808000000000000000000000FF00FFFFFF00FFFFFF800000FF0080FF80FF
800080808000000000000000000080FFFFFFFFFF000000FF808000FFFFFF000080008000
00008000008000FF00FFFFFF000080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000800000008080FFFF8080008080FFFF0000008000FF00FFFFFF80FFFFFFFFFFFFFF00
0000000000FF0000FFFF00FF00FF808080FFFFFF80FF8000008080808080000000000000
00000000FF00FFFFFF00FF000080FF800000000000000000800080808080800080000000
00000000000000000000000000000000800080808080800080000000000000000080FF80
0000FF00FFFFFF00FF000000000000000000008080808080000080FF80FFFFFF808080FF
00FF00FFFF0000FF000000000000FFFFFFFFFFFFFF80FFFFFF00FF0080000000FFFF8080
008080FFFF808000000080000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
80FFFF0000FF00FFFFFFFF00FF00FFFFFFFF80FFFF00008080808080FF008000008000FF
0000000000008080000080808000FFFF00FF8000FFFFFF0000FFFF00FFFF000000000000
00000000008080808080000000FFFFFF0000000000000000FFFF8080FF8080FFFF000000
00000000000000000000000000000000FFFF8080FF8080FFFF0000000000000000FFFFFF
00000080808080800000000000000000000000FFFF00FFFF0000FFFFFF0080FF00FFFF00
80808000008080000000000000FF008000008000FF80808080800000FFFF80FFFFFFFF00
FF00FFFFFFFF00FF0000FFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0080FFFF800080000080FFFFFF80000080FF80000000FFFF00FFFF008080FFFF808000
000000000000FFFF0000FFFF00FF0080FFFFFF0000800000FF0080008000000000000000
0000000000FFFF00FFFF000000FF800000000000000000000080FF808080FF8000000000
000000000000000000000000000000000080FF808080FF800000000000000000000080FF
000000FFFF00FFFF00000000000000000000000080008000FF0000800000FFFFFF8000FF
00FFFF0000FFFF000000000000008080FFFF808000FFFF00FFFF00000080FF80000080FF
FFFF800000800080FFFF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF80808080FFFF0000FFFFFFFFFF0000FFFFFF0000000080008000FF00FFFFFFFF00FF
0000000000000080008080808000FF00FF800000FF00FF00008080FFFF00000000000000
00000000000080FFFFFFFF80FFFFFF00000000000000000000FFFFFF00FFFFFF00000000
0000000000000000000000000000000000FFFFFF00FFFFFF00000000000000000000FFFF
FF80FFFFFFFF8000000000000000000000000000FFFF80800000FF00FF000080FF00FF00
80808080008000000000000000FF00FFFFFFFF00FF0080008000000000FFFFFF0000FFFF
FFFFFF0000FFFF80808080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFF0080FFFF80000080FF0000008000000000FF00FF00FF0080808080808000
00000000000000FFFF8080FF80800000FF808000800080008080FF800000000000000000
000000000000FFFFFFFFFFFF008000000000FF0000FF0000000080000000800000000000
000000000000000000000000000000000000800000008000000000FF0000FF0000000080
00FFFFFFFFFFFF000000000000000000000000000080FF808000800080008080FF000080
80FF8080FFFF000000000000000080808080808000FF00FF00FF0000000080000000FF80
000080FFFF8000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF800000FFFFFFFF0000FFFFFF80FFFF000000FF0080808000FF00FFFF00FFFF00
000000000000000080FF808080FF80FFFFFF00FF00FF00FF00FFFFFF0000000000000000
0000000000FF008000008000FF00FF0000FF0080800000FF0000FFFF80FFFF0000000000
000000000000000000000000000000000000FFFF80FFFF0000FF0000808000FF0000FF00
FF008000008000FF00000000000000000000000000FFFFFF00FF00FF00FF00FFFFFF80FF
808080FF80000000000000000000FFFF00FFFF00FF0080808000FF000000FFFF80FFFFFF
0000FFFFFFFF000080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000008000008080000080FF8000000000008080FF808000000080008000FF
0000000000000000FFFFFF00FFFFFF008000000080808000000080000000000000000000
0000000000008080FFFF8080000000808000FF00FFFF80FF00000080FF80000000000000
0000000000000000000000000000000000000080FF80000000FF80FFFF00FF0080800000
008080FFFF8080000000000000000000000000000000800000008080800000008000FFFF
FF00FFFFFF0000000000000000FF008000800000008080FF8080000000000080FF800000
8080000080000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF80FFFF0000FFFF0000FFFFFF00000000FF00FFFFFF00FF0000FFFF808000
000000FF000000000080000000800000FFFF80FFFF00FFFF80FFFF000000000000000000
0000000000FF00FFFFFFFF00FF0000FFFF000080808080FF000000FFFFFF00000000FF00
00FF000000000000000000FF0000FF00000000FFFFFF000000FF808080800000FFFF0000
FF00FFFFFFFF00FF0000000000000000000000000000FFFF80FFFF00FFFF80FFFF000080
000000800000000000FF000000008080FFFF0000FF00FFFFFF00FF00000000FFFFFF0000
FFFF0000FFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0080FFFF80000000008000000000000080808080800000000080FF8080
008080000000000000FFFF80FFFF00000080FF8000000080FF8000000000000000000000
0000000000008080808080800000000080008080FF8080FF0000FF008000FF0000000080
800000000000000000000000808000000000FF008000FF0000FF8080FF80800080000000
008080808080800000000000000000000000000000000080FF8000000080FF80000000FF
FF80FFFF0000000000008080008080FF8000000000808080808000000000000080000000
0080FFFF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF80808080FFFF80FFFF000000000000FFFF00FFFF000000FF00FF8080
FFFF00FF0000FF00000080FF8000000000FFFFFF000000FFFFFF00000000000000000000
000000000000FFFF00FFFF00FF0000FF00FF00FFFFFF00FF80FFFFFF808000FF000000FF
FF0000000000000000000000FFFF000000FF008080FFFFFF80FF00FFFFFF00FF00FF0000
FF00FFFF00FFFF00000000000000000000000000000000FFFFFF000000FFFFFF00000000
80FF80000000FF0000FF00FFFF8080FF00FF000000FFFF00FFFF000000000000FFFF80FF
FF80808080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF0080FF80000000000000FF008000800000000000808080FF
8000FF00808000000000FFFFFF000000000080FF000000FF800000000000000000000000
0000000000000080008000FF008080000000808080808000FFFFFFFFFF00FF0080800080
000000000000000000000000008000808000FF00FFFFFFFFFF0080808080800000008080
00FF0080008000000000000000000000000000000000000080FF000000FF800000000000
FFFFFF00000000808000FF0080FF808080000000000080008000FF00000000000080FF80
00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF800000FFFFFF0000000000FF008080FFFF0000000000FFFF00FF
80800000FFFF000000000080000000FF0000FFFFFF80FFFFFF0000FF0000000000000000
00000000000000FFFF80800000FFFF000000FFFF00FFFF000080FF0080FFFFFF8080FFFF
00000000000000000000000000FFFF8080FFFFFF8000FF800000FFFF00FFFF000000FFFF
00008080FFFF000000000000000000000000000000FF0000FFFFFF80FFFFFF0000FF0000
00800000000000FFFF00008080FF00FFFF0000000000FFFF808000FF0000000000FFFFFF
000080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000080000000000000008080FF8000000000000000800080
FF80800080FF00000000FF00FF0000008080000080FF8000008080000000000000000000
000000000000000080FF808000800000000000800080000000FFFFFF8080808080FF8000
000000000000000000000000000080FF8080808080FFFFFF000000800080000000000080
008080FF8000000000000000000000000000000000008080000080FF8000008080000000
FF00FF00000000FF80008080FF8000800000000000000080FF8080000000000000008000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF80FFFF0000FF000000FF00FFFFFF000000000000FF00FF00
FF8080FFFF0080800080808000000000FFFF0000FFFFFF0000FFFF000000000000000000
00000000000000FF00FF8080FFFF00000000FF00FF00FF00000080FF00FFFF00FFFFFF00
0000000000000000000000000000FFFFFF00FFFF00FF80000000FF00FF00FF00000000FF
FF8080FF00FF00000000000000000000000000000000FFFF0000FFFFFF0000FFFF000000
0080808000808000FFFF8080FF00FF00FF000000000000FFFFFF00FF000000FF0000FFFF
80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0080FFFF8000808000FF0080FF00000000000000808080
00FFFF0080FFFF00FF00FFFF000000000080008080808080008000000000000000000000
0000000000000000808080FF8000FF0000000080808000000000FFFFFF80000000800000
0000000000000000000000000000008000000080FFFFFF0000000080808000000000FF00
80FF80808000000000000000000000000000000000000080008080808080008000000000
00FFFF00FF00FFFF8000FFFF0080808000000000000000FF8000FF0080800080FFFF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF80808080FFFF00FF008080FF000000FF000000FFFF00
FF0080FFFF0080FFFFFF80000000000000FFFF8080FF8080FFFF00000000000000000000
0000000000000000FFFF00FF808000000000FF00FFFF00000000FF8000FFFF80FFFF0000
000000000000000000000000000000FFFF80FFFF0080FF00000000FFFF00FF0000000080
80FF00FFFF000000000000000000000000000000000000FFFF8080FF8080FFFF00000000
000080FFFFFF8000FFFF8000FF00FFFF000000FF000000FF808000FF00FFFF80808080FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0080FFFFFF8080FF0000FF00808000800000
FF80FF800000FFFFFFFFFF0000000000000080FF808080FF800000000000000000000000
000000000000000000800080FF808000808000FF0080FFFF80FFFFFF000080FF80000000
0000000000000000000000000000000080FF800000FFFFFF80FFFF8000FF008080008080
FF800080000000000000000000000000000000000000000080FF808080FF800000000000
0000FFFFFFFFFF000080FF80FF00008000808000FF0000FF8080FFFFFF8000FFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800000FFFFFFFFFF00FF80FFFFFF8080FFFF0000
FF808080FFFF8000FF800000FF0000FF0000FFFFFF00FFFFFF0000000000000000000000
000000000000000000FFFF808080FF80FF80800000FFFFFFFF0080000000FFFFFF000000
00000000000000000000000000000000FFFFFF0000008000FFFFFFFF00008080FF80FF80
8080FFFF0000000000000000000000000000000000000000FFFFFF00FFFFFF0000FF0000
FF000080FF0080FFFF808080FF0000FFFF8080FFFFFF80FF00FFFFFFFFFF000080FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000080000080FFFFFF008000FFFF00800080
8080FF80808080FFFFFF0000008080000000008000000080000000000000000000000000
0000000000000000000080FF8080FF00FF8080FFFF80000080FFFF000000FF8000000000
000000000000000000000000000000000080FF000000FFFF80000080FFFF8080FF00FF80
80FF80000000000000000000000000000000000000000000008000000080000000008080
000000FFFFFF80808080FF808080008000FFFF008000FFFFFF80000080000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFF0000FFFFFFFFFF808000008080FFFF
00FFFFFF00FFFF008000000000FFFF00000000FFFF80FFFF000000000000000000000000
00000000000000FF0000FFFFFF00FF80FF00FFFFFFFF0000FFFFFFFF80FFFFFF0000FF00
0000000000000000000000000000FF0000FFFFFF80FFFFFFFF0000FFFFFFFF00FF80FF00
FFFFFF0000FF00000000000000000000000000000000000000FFFF80FFFF00000000FFFF
000000008000FFFF00FFFFFF00FFFF808000008080FFFFFFFFFF0000FFFF80FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0080FFFF8000008000FFFF0000FFFF0080
FFFFFFFFFF800000FFFF80FFFF8000000000000080FF8000000000000000000000000000
000000000000000080800000800080FF800080000080FFFF80000080FF80000080800000
0000000000000000000000000000008080000080FF80000080FFFF800000800080FF8000
800000808000000000000000000000000000000000000000000080FF8000000000000080
FFFF80FFFF000080FFFFFFFFFF8000FFFF0000FFFF0080000080FFFF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80808080FFFF808000FF80FFFFFFFF80
808080808080FFFF8000FFFFFFFF000000000000FFFFFF00000000000000000000000000
0000000000000000FFFF0000FFFF808080FFFF0000FFFFFFFF0000FFFFFF0000FFFF0000
000000000000000000000000000000FFFF0000FFFFFF0000FFFFFFFF0000FFFF808080FF
FF0000FFFF000000000000000000000000000000000000000000FFFFFF000000000000FF
FFFFFF0080FFFF80808080808080FFFFFFFF80FF008080FFFF80808080FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0080FF808000FFFFFFFFFFFF
00FFFF00FFFF0080FF80FF0080FF000000FF0000FF800000000000000000000000000000
000000000000000000800080808080FF8080808000800000800080808080800080000000
000000000000000000000000000000008000808080808000800000800080808080FF8080
80800080000000000000000000000000000000000000000000000080FF0000FF000000FF
8000FF80FF8000FFFF00FFFF00FFFFFFFFFFFF008080FF8000FFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800000FFFFFF00FF008000008000
00008000800000FFFFFF008080FF000000FF80FFFFFF0000000000000000000000000000
000000000000000000FFFF8080FF808080FF8080FFFF0000FFFF8080FF8080FFFF000000
00000000000000000000000000000000FFFF8080FF8080FFFF0000FFFF8080FF808080FF
8080FFFF0000000000000000000000000000000000000000000000FFFFFF80FF000000FF
808000FFFFFF00008000800000008000008000FF00FFFFFF000080FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000800000008080FFFF8080
008080FFFF0000008000FF00FFFFFF80FFFFFF0080000000000000000000000000000000
0000000000000000000080FF808080FF808080FF800000000080FF808080FF8000000000
000000000000000000000000000000000080FF808080FF800000000080FF808080FF8080
80FF80000000000000000000000000000000000000000000000000008000FFFFFF80FFFF
FF00FF0080000000FFFF8080008080FFFF808000000080000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFF0000FF00FFFFFFFF00
FF00FFFFFFFF80FFFF00008080808080FF0080FFFF0000000000FF000000000000000000
00000000000000000000FFFFFF00FFFFFF00FFFFFF00000000FFFFFF00FFFFFF00000000
00FF0000FF000000FF0000FF0000000000FFFFFF00FFFFFF00000000FFFFFF00FFFFFF00
FFFFFF00000000000000000000000000000000000000FF0000000000FFFF8000FF808080
80800000FFFF80FFFFFFFF00FF00FFFFFFFF00FF0000FFFF80FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0080FFFF800080000080FF
FFFF80000080FF80000000FFFF00FFFF008080FF00808000808000000000000000000000
000000000000000000000080000000800000008000000000000080000000800000000000
000080800000000000808000000000000000800000008000000000000080000000800000
0080000000000000000000000000000000000000000000808000808000FF808000FFFF00
FFFF00000080FF80000080FFFFFF800000800080FFFF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80808080FFFF0000FFFF
FFFFFF0000FFFFFF0000000080008000FF00FFFFFF8080FFFF00FF0000FF000000000000
0000000000000000000000FFFF80FFFF0000FF00FF0000000000FFFF80FFFF0000000000
0000FFFF0000FF0000FFFF00000000000000FFFF80FFFF0000000000FF00FF0000FFFF80
FFFF0000000000000000000000000000000000FF0000FF00FFFF8080FFFFFF00FF008000
8000000000FFFFFF0000FFFFFFFFFF0000FFFF80808080FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0080FFFF8000
0080FF0000008000000000FF00FF00FF008080808080FF80000000808000000000000000
00000000000000000000000080FF80000000FF80FF00000000000080FF80000000000000
00FF008000808080008000FF0000000000000080FF80000000000000FF80FF00000080FF
8000000000000000000000000000000000000000808000000080FF808080808000FF00FF
00FF0000000080000000FF80000080FFFF8000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800000FFFFFFFF00
00FFFFFF80FFFF000000FF0080808000FF00FFFF00FFFFFF000000FFFF00000000FF0000
FF00000000000000000000FF00FF808000808080FF000000FF0000FFFFFF000000FF0000
FF008080FFFF00FFFF808000FF0000FF000000FFFFFF0000FF000000FF808080008080FF
00FF00000000000000000000FF0000FF00000000FFFF000000FFFFFF00FFFF00FF008080
8000FF000000FFFF80FFFFFF0000FFFFFFFF000080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000080000080
80000080FF8000000000008080FF808000000080008000FF80FFFF80000000FF00008080
00000000000000000000FF00808080FF80FF8080FF000000008080000080FFFF80FF0000
008080FF8000000080FF8080000000FF80FFFF800000808000000000FF8080FF80FF8080
8000FF0000000000000000000080800000FF00000080FFFF80FF008000800000008080FF
8080000000000080FF8000008080000080000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFF0000FF
FF0000FFFFFF00000000FF00FFFFFF00FF0000FFFF808000FFFFFFFF000000FF80FFFF00
FF000000000000000000008080FF808080FF00FFFFFF80FFFF8080FFFF80808080FF0000
FF00FFFFFF000000FFFFFF00FF0000FF80808080FFFF8080FFFF80FFFFFF00FF808080FF
808000000000000000000000FF00FFFF80FF000000FFFFFFFF008080FFFF0000FF00FFFF
FF00FF00000000FFFFFF0000FFFF0000FFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0080FFFF80
000000008000000000000080808080800000000080FF808000FF8000000000FF80808080
00FF0000000000000000FF00FFFFFF00FFFFFF8000FF80808080FF8000FFFF00FFFFFF80
FF000080FF000000FF800000FF80FFFFFF00FFFF0080FF80808080FF0080FFFFFF00FFFF
FF00FF0000000000000000FF0080808080FF0000000080FF008080FF8000000000808080
8080000000000000800000000080FFFF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80808080
FFFF80FFFF000000000000FFFF00FFFF000000FF00FF8080FFFFFF00000000FF8080FF80
80000000000000000000008080808080000080FF80FF00FFFF00FF808000008080808080
FF0000FFFFFF80FFFFFF0000FF808080808000008080FF00FFFF00FF80FF800000808080
8080000000000000000000008080FF8080FF00000000FFFFFF8080FF00FF000000FFFF00
FFFF000000000000FFFF80FFFF80808080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
0080FF80000000000000FF008000800000000000808080FF8000FF80FFFF80FF00FFFFFF
00FF000000000000000000FFFF00FFFF0000FFFFFF008080808000FFFF0000FFFF00FFFF
008080000080FF800000808000FFFF00FFFF0000FFFF008080808000FFFFFF0000FFFF00
FFFF000000000000000000FF00FFFFFF00FF80FFFF80FF0080FF80808000000000008000
8000FF00000000000080FF8000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
00FFFFFF0000000000FF008080FFFF0000000000FFFF00FF808000FFFFFFFF0080808080
80000000000000000000000080008000FF0000800000FFFF00FFFF800000000080008000
00FFFF0000FFFFFF0000FFFF00008000800000000080FFFF00FFFF0000800000FF008000
800000000000000000000000808080808000FFFFFFFF008080FF00FFFF0000000000FFFF
808000FF0000000000FFFFFF000080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000080000000000000008080FF8000000000000000800080FF808000FF800000FFFF00FF
FF0000000000000000000000FFFF80800000FF00FF000080FFFFFFFF000000FF00FF00FF
00008000808080808000800000FF00FF00FF000000FFFFFFFF800000FF00FF00008080FF
FF0000000000000000000000FFFF00FFFF000080FF008080FF8000800000000000000080
FF80800000000000000080000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
80FFFF0000FF000000FF00FFFFFF000000000000FF00FF00FF8080FFFFFF000000800080
0000000000000000000000000080FF808000800080008080FF008000FF00000080808000
0000FFFF8080FF8080FFFF000000808080000000FF008000FF808000800080008080FF80
00000000000000000000000000800080000000FFFFFF8080FF00FF00FF000000000000FF
FFFF00FF000000FF0000FFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0080FFFF8000808000FF0080FF0000000000000080808000FFFF0080000000FF00FF00
FF000000000000000000000000FFFFFF00FF00FF00FF00FFFFFF808000FF0000FFFF00FF
00000080FF808080FF80000000FF00FFFF0000FF008080FFFFFF00FF00FF00FF00FFFFFF
000000000000000000000000FF00FF00FF0000008000FFFF0080808000000000000000FF
8000FF0080800080FFFF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF80808080FFFF00FF008080FF000000FF000000FFFF00FF0080FFFF00000000808080
00000000000000000000000000008000000080808000000080FF00FFFF80008080808000
000000FFFFFF00FFFFFF00000000808080800080FFFF00FF800000008080800000008000
0000000000000000000000000080808000000000FFFF8000FF00FFFF000000FF000000FF
808000FF00FFFF80808080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFF0080FFFFFF8080FF0000FF00808000800000FF80FF800000FF0000FFFF00
FF00000000000000000000000000FFFF80FFFF00FFFF80FFFF0080808080FFFF00FFFF00
0000000080000000800000000000FFFF00FFFF8080808000FFFF80FFFF00FFFF80FFFF00
000000000000000000000000FF00FFFF0000FF000080FF80FF00008000808000FF0000FF
8080FFFFFF8000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF800000FFFFFFFFFF00FF80FFFFFF8080FFFF0000FF808080FFFF800080808080
00FF0000FF0000000000000000000080FF8000000080FF800000FFFF00FFFFFFFF800000
00000000FFFF80FFFF00000000000080FFFFFFFF00FFFF000080FF8000000080FF800000
0000000000000000FF0000FF00808080800080FFFF808080FF0000FFFF8080FFFFFF80FF
00FFFFFFFFFF000080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000080000080FFFFFF008000FFFF008000808080FF80808080FFFF00FFFF
000080800000000000000000000000FFFFFF000000FFFFFF00000080FFFFFFFFFFFF0000
000000000080FF8000000000000000FFFFFFFFFFFF80000000FFFFFF000000FFFFFF0000
00000000000000000080800000FFFF00FFFF80808080FF808080008000FFFF008000FFFF
FF80000080000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF80FFFF0000FFFFFFFFFF808000008080FFFF00FFFFFF00FFFF00800080FF
0000FFFF00000000000000000000000080000000000080000000FF00FF8000FF80000000
0000000000FFFFFF000000000000000080FF0080FF00FF00000080000000000080000000
000000000000000000FFFF0000FF80008000FFFF00FFFFFF00FFFF808000008080FFFFFF
FFFF0000FFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0080FFFF8000008000FFFF0000FFFF0080FFFFFFFFFF800000FFFF8080
800080000000000000000000000000FF00FF000000FF00FF000000808080FFFFFF000000
00000000FF008000FF00000000000000FFFFFF808080000000FF00FF000000FF00FF0000
000000000000000000008000808080FFFF000080FFFFFFFFFF8000FFFF0000FFFF008000
0080FFFF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF80808080FFFF808000FF80FFFFFFFF80808080808080FFFF8000FFFF
00FF00FF0000000000000000000000008080800080808000000000FFFF00FF800000FF00
00FF0000FF80FF80FF0000FF0000FF000080FF00FFFF0000000080808000808080000000
000000000000000000FF00FF00FFFF0080FFFF80808080808080FFFFFFFF80FF008080FF
FF80808080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF0080FF808000FFFFFFFFFFFF00FFFF00FFFF0080FF80FF00
80808000FF0000000000000000000000FFFF00FF00FFFF000000000080FFFFFF00000080
80000000FF808080FF0000008080000000FFFFFF800000000000FFFF00FF00FFFF000000
0000000000000000FF0080808000FF80FF8000FFFF00FFFF00FFFFFFFFFFFF008080FF80
00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF800000FFFFFF00FF00800000800000008000800000FFFFFF0080
80FF80800000000000000000000000000080FFFFFF8000FF000000FF00FF80000000FF00
FFFF80FFFFFF00FFFFFF80FFFF00FF00000080FF00FF000000FF0080FFFFFF8000000000
0000000000000000008080FF808000FFFFFF00008000800000008000008000FF00FFFFFF
000080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000800000008080FFFF8080008080FFFF0000008000FF00
FFFFFF00FF000000000000000000000000FFFFFFFFFF000080800080FFFFFF0000000080
808080FF0080008000FF8080808000000000FFFFFF800080800000FFFFFFFFFF00000000
0000000000000000FF00FFFFFF00FF0080000000FFFF8080008080FFFF80800000008000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF80FFFF0000FF00FFFFFFFF00FF00FFFFFFFF80FFFF000080
80808080000000000000000000000000000080FF0080FFFF8080FFFF008000FF0000FF00
FFFF00FF80FF80FF80FF00FFFF00FF0000FF008000FFFF8080FFFF8000FF800000000000
00000000000000000080808080800000FFFF80FFFFFFFF00FF00FFFFFFFF00FF0000FFFF
80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0080FFFF800080000080FFFFFF80000080FF80000000FF
FF00FFFF0000000000000000000000000000FFFFFF80808080FF800000FFFF8000808080
0000808080FF00FF80808000008080800080FFFF000080FF80808080FFFFFF0000000000
000000000000000000FFFF00FFFF00000080FF80000080FFFFFF800000800080FFFF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF80808080FFFF0000FFFFFFFFFF0000FFFFFF00000000
80008000000000000000FF0000FF000000000080FF00FFFF00FF80800080FF00FF00FFFF
0000FFFF00FF80FF00FFFF0000FFFF00FF00FF80008080FF00FFFF00FF800000000000FF
0000FF0000000000000080008000000000FFFFFF0000FFFFFFFFFF0000FFFF80808080FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0080FFFF80000080FF0000008000000000FF
00FF00FF00000000000000808000FF000000FF00FF80FF00808080FF80FF800080008000
000000800080FF800080000000008000800080FF80FF80808000FF80FF00FF000000FF00
808000000000000000FF00FF00FF0000000080000000FF80000080FFFF8000FFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800000FFFFFFFF0000FFFFFF80FFFF000000FF00
80808000FF000000000000FFFF000080800080FFFFFF008080FF808080FF00FF00FF00FF
000000FFFF808080FFFF000000FF00FF00FF00FF808080FF808000FFFFFF800080800000
FFFF000000000000FF0080808000FF000000FFFF80FFFFFF0000FFFFFFFF000080FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000008000008080000080FF80000000000080
80FF8080000000000000000080008080FF80FF8000FF80FF808080FF8080800000008080
800080808080FF8080808000808080000000808080FF808080FF80FF0080FF80FF808000
8000000000000000008080FF8080000000000080FF8000008080000080000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFF0000FFFF0000FFFFFF00000000FF00
FFFFFF00FF00000000000000FFFF8080FF00FF808000FFFFFF00FFFFFF00FFFF80FFFF00
FFFF8080FF808080FF8080FFFF00FFFF80FFFF00FFFFFF00FFFFFF008080FF00FF8080FF
FF00000000000000FF00FFFFFF00FF00000000FFFFFF0000FFFF0000FFFF80FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0080FFFF80000000008000000000000080
8080808000000000000000000080FF80808000FFFF0000800000008000000080FF800000
0080FF808080FF808080FF8000000080FF8000000080000000800000FFFF00808080FF80
0000000000000000008080808080000000000000800000000080FFFF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80808080FFFF80FFFF000000000000FF
FF00FFFF000000000000FF0000FFFFFF00FFFF80000000FFFF80FFFF000000FFFFFF0000
00FFFFFF00FFFFFF00FFFFFF000000FFFFFF000000FFFF80FFFF00000080FFFF00FFFFFF
0000FF000000000000FFFF00FFFF000000000000FFFF80FFFF80808080FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0080FF80000000000000FF00
800080000000000000000080800000800080FF00FF00000080FF80000000000080FF0000
00FF800000008000000080FF000000FF80000000000080FF80000000FF00FF8000800000
8080000000000000000080008000FF00000000000080FF8000FFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800000FFFFFF0000000000FF0080
80FFFF0000000000000000FFFF0000FFFF80808000FF0000FFFFFF0000FF0000FFFFFF80
FFFFFF0000FF00FF0000FFFFFF80FFFFFF0000FF0000FFFFFF0000FF00808080FFFF0000
FFFF0000000000000000FFFF808000FF0000000000FFFFFF000080FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000080000000000000008080
FF8000000000000000000000800080808080FF80800000000080000000008080000080FF
80000080800000008080000080FF80000080800000000080000000008080FF8080808000
800000000000000000000080FF80800000000000000080000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFF0000FF000000FF00FF
FFFF000000000000FF0000FF00FF00FFFF00FF8080FFFF80FFFF00000000FFFF0000FFFF
FF0000FFFF000000FFFF0000FFFFFF0000FFFF00000000FFFF80FFFF8080FF00FFFF00FF
00FF0000FF000000000000FFFFFF00FF000000FF0000FFFF80FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0080FFFF8000808000FF00
80FF0000000000000080800000008080808000FFFF0080FF800000000000008000808080
80800080000000000080008080808080008000000000000080FF8000FFFF008080808000
0000808000000000000000FF8000FF0080800080FFFF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80808080FFFF00FF0080
80FF000000FF000000FFFF000000FFFF00FFFF800000FFFFFF000000000000FFFF8080FF
8080FFFF0000000000FFFF8080FF8080FFFF000000000000FFFFFF000080FFFF00FFFF00
0000FFFF000000FF000000FF808000FF00FFFF80808080FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0080FFFFFF80
80FF0000FF00808000800000FF000080FFFFFFFF0000FF80000000000000000080FF8080
80FF800000000000000080FF808080FF80000000000000000080FF0000FFFFFFFF800000
FF00008000808000FF0000FF8080FFFFFF8000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800000FFFFFFFFFF
00FF80FFFFFF8080FFFF0000FF80FFFF008000FF80FFFFFF0000000000000000FFFFFF00
FFFFFF00000000000000FFFFFF00FFFFFF0000000000000000FFFFFF80FF008000FFFF80
FF0000FFFF8080FFFFFF80FF00FFFFFFFFFF000080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000080000080
FFFFFF008000FFFF008000808080FF008080FFFFFF008000000000000000000000800000
00800000000000000000008000000080000000000000000000008000FFFFFF808000FF80
8080008000FFFF008000FFFFFF80000080000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFF0000FF
FFFFFFFF808000008080FFFF00FFFFFF8080FF0080FFFF00000000000000000000FFFF80
FFFF000000000000000000FFFF80FFFF00000000000000000000FFFF8000FF8080FFFFFF
00FFFF808000008080FFFFFFFFFF0000FFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0080FFFF80
00008000FFFF0000FFFF0080FFFFFFFFFF00FF80FF8000000000000000000000000080FF
80000000000000000000000080FF8000000000000000000000000080FF80FF00FFFFFFFF
FF8000FFFF0000FFFF0080000080FFFF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80808080
FFFF808000FF80FFFFFFFF8080808080808000FFFFFF000000000000000000000000FFFF
FF0000000000000000000000FFFFFF000000000000000000000000FFFFFF008080808080
8080FFFFFFFF80FF008080FFFF80808080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
0080FF808000FFFFFFFFFFFF00FFFF00FFFF000080000000000000000000000000FF0080
FF0000000000000000000000FF8000FF000000000000000000000000800000FFFF00FFFF
00FFFFFFFFFFFF008080FF8000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
00FFFFFF00FF00800000800000008000800000FF00FF00000000FF000000000000008080
FF0000FF0000000000FF0000FF808000000000000000FF00000000FF00FF000080008000
00008000008000FF00FFFFFF000080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000800000008080FFFF8080008080FFFF0000008080800080800000FF0000FF0000FFFF
00808000000000000000808000FFFF0000FF0000FF0000808000808080000000FFFF8080
008080FFFF808000000080000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
80FFFF0000FF00FFFFFFFF00FF00FFFFFFFF80FFFF00FFFF8080FFFF8000808080008000
00FFFF00000000000000FFFF000080008080800080FFFF8080FFFF00FFFF80FFFFFFFF00
FF00FFFFFFFF00FF0000FFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0080FFFF800080000080FFFFFF80000080FF8000000080FF80808080FFFF00FFFF8080
008000000000000000000080008080FFFF00FFFF80808080FF8000000080FF80000080FF
FFFF800000800080FFFF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF80808080FFFF0000FFFFFFFFFF0000FFFFFF000000FFFFFF00FFFF0080FFFFFFFF00
FF00FF00000000000000FF00FF00FFFFFFFF8000FFFF00FFFFFF000000FFFFFF0000FFFF
FFFFFF0000FFFF80808080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFF0080FFFF80000080FF0000008000000000008000000080FFFF0080000080
808000000000000000000080808000008000FFFF8000000080000000000080000000FF80
000080FFFF8000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF800000FFFFFFFF0000FFFFFF80FFFF0000000000FFFF80FFFF0080FFFF0000FF
FF00FF00000000000000FF00FFFF0000FFFF8000FFFF80FFFF0000000000FFFF80FFFFFF
0000FFFFFFFF000080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000008000008080000080FF800000000000000080FF8000FF00FF80008080
8080000000000000000000808080800080FF00FF0080FF800000000000000080FF800000
8080000080000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF80FFFF0000FFFF0000FFFFFF00000000000000FFFFFF0000808080FFFF00
FFFF000000000000000000FFFF00FFFF8080800000FFFFFF00000000000000FFFFFF0000
FFFF0000FFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0080FFFF80000000008000000000000000000080FF0000FFFF00FF8000
800000000000000000000000800080FF00FFFF0000FF8000000000000000000080000000
0080FFFF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF80808080FFFF80FFFF000000000000000000FFFFFF80FF00808080FF
FF0000000000000000000000FFFF80808000FF80FFFFFF000000000000000000FFFF80FF
FF80808080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF0080FF80000000000000000000FF008000FFFFFF8080FF80
00FF000000000000000000FF0080FF8080FFFFFF008000FF00000000000000000080FF80
00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF800000FFFFFF000000000000000000008080FFFFFFFFFF00FF80
8000000000000000000000008080FF00FFFFFFFFFF808000000000000000000000FFFFFF
000080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000080000000000000FF00000000FFFF0080000080FFFFFF
00FF000000000000000000FF00FFFFFF8000008000FFFF00000000FF0000000000008000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF80FFFF0000FF000000FF80FFFF80FF008080FFFF80808080
8000000000000000000000008080808080FFFF808000FF80FFFF80FF000000FF0000FFFF
80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0080FFFF8000808000FFFFFFFF008080FF8000FFFF00FF
FF0000000000000000000000FFFF00FFFF0080FF808000FFFFFFFF0080800080FFFF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF80808080FFFF00FF008000FF80FF808080FFFFFFFF80
0000000000000000000000000080FFFFFFFF808080FF80FF008000FF00FFFF80808080FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0080FFFFFF808000FFFFFF00FFFFFFFFFFFF
00000000000000000000000000FFFFFFFFFFFF00FFFFFF008080FFFFFF8000FFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800000FFFFFFFFFF00FF00800000008000008000
FF0000000000000000000000FF00800000800000008000FF00FFFFFFFFFF000080FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000080000080FFFFFF8080008080FFFF8080
000000000000000000000000008080FFFF8080008080FFFFFF80000080000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFF0000FFFFFFFFFF00FF00FFFFFFFF00
FF0000000000000000000000FF00FFFFFFFF00FF00FFFFFFFFFF0000FFFF80FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0080FFFF8000008000FF00808080808080
0000000000000000000000000080808080808000FF0080000080FFFF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80808080FFFF808000FF00FFFF00FFFF
00000000000000000000000000FFFF00FFFF00FF008080FFFF80808080FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0080FF808000FF0080008000
000000000000000000000000000080008000FF008080FF8000FFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800000FFFFFF00FF008080FFFF00
0000000000000000000000000000FFFF808000FF00FFFFFF000080FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000800000008080FF800000
00000000000000000000000000000080FF808000000080000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFF0000FF00FFFFFF0000
FF0000000000000000000000FF0000FFFFFF00FF0000FFFF80FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0080FFFF80008000008080
0000000000000000000000000080800000800080FFFF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80808080FFFF0000FFFF
00000000000000000000000000FFFF0000FFFF80808080FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0080FFFF8000
000000000000000000000000000080FFFF8000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800000FFFFFFFF00
00000000FF000000FF0000000000FFFFFFFF000080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000080FF0080
800080800000FF0000808000808000FF80000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFF008080
FF80FF80800080008080FF80FF808000FFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0080FFFF00
FF808080FF80FF80FF808080FF00FFFF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80808080
00FFFF00FF808080FF00FFFF0080808080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
000080FFFFFF00FFFFFF800000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
00FF00FF8000FF0080FF00FF000080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000808080FFFFFF808080000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
80FFFF00FFFFFFFFFF00FFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0080FFFFFFFFFFFFFF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF808080808080808080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000000080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{350.563, 174.625},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005N0000[R000`400?l00000o`00003oo`3AcJUO
0=7=Z@00o`3AcJUO0=7=Z@00o`3AcJUO0=7=Z@00o`3AcJUO0=7=Z@001`3AcJT00`3oool000000820
P0030?ooo`080820P0000000P8200820P0000000oooo00000020P8020?ooo`L000001020P8001@00
0000oooo0?ooo`000000P82000<0oooo00<000000?ooo`0000000P0000020820P0@0000000D0P820
0?ooo`3oool0oooo0820P00@000000<0oooo0`0000040?ooo`H000000P3oool01P000000oooo0?oo
o`3oool000000?ooo`@0000000<0P8200?ooo`20P8000`0000001020P800oooo0?ooo`20P8050000
0080oooo0`0000030?ooo`030000003oool0oooo00<0oooo0P20P802000000030820P00000000000
00@0P82000@000000820P0000000P8203`0000001020P800oooo0820P00000030?ooo`030000003o
ool0oooo0080oooo0`0000040?ooo`080000003oool0oooo0?ooo`000000P8200?ooo`20P80?0000
00040820P0000000P820000000@0P8200P0000000`20P8000000000000020820P0D0oooo00@00000
0?ooo`3oool0oooo0`0000020?ooo`D0000000@0P8200?ooo`3oool0P8200`0000000`20P800oooo
0820P004000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool01P0000040?ooo`<00000
0`3oool@000000050820P03oool0oooo0?ooo`20P800100000020820P0<0000000<0oooo00000000
00000P3oool01@20P80000000?ooo`3oool0000000@0P8201`0000020?ooo`040820P0000000oooo
00000080P82000<000000820P03oool00P3oool00`20P80000000?ooo`080=7=Z@001`3AcJT20?oo
o`D0P8200P3oool00`000000oooo000000020820P080oooo0`000000103oool00000000000000003
0?ooo`040000003oool000000820P080oooo00<000000820P020P8000`3oool01@20P800oooo0?oo
o`000000oooo00<000001@3ooolA000000030820P0000000000000@0000000<0P820000000000000
1`0000050820P0D000000`3oool3000000@0oooo1P0000001@20P800oooo0?ooo`3oool0P8200080
00001`20P800103oool0P8200?ooo`3oool2000000<0oooo00H000000?ooo`000000oooo0000003o
ool>000000<0oooo0P0000000`20P800000000000002000000030820P0000000000000<0000000<0
P8200000000000000P0000000`20P8000000000000030?ooo`h0000000H0oooo0000003oool00000
0?ooo`0000030?ooo`8000000P3oool00`20P800oooo0820P0060820P080000000D0P8200?ooo`3o
ool0oooo0820P006000000@0oooo0`0000030?ooo`D000001@20P809000000030820P00000000000
00@0000000<0P8200000000000003`0000050?ooo`<0000000D0oooo0000003oool0oooo0820P004
0?ooo`080820P0000000oooo0?ooo`20P80000000?ooo`0000030?ooo`<0000000@0oooo00000000
000000000P3oool20820P0030000003oool000000080oooo1@20P8020?ooo`P0dLfY00070=7=Z@<0
oooo00H000000?ooo`3oool0oooo00000020P8030?ooo`80P8200P3oool2000000060?ooo`000000
P8200820P0000000P8200`000000103oool0P8200?ooo`20P802000000H0oooo00@000000820P000
0000P8200`3oool01P20P800000000000020P80000000?ooo`l0000000<0oooo0000003oool00`00
00020?ooo`030000003oool0000000L000000P3oool00`000000oooo0?ooo`06000000030820P03o
ool000000080000000<0oooo0820P020P8001`0000050?ooo`8000000P3oool01P000000oooo0?oo
o`3oool000000?ooo`@0P82000H000000820P000000000000?ooo`0000030820P0030000003oool0
000000H0000000@0oooo000000000000oooo0`0000001020P80000000000000000020?ooo`040820
P03oool0oooo0?ooo`D000000`3oool00`20P800oooo0?ooo`03000000050820P000000000000000
003oool00P0000000`3oool0000000000005000000030?ooo`000000P8200080P82000H000000?oo
o`00000000000820P00000040820P0030?ooo`000000oooo0080oooo00<000000?ooo`3oool00P00
00050?ooo`L000000P20P8001P3oool00000000000000000oooo0820P0H000000P3oool00`000000
oooo0?ooo`08000000040?ooo`000000oooo0?ooo`<0000000<0oooo0000003oool03`0000000`3o
ool000000820P002000000080820P03oool0oooo0?ooo`20P80000000820P00000060?ooo`800000
00@0P8200?ooo`20P800oooo0`0000001P20P80000000820P020P80000000?ooo`8000000P3oool2
0820P0<0oooo00<0P8200000003oool00P3oool010000000oooo0?ooo`3oool80=7=Z@001`3AcJT4
0?ooo`80P8200P0000050?ooo`040000003oool0oooo0820P0<0oooo0P20P8020?ooo`<0000000@0
oooo0820P020P800P8200P3oool20820P0030000003oool0P820008000000P3oool50820P080oooo
0P20P80A000000<0P82000<000000820P020P8000P20P80:000000030820P0000000P82000<00000
00@0oooo00000000000000000`3oool00`20P800oooo0?ooo`020?ooo`80000000<0oooo00000000
00000`0000020820P0080?ooo`000000P8200820P0000000oooo0820P03oool2000000<0P82000<0
oooo0820P020P8000P3oool300000080P82000<0oooo0820P020P8002@0000020820P0<0000000<0
oooo0000003oool00`0000001020P800oooo0820P020P80700000080P82000<0oooo0820P0000000
0P0000000`3oool000000?ooo`0300000080P8202@0000020820P0030?ooo`20P800P82000<00000
0P3oool20820P0040?ooo`20P800P8200820P080000000@0oooo0820P03oool000000P20P8001000
0000oooo0820P020P805000000030?ooo`000000000000@0oooo00@0P8200?ooo`3oool0oooo0`00
00001`3oool00000000000000000P82000000020P8002P0000040820P00400000020P800P8200820
P14000000P20P8020?ooo`D0P8200P3oool2000000050820P03oool0000000000020P8000P3oool3
0820P0040?ooo`000000000000000080oooo0P20P8030?ooo`040820P03oool0oooo000000D0oooo
0P0000020820P0@0oooo203AcJT000L0dLfY1P3oool3000000040820P000000000000820P0@0oooo
00<000000820P00000000P3oool010000000P8200000000000030820P0030?ooo`20P800P82000<0
P8200`3oool3000000030820P03oool0P8200080P82000<0oooo0820P00000000P3oool200000080
oooo3@0000020?ooo`030000003oool0000000<0oooo2@0000001@3oool000000?ooo`000000oooo
00<000000`20P802000000030820P03oool0P82000<000000P20P806000000@0oooo0P20P8030?oo
o`0500000020P800P8200820P03oool00`20P8000`3oool0P82000000002000000030?ooo`000000
oooo0080oooo00<000000?ooo`0000001`0000020?ooo`<0000000<0oooo0820P03oool00`000004
0?ooo`L00000103oool3000000030?ooo`20P800oooo00<000000P3oool8000000030?ooo`000000
oooo0080oooo00<000000?ooo`0000000P0000000`20P800oooo0820P0020820P0050?ooo`20P800
P8200820P00000000`3oool20820P0@0oooo1P0000020820P0<0000000<0P8200?ooo`20P8000P00
00030820P0<0000000D0oooo0000003oool000000?ooo`09000000<0oooo00<000000?ooo`000000
0P3oool=00000080oooo0P0000020?ooo`0300000020P800oooo00<0P82000<0oooo0820P0000000
0P0000040?ooo`@0P82000@0oooo0820P020P800P8200P0000001`20P80000000?ooo`3oool00000
0820P0000000103oool01020P800000000000020P803000000H0oooo203AcJT000L0dLfY1P3oool3
000000040820P000000000000820P0@0oooo00<000000820P00000000P3oool010000000P8200000
000000030820P0030?ooo`20P800P82000<0P8200`3oool3000000030820P03oool0P8200080P820
00<0oooo0820P00000000P3oool200000080oooo3@0000020?ooo`030000003oool0000000<0oooo
2@0000001@3oool000000?ooo`000000oooo00<000000`20P802000000030820P03oool0P82000<0
00000P20P806000000@0oooo0P20P8030?ooo`0500000020P800P8200820P03oool00`20P8000`3o
ool0P82000000002000000030?ooo`000000oooo0080oooo00<000000?ooo`0000001`0000020?oo
o`<0000000<0oooo0820P03oool00`0000040?ooo`L00000103oool3000000030?ooo`20P800oooo
00<000000P3oool8000000030?ooo`000000oooo0080oooo00<000000?ooo`0000000P0000000`20
P800oooo0820P0020820P0050?ooo`20P800P8200820P00000000`3oool20820P0@0oooo1P000002
0820P0<0000000<0P8200?ooo`20P8000P0000030820P0<0000000D0oooo0000003oool000000?oo
o`09000000<0oooo00<000000?ooo`0000000P3oool=00000080oooo0P0000020?ooo`0300000020
P800oooo00<0P82000<0oooo0820P00000000P0000040?ooo`@0P82000@0oooo0820P020P800P820
0P0000001`20P80000000?ooo`3oool000000820P0000000103oool01020P800000000000020P803
000000H0oooo203AcJT000L0dLfY1`3oool00`20P800oooo0?ooo`02000000H0oooo0P20P8020000
0080P8200`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000820P00000000`000004
0?ooo`040000003oool0P8200820P08000000P20P80@000000040820P03oool0oooo0?ooo`80P820
200000020?ooo`0600000020P800P8200820P0000000oooo0P0000030?ooo`8000000`3oool30000
0080oooo1@0000001@3oool0000000000020P80000000080oooo00@000000820P0000000oooo0P00
00030?ooo`040000003oool0oooo0?ooo`@000001@20P808000000040?ooo`000000P820000000@0
P82000H0oooo00000000000000000?ooo`20P80;000000030820P03oool000000080000000<0oooo
0820P020P8000P20P80010000000P8200000003oool8000000D0P820100000030?ooo`040000003o
ool0oooo0?ooo`80000000@0oooo00000020P80000000P3oool01@000000P820000000000000oooo
00D000000P3oool3000000<0oooo0P0000030?ooo`80000000<0oooo00000020P8000P20P8000`00
0000oooo0?ooo`0800000080P8200`3oool00`20P80000000000000>00000080P8200P0000020820
P0030?ooo`000000oooo00<0oooo100000000`20P8000000000000020?ooo`050000003oool0oooo
0?ooo`0000000`3oool20820P08000000P20P8060?ooo`8000000P3oool00`20P800oooo0?ooo`05
0?ooo`P0dLfY00070=7=Z@P0oooo00D000000820P03oool0oooo0820P003000000040820P0000000
oooo0?ooo`8000000P3oool2000000030820P03oool0oooo00<0oooo00@0P8200000000000000000
0P3oool01020P800oooo0?ooo`20P803000000<0P82000D0oooo0820P03oool0oooo000000020?oo
o`/0000000<0oooo0000000000001P3oool2000000030?ooo`000000000000D000000P20P8000`3o
ool0P8200820P005000000030820P0000000P82000@0P8200P0000000`20P8000000000000050000
00<0P820103oool20820P0@0000000D0P82000000000000000000820P00500000080oooo00<00000
0?ooo`3oool01`000000103oool000000820P020P8030?ooo`050000003oool0oooo0?ooo`20P800
0`3oool3000000050?ooo`00000000000000003oool00`0000030?ooo`050820P03oool0oooo0?oo
o`0000000`3oool20820P0030000003oool0000000H000000P3oool00`000000oooo0?ooo`050000
00050820P0000000000000000020P800100000020820P0@0oooo0`20P807000000030820P0000000
000000D0P82000<000000820P0000000100000020820P0030?ooo`20P800P82000L0000000<0oooo
0000000000001P3oool2000000030?ooo`000000000000T000000P3oool01@000000oooo0?ooo`20
P800oooo00<0P8200`0000001020P800oooo0?ooo`20P8020?ooo`<0000000<0P8200?ooo`3oool0
0`3oool00`20P8000000000000020?ooo`8000000P3oool00`000000P82000000002000000050820
P03oool0oooo0820P0000000203oool80=7=Z@001`3AcJT90?ooo`@0P8200`3oool20820P0030000
003oool0P82000D0oooo1`20P8030?ooo`030820P0000000oooo00<0oooo0`0000020?ooo`030000
003oool0P82000<0P8203P0000020820P080000000@0P82000000000000000000P20P8000`000000
oooo0000000300000080oooo00H000000?ooo`3oool0oooo0000003oool400000080oooo0P20P800
0`3oool0P8200820P0030?ooo`H0000000<0oooo0000000000001P3oool00`000000oooo00000002
00000080oooo00<0P8200?ooo`3oool01P0000001@20P80000000820P0000000oooo00<0000000H0
oooo000000000000oooo0820P03oool50820P080000000<0P8200?ooo`20P8000P0000030820P0D0
00000`20P802000000030820P03oool0P820008000001@20P8000`3oool0P8200?ooo`0200000009
0?ooo`00000000000000003oool000000820P0000000P82000H000000P3oool00`20P800oooo0?oo
o`03000000030?ooo`000000oooo00D0oooo0P0000000`3oool0000000000004000000<0oooo0P20
P8000`3oool0P8200820P0020?ooo`@0000000<0oooo0000003oool00P3oool00`000000oooo0?oo
o`04000000040?ooo`000000P8200820P0<0000000<0P8200000000000000P20P80>000000@0P820
00@0oooo0000003oool0oooo0`0000040?ooo`0300000020P800oooo0080oooo1`20P8050?ooo`03
0820P03oool000000080P8200`3oool40820P0T0oooo203AcJT000L0dLfY2P3oool010000000oooo
0?ooo`0000020820P0040?ooo`20P800P820000000L0oooo00@000000?ooo`3oool000000P3oool2
000000070820P03oool0P8200?ooo`000000P8200?ooo`04000000050820P03oool0oooo0?ooo`00
00000P3oool>00000080oooo0P0000020?ooo`80P82000<0oooo0820P020P8000`000000103oool0
00000000000000050820P0030000003oool0000000<0000000<0P8200?ooo`20P8000P20P8000`3o
ool0P8200820P008000000T0P8201@0000000`20P800oooo0820P00300000080oooo0P0000020?oo
o`80P8201@0000020820P0050000003oool0oooo0?ooo`0000000`3oool2000000<0oooo0P000003
0?ooo`D000000`3oool2000000<0oooo0P0000030?ooo`050000003oool0oooo0?ooo`0000000P20
P80500000080P8200P3oool200000080oooo0`0000000`20P800oooo0820P005000000T0P8202000
00020820P0060?ooo`20P800P8200820P03oool0P820100000000`3oool000000820P0040820P0<0
000000@0oooo00000000000000000P20P8000`3oool0P8200820P0020?ooo`8000000P3oool>0000
0080oooo00D000000?ooo`3oool0oooo0820P004000000060?ooo`20P80000000?ooo`20P800oooo
0P20P80010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0oooo00@000000820P020
P800oooo0P20P80010000000oooo0?ooo`00000:0?ooo`P0dLfY00070=7=Z@/0oooo00<0P8200000
00000000103oool010000000oooo00000020P80200000080P8200`0000000`20P80000000820P003
000000<0oooo00@000000820P020P800oooo100000050?ooo`030820P0000000000000h0000000<0
P82000000020P8001020P8001@3oool000000?ooo`3oool0P82000<0oooo0P20P800103oool0P820
0820P03oool20820P0D000000`3oool00`000000oooo0?ooo`020?ooo`P000000`3oool010000000
oooo0?ooo`0000020?ooo`D000000`3oool300000080oooo00<0P8200?ooo`3oool00P3oool00`00
0000oooo0000000300000080oooo0P0000000`20P80000000?ooo`02000000030820P0000000P820
00@0P82000<000000820P020P8001`0000020820P00300000020P800P82000<0P82000L000000820
P000000000000?ooo`000000P820008000000P3oool4000000030?ooo`000000oooo00<0oooo00<0
P8200?ooo`3oool00`0000030?ooo`D000000P3oool010000000oooo0?ooo`0000030?ooo`P00000
103oool010000000oooo0?ooo`3oool500000080P82000@0oooo0820P020P800oooo0P20P8030?oo
o`050820P03oool0oooo0000003oool01@20P8000`000000P8200000000?000000030820P03oool0
oooo00<0oooo10000000103oool0P8200820P00000040?ooo`80000000<0P82000000020P8000`00
00020820P080000000@0P8200000003oool00000103oool2000000030820P03oool0oooo00T0oooo
203AcJT000L0dLfY303oool4000000040820P0000000000000000080P8200P3oool30820P0030000
0020P800P8200080oooo100000001020P80000000?ooo`0000030?ooo`80P8201`3oool@00000080
oooo0P20P8000`3oool0P8200820P0020820P0030000003oool0P82000D0P82000<0oooo0000003o
ool00P3oool00`000000oooo00000004000000050820P0000000000000000020P800300000000`20
P800oooo0?ooo`020?ooo`030820P0000000000000D0000000<0P8200?ooo`0000000P0000020?oo
o`H0P8200P0000020?ooo`80000000<0P8200?ooo`3oool00P20P80300000080oooo0P20P8000`3o
ool0P8200820P0030?ooo`L000000`3oool20820P0030?ooo`20P800P8200080oooo0`0000020820
P080oooo00<0P8200000000000000P3oool2000000H0P8200P3oool3000000030?ooo`20P8000000
00H0000000<0P8200?ooo`3oool00P3oool00`20P80000000000000:000000050820P00000000000
00000020P8001@0000000`3oool000000?ooo`020?ooo`030000003oool0P82000D0P82000<0oooo
00000020P8000`20P8000`3oool0P8200820P0020?oooa0000001`3oool20820P0<0oooo00@00000
0?ooo`000000P820100000020?ooo`80P82000@000000820P020P800P8200P3oool20820P0<00000
00<0P8200000000000000P00000<0?ooo`P0dLfY00070=7=Z@d0oooo00@0P8200?ooo`3oool0oooo
0P0000000`3oool000000?ooo`040?ooo`030000003oool0000000@0oooo0P20P8020?ooo`800000
1P20P8000`3oool000000820P002000000030820P0000000oooo0100000000<0P8200?ooo`20P800
0`20P800103oool0P8200820P00000020?ooo`050000003oool0oooo0?ooo`0000001@20P8060000
0080oooo00<0P8200?ooo`3oool0300000060?ooo`L000000`3oool00`20P800oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00<0P8200?ooo`3oool00P0000040?ooo`030000003oool0
00000080000000<0P8200?ooo`20P8000P20P8000`3oool0P8200000000:000000030820P03oool0
P8200080P82000<0oooo0820P00000000P0000000`3oool000000?ooo`030?ooo`8000000P3oool0
1020P800oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00@0P8200?ooo`3oool0oooo
1`0000060?ooo``000000P3oool00`20P800oooo0?ooo`06000000D0P82000D000000?ooo`3oool0
oooo000000020?ooo`0400000020P800P8200?ooo`@0P82000<0oooo0820P00000003`0000000`3o
ool000000820P002000000030820P0000000oooo00H0P8200P0000030?ooo`030820P03oool0oooo
0080oooo00<000000?ooo`0000001@3oool010000000oooo0000000000030?ooo`030820P03oool0
oooo00/0oooo203AcJT000L0dLfY3P3oool2000000060820P03oool0oooo0820P0000000P8200P00
00020820P0<0oooo00@0P820000000000000P8200P3oool01020P80000000000000000020?ooo`05
0000003oool0oooo0?ooo`0000000P20P8020?ooo`80P8204@0000030?ooo`030000003oool0oooo
0080oooo00H000000?ooo`000000P82000000020P80300000080oooo00<000000?ooo`3oool01`00
00000`20P800oooo0820P00;00000080oooo00D000000820P0000000oooo0820P007000000040?oo
o`000000P820000000H0oooo00H0P8200000003oool000000820P03oool20820P00300000020P800
P82000@0P820100000030?ooo`040000003oool0oooo0?ooo`/000000`3oool010000000oooo0?oo
o`3oool4000000H0P82000T000000820P020P800oooo0820P0000000oooo00000020P8001P3oool0
10000000P8200000003oool7000000050820P03oool000000820P00000000P3oool;000000030820
P03oool0P82000L000000P3oool00`000000oooo0?ooo`03000000060820P0000000P8200000003o
ool00000103oool010000000oooo0?ooo`3ooolA00000080P8200P3oool20820P0050000003oool0
oooo0?ooo`0000000P3oool300000080P82000D0oooo0820P000000000000820P0030?ooo`80P820
0P0000000`20P80000000820P0020?ooo`030820P0000000000000h0oooo203AcJT000L0dLfY403o
ool40820P080oooo0P0000060?ooo`800000103oool4000000030820P0000000P8200080000000<0
oooo0000003oool00`3oool00`000000oooo0000000>000000050?ooo`000000P8200000003oool0
0P0000001020P80000000000000000020820P080oooo100000001@20P80000000820P0000000oooo
00<0000000<0oooo0000000000000`3oool3000000040?ooo`00000000000?ooo`H000000P20P803
0?ooo`P000000P20P8080?ooo`8000000P20P8001@3oool000000000003oool000000080oooo00<0
00000?ooo`3oool01@0000001@20P8000000000000000000P82000d0000000D0P820000000000000
00000820P00500000080oooo00D000000?ooo`3oool000000?ooo`02000000030?ooo`20P800P820
00800000203oool20820P0P000000`3oool20820P0H0000000@0oooo000000000000oooo0`000003
0?ooo`80000000T0oooo00000000000000000?ooo`000000P82000000020P800100000020?ooo`80
P8200`0000002020P80000000000003oool000000820P0000000oooo3`0000000`3oool000000?oo
o`030?ooo`070000003oool0000000000020P80000000820P004000000@0oooo0P0000060?ooo`80
00000P3oool40820P100oooo203AcJT000L0dLfY403oool40820P080oooo0P0000060?ooo`800000
103oool4000000030820P0000000P8200080000000<0oooo0000003oool00`3oool00`000000oooo
0000000>000000050?ooo`000000P8200000003oool00P0000001020P80000000000000000020820
P080oooo100000001@20P80000000820P0000000oooo00<0000000<0oooo0000000000000`3oool3
000000040?ooo`00000000000?ooo`H000000P20P8030?ooo`P000000P20P8080?ooo`8000000P20
P8001@3oool000000000003oool000000080oooo00<000000?ooo`3oool01@0000001@20P8000000
000000000000P82000d0000000D0P82000000000000000000820P00500000080oooo00D000000?oo
o`3oool000000?ooo`02000000030?ooo`20P800P82000800000203oool20820P0P000000`3oool2
0820P0H0000000@0oooo000000000000oooo0`0000030?ooo`80000000T0oooo0000000000000000
0?ooo`000000P82000000020P800100000020?ooo`80P8200`0000002020P80000000000003oool0
00000820P0000000oooo3`0000000`3oool000000?ooo`030?ooo`070000003oool0000000000020
P80000000820P004000000@0oooo0P0000060?ooo`8000000P3oool40820P100oooo203AcJT000L0
dLfY4@3oool01@000000oooo0?ooo`000000P8200080oooo0P20P802000000030820P03oool00000
008000000P20P804000000040?ooo`000000oooo00000080oooo00<000000820P020P8001020P80A
00000080P820103oool20820P00500000020P800P8200?ooo`20P800100000001P3oool000000?oo
o`000000oooo000000<0P82000H000000?ooo`00000000000820P03oool400000080P8201`000002
0?ooo`0300000020P800000000L0000000<0oooo0000003oool02@3oool00`20P800oooo0820P003
0820P0<0000000<0P82000000020P8001P0000020?ooo`030820P03oool0oooo00d000000P3oool0
0`20P800oooo0?ooo`06000000030820P0000000P82000<000001020P8000`3oool0P8200?ooo`09
0?ooo`030000003oool0000000L0000000@0P8200000003oool0oooo1`0000020820P0@0000000H0
oooo0820P000000000000?ooo`0000030820P0060000003oool000000?ooo`000000oooo10000000
1@20P800oooo0820P020P80000000080P820103oool20820P14000001P20P8001`000000oooo0?oo
o`000000oooo0000003oool01@0000001P20P8000000000000000000oooo0820P08000000P20P802
0?ooo`050820P0000000oooo0?ooo`0000004@3oool80=7=Z@001`3AcJTB0?ooo`030820P0000000
000000D0oooo0P0000030?ooo`040820P03oool0oooo0?ooo`<0000000<0oooo00000020P8000P20
P802000000050?ooo`000000oooo0?ooo`0000000P3oool@000000030?ooo`000000oooo00D0oooo
00<000000?ooo`0000000`3oool5000000<0P82000<000000?ooo`0000000`3oool01@20P8000000
0820P020P800oooo00@000000P3oool500000080oooo00@000000820P03oool0oooo2@00000<0820
P0030?ooo`000000oooo0080oooo0P0000001@3oool000000?ooo`000000oooo00@0000000D0oooo
00000020P800oooo0820P00?000000050820P03oool0P8200000003oool0100000001@3oool00000
0?ooo`000000oooo008000000`3oool00`000000oooo0820P00;0820P0T000000P3oool01020P800
00000?ooo`3oool500000080oooo100000001@3oool0P8200820P0000000P82000<0oooo00<00000
0?ooo`0000000`20P805000000<0oooo00<000000?ooo`0000001P3oool00`000000oooo0000000?
00000080oooo00D000000?ooo`3oool000000?ooo`02000000<0P82000<000000?ooo`0000000`00
00020?ooo`040820P03oool0oooo0?ooo`8000001@3oool2000000030820P03oool0oooo0100oooo
203AcJT000L0dLfY4`3oool3000000040820P0000000000000000080P8200P0000000`20P800oooo
0820P00600000080P82000@0oooo0820P020P800P8200`0000001@20P80000000820P0000000oooo
010000002020P803000000030820P0000000000000@000000P3oool00`000000oooo000000050820
P080oooo00<000000?ooo`20P8000`3oool01@20P8000000000000000000oooo008000000P3oool0
0`20P800oooo0820P00500000080oooo0P0000001@3oool000000?ooo`3oool0000000<0oooo00@0
00000?ooo`3oool000000`3oool00`20P800000000000003000000<0P820100000001`3oool00000
0820P020P800oooo0000003oool03@0000000`3oool000000?ooo`020820P0030000003oool00000
00<000000`20P805000000050820P03oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`00000000000P3oool5000000030820P03oool0P8200080oooo
0P0000001@3oool00000000000000000P82000<0oooo00<0P8200?ooo`0000000P3oool50820P003
0000003oool000000080oooo1P0000001020P80000000000000000080820P100000000D0oooo0000
0020P80000000820P003000000<0P82000<0oooo0820P020P8001P0000000`20P800oooo0820P002
00000080P8200`0000001020P800000000000000000C0?ooo`P0dLfY00070=7=ZA@0oooo00<0P820
0?ooo`3oool00`0000020?ooo`8000000`3oool5000000030?ooo`000000oooo0080oooo0P000000
0`3oool00000000000020?ooo`80P8201@0000000`3oool000000000000900000080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030820P03oool0oooo00L0000000@0P8200?ooo`3oool0oooo
0`20P8000`3oool0P8200820P0020820P0030000003oool0oooo00<0oooo100000020820P0800000
0`3oool700000080P82000H000000?ooo`000000P82000000020P804000000030820P03oool0oooo
00<0oooo10000000103oool000000?ooo`3oool4000000030?ooo`20P800oooo00<0P82000<00000
0?ooo`0000002P0000000`3oool000000820P0020820P0030?ooo`20P800oooo00@000000P3oool0
0`000000oooo00000003000000D0oooo00<0P8200000000000000P0000001P20P80000000820P000
0000oooo00000080P8201`0000030?ooo`8000000P20P804000000D0oooo00<000000820P020P800
0P20P800103oool0P8200820P020P8030?ooo`030820P0000000000000D000000P3oool01020P800
oooo0?ooo`0000030?ooo`030000003oool0oooo00/0000000<0oooo0000000000000`0000020820
P080oooo0P0000000`3oool00000000000030?ooo`030000003oool0000000@000000`3oool20000
0080oooo0`0000020?ooo`030820P03oool0oooo0180oooo203AcJT000L0dLfY5@3oool00`000000
P8200?ooo`020?ooo`030820P000000000000080000000<0P8200000000000001@0000060820P0@0
000000@0P8200?ooo`20P800P8200P0000020820P0d0000000<0P82000000020P800100000000`20
P800oooo0820P008000000D0oooo0P000000103oool0P8200820P03oool20820P0040000003oool0
oooo0820P0D000000P3oool3000000030820P0000000oooo00H000000P3oool200000080P8200P3o
ool4000000P0oooo00D0P8200?ooo`3oool0oooo0820P005000000050?ooo`20P800P8200820P03o
ool00P20P80=00000080P82000D0oooo0820P020P800P8200?ooo`05000000050820P03oool0oooo
0?ooo`20P800203oool400000080oooo0P20P80200000080oooo1P0000000`3oool000000820P003
00000080oooo1@0000001020P800oooo0?ooo`0000020820P0040?ooo`20P800P8200?ooo`800000
1@3oool8000000030820P03oool0P82000@0000000<0P82000000020P8003@0000020820P0800000
0P20P8000`3oool0P82000000003000000H0P8201`0000000`20P800000000000002000000060820
P03oool0oooo0?ooo`20P80000005@3oool80=7=Z@001`3AcJTF0?ooo`D0P8200P3oool00`20P800
oooo0?ooo`0700000080oooo00@000000?ooo`3oool0oooo0`0000000`3oool000000?ooo`020820
P0<0oooo00D000000?ooo`00000000000?ooo`08000000040?ooo`000000oooo00000080oooo0P00
00030?ooo`T0000000@0P8200?ooo`000000P820103oool010000000oooo0820P020P8040?ooo`H0
000000@0P8200?ooo`3oool0oooo0P20P808000000060820P0000000P8200820P03oool0P8201000
00000`3oool000000820P002000000040820P0000000oooo0?ooo`D0P8200P3oool00`20P800oooo
0?ooo`020?ooo`060000003oool0oooo0?ooo`000000oooo2`0000000`3oool000000?ooo`020?oo
o`030000003oool0oooo0080oooo00<0P8200?ooo`3oool01@20P8020?ooo`0700000020P8000000
00000020P80000000?ooo`04000000060820P03oool0P8200820P0000000P820200000020820P0<0
oooo00<0P820000000000000100000040?ooo`80P82000<0oooo0000003oool00`3oool01020P800
00000?ooo`20P809000000<0oooo0P0000020?ooo`040000003oool000000?ooo`P0000000D0oooo
000000000000oooo000000030?ooo`80P82000<0oooo0000003oool00`0000030?ooo`030000003o
ool0oooo00L000000P3oool00`20P800oooo0?ooo`050820P1H0oooo203AcJT000L0dLfY5`3oool0
20000000oooo0?ooo`3oool000000820P03oool0P8201`0000001@3oool000000820P0000000P820
00H000000`20P8001P3oool0P8200820P0000000oooo00000080P8202P0000030820P0D0000000D0
P82000000000000000000?ooo`03000000030?ooo`000000000000<0oooo1P20P80010000000oooo
0?ooo`0000020820P080000000<0oooo0000000000000P0000050?ooo`030000003oool0000000H0
00000P3oool20820P0030?ooo`000000oooo00@000000P20P8020?ooo`80P8200P0000020?ooo`06
0000003oool0oooo00000020P800oooo0P20P802000000D0P8203@0000050820P08000000P20P800
0`3oool0P820000000020?ooo`030000003oool0oooo008000000P20P8020?ooo`80P82010000000
0`3oool000000?ooo`020820P080oooo1`0000000`3oool000000?ooo`040?ooo`@0000000<0oooo
0000000000000P20P80010000000oooo0?ooo`0000060820P0<0oooo0P0000001@3oool000000000
00000000oooo00<0000000<0P8200000000000000`0000030820P0X000000P20P8000`000000oooo
000000020820P0040?ooo`20P800P8200820P0H0000000D0P82000000020P80000000?ooo`070000
00040820P03oool0P820000000<0oooo00<000000?ooo`3oool05@3oool80=7=Z@001`3AcJTH0?oo
o`80P8200P0000030?ooo`H0000000@0oooo00000020P800P8200P3oool600000080oooo00<00000
0?ooo`20P8000P20P80200000080oooo2@000000103oool000000?ooo`3oool4000000030?ooo`00
0000oooo00<000000`20P804000000030820P0000000oooo0080oooo00<000000?ooo`3oool00P00
00001020P800oooo0?ooo`3oool300000080P82000<000000820P020P8001@20P807000000040?oo
o`000000P8200?ooo`<0P820100000000`3oool000000?ooo`030?ooo`070000003oool0oooo0000
0020P80000000820P002000000@0oooo0P0000020?ooo`030000003oool0oooo00d000000P3oool0
0`000000oooo0?ooo`02000000@0oooo0P0000001020P80000000820P00000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`0000000`0000030820P0040?ooo`20P80000000?ooo`L00000
1`20P8000`000000P8200820P003000000<0oooo00<0P8200000000000000P3oool01P000000oooo
0?ooo`3oool000000820P0@000000`20P803000000030?ooo`000000oooo00@000000P3oool00`00
0000oooo0000000800000080oooo0P0000030820P0040?ooo`000000oooo0?ooo`H000000P3oool2
0820P0030000003oool0000000D000000`3oool200000080P820603oool80=7=Z@001`3AcJTJ0?oo
o`<0000000<0P8200000000000001P0000020820P0030?ooo`20P800000000L0000000<0P8200000
0020P8000P3oool20820P00300000020P800oooo0080000000<0oooo0000000000001@0000050820
P00400000020P800P8200820P0@000000`3oool3000000040?ooo`000000oooo00000080P82000<0
00000820P00000000P0000050?ooo`060820P03oool0oooo0000003oool000000`3oool00`000000
oooo0?ooo`0800000080P82000@0oooo0000003oool0oooo1@0000060820P080000000D0oooo0000
003oool000000?ooo`02000000090820P000000000000000003oool000000820P0000000P82000l0
000000D0P82000000020P80000000?ooo`03000000080820P000000000000?ooo`000000oooo0000
003oool2000000H0P8201@0000020?ooo`040000003oool0P8200820P0P000000P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool00`20P800oooo0?ooo`030?ooo`<0000000P0P820
00000020P800P8200000003oool000000?ooo`<000000`3oool4000000<0P82000<000000820P020
P8000`20P807000000060?ooo`00000000000?ooo`20P80000000P20P8020?ooo`030820P0000000
P82000P0000000@0P8200?ooo`20P800P820200000001020P800000000000000000J0?ooo`P0dLfY
00070=7=ZAX0oooo0`0000000`20P80000000000000600000080P82000<0oooo0820P00000001`00
00000`20P80000000820P0020?ooo`80P82000<000000820P03oool00P0000000`3oool000000000
0005000000D0P82000@000000820P020P800P820100000030?ooo`<0000000@0oooo0000003oool0
00000P20P8000`000000P82000000002000000D0oooo00H0P8200?ooo`3oool000000?ooo`000003
0?ooo`030000003oool0oooo00P000000P20P800103oool000000?ooo`3oool5000000H0P8200P00
00001@3oool000000?ooo`000000oooo0080000000T0P82000000000000000000?ooo`000000P820
00000020P8003`0000001@20P80000000820P0000000oooo00<0000000P0P820000000000000oooo
0000003oool000000?ooo`8000001P20P80500000080oooo00@000000?ooo`20P800P82020000002
0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030820P03oool0oooo00<0oooo
0`0000002020P80000000820P020P80000000?ooo`000000oooo0`0000030?ooo`@000000`20P800
0`000000P8200820P0030820P0L0000000H0oooo000000000000oooo0820P00000020820P080oooo
00<0P82000000020P800200000001020P800oooo0820P020P808000000040820P000000000000000
01X0oooo203AcJT000L0dLfY6`3oool00`20P800oooo0?ooo`02000000030?ooo`00000000000080
000000<0oooo0000003oool00P3oool7000000040?ooo`000000oooo00000080oooo0P20P8020?oo
o`0300000020P800P82000@0000000D0oooo000000000000oooo000000020?ooo`80000000@0oooo
0000003oool0oooo1P0000001020P80000000820P020P803000000<0P8200P3oool3000000050?oo
o`20P80000000000003oool01020P8000`000000oooo000000020820P00300000020P800000000L0
000000<0oooo0000003oool00P3oool00`20P80000000?ooo`0400000080oooo00@000000?ooo`3o
ool000000P3oool010000000P8200820P020P802000000040?ooo`000000oooo0?ooo`8000000P20
P8020?ooo`l000000P3oool20820P08000000P3oool010000000oooo0000000000030820P0040000
003oool0oooo00000080oooo00<000000?ooo`3oool0100000000`3oool000000820P0030?ooo`03
0000003oool0000000L0000000L0P82000000020P800P8200000003oool0000000@0P82000D0oooo
000000000000P8200?ooo`0300000080oooo0`20P80300000080P82000<000000820P00000001@00
00020?ooo`040000003oool0000000000080oooo00D000000?ooo`00000000000?ooo`0400000080
P82000<000000?ooo`3oool00P20P8020?ooo`040000003oool000000?ooo`L000000`3oool00`00
0000oooo00000003000000030?ooo`00000000000080oooo00<0P8200?ooo`3oool06@3oool80=7=
Z@001`3AcJTL0?ooo`0500000020P800oooo0?ooo`20P8000P0000020820P0050000003oool00000
0820P03oool0200000030820P08000000P3oool01P000000P8200?ooo`3oool000000?ooo`@00000
0P20P803000000030820P03oool0oooo0080oooo00<0P8200000000000001@0000020?ooo`80P820
0P3oool00`20P800oooo0820P0040820P00400000020P800P8200820P0@0oooo00<000000?ooo`3o
ool00P0000030820P080oooo2@0000050820P0@0oooo00<0P8200?ooo`3oool00P3oool00`20P800
00000000000200000080P82000H0oooo0820P020P80000000820P00000020820P00500000020P800
P8200?ooo`20P8004@0000001@20P800oooo0820P020P80000000080P82000<000000820P0000000
0P20P8000`3oool0P8200820P004000000030820P03oool0oooo0080oooo00<0P8200?ooo`3oool0
0P3oool50820P0T000000P3oool30820P08000000P3oool00`000000oooo0?ooo`020?ooo`<0P820
00<000000820P020P8000`20P800103oool0P8200?ooo`3oool20820P080oooo1`0000000`20P800
oooo0?ooo`020?ooo`040820P0000000000000000080P820100000001P3oool000000?ooo`3oool0
P82000000080oooo0P0000030820P0P0000000D0oooo0820P0000000oooo000000030820P0060000
0020P800oooo0?ooo`20P8000000703oool80=7=Z@001`3AcJTM0?ooo`@0P8200`3oool00`000000
oooo000000020820P0030?ooo`00000000000080000000@0oooo00000000000000000P3oool01@00
0000oooo0?ooo`000000P8200080oooo00<000000820P03oool00`3oool01@20P800oooo0?ooo`00
0000oooo008000001P3oool8000000030820P03oool0P82000<0P82000<0oooo0000000000000P3o
ool00`000000oooo000000020?ooo`80000000H0P82000000000000000000820P00000020820P080
oooo00<0P820000000000000200000020?ooo`050000003oool0oooo00000020P8000P0000060?oo
o`8000000P3oool020000000oooo0?ooo`3oool000000?ooo`000000oooo0P0000000`3oool00000
0?ooo`020?oooa4000000`3oool020000000oooo000000000000oooo0000003oool000000`3oool0
0`000000oooo0?ooo`02000000H0oooo0P0000001@20P80000000?ooo`3oool000000080oooo2P00
00000`20P800oooo0?ooo`020820P00300000020P80000000080000000<0P8200000000000000P3o
ool00`000000oooo000000020?ooo`80000000<0oooo0820P020P8000P20P8000`3oool0P8200000
0007000000H0oooo0P0000001@3oool000000?ooo`3oool0P82000@0oooo00H0P8200000003oool0
oooo0820P00000020?ooo`030000003oool0oooo00<0000000<0oooo0000000000000P0000001P3o
ool0P8200820P0000000oooo000000<0oooo1020P80M0?ooo`P0dLfY00070=7=ZAh0oooo00<00000
0?ooo`3oool00P0000001020P800oooo0?ooo`3oool20820P0060?ooo`00000000000000003oool0
00000P20P80010000000P8200000000000020?ooo`030820P03oool0P820008000001P3oool01000
0000P82000000020P8020?ooo`070820P0000000000000000020P80000000?ooo`07000000<0oooo
00@000000?ooo`3oool000001@20P803000000040820P03oool0oooo0?ooo`80000000@0oooo0000
003oool00000103oool;000000030820P0000000P820008000000`3oool01020P800000000000020
P80200000080P820100000001020P80000000000000000040820P0<0000000<0P820000000000000
4@0000001020P80000000000000000040820P0<0000000<0P8200000000000000P0000020820P080
000000@0P820000000000000P8200`3oool2000000030820P0000000P82000/00000103oool01000
0000oooo0000003oool2000000<0oooo00@0P82000000000000000001@20P80010000000oooo0?oo
o`0000030?ooo`L0000000<0oooo00000020P8000`0000001`20P800oooo0?ooo`20P80000000820
P00000001P3oool2000000030820P03oool0P8200080oooo0P0000001P20P80000000820P020P800
00000?ooo`<0000000<0oooo0820P020P8000`3oool20820P0040000003oool0oooo000001h0oooo
203AcJT000L0dLfY7`3oool01020P80000000000000000050?ooo`030000003oool0P82000@0oooo
0P20P8020?ooo`8000000P3oool30820P080oooo00<0P8200000003oool00P20P80200000080oooo
1020P8030?ooo`80P8202@0000001@20P8000000000000000000P82000<0oooo00<000000?ooo`3o
ool00P0000001P3oool000000?ooo`3oool0P820000000<0P8200`0000020820P0/0000000D0oooo
0000003oool000000?ooo`0200000080P82000@0oooo0820P03oool0oooo0P0000020?ooo`@00000
0P3oool01020P800oooo0?ooo`0000030?ooo`030820P03oool0oooo01<000000P3oool01@20P800
oooo0?ooo`3oool000000080oooo00<0P8200?ooo`3oool0100000020?ooo`8000000P3oool01020
P800oooo0820P020P802000000050?ooo`000000oooo0000003oool02`0000020820P0<000000`20
P8001P000000P8200?ooo`3oool000000?ooo`8000000P3oool01@000000oooo0?ooo`3oool0P820
00<0000000<0P8200000000000001`0000020820P0<0oooo1020P8020?ooo`8000000P20P8000`3o
ool000000820P0020?ooo`<0P8200P3oool200000080oooo0P20P8040?ooo`030820P03oool00000
00H0oooo0P0000000`20P800oooo0?ooo`0M0?ooo`P0dLfY00070=7=ZB00oooo100000001020P800
000000000020P8030?ooo`80000000L0P8200000003oool0oooo00000020P800000000@0P82000<0
oooo0820P020P8000P20P8040?ooo`<0000000D0P8200?ooo`20P800P8200?ooo`020820P0030000
003oool0oooo0080000000<0oooo000000000000100000020?ooo`040820P03oool0oooo00000080
P82000<000000820P03oool00`0000040820P080oooo00@000000?ooo`3oool0P8200`3oool<0000
00<0P8200P000000103oool000000000003oool40820P00300000020P800000000D0000000<0P820
0?ooo`20P800100000000`20P800oooo0820P00E000000030820P03oool0P82000@0000000<0P820
0?ooo`20P8001P0000000`20P80000000820P0030820P0040?ooo`00000000000?ooo`8000000`20
P80<000000<0oooo00@0P8200?ooo`3oool000000P3oool40820P0<0000000<0oooo0820P0000000
0P20P80010000000oooo0?ooo`20P8020?ooo`H0000000<0oooo0000000000000P3oool010000000
P8200820P03oool20820P0030?ooo`20P800000000800000103oool40820P0030?ooo`20P800P820
0080P82000<000000820P00000000P3oool010000000P8200000000000030?ooo`040820P0000000
00000820P0@00000803oool80=7=Z@001`3AcJTQ0?ooo`80P8200P3oool2000000H0oooo0P20P802
00000080P8200P3oool2000000<0oooo00D000000?ooo`3oool000000820P005000000<0oooo00<0
00000?ooo`20P8000P20P80200000080P820200000001@20P800oooo0820P0000000oooo00800000
00@0oooo0000003oool0P8200P3oool30820P0030?ooo`20P80000000080000000<0P8200?ooo`20
P8003P0000020?ooo`040000003oool00000000000@0P82000<0oooo0820P020P8000P3oool60000
00<0oooo100000030?oooaD000000`3oool4000000<0oooo1P0000020?ooo`80P82000<0oooo0820
P020P8000P20P802000000040?ooo`000000oooo0?ooo`h0000000<0P8200?ooo`20P8000`000000
0`20P800oooo0820P0020820P080oooo00@0P8200?ooo`000000oooo0P0000001@3oool000000820
P03oool0P82000P000000P20P802000000<0P82000<0oooo0000003oool00P3oool5000000050820
P0000000oooo0?ooo`0000000`3oool200000080oooo0P20P80200000080P8201P3oool2000000<0
oooo00<0P8200?ooo`3oool07`3oool80=7=Z@001`3AcJTS0?ooo`0500000020P800oooo0?ooo`20
P8000P0000000`20P8000000000000020?ooo`8000000P3oool00`000000P8200?ooo`050?ooo`03
0820P0000000000000<0oooo00@0P8200?ooo`3oool0P8200P0000040820P0060?ooo`20P800oooo
0?ooo`000000oooo1`0000030?ooo`8000001020P8000`000000oooo0?ooo`020?ooo`80000000@0
oooo0820P020P80000000P20P800103oool000000?ooo`3oool=000000040820P0000000P8200000
00<0P82000H0oooo0820P020P800P8200?ooo`20P808000000030820P03oool0000000<0000000<0
oooo0820P00000005P0000000`20P800oooo00000003000000030?ooo`20P800000000L0000000<0
P8200?ooo`20P8000P20P800203oool0P8200820P020P80000000820P0000000P8203@0000020?oo
o`050000003oool0P8200820P00000000P20P8000`3oool00000000000040?ooo`0300000020P800
P8200080P8200P0000030?ooo`L0000000H0oooo0000003oool0oooo0820P03oool40820P0800000
00@0P8200?ooo`3oool0P8200`3oool2000000030820P03oool0oooo00@0oooo00@0P8200000003o
ool0oooo0P0000020?ooo`80000000@0P820000000000000P8200P3oool00`20P80000000000000R
0?ooo`P0dLfY00070=7=ZB<0oooo00D000000820P03oool0oooo0820P002000000030820P0000000
00000080oooo0P0000020?ooo`0300000020P800oooo00D0oooo00<0P8200000000000000`3oool0
1020P800oooo0?ooo`20P802000000@0P82000H0oooo0820P03oool0oooo0000003oool7000000<0
oooo0P0000040820P0030000003oool0oooo0080oooo0P000000103oool0P8200820P00000020820
P0040?ooo`000000oooo0?ooo`d0000000@0P82000000020P80000000`20P8001P3oool0P8200820
P020P800oooo0820P0P0000000<0P8200?ooo`0000000`0000000`3oool0P8200000000F00000003
0820P03oool0000000<0000000<0oooo0820P00000001`0000000`20P800oooo0820P0020820P008
0?ooo`20P800P8200820P0000000P82000000020P80=00000080oooo00D000000?ooo`20P800P820
000000020820P0030?ooo`000000000000@0oooo00<000000820P020P8000P20P802000000<0oooo
1`0000001P3oool000000?ooo`3oool0P8200?ooo`@0P8200P0000001020P800oooo0?ooo`20P803
0?ooo`80000000<0P8200?ooo`3oool0103oool01020P80000000?ooo`3oool200000080oooo0P00
00001020P800000000000020P8020?ooo`030820P000000000000280oooo203AcJT000L0dLfY903o
ool40820P080oooo0`20P8000`000000oooo0820P0040?ooo`P0P8200P3oool00`20P80000000000
00040?ooo`8000000P3oool2000000030?ooo`20P800P8200080P8202@0000001020P80000000000
000000030?ooo`040000003oool000000820P08000001020P8000`3oool0P8200?ooo`030820P080
000000<0oooo0000000000002@0000001P3oool000000?ooo`000000oooo000000@0oooo00@00000
0?ooo`3oool0oooo1@0000000`3oool00000000000030?ooo`030820P03oool0oooo0080oooo0P00
00000`3oool000000000000?000000030?ooo`000000000000@0oooo00@0P8200?ooo`3oool0oooo
0P0000000`3oool0000000000003000000<0oooo00<000000?ooo`3oool00P3oool01P000000oooo
0000003oool000000?ooo`/0000000<0oooo0000000000000`20P8000`3oool0P8200?ooo`040820
P080000000@0P8200000003oool000000`3oool3000000030820P0000000000000L000001020P800
0`3oool00000000000020?ooo`800000103oool2000000030820P03oool0oooo00P0P820103oool0
0`20P800oooo000000030820P080oooo1020P80T0?ooo`P0dLfY00070=7=ZBD0oooo00H000000?oo
o`3oool000000820P03oool30820P0030000003oool0oooo00@0oooo0P0000020?ooo`060000003o
ool0oooo00000020P800oooo0P20P800103oool000000820P03oool3000000030820P03oool0oooo
0080oooo00<000000?ooo`3oool0200000000`3oool000000?ooo`0200000080oooo00<0P8200000
0020P8000P3oool2000000<0oooo00<000000?ooo`20P8000P20P800103oool0P8200820P020P80;
000000030?ooo`000000P8200080P82000D000000?ooo`00000000000820P003000000030820P000
0000000000D000000P20P802000000040820P03oool0P8200820P08000000P20P80C00000080P820
0P0000020820P0040?ooo`20P800000000000080P8201`0000001@20P8000000000000000000P820
0080000000<0oooo00000020P8000P20P8000`000000oooo0000000:000000<0P82000H0oooo0820
P020P800P8200?ooo`0000030?ooo`8000000P3oool00`20P80000000820P0020?ooo`80000000<0
oooo0000003oool0200000020?ooo`030000003oool0oooo0080oooo00P0P8200000000000000000
0?ooo`20P80000000?ooo`80P82000<0oooo0820P00000000P3oool00`000000oooo0?ooo`020000
00H0oooo00L000000820P020P800P8200?ooo`20P80000000080oooo00<000000?ooo`3oool08`3o
ool80=7=Z@001`3AcJTV0?ooo`030820P0000000000000@0oooo00@000000?ooo`000000P8200P00
00000`20P800000000000002000000030820P0000000P82000800000103oool010000000P8200820
P03oool3000000H0oooo00<0P820000000000000200000030820P00900000020P800P8200?ooo`20
P800oooo0820P0000000oooo00<0000000D0P8200?ooo`3oool0oooo000000030?ooo`80000000<0
oooo0000000000002@0000020820P0030?ooo`20P800P82000<000000P3oool00`20P800oooo0?oo
o`0700000080oooo0P0000040?ooo`8000000P3ooolC00000080oooo0P0000040?ooo`8000000P3o
ool700000080oooo00<0P8200?ooo`3oool00`0000020820P0030?ooo`20P800P82000/0000000<0
oooo0000000000000`3oool01@000000oooo0?ooo`3oool0P82000<0000000H0oooo00000020P800
oooo0820P03oool20820P00400000020P800P8200820P0X0000000<0P8200?ooo`3oool0103oool3
000000040?ooo`20P800P820000000@0oooo0P0000000`20P80000000820P004000000070820P000
000000000820P0000000oooo000000040?ooo`80000000<0P8200?ooo`3oool0903oool80=7=Z@00
1`3AcJTW0?ooo`<0000000<0P8200000000000000P0000020820P080oooo0P20P80200000080P820
0P3oool3000000050820P000000000000?ooo`0000000`3oool00`20P800oooo0?ooo`060?ooo`L0
000000<0oooo0000000000000P3oool01@000000oooo000000000000oooo00<0P8200`3oool20820
P0040?ooo`20P8000000000000H0P8202`0000000`3oool000000?ooo`020?ooo`030000003oool0
00000080000000<0P8200?ooo`20P8002@0000000`20P80000000820P0050820P00300000020P800
000001@0000000<0P82000000020P8001@20P8000`000000P82000000008000000030820P03oool0
P82000<0000000<0oooo0000003oool00P3oool00`000000oooo0000000:000000H0P8200P000000
1020P800oooo0820P020P8030?ooo`<0P82000D0oooo000000000000oooo000000020?ooo`800000
00<0oooo0000000000001@0000080?ooo`060820P03oool0oooo0?ooo`000000oooo0P0000001020
P80000000000000000020?ooo`80P8200P0000020820P080oooo0P20P804000000040820P0000000
0000000002L0oooo203AcJT000L0dLfY:03oool00`20P800oooo0?ooo`03000000030?ooo`000000
oooo00<0oooo00@000000?ooo`3oool00000103oool00`20P800oooo0?ooo`03000000D0P82000@0
oooo00000020P800P8200P0000000`20P80000000?ooo`0700000080P8200P0000040820P0070000
003oool0oooo0000003oool0P820000000040?ooo`8000000P3oool010000000oooo0?ooo`3oool<
000000D0P820100000030?ooo`T000000P3oool20820P0040?ooo`20P800P8200820P080oooo5@00
00020?ooo`<0P82000<0oooo0820P020P8000P3oool9000000<0oooo100000050820P0`000000`3o
ool00`000000oooo0?ooo`02000000@0oooo00@000000820P03oool000000P3oool00`000000P820
0820P0020820P08000000P20P807000000030?ooo`000000P820008000000P20P8000`000000oooo
0820P0040820P0<000000P3oool00`20P800oooo0?ooo`020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`0000000P0000020?ooo`030820P03oool0oooo02H0oooo203AcJT000L0dLfY
:@3oool00`000000P8200?ooo`020?ooo`030820P0000000P8200080000000<0P8200?ooo`3oool0
0P3oool01P20P800000000000020P800oooo0820P0@000000P3oool010000000oooo0?ooo`000003
0820P080oooo0P20P80800000080oooo0P0000020?ooo`80000000<0oooo00000020P8000`3oool3
000000080820P000000000000?ooo`000000P82000000020P80>00000080oooo00<000000?ooo`3o
ool0100000000`3oool0P8200000000:000000030820P03oool0P82000<0P82000<0oooo0820P000
00005P0000000`20P800oooo0820P0030820P0030?ooo`20P800000000X0000000<0P8200?ooo`00
00000`0000020?ooo`030000003oool0oooo00h0000000D0P82000000020P80000000?ooo`020000
00040820P00000000000000000<0oooo00<0P8200000003oool00P0000020?ooo`8000000P3oool8
00000080P8200P3oool30820P0040000003oool0oooo00000080oooo100000000`20P800oooo0820
P002000000030820P03oool0oooo0080oooo00H0P820000000000000P82000000020P8030?ooo`03
0820P0000000oooo02P0oooo203AcJT000L0dLfY:P3oool50820P080oooo0P0000060?ooo`800000
0`3oool5000000060820P0000000P8200000003oool000001@3oool00`000000oooo000000070000
00030820P0000000P82000@0P82000D000000?ooo`000000oooo0820P00200000080oooo00@00000
0?ooo`00000000000P20P8020?ooo`l0000000<0P8200?ooo`3oool00P3oool20820P0<0oooo2`00
00030?ooo`030000003oool0oooo0080oooo5`0000040?ooo`040000003oool0oooo0?ooo`/00000
0`3oool20820P0@0oooo00<0P8200000000000003@0000020?ooo`80P8200P000000103oool00000
0?ooo`3oool2000000050820P03oool000000?ooo`0000001@20P8000`000000P820000000070000
00030?ooo`000000oooo00@0oooo00H000000?ooo`000000P82000000020P805000000<0oooo0P00
00060?ooo`8000000P3oool50820P2X0oooo203AcJT000L0dLfY:`3oool200000080oooo00D00000
0820P03oool0oooo0820P003000000030820P03oool000000080000000<0P8200000000000000`00
00001P3oool000000?ooo`000000oooo000000L0P8202@0000020?ooo`80P82000@0oooo0820P020
P800P8200P000000103oool0P8200820P00000020820P00300000020P80000000080P82000<0oooo
0820P00000003`0000070?ooo`0300000020P800000000<0000000D0oooo00000000000000000?oo
o`04000000030820P000000000000080000000<0P8200000000000005`0000000`20P80000000000
0002000000030820P000000000000080000000D0oooo00000000000000000?ooo`04000000030820
P0000000oooo00H0oooo400000001`20P800oooo0820P020P80000000820P00000000P20P8001000
0000P8200820P03oool2000000<0P82000<0oooo0820P020P8000P3oool9000000L0P82000H00000
0?ooo`000000oooo0000003oool5000000060820P000000000000000003oool0P8200`0000001@20
P800oooo0?ooo`20P80000000080oooo0P00000[0?ooo`P0dLfY00070=7=ZBd0oooo00<0P8200000
00000000103oool3000000<0oooo00<0P8200?ooo`3oool0100000000`3oool000000820P0020820
P0030000003oool0000000<0oooo00<000000?ooo`3oool02P0000000`20P800oooo0820P0030820
P0030?ooo`20P800oooo0080oooo00P000000?ooo`00000000000?ooo`000000oooo000000<0oooo
3`0000000`3oool000000820P002000000060820P000000000000?ooo`000000oooo0P0000000`3o
ool000000820P0020820P080000000<0oooo0000000000000P3oool01020P800oooo0?ooo`3ooolI
000000<0oooo00<0P8200?ooo`3oool00P0000000`3oool00000000000030820P0070000003oool0
00000000003oool000000?ooo`02000000060820P000000000000820P0000000oooo3`0000030?oo
o`040000003oool000000?ooo`80000000<0oooo0000003oool00P3oool00`20P800oooo0820P003
0820P0030?ooo`20P800000000T000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0`20P8000`000000oooo0000000300000080oooo00@0P8200?ooo`3oool0oooo0`0000040?ooo`80
000000<0P8200?ooo`3oool0:`3oool80=7=Z@001`3AcJT]0?ooo`030820P0000000000000@0oooo
0`0000030?ooo`030820P03oool0oooo00@0000000<0oooo00000020P8000P20P8000`000000oooo
000000030?ooo`030000003oool0oooo00X0000000<0P8200?ooo`20P8000`20P8000`3oool0P820
0?ooo`020?ooo`080000003oool000000000003oool000000?ooo`0000030?ooo`l0000000<0oooo
00000020P8000P0000001P20P80000000000003oool000000?ooo`80000000<0oooo00000020P800
0P20P802000000030?ooo`00000000000080oooo00@0P8200?ooo`3oool0oooo6@0000030?ooo`03
0820P03oool0oooo0080000000<0oooo0000000000000`20P8001`000000oooo000000000000oooo
0000003oool00P0000001P20P800000000000020P80000000?ooo`l000000`3oool010000000oooo
0000003oool2000000030?ooo`000000oooo0080oooo00<0P8200?ooo`20P8000`20P8000`3oool0
P8200000000900000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0P82000<00000
0?ooo`0000000`0000020?ooo`040820P03oool0oooo0?ooo`<00000103oool2000000030820P03o
ool0oooo02/0oooo203AcJT000L0dLfY;P3oool3000000030820P0000000000000<0P8200P000000
0`20P800oooo0820P00600000080P82000<0oooo0820P020P800100000001@20P80000000820P000
0000oooo00T000000`3oool00`000000oooo0?ooo`020?ooo`0300000020P8000000008000001020
P803000000030820P0000000000000l000000P20P8020?ooo`<0P8200`0000020820P0030000003o
ool0000000<0oooo00<0P8200?ooo`0000000P0000001020P800oooo0820P020P80K00000080P820
00<0oooo0820P00000000P0000000`3oool0P8200?ooo`020?ooo`030000003oool000000080P820
0`0000030820P080oooo0P20P80A000000040820P00000000000000000@0P8200`0000000`20P800
00000?ooo`030?ooo`040000003oool0oooo0?ooo`T0000000D0oooo00000020P80000000820P004
00000080P82000<0oooo0820P020P8001P0000000`20P800oooo0820P002000000<0P8200P000000
1020P800000000000000000^0?ooo`P0dLfY00070=7=ZBl0oooo00<0P8200?ooo`3oool00P000003
0?ooo`8000000`3oool5000000030?ooo`000000oooo0080oooo00<000000?ooo`0000000P000002
0?ooo`80P820100000020?ooo`D0000000<0P8200000000000000P0000000`20P800000000000002
0?ooo`050820P03oool0oooo0?ooo`0000000P3oool00`20P800oooo0?ooo`0@000000030?ooo`00
0000oooo00<0oooo0P0000000`3oool00000000000020?ooo`8000001@20P800103oool000000000
000000040?ooo`@0000000@0oooo000000000000oooo2`000000103oool000000000003oool40000
00@0oooo0`0000000`3oool0P8200820P0030820P08000000P3oool2000000030?ooo`0000000000
00@0oooo00<000000?ooo`0000003`0000020?ooo`040820P03oool0oooo000000<0oooo00<0P820
0?ooo`3oool00P0000000`20P800000000000002000000030820P0000000000000<000000P3oool4
00000080P8200P3oool3000000030?ooo`000000oooo0080oooo00<000000?ooo`00000010000003
0?ooo`8000000`3oool200000080oooo00<0P8200?ooo`3oool0;@3oool80=7=Z@001`3AcJT`0?oo
o`0500000020P800oooo0?ooo`20P8001@0000000`20P800000000000005000000D0P8201@000000
1@20P800oooo0820P020P80000000080P8201`0000020?ooo`040820P03oool0oooo0?ooo`<00000
00<0P8200?ooo`20P800100000000`20P800oooo0820P00B000000L0P820100000001020P8000000
0820P020P8020?ooo`80P82000H0oooo000000000000oooo00000020P802000000030?ooo`000000
0000008000000P20P80=00000080P820100000001P3oool0000000000020P80000000?ooo`800000
00<0oooo0820P020P8000P3oool20820P00300000020P800000000<000001`20P80B000000030820
P03oool0P82000@0000000<0P8200?ooo`20P8000`0000030?ooo`030820P03oool0oooo00L00000
0P20P8001@000000P8200820P03oool0P82000D000001@20P807000000030820P0000000000000<0
000000D0P8200?ooo`3oool0P8200000000`0?ooo`P0dLfY00070=7=ZC40oooo1020P8030?ooo`03
0820P03oool0oooo00L000000P3oool00`000000oooo0?ooo`04000000030?ooo`000000oooo0080
P8200P3oool00`000000oooo0?ooo`02000000060?ooo`000000000000000020P800oooo0P20P804
000000<0oooo100000030?oooa8000000P3oool00`000000oooo0?ooo`02000000070?ooo`000000
00000?ooo`000000oooo000000040?ooo`030000003oool0P82000<0oooo0`20P8000`000000oooo
0000000200000080oooo3@0000020?ooo`<0000000<0oooo00000020P8000P20P8030?ooo`030820
P03oool0000000@0oooo00@000000?ooo`000000oooo0P0000000`3oool00000000000020?ooo`03
0000003oool0oooo018000000`3oool4000000<0oooo100000020820P0030?ooo`20P80000000080
000000<0oooo0000000000000P3oool00`000000oooo0?ooo`020820P0030?ooo`000000oooo00@0
00000P3oool00`000000oooo0?ooo`0700000080oooo00@0P8200?ooo`3oool0oooo1020P80a0?oo
o`P0dLfY00070=7=ZC80oooo00<000000?ooo`3oool00P0000000`20P800oooo0820P00700000005
0?ooo`000000P82000000020P8001P0000030820P0040?ooo`20P80000000?ooo`8000000P20P804
000000@0oooo1@0000000`20P800oooo00000003000000030?ooo`20P800000001<0000000@0P820
00000020P80000000P3oool00`000000P8200820P003000000H0P82000<000000?ooo`3oool00`3o
ool2000000060?ooo`000000P8200820P0000000P8203`0000001P20P80000000820P020P8000000
0?ooo`8000001@3oool00`000000P8200820P0040820P0<000000P20P8001`000000oooo0?ooo`00
0000P82000000020P800500000000`20P800oooo00000003000000030?ooo`20P800000000@00000
103oool400000080P8200P000000103oool000000820P03oool30820P0H0000000D0P82000000020
P80000000?ooo`07000000030820P03oool0P820008000000P3oool00`000000oooo0?ooo`0`0?oo
o`P0dLfY00070=7=ZC<0oooo00@0P82000000000000000000`3oool500000080oooo00<000000820
P020P8000P3oool600000080oooo00@000000?ooo`20P800P8200`0000020?ooo`D0000000<0P820
0000000000000P0000000`3oool00000000000040?ooo`040820P03oool0oooo0?ooo`80000000<0
oooo0000000000003`0000020?ooo`80P8200`0000020?ooo`<000000P3oool200000080oooo0P00
00001020P800oooo00000020P8040?ooo`80P8200P3oool?00000080oooo0P20P8040?ooo`040820
P0000000oooo0820P08000000P3oool200000080oooo0`0000020?ooo`<000000P20P8020?oooa40
000000<0oooo0000000000000`3oool00`20P800oooo0?ooo`020?ooo`80000000<0oooo00000000
00000P0000000`20P80000000000000300000080oooo0`0000020820P0040?ooo`000000oooo0?oo
o`H000000P3oool20820P0030000003oool0oooo00D000000`3oool3000000030820P03oool0oooo
0340oooo203AcJT000L0dLfY=03oool4000000030820P0000000000000H000000P20P8000`3oool0
P82000000007000000040820P0000000P8200?ooo`80P8200P0000000`20P800oooo000000030000
00040?ooo`000000oooo0?ooo`<000000P20P80200000080P82000@0oooo0820P000000000000P20
P80C000000030820P03oool0P8200080P82000<000000820P0000000100000001020P80000000000
0020P803000000<0oooo1P20P8000`3oool0P8200000000@000000030820P03oool0P82000D0P820
0`3oool3000000040820P000000000000820P0D0000000<0P82000000020P8000P20P8000`3oool0
P8200000000B00000080P8200P0000001020P800oooo0820P020P80200000080P8200`0000020?oo
o`030000003oool0000000<0000000@0oooo0820P000000000000P20P800103oool0P82000000020
P808000000040820P03oool0P8200820P0P0000000<0P8200000000000000P00000d0?ooo`P0dLfY
00070=7=ZCD0oooo0P20P8020?ooo`80000000@0oooo00000000000000000P3oool010000000oooo
0?ooo`3oool7000000050?ooo`000000oooo0000003oool00P20P8030?ooo`0400000020P800P820
000000<0P8201@0000020?ooo`800000103oool200000080oooo4P0000000`3oool000000?ooo`03
0820P080oooo100000001P3oool000000?ooo`3oool000000?ooo`<0000000<0P8200?ooo`000000
0`3oool010000000oooo0?ooo`3ooolA000000<0oooo00L000000?ooo`3oool0oooo0000003oool0
P82000<0000000H0oooo0000003oool0oooo0000003oool400000080oooo0`20P8000`3oool00000
0?ooo`0B00000080oooo0P0000040?ooo`8000000P3oool5000000<0P82000@000000820P020P800
00000`3oool20820P0050?ooo`000000oooo0000003oool01`0000030?ooo`030000003oool0oooo
00<0000000<0oooo0000000000000P3oool20820P3D0oooo203AcJT000L0dLfY=`3oool01P000000
P8200?ooo`3oool0P82000000080P8200P000000103oool000000820P03oool8000000<0P82000<0
00000?ooo`3oool00P0000001P20P800oooo0?ooo`000000oooo00000080oooo1P0000000`20P800
00000820P0050820P00300000020P800000001<000000`20P8020?ooo`030820P0000000oooo00@0
00001020P804000000<0oooo0P20P803000000030820P000000000000140000000@0P82000000000
000000000P20P8030?ooo`@000001020P804000000030?ooo`000000P8200080oooo0`20P80D0000
00030820P0000000P82000D0P82000<000000820P00000001@0000020?ooo`030000003oool00000
0080oooo00<0P8200000000000000P3oool010000000P8200820P020P808000000040?ooo`20P800
00000?ooo`8000000P20P8001P000000P8200?ooo`3oool0P820000003L0oooo203AcJT000L0dLfY
=`3oool01P000000P8200?ooo`3oool0P82000000080P8200P000000103oool000000820P03oool8
000000<0P82000<000000?ooo`3oool00P0000001P20P800oooo0?ooo`000000oooo00000080oooo
1P0000000`20P80000000820P0050820P00300000020P800000001<000000`20P8020?ooo`030820
P0000000oooo00@000001020P804000000<0oooo0P20P803000000030820P0000000000001400000
00@0P82000000000000000000P20P8030?ooo`@000001020P804000000030?ooo`000000P8200080
oooo0`20P80D000000030820P0000000P82000D0P82000<000000820P00000001@0000020?ooo`03
0000003oool000000080oooo00<0P8200000000000000P3oool010000000P8200820P020P8080000
00040?ooo`20P80000000?ooo`8000000P20P8001P000000P8200?ooo`3oool0P820000003L0oooo
203AcJT000L0dLfY>03oool40820P080oooo00@000000?ooo`3oool000000P20P8001@3oool00000
000000000000oooo00@000000P3oool010000000oooo00000020P8030?ooo`0300000020P800oooo
0080oooo00<0P8200000000000001@0000020?ooo`<0P82000<0oooo0820P020P8000P3ooolD0000
0080oooo00<000000?ooo`3oool00P20P804000000030?ooo`000000oooo0080oooo100000000`3o
ool0P820000000030?ooo`030820P03oool0oooo01<000000P3oool01`20P800oooo0?ooo`3oool0
00000820P03oool0100000030?ooo`030000003oool0000000<000000P20P8020?ooo`030000003o
ool0oooo01@000000P3oool20820P0040?ooo`20P800P8200820P080oooo1`0000001P20P800oooo
0?ooo`3oool0P820000000<0oooo00@0P8200000003oool000000P3oool4000000050?ooo`000000
00000000003oool00P20P80010000000oooo0?ooo`0000020?ooo`@0P820>03oool80=7=Z@001`3A
cJTi0?ooo`050000003oool0oooo00000020P800103oool20820P0050?ooo`00000000000?ooo`00
00000`20P8001`000000P820000000000000oooo0820P03oool00P20P802000000D0oooo20000000
0`20P800oooo0820P0030820P0030?ooo`20P800000001D0000000D0P82000000020P800P8200?oo
o`020820P00500000020P800P8200000003oool00P0000001020P800oooo0?ooo`20P8030?ooo`<0
000000<0P8200?ooo`20P8005@0000000`20P800oooo0820P003000000<0oooo00@0P8200?ooo`3o
ool0P8200P0000001@3oool000000820P020P80000000080P82000D0oooo0820P020P80000000820
P00F000000030820P03oool0P82000<0P82000<0oooo0820P00000001`0000050?ooo`8000000P20
P8000`3oool0P8200?ooo`02000000030820P0000000P8200080P82000D000000?ooo`0000000000
0?ooo`020820P0@0oooo00D0P8200000003oool0oooo0000000i0?ooo`P0dLfY00070=7=ZCX0oooo
00<0P8200000000000001P3oool00`000000oooo0820P0030?ooo`<0P8200P3oool2000000030?oo
o`20P800P8200080P8200P3oool01020P80000000?ooo`20P80200000080oooo0P0000000`3oool0
0000000000040?ooo`040000003oool0oooo0?oooaH000000P3oool40820P0030?ooo`20P800oooo
0080P8200`0000040?ooo`0300000020P800000000<000000`3ooolE000000<0oooo100000000`20
P80000000?ooo`030?ooo`<000000P20P8000`3oool0P8200?ooo`040820P080oooo5P0000030?oo
o`030000003oool0oooo0080oooo0P0000000`3oool00000000000020?ooo`80000000@0P8200?oo
o`000000P8200P3oool40820P0030?ooo`00000000000080oooo0`20P8030?ooo`030820P03oool0
000000H0oooo0P0000000`20P800oooo0?ooo`0h0?ooo`P0dLfY00070=7=ZC/0oooo0`0000001@20
P8000000000000000000P82000<0oooo00<000000820P00000000`3oool00`000000P82000000003
0820P0030?ooo`20P800P82000<0P8200`3oool400000080P820100000000`20P800000000000002
000000030820P0000000000001H0000000<0P8200?ooo`3oool00P20P8000`3oool000000?ooo`02
0820P0<0oooo00@0P820000000000000P8200P3oool4000000030?ooo`20P800000001H0000000<0
P8200?ooo`0000000`0000020?ooo`040820P000000000000820P0<0oooo0P20P8000`3oool00000
0?ooo`020820P080oooo00<0P8200000000000005P0000000`20P800000000000002000000030820
P00000000000008000000P20P804000000<0oooo1@20P8001`3oool0P8200820P020P80000000820
P00000000`3oool00`000000P820000000030?ooo`050820P0000000000000000020P8000`00000k
0?ooo`P0dLfY00070=7=ZC`0oooo00<0P8200?ooo`3oool00`0000050?ooo`80P8200`0000020820
P080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`000000P82000D000000P3oool4
000000<0oooo00<0P8200?ooo`3oool05@0000000`3oool00000000000040?ooo`050000003oool0
P8200?ooo`0000001@3oool2000000@0oooo00<0P8200?ooo`3oool00P3oool2000000030?ooo`00
0000000000l0000000<0oooo000000000000103oool00`20P800oooo0?ooo`020?ooo`8000001@3o
ool01@000000oooo0820P03oool0000000@0oooo0P0000000`3oool000000000000C00000080oooo
00@0P8200?ooo`3oool0oooo100000020?ooo`D0000000D0P8200000003oool0oooo000000040?oo
o`030000003oool0oooo0080P8200`0000020820P0D0oooo0`0000020?ooo`030820P03oool0oooo
03X0oooo203AcJT000L0dLfY?@3oool00`000000P8200?ooo`020?ooo`050820P000000000000820
P00000000P3oool300000080oooo00<000000820P03oool01@3oool00`20P8000000000000020?oo
o`050820P03oool0oooo0?ooo`20P8001P0000020820P0030?ooo`20P800000001H000000P20P803
000000070820P0000000P8200?ooo`20P80000000820P003000000040820P03oool0oooo0820P080
000000@0P8200?ooo`20P800P8200P0000020820P1<000000P20P80200000080P82000D0oooo0820
P000000000000820P0020?ooo`0;0820P0000000000000000020P80000000820P03oool0P8200000
0020P8000`0000020820P1L0000000@0P8200?ooo`20P800P8201P0000001@20P800oooo0?ooo`3o
ool0P8200080oooo0P0000000`20P800oooo0?ooo`040?ooo`040820P0000000oooo0?ooo`<00000
0P3oool01@000000P820000000000000P82000<0oooo00<0P8200000003oool0?03oool80=7=Z@00
1`3AcJTn0?ooo`D0P8200P3oool20820P0040000003oool0P8200820P0@0oooo2020P8020?ooo`03
0820P0000000oooo00@0oooo1P0000040?oooaL000000P3oool300000080oooo0`20P8020?ooo`<0
0000103oool2000000@0oooo0P0000020?oooa<000000P3oool2000000@0oooo0P0000040?ooo`<0
00000P3oool30820P080oooo0`0000020?oooaL00000103oool6000000D0oooo00@000000820P03o
ool0oooo2020P8040?ooo`80P82000@0oooo00000020P800P8200P3oool50820P3h0oooo203AcJT0
00L0dLfY?`3oool200000080oooo00<000000820P03oool00P20P8000`000000oooo0?ooo`050?oo
o`030000003oool0oooo008000000P3oool01P000000P8200?ooo`20P800oooo00000080P82000D0
oooo00000000000000000?ooo`0200000080oooo00<0P8200000000000005`0000000`20P8000000
0820P0040820P0030?ooo`20P800P8200080P8200P0000001@20P800000000000020P800000000H0
P82000<000000820P0000000500000000`20P80000000820P0050820P00500000020P80000000000
0020P8000P0000040820P0030?ooo`20P800P82000<0P82000<000000820P0000000600000000`20
P800oooo0?ooo`02000000050?ooo`00000000000000003oool00P20P8001P000000oooo0820P03o
ool0P82000000080oooo0P0000020?ooo`030000003oool0oooo00D0oooo00H000000820P020P800
oooo0820P00000020?ooo`800000?`3oool80=7=Z@001`3AcJU10?ooo`030820P0000000000000<0
oooo00D000000?ooo`00000000000820P002000000050820P0000000000000000020P8000P000000
0`20P8000000000000030?ooo`0500000020P800P8200820P03oool00`0000000`3oool0P8200?oo
o`030?oooaT000000P3oool30820P0050?ooo`20P800P8200820P03oool00P20P8030?ooo`800000
0P3oool20820P0040?ooo`20P800P8200820P080oooo5@0000020?ooo`<0P82000<0oooo0820P020
P8000P3oool2000000<0oooo0P20P8001@3oool0P8200820P020P800oooo00<0P8200P3ooolI0000
00@0oooo00<0P8200?ooo`0000000P0000001@3oool0P8200820P020P800000000<0oooo0P000000
1020P800000000000020P803000000040820P000000000000820P080000000<0oooo0000003oool0
0P3oool2000000030820P03oool0oooo03l0oooo203AcJT000L0dLfY@@3oool00`20P80000000000
00030?ooo`050000003oool0000000000020P8000P0000001@20P8000000000000000000P8200080
000000<0P8200000000000000`3oool01@000000P8200820P020P800oooo00<0000000<0oooo0820
P03oool00`3ooolI00000080oooo0`20P8001@3oool0P8200820P020P800oooo0080P8200`3oool2
00000080oooo0P20P800103oool0P8200820P020P8020?oooaD000000P3oool30820P0030?ooo`20
P800P8200080oooo0P0000030?ooo`80P82000D0oooo0820P020P800P8200?ooo`030820P080oooo
6@0000040?ooo`030820P03oool000000080000000D0oooo0820P020P800P820000000030?ooo`80
000000@0P820000000000000P8200`0000001020P800000000000020P802000000030?ooo`000000
oooo0080oooo0P0000000`20P800oooo0?ooo`0o0?ooo`P0dLfY00070=7=ZD80oooo0`0000001020
P80000000000000000030820P080oooo0P20P8000`000000P8200820P0030?ooo`<0000000@0P820
0000003oool00000103oool01@20P800oooo0?ooo`3oool000000080P8206`0000000`20P800oooo
0?ooo`030820P0050?ooo`20P800P8200820P03oool00P20P804000000030820P03oool0P82000<0
P82000<0oooo0820P00000005P0000000`20P800oooo0820P0030820P0030?ooo`20P800000000<0
00000P20P8001@3oool0P8200820P020P800oooo00<0P8200P3oool00`20P80000000000000I0000
0080P82000D000000?ooo`3oool0oooo0820P0040?ooo`040000003oool000000820P0<000000`3o
ool20820P00300000020P800P8200080oooo0`20P803000000040820P0000000000000000480oooo
203AcJT000L0dLfY@`3oool00`20P800oooo0?ooo`02000000030?ooo`000000000000@0oooo00<0
00000?ooo`0000001@3oool00`20P800oooo0?ooo`02000000H0P82000<0oooo00000020P8000`3o
ool5000000030?ooo`000000000001<00000103oool01@000000oooo0?ooo`3oool0000000@0oooo
100000030?ooo`030000003oool0oooo0080oooo1@0000001@3oool00000000000000000oooo00<0
000000D0oooo00000000000000000?ooo`05000000@0oooo00@000000?ooo`3oool0oooo10000004
0?ooo`050000003oool0oooo0?ooo`000000103ooolE000000030?ooo`000000000000<000000`3o
ool00`20P80000000?ooo`060820P08000000P3oool00`20P800oooo0?ooo`030?ooo`030000003o
ool0000000@0oooo0P0000000`3oool00000000000020?ooo`030820P03oool0oooo0440oooo203A
cJT000L0dLfYA03oool01@000000P8200?ooo`3oool0P8200080000000@0P820000000000000P820
0`3oool01`20P8000000000000000000P8200?ooo`20P8000`0000030?ooo`040000003oool0oooo
00000080P82000<0oooo0000000000000P20P8000`000000P8200820P00G00000080P8200`000000
1@20P8000000000000000000P82000L0000000<0P8200000000000000P0000000`20P80000000000
0005000000<0P8201@0000030820P0L0000000<0P8200000000000000P0000000`20P80000000000
0005000000050820P0000000000000000020P8000`0000020820P1L000000P20P8000`000000P820
0820P002000000040?ooo`20P800P82000000080oooo00@000000?ooo`3oool0oooo0`0000000`20
P800oooo0820P003000000050820P03oool0oooo0?ooo`20P8000P0000001020P800000000000020
P8020?ooo`030820P0000000oooo04<0oooo203AcJT000L0dLfYA@3oool40820P0<0oooo0P000005
0?ooo`<000000`3oool400000080P82000D000000820P0000000oooo000000040?ooo`80P8200P3o
ool010000000oooo0000000000020?oooa8000000`3oool00`20P800oooo0?ooo`02000000040?oo
o`000000oooo0?ooo`D000000P3oool01020P800oooo0?ooo`3oool7000000<0oooo0P0000000`3o
ool00000000000030?ooo`L000000`3oool00`20P800oooo0?ooo`0500000080oooo00@000000?oo
o`00000000000P3oool01020P800oooo0?ooo`3ooolB00000080oooo0P000000103oool000000?oo
o`3oool20820P0@0oooo00D000000?ooo`000000P820000000020820P0@000000`3oool3000000D0
oooo0P0000030?ooo`@0P820A@3oool80=7=Z@001`3AcJU60?ooo`030000003oool0oooo00800000
00@0P8200?ooo`3oool0P8200P0000000`20P800oooo00000003000000030820P000000000000080
000000L0oooo000000000000oooo0000003oool0000000H0P82000<0oooo0820P00000000P000002
0820P1H0000000<0P8200?ooo`20P8000`000000103oool0P8200?ooo`3oool6000000040820P03o
ool0P8200820P0L0000000D0oooo000000000000P820000000030820P00500000020P80000000000
003oool01`0000020820P0030?ooo`20P800000000D000000P3oool00`20P800oooo000000020000
00030820P03oool0P82001H000000P20P803000000030820P03oool0P82000D0P82000@000000?oo
o`000000oooo0P0000000`3oool0000000000002000000030820P000000000000080000000D0oooo
0820P000000000000820P0020?ooo`030820P000000000000080oooo00<000000?ooo`3oool0A03o
ool80=7=Z@001`3AcJU70?ooo`040820P00000000000000000@0oooo0P0000040?ooo`030820P03o
ool0oooo00<0000000<0oooo00000020P8000`20P8000`000000oooo000000020?ooo`8000000`3o
ool300000080oooo1@000000103oool000000000003oool;00000080oooo00D000000?ooo`20P800
P820000000030820P080oooo0`0000000`3oool00000000000040?ooo`<0000000D0oooo00000000
0000oooo000000030820P080oooo00<000000?ooo`3oool00`20P8001@000000oooo000000000000
oooo00<00000103oool2000000040?ooo`000000000000000080oooo0`20P8001@000000P8200820
P03oool000000080oooo2`000000103oool000000000003oool500000080oooo0`0000030?ooo`80
00000P3oool00`000000oooo000000040820P0030000003oool00000008000000P3oool00`20P800
oooo0?ooo`020?ooo`800000103oool3000000030820P03oool0oooo04D0oooo203AcJT000L0dLfY
B03oool4000000030820P000000000000080P8200P0000020820P0030?ooo`20P800000000@00000
0`20P8000`3oool0P8200820P003000000070820P000000000000820P0000000oooo0820P0020?oo
o`030820P000000000000080000000<0oooo0000000000000P20P80;000000030?ooo`0000000000
00<0P82000<0oooo0820P03oool00P20P8020?ooo`@000000P20P80200000080P8200P3oool00`20
P800oooo00000002000000<0P82000<0oooo0820P00000000P0000000`20P800oooo0820P0020820
P0<0000000@0oooo0820P03oool0oooo0P20P80200000080P820100000020?ooo`80P82000<0oooo
0820P03oool00`20P802000000030?ooo`000000000000T000000P20P802000000030?ooo`000000
00000080000000L0P8200?ooo`3oool0P8200?ooo`000000P8200080000000@0P820000000000000
00000P20P800103oool0P8200820P020P805000000040820P03oool0P8200820P08000000P20P802
000000030820P0000000000000800000B03oool80=7=Z@001`3AcJU90?ooo`80P8200P3oool20000
0080oooo0P0000040?ooo`@0000000<0oooo0000003oool00`3oool010000000oooo000000000003
0?ooo`80P82000<000000?ooo`3oool00P3oool4000000060?ooo`20P800oooo0?ooo`000000oooo
2`0000030820P0060?ooo`20P800P8200820P03oool00000103oool00`20P800oooo0?ooo`020820
P080oooo1@20P8001@3oool000000000003oool0000000@0oooo0`0000040?ooo`050000003oool0
00000000003oool01@20P8020?ooo`80P8200P3oool00`20P800oooo0?ooo`020?ooo`030000003o
ool0P8200080P82000@0oooo0820P020P800P8202`0000001P3oool000000?ooo`3oool0P8200?oo
o`@00000103oool00`000000P8200820P0030?ooo`80000000<0oooo0000003oool00`3oool00`00
0000oooo00000003000000@0oooo0P0000020?ooo`8000000P3oool20820P4T0oooo203AcJT000L0
dLfYB`3oool01@000000P8200?ooo`3oool0P82000D0000000<0P820000000000000100000060820
P0@000000P20P8001P3oool0P8200820P0000000oooo0820P0D0000000<0oooo0820P020P8000P20
P8000`000000oooo00000008000000030?ooo`000000000000<0oooo00D000000?ooo`3oool0oooo
0820P002000000030?ooo`20P800P8200080P82000<0oooo0820P00000000`3oool01P000000oooo
0?ooo`3oool0P8200?ooo`<0000000<0P8200?ooo`0000000P0000000`3oool0P820000000020000
00030?ooo`20P800oooo0080oooo00L000000?ooo`3oool0oooo00000020P800oooo00@0P82000@0
oooo000000000000P8200`3oool010000000oooo0?ooo`3oool2000000030?ooo`000000000000L0
000000<0oooo00000020P8000`20P8000`3oool0000000000003000000030820P03oool000000080
P82000<0oooo0820P020P800100000060820P0H0000000<0P8200000000000000`0000001@20P800
oooo0?ooo`20P800000004/0oooo203AcJT000L0dLfYB`3oool01@000000P8200?ooo`3oool0P820
00D0000000<0P820000000000000100000060820P0@000000P20P8001P3oool0P8200820P0000000
oooo0820P0D0000000<0oooo0820P020P8000P20P8000`000000oooo00000008000000030?ooo`00
0000000000<0oooo00D000000?ooo`3oool0oooo0820P002000000030?ooo`20P800P8200080P820
00<0oooo0820P00000000`3oool01P000000oooo0?ooo`3oool0P8200?ooo`<0000000<0P8200?oo
o`0000000P0000000`3oool0P82000000002000000030?ooo`20P800oooo0080oooo00L000000?oo
o`3oool0oooo00000020P800oooo00@0P82000@0oooo000000000000P8200`3oool010000000oooo
0?ooo`3oool2000000030?ooo`000000000000L0000000<0oooo00000020P8000`20P8000`3oool0
000000000003000000030820P03oool000000080P82000<0oooo0820P020P800100000060820P0H0
000000<0P8200000000000000`0000001@20P800oooo0?ooo`20P800000004/0oooo203AcJT000L0
dLfYC03oool40820P080oooo00@0P8200?ooo`3oool0oooo1P0000030?ooo`030000003oool0oooo
00<0000000@0oooo000000000000oooo0P20P8030?ooo`D0000000@0oooo0820P020P800oooo0P20
P80;000000H0P8200P0000001P20P800oooo0820P020P800oooo00000080oooo00@000000?ooo`20
P800P8200`0000050820P0040?ooo`0000000000000000<0oooo00@0P8200?ooo`3oool0oooo0`00
00000`3oool0P8200820P0030820P0<000000P20P8001P3oool000000?ooo`3oool000000?ooo`80
P82000@0oooo0820P000000000001P20P80;00000080P82000@0oooo0820P020P800oooo1@000003
0?ooo`80P82000@0oooo000000000000oooo0`0000020?ooo`040000003oool0oooo0?ooo`H00000
0`3oool00`20P800oooo0?ooo`040820P4`0oooo203AcJT000L0dLfYC@3oool01P000000oooo0?oo
o`000000P8200?ooo`80P8201P0000001P3oool000000820P020P80000000820P0D000001020P800
1@3oool0P8200000003oool0P82000<0oooo00<0P8200?ooo`0000000`3oool00`000000oooo0000
0009000000<0oooo00<000000?ooo`3oool00P0000040?ooo`0300000020P800P8200080P82000<0
00000?ooo`3oool00`0000020?ooo`040000003oool0oooo000000<0P8200P0000000`20P800oooo
0820P002000000<0P82000@000000?ooo`3oool000000P3oool300000080oooo00<000000820P020
P8000P20P8000`000000oooo0?ooo`020?ooo`8000000P3oool010000000oooo0?ooo`3oool:0000
00030?ooo`000000oooo0080oooo00<000000?ooo`20P8000`3oool01@20P800oooo00000020P800
oooo00@0P8201@0000001P20P80000000820P020P80000000?ooo`H000000P20P8000`3oool0P820
000000020?ooo`030000003oool0oooo04/0oooo203AcJT000L0dLfYCP3oool00`20P80000000000
00040?ooo`D0000000<0oooo00000020P8000P20P8020?ooo`D000000`3oool01@000000oooo0820
P020P800000000D0oooo00<000000820P020P8000`20P80=000000050820P0000000P8200000003o
ool00P0000001020P80000000000000000020?ooo`040000003oool0oooo0820P0D0000000<0P820
00000020P8000P0000030?ooo`8000000`3oool2000000<0oooo0P0000000`20P80000000820P005
000000040820P03oool0oooo00000080oooo0`0000002020P80000000000003oool000000820P000
0000P8203@0000050820P0030000003oool0oooo00<0oooo00D000000820P020P800oooo00000003
0?ooo`D000000P3oool30820P0030000003oool0000000@00000103oool2000000030820P03oool0
oooo04`0oooo203AcJT000L0dLfYC`3oool3000000030820P0000000000000H000000P20P8020?oo
o`030820P0000000000000H0000000@0P82000000020P800oooo0P20P80010000000oooo0820P020
P80200000080oooo00<000000?ooo`3oool03@0000020?ooo`80P8200P000000103oool000000?oo
o`3oool2000000030820P03oool0oooo0080oooo100000001@3oool000000?ooo`000000oooo0080
00000P20P8000`000000P8200820P0030820P00300000020P800P8200080000000D0oooo0000003o
ool000000?ooo`04000000@0oooo00<0P8200000000000000P3oool010000000oooo000000000002
0820P080oooo3@0000020?ooo`030000003oool0oooo008000000P20P800203oool000000820P020
P800oooo0820P0000000P820200000000`20P800oooo0?ooo`020820P0P0000000@0P82000000000
00000000C`3oool80=7=Z@001`3AcJU@0?ooo`030820P03oool0oooo00<0000000H0oooo00000000
000000000?ooo`0000040?ooo`H000000P3oool010000000oooo0000003oool20820P0@0oooo0`00
00000`20P80000000820P00?000000070820P03oool0P8200820P0000000P820000000020820P008
00000020P800P8200?ooo`000000P8200000003oool4000000<0P8200`0000030?ooo`80P82000<0
oooo0820P020P8000`3oool3000000<0P820100000001@3oool000000820P0000000oooo0080P820
00H000000820P020P80000000820P00000020820P0030?ooo`20P800000000h0000000<0P8200000
0020P8000`0000040?ooo`80P82000@0oooo0000003oool000000P3oool6000000@0oooo00<00000
0?ooo`0000000P000000103oool000000000000000020?ooo`030820P03oool0oooo04h0oooo203A
cJT000L0dLfYD@3oool00`000000P8200?ooo`020?ooo`070820P0000000P8200820P0000000oooo
000000020820P0030?ooo`000000000000H000000`20P8001@000000oooo0?ooo`000000P82000@0
000000D0oooo0000003oool000000?ooo`0>000000<0oooo00@000000?ooo`000000oooo0P000000
0`3oool000000?ooo`020?ooo`80P82000<000000?ooo`3oool00P0000020?ooo`030000003oool0
000000<0000000<0P8200?ooo`20P8000P20P8000`3oool0P82000000003000000040?ooo`000000
oooo0?ooo`8000000P3oool00`000000P8200820P0030?ooo`080000003oool000000000003oool0
00000?ooo`0000030?ooo`h0000000D0oooo0000003oool000000?ooo`04000000050820P0000000
oooo0?ooo`0000000`20P808000000060?ooo`20P800P8200000003oool000000P20P8000`000000
P8200?ooo`020?ooo`030820P0000000oooo0500oooo203AcJT000L0dLfYDP3oool50820P080oooo
00<000000?ooo`0000000`20P8001@3oool00000000000000000oooo00@000000P3oool010000000
oooo00000020P8020?ooo`D000000`20P80@000000040820P00000000000000000@0P8200`000000
0`20P800oooo000000020?ooo`80P82000<000000820P020P8000P20P805000000<0oooo00@00000
0?ooo`3oool0oooo1@0000040820P00300000020P800P8200080oooo00<000000?ooo`20P8000`00
00040820P0<0000000<0P8200000000000003P0000030820P0D000000P3oool01020P80000000?oo
o`0000020?ooo`@0000000D0oooo00000000000000000?ooo`030820P0030000003oool000000080
oooo1@20P81B0?ooo`P0dLfY00070=7=ZE<0oooo0P0000020?ooo`0300000020P800oooo0080oooo
0`20P8001@3oool000000000003oool000000080P8200P0000001`20P80000000000003oool0P820
0?ooo`20P8000`0000000`3oool00000000000020?ooo`030000003oool0000000h000000P3oool0
1020P800oooo0?ooo`0000030?ooo`040820P03oool0oooo000000D0P8200P3oool00`000000oooo
0?ooo`06000000050820P0000000000000000020P8001P0000020?ooo`030000003oool0oooo00D0
P82000@000000?ooo`3oool0P8200`3oool010000000oooo0?ooo`20P8020?ooo`l0000000@0oooo
0000003oool0oooo0P000000203oool00000000000000000P8200?ooo`20P800oooo0P0000000`20
P8000000000000020820P0050000003oool000000000003oool00`20P8030?ooo`040820P0000000
oooo0?ooo`800000D`3oool80=7=Z@001`3AcJUC0?ooo`8000000P3oool00`000000P8200?ooo`02
0?ooo`<0P82000D0oooo000000000000oooo000000020820P080000000L0P820000000000000oooo
0820P03oool0P82000<0000000<0oooo0000000000000P3oool00`000000oooo0000000>00000080
oooo00@0P8200?ooo`3oool000000`3oool01020P800oooo0?ooo`0000050820P080oooo00<00000
0?ooo`3oool01P0000001@20P8000000000000000000P82000H000000P3oool00`000000oooo0?oo
o`050820P0040000003oool0oooo0820P0<0oooo00@000000?ooo`3oool0P8200P3oool?00000004
0?ooo`000000oooo0?ooo`80000000P0oooo00000000000000000820P03oool0P8200?ooo`800000
00<0P8200000000000000P20P8001@000000oooo000000000000oooo00<0P8200`3oool01020P800
00000?ooo`3oool2000005<0oooo203AcJT000L0dLfYE@3oool00`20P8000000000000050?ooo`80
000000<0oooo0820P03oool00P3oool20820P0<0oooo0P000000103oool0P8200820P020P8030?oo
o`030820P0000000P82000<0P82000<000000?ooo`0000000P0000000`3oool00000000000090000
00030820P03oool0P82000@0000000<0P8200?ooo`20P8000P0000020?ooo`030000003oool0oooo
00<0oooo00<0P8200000000000001@0000020?ooo`030820P03oool0oooo00L0000000<0P8200?oo
o`3oool00`3oool00`000000oooo0?ooo`02000000030820P03oool0P82000@0000000<0P8200?oo
o`20P8002`0000001P3oool00000000000000000oooo000000@0P82000<000000820P03oool00P3o
ool30820P0030?ooo`000000000000<0oooo0P20P8030?ooo`040820P03oool00000000000D0oooo
0P0000000`20P800oooo0?ooo`1C0?ooo`P0dLfY00070=7=ZEH0oooo0`0000001020P80000000000
0020P8040?ooo`0300000020P80000000080oooo0P0000000`20P80000000820P0020820P0030?oo
o`20P800P82000<0P8200P3oool00`000000oooo0?ooo`02000000<0P820300000030?ooo`@00000
0`3oool3000000030820P03oool0oooo00D0oooo200000000`20P800oooo0820P008000000L0oooo
00@0P82000000000000000000`3oool4000000<0oooo300000030820P08000000P3oool00`000000
oooo0?ooo`050820P0060?ooo`20P800P8200820P0000000P8200P0000020?ooo`0300000020P800
000000@0oooo00@0P820000000000000P8200`00001F0?ooo`P0dLfY00070=7=ZEL0oooo00<0P820
0?ooo`3oool00P0000060?ooo`80P8200P0000030820P080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`0500000020P80000000820P03oool00P0000030?ooo`d0000000<0P820000000000000
100000001`20P8000000000000000000oooo0000003oool00P20P8000`000000oooo0820P0090000
00<0oooo2@0000000`20P800oooo000000020820P0030?ooo`000000oooo00<0000000<0P8200000
00000000100000000`20P80000000000000;000000<0oooo0P0000001@3oool0P82000000020P800
000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`<0P8200P0000020820P0H0oooo0P00
00020?ooo`030820P03oool0oooo05D0oooo203AcJT000L0dLfYF03oool01@000000P8200?ooo`3o
ool0P82000<0000000@0P8200000003oool0oooo0P0000030?ooo`0300000020P800oooo00@0oooo
0P20P80200000080oooo0`20P8000`000000P8200820P00=000000030?ooo`000000oooo00@00000
00<0oooo0000003oool00`0000040820P0<0oooo200000001@3oool000000820P0000000oooo00P0
00000`3oool40820P0<0000000<0oooo0000003oool0100000000`3oool000000?ooo`0=00000080
P82000@000000820P020P800P8200P3oool200000080P8201@3oool00`20P80000000?ooo`020?oo
o`8000000P3oool00`000000P82000000002000000050820P03oool0oooo0820P0000000F03oool8
0=7=Z@001`3AcJUI0?ooo`@0P8200`3oool20820P0030000003oool0P82000D0oooo2020P8020?oo
o`060820P0000000oooo0?ooo`000000oooo0P0000000`3oool000000000000;000000<0P82000<0
00000820P020P8000P20P80400000080oooo0P0000001@3oool0P820000000000000oooo00800000
00T0oooo00000000000000000?ooo`20P800oooo0820P03oool00`000000103oool000000000003o
ool2000000040820P03oool0000000000080oooo100000040820P00400000020P800P8200820P0d0
000000D0oooo000000000000oooo000000020?ooo`0400000020P800oooo0?ooo`P0P8201@3oool0
0`20P800oooo000000020820P0<0oooo1020P81I0?ooo`P0dLfY00070=7=ZEX0oooo00<000000?oo
o`3oool00P0000001@20P800oooo0820P020P800000000L0oooo00@000000?ooo`3oool000000`3o
ool01P000000P8200?ooo`20P800oooo000000@0P82000<000000?ooo`0000002`0000020?ooo`04
0000003oool0000000000080oooo1@0000000`20P800oooo0?ooo`020?ooo`<000000P20P8040000
00050?ooo`20P800P8200820P03oool0100000020820P0<00000103oool00`20P800000000000003
00000080oooo0P000000103oool000000?ooo`3oool<000000030?ooo`000000P82000<0P82000H0
00000?ooo`20P800oooo0820P00000030?ooo`040000003oool0oooo000000L0oooo00D000000820
P020P800oooo0820P00200000080oooo00<000000?ooo`3oool0F03oool80=7=Z@001`3AcJUK0?oo
o`040820P00000000000000000<0oooo00@000000?ooo`000000P8200`0000001`20P80000000000
00000000P82000000020P8000`0000030?ooo`0400000020P800P8200?ooo`<0P8203P0000000`20
P800oooo0?ooo`020?ooo`030820P0000000oooo00<0000000D0oooo0000003oool0oooo0820P003
000000040?ooo`000000oooo0?ooo`80P8200`3oool010000000oooo0?ooo`3oool20820P080oooo
00<000000?ooo`0000000P0000001@20P800oooo0?ooo`000000oooo00<0000000<0oooo00000020
P800103oool00`20P80000000000000<000000<0P82000@0oooo0820P020P80000000`3oool30000
00030820P0000000P82000<0000000P0P82000000000000000000820P0000000oooo000000<0oooo
0`0000000`20P800oooo0?ooo`1I0?ooo`P0dLfY00070=7=ZE`0oooo100000001020P80000000000
000000020820P0<0oooo0P20P8000`000000P8200820P0020?ooo`@0000000@0P8200000003oool0
0000103oool00`000000oooo0000000<000000H0oooo0P0000020820P00300000020P800oooo00<0
oooo100000050820P0070?ooo`000000P82000000020P80000000?ooo`050820P0@00000103oool0
1020P80000000820P020P802000000H0oooo3@0000000`3oool000000?ooo`030?ooo`040000003o
ool000000820P0@000000P3oool20820P00300000020P800P82000<0oooo0P20P803000000030820
P0000000000000800000G03oool80=7=Z@001`3AcJUM0?ooo`80P8200P3oool2000000030?ooo`00
0000oooo00@0oooo00<000000?ooo`0000001@3oool00`20P800oooo0?ooo`02000000H0P8203`00
00001@20P800oooo000000000000P8200080oooo0P20P8020?ooo`0500000020P800P8200000003o
ool00P000000103oool000000?ooo`3oool2000000070?ooo`20P800oooo0820P03oool0P8200?oo
o`0200000080oooo00H000000?ooo`00000000000?ooo`0000020820P0030000003oool0oooo0080
P8200P3oool01@20P80000000000003oool0P82000l000001P20P80200000080oooo00<0P8200?oo
o`3oool00`3oool00`000000oooo000000050?ooo`040000003oool0000000000080oooo0P20P81M
0?ooo`P0dLfY00070=7=ZEd0oooo0P20P8020?ooo`80000000<0oooo0000003oool0103oool00`00
0000oooo000000050?ooo`030820P03oool0oooo008000001P20P80?000000050820P03oool00000
00000020P8000P3oool20820P080oooo00D000000820P020P80000000?ooo`02000000040?ooo`00
0000oooo0?ooo`80000000L0oooo0820P03oool0P8200?ooo`20P800oooo008000000P3oool01P00
0000oooo000000000000oooo00000080P82000<000000?ooo`3oool00P20P8020?ooo`050820P000
000000000?ooo`20P8003`0000060820P08000000P3oool00`20P800oooo0?ooo`030?ooo`030000
003oool0000000D0oooo00@000000?ooo`00000000000P3oool20820P5d0oooo203AcJT000L0dLfY
G`3oool01`000000P8200?ooo`3oool0P82000000020P8000`0000001@20P800oooo0?ooo`3oool0
P820008000000P20P8000`3oool0P8200000000200000080oooo00@000000?ooo`3oool0oooo3`00
00040?ooo`@0P82000@0oooo0820P000000000000`3oool00`20P80000000820P0020820P0800000
1020P8000`3oool000000?ooo`040820P08000000`20P8000`000000P8200?ooo`020?ooo`800000
00<0P8200?ooo`20P8000`20P8040?ooo`l000000`3oool00`000000oooo0?ooo`03000000040820
P03oool0P8200820P080000000D0P8200?ooo`3oool0oooo0820P003000000030820P0000000P820
0080oooo00<0P8200000003oool0GP3oool80=7=Z@001`3AcJUP0?ooo`@0P8200P3oool3000000D0
oooo0P0000040?ooo`@0000000@0P82000000020P800P8201`0000001@3oool00000000000000000
oooo00D0000000@0P8200?ooo`3oool000000P3oool01@000000oooo0820P020P80000000080P820
00@0oooo0000003oool000000P3oool2000000<0oooo00D000000?ooo`20P800oooo000000030?oo
o`8000000P3oool010000000oooo0000003oool20820P00500000020P800P8200?ooo`0000000P3o
ool010000000oooo0?ooo`20P805000000050?ooo`00000000000000003oool01`0000020820P003
00000020P800000000<00000103oool2000000D0oooo0`0000020?ooo`@0P820H03oool80=7=Z@00
1`3AcJUQ0?ooo`050000003oool0oooo00000020P8000`3oool01@20P800000000000020P800oooo
00@0000000<0P8200000000000000P0000000`3oool000000?ooo`02000000030?ooo`0000000000
00D000000`20P8000`000000oooo00000002000000070?ooo`000000oooo0?ooo`20P800oooo0000
00030820P0090?ooo`20P800oooo0?ooo`20P80000000820P0000000P82000D0000000L0P8200000
0020P800oooo0820P0000000P82000D0000000D0P82000000020P80000000820P0020?ooo`030820
P03oool0P8200080P82000<000000?ooo`20P8000P3oool00`000000oooo00000002000000030?oo
o`000000P8200080P8201`0000001P3oool000000000003oool000000?ooo`@0000000<0P8200000
000000000P0000001@3oool0P820000000000000P82000<0oooo00D0P8200000003oool0oooo0000
001Q0?ooo`P0dLfY00070=7=ZF80oooo00<0P8200000000000001@3oool2000000<0oooo00@0P820
0?ooo`3oool0oooo0`0000000`3oool000000820P0030820P0030000003oool0000000D000000`3o
ool200000080P82000<000000820P03oool00`3oool010000000P8200820P03oool30820P080oooo
00H000000?ooo`000000oooo0000003oool400000080oooo0`20P8020?ooo`@0000000H0oooo0000
003oool000000?ooo`0000020?ooo`<0P82000@0oooo0820P020P8000000103oool01020P8000000
0820P020P802000000<0oooo1P0000000`3oool000000820P0030820P0030000003oool000000080
00000`3oool01020P800oooo0?ooo`3oool2000000D0oooo0P0000000`20P800oooo0?ooo`1P0?oo
o`P0dLfY00070=7=ZF<0oooo0`0000020820P08000000P20P802000000040820P03oool0P8200820
P0D000000P20P800103oool0P8200820P020P809000000080820P0000000P8200820P03oool0P820
0?ooo`20P802000000030?ooo`20P800oooo00<0P82000<0oooo0820P020P8000P20P803000000<0
P82000<000000820P020P8000`20P8000`3oool0P8200820P0030820P00400000020P800P8200820
P0<000001020P8001`3oool0P8200820P020P800oooo0820P03oool00P0000001020P800oooo0820
P03oool20820P00300000020P800000000P000000`20P8000`3oool0P8200820P00500000080P820
00@0oooo0820P000000000000P20P80200000080P8200`00001S0?ooo`P0dLfY00070=7=ZF@0oooo
00@0P8200?ooo`3oool0oooo0P0000020?ooo`800000103oool4000000030?ooo`000000oooo00<0
oooo00<000000?ooo`0000001`0000020?ooo`80P82000<0oooo0000003oool00`20P8001@000000
oooo0?ooo`3oool0000000<0oooo0P0000020?ooo`040820P03oool0oooo00000080oooo0`20P800
1@3oool0P8200820P020P800oooo00<0P8200P3oool010000000oooo0?ooo`20P8020?ooo`800000
0`3oool01@000000oooo0?ooo`3oool0000000<0P82000<0oooo0000003oool00P20P8020?ooo`P0
000000<0oooo0000003oool00`3oool00`000000oooo00000003000000@0oooo0P0000020?ooo`80
00000`3oool00`20P800oooo0?ooo`1R0?ooo`P0dLfY00070=7=ZFD0oooo00<000000820P020P800
0P3oool00`20P800000000000002000000030820P0000000000000D000001P20P80:000000030820
P03oool0P8200080P82000@000000?ooo`3oool0oooo0P0000001@20P8000000000000000000P820
00@0000000<0P8200?ooo`20P8000`0000000`20P800oooo0?ooo`030820P0040?ooo`20P800P820
0820P080oooo00L0P82000000000000000000820P03oool0P82000@0000000D0P820000000000000
00000820P002000000<0oooo00H000000820P020P800P8200?ooo`20P80:000000H0P8201`000000
0`20P800000000000002000000030820P03oool0oooo0080P82000<000000?ooo`3oool0H`3oool8
0=7=Z@001`3AcJUV0?ooo`D0P8200P3oool00`20P800oooo0?ooo`0700000080oooo00@000000?oo
o`3oool0oooo1P000000103oool000000000000000030?ooo`040000003oool0oooo0820P0@00000
0P3oool00`20P800oooo0?ooo`04000000<0oooo0`0000040?ooo`050000003oool0oooo0?ooo`00
0000103oool3000000<0oooo100000020?ooo`030820P03oool0oooo00@0000000@0P8200?ooo`3o
ool000000`3oool3000000030?ooo`000000000000@000000`3oool00`000000oooo0?ooo`070000
0080oooo00<0P8200?ooo`3oool01@20P81V0?ooo`P0dLfY00070=7=ZFP0oooo00L000000?ooo`3o
ool000000820P03oool0P82000L0000000@0oooo00000020P80000000P20P808000000<0P8200P00
00001@20P80000000820P03oool000000080oooo0`0000000`20P800oooo0820P006000000030820
P03oool000000080000000<0oooo0820P020P8000`0000001020P80000000000000000020820P006
0?ooo`00000000000000003oool0P8201P0000000`20P800oooo0820P00300000080oooo00D00000
0?ooo`20P80000000820P002000000<0P820200000020820P00400000020P80000000?ooo`L00000
00@0P8200?ooo`20P80000000P3oool00`000000oooo0?ooo`1V0?ooo`P0dLfY00070=7=ZFP0oooo
00L000000?ooo`3oool000000820P03oool0P82000L0000000@0oooo00000020P80000000P20P808
000000<0P8200P0000001@20P80000000820P03oool000000080oooo0`0000000`20P800oooo0820
P006000000030820P03oool000000080000000<0oooo0820P020P8000`0000001020P80000000000
000000020820P0060?ooo`00000000000000003oool0P8201P0000000`20P800oooo0820P0030000
0080oooo00D000000?ooo`20P80000000820P002000000<0P820200000020820P00400000020P800
00000?ooo`L0000000@0P8200?ooo`20P80000000P3oool00`000000oooo0?ooo`1V0?ooo`P0dLfY
00070=7=ZFT0oooo00<0P8200000000000000`3oool6000000040?ooo`000000P8200820P0<0oooo
200000030?ooo`8000000P3oool30820P080000000<0oooo0000000000000`3oool200000080oooo
0P0000030?ooo`030820P03oool0oooo0080oooo0P0000000`3oool000000?ooo`02000000@0oooo
00@0P8200?ooo`3oool0oooo0P0000020?ooo`8000000`3oool2000000030?ooo`000000000000<0
P8200P3oool2000000<0oooo200000030?ooo`80P82000<000000?ooo`0000001@0000030?ooo`80
000000<0P8200?ooo`3oool0I`3oool80=7=Z@001`3AcJUZ0?ooo`<0000000<0P820000000000000
1P0000020820P0030?ooo`20P800000000/0000000<0P82000000020P8000`20P800103oool0P820
0820P020P804000000030820P0000000000000<000000P20P802000000030820P03oool0P82000<0
00000P20P80300000080P8200`0000000`20P800oooo0820P00200000080P8201@0000000`20P800
000000000002000000<0P82000<0oooo0820P020P8000P20P8000`000000P8200000000;00000004
0820P03oool0P8200820P0P0000000@0P8200000000000000000JP3oool80=7=Z@001`3AcJU[0?oo
o`030820P03oool0oooo008000000P3oool3000000030?ooo`000000oooo0080oooo1`0000000`3o
ool00000000000020?ooo`030000003oool000000080oooo00<000000?ooo`20P8000P20P8020?oo
o`030820P03oool0oooo00D000000P3oool2000000<0oooo0`0000020?ooo`<000000P3oool30000
00<0oooo0P0000020?ooo`D000000P3oool00`20P800oooo0?ooo`030820P0070?ooo`000000oooo
0?ooo`000000oooo000000020?ooo`80000000<0oooo0000000000001@0000030?ooo`030000003o
ool00000008000000P3oool200000080oooo00<0P8200?ooo`3oool0J@3oool80=7=Z@001`3AcJU/
0?ooo`0400000020P800oooo0?ooo`80P82000P000000820P020P80000000?ooo`000000P8200?oo
o`P000000P20P804000000@0P82000P000000?ooo`3oool0oooo00000020P800oooo0820P0L00000
00<0P82000000020P8001020P802000000030820P0000000000000<0000000<0P820000000000000
1@20P8000`000000P82000000006000000040820P03oool0P820000000<0oooo00<000000820P020
P8000P20P80400000080P820200000001@3oool0P8200000003oool000000080P82000<000000820
P020P8000P3oool00`20P80000000?ooo`1[0?ooo`P0dLfY00070=7=ZFd0oooo1@20P8020?ooo`03
0000003oool000000080P82000<0oooo0000000000000P000000103oool000000000000000020?oo
o`@000000P3oool010000000oooo0?ooo`20P803000000<0oooo1`0000020?ooo`80P82000<0oooo
0820P020P8000`3oool5000000<0oooo0P20P8000`3oool0P8200820P0020?ooo`L000000`3oool3
000000040820P03oool0oooo00000080oooo100000020?ooo`<0000000<0oooo0000000000000P00
00001P3oool0P8200820P0000000oooo00000080oooo1@20P81]0?ooo`P0dLfY00070=7=ZFh0oooo
00H000000?ooo`3oool0oooo00000020P8030?ooo`80P82000H0oooo00000000000000000?ooo`00
00020820P00300000020P80000000080000000@0oooo000000000000P820103oool3000000030?oo
o`20P800000000P0000000<0P8200?ooo`20P8000P20P8000`3oool0P8200820P00700000080P820
00H0oooo0820P020P800P8200?ooo`20P809000000030820P03oool0000000800000103oool01020
P80000000000003oool3000000060820P0000000P8200820P0000000oooo0`0000000`3oool0P820
0820P0030?ooo`030820P0000000oooo0080oooo00<000000?ooo`3oool0K03oool80=7=Z@001`3A
cJU_0?ooo`040820P00000000000000000D0oooo00@000000?ooo`20P800P8200`3oool20820P080
oooo0`000000203oool0P8200?ooo`3oool000000820P0000000oooo0P20P8030?ooo`T000000`3o
ool00`000000oooo0?ooo`020?ooo`L00000103oool010000000oooo0?ooo`3oool9000000<0oooo
0P20P800103oool000000820P00000020?ooo`030820P03oool00000008000000P3oool20820P0<0
oooo0P20P8000`3oool000000?ooo`040?ooo`<0000000<0P8200?ooo`3oool0K@3oool80=7=Z@00
1`3AcJU`0?ooo`@0000000@0P820000000000000P820103oool00`000000P820000000020?ooo`03
00000020P800000000@0P82000@0oooo00000020P800P820103oool00`000000P8200000000:0000
00050820P0000000000000000020P8002`0000001@20P8000000000000000000P82000/0000000<0
P8200000003oool00`3oool20820P0030000003oool0P82000<0P82000<000000820P00000000P3o
ool00`000000P820000000040?ooo`040820P000000000000820P0@00000L03oool80=7=Z@001`3A
cJUb0?ooo`030820P03oool0oooo008000001P3oool20820P08000000P20P8030?ooo`040000003o
ool0oooo0?ooo`80P82000@0oooo00000020P800P8200P3oool;00000080oooo00<0P8200?ooo`3o
ool02`0000020?ooo`030820P03oool0oooo00/000000P3oool20820P0040000003oool0P8200820
P0<0oooo00@000000?ooo`3oool0oooo0P20P80200000080P8201P3oool200000080oooo00<0P820
0?ooo`3oool0L03oool80=7=Z@001`3AcJUb0?ooo`030820P03oool0oooo008000001P3oool20820
P08000000P20P8030?ooo`040000003oool0oooo0?ooo`80P82000@0oooo00000020P800P8200P3o
ool;00000080oooo00<0P8200?ooo`3oool02`0000020?ooo`030820P03oool0oooo00/000000P3o
ool20820P0040000003oool0P8200820P0<0oooo00@000000?ooo`3oool0oooo0P20P80200000080
P8201P3oool200000080oooo00<0P8200?ooo`3oool0L03oool80=7=Z@001`3AcJUc0?ooo`050000
0020P800oooo0?ooo`20P8000P0000020820P0030000003oool0oooo008000000P3oool00`000000
P8200820P0050?ooo`030000003oool0P8200080oooo00<0P8200000000000002`0000000`20P800
oooo0820P00=000000030820P03oool0P82000d0000000H0P8200?ooo`3oool0P8200?ooo`000005
0?ooo`80P82000<000000?ooo`3oool00P0000020?ooo`0300000020P800P8200080000000D0P820
0?ooo`3oool0P8200000001c0?ooo`P0dLfY00070=7=ZG@0oooo1020P8020?ooo`<0P82000<00000
0?ooo`20P800103oool80820P0030000003oool0oooo0080oooo3@0000030?ooo`d000000`3oool=
000000@0oooo00<000000820P020P8001P20P8040?ooo`030820P03oool0000000<0P8200P3oool4
0820P7@0oooo203AcJT000L0dLfYM@3oool01@000000oooo0?ooo`000000P8200080oooo0P20P800
0`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo0P0000020820P0d0000000@0
oooo00000020P800oooo3@000000103oool0P8200000003oool=00000080P8200P0000020?ooo`04
0000003oool0oooo000000L0oooo00<000000820P020P8000P3oool01@20P80000000?ooo`3oool0
000007D0oooo203AcJT000L0dLfYMP3oool00`20P8000000000000040?ooo`040000003oool00000
0820P080000000<0P8200000000000000P0000000`20P80000000820P002000000040?ooo`000000
00000?ooo`@0000000<0oooo0000000000001P0000020820P0050?ooo`00000000000000003oool0
1@0000001@3oool00000000000000000oooo0080P820200000000`3oool000000000000200000004
0?ooo`00000000000?ooo`80000000<0P82000000020P800100000001`20P800000000000020P800
00000?ooo`000000103oool2000000030820P03oool0oooo07@0oooo203AcJT000L0dLfYM`3oool3
00000080P8200`0000020820P080oooo0`20P8000`000000P8200820P0020?ooo`<000001020P800
0`000000P8200820P002000000050?ooo`00000000000000003oool00P0000020?ooo`0400000020
P800P8200820P0L000000`20P8000`000000oooo0?ooo`02000000050?ooo`00000000000000003o
ool00P0000020820P00300000020P800P8200080P8200`0000020?ooo`80P82000@000000820P020
P800P8200P3oool20820P0<000000P20P803000007L0oooo203AcJT000L0dLfYN03oool01020P800
oooo0?ooo`3oool2000000030?ooo`000000oooo00<0oooo0P0000000`3oool000000?ooo`030?oo
o`050820P03oool0oooo0?ooo`0000000P3oool20820P080oooo00<0P8200000000000000`20P800
10000000P8200000000000030?ooo`L000000`3oool2000000030820P0000000P8200080P8200P00
00000`20P800oooo0?ooo`020820P080oooo00D000000?ooo`3oool0oooo0820P0040?ooo`040000
003oool00000000000@0oooo00@000000?ooo`00000000000`3oool00`20P800oooo0?ooo`1f0?oo
o`P0dLfY00070=7=ZGT0oooo00<000000820P020P8000P3oool00`20P80000000820P00200000003
0820P03oool0oooo0080oooo00H0P820000000000000P8200?ooo`20P804000000030820P03oool0
P82000<0P8200`3oool00`000000oooo0?ooo`020820P00300000020P800000000X0000000@0P820
00000020P800P8200P3oool010000000oooo0?ooo`3oool40820P0030?ooo`20P800000000<00000
00<0P8200?ooo`20P8000P0000000`20P800oooo0?ooo`020?ooo`060820P000000000000820P000
0000P8200P3oool20820P0030000003oool0oooo07L0oooo203AcJT000L0dLfYNP3oool50820P080
oooo0P0000060?ooo`8000000`3oool4000000<0oooo00<000000?ooo`3oool00P0000000`20P800
oooo0?ooo`020?ooo`030000003oool000000080oooo1`0000020?ooo`030000003oool0000000@0
oooo00<0P8200000000000000P3oool010000000oooo0?ooo`3oool4000000<0oooo0P0000060?oo
o`8000000P3oool50820P7X0oooo203AcJT000L0dLfYO03oool01@000000oooo0?ooo`000000P820
0080oooo00H0P82000000000000000000820P03oool3000000030820P0000000000000@0000000D0
P82000000000000000000820P0030?ooo`0400000020P8000000000000<0P8202`0000030820P080
000000<0P8200000003oool00P3oool01@20P8000000000000000000P82000H0000000H0P8200000
0000000000000?ooo`20P803000000050820P03oool0oooo0820P00000000P3oool00`000000oooo
0?ooo`1j0?ooo`P0dLfY00070=7=ZG`0oooo00D000000?ooo`3oool000000820P0020?ooo`060820
P0000000000000000020P800oooo0`0000000`20P800000000000004000000050820P00000000000
00000020P8000`3oool010000000P8200000000000030820P0/000000`20P802000000030820P000
0000oooo0080oooo00D0P82000000000000000000820P006000000060820P000000000000000003o
ool0P8200`0000001@20P800oooo0?ooo`20P80000000080oooo00<000000?ooo`3oool0NP3oool8
0=7=Z@001`3AcJUm0?ooo`030820P0000000000000@0oooo0`0000030?ooo`030820P03oool0oooo
00H000000P3oool00`20P800oooo0?ooo`02000000030820P03oool0oooo008000000P3oool00`00
0000oooo0?ooo`0700000080oooo00<000000?ooo`3oool00P0000020?ooo`030820P00000000000
0080oooo00<0P8200?ooo`3oool01P0000020?ooo`040820P03oool0oooo0?ooo`<00000103oool2
000000030820P03oool0oooo07/0oooo203AcJT000L0dLfYOP3oool3000000030820P00000000000
00<0P8200P0000000`20P800oooo0820P008000000040820P03oool0P82000000080oooo00@00000
0?ooo`20P80000001020P80;000000@0P82000@000000820P03oool000000P3oool010000000P820
0?ooo`20P808000000030820P03oool0P820008000000`20P802000000040820P000000000000000
07h0oooo203AcJT000L0dLfYO`3oool00`20P800oooo0?ooo`02000000<0oooo0P0000030?ooo`P0
00000`3oool3000000<0P8200P3oool00`000000oooo0?ooo`0;00000080oooo00<000000?ooo`3o
ool00`20P803000000<0oooo200000030?ooo`8000000`3oool200000080oooo00<0P8200?ooo`3o
ool0O@3oool80=7=Z@001`3AcJV00?ooo`0400000020P800oooo0?ooo`80P820100000000`20P800
000000000008000000030820P03oool00000008000000P3oool01@000000oooo0820P0000000P820
00d0000000D0P82000000020P800oooo000000020?ooo`<0000000<0oooo0820P00000002@000000
0`20P80000000000000200000080P8200P3oool00`20P80000000?ooo`1o0?ooo`P0dLfY00070=7=
ZH40oooo1@20P8020?ooo`030820P03oool0oooo00X000000`3oool20820P0030?ooo`000000P820
0080P8200P3oool=00000080oooo0`20P80010000000oooo0820P020P8030?ooo`X000000P3oool0
0`20P800oooo0?ooo`050820P840oooo203AcJT000L0dLfYPP3oool020000000oooo0?ooo`3oool0
00000820P03oool0P8202P000000103oool000000820P00000040?ooo`80P82000@0oooo0820P000
0000oooo2`000000103oool000000820P03oool20820P0@0oooo00@000000820P0000000oooo2P00
00001020P800oooo0820P00000030?ooo`030000003oool0oooo0800oooo203AcJT000L0dLfYP`3o
ool01020P80000000000000000030?ooo`/000000P20P8060?ooo`040000003oool0P8200820P0d0
00000P20P8000`3oool000000?ooo`050?ooo`80P8202`0000030?ooo`<0000000<0P8200?ooo`3o
ool0P@3oool80=7=Z@001`3AcJV40?ooo`@0000000<0P8200000000000001@0000000`3oool00000
0000000200000080oooo00<000000820P020P8000P0000001P20P800oooo0?ooo`3oool000000?oo
o`/0000000<0oooo0000003oool00P3oool00`20P8000000000000020820P0030000003oool0oooo
00@0000000<0oooo0000000000001@0000000`20P800000000000002000008@0oooo203AcJT000L0
dLfYQP3oool00`20P800oooo0?ooo`02000000030?ooo`00000000000080000000L0oooo0820P03o
ool0oooo0820P03oool0000000<0P8200P3oool50820P0d000001@20P8020?ooo`<0P82000<00000
0?ooo`20P8000P3oool00`20P800oooo00000003000000030?ooo`00000000000080oooo00<0P820
0?ooo`3oool0Q03oool80=7=Z@001`3AcJV60?ooo`030820P03oool0oooo0080000000<0oooo0000
000000000P0000001`3oool0P8200?ooo`3oool0P8200?ooo`0000000`20P8020?ooo`D0P8203@00
00050820P080oooo0`20P8000`000000oooo0820P0020?ooo`030820P03oool0000000<0000000<0
oooo0000000000000P3oool00`20P800oooo0?ooo`240?ooo`P0dLfY00070=7=ZHL0oooo00H00000
0820P03oool0oooo0820P00000030820P0030000003oool0oooo0080oooo00<000000820P020P800
0P3oool01@20P80000000?ooo`3oool000000080oooo3@0000020?ooo`050000003oool0oooo0000
0020P8000P3oool20820P0030000003oool0oooo0080oooo00H000000820P020P800P82000000020
P8020?ooo`030820P0000000oooo08H0oooo203AcJT000L0dLfYR03oool40820P080oooo0P000000
1`3oool000000820P0000000oooo0820P03oool01020P8040?ooo`030820P0000000000000d00000
00<0P8200?ooo`3oool00P3oool40820P0070?ooo`20P800oooo00000020P80000000?ooo`020000
0080oooo1020P8280?ooo`P0dLfY00070=7=ZHT0oooo00D000000?ooo`3oool000000820P0040?oo
o`80P82000@000000?ooo`3oool0oooo0P0000060?ooo`l000001P3oool2000000<0oooo00<00000
0820P020P800103oool01@20P80000000?ooo`3oool0000008T0oooo203AcJT000L0dLfYRP3oool0
0`20P8000000000000060?ooo`040000003oool000000820P0@0000000H0P820000000000000P820
0000003oool=000000030?ooo`000000P8200080000000<0P8200000000000000P0000001020P800
00000?ooo`0000060?ooo`80000000<0P8200?ooo`3oool0R03oool80=7=Z@001`3AcJV;0?ooo`<0
00000P20P802000000040820P03oool0oooo0?ooo`80P8200P0000020820P080oooo0P20P80?0000
0080P8200P3oool20820P08000000P20P8030?ooo`030820P000000000000080P8200`00002;0?oo
o`P0dLfY00070=7=ZH`0oooo00@0P8200?ooo`3oool0oooo0P0000050?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`000000300000000`3oool000000?ooo`030?ooo`040000003oool0
oooo000000D0oooo0P0000030?ooo`030820P03oool0oooo08X0oooo203AcJT000L0dLfYS@3oool0
0`000000P8200820P0020?ooo`060820P000000000000820P0000000oooo0P0000060820P0l00000
1P20P802000000030?ooo`000000P8200080000000<0P8200?ooo`3oool00P20P8000`000000oooo
0?ooo`2;0?ooo`P0dLfY00070=7=ZHh0oooo1@20P8020?ooo`80P82000@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0?00000080oooo00@000000?ooo`3oool000000P3oool00`000000
P8200820P0020?ooo`D0P820SP3oool80=7=Z@001`3AcJV>0?ooo`D0P8200P3oool20820P0040000
003oool0oooo00000080oooo00<000000?ooo`3oool03`0000020?ooo`040000003oool0oooo0000
0080oooo00<000000820P020P8000P3oool50820P8h0oooo203AcJT000L0dLfYT03oool01P000000
oooo0?ooo`000000P8200?ooo`80P8200P0000001@3oool000000820P0000000P8200140000000D0
P82000000020P80000000?ooo`0200000080P82000<0oooo0820P00000000P3oool00`000000oooo
0?ooo`2>0?ooo`P0dLfY00070=7=ZI40oooo00<0P8200000000000000`3oool010000000oooo0?oo
o`0000020820P080oooo4@0000020?ooo`80P82000@000000?ooo`3oool000000`3oool200000003
0820P03oool0oooo08l0oooo203AcJT000L0dLfYTP3oool3000000030820P0000000000000800000
0P20P8000`3oool0P8200000000B000000040820P03oool0P8200820P0@0000000@0P82000000000
00000000TP3oool80=7=Z@001`3AcJVC0?ooo`030820P03oool0oooo008000000P3oool010000000
oooo0?ooo`3oool2000000030?ooo`000000000000/0000000<0oooo0000000000000`3oool00`00
0000oooo0?ooo`0200000080oooo00<0P8200?ooo`3oool0T@3oool80=7=Z@001`3AcJVD0?ooo`04
00000020P800oooo0?ooo`80P82000@000000820P000000000000P20P80?00000080P8200P000000
1020P80000000820P020P8020?ooo`030820P0000000oooo09<0oooo203AcJT000L0dLfYU@3oool5
0820P080oooo0P0000020?ooo`l000000P3oool200000080oooo1@20P82E0?ooo`P0dLfY00070=7=
ZIH0oooo00H000000?ooo`3oool0oooo00000020P8020?ooo`030820P0000000000000l0000000D0
P8200?ooo`3oool0P820000000030?ooo`030000003oool0oooo09@0oooo203AcJT000L0dLfYU`3o
ool01020P80000000000000000040?ooo`H0000000D0oooo00000000000000000?ooo`06000000@0
oooo0`0000000`20P800oooo0?ooo`2E0?ooo`P0dLfY00070=7=ZIP0oooo100000000`20P800oooo
000000020820P00400000020P800P8200820P080000000<0oooo0000000000000`20P8001P000000
P8200820P0000000oooo0820P0@00000V03oool80=7=Z@001`3AcJVH0?ooo`@0000000<0P8200?oo
o`0000000P20P80010000000P8200820P020P802000000030?ooo`000000000000<0P82000H00000
0820P020P80000000?ooo`20P804000009P0oooo203AcJT000L0dLfYVP3oool01020P800oooo0?oo
o`0000020820P0040?ooo`20P800oooo0?ooo`80P82000<000000820P00000000P20P8020?ooo`05
0820P03oool0P8200820P00000000P3oool00`20P800oooo0?ooo`2H0?ooo`P0dLfY00070=7=ZI/0
oooo00H000000820P03oool0oooo0000003oool40820P0050?ooo`20P800oooo0820P03oool01020
P8001P3oool000000?ooo`3oool0P820000009/0oooo203AcJT000L0dLfYW03oool40820P0060000
003oool0oooo0?ooo`000000oooo0`20P8000`3oool000000?ooo`020?ooo`0300000020P800P820
0080P820W03oool80=7=Z@001`3AcJVM0?ooo`030000003oool0oooo008000000P20P8030?ooo`04
0000003oool0oooo0?ooo`80P8200P0000020?ooo`030000003oool0oooo09/0oooo203AcJT000L0
dLfYWP3oool01020P80000000000003oool2000000070?ooo`20P80000000?ooo`000000P8200?oo
o`02000000040?ooo`00000000000820P9h0oooo203AcJT000L0dLfYW`3oool3000000@0P8200`3o
ool40820P0<00000W`3oool80=7=Z@001`3AcJVP0?ooo`050820P03oool0oooo0?ooo`0000001@3o
ool01@000000oooo0?ooo`3oool0P8200:00oooo203AcJT000L0dLfYX@3oool00`000000P8200820
P0070?ooo`80P82000<000000?ooo`3oool0W`3oool80=7=Z@001`3AcJVR0?ooo`/0P820XP3oool8
0=7=Z@001`3AcJVR0?ooo`/0P820XP3oool80=7=Z@001`3AcJVT0?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0XP3oool80=7=Z@001`3AcJVU0?ooo`050820P000000000000000
0020P800Y@3oool80=7=Z@001`3AcJVV0?ooo`<00000YP3oool80=7=Z@001`3AcJVW0?ooo`030820
P03oool0oooo0:D0oooo203AcJT00?l0dLfYG`3AcJT00?l0dLfYG`3AcJT00?l0dLfYG`3AcJT00001
\
\>"],
  ImageRangeCache->{{{0, 349.563}, {173.625, 0}} -> {-6.54081, -3.00078, \
0.898499, 0.898499}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A CATALOG OF IRREDUCIBLE TOTALISTIC TETRADIC CA", "Section"],

Cell[TextData[{
  "Of the ",
  Cell[BoxData[
      \(TraditionalForm\`4\^\(4\^3\)\)]],
  " = 340282366920938463463374607431768211456 tetradic rules, only 196608 are \
totalistic, which prompt us to attack the problem of generating all \
irreducible totalistic ones. They turned out to be 21523 and are stored in \
file totalistic4, a sample of which follows."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(b = 4;\)\), "\[IndentingNewLine]", 
    \(\(cS = cellularSpace[101];\)\), "\[IndentingNewLine]", 
    \(\(allRules = << totalistic4;\)\), "\[IndentingNewLine]", 
    \(\(g = 
        Map[showCA[b, cS, #, 50, 1, 1, 101, 0] &, 
          Take[allRules, {100, 20000, 100}]];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Partition[g, 5]], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input",
  CellLabel->"In[139]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 4.02457 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0958231 0.190476 [
[ 0 0 0 0 ]
[ 1 4.02457 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 4.02457 L
0 4.02457 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0958231 0.200176 0.183133 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00000000AAFFAAAA0055FFAAFFFFFFFFAAFF55AA55FFAA0000FFAAFFFFFFFFFFFFAA00
00FFAAAA5500FF5500AAAA55FFAA00AAFF55AAAA0055FF0055AAAAFF0000AAFFFFFFFFFF
FFAAFF0000AAFF55AA55FFAAFFFFFFFFAAFF5500AAAAFFAA00000000FF
FFFF00FFFF005500AAAAAAFF000000000000FFAAAA000055FFAAFF0055000000550000FF
FFAA00AAAAFFFFFF55AA00AA00FF00FF00AA00AA55FFFFFFAAAA00AAFFFF000055000000
5500FFAAFF550000AAAAFF000000000000FFAAAAAA005500FFFF00FFFF
FFFFFF00AAFFFF55AA00AAAA55FFAAFF55AAFF0000FFFFAAAA5555FFAAAAAAAAAAFFFFAA
00FF00FF0000550000AA55FF00FFAAFF00FF55AA0000550000FF00FF00AAFFFFAAAAAAAA
AAFF5555AAAAFFFF0000FFAA55FFAAFF55AAAA00AA55FFFFAA00FFFFFF
FFFFFFFF00000000AA55FF005555FF00AA00AAFF55AAAA555555005500FF5500AAAA55AA
55FF55AAAAAAAAFFFF0000AAFF555555FFAA0000FFFFAAAAAAAA55FF55AA55AAAA0055FF
005500555555AAAA55FFAA00AA00FF555500FF55AA00000000FFFFFFFF
FFFFFFFFFF00FFFF005555FFAAAAFF00FF00FF00AA00AAAAFFAAAAAAFFFFFF55AA005555
550000AA5555AA00FFAAFF550000AA000055FFAAFF00AA5555AA000055555500AA55FFFF
FFAAAAAAFFAAAA00AA00FF00FF00FFAAAAFF555500FFFF00FFFFFFFFFF
FFFFFFFFFFFF00AAFFFF55FF5500FFAA55AAFF00FF00FF000000FF0000550000AAAAAAFF
AAAAAAAA0000AAAAAA5555FFFF00FF00FFFF5555AAAAAA0000AAAAAAAAFFAAAAAA000055
0000FF000000FF00FF00FFAA55AAFF0055FF55FFFFAA00FFFFFFFFFFFF
FFFFFFFFFFFFFF00000000AAFFAAFF0000AA55AAFF00FFAAFF55AAAAAAAAFFFF0000FF55
55AA00AAAAAAAA00AAAAFFAA00FFFFFF00AAFFAAAA00AAAAAAAA00AA5555FF0000FFFFAA
AAAAAA55FFAAFF00FFAA55AA0000FFAAFFAA00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFF005500AAFFFF005555AAAAAA550000AA5555AA00FFAAFFFFFF
55FF00FF5500AAAAAA005500FFFFFFFFFF005500AAAAAA0055FF00FF55FFFFFFAAFF00AA
5555AA000055AAAAAA555500FFFFAA005500FFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00AAFFFF55AA00FFAAFFAAAA00AAAAFF55AA0000AAAAAA55000000
00AAFFFFFF55AA00AAAAAAFFFFFFFFFFFFFFAAAAAA00AA55FFFFFFAA0000000055AAAAAA
0000AA55FFAAAA00AAAAFFAAFF00AA55FFFFAA00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000AA55FF550000FF00FF000000AAAAAAAA00AAAAFFFFAA
FF5500000000AAAAAA0055FF5555FF5555FF5500AAAAAA0000000055FFAAFFFFAAAA00AA
AAAAAA000000FF00FF000055FF55AA00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF005555FFFFAAFF00FFAAFF55AA0055FF00FF00000000
FFAAAAAAAAAAAA00AA55FFFFFF55FF55FFFFFF55AA00AAAAAAAAAAAAFF00000000FF00FF
5500AA55FFAAFF00FFAAFFFF555500FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF55FF5555AAAAAA550000AAAAAAFF00FFAAFFFFAA
FF0000FF5500AAAAAA0000005500550055000000AAAAAA0055FF0000FFAAFFFFAAFF00FF
AAAAAA000055AAAAAA5555FF55FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000AAFFAAAA0055FFFFAA555555AAAAAA55000000
FFAAFFFFFF55AA00AAAAAAAAAAFF55FFAAAAAAAAAA00AA55FFFFFFAAFF00000055AAAAAA
555555AAFFFF5500AAAAFFAA00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF005500AAAAAAFF00AAAAFFAAAA00AAAAFFFFAA
FF0000000000AAAAAA0055FF0055005500FF5500AAAAAA0000000000FFAAFFFFAAAA00AA
AAFFAAAA00FFAAAAAA005500FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF55AA00AAAA55FF005500FF00FF00005500
FFAAFFFFAAFF5500AA55FFFFFFAAAAAAFFFFFF55AA0055FFAAFFFFAAFF00550000FF00FF
005500FF55AAAA00AA55FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000AA55FF005555FFAAAAAA55FF55AAFFAA
FF00550000FFAAAAAA0000000000FF0000000000AAAAAAFF00005500FFAAFFAA55FF55AA
AAAAFF555500FF55AA00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF005555FFAAAAFF0000FF55FF55FF00AA
AA55FFFFAAFF0000FF00FFFF00FFFFFF00FFFF00FF0000FFAAFFFF55AAAA00FF55FF55FF
0000FFAAAAFF555500FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF55FF5500FFAA55FF55FF55FF55AA
5500550000FFAAFFFFFFAA00FFFFFFFFFF00AAFFFFFFAAFF0000550055AA55FF55FF55FF
55AAFF0055FF55FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000AAFFAAFF0000AAFFAA000000AA
AAFFFF55AAFF0000000000FFFFFFFFFFFFFF0000000000FFAA55FFFFAAAA000000AAFFAA
0000FFAAFFAA00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF005500AAFFFF000000FFFF00FF
00000000AA55AAFFFFAAFFFFFFFFFFFFFFFFFFAAFFFFAA55AA00000000FF00FFFF000000
FFFFAA005500FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF55AA00FFAAFFFFAA00FFFF
FF00FFFF00555555FF5500000000000000000055FF55555500FFFF00FFFFFF00AAFFFFAA
FF00AA55FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000AA55FF55000000FFFFFF
FFFF00AAFFFF55FFFFFF55AAFFFFAAFFFFAA55FFFFFF55FFFFAA00FFFFFFFFFF00000055
FF55AA00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF005555FFFFAAFFFFFFFF
FFFFFF0000550055000000AAAA55AA55AAAA0000005500550000FFFFFFFFFFFFFFAAFFFF
555500FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF55FF5555AAAA55AA
AA55AAAAAAAAFF55FFAA55FF0055555500FF55AAFF55FFAAAAAAAA55AAAA55AAAA5555FF
55FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000AAFFAAAA005555
555500AA5555AAAAFF0000AAFFFF55FFFFAA0000FFAAAA5555AA005555555500AAAAFFAA
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF005500AAAAAAFF
AAAAFF550055555555FFAA5555FF55FF5555AAFF555555550055FFAAAAFFAAAAAA005500
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF55AA00AAAA
5555AAAAFFFF55FFFF5555550055005500555555FFFF55FFFFAAAA5555AAAA00AA55FFFF
AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000AA55FF00
555500FF5555FFFFFFFF55FFFFAAAAAAFFFF55FFFFFFFF5555FF00555500FF55AA000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF005555FF
AAAAFF5555005500005500550000FF0000550055000055005555FFAAAAFF555500FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF55FF
5500FFAAAAFF55FFAAFFAAFFAAFFFFFFAAFFAAFFAAFF55FFAAAAFF0055FF55FFFFAA00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000AA
FFAAFF0055AAAAFF000055FF5500000055FF550000FFAAAA5500FFAAFFAA00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00
5500AAFFFF5500FFAAFF55FF55FFAAFF55FF55FFAAFF0055FFFFAA005500FFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF
FF55AA00FFAAAAAA5555FFFFFF555555FFFFFF5555AAAAAAFF00AA55FFFFAA00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000AA55FF5500FF55FFFFFFFFFF55FFFFFFFFFF55FF0055FF55AA00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF005555FFFFAA00005500005500550000550000AAFFFF555500FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00AAFFFF55FF5555AAFFFF55AAFFAAFFAA55FFFFAA5555FF55FFFFAA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000AAFFAAAA00FFAAAA00FF00AAAAFF00AAAAFFAA00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFF005500AAAAAA5500FFFFFF0055AAAAAA005500FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00AAFFFF55AA00AAAAFFFFFFFFFFAAAA00AA55FFFFAA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000AA55FF00550000005500FF55AA00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFF005555FFAAAAAAAAAAFF555500FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00AAFFFF55FF5500FF0055FF55FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000AAFFAA55AAFFAA00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFF005500AA005500FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00AAFFFF55AA55FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000555555000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFF55FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AAFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.0958231 0.39418 0.183133 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000555555AA0055FFFF550055AAAAFF55AAAA000000FF55FFFF00FF00FF00FF00FF00
550055005555AA55000055AA55AA55AA55AA55000055AA55550055005500FF00FF00FF00
FF00FFFF55FF000000AAAA55FFAAAA550055FFFF5500AA5555550000FF
FFFF00FF550000FFFF5555FFFF00555555FF0000FFFFAA55AA55AAAAAA55FF55AAAAAA55
FF00FF55AA555555AAFF550055005500550055FFAA555555AA55FF00FF55AAAAAA55FF55
AAAAAA55AA55AAFFFF0000FF55555500FFFF5555FFFF000055FF00FFFF
FFFFFF00AAAAAAAA55AA5555FF55AA5555AAAAAAAA55AA00AA55555500AAAA5555555555
AAAAAA55550000005555FF00FF55AA55FF00FF55550000005555AAAAAA5555555555AAAA
00555555AA00AA55AAAAAAAA5555AA55FF5555AA55AAAAAAAA00FFFFFF
FFFFFFFF0000FF000000AAAAFF0055AA555500555500FF00FF0055FFFF0000FF55000055
00555555AA55FFAA5555AAAAAA555555AAAAAA5555AAFF55AA5555550055000055FF0000
FFFF5500FF00FF005555005555AA5500FFAAAA000000FF0000FFFFFFFF
FFFFFFFFFF00FFAAFFFF0000FFAA555555AA55FFFF55AAAAAA55FFFFFFFF00FFAAAAAAAA
FFFF550000FF555555AA55005555AA55550055AA555555FF000055FFFFAAAAAAAAFF00FF
FFFFFF55AAAAAA55FFFF55AA555555AAFF0000FFFFAAFF00FFFFFFFFFF
FFFFFFFFFFFF00AA55AAAAAAAA550000005555AAAA5555555555AAAA55AAAAAA55005555
55FF55FFAAFF00550000FF55AA555555AA55FF00005500FFAAFF55FF5555550055AAAAAA
55AAAA5555555555AAAA555500000055AAAAAAAA55AA00FFFFFFFFFFFF
FFFFFFFFFFFFFF00005555555555AAFFFF005500AA5555AA5555AA000055555500FFFF55
FFFFFF555555FFAAAAAAAA555555AA555555AAAAAAAAFF555555FFFFFF55FFFF00555555
0000AA5555AA5555AA005500FFFFAA55555555550000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF5500000055AAAA55FF00FF0055005500FF00FFFF5500FFFFFFFF
5555FF55FFFF555555555555AA555555AA555555555555FFFF55FF5555FFFFFFFF0055FF
FF00FF0055005500FF00FF55AAAA5500000055FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00AAAAAAAAAA0000AAAA55FF55AA55FF00FFAA55AAAAFFFFFFFFFF
FF55FF55FF5555AA5555AA555555AA555555AA5555AA5555FF55FF55FFFFFFFFFFFFAAAA
55AAFF00FF55AA55FF55AAAA0000AAAAAAAAAA00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF0000FFFF0000AAAA555555AAAAAA550000AA55AAAA55AA
AA5555FFFFFF55005500FF005500FF005500FF00550055FFFFFF5555AAAA55AAAA55AA00
0055AAAAAA555555AAAA0000FFFF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFAAFFFFFFFF00FF0000000055555500FFFF000055550000
FF0055FF5555FF00FF55AAAAAAFFFFFFAAAAAA55FF00FF5555FF5500FF000055550000FF
FF0055555500000000FF00FFFFFFFFAAFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AA55AAAA55AAFF00FFFF00FF5500FFFFFFFFAA5555AAFF
FFFFAAAA5555AAAAAA5555555555FF5555555555AAAAAA5555AAAAFFFFFFAA5555AAFFFF
FFFF0055FF00FFFF00FFAA55AAAA55AA00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000555555AA00FFFFFFFF00AAAAAA55AAAA55000055AA
AA55AA005500FF0000FF55FFFF55FF55FFFF55FF0000FF005500AA55AAAA55000055AAAA
55AAAAAA00FFFFFFFF00AA5555550000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF550000FFFFFFFFFFFF0000FF00555500FFFF0055
5500FF00FF55AAAAAAAA5555FF55FF55FF5555AAAAAAAA55FF00FF00555500FFFF005555
00FF0000FFFFFFFFFFFF000055FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAA55AAAA55AAAAAAAA55FFFF55AAAA55FF
FF55AAAAAA555555555555AA55AA55AA55AA555555555555AAAAAA55FFFF55AAAA55FFFF
55AAAAAAAA55AAAA55AAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000AA555555555555AAAA55555555AA
AA555555005500000000550055005500550055000000005500555555AAAA55555555AAAA
555555555555AA000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAFFFF0000000000000000FF0055000055
55000055FFAAAAAAAAAAAAFFFF55AA55FFFFAAAAAAAAAAAAFF550000555500005500FF00
00000000000000FFFFAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AAAAAAAAAAAAAAAAAAAA55FFFFAA55
55AAFFFF5555555555555555FF550055FF5555555555555555FFFFAA5555AAFFFF55AAAA
AAAAAAAAAAAAAAAA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00005555555555555555550055FF555500
005555FF5500000000005500FFAAAAAAFF0055000000000055FF555500005555FF550055
55555555555555550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF5500000055FF0055FFAAAA5555AA
FF5500FFAAAAAAAAAAAAAAFF5555555555FFAAAAAAAAAAAAAAFF0055FFAA5555AAAAFF55
00FF5500000055FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAAAA00FFFF555555000055
AAAAFF5555555500AA005555FF005500FF555500AA0055555555FFAAAA550000555555FF
FF00AAAAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFFFFFFF5500FFFF00
555555FF0055FF00FF00FF55FF55AA55FF55FF00FF00FF5500FF55555500FFFF0055FFFF
FFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAFFFFFFFFFFFF55AAAA55
FFFF55FF55AA55AAFF00FFAAAA555555AAAAFF00FFAA55AA55FF55FFFF55AAAA55FFFFFF
FFFFFFAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AAAA55AAAA55555555
AAAA5555FF000000FFAA55AA0000000000AA55AAFF000000FF5555AAAA55555555AAAA55
AAAA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000555555AA0055FFFF55
00AA5555AAAAAAAAAA550000FFFF00FFFF000055AAAAAAAAAA5555AA0055FFFF5500AA55
55550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF550000FFFF5555FF
FF000000555555550055FFAA55AAAAAA55AAFF550055555555000000FFFF5555FFFF0000
55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAA55AA5555
FF55AAFF55000055FFAAAA550000FF000055AAAAFF55000055FFAA55FF5555AA55AAAAAA
AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000AAAA
FF005555FFFF00FF55555555AAFFFFFFAA55555555FF00FFFF555500FFAAAA000000FF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAFFFF0000
FFAA5555AAAA55FF550000005555FF555500000055FF55AAAA5555AAFF0000FFFFAAFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AAAAAA
AA55000000AA5555FF00FFFF0055FF5500FFFF00FF5555AA00000055AAAAAAAA55AA00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000555555
5555AAFFFF000055FF55AAAA55FFFFFF55AAAA55FF550000FFFFAA55555555550000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF5500
000055AAAA55FFAAAA555500AAAA55AAAA005555AAAAFF55AAAA5500000055FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAA
AAAAAA0000FF55550055FF00FF000000FF00FF55005555FF0000AAAAAAAAAA00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000FFFF00AAAAFF55FF55AAAAAAAAAA55FF55FFAAAA00FFFF0000FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFAAFFFFFFFF0000FFAAAA55555555555555AAAAFF0000FFFFFFFFAAFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00AA55AAAA55AAFF55550055FFFF55FFFF55005555FFAA55AAAA55AA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000555555AA00FF55FFAAAA55AA55AAAAFF55FF00AA5555550000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF550000FFFFFF555500550055005555FFFFFF000055FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00AAAAAAAA55AAAAFFAAFFAAFFAAFFAAAA55AAAAAAAA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FF000000AA55AA00FF00AA55AA000000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFAAFFFF000000FFFFFF000000FFFFAAFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00AA55AAAAAAAAAA55AAAAAAAAAA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000055555555005500555555550000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF5500FF55AA55FF0055FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00AAAAAA555555AAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF005500FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFAAFFAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.0958231 0.588183 0.183133 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00AAAAAAAA00AAAAFF55AAAAAA0055000000550000FF0000FFAAAAAA00FFAAFFFF00FF
550000AAAA00FFFF00FFAAAA55FFFFFF55AAAAFF00FFFF00AAAA000055FF00FFFFAAFF00
AAAAAAFF0000FF0000550000005500AAAAAA55FFAAAA00AAAAAAAA00FF
FFFF00AAFF0000AAFF005500AA55AAFFAAFFFFAAAAAAAA0000AAAA55AAAAAA00FF550055
FFFF00FF00AA00AAAAAA00FFAAAA00AAAAFF00AAAAAA00AA00FF00FFFF550055FF00AAAA
AA55AAAA0000AAAAAAAAFFFFAAFFAA55AA005500FFAA0000FFAA00FFFF
FFFFFF00AAAAAAAA55550000AAFFAA00AA5555AA0055AA0000AA550000FF0000AAAAFFFF
5500FFFFFF00AA00FF00AA00AA550055AA00AA00FF00AA00FFFFFF0055FFFFAAAA0000FF
000055AA0000AA5500AA5555AA00AAFFAA00005555AAAAAAAA00FFFFFF
FFFFFFFF00AAFF00000000AA0055FF55AAAAFFAA000000FFFF0000555500FFFF0000FF55
0000AAAA00AA00FFFFFF00AA0055005500AA00FFFFFF00AA00AAAA000055FF0000FFFF00
55550000FFFF000000AAFFAAAA55FF5500AA00000000FFAA00FFFFFFFF
FFFFFFFFFF00AAAAAAAAAAAA55FFFFFF555555AAAAAAAAAA00AA00000000AAAA0000AAAA
FFFFAA0055555500FF550055AAFFAAFFAA550055FF0055555500AAFFFFAAAA0000AAAA00
000000AA00AAAAAAAAAA555555FFFFFF55AAAAAAAAAAAA00FFFFFFFFFF
FFFFFFFFFFFF00AAFF0000FFAAAA00AAAAFFAAAA5500AA550055AAFFFF00FFAA0000AA55
00FF55550000550055FFFFAAAA555555AAAAFFFF55005500005555FF0055AA0000AAFF00
FFFFAA550055AA0055AAAAFFAAAA00AAAAFF0000FFAA00FFFFFFFFFFFF
FFFFFFFFFFFFFF00AAAAAAAA00FF00FF00AAAA550000AAFFAAFFAA00AAAAAA00FFFF0000
00AAAAFFAA55FFFFAAAA00AA5500000055AA00AAAAFFFF55AAFFAAAA000000FFFF00AAAA
AA00AAFFAAFFAA000055AAAA00FF00FF00AAAAAAAA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00AAFF0000AAAAAA0000FFAAAAAAAA5555FF00AA00FF00AA00AAAAAA
AAAA5500FFAAAA00AAFF00FFAAAAAAAAAAFF00FFAA00AAAAFF0055AAAAAAAAAA00AA00FF
00AA00FF5555AAAAAAAAFF0000AAAAAA0000FFAA00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00AAAAAAAA55AAAAAAAA00FF00AAFFAAAA0000FFFFFF00AA00FF00
00FFAAAAAA00FFAAFF005555AA00FF00AA555500FFAAFF00AAAAAAFF0000FF00AA00FFFF
FF0000AAAAFFAA00FF00AAAAAAAA55AAAAAAAA00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00AAFF000000FFAA00FFFFFF00AAAA55AAFFFFFFFFFF0000AAAA
AAAA00FF00AA00AA5555000000FFFFFF0000005555AA00AA00FF00AAAAAAAA0000FFFFFF
FFFFAA55AAAA00FFFFFF00AAFF000000FFAA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AAAAAAAAAA00FFFFFFFFFF00AAFFAA00AAAA00AAAAAAAA55
AA00FFFFFF0000AAFFAAAAAAAAAA00AAAAAAAAAAFFAA0000FFFFFF00AA55AAAAAAAA00AA
AA00AAFFAA00FFFFFFFFFF00AAAAAAAAAA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AAFF0000FFFFFFFFFFFFFFAA00AA55FF555500AAFF0000
00FFFFFFFFFFAAFF0055AAAA55AAAAAA55AAAA5500FFAAFFFFFFFFFF000000FFAA005555
FF55AA00AAFFFFFFFFFFFFFF0000FFAA00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAA00AAAA00AAAA005555FFFFFF55FFAA00AA00
00AAAA00AAAA0055FFAAAA550000FF000055AAAAFF5500AAAA00AAAA0000AA00AAFF55FF
FFFF555500AAAA00AAAA00AAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF0000AAFF00FFAA00000055FF005500FF00FFAA
FF55555500AAFFFF5500AAFFAAFFFFFFAAFFAA0055FFFFAA00555555FFAAFF00FF005500
FF55000000AAFF00FFAA0000FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAA555500FFAAFFFFAAAA000000AAAAAA00
55FFFF55FFAA00AAAAFF5555AAAA00AAAA5555FFAAAA00AAFF55FFFF5500AAAAAA000000
AAAAFFFFAAFF005555AAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF00000000AAAA5555AA00FFFF00FF00AA55
FFFFFFFF5500AA00FF00550000FF00FF00005500FF00AA0055FFFFFFFF55AA00FF00FFFF
00AA5555AAAA00000000FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAAAAAA55000000FFFFFFFF005555FF
FFFFFFFFFF55AAAAAA000000AA00AA00AA000000AAAAAA55FFFFFFFFFFFF555500FFFFFF
FF00000055AAAAAAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF0000FFAAAAAAAAAA00AAAA00005500
FF5500FF550000FFAA0000AA0055555500AA0000AAFF000055FF0055FF00550000AAAA00
AAAAAAAAAAFF0000FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAA00FF0000FFAA5500AA000000
AAAAFF550000AA00AA55FFAA0000000000AAFF55AA00AA000055FFAAAA000000AA0055AA
FF0000FF00AAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF0000AAAAAAAA00550055AAFFFF
AA0055FFFFAAFF00FFAAAA00555500555500AAAAFF00FFAAFFFF5500AAFFFFAA55005500
AAAAAAAA0000FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAA55AAAA55FFFFAAAA5555
AA000055FF00AAAAAA00FFAAFFAAAAAAFFAAFF00AAAAAA00FF550000AA5555AAAAFFFF55
AAAA55AAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF000000FFAAAA00AA550000
00FFFFAAAA0000FF0000AAAA5555555555AAAA0000FF0000AAAAFFFF00000055AA00AAAA
FF000000FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAAAA00FF00FFAAAAAA
AAAA00AA55AAFFFFFF00FF00000000000000FF00FFFFFFAA55AA00AAAAAAAAAAFF00FF00
AAAAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF0000FFFFFF0055AAAA
5500AA005500AAAA00AA00AA0000AA0000AA00AA00AAAA005500AA0055AAAA5500FFFFFF
0000FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAA00AAAAAAFF00
005555550000AAFF00FFAA55005555550055AAFF00FFAA00005555550000FFAAAAAA00AA
AAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF0000AAFF00AAAA
AAAAFFAAAAAAAA555500FFAAAAAAFFAAAAAAFF005555AAAAAAAAFFAAAAAAAA00FFAA0000
FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAA555500AA
5500AAAA5500AAFFAAAAAA00FFAA00AAFF00AAAAAAFFAA0055AAAA0055AA005555AAAAAA
AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF00000000AA
FFAAFF000000AA555555555500FF00FF005555555555AA000000FFAAFFAA00000000FFAA
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAAAAAA
555555AAFFFF00000000000000AAAAAA00000000000000FFFFAA555555AAAAAAAAAAAA00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF0000FF
AAAAFFAA00AAAAAAAAAAAAAAAAAA55AAAAAAAAAAAAAAAAAA00AAFFAAAAFF0000FFAA00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAA
00FF0055AAFF00AAFF0000FF00AAFFAA00FF0000FFAA00FFAA5500FF00AAAAAAAA00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF00
00AAAAAAFF00555555AAFFFFFFAA00AAFFFFFFAA55555500FFAAAAAA0000FFAA00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAA
AAAA55AAAA0000000000FF5500FF00FF0055FF0000000000AAAA55AAAAAAAA00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA
FF000000FFAAFF55AAFF550000AAAAAA000055FFAA55FFAAFF000000FFAA00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
AAAAAAAAAA00FF55FF550000AA00FF00AA000055FF55FF00AAAAAAAAAA00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00AAFF0000FFFFFF550000AA00FFFFFF00AA000055FFFFFF0000FFAA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00AAAAAAAA00AAAAFF55AAAAAA00AAAAAA55FFAAAA00AAAAAAAA00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00AAFF0000AAFF005500AA550055AA005500FFAA0000FFAA00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00AAAAAAAA55550000AAFFAAFFAA00005555AAAAAAAA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00AAFF00000000AA0055FF5500AA00000000FFAA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00AAAAAAAAAAAA55FFFFFF55AAAAAAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00AAFF0000FFAAAA00AAAAFF0000FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00AAAAAAAA00FF00FF00AAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00AAFF0000AAAAAA0000FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00AAAAAAAA55AAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00AAFF000000FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AAAAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.0958231 0.782187 0.183133 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000055AAFFFFFFAA00AA5555FF55555555AAFFFFFF5555555555555555555555555555
55555555FFFFFFAA550000FFFFFFFFFFFFFF000055AAFFFFFF5555555555555555555555
55555555555555FFFFFFAA55555555FF5555AA00AAFFFFFFAA550000FF
FFFF00FF5555555555FFAA00AA00555500FF555555555500000000005500000000000055
5500005555555555FF00FFFFFFFFFFFFFFFFFF00FF555555555500005555000000000000
5500000000005555555555FF00555500AA00AAFF5555555555FF00FFFF
FFFFFF00005555000055AAAAAA55FFFF55AA00000055FF00FFFF00FFFF55AAFFFFAA55FF
FF55AAFFAAAA000000FFFFFFFFFFFFFFFFFFFFFF000000AAAAFFAA55FFFF55AAFFFFAA55
FFFF00FFFF00FF55000000AA55FFFF55AAAAAA55000055550000FFFFFF
FFFFFFFF00FF55FFAA5555FF5555AA005555FFAA55FFFFFF0000FFFFFFFF55555555FF00
00FF555555FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF555555FF0000FF55555555FF
FFFFFF0000FFFFFF55AAFF555500AA5555FF5555AAFF55FF00FFFFFFFF
FFFFFFFFFF000055AAAA0000FF55FF55AA555555FFFFFFFFFFAA5500AA550000550055AA
FFFFFF550000FF555555555555555555555555555555FF000055FFFFFFAA550055000055
AA0055AAFFFFFFFFFF555555AA55FF55FF0000AAAA550000FFFFFFFFFF
FFFFFFFFFFFF00FF5555FFAA550000FF5555AA55555555555555FFFF00AAAAAAAAFFFF55
55555555AAFFFFFF5500005500FF55FF0055000055FFFFFFAA5555555555FFFFAAAAAAAA
00FFFF55555555555555AA5555FF000055AAFF5555FF00FFFFFFFFFFFF
FFFFFFFFFFFFFF0000555555FFFF00FF0055FF550000000055FFFFFFFF00AAFF00AA5500
0055FFFF5555555555AAFFFF55AA00AA55FFFFAA5555555555FFFF55000055AA00FFAA00
FFFFFFFF550000000055FF5500FF00FFFF5555550000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF55FF0000FFFFFF0055AA55FFAA55FFFFFFFFFFFF00AA55FF55FF
AA55555555005500FF55555555AAAAAA55555555FF00550055555555AAFF55FF55AA00FF
FFFFFFFFFF55AAFF55AA5500FFFFFF0000FF55FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000055AAFFFFFFFFFFAAAA555555FFFFFFFFFFFFFFFFAA00AA5555
55FF005555AAFFAA550000005555FF555500000055AAFFAA555500FF555555AA00AAFFFF
FFFFFFFFFFFF555555AAAAFFFFFFFFFFAA550000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF55555555555555FF550055555555555555555555FFAA00AA
00AA55FFFF555555FFFFAAFF55FFFFFF55FFAAFFFF555555FFFF55AA00AA00AAFF555555
555555555555550055FF55555555555555FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00005555000055FFFFFF55AA55550000555500000055AAAAAA
55FF5500AA55550000FF00AA5555555555AA00FF00005555AA0055FF55AAAAAA55000000
555500005555AA55FFFFFF55000055550000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF55FFAA5555555555AAAAFFAA55FFFF55AAFFFF5555FF
5500AAAAAA5555AAFFFFFFAA0000AA0000AAFFFFFFAA5555AAAAAA0055FF5555FFFFAA55
FFFF55AAFFAAAA5555555555AAFF55FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000055AAAA00000055FF555555FFFFFFFF555555550055
AA55FF5555FFFF5555555555FFAA55AAFF5555555555FFFF5555FF55AA550055555555FF
FFFFFF555555FF55000000AAAA550000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF5555FFAA55FF0000550000FF0000FF5500FF55AA
55AA55005500AA555500005500AAFFAA005500005555AA00550055AA55AA55FF0055FF00
00FF0000550000FF55AAFF5555FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000555555FFFFFFAAFFAAFFFFFFAA5500FFFFFF55
55AAAAFF55FFAA00AAAAAAAAFF555555FFAAAAAAAA00AAFF55FFAAAA5555FFFFFF0055AA
FFFFFFAAFFAAFFFFFF5555550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FF0000FF00AA55AA0055AAAAFFFFFFFFFF
55FF55555500AAFF5555FF555555AA555555FF5555FFAA00555555FF55FFFFFFFFFFAAAA
5500AA55AA00FF0000FF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055AAFFFFFFAA00AAFF55FF555555555555
55AA00AAAAFF555555AA55000055FF55000055AA555555FFAAAA00AA55555555555555FF
55FFAA00AAFFFFFFAA550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF5555555555FFAA0055555500555500FF
55FF55AAAA55000055FF55FFAA555555AAFF55FF55000055AAAA55FF55FF005555005555
5500AAFF5555555555FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00005555000055AAAAAAFFAAAAAAFFAA55
0000FF5555FFFFAA555555AA00FF55FF00AA555555AAFFFF5555FF000055AAFFAAAAAAFF
AAAAAA55000055550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FFAA5555FF555555FF555555FF
FF00FF0055555555FFFF55FF55AA00AA55FF55FFFF5555555500FF00FFFF555555FF5555
55FF5555AAFF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055AAAA0000FF55FFFFFF55FF00
00FFFFFF0055005500AA555555AAAAAA555555AA0055005500FFFFFF0000FF55FFFFFF55
FF0000AAAA550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF5555FFAA550000FF000055AA
FFFFFFFFFFAAAAAAFF5555AA5555FF5555AA5555FFAAAAAAFFFFFFFFFFAA550000FF0000
55AAFF5555FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000555555FFFF00FF00FFFF55
555555555555FF555555AA55AA555555AA55AA555555FF55555555555555FFFF00FF00FF
FF5555550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FF0000FFFFFF0000FF
55005500000000FF55FF00AA00FF55FF00AA00FF55FF00000000550055FF0000FFFFFF00
00FF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055AAFFFFFFFFFFAA55
00FFFF55AAFF55AA00AA55FF55AA00AA55FF55AA00AA55FFAA55FFFF0055AAFFFFFFFFFF
AA550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55555555555555FF
FF0000FF555555AAAAAA555555AAAAAA555555AAAAAA555555FF0000FFFF555555555555
55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00005555000055FFFF
FFFFAA5500005555FF5555005555FF5555005555FF5555000055AAFFFFFFFF5500005555
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FFAA555555
555555FF00FFFF5500AAAAFF55FFFFFF55FFAAAA0055FFFF00FF555555555555AAFF55FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055AAAA0000
55550000FFFFFFFF55AAAA550000FF000055AAAA55FFFFFFFF000055550000AAAA550000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF5555FFAA
5555AAFFFFFFFFFFFF5555FF00FFFFFF00FF5555FFFFFFFFFFFFAA5555AAFF5555FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000555555
FFFF55555555555555550000FFFFFFFFFF00005555555555555555FFFF5555550000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FF
0000FF55005555AA5555AAFFFFFFFFFFFFFFAA5555AA55550055FF0000FF55FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055
AAFFFFFF55AA5555FFFF555555555555555555FFFF5555AA55FFFFFFAA550000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
5555555555AAAA00AA55005500FF55FF00550055AA00AAAA5555555555FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
005555005555FF55AAAAFFFF55AA00AA55FFFFAAAA55FF55550055550000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF55FFAAAA0055FF55555555AAAAAA55555555FF5500AAAAFF55FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000055AAAA55FFFFFF55005555FF55550055FFFFFF55AAAA550000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF5555FFFFFFFFFF55AA555555AA55FFFFFFFFFF5555FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000055555555555555AAAAFFAAAA555555555555550000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF55FF00550055FF555555FF55005500FF55FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000055AAFFAA555555AA555555AAFFAA550000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF555555FFFF55FF55FFFF555555FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000555500AA555555AA0055550000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF55FFAA000000AAFF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000055AAAAAAAAAA550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF5555FF5555FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00005555550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.0958231 0.97619 0.183133 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0055FFAAFFAAFFFF00FFFF550000AA00FFAAFF5500FF0055555555AAAA0000FF55AA55
550055AAFFFF000000AA005555000000555500AA000000FFFFAA55005555AA55FF0000AA
AA5555555500FF0055FFAAFF00AA000055FFFF00FFFFAAFFAAFF5500FF
FFFF0055555500AA000000AA00FFFF000055555500FFFFFF0055FF00AA5500005555AA00
FFAA5555550055000055AAFFAAAAAAAAAAFFAA5500005500555555AAFF00AA5555000055
AA00FF5500FFFFFF005555550000FFFF00AA000000AA0055555500FFFF
FFFFFF0055FFFF0000000000FFFFFFFFAA55AAAAFFFFFFFFFFAA000055AAAAAAAAFF0000
00AA5555AAAAAAFFFFAA005555555555555500AAFFFFAAAAAA5555AA000000FFAAAAAAAA
550000AAFFFFFFFFFFAAAA55AAFFFFFFFF0000000000FFFF5500FFFFFF
FFFFFFFF005555000055000000AA0000AA555555550055550055AAFF5555555555550000
0055AA55555555550055AAFFAAAA55AAAAFFAA55005555555555AA550000005555555555
55FFAA550055550055555555AA0000AA000000550000555500FFFFFFFF
FFFFFFFFFF0055FFAAFFAAFFFF00000000FFAAAAFFAA5555AAFF0000AAAA55AA5555AAFF
FF0055AAAA00FFAAAAAA550055AA00AA550055AAAAAAFF00AAAA5500FFFFAA5555AA55AA
AA0000FFAA5555AAFFAAAAFF00000000FFFFAAFFAAFF5500FFFFFFFFFF
FFFFFFFFFFFF0055555500AA000000000000AA550055AAAA5500550000FF0055AA555555
005500FF00005555555555AAFF000000FFAA55555555550000FF005500555555AA5500FF
0000550055AAAA550055AA000000000000AA0055555500FFFFFFFFFFFF
FFFFFFFFFFFFFF0055FFFF0000000000000000FFAAFF0000FFAAFF00FFFFFF00AA5555AA
AAAAFFFFFFAA55AA55AA555555000000555555AA55AA55AAFFFFFFAAAAAA5555AA00FFFF
FF00FFAAFF0000FFAAFF0000000000000000FFFF5500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF005555000055000000000055555500005555550000AA000000FF5555
55555500555555AA00AA5555AAAAAAAAAA5555AA00AA555555005555555555FF000000AA
000055555500005555550000000000550000555500FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0055FFAAFFAAFFFF00FFFF5500FFFF0055FFFFAA550000005555FF
5555FFFF00AAAA550000FF55555555555555FF000055AAAA00FFFF5555FF555500000055
AAFFFF5500FFFF0055FFFF00FFFFAAFFAAFF5500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055555500AA000000AA00FFFFFFFF00AA0000FF55AAFFFF5500
55FFFFFFFF0000FFAAFFFFFF5555FF5555FFFFFFAAFF0000FFFFFFFF550055FFFFAA55FF
0000AA00FFFFFFFF00AA000000AA0055555500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0055FFFF0000000000FFFFFFFFFFFF0000005555AA0000AAAA
AA0000AA000000555555005555FFFFFF555500555555000000AA0000AAAAAA0000AA5555
000000FFFFFFFFFFFF0000000000FFFF5500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF005555000055000000AA0000AA0000000055FF00000000FF
00000000FFFF00FFAAAAFFFF5555005555FFFFAAAAFF00FFFF00000000FF00000000FF55
00000000AA0000AA000000550000555500FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0055FFAAFFAAFFFF00000000FFFFAAFF55550000005500
5500000055550000AA55005555AAAAAA55550055AA000055550000005500550000005555
FFAAFFFF00000000FFFFAAFFAAFF5500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0055555500AA000000000000AA005555FF00FFFFAAAA
AAFFFF00FF55000055AAAAAA5555555555AAAAAA55000055FF00FFFFAAAAAAFFFF00FF55
5500AA000000000000AA0055555500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFF0000000000000000FFFF55005500555555
555500550055FFAA5555555555AA55AA5555555555AAFF55005500555555555500550055
FFFF0000000000000000FFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055550000550000000000555500FFFF55AAAAFF
AAAA55FFFF00555555AAAA5555AA00AA5555AAAA55555500FFFF55AAAAFFAAAA55FFFF00
55550000000000550000555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFAAFFAAFFFF00FFFF550000AA00AA5500
55AA00AA000055FF55555555FF000000FF55555555FF550000AA00AA550055AA00AA0000
55FFFF00FFFFAAFFAAFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055555500AA000000AA00FFFF000055AAAA
AA550000FFFF00AA00FFAAAA0000000000AAAAFF00AA00FFFF000055AAAAAA550000FFFF
00AA000000AA0055555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFF0000000000FFFFFFFFAA555555
5555AAFFFFFFFF000000AA55000000000055AA000000FFFFFFFFAA5555555555AAFFFFFF
FF0000000000FFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555000055000000AA0000AA5555FF
5555AA0000AA0000000055AAAAAAAAAAAAAA5500000000AA0000AA5555FF5555AA0000AA
000000550000555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFAAFFAAFFFF00000000FF5500
55FF00000000FFFFAAFF555555555555555555FFAAFFFF00000000FF550055FF00000000
FFFFAAFFAAFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055555500AA000000000000AAAA
AA000000000000AA005555AA5555FF5555AA555500AA000000000000AAAAAA0000000000
00AA0055555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFF0000000000000000FF
0000000000000000FFFF555555FFFFFF555555FFFF0000000000000000FF000000000000
0000FFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555000055000000005500
5500000000000055005555AA5555005555AA555500550000000000005500550000000055
0000555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFAAFFAAFFFF00FFAA
55AAFFFF00FFFFAAAAAA555555AAAAAA555555AAAAAAFFFF00FFFFAA55AAFF00FFFFAAFF
AAFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055555500AA000000AA
5555550055005555555555AA5555555555AA5555555555005500555555AA000000AA0055
555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFF0000000000
FF5555AAFF00FFAAAAFF00AA5555AA5555AA00FFAAAAFF00FFAA5555FF0000000000FFFF
5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055550000550000
00AAAA5500550055AA000000FF555555FF000000AA5500550055AAAA0000005500005555
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFAAFFAAFF
FF0000FFAA55AAFF000000005555FF555500000000FFAA55AAFF0000FFFFAAFFAAFF5500
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055555500AA
00000000AA5555550000000055FFFFFF5500000000555555AA00000000AA0055555500FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFF00
0000000000FF5555AAFFFFAA5555005555AAFFFFAA5555FF000000000000FFFF5500FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555500
00550000005555AA5500555555FF00FF5555550055AA5555000000550000555500FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF
AAFFAAFF55AA555555AAFFAAAA000000AAAAFFAA555555AA55FFAAFFAAFF5500FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055
555500AA00AA5555FF0000AA5500000055AA0000FF5555AA00AA0055555500FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
55FFFF000000FF5555000055AAAAAAAAAA5500005555FF000000FFFF5500FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0055550000550055FFFFAA55555555555555AAFFFF5500550000555500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0055FFAAFFAA55550055AA55AA55AA55AA55005555AAFFAAFF5500FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0055555500AAFFAA555555AA00AA555555AAFFAA0055555500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0055FFFF0000AA5555FF000000FF5555AA0000FFFF5500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF005555000055AA55550000005555AA550000555500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0055FFAA555555FFFF00FFFF555555AAFF5500FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00555555FF00AA000000AA00FF55555500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0055FFFFFF0000000000FFFFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00555500550000005500555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0055FFAAAAAAAAAAFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF005555555555555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0055FF55FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AA00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.191864 0.200176 0.279175 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000555500550055000055555555005500FFFFAAAA000000AAFF00000055AA555500
555500555500FFFF55AA555500005500005555AA55FFFF005555005555005555AA550000
00FFAA000000AAAAFFFF005500555555550000550055005555000000FF
FFFFAA00005500550055AAAA5500005500550055FF00FFFFAA00FFFFFFAAFF0000005500
5500AA00550055FF00000055005555550055000000FF55005500AA00550055000000FFAA
FFFFFF00AAFFFF00FF5500550055000055AAAA55005500550000AAFFFF
FFFFFF00AA00555555FFFF00FF00AA0055555500AAAA5555AAFFFFFFFFFF005555005500
55AAAAAA55005500FFAAFFFF5555555555FFFFAAFF00550055AAAAAA55005500555500FF
FFFFFFFFAA5555AAAA0055555500AA00FF00FFFF55555500AA00FFFFFF
FFFFFFFFAA55AA005500FF5555AAAAAA550000FFAA55FFFF55AA5555AA55550000555555
0000000000555555FF00FF55000055000055FF00FF555555000000000055555500005555
AA5555AA55FFFF55AAFF000055AAAAAA5555FF005500AA55AAFFFFFFFF
FFFFFFFFFF000000AA55AA550000000000555500FFFF5500FF00FF00000055AAAA550000
5555FF5555000055AA55AA55005555550055AA55AA5500005555FF5555000055AAAA5500
0000FF00FF0055FFFF005555000000000055AA55AA000000FFFFFFFFFF
FFFFFFFFFFFFAA000000FFFF555500555500005555AA550055FF55005555000000005555
000055FFFF5555000000FFFF5555555555FFFF0000005555FFFF55000055550000000055
550055FF550055AA555500005555005555FFFF000000AAFFFFFFFFFFFF
FFFFFFFFFFFFFF00AA00FF550000555555550055000000555555AA000055005555005500
00AA0055FF0000FFAA00FF55000055000055FF00AAFF0000FF5500AA0000550055550055
0000AA555555000000550055555555000055FF00AA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55AA55005555555555550000AAFFFF55FFFF00AA005555555500AA
00FFFFAAAA0000AAAAAA555555FF55FF555555AAAAAA0000AAAAFFFF00AA005555555500
AA00FFFF55FFFFAA00005555555555550055AA55AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000005555555555555555FF55AA555555AA55AAFF00005500AAFF
5555AA55FFAA00FFFF00FF0000FF55FF0000FF00FFFF00AAFF55AA5555FFAA00550000FF
AA55AA555555AA55FF5555555555555555000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA00005500005500005500FF00FF0000FFFF55AA55AAAAFFFF00
55000000FF55AAAA00AA00AA00FF55FF00AA00AA00AAAA55FF0000005500FFFFAAAA55AA
55FFFF0000FF00FF00550000550000550000AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AA005555FFFFAAFFAA00AA00AA00FF55000000FFFF0055FF
55FF555500FF00FFFFAA55AAFF005500FFAA55AAFFFF00FF005555FF55FF5500FFFF0000
0055FF00AA00AA00AAFFAAFFFF555500AA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55AA0055FF00FF55AAAAAA55FF5500AA0000AAAA00FF00
55AA5500AA00AA00AAAAAAFF5500550055FFAAAAAA00AA00AA0055AA5500FF00AAAA0000
AA0055FF55AAAAAA55FF00FF5500AA55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000AA5555FF000000000055FFFFAA55AAAAAAAA5555
000000FFAA55AAFF00FFFF00550055005500FFFF00FFAA55AAFF0000005555AAAAAAAA55
AAFFFF550000000000FF5555AA000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000FF005555005555FFFFFFFF00000000000055
00555500FFFF55AA55AA555500AAFFAA005555AA55AA55FFFF0055550055000000000000
FFFFFFFF555500555500FF000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00FF555555550000FF5500FF55550055550055
0055AA00FF55000000FFFF55FF55AA55FF55FFFF00000055FF00AA550055005555005555
FF0055FF000055555555FF00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA55000055AAAA55555500FF0000AA550055
0055AAFF0055005555FF005500FF00FF005500FF5555005500FFAA5500550055AA0000FF
00555555AAAA55000055AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000005555000000005500AA00AA0000005555
55FFFF00555555FFFF5500550055FF5500550055FFFF55555500FFFF555555000000AA00
AA0055000000005555000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000550055550055AAAAAA55FF5555FFFF
55FF005555555555AA5500550055AA5500550055AA555555555500FF55FFFF5555FF55AA
AAAA5500555500550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00555555550000000000FF55FFFFFF
FF550055000055000000555555000000555555000000550000550055FFFFFFFF55FF0000
0000005555555500AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA005500AA0000AAFF0055AA5555
AA550055005555550055555555550055555555550055555500550055AA5555AA5500FFAA
0000AA005500AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000AA55AAFFFFAA555500000055
AAFFAA00555555555500005500AA55AA00550000555555555500AAFFAA550000005555AA
FFFFAA55AA000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000FFFFFFFF0000FFAAFFFF
55AA55FF55FFFF55FFFFAAFFAAFF55FFAAFFAAFFFF55FFFF55FF55AA55FFFFAAFF0000FF
FFFFFF000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00FF5500FF5555FF00FF55
00000055FFFFFFFF5500FFFFFF005500FFFFFF0055FFFFFFFF5500000055FF00FF5555FF
0055FF00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA550055FFFF550055FF
FFAA0000FF5500FF55FF5500FF555555FF0055FF55FF0055FF0000AAFFFF550055FFFF55
0055AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000555555AA55005500
FF55AAAA55555500FF0055AAAA005500AAAA5500FF00555555AAAA55FF00550055AA5555
55000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000055000000555555
FF000000005500AA00AAFFAA55FF55FF55AAFFAA00AA005500000000FF55555500000055
0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA005555FF55FFFF
550055550055AAAAAA55FF00FF005500FF00FF55AAAAAA550055550055FFFF55FF555500
AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA0055FFFFFF
FF55555555000000000055FF5500550055FF55000000000055555555FFFFFFFF5500AA55
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000AA5555AA
5555555555550055550055AA5500550055AA5500555500555555555555AA5555AA000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000FF00
FF000055000055555555000000555555000000555555550000550000FF00FF000000AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00FF55
55AAAA5500555555555555005555555555005555555555550055AAAA5555FF00AA00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA55
000000005555555555555555000055000055555555555555550000000055AA55AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
5555005555555555555555555500550055555555555555555555005555000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00
005500550000FF000055000055005500550000550000FF00005500550000AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
AA00555555FF5500555555005500550055005555550055FF55555500AA00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55AA005500FF00AA5500AA0055555500AA0055AA00FF005500AA55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000AA55AA55AAFFAAFF5555555555FFAAFFAA55AA55AA000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA000000FFFF55AA55FF0000550000FF55AA55FFFF000000AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00AA00FF5500000055FF555555FF5500000055FF00AA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA55AA55005555FFFFFF55FFFFFF55550055AA55AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000055555555AA555555AA55555555000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA0000550000FFFF55FFFF0000550000AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00AA005555FF005500FF555500AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55AA0055FF55FF5500AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AA555555AA000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA00000055000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AA00FF00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.191864 0.39418 0.279175 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FFAAAAAAFF00AAFF00005500AA0055550000550055000000FFAA55AA00FFAA55
550000FF00FFAAFFAAAAAAFF00FFFFFF00FFAAAAAAFFAAFF00FF00005555AAFF00AA55AA
FF0000005500550000555500AA00550000FFAA00FFAAAAAAFF000000FF
FFFFAAFF0000550000FF55AA00AAAAFFFF00AA00000000AAFFAAFF00AA55FFFF0055AAFF
AAAA55AA00FF00FF00FFFF000000FF000000FFFF00FF00FF00AA55AAAAFFAA5500FFFF55
AA00FFAAFFAA00000000AA00FFFFAAAA00AA55FF0000550000FFAAFFFF
FFFFFF00000000AAAA55005500FFFF0000FFAA55AAAA00FFFFFF00000055555555FFFF00
0055005500FF00AA55555555FF555555FF55555555AA00FF005500550000FFFF55555555
000000FFFFFF00AAAA55AAFF0000FFFF00550055AAAA00000000FFFFFF
FFFFFFFFAAFF00550000AAFFAA0055AAAA00550055000000FF0000000000AA0000AA5500
FF55FF55FF00000055550055555500555555005555000000FF55FF55FF0055AA0000AA00
00000000FF00000055005500AAAA5500AAFFAA00005500FFAAFFFFFFFF
FFFFFFFFFF000000AAFF00FF00FFAAAAAAAA000000AAAA55AA00AAFFFFAAFF5555FFAAAA
0055555500AAFF00AA000000AA000000AA000000AA00FFAA0055555500AAAAFF5555FFAA
FFFFAA00AA55AAAA000000AAAAAAAAFF00FF00FFAA000000FFFFFFFFFF
FFFFFFFFFFFFAAFF00FF0055AA55000055000000000055005500FFFFFFFF0000AA005500
0000AA00000055AAAAAA00AAAAAA00AAAAAA00AAAAAA55000000AA0000005500AA0000FF
FFFFFF00550055000000000055000055AA5500FF00FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFAAAAAAFF00AA00FFAAFFFFAAAA000000FF0000FFAAFF550055
FF005500FFAA0000550000005500000055000000550000AAFF005500FF550055FFAAFF00
00FF000000AAAAFFFFAAFF00AA00FFAAAAAAFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF0000550000FF55AA550000FF00FFFFAAFF00000000FFFFFF5555
00AAAAFFFFFF00AAAAFFFFAA0000000000AAFFFFAAAA00FFFFFFAAAA005555FFFFFF0000
0000FFAAFFFF00FF000055AA55FF0000550000FFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000AAAA5500550055FF000000FF00FF00AAAA00AA5500AA00
00005500AA5500FFFF0000FFFFAA00AAFFFF0000FFFF0055AA0055000000AA0055AA00AA
AA00FF00FF000000FF5500550055AAAA00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF00550000AAFFAA0000FF5555AA00FF00550000005555AAFF
00AAFFAAFF55FF0000FF5500AA55FF55AA0055FF0000FF55FFAAFFAA00FFAA5555000000
5500FF00AA5555FF0000AAFFAA00005500FFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000AAFF00FF00FFAA005555000000FFAAAA5555FFFF55AA
00FFFFFF0000AA5555AA000000555555000000AA5555AA0000FFFFFF00AA55FFFF5555AA
AAFF000000555500AAFF00FF00FFAA000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF00FF0055AA55000000AA00AAFF000055005555555500
0000FF0000000055550000000000AA0000000000555500000000FF000000555555550055
0000FFAA00AA00000055AA5500FF00FFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFAAAAAAFF00AAFF550000FFAAFFAA0000AA0000
000000FFAA00AAAAFFAAFFFFAAFF00FFAAFFFFAAFFAAAA00AAFF0000000000AA0000AAFF
AAFF000055FFAA00FFAAAAAAFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0000550000FF55AA00000000FFFFFF00AAAAAA00
FFAAFFFFFF00550000FFFFFFFF000000FFFFFFFF00005500FFFFFFAAFF00AAAAAA00FFFF
FF00000000AA55FF0000550000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000AAAA55005500FFAA00AA5500AAAAAAAAAA
550000FF000000AAFF0000FF0000000000FF0000FFAA000000FF000055AAAAAAAAAA0055
AA00AAFF00550055AAAA00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00550000AAFFAA005500FFFF550000550000
5555FF000000000055AA555555AA55AA555555AA550000000000FF5555000055000055FF
FF005500AAFFAA00005500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000AAFF00FF00FFAAAA5500AA00AAAAFF00
555500AAAA00AAAA00005555005500550055550000AAAA00AAAA00555500FFAAAA00AA00
55AAAAFF00FF00FFAA000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FF0055AA5500005555AAFFFF00FF00
555500FFFF005500000000AA00AA00AA00AA000000005500FFFF00555500FF00FFFFAA55
55000055AA5500FF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFAAAAAAFF00AA000055AA00FF00
555500FF000000AAAA55AAAAAA55FF55AAAAAA55AAAA000000FF00555500FF00AA550000
AA00FFAAAAAAFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0000550000FF55AA5555000000FF
AAAAFF0000000000550055000055555500005500550000000000FFAAAAFF0000005555AA
55FF0000550000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000AAAA550055005555AAAA00
550000FFAAFFFFAAFFAA00000000AA00000000AAFFAAFFFFAAFF00005500AAAA55550055
0055AAAA00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00550000AAFFAAFFAAAAAAAA
00000000FFFFFFFF000055FF00AAAAAA00FF550000FFFFFFFF00000000AAAAAAAAFFAAFF
AA00005500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000AAFF00FF00FF00FFFF00
FFAAFF0055AA0055AA555500AAAAAAAAAA005555AA5500AA5500FFAAFF00FFFF00FF00FF
00FFAA000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FF0055AA5500FF0000
00FFFFFFAAAAAA0000555500FFFF00FFFF0055550000AAAAAAFFFFFF000000FF0055AA55
00FF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFAAAAAAFF000000
0000FF00005500000000AA00FF000000FF00AA00000000550000FF0000000000FFAAAAAA
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0000550000FFAA00
AAFF00000000AAAA00AAAAAA0055FF5500AAAAAA00AAAA00000000FFAA00AAFF00005500
00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000AAAA550000
0055AAAA00FFAA55FF00FFFF0055555500FFFF00FF55AAFF00AAAA5500000055AAAA0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00550000AAFF
FFAAAAAAAA00550055AA5500AAAAFFAAAA0055AA55005500AAAAAAAAFFFFAA00005500FF
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000AAFF00FF
000055000055FFFFAAAAAAFFFF00FF00FFFFAAAAAAFFFF550000550000FF00FFAA000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FF0055
AAAA00000000AA5500005500AA555555AA0055000055AA00000000AAAA5500FF00FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFAA
AAAAAA5555AAAAAAFF00AA00FFFF55FFFF00AA00FFAAAAAA5555AAAAAAAAFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0000
550000555500005500AAAAAA5500AA0055AAAAAA0055000055550000550000FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00AAAA0000AAAA000000550000AAAAAA000055000000AAAA0000AAAA00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
0055000000005500FFAA000000005500000000AAFF0055000000005500FFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000AAFF00AAAAFFFFFF00AAFF00AA00FFAA00FFFFFFAAAA00FFAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAFF00FF00550000FF00000055AAAAAA55000000FF00005500FF00FFAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFAAAA55AA00FFAA0000550000AAFF00AA55AAAAFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFF000055005500FF00FFAAFFAAFF00FF005500550000FFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000AAAAFF000000FFFFFF000000FFAAAA00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAFF00550000FFAAFFFFFFFFFFAAFF00005500FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000AAFFFFFF0000FF0000FFFFFFAA000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFF00FF0000FF555555FF0000FF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF55555500555555FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF0000AA000000AA0000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000055FF5500000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF0055555500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000AA000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.191864 0.588183 0.279175 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF5555AA55AAAAFFFF5555AAAAFFAAAA550055AA5500005555000055FFAAFFFFFFFF5555
005555FFFF0000FFFFFFAAAA55AAAAAA55AAAAFFFFFF0000FFFF5555005555FFFFFFFFAA
FF5500005555000055AA550055AAAAFFAAAA5555FFFFAAAA55AA5555FF
FFFF55AAAAFF0000AAAAFFAA00FF5555FFFFAA55AAFFFFAAAAFFFFAA555555005555AAFF
AAFFAA555500005555AA55AAAAAA55AAAAAA55AA555500005555AAFFAAFFAA5555005555
55AAFFFFAAAAFFFFAA55AAFFFF5555FF00AAFFAAAA0000FFAAAA55FFFF
FFFFFF555555000055AAAA005500FFFF550055AAFF005555555500FFAAAAFFAAFFAAAA55
5555AAAAFFAAFFFF55AAAAAA55AAAAAA55AAAAAA55FFFFAAFFAAAA555555AAAAFFAAFFAA
AAFF005555555500FFAA550055FFFF005500AAAA550000555555FFFFFF
FFFFFFFF55AAFFFFAAAA550000005555AAFFFF555500000000000055555555AA0000FFAA
AAFF555555AA00AAAAAA55AAAAAA55AAAAAA55AAAAAA00AA555555FFAAAAFF0000AA5555
55550000000000005555FFFFAA555500000055AAAAFFFFAA55FFFFFFFF
FFFFFFFFFF5555AA55AAAAFFFFAAFFAAAA5555AAFFAAFFFFAAFFFFAAAAFFAA5500005555
5555AAFFAA550000FF000000FF000000FF000000FF000055AAFFAA55555555000055AAFF
AAAAFFFFAAFFFFAAFFAA5555AAAAFFAAFFFFAAAA55AA5555FFFFFFFFFF
FFFFFFFFFFFF55AAAAFF0000AAAA555555FFAAAA55555500FF0055555555AAAAFFFFAAAA
AAAAAA5555FFAAFFFFFFAAFFFFFFAAFFFFFFAAFFFFFFAAFF5555AAAAAAAAAAFFFFAAAA55
55555500FF00555555AAAAFF555555AAAA0000FFAAAA55FFFFFFFFFFFF
FFFFFFFFFFFFFF555555000055AAAAFFAA555555FFAAAAFFFFFFAAAAAAAAAA5500555555
555555FFAA555555AA5555550055555500555555AA555555AAFF5555555555550055AAAA
AAAAAAFFFFFFAAAAFF555555AAFFAAAA550000555555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55AAFFFFAAAA550055AAFFAA55555555005555FF555555FFFFAAAAAA
AAFFAA5555FFFF00FFAAAAAAFFFF00FFFFAAAAAAFF00FFFF5555AAFFAAAAAAAAFFFF5555
55FF55550055555555AAFFAA550055AAAAFFFFAA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555AA55AAAAFFFF5555AAAAFFAAAAFFFF00FF55FFFF0055555555
5555AAAAAAAA000055555555FF005500FF555555550000AAAAAAAA55555555555500FFFF
55FF00FFFFAAAAFFAAAA5555FFFFAAAA55AA5555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55AAAAFF0000AAAAFFAA00FF5555FF005500FFFFFFFFAAAAAAAA
AAAAFF0000FFAAFFFF00FFFF5500000055FFFF00FFFFAAFF0000FFAAAAAAAAAAAAFFFFFF
FF005500FF5555FF00AAFFAAAA0000FFAAAA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF555555000055AAAA005500FFFF550000005555AA5555555555
555555000055555500550055FFFFAAFFFF5500550055555500005555555555555555AA55
5500000055FFFF005500AAAA550000555555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AAFFFFAAAA550000005555AAFFFFAAFFAAAA55FFAAAAAA
AAAAFFAAFFFF55FFAAFFAAFF5500FF0055FFAAFFAAFF55FFFFAAFFAAAAAAAAAAFF55AAAA
FFAAFFFFAA555500000055AAAAFFFFAA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF5555AA55AAAAFFFFAAFFAAAA5555AA0000FFAA55555555
5555FF0000AAAAAA00FF5555AAFFFFFFAA5555FF00AAAAAA0000FF555555555555AAFF00
00AA5555AAAAFFAAFFFFAAAA55AA5555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAAFF0000AAAA555555FFAA5500005555FFAAAAAA
AAFF55000055AA005500FFFF5555005555FFFF005500AA55000055FFAAAAAAAAFF555500
0055AAFF555555AAAA0000FFAAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555000055AAAAFFAA5555FFFFAAFFAA55555555
5555AAFFFFAA550000005555AAFFAAFFAA555500000055AAFFFFAA555555555555AAFFAA
FFFF5555AAFFAAAA550000555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFFAAAA550055AAFF5500FF0055AAFFAAAA
AAAAAA5555AAAAFFFFAAFFAA5500FF0055AAFFAAFFFFAAAA5555AAAAAAAAAAFFAA5500FF
0055FFAA550055AAAAFFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA55AAAAFFFF5555AAFFFFFFAAAA555555
555555FFFF555555AA550055AAFFFFFFAA550055AA555555FFFF555555555555AAAAFFFF
FFAA5555FFFFAAAA55AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAAFF0000AAAAFFAA0000AAAA55AAFFAA
AAAAFF5500FFFF55AAAAFFFF5555005555FFFFAAAA55FFFF0055FFAAAAAAFFAA55AAAA00
00AAFFAAAA0000FFAAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555000055AAAA00550000FFAAAA5555
555555AAFFFFFFFF555555AA55FFAAFF55AA555555FFFFFFFFAA5555555555AAAAFF0000
5500AAAA550000555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFFAAAA55000000550055AAAAAA
AAAAFF5555005555AAFF55FF55AA55AA55FF55FFAA5555005555FFAAAAAAAAAA55005500
000055AAAAFFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA55AAAAFFFFAAFFAAFF555555
555555AAFFAAFFAA5500FFFFFF000000FFFFFF0055AAFFAAFFAA555555555555FFAAFFAA
FFFFAAAA55AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAAFF0000AAAA555555AAFFAA
AAAAAAAA555555AAAAFFFFFFFFFFAAFFFFFFFFFFAAAA555555AAAAAAAAAAFFAA555555AA
AA0000FFAAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555000055AAAAFFAAAA5555
55555555FFFF55FF5555AA555500FF005555AA5555FF55FFFF555555555555AAAAFFAAAA
550000555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFFAAAA550055AAAAAA
AAAAAAFF5500FFFFFF55AAAAAAFFFFFFAAAAAA55FFFFFF0055FFAAAAAAAAAAAA550055AA
AAFFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA55AAAAFFFF555555
55555555AAFFFFFFFFFF55555555AA55555555FFFFFFFFFFAA55555555555555FFFFAAAA
55AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAAFF0000AAAAAAFF
AAAAAAAAAA5555005555AAFFAA55FF55AAFFAA5555005555AAAAAAAAAAFFAAAAAA0000FF
AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555000055AAAA55
55555555FF55FFFFAAAAAA5555FFFFFF5555AAAAAAFFFF55FF5555555555AAAA55000055
5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFFAA55AAAA
FFAA55FFFFFF550055AAAA55FFFFFFFFFF55AAAA550055FFFFFF55AAFFAAAA55AAFFFFAA
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA55AAFF00
00AA55FF0055FFAAFF5555FFFFFFFFFFFFFF5555FFAAFF5500FF55AA0000FFAA55AA5555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAAFF0055
0000FFFFFFAAAA00FF55FFFFFFFFFFFFFFFFFF55FF00AAAAFFFFFF00005500FFAAAA55FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555550000
0055005555AA005500FFFFFFFFFFFFFFFFFFFFFF005500AA55550055000000555555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFF
AAFFAAFFAA550000005555AA5555005555AA555500000055AAFFAAFFAAFFFFAA55FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA
55AA55AA55AAFFFFAAFFAA55AAFFAAFFAA55AAFFAAFFFFAA55AA55AA55AA5555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA
AAFF00FFAA5500555555AAAAAA555555AAAAAA5555550055AAFF00FFAAAA55FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
55550000AAFFAAFF55FFAA00FFAAAAAAFF00AAFF55FFAAFFAA0000555555FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
55AAFFFFAA0000FF55FF000055555555550000FF55FF0000AAFFFFAA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5555AA55000055FFFFFFAAFFAAAAAAFFAAFFFFFF55000055AA5555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF55AAAAFFFFAAAA00AAAA5555555555AAAA00AAAAFFFFAAAA55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55555500FF000055AAAAAAAAAAAAAA550000FF00555555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF55AAFFFFFFAAFF55555555555555FFAAFFFFFFAA55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF5555AA555555AAFFAAAAAAFFAA555555AA5555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF55AAAAAAAAAA5555555555AAAAAAAAAA55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5555555555FFAAAAAAFF5555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55AAFFAA5555555555AAFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555AAAAAAFFAAAAAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55AAAA550055AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5555FFAAFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AA55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.191864 0.782187 0.279175 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF55555555AAFFAA00AA555555AAFF0055AAFFAAFFAA555555AA00AA00FF00AA000055FF
AAFF00AAAA555500AAAAAA00555500555500AAAAAA005555AAAA00FFAAFF550000AA00FF
00AA00AA555555AAFFAAFFAA5500FFAA555555AA00AAFFAA55555555FF
FFFF55AAFFAA005555AAAAAAFF555555AAFF000000FFAAAAAAFF005555AA00AAFFFFAA55
0000FF5555FFAAAA00005555AAFFAAFFAA55550000AAAAFF5555FF000055AAFFFFAA00AA
555500FFAAAAAAFF000000FFAA555555FFAAAAAA555500AAFFAA55FFFF
FFFFFF55555500FFFF00AA00FF00FFFF00AA5555AA550000AA0055FFFF00AAAA5500AAFF
AAFFFFFF00FF00AA00AAAAAAAA550055AAAAAAAA00AA00FF00FFFFFFAAFFAA0055AAAA00
FFFF5500AA000055AA5555AA00FFFF00FF00AA00FFFF00555555FFFFFF
FFFFFFFF55AAFFFFFFFFAA00AA55555555AAAAAAAA55FF005500FFFFFFFFAA00FFFFAA00
5555555555AA00AA00AA0000AAFFAAFFAA0000AA00AA00AA555555555500AAFFFF00AAFF
FFFFFF005500FF55AAAAAAAA55555555AA00AAFFFFFFFFAA55FFFFFFFF
FFFFFFFFFF55555555555500FFAAAAAAAAFF00AA00FFFFFFAA55555555555500FF0000AA
AAAAAAAAFFAA00AA00AAFFFFAA005500AAFFFFAA00AA00AAFFAAAAAAAAAA0000FF005555
55555555AAFFFFFF00AA00FFAAAAAAAAFF00555555555555FFFFFFFFFF
FFFFFFFFFFFF55AAFFAAAAAA005500555500AAAA5555555555FFFF55FFAAAAAA0055FF00
AA000055555500FFAAFF0000FFAAFFAAFF0000FFAAFF005555550000AA00FF5500AAAAAA
FF55FFFF5555555555AAAA005555005500AAAAAAFFAA55FFFFFFFFFFFF
FFFFFFFFFFFFFF555555005500FFFFAAAAAA00FFAAAAFF55FFFFFFFF0000555500FFFFFF
AA00AAAAAAAAAA005500AAAA0055555500AAAA005500AAAAAAAAAA00AAFFFFFF00555500
00FFFFFFFF55FFAAAAFF00AAAAAAFFFF005500555555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55AAFFFF0055AA00005555AA000000FFFFFFFFFFFFAAFFAA55555555
55FF00AA0000AAFFFF550000AAAAFFAAAA000055FFFFAA0000AA00FF5555555555AAFFAA
FFFFFFFFFFFF000000AA55550000AA5500FFFFAA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55555555AAFF0055FFFF5555AA555555555555555500AAFF55FFFF
55AA00AAFFFFAA0055AAFFFFAA00FF00AAFFFFAA5500AAFFFFAA00AA55FFFF55FFAA0055
55555555555555AA5555FFFF5500FFAA55555555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55AAFFAA0055FFFFFFFF55AAAAAAFF55FFAAAAAAAA0000FFFFFF
FF00AAAA5500AAFFFF5555555500FF0055555555FFFFAA0055AAAA00FFFFFFFF0000AAAA
AAAAFF55FFAAAAAA55FFFFFFFF5500AAFFAA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55555500FFFFFFFFFFFF00AA00FF00FF00AA00FFAAFFFFFFFF
FFFFAA00FFFFAA0055AAFFAAAAFFFFFFAAAAFFAA5500AAFFFF00AAFFFFFFFFFFFFAAFF00
AA00FF00FF00AA00FFFFFFFFFFFF00555555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AAFFFFFFFFFFFFFFFFAA00AA555555AAAA005555555555
55555500FF0000AAAAAA550055555555550055AAAAAA0000FF00555555555555555500AA
AA555555AA00AAFFFFFFFFFFFFFFFFAA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF5555555555555555555500FFAAAAAAFF00AAAAAAAAAAAA
FFAAAAAA0055FF00AA00FFFFAAAAAAAAAAFFFF00AA00FF5500AAAAAAFFAAAAAAAAAAAA00
FFAAAAAAFF0055555555555555555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFAAAAAAFFAAAAAA0055550055AA55AAAA55AAAA
5500005500FFFFFFAA00AA550000AA000055AA00AAFFFFFF0055000055AAAA55AAAA55AA
5500555500AAAAAAFFAAAAAAFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555005500AA00FFAAFF55FF00FFAA55AAAAAA55
AAFFFFAA555555555500FFAAAA00AA00AAAAFF005555555555AAFFFFAA55AAAAAA55AAFF
00FF55FFAAFF00AA005500555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFF005555AA00FF00FF0055AAAAFF00AAFF
AA0055AAAAAAAAFF55FF0000AA00AA00AA0000FF55FFAAAAAAAA5500AAFFAA00FFAAAA55
00FF00FF00AA555500FFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555AAFFAA00AA555555AAFF00AA555500
AAFFFF00AA000000FFFFFFAAFF005500FFAAFFFFFF000000AA00FFFFAA005555AA00FFAA
555555AA00AAFFAA55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFAA005555AAAAAAFF555555AAAAAAAA
0000FF005555AA555555555500AAAAAA005555555555AA555500FF0000AAAAAAAA555555
FFAAAAAA555500AAFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555500FFFF00AA00FF00FFFF00AA00FF
AAFFFFFFAA55FF55AAFFAAAAAA000000AAAAAAFFAA55FF55AAFFFFFFAAFF00AA00FFFF00
FF00AA00FFFF00555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFFFFFFAA00AA55555555AAAA00
5555555555FFFFFF555555005555AA555500555555FFFFFF555555555500AAAA55555555
AA00AAFFFFFFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555555500FFAAAAAAAAFF00AA
AAFFAA55FFFFFFFFFF55FFAAFF55FF55FFAAFF55FFFFFFFFFF55AAFFAAAA00FFAAAAAAAA
FF00555555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFAAAAAA005500555500AAAA
55AA00FFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFF00AA55AAAA0055550055
00AAAAAAFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555005500FFFFAAAAAA00FF
AAAA555555555555555555AA5555555555AA555555555555555555AAAAFF00AAAAAAFFFF
005500555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFF0055AA00005555AA
00FFAAAAAAAAAAAAAAFF55AAAAAAFFAAAAAA55FFAAAAAAAAAAAAAAFF00AA55550000AA55
00FFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555AAFF0055FFFF55
55AA0000000000AA00FF00FFAA00FF00AAFF00FF00AA0000000000AA5555FFFF5500FFAA
55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFAA0055FFFFFFFF
55AAAA00AAAA00AA00AA55555500FF00555555AA00AA00AAAA00AAAA55FFFFFFFF5500AA
FFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555500FFFFFFFFFF
FF00AA00AA00FF5555AAAAFFAA555555AAFFAAAA5555FF00AA00AA00FFFFFFFFFFFF0055
5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFFFFFFFFFF
FFFFAA00AA00AA55FFAA0000FFAAAAAAFF0000AAFF55AA00AA00AAFFFFFFFFFFFFFFFFAA
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555555555
55555500FFAAFF00FF00AAAA0055005500AAAA00FF00FFAAFF0055555555555555555555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFAAAAAA
FFAAAAAA00555555AA00AA00FF55AA55FF00AA00AA55555500AAAAAAFFAAAAAAFFAA55FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555550055
00AA00FFAAFF55FFAA00AA00AA55FF55AA00AA00AAFF55FFAAFF00AA005500555555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFF
005555AA00FF00FF00AAAA5555FFFFFF5555AAAA00FF00FF00AA555500FFFFAA55FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555
55AAFFAA00AA555555AAAA55FFFFFFFFFF55AAAA555555AA00AAFFAA55555555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA
FFAA005555AAAAAAFF5555FFFFFFFFFFFFFF5555FFAAAAAA555500AAFFAA55FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
555500FFFF00AA00FF00FFFFFFFFFFFFFFFFFF00FF00AA00FFFF00555555FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
55AAFFFFFFFFAA00AA5555555555555555555555AA00AAFFFFFFFFAA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55555555555500FFAAAAAAAAAAAAAAAAAAAAAAFF00555555555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF55AAFFAAAAAA005500550000AA000055005500AAAAAAFFAA55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF555555005500FFFFAAAA00AA00AAAAFFFF005500555555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF55AAFFFF0055AA000055FF550000AA5500FFFFAA55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55555555AAFF0055FFFFFF5500FFAA55555555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF55AAFFAA0055FFFFFFFFFF5500AAFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55555500FFFFFFFFFFFFFF00555555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55AAFFFFFFFFFFFFFFFFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555555555555555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55AAFFAAAAAAFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55555500555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55FFAAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.191864 0.97619 0.279175 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF5500AA00FFFFFF55550000FF00FF5500FF00AAFFFF00AA000000FFFF55FF550000FFAA
0000AA000000FFFF55FF00AA00AA00AA00AA00FF55FFFF000000AA0000AAFF000055FF55
FFFF000000AA00FFFFAA00FF0055FF00FF00005555FFFFFF00AA0055FF
FFFF555555000055FFFF5555FF00AAAAAA555500AAAA00FF00AAFF0055FFFFFF5555FF00
00AA0055550055FF00FF55555500AA00555555FF00FF5500555500AA0000FF5555FFFFFF
5500FFAA00FF00AAAA005555AAAAAA00FF5555FFFF550000555555FFFF
FFFFFF55FFAA00000055FFAAAA00FF0000FFFF55555555FF00AA5555FFFFFFFFFF00FF55
5500AAFF55FF55AA55AA55FFFF555555FFFF55AA55AA55FF55FFAA005555FF00FFFFFFFF
FF5555AA00FF55555555FFFF0000FF00AAAAFF55000000AAFF55FFFFFF
FFFFFFFF5500AA00FFAA555555550000AA00AAAAAAAAAAAA0000FFFF550000550000AAAA
FFAA0055FFFFFF000000FFFFFFFF55FFFFFFFF000000FFFFFF5500AAFFAAAA0000550000
55FFFF0000AAAAAAAAAAAA00AA000055555555AAFF00AA0055FFFFFFFF
FFFFFFFFFF5555550000FFFF00FFFFAA005555555555555555FF5500FFFFAAFF555500AA
555555FFFFFFFFFFAA00005500FF55FF00550000AAFFFFFFFFFF555555AA005555FFAAFF
FF0055FF555555555555555500AAFFFF00FFFF0000555555FFFFFFFFFF
FFFFFFFFFFFF55FFAA000055FF550000FFAA55FFFF55FFFF55AA55FF550000FF55AAFF00
0000000055FF005500AAFFFF00AAAAAA00FFFFAA005500FF550000000000FFAA55FF0000
55FF55AA55FFFF55FFFF55AAFF000055FF550000AAFF55FFFFFFFFFFFF
FFFFFFFFFFFFFF5500AA00FFFFFF55550000FFFFFFFF55000000FFFFFF5555000000FF55
55FF5555FFFFFFAAAA5500FF5555555555FF0055AAAAFFFFFF5555FF5555FF0000005555
FFFFFF00000055FFFFFFFF00005555FFFFFF00AA0055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF555555000055FFFF5555FF005500FFFFAAFF0055FF00FFFFAA00FF55
FFFFFF00FF5500FF000000AAAAFF55FFAAAA000000FF0055FF00FFFFFF55FF00AAFFFF00
FF5500FFAAFFFF005500FF5555FFFF550000555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55FFAA00000055FFAAAA000000AAAA0055FF55AA55AA5555550000
00550000AAAAFFFFFFAAFF0000FF55FF0000FFAAFFFFFFAAAA000055000000555555AA55
AA55FF5500AAAA000000AAAAFF55000000AAFF55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5500AA00FFAA555555550055555555FFFFFF000000FFFF55FF55
55FFAA0000FF00550000FF55550000005555FF00005500FF0000AAFF5555FF55FFFF0000
00FFFFFF555555550055555555AAFF00AA0055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5555550000FFFF00FFFFAA55FFFF0055FF00AA000055FFFFFF
55FF0000AA00AAFF555500000000AA000000005555FFAA00AA0000FF55FFFFFF550000AA
00FF5500FFFF55AAFFFF00FFFF0000555555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55FFAA000055FF550000FFFFFFFFAA555500AA00FFFFFFFF
FF550055555500AAAAFF5555FF555555FF5555FFAAAA005555550055FFFFFFFFFF00AA00
5555AAFFFFFFFF000055FF550000AAFF55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF5500AA00FFFFFF55550000550000FFFF555555FF005500
FF55AAAAAAAAFF0000FF55FFFFFF55FFFFFF55FF0000FFAAAAAAAA55FF005500FF555555
FFFF00005500005555FFFFFF00AA0055FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF555555000055FFFF5555FFAA000055FFFF55AA55AAFF
FFFF0000FF00005555000000550000005500000055550000FF0000FFFFFFAA55AA55FFFF
550000AAFF5555FFFF550000555555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA00000055FFAAAA005555FFFFFFFF000000FF
550000AA00AA00FFFF00AA000000AA000000AA00FFFF00AA00AA000055FF000000FFFFFF
FF555500AAAAFF55000000AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA00FFAA55555555FFFF5500005500555500
FFFFAA0055555500005555550055555500555555000055555500AAFFFF00555500550000
55FFFF55555555AAFF00AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555550000FFFF00FFFFFFFF5555FFFFAA55FF
550000FFAAAAAAAA55AAFF55AAAAFFAAAA55FFAA55AAAAAAAAFF000055FF55AAFFFF5555
FFFFFFFF00FFFF0000555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA000055FF55000055FFFF550000FFFF
FF5555FF0000FF000000FF55AA005500AA55FF000000FF0000FF5555FFFFFF000055FFFF
55000055FF550000AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA00FFFFFF5555FFFFFFFF55550000
55FFFF00555500FFAA00FF55AA000000AA55FF00AAFF00555500FFFF5500005555FFFFFF
FF5555FFFFFF00AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555000055FFFF55000055FFFF5555
FFFFFFFFAAAAAA555555FF00FF00AA00FF00FF555555AAAAAAFFFFFFFF5555FFFF550000
55FFFF550000555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA00000055FFAA00FFFFFFFF55
AA5555AA5500AA55FFAAAA00005555550000AAAAFF55AA0055AA5555AA55FFFFFFFF00AA
FF55000000AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA00FFAA5555550000550000
00FFFF000000AA55FF0000FFAAFF55FFAAFF0000FF55AA000000FFFF0000005500005555
55AAFF00AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555550000FFFF00FFAAFF5555
0055FF00AA00FF00FF55550000FF55FF00005555FF00FF00AA00FF55005555FFAAFF00FF
FF0000555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA000055FF5500AAAAAA
FFFF005555550000AAAAFFAA00FF55FF00AAFFAAAA000055555500FFFFAAAAAA0055FF55
0000AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA00FFFFFF55555555
55AA55AAFF55FF55555555AA00FF55FF00AA55555555FF55FFAA55AA5555555555FFFFFF
00AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555000055FFFF55FF
FF000000FF55FF00FFFF00FF00AAAAAA00FF00FFFF00FF55FF000000FFFF55FFFF550000
555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA00000055FFFF
FFFFAA00FF55FF00AAAA00FF5555555555FF00AAAA00FF55FF00AAFFFFFFFF55000000AA
FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA00FFAA5555
AA555555000000555555550000000000000055555555000000555555AA5555AAFF00AA00
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555550000FFFF
0000000000AAFFFF55FFAA55AAAA55AAAA55AAFF55FFFFAA0000000000FFFF0000555555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA000055
FF555500555555AA55FF000000FF00FF000000FF55AA555555005555FF550000AAFF55FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA00FF
FFFF55FF55FFFF000000555500550055005555000000FFFF55FF55FFFFFF00AA0055FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555500
0055FFFFFF550000AAFF00FFFFAA55AAFFFF00FFAA000055FFFFFF550000555555FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA
00000055FF00FFAA00550055FF000000FF55005500AAFF00FF55000000AAFF55FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500
AA00FFAA55550000FFAAAA55FF00AA00FF55AAAAFF00005555AAFF00AA0055FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
55550000FFFF55550000FF00FF555555FF00FF00005555FFFF0000555555FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
55FFAA000055FFFF5555FF00AAAAAAAAAA00FF5555FFFF550000AAFF55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5500AA00FFFFFFFF00FF55555555555555FF00FFFFFFFF00AA0055FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF555555000055FF00AAAAAAAAAAAAAAAAAA00FF550000555555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55FFAA0000005555555555555555555555000000AAFF55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF5500AA00FFAAAAAAAAFF55FFAAAAAAAAFF00AA0055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF5555550000FF0000FF55FF0000FF0000555555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF55FFAA0000555500000055550000AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5500AA00FFFF00AA00FFFF00AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55555500005555550000555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55FFFFAAFF55FFAAFFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF550000FF55FF000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5555FF00FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AA55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.287906 0.200176 0.375216 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000000055FFFFAA55AA55AAAAAA00AAFFFFFF5500AAFFAA55FF55FF555555FF555500
55AA00AAAA55AA55FFAAFFAA55FF00FF55AAFFAAFF55AA55AAAA00AA55005555FF555555
FF55FF55AAFFAA0055FFFFFFAA00AAAAAA55AA55AAFFFF5500000000FF
FFFFAAFFFFAAAA55AAFFAA55550055555500005500FF00FFAA5555FFFFFF55FF00AAAA00
55FFAAFF55AA55FF00AA00FFFF555555FFFF00AA00FF55AA55FFAAFF5500AAAA00FF55FF
FFFF5555AAFF00FF00550000555555005555AAFFAA55AAAAFFFFAAFFFF
FFFFFF00AAFF55AA55FF55AA555555AA55555555AA00FF00AA00AAAA55AAAAFF0000AA00
55FF55AAAAFF55000000AA55AAAA00AAAA55AA00000055FFAAAA55FF5500AA0000FFAAAA
55AAAA00AA00FF00AA55555555AA555555AA55FF55AA55FFAA00FFFFFF
FFFFFFFFAA55AA55FFFFFF55AA5555AAFFAAAAFFAA55000000AA55FFAAAAAAAA5500AA00
55FF55FFAA55AA5500AA55FFFF00FF00FFFF55AA0055AA55AAFF55FF5500AA0055AAAAAA
AAFF55AA00000055AAFFAAAAFFAA5555AA55FFFFFF55AA55AAFFFFFFFF
FFFFFFFFFF005555AAAA55AA55FFFF55AAAAAAAA55FF00000000AAAA55FFAA55FF0000AA
5555FF00AA00AA00AA55FF00AAFFFFFFAA00FF55AA00AA00AA00FF5555AA0000FF55AAFF
55AAAA00000000FF55AAAAAAAA55FFFF55AA55AAAA555500FFFFFFFFFF
FFFFFFFFFFFFAAAAFF55AA55FFFFFFFF55AAFF55AA55AA0055AA0000AAAA55FF00AA5500
55FFFFFFAA550055AAFFAA005555FF555500AAFFAA550055AAFFFFFF550055AA00FF55AA
AA0000AA5500AA55AA55FFAA55FFFFFFFF55AA55FFAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFAAAAAAFF00AAFF005555FFFF00555555AAFFFFAA55FFFFFFAA5555
55AAAA55AAFFAAFFAA55AAFFFF55FF55FFFFAA55AAFFAAFFAA55AAAA555555AAFFFFFF55
AAFFFFAA55555500FFFF555500FFAA00FFAAAAAAFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA0000AA00FF00FFAAFFAAAA55AA00AAAAFF5555FFAAAA55AAAAAAFF
AAAAAAAAFF55550000AAAAAA55AA55AA55AAAAAA00005555FFAAAAAAAAFFAAAAAA55AAAA
FF5555FFAAAA00AA55AAAAFFAAFF00FF00AA0000AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AA55AA00FFFFFF00FF55AA0000AAFFAAAA55FFAAAAAAAAAA
55FFAA55FF55FF0000FFFF00FF55AA55FF00FFFF0000FF55FF55AAFF55AAAAAAAAAAFF55
AAAAFFAA0000AA55FF00FFFFFF00AA55AA000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFF00555555FF555555FF00FF0000AAFF55AA55AAFF55AAFF
55FF55AA55AA55AA00550000FFAAAAAAFF00005500AA55AA55AA55FF55FFAA55FFAA55AA
55FFAA0000FF00FF555555FF55555500FFFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AAFFFF55FFFFFF5500FFAAFF0000FFFFFF55AA55FF550055
00FFAAAAAAFF55FFAAFFAAFFFFFF00FFFFFFAAFFAAFF55FFAAAAAAFF00550055FF55AA55
FFFFFF0000FFAAFF0055FFFFFF55FFFFAA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55AAAAFF00AAFFAAFF00FFAAFFFFFFFFFF55AA55AA5500
FF00AA0000AAFFAA00005555FF555555FF55550000AAFFAA0000AA00FF0055AA55AA55FF
FFFFFFFFAAFF00FFAAFFAA00FFAAAA55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF005555000000AAFF555555FFAA00FFAA00FF55AA55FFFF
AA00555555550000AA5500FF5555AA5555FF0055AA00005555555500AAFFFF55AA55FF00
AAFF00AAFF555555FFAA000000555500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFFAAFF5555AA5555FFAAFF00FF00AAAAAAFF00
AA0055FFFF5500AA55FFFFAA00AAAAAA00AAFFFF55AA0055FFFF5500AA00FFAAAAAA00FF
00FFAAFF5555AA5555FFAAFFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA000055FF00FF550000AAFFFFFFAA55FFAA00
555555AAAA55555500FFAA000000AA000000AAFF00555555AAAA55555500AAFF55AAFFFF
FFAA000055FF00FF550000AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000FF555555FFFFAAFF5555FF55AA55AAFF
FF55FF00FFFF55FFFFAA000000FF00FF000000AAFFFF55FFFF00FF55FFFFAA55AA55FF55
55FFAAFFFF555555FF000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000055FF00550000AAFFAAAA555500FFFF
FFFF555555FF55FF555500AA5500000055AA005555FF55FF555555FFFFFFFF005555AAAA
FFAA00005500FF5500000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAAAA5500FF0000AAFF55AA555555FF
5555FFFF55FF55FF55FFFFAA5555555555AAFFFF55FF55FF55FFFF5555FF555555AA55FF
AA0000FF0055AAAAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF55AA5500000000AAFFAA5555AA55
AA5555FF55FF55FF55FF555500FF55FF005555FF55FF55FF55FF5555AA55AA5555AAFFAA
0000000055AA55FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA55FFFFAAFFFFAA55AAFFAAAAAA
FF55FFFFFF5555AAAA00FF5500AAFFAA0055FF00AAAA5555FFFFFF55FFAAAAAAFFAA55AA
FFFFAAFFFF55AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555AAAA55FF555500FFFFFF00FF
FFFF5555FF55FF00FFFFAA00AA55FF55AA00AAFFFF00FF55FF5555FFFFFF00FFFFFF0055
55FF55AAAA555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55AA55AA555555FF555555
FF5555AA55AA55AA00FFAA550055FF550055AAFF00AA55AA55AA5555FF555555FF555555
AA55AA55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAAAAAFF55FF005500FF55
FF55FFFF005555AAFFFFFF0055AA55AA5500FFFFFFAA555500FFFF55FF55FF005500FF55
FFAAAAAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AA00FF555555AA00FF
5555AAAA5500FF55AAAA55AA00AA00AA00AA55AAAA55FF0055AAAA5555FF00AA555555FF
00AA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000AA55AA5555AAFFFF
FF55FFAA555555FF00FFFF55AA000000AA55FFFF00FF555555AAFF55FFFFFFAA5555AA55
AA000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF005555AA55FF55
55FFFFFF0055FF00AA55AAAA0000FF0000AAAA55AA00FF5500FFFFFF5555FF55AA555500
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF55FFAAAA55
55AAAA55AA00AAFFFF00555500AA55AA00555500FFFFAA00AA55AAAA5555AAAAFF55FFFF
AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAAFF00FFFF
55005555AAFFFF00AAFFFF5500AA00AA0055FFFFAA00FFFFAA55550055FFFF00FFAAAA55
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055550000FFAA
00AA5555AAFF00AA55FF5555AA000000AA5555FF55AA00FFAA5555AA00AAFF0000555500
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFFAA00
0000AAAAFF55555500FFAAAA0000000000AAAAFF00555555FFAAAA000000AAFFFFAAAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA0000
000000AA00FF5500FF00AA000000FF000000AA00FF0055FF00AA0000000000AAFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000
00000000AA55AA550000FFFFAAFFFFFFAAFFFF000055AA55AA00000000000000AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FF0000AAAAAAFFFFAA00FFFFFFFFFF00AAFFFFAAAAAA0000FF0000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
FFAAFF000000AA0000550055AAAA55AAAA5500550000AA000000FFAAFFFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
AAFF555555555500AA555555AAFF55FFAA555555AA005555555555FFAA00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55AA5555AA55555500FF55FFAA00AAFF55FF00555555AA5555AA55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF005555AA55FFFF5500AAFFAA000000AAFFAA0055FFFF55AA555500FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAFF55FF5555AA000055555555550000AA5555FF55FFAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFAAAA5555AAFFFFAAAAFFAAAAFFFFAA5555AAAAFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA0000AAAAFF5555FFAA55AAFF5555FFAAAA0000AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000AA00FF55FF55AA55FF55FF00AA000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFFF000055FF550055FF550000FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00AAFFFFAAAA555555AAAAFFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55AAAAAAAA00AAAAAAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0055550055555500555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAFFFF55FFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFAA00AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.287906 0.39418 0.375216 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00FFAA55AA00FF55550000FFFFAAAAFF5555FFAAFF55000000AAFFAA55FFFF0055FF55
FFFFFF00AA0055AAAA0055FFFFFFFFFFFFFF5500AAAA5500AA00FFFFFF55FF5500FFFF55
AAFFAA00000055FFAAFF5555FFAAAAFFFF00005555FF00AA55AAFF00FF
FFFFAA00555555AAAAFFAAFFFFFFFF000000AA00FF00AA00AAAA005500AA00FFAAFFAA00
00005500FFFFAAAAAAAA000000005500000000AAAAAAAAFFFF0055000000AAFFAAFF00AA
005500AAAA00AA00FF00AA000000FFFFFFFFAAFFAAAA55555500AAFFFF
FFFFFF0055550055AAFF000000000055FF0055AA55AA5500FFFF005555AA00AAFF555555
AA555500FFAA0055AAFF5500FF550055FF0055FFAA5500AAFF005555AA555555FFAA00AA
555500FFFF0055AA55AA5500FF550000000000FFAA5500555500FFFFFF
FFFFFFFFAAAAFFFF55AAAA00AAAA00AA00FF55FFAAAAAAFFFFFFFFAAAAFF5500AAFFAAAA
FF55FFFFAA0055FFFF00AA00AAFFAAFFAA00AA00FFFF5500AAFFFF55FFAAAAFFAA0055FF
AAAAFFFFFFFFAAAAAAFF55FF00AA00AAAA00AAAA55FFFFAAAAFFFFFFFF
FFFFFFFFFF00FFAA0000FFFFAA5500FF0055005500AA550000000000FFFFFF5500AAFF55
AAAAFF00AA5555000055FFAAFF555555FFAAFF5500005555AA00FFAAAA55FFAA0055FFFF
FF000000000055AA0055005500FF0055AAFFFF0000AAFF00FFFFFFFFFF
FFFFFFFFFFFFAA0055FF00AAFF55FF00AAAAFFFF5500AA00AAAA00AAAA55AAAAFFFF00AA
0055AAAA00555500FF55FF55AAAAFFAAAA55FF55FF00555500AAAA5500AA00FFFFAAAA55
AAAA00AAAA00AA0055FFFFAAAA00FF55FFAA00FF5500AAFFFFFFFFFFFF
FFFFFFFFFFFFFF005555FF000000AAFFFF0000005555AA00AA55FF00FFFF55AAFF00AAAA
AA0000FFFFAAAAFFFFFF555500AA55AA005555FFFFFFAAAAFFFF0000AAAAAA00FFAA55FF
FF00FF55AA00AA5555000000FFFFAA000000FF555500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAFF0055FF00005500FF5500555555AA000055FF555500AAFFFF00
FFFFAAFF00AA55000055005555AAFFAA55550055000055AA00FFAAFFFF00FFFFAA005555
FF550000AA5555550055FF00550000FF5500FFAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFAAFFAA00AAAAFFFFFF5500555500AAAA0000555500FFFFFFFF
AA00FF00AAAAAAFFFFAAAA0000AA55AA0000AAAAFFFFAAAAAA00FF00AAFFFFFFFF005555
0000AAAA0055550055FFFFFFAAAA00AAFFAAFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA005500AAAAAAAA55AAAAFFFF55FF00FFFFAAFFAAAA00FFAA00
FF005500FFFF00000000FFFFAAFF55FFAAFFFF00000000FFFF005500FF00AAFF00AAAAFF
AAFFFF00FF55FFFFAAAA55AAAAAAAA005500AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF005555AA0055AAFFAA5500005555FF00AAFF55555555AAAAAA
00FF55FF00AAFFFFAAFFFFFFFF00AA00FFFFFFFFAAFFFFAA00FF55FF00AAAAAA55555555
FFAA00FF5555000055AAFFAA5500AA555500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAAFF550055AAAAAAFFFFAAAAFF0055AAAAFFAAAAFF55AA
00AAFFAA00AA55AAAAAA55AAAA555555AAAA55AAAAAA55AA00AAFFAA00AA55FFAAAAFFAA
AA5500FFAAAAFFFFAAAAAA550055FFAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAAA0000FFFF00AAFF55AAAA0000FF00AA55FF55FF
AAFF555555AAFFAA55FFAAAAAAAAFFAAAAAAAAFF55AAFFAA555555FFAAFF55FF55AA00FF
0000AAAA55FFAA00FFFF0000AAAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AA5555FF5500AAFFAA5500FF5555AAFFAA0000
55AAAAFFAAAAAA55FFFFFF00FF000000FF00FFFFFF55AAAAAAFFAAAA550000AAFFAA5555
FF0055AAFFAA0055FF5555AA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055555500550055FFAA005555AAAAFFAA55AA00AA
AAFF55AAAAAAAAAAFF00AAFFFFFFAAFFFFFFAA00FFAAAAAAAAAA55FFAAAA00AA55AAFFAA
AA555500AAFF5500550055555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAAFFAAFFAA0055FFFF55AA00FFFF55AA55
FFAA0000FFFF00FF00AAAAAA55AAAAAA55AAAAAA00FF00FFFF0000AAFF55AA55FFFF00AA
55FFFF5500AAFFAAFFAAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA55AA00FF005555FF55FFAAFF00AA0055
55FFAAFFFFFFFFAA00AA55FFAAAAAAAAAAFF55AA00AAFFFFFFFFAAFF555500AA00FFAAFF
55FF555500FF00AA55AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00555555AAAA0000AAFFAA005500FFFFAA
AAFF000000005500AAAAAAFF0000FF0000FFAAAAAA005500000000FFAAAAFFFF005500AA
FFAA0000AAAA55555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055550055AAFFFFAA55AAFFFF55000000
FF00AAAA00AAAAFFFF0000FFAAFFFFFFAAFF0000FFFFAAAA00AAAA00FF00000055FFFFAA
55AAFFFFAA5500555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFF55AAAA55FFFF00AAFFAAFFFF
AA00AA5500FF00FFAA00AAAA5500000055AAAA00AAFF00FF0055AA00AAFFFFAAFFAA00FF
FF55AAAA55FFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA0000FFFF5555FF00FFAA55AA
AAAA005555AAAA00FFFFAA55FFFFAAFFFF55AAFFFF00AAAA555500AAAAAA55AAFF00FF55
55FFFF0000AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FF00AAFFAAAA5555FFAAAA
AAAAAA0000AA55FF00AAFF55FF555555FF55FFAA00FF55AA0000AAAAAAAAAAFF5555AAAA
FFAA00FF5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555FF00FFAA55FFFF555555
55555555AA55005500FFFFFF5555005555FFFFFF00550055AA55555555555555FFFF55AA
FF00FF555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF005500AA00FFAAAAFF
AAAAFFAAAAAAFFFF5500000000AA00AA0000000055FFFFAAAAAAFFAAAAFFAAAAFF00AA00
5500FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAFFAAFF550000FFFF
FF000000FF0000550055FF0055FFAAFF5500FF5500550000FF000000FFFFFF000055FFAA
FFAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFFAAFFFFFF
FFFFAAFFFFFFAAFFAAFFAA00AA00FF00AA00AAFFAAFFAAFFFFFFAAFFFFFFFFFFAAFFAA00
5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555AA00FFFFFFFF
FFFFFF00AAFF000055AAAAAA0055FF5500AAAAAA550000FFAA00FFFFFFFFFFFFFF00AA55
5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF5500000055
00005500FF00AAAA0000FF00FF55FF55FF00FF0000AAAA00FF005500005500000055FFAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAAA00AAAA
FFFFAAAA00FF55AA00AAAA5555FFFFFF5555AAAA00AA55FF00AAAAFFFFAAAA00AAAAFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AA5500
AAFF00FF00550055AA5500AA0000000000AA0055AA55005500FF00FFAA0055AA5500AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055555500
FFFFFFAA00AA00AA005555AAFFFFAAFFFFAA555500AA00AA00AAFFFFFF0055555500FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAA
FF00AAFF5500AAAAAA0000AA55AAAAAA55AA0000AAAAAA0055FFAA00FFAAFFAAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA
55AA55FF55FF0000FF0055FFAAAAAAAAAAFF5500FF0000FF55FF55AA55AAFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00
5555550000AAFFFFAA00AA00FF00FF00FF00AA00AAFFFFAA000055555500AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
55550055FF00FFAA0055FFAAFF005500FFAAFF5500AAFF00FF5500555500FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAAFFFF5555AAAAAA000000FFAAFFAAFF000000AAAAAA5555FFFFAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFAA0000AA55FFAAFFFFAA005500AAFFFFAAFF55AA0000AAFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA0055FF0000AAFF5555FFAAFFAAFF5555FFAA0000FF5500AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF005555FF0055AAAAFFAA005500AAFFAAAA5500FF555500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAFF0055555555FFAAFFAAFF5555555500FFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFAAFFAAAAFFAA005500AAFFAAAAFFAAFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA005500AA55AA00AA00AA55AA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF005555AAFFAA555555AAFFAA555500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAFF55555500555555FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFAAAAFFAAFFAAAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA0055AAAAAA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00555555555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.287906 0.588183 0.375216 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000005555FFFFFFAAAAAAAAAAAAAAAAAA55000055AAAAAAAAAAAA00FF00AAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA00FF
00AAAAAAAAAAAA55000055AAAAAAAAAAAAAAAAAAFFFFFF5555000000FF
FFFFAAFFFF55FF005555FF55AAAAAAAAAAAAAAFFFFAAAAAAAAAA55AAFFFFFFAA55AAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA55AAFFFF
FFAA55AAAAAAAAAAFFFFAAAAAAAAAAAAAA55FF555500FF55FFFFAAFFFF
FFFFFF005555550000FF0055AAAAAAAAAAAAAA5555AAAAAAAAAAAAFF550055FFAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFF5500
55FFAAAAAAAAAAAA5555AAAAAAAAAAAAAA5500FF000055555500FFFFFF
FFFFFFFFAAAAFFAAFFFFFFAAAA55AAAA55FFAA0055AAAAAAAAAAAAAA005500AAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA0055
00AAAAAAAAAAAAAA5500AAFF55AAAA55AAAAFFFFFFAAFFAAAAFFFFFFFF
FFFFFFFFFF00AAAA5555AA55FFAAAAAA5500FFFFAAAAAAAAAAAA55FFAAFFAAFF55AAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA55FFAAFF
AAFF55AAAAAAAAAAAAFFFF0055AAAAAAFF55AA5555AAAA00FFFFFFFFFF
FFFFFFFFFFFFAA55FFFF555555AAAAAA550000AAAAAAAAAAAAAA5500FFFFFF0055AAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA5500FFFF
FF0055AAAAAAAAAAAAAA000055AAAAAA555555FFFF55AAFFFFFFFFFFFF
FFFFFFFFFFFFFF0000AAAAFFAAAAAAAAAAFFFFAA55AAFF55AAAAAAFFFFFFFFFFAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFFFFFF
FFFFAAAAAA55FFAA55AAFFFFAAAAAAAAAAFFAAAA0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF55AA55AAAAAA55AA5555FFFF0055AAAAAA5555005555AAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA555500
5555AAAAAA5500FFFF5555AA55AAAAAA55AA55FFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0055AAFFAA55FF55FF55FFFFFFFFAAAA55AAAAFFAAFFAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFFAA
FFAAAA55AAAAFFFFFFFF55FF55FF55AAFFAA5500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAA00FF0055AA55005555AA55AAAAFF00FF5555AAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA5555
FF00FFAAAA55AA55550055AA5500FF00AAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AAFFFFFFAAAAAAFFFF55FF55FFAA000055FFFF55AAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA55FFFF
550000AAFF55FF55FFFFAAAAAAFFFFFFAA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA555500FFAA55FF0055AA5500FFAAFFFF550055AAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA550055
FFFFAAFF0055AA5500FF55AAFF005555AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000005555FFFFFFAAAAAAFFFFFF0055FFFFAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFFFF
5500FFFFFFAAAAAAFFFFFF5555000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55FF005555FF55AA5555000000AAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA00
00005555AA55FF555500FF55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555550000FF0055AAAAFFAAFFFFAA55AAAA55AA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA55AAAA55AAFF
FFAAFFAAAA5500FF000055555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAAFFFFFFAAAA55AA55AA5555FFFF00AA55
FF55AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA55FF55AA00FFFF5555
AA55AA55AAAAFFFFFFAAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAA5555AA55FFAAAAAAFF55FFFFFFFFAA55
0055AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA550055AAFFFFFFFF55
FFAAAAAAFF55AA5555AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFF555555AAAAAA555555AA5555AAAA
FFFF55AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA55FFFFAAAA5555AA5555
55AAAAAA555555FFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AAAAFFAAAAAAAAAAFFAAAAAAFFAA55
FF0055AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA5500FF55AAFFAAAAAAFF
AAAAAAAAAAFFAAAA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55AA55AAAAAA55AA55AAAA5555FF
FFFFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFFFFFF5555AAAA55AA
55AAAAAA55AA55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AAFFAA55FF55FF55FF55AA0055
55AA55AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA55AA555500AA55FF55FF
55FF55AAFFAA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FF0055AA550055AAFFFF
55FFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFF55FFFFAA550055AA
5500FF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFFFFAAAAAAFFFF55AA55
5555AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA555555AA55FFFFAAAA
AAFFFFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555500FFAA55FF0055AAAA
FFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFFAAAA5500FF55AA
FF005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000005555FFFFFFAAAA55
AA55AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA55AA55AAAAFFFFFF55
55000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55FF005555FF55
FFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFF55FF555500FF55
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555550000FF0055
AA55AAFF55AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA55FFAA55AA5500FF00005555
5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAAFFFFFFAA
AAAAFF0055AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA5500FFAAAAAAFFFFFFAAFFAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAA5555AA55
FFAA000055AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA550000AAFF55AA5555AAAA00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFF5555
55AAFFFFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFFFFAA555555FFFF55AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AAAAFF
AAAA5555AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA5555AAAAFFAAAA0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55AA
55AAFFAAAA55AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA55AAAAFFAA55AA55FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AA
FFAA5555FFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFF5555AAFFAA5500FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
AA00FF0000AAFF55AAAAAAAAAAAAAAAAAAAAAAAAAA55FFAA0000FF00AAAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
AAFFFFFFAAFF0055AAAAAAAAAAAAAAAAAAAAAAAAAA5500FFAAFFFFFFAA00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA555500FFFFFFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFFFFFF005555AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000005555AA55AAAAAAAAAAAAAAAAAAAAAAAAAA55AA5555000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFF55FFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFF55FFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00555555AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA55555500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAFFAA55FF55AAAAAAAAAAAAAA55FF55AAFFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00AAAA550055AAAAAAAAAAAAAA550055AAAA00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA55FFFFAAAAAAAAAAAAAAAAAAFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000AAAAAAAAAAAAAAAAAAAAAA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF55AAAAAAAAAAAAAA55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0055AAAAAAAAAAAAAA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAAAA55AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AAFF55FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.287906 0.782187 0.375216 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FF0000AAFF0055005555005555AA555555AAFFFFAAAA00FF555500AAAAFF5555
00555555FFFFFFFF55FF00FF5555FF5555FF00FF55FFFFFFFF555555005555FFAAAA0055
55FF00AAAAFFFFAA555555AA5555005555005500FFAA0000FF000000FF
FFFFAAFFFFFFAAFF5500AAFFFF555555FF55AAAAFF00FF5500555555AAAA55005555AAAA
FFFF55FF5500FF55000000FF55FFFFFF55FF00000055FF0055FF55FFFFAAAA55550055AA
AA5555550055FF00FFAAAA55FF555555FFFFAA0055FFAAFFFFFFAAFFFF
FFFFFF0055FF00FF55555500FF55FF5555AAAAAAAA0055FFFFAA00FFAA55FFFFAA00FFFF
0055FF550000FF5555555555AAAA00AAAA5555555555FF000055FF5500FFFF00AAFFFF55
AAFF00AAFFFF5500AAAAAAAA5555FF55FF00555555FF00FF5500FFFFFF
FFFFFFFFAA00AA5555FF555555AAAA00FFAA55FFAA5500000000AA555500000000AA5555
AA00FF55555555AAAA55AAAA55FFAAFF55AAAA55AAAA55555555FF00AA5555AA00000000
5555AA0000000055AAFF55AAFF00AAAA555555FF5555AA00AAFFFFFFFF
FFFFFFFFFF0000AAFF00550000555500AAAAAA55550000FF0000FFFF5555555555550000
555555AAAA55AAAAAAAA55FFAA00AA00AAFF55AAAAAAAA55AAAA55555500005555555555
55FFFF0000FF00005555AAAAAA00555500005500FFAA0000FFFFFFFFFF
FFFFFFFFFFFFAAFF5500AAFFFFAAAA55005555000055AA00AA5500FF55FF55FF55FFFFAA
FFAAAA55FFAAAAAAAAAAAA555500AA005555AAAAAAAAAAAAFF55AAAAFFAAFFFF55FF55FF
55FF0055AA00AA55000055550055AAAAFFFFAA0055FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFF005500AA00AAAAAAAAFFFF55555555FFAAFF555555AAAA00FF55FF0055
55AAFF5555AAFF55AAFF55AAAA550055AAAA55FFAA55FFAA5555FFAA555500FF55FF00AA
AA555555FFAAFF55555555FFFFAAAAAAAA00AA005500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA0055555500555500FF5555FF55FF00FF5555FF55AAFFFFFF5500AA
FFAA5555FFFF00550055FF55AAFFAAFFAA55FF55005500FFFF5555AAFFAA0055FFFFFFAA
55FF5555FF00FF55FF5555FF0055550055555500AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000550000FFAA0055FF5555AAAA0055FF5555AAAAAA00AAAA5500
55FFAA00FF5500AAFFFF550000AAAAAA000055FFFFAA0055FF00AAFF550055AAAA00AAAA
AA5555FF5500AAAA5555FF5500AAFF0000550000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFAAFFFFFF000055FF55FFAA550000005500555500AA000055
AAAA0000FF55555500FF555555550055555555FF00555555FF0000AAAA550000AA005555
005500000055AAFF55FF550000FFFFFFAAFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF005555AA55555555FF00AAAAAAFFFFAAFFAAFFAA0055555555
FFAA5500AAAAFFAA0055FF55FF555555FF55FF5500AAFFAAAA0055AAFF5555555500AAFF
AAFFAAFFFFAAAAAA00FF55555555AA555500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF55FF5555AA0000AA00AAAAAA000000AA55AAAA55
AA55FFFFAA55FF00FF00AAAA5555FF5555AAAA00FF00FF55AAFFFF55AA55AAAA55AA0000
00AAAAAA00AA0000AA5555FF55FFFF00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000055FF55FFAAFFFF0000AA0000FF0000AAFF55AA
AAAA5555AAFF0055AA55005555FFFFFF55550055AA5500FFAA5555AAAAAA55FFAA0000FF
0000AA0000FFFFAAFF55FF5500000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAAAA00FF55AA5555555500AA5555555500FFAA
55FFAA00FFFFFFAAAAAAFFFF5555AA5555FFFFAAAAAAFFFFFF00AAFF55AAFF0055555555
AA0055555555AA55FF00AAAAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFAA5500FFAA55AAAAFFAAFF5555FF555555AA
FF00555555AA5555005555AA55AAAAAA55AA5555005555AA55555500FFAA555555FF5555
FFAAFFAAAA55AAFF0055AAFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA00FF005555FFAA555500FFAA00AAFF00AA
00AA55AAAAFF55FFFFAAAAFF5555005555FFAAAAFFFF55FFAAAA55AA00AA00FFAA00AAFF
005555AAFF555500FF00AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA555555FF5500550000FF55AA000000FF
FFAA55AAFF5500000000AA00AAFFAAFFAA00AA0000000055FFAA55AAFFFF000000AA55FF
0000550055FF555555AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555FF550000FFAAFFFFFF55AA0055AA
55550000AAAAFFFFAAFFFF0000AAAAAA0000FFFFAAFFFFAAAA00005555AA5500AA55FFFF
FFAAFF000055FF5555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005500000055AA00AA00AAAA00FFFFAAAA
AA55AA00555500FF55AA555555550055555555AA55FF00555500AA55AAAAAAFFFF00AAAA
00AA00AA550000005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AA00FFFFAA5500555555AA55FF
AA55AAFFFF555555AAAAAAFFAA00FF00AAFFAAAAAA555555FFFFAA55AAFF55AA55555500
55AAFFFF00AA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000555555AA55FFFFAAAAFFAA55AA
55FF55AA5555FF5555005555AAFFFFFFAA5555005555FF5555AA55FF55AA55AAFFAAAAFF
FF55AA5555550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAAA55FFFFFFFF00FF55AAAA
AA5555FFAAAA5555FFFFAA00FFFFFFFFFF00AAFFFF5555AAAAFF5555AAAAAA55FF00FFFF
FFFF55AAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555000000000000FF55FFAA
55FFFF55005555FFFFFFFF00000000000000FFFFFFFF55550055FFFF55AAFF55FF000000
000000555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF0000FF0000FF5555AA
FF0055FFFFAAAA5555AA555555555555555555AA5555AAAAFFFF5500FFAA5555FF0000FF
0000FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0055AA00AAFFAA
555555FF00555500005555FFFF55FF55FFFF55550000555500FF555555AAFFAA00AA5500
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAA0000FFFFFF
00AAFF0055AAAAFFFFAA00FF5500000055FF00AAFFFFAAAA5500FFAA00FFFFFF0000AAFF
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF00FF00000000
00FFFFFFAA0000AAAA0000FF5555555555FF0000AAAA0000AAFFFFFF0000000000FF00FF
5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA5555555555
5555AA555500AA55FFAAFFFFFF55FF55FFFFFFAAFF55AA005555AA55555555555555AA00
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AAFF00AAFF
AAAAFF55FFFFAA55AA55FF0055FFFFFF5500FF55AA55AAFFFF55FFAAAAFFAA00FFAA0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5500AA00
AA00000055FF00FFAA55AA55000000000055AA55AAFF00FF55000000AA00AA0055FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005500AA00
5555555555FF000000AAFF55555555555555FFAA000000FF555555555500AA005500FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005555
55FFFF55FF5500AA550055FFFF55FF55FFFF550055AA0055FF55FFFF55555500AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055
0000000055FFFFAA55AA00FF5500000055FF00AA55AAFFFF5500000000550000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
AAFFFFAAFF0055FFAA0000FF5555555555FF0000AAFF5500FFAAFFFFAAFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
5555AA55FF000055FFAAFFFFFF55FF55FFFFFFAAFF550000FF55AA555500FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA00FFFF5500AA55AA55FF0055FFFFFF5500FF55AA55AA0055FFFF00AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000055AAFFAA55AA55000000000055AA55AAFFAA5500000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFFAA000000AAFF55555555555555FFAA000000AAFFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0055FFAAFFFFAA5555FF55FF55FF5555AAFFFFAAFF5500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA00AA00AAAAAA55AA55AA55AA55AAAAAA00AA00AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000AA55FFAA55AAFF00FFAA55AAFF55AA0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFF5555AAFFAA555555AAFFAA5555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00550000AAAAAAFFAAAAAA00005500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA0055AAFF55AA55FFAA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00005555AAAAAA55550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFAAAAAAAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00555500555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.287906 0.97619 0.375216 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FFFFFFAAAAAAFFFFAAFFFF5500FF555555FFFF5500550000FF55AAAA00005555
0000555500FFAAAAFFFFFFAA00FFFFFF00AAFFFFFFAAAAFF005555000055550000AAAA55
FF0000550055FFFF555555FF0055FFFFAAFFFFAAAAAAFFFFFF000000FF
FFFFAAFF0055FF00FFFF0000FFFFFFFF555555005555AA000000AAFFFFFF55AAFFFFAAAA
FFFFAAAAFFFFFF00FF0055AAFFFFFFFFFFAA5500FF00FFFFFFAAAAFFFFAAAAFFFFAA55FF
FFFFAA000000AA555500555555FFFFFFFF0000FFFF00FF5500FFAAFFFF
FFFFFF000000AAAA555555FF55000055FFFF55FF55FFFF00AAFFFF000055FFFF0000FFFF
0055FFAA5500FF555555FFFF0055AA5500FFFF555555FF0055AAFF5500FFFF0000FFFF55
0000FFFFAA00FFFF55FF55FFFF55000055FF555555AAAA000000FFFFFF
FFFFFFFFAAFF00FFFF55FFFFFF5555FFFFFFFF550055AA00FFFFFFFFAA0000FF5555FF00
0000AAAAAAFFFFFF55FFFFFFFFAAAAAAFFFFFFFF55FFFFFFAAAAAA000000FF5555FF0000
AAFFFFFFFF00AA550055FFFFFFFF5555FFFFFF55FFFF00FFAAFFFFFFFF
FFFFFFFFFF000000FF55FF0055FFFF55000055FFFFAAAAAA55000055FFAAFF00555500FF
AAFF00FFFF000055FFFFFFFFFFFF00FFFFFFFFFFFF550000FFFF00FFAAFF00555500FFAA
FF55000055AAAAAAFFFF55000055FFFF5500FF55FF000000FFFFFFFFFF
FFFFFFFFFFFFAAFF00555555FFFFFFFF5555FFFFFFFF00FFFF5555FFFFFF000000AA00FF
00FF55555555FF55FF0000FF5500000055FF0000FF55FF55555555FF00FF00AA000000FF
FFFF5555FFFF00FFFFFFFF5555FFFFFFFF55555500FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFF000000AA000055000055550000FF000000FF55FFFFFFFFFFAAFFFF00AA
AA550055550055FFFFFFAA005555FF555500AAFFFFFF550055550055AAAA00FFFFAAFFFF
FFFFFF55FF000000FF000055550000550000AA000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF00FFAAFFAAFFFF55FF555555FF5555550000550000FFFFFFFFAA
55FFFFAAAAFFFF5500AA55FF55FFFFFF55FF55AA0055FFFFAAAAFFFF55AAFFFFFFFF0000
550000555555FF555555FF55FFFFAAFFAAFF00FFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFF0055FFFFFF55FFFFFF55FFFFAAFFAAFF00550000FF
FF5500FFFF00005555FFAAAA0000550000AAAAFF55550000FFFF0055FFFF00005500FFAA
FFAAFFFF55FFFFFF55FFFFFF5500FFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF0055FF00AA005500AA00AA55550000FFFFFF000000AAFFFF
FFFF55555555FF55FFFFFF00FFAAFFAAFF00FFFFFF55FF55555555FFFFFFFFAA000000FF
FFFF00005555AA00AA005500AA00FF5500FFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000AAAA55FF55FF55AAAAAAFFAAFFFFFFFFFFAAFFFF0055
AA5500555500550055FF000000FFFFFF000000FF5500550055550055AA5500FFFFAAFFFF
FFFFFFAAFFAAAAAA55FF55FF55AAAA000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFFF550055FFFF00FFFFFF0000550000FFFFFFFFAA
AAAAFFFF55FF55FF55FF00AAFFFFFFFFFFAA00FF55FF55FF55FFFFAAAAAAFFFFFFFF0000
550000FFFFFF00FFFF550055FFFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF55FF55FF000000FF00000000AAFFFFFFFFFFFF
00FFFFFFFF550055FFFFFFAA5500FF0055AAFFFFFF550055FFFFFFFF00FFFFFFFFFFFFAA
00000000FF000000FF55FF55FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0055555500FFAAFFFFFFAAFFFFAA5555AA5555AA
55AA5500FF55FF55FF0000FFFF555555FFFF0000FF55FF55FF0055AA55AA5555AA5555AA
FFFFAAFFFFFFAAFF0055555500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000AA000000FFFFFFFFFF0000FFFF55FFAAAAFF
55FFAAAA550055FFFFFFAA00AAAAFFAAAA00AAFFFFFF550055AAAAFF55FFAAAAFF55FFFF
0000FFFFFFFFFF000000AA000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFAAFF0055AA550000000055FFFFFF00FF
55FF00FFFF5555000055AAFF00FFFFFF00FFAA5500005555FFFF00FF55FF00FFFFFF5500
00000055AA5500FFAAFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFAAAAAAFFFFAAFFFF5500FF5555
5500000055FFFF5555FFFF000000FF000000FFFF5555FFFF55000000555555FF0055FFFF
AAFFFFAAAAAAFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0055FF00FFFF0000FFFFFFFF55555500
5555FF555500FF55FFFFFFFFAAFFFFFFAAFFFFFFFF55FF005555FF555500555555FFFFFF
FF0000FFFF00FF5500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000AAAA555555FF55000055FFFF55FF
55FFFFFF55FF550055AA5500FFFFFFFFFF0055AA550055FF55FFFFFF55FF55FFFF550000
55FF555555AAAA000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFFF55FFFFFF5555FFFFFFFF55
0055AA550055FFFFAAAAAAFFFFFFFFFFFFFFAAAAAAFFFF550055AA550055FFFFFFFF5555
FFFFFF55FFFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF55FF0055FFFF55000055FF
FFAAAAAAFFFF5500FFFF00FF0000550000FF00FFFF0055FFFFAAAAAAFFFF55000055FFFF
5500FF55FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00555555FFFFFFFF5555FFFF
FFFF00FFFFFFFF5555AA00FF00AAFFAA00FF00AA5555FFFFFFFF00FFFFFFFF5555FFFFFF
FF55555500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000AA000055000055550000
FF000000FF0055FFFF55AAAA00FFFFFF00AAAA55FFFF5500FF000000FF00005555000055
0000AA000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFAAFFAAFFFF55FF55
5555FF555555FFFFFFFF55AAFFFFFFFFFFAA55FFFFFFFF555555FF555555FF55FFFFAAFF
AAFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF0055FFFFFF
55FFFFFF55FFFFFFFFFFFF55AA005500AA55FFFFFFFFFFFF55FFFFFF55FFFFFF5500FFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0055FF00AA005500
AA00AA55550000FF5500FF55FFAAFFAAFF55FF0055FF00005555AA00AA005500AA00FF55
00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000AAAA55FF55FF
55AAAAAAFFAAFFFFFF55555500FFFFFF00555555FFFFFFAAFFAAAAAA55FF55FF55AAAA00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFFF550055
FFFF00FFFFFF00550000AA000000FF000000AA00005500FFFFFF00FFFF550055FFFF00FF
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF55FF55
FF000000FF000000AAFF00FFAAFFFFFFAAFF00FFAA000000FF000000FF55FF55FF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00555555
00FFAAFFFFFFAAFFFF000000FFFFFFFFFF000000FFFFAAFFFFFFAAFF0055555500FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000AA00
0000FFFFFFFFFF0000FFAAFFFFFFFFFFFFFFAAFF0000FFFFFFFFFF000000AA000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FF
AAFF0055AA5500000000FFFFFFFFFFFFFFFFFF0000000055AA5500FFAAFF00FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFAAAAAAFFFFAAFFFFFFFFFFFFFFFFFFFFFFAAFFFFAAAAAAFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
0055FF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FF5500FFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000AAAA555555FF55000055000055000055000055FF555555AAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAFF00FFFF55FFFFFF5555FFFFAAFFAAFFFF5555FFFFFF55FFFF00FFAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FF55FF0055FFFF5500FFFFFF0055FFFF5500FF55FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFF00555555FFFFFFFF5555555555FFFFFFFF55555500FFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000AA000055000055550055550000550000AA000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAFF00FFAAFFAAFFFF55FF55FFFFAAFFAAFF00FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFF0055FFFFFF5500FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFF0055FF00AA005500AA00FF5500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000AAAA55FF55FF55AAAA000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF00FFFF550055FFFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF55FF55FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF0055555500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000AA000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.383947 0.200176 0.471257 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFF5555AA55FFFFFF55FF00005555FF55FFAAAAAAAAAAAA550055FFFFFF55AAAA5555
AAFF5555000000FF55FFFF5555AAFFAA5555FFFF55FF0000005555FFAA5555AAAA55FFFF
FF550055AAAAAAAAAAAAFF55FF55550000FF55FFFFFF55AA5555FFFFFF
FFFFFFFF55FF55FFAA55FFFFFFAAFFAAAAAAFF5555FF555555FFFFAAAAAAAAAA0055AA55
55FFAAAAFFFFAAFF55FFAA5555AAAAAA5555AAFF55FFAAFFFFAAAAFF5555AA5500AAAAAA
AAAAFFFF555555FF5555FFAAAAAAFFAAFFFFFF55AAFF55FF55FFFFFFFF
FFFFFFFFFF55AA55FF55FFAA55FF55AAAA55AAFFAAAAAAFFAAAAAAAA550000005555AAAA
FFAA55AAAAAAAA55FF00FFAAAA005500AAAAFF00FF55AAAAAAAA55AAFFAAAA5555000000
55AAAAAAAAFFAAAAAAFFAA55AAAA55FF55AAFF55FF55AA55FFFFFFFFFF
FFFFFFFFFFFF5555AAFFAA5500FFFF555555AAAAAA55AAAAAA55AAAA5555005555AA55AA
AAAA5555FF5555FFFFFFAA5500AA00AA0055AAFFFFFF5555FF5555AAAAAA55AA55550055
55AAAA55AAAAAA55AAAAAA555555FFFF0055AAFFAA5555FFFFFFFFFFFF
FFFFFFFFFFFFFF55FF55AAAAFFFFFFFF5500FF000055FF5555FF000055FFFFAAAAFF0055
AAAA5555AAFFAAAAAAAAAA555500AA005555AAAAAAAAAAFFAA5555AAAA5500FFAAAAFFFF
550000FF5555FF550000FF0055FFFFFFFFAAAA55FF55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55AA55AAAAAAAAAAAAFFFFFFAAFFAA5555AAFFFFAAAAAAAA55AAFFFF
555555AA55AAFF000000FFAAAA000000AAAAFF000000FFAA55AA555555FFFFAA55AAAAAA
AAFFFFAA5555AAFFAAFFFFFFAAAAAAAAAAAA55AA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555AAAA55AAAA55AAFF55AAAAAA5555AAAAAAAA55AAAA5555FFAA
5555AA55AA55AAFFFFAAFF55555500555555FFAAFFFFAA55AA55AA5555AAFF5555AAAA55
AAAAAAAA5555AAAAAA55FFAA55AAAA55AAAA5555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55FF5555AAAA5555FFAAAA55AA00AAAA55AAAA555555FFFF55AA
00AAAA555555AAAAAAAA55FFFF550055FFFF55AAAAAAAA555555AAAA00AA55FFFF555555
AAAA55AAAA00AA55AAAAFF5555AAAA5555FF55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AA5555FF55FFFF00AA5555550000FF5555FF0055FFAA5555
55000055FFFF5555555555AAFF550055FFAA5555555555FFFF550000555555AAFF5500FF
5555FF0000555555AA00FFFF55FF5555AA55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5555AA55FFFFFFFFAA00AAAAFFFFAA5555AAFFFF55AA00AA
AAFFFFAAAAAAAA00AAAA00AAFF550055FFAA00AAAA00AAAAAAAAFFFFAAAA00AA55FFFFAA
5555AAFFFFAAAA00AAFFFFFFFF55AA5555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF55FF55FFAA55FFAA000055AAFF5555AA55AAFF5500AA00
55AAFF5555555555000000AAFF550055FFAA0000005555555555FFAA5500AA0055FFAA55
AA5555FFAA550000AAFF55AAFF55FF55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA55FF55FFAA0000AAAA55FFFF5555AAAAAA000055
55AAAAAA00AAAA00AA0000AAFF550055FFAA0000AA00AAAA00AAAAAA55550000AAAAAA55
55FFFF55AAAA0000AAFF55FF55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAFFAA5500555555FFFFFFFF5500000000AA00
AAAA55AA0000005555550055AAFFAAFFAA5500555555000000AA55AAAA00AA0000000055
FFFFFFFF5555550055AAFFAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF55AAAAFFFF5500FFFFFFFF00555500555555
00AA555555005555AA555500FFAA55AAFF005555AA555500555555AA0055555500555500
FFFFFFFF0055FFFFAAAA55FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA55AAAAAAAAFFFFFFFFFFFFAAAAFFFF55FF
FFAA00AAAAFFFF55FF55FFFFAA55AA55AAFFFF55FF55FFFFAAAA00AAFFFF55FFFFAAAAFF
FFFFFFFFFFAAAAAAAA55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAAA55AAAAAAAAAAAAAAAA55AAFF55FF
AA550055AAAAAAAAFF55FFAA55AA55AA55AAFF55FFAAAAAAAA550055AAFF55FFAA55AAAA
AAAAAAAAAAAA55AAAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF5555AAAA55AAAA55AAAA5555FFAAAA
AA555500FFAA0055AAFFAA55AA55AA55AA55AAFFAA5500AAFF005555AAAAAAFF5555AAAA
55AAAA55AAAA5555FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5555FF55FF5555AAAA5555AAFF00
0055FFFFAA550055FF55AAAAFF005500FFAAAA55FF550055AAFFFF550000FFAA5555AAAA
5555FF55FF5555AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA55FFFFFF55FF5555AA55AAFF
FFAAAAAAAA555500FFFF5555FFAAFFAAFF5555FFFF005555AAAAAAAAFFFFAA55AA5555FF
55FFFFFF55AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF55FFAA55FFFFFF55FF55FF55
AAFF00000055FFFFAA55FFFF55AAAAAA55FFFF55AAFFFF55000000FFAA55FF55FF55FFFF
FF55AAFF55FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA55FF55FFAA55FFFFFF55AA
55AAFFFFAAFFAA55FF55FFAA5555555555AAFF55FF55AAFFAAFFFFAA55AA55FFFFFF55AA
FF55FF55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAFFAA5500FFFF00FF55
55AAAAAAAA55FF55FFAAAAAA5555AA5555AAAAAAFF55FF55AAAAAAAA5555FF00FFFF0055
AAFFAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF55AAAAFFFFFFFFAA55
55AAAA5500AAAAAAFF5555FF5500FF0055FF5555FFAAAAAA0055AAAA5555AAFFFFFFFFAA
AA55FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA55AAAAAAAAAAAA55
55AAAA555500AA55AAFFAAAAAAFFFFFFAAAAAAFFAA55AA005555AAAA5555AAAAAAAAAAAA
55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAAA55AAAA55AA
555555FF00555555AAAAAA55AAAAAAAAAA55AAAAAA55555500FF555555AA55AAAA55AAAA
5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF5555AAAA5555
FFFF55FFAAFFAAAAFF000055FF555555FF550000FFAAAAFFAAFF55FFFF5555AAAA5555FF
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5555FF55FF
FF00FF55AAAAAA55AAFFFFAAAAAAFFAAAAAAFFFFAA55AAAAAA55FF00FFFF55FF5555AA55
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA55FFFF
FFFFAA5555FF5555AAAAAAAA55AAAAAA55AAAAAAAA5555FF5555AAFFFFFFFF55AA5555FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF55FFAA
55FFAA00AAAAAA00AA55AAAA5555FF5555AAAA55AA00AAAAAA00AAFF55AAFF55FF55FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA55FF
55FFAA00000000555555AA0055FF00FF5500AA55555500000000AAFF55FF55AA55FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA
FFAA550055550055FF00550055FFAAFF55005500FF550055550055AAFFAA5555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF
55AAAAFFFF550055FFAAFFAAFFAA55AAFFAAFFAAFF550055FFFFAAAA55FF55FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
AA55AAAAAAAAFFFF55AAAAAA55FF55FF55AAAAAA55FFFFAAAAAAAA55AA55FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
5555AAAA55AAAAAAAA0055AAAAFF55FFAAAA5500AAAAAAAA55AAAA5555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55FF5555AAAA550000AAAA55AAFFAA55AAAA000055AAAA5555FF55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF55AA5555FF550055555555AAAAAA555555550055FF5555AA55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5555AA55FFFFAAAAFFAAAA55AAAAFFAAAAFFFF55AA5555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF55FF55FFAA55AAAAAA55AA55AAAAAA55AAFF55FF55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55AA55FF5500000055FF5500000055FF55AA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF5555AAFFAAFFFFAAAAAAFFFFAAFFAA5555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55FF55AAAAAAAA55AAAAAAAA55FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55AA55AAAA55AA55AAAA55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555AAAA555555AAAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55FF5555AA5555FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AA555555AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5555AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.383947 0.39418 0.471257 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFF55555555FF555500005555FF555555AAAAAAFF550000AA5500000055AAAAAA55FF
00000055550000555555FF555555FF555555FF55555500005555000000FF55AAAAAA5500
000055AA000055FFAAAAAA555555FF555500005555FF55555555FFFFFF
FFFFFFFF5555FF55AAAAFFFFAAAAFF55FF5555AA55550000FF005500AA55000000000055
55555555FFFFAAFFAAAAFF5555FFFFFF5555FFAAAAFFAAFFFF5555555555000000000055
AA005500FF00005555AA5555FF55FFAAAAFFFFAAAA55FF5555FFFFFFFF
FFFFFFFFFF555500000000AA00AAAAAA55FF5555AAAAFFFFAA550000FF55555555555555
FFFF55FFFFFF005555AA55FF5555005555FF55AA555500FFFFFF55FFFF55555555555555
FF000055AAFFFFAAAA5555FF55AAAAAA00AA000000005555FFFFFFFFFF
FFFFFFFFFFFF555555555555AA00AAAA00FFFF55FF00555500FFAAFFFFFF5555FF5555FF
FF00FFAA55FFAAFF00AAAA55FF555555FF55AAAA00FFAAFF55AAFF00FFFF5555FF5555FF
FFFFAAFF00555500FF55FFFF00AAAA00AA555555555555FFFFFFFFFFFF
FFFFFFFFFFFFFF5555FF5555FF00000000FFFFFF55AA00FFAAFF5500555500005555FFFF
FF0000AAAA55FF00FF0055FFFFFF55FFFFFF5500FF00FF55AAAA0000FFFFFF5555000055
550055FFAAFF00AA55FFFFFF00000000FF5555FF5555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55550000555555555555005555FF0000AAAAAAFFFF55555555FFFFFF
00FF0000000055555500AAFF55AAFFAA55FFAA0055555500000000FF00FFFFFF55555555
FFFFAAAAAA0000FF55550055555555555500005555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55555555FF5555FF555555FFFF0000FF5500FFFFFF5555FFFFFFFF
0000AA5500AA55AAAA5500FFFF550055FFFF0055AAAA55AA0055AA0000FFFFFFFF5555FF
FFFF0055FF0000FFFF555555FF5555FF55555555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5555FF55AAAAFF5555FFFFFFFFAAFF555555005555FFFFFFFFFF
0000FF555555AAAA00AAFFFF00FFAAFF00FFFFAA00AAAA555555FF0000FFFFFFFFFF5555
00555555FFAAFFFFFFFF5555FFAAAA55FF5555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF555500000000AAFF00FFFFFF005555FF555555FFFFFFFFFFFF
0000FFFF55FF5500FF00555500AA00AA00555500FF0055FF55FFFF0000FFFFFFFFFFFF55
5555FF555500FFFFFF00FFAA000000005555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF555555555555AAFFFF00FFFFAAAAFF5555FFFFFFFFFFFFFF
FFAAFF55AAAAAA550055AAAA5500FF0055AAAA550055AAAAAA55FFAAFFFFFFFFFFFFFFFF
5555FFAAAAFFFF00FFFFAA555555555555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF5555FF5555FF00FFFFAA55FF005555FFFFFF00FFFFFFFF
FF005555FF0055FFFFAAAA00AAFFFFFFAA00AAAAFFFF5500FF555500FFFFFFFFFF00FFFF
FF555500FF55AAFFFF00FF5555FF5555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF555500005555550055FFFFFFAAAAFF55AAFFFFFFFFFF
FF0000550055AAAAAAAA00AA5555005555AA00AAAAAAAA5500550000FFFFFFFFFFFFAA55
FFAAAAFFFFFF550055555500005555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555FF555555FFAA55FF005555FF00FFFFFFFF
00FF000055AAAA00AAAA0055FF555555FF5500AAAA00AAAA550000FF00FFFFFFFF00FF55
5500FF55AAFF555555FF55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF55AAAAFF00FF55FFAAFFAA0000FFFFFFFF
0000AA5500000000FF5500AAFF55FF55FFAA0055FF0000000055AA0000FFFFFFFF0000AA
FFAAFF55FF00FFAAAA55FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500000000AA55FF55AA55FF0000FFFFFFFF
0000FF5555555555550000FF55AAAAAA55FF0000555555555555FF0000FFFFFFFF0000FF
55AA55FF55AA000000005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555555555AAAAAA5555FFAAFFFFFFFFFF
FFAAFF55FF5555FF55555555000000000055555555FF5555FF55FFAAFFFFFFFFFFFFAAFF
5555AAAAAA555555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF5555FF0055FF555500FFFF00FFFF
FF005555FFAAAAFF5555FF55555555555555FF5555FFAAAAFF555500FFFFFF00FFFF0055
55FF5500FF5555FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55550000555555FFAAAA550055555500
555555FFFF0055FFAAAA55FF5555FF5555FF55AAAAFF5500FFFF555555005555550055AA
AAFF55555500005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555FF555500FF555555FF5555
55FF55550055AAAAAA00AAFF55FFFFFF55FFAA00AAAAAA55005555FF555555FF555555FF
005555FF55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF55AAAAFFFFFF55FFFFFF55
FF55AAAA550000000000FF55AAAAAAAAAA55FF000000000055AAAA55FF55FFFFFF55FFFF
FFAAAA55FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500000000AA000055550055
005500FF555555555555550000000000000055555555555555FF005500550055550000AA
000000005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555555555AA00550000FF
AAFFAAFF55FFFF5555FF555555555555555555FF5555FFFF55FFAAFFAAFF00005500AA55
5555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF5555FF000055AA00
0000AAAAAA55FFAAAA55FF55FF55FF55FF55FF55AAAAFF55AAAAAA000000AA550000FF55
55FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555000055555555FF00
00FF0055FF00AA00AAAA55FFFF00AA00FFFF55AAAA00AA00FF5500FF0000FF5555555500
005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555FF5555FFAA
FFFF0000555555AA00AAAAFF55AA00AA55FFAAAA00AA5555550000FFFFAAFF5555FF5555
5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF55AAAAFF55
0055555555FF5555AA00AAAAAA555555AAAAAA00AA5555FF555555550055FFAAAA55FF55
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500000000AA
FFFF5555FF55AAAA555555AA5555FF5555AA555555AAAA55FF5555FFFFAA000000005555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555555555
AAFF55FFFFFF5500FFAAAA5555FFFFFF5555AAAAFF0055FFFFFF55FFAA555555555555FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF5555
FF00FFAA55FFAA005555AA55AAAAAAAAAA55AA555500AAFF55AAFF00FF5555FF5555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55550000
55555500FFAA555555FF550000000000000055FF555555AAFF0055555500005555FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555
55FF55555500FFAAAAFF555555555555555555FFAAAAFF00555555FF55555555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555
FF55AAAAFFAAFF5500FFFF55FF55FF55FF55FFFF0055FFAAFFAAAA55FF5555FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
5500000000AAAAAAFFFFFFFF55AAAAAA55FFFFFFFFAAAAAA000000005555FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
555555555555AA555500555500000000005555005555AA555555555555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5555FF5555FF00AAFFFF55555555555555FFFFAA00FF5555FF5555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF55550000555555AAFF55FF55FF55FF55FFAA55555500005555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55555555FFFF5500550055005500550055FFFF55555555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF5555FF55AAFFAAFFAAFFAAFFAAFFAAFFAA55FF5555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF5555000000AAAAAA000000AAAAAA0000005555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF5555555555AA5555555555AA5555555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5555FF5555AAAAFFAAAA5555FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF5555000055FF00FF5500005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55555555FFAAFF55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5555FF55AA55FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55550000005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF55FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.383947 0.588183 0.471257 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF5555FF55000000AAAA55555500AAAA55AA5555AA00FF00AA55AA55AAAAFFAA550055
55AA55AAAAAA555555555555AA00FF00AA555555555555AAAAAA55AA55550055AAFFAAAA
55AA55AA00FF00AA5555AA55AAAA00555555AAAA00000055FF5555FFFF
FFFFFF55FFAAAA55AAAA00AA0055AAAA00AA55555555AAAAAA555555AA00AAAAAA000000
AA555555AA5555555555555555AAAAAA5555555555555555AA555555AA000000AAAAAA00
AA555555AAAAAA55555555AA00AAAA5500AA00AAAA55AAAAFF55FFFFFF
FFFFFFFF55AA555555AA55AA55AA00AAAA555555555555AA5555555555AAAA00AAAA55AA
AA0000AA55555555555555555555AA55555555555555555555AA0000AAAA55AAAA00AAAA
5555555555AA555555555555AAAA00AA55AA55AA555555AA55FFFFFFFF
FFFFFFFFFF5500005500FF0055AA55AA5555555555555555AA0055555555AA55AA555555
AA55AAAA0000AA550055AA0000AA00AA0000AA550055AA0000AAAA55AA555555AA55AA55
55555500AA5555555555555555AA55AA5500FF0055000055FFFFFFFFFF
FFFFFFFFFFFF5555FFFFAA55AA00AA555555005500AA0000AAAA5500005500FF005500AA
555555AA55AAAA000000AAAA55AA55AA55AAAA000000AAAA55AA555555AA005500FF0055
000055AAAA0000AA005500555555AA00AA55AAFFFF5555FFFFFFFFFFFF
FFFFFFFFFFFFFF55FFAA555555AAAA0000FF00AA55AA55AAAA00AA55AAAAFF00FFAAAA55
55555555AA00AAAA55AAAA00AA555555AA00AAAA55AAAA00AA5555555555AAAAFF00FFAA
AA55AA00AAAA55AA55AA00FF0000AAAA555555AAFF55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55AA55005555AA55AAAAAA555555AA00AAAA555555AA55FF55AA5555
5555555555AAAA00AA00AAAA5555555555AAAA00AA00AAAA55555555555555AA55FF55AA
555555AAAA00AA555555AAAAAA55AA55550055AA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55000000AA555555AA5555555555AAAA00AA005500FF00FF005500
AA0055555555AA55AA55AA55555555555555AA55AA55AA5555555500AA005500FF00FF00
5500AA00AAAA5555555555AA555555AA00000055FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5555FF550000AA55555555555555AA55AA55AA00FFFFAA55AA00
FF555555555555AA00AA555555555555555555AA00AA555555555555FF00AA55AAFFFF00
AA55AA55AA55555555555555AA000055FF5555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55FFAAAA55AA550000FF0000AA555555AA00AAFF55AA5500FF
AA550055AA0000AAAA5555555555555555555555AAAA0000AA550055AAFF0055AA55FFAA
00AA555555AA0000FF000055AA55AAAAFF55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AA555555AA00FFAA55AAAA0000AA5555FF00FF0055AAAA
AA000000AAAA55AA55555555555555555555555555AA55AAAA000000AAAAAA5500FF00FF
5555AA0000AAAA55AAFF00AA555555AA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF5500005500FFAA555555AA55AAAA0055AAFF00FFAAAA00
AAAA55AAAA00AA555555555555555555555555555555AA00AAAA55AAAA00AAAAFF00FFAA
5500AAAA55AA555555AAFF0055000055FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFFFAA5555555555AA00AAAA5500FFFFAA5555AA
AA00AA00AAAA5555555555555555555555555555555555AAAA00AA00AAAA5555AAFFFF00
55AAAA00AA5555555555AAFFFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA55555555555555AAAA00AA00FFFF00555555
AA55AA55AA55555555555555555555555555555555555555AA55AA55AA55555500FFFF00
AA00AAAA55555555555555AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5500555555555555AA55AA55AAFF55550055
55AA00AA555555555555555555555555555555555555555555AA00AA5555005555FFAA55
AA55AA5555555555550055AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55000000AA550055AA00AA555555AAFFAAAA55
00AAAA5555555555555555555555555555555555555555555555AAAA0055AAAAFFAA5555
55AA00AA550055AA00000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF55000000AAAA55555500AAAAAA00AA
55AA55555555555555555555555555555555555555555555555555AA55AA00AAAAAA0055
5555AAAA00000055FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAAAA55AAAA00AA0055AAAA00AAAA55
5555AA0055555555555555555555555555555555555555555500AA555555AAAA00AAAA55
00AA00AAAA55AAAAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA555555AA55AA55AA00AAAA5555AA
0000AAAA55005500AA0055550055555500555500AA00550055AAAA0000AA5555AAAA00AA
55AA55AA555555AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500005500FF0055AA55AA55555555
AAAA5555AA00FF00AAAA55000000AA00000055AAAA00FF00AA5555AAAA55555555AA55AA
5500FF0055000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFFFAA55AA00AA5555550055
AA55555555AAAAAA5555AA00FFAA00AAFF00AA5555AAAAAA55555555AA5500555555AA00
AA55AAFFFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA555555AAAA0000FF00AA
555555555555AA55550055FF55AA55AA55FF55005555AA555555555555AA00FF0000AAAA
555555AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA55005555AA55AAAAAA55
55555555555555AA000000FFFF550055FFFF000000AA5555555555555555AAAAAA55AA55
550055AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55000000AA555555AA5555
5555555555555555AAAA55AAFF55FF55FFAA55AAAA55555555555555555555AA555555AA
00000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF550000AA555555
0055AA005500AA5500FF55FF00FF00FF00FF55FF0055AA005500AA5500555555AA000055
FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAAAA55AA550000
FFAAAA00FF00AAAAFF00FF00FFAA55AAFF00FF00FFAAAA00FF00AAAAFF000055AA55AAAA
FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA555555AA00FF
AA5555AAAAAA5555AAFF00FFAA555555AAFF00FFAA5555AAAAAA5555AAFF00AA555555AA
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500005500FFAA
55555555AA55555500FFFFAA5555555555AAFFFF00555555AA55555555AAFF0055000055
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFFFAA55
5555555555AA005555FFAA55555555555555AAFF555500AA555555555555AAFFFF5555FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA5555
555555555555AAAAFFAA555555555555555555AAFFAAAA5555555555555555AAFF55FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5500
55555555555555AA55FF000055555555550000FF55AA555555555555550055AA55FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000
00AA550000555500FF00FFAA0055555500AAFF00FF005555000055AA00000055FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555
FF5500000000AA55AAFF00FF5555555555FF00FFAA55AA0000000055FF5555FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
FFAAAA55AAAA555555AAFFFF0000AA0000FFFFAA555555AAAA55AAAAFF55FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
55AA555555AA55005500FFFFFFAA00AAFFFFFF00550055AA555555AA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5500005500FF00AA55AAFF55AA55AA55FFAA55AA00FF0055000055FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF5555FFFFAA55AA5500FFFF550055FFFF0055AA55AAFFFF5555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55FFAA555555AA00FFFF000000FFFF00AA555555AAFF55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF55AA55005555AAAAAAAA55AAAAAAAA55550055AA55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55000000AA5555AA555555AA5555AA00000055FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF5555FF5500AA5555555555AA0055FF5555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55FFAAAA55555555555555AAAAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55AA555555555555555555AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF550000AA005500AA000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5555FF00AA00FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55FFAA00AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AA55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.383947 0.782187 0.471257 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00000000AAFF0000FF55FF00AA5555FFFF550055FF55FFFFFFFFAAAA55FF5555FFAAAA
AAFFAAAAFFFFFF55FFAAFFFFFFFFFFFFFFFFFFAAFF55FFFFFFAAAAFFAAAAAAFF5555FF55
AAAAFFFFFFFF55FF550055FFFF5555AA00FF55FF0000FFAA00000000FF
FFFFAAFFFFAA55550055FFFFFFAA5500AAFF0000AA555555AA5555AAFF55FF55FFFFFF00
FFFFFF00FF5555AA00FFFFFFFFFFFFFFFFFFFFFF00AA5555FF00FFFFFF00FFFFFF55FF55
FFAA5555AA555555AA0000FFAA0055AAFFFFFF55005555AAFFFFAAFFFF
FFFFFF00AAFF55FFFFAAAA5555AAFFAAFF5555000000FF000000FF00FF55FF55FF00AAFF
FFFFFFFFAA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AAFFFFFFFFFFAA00FF55FF55
FF00FF000000FF0000005555FFAAFFAA5555AAAAFFFF55FFAA00FFFFFF
FFFFFFFFAA55AA00FFAA55FFFF55AA55FF55FFFFAAFFFFFFAAFFFFFFAA0055FFFFFFAA55
55FF0055FFAAFFAA5555AAAA55AA55AA55AAAA5555AAFFAAFF5500FF5555AAFFFFFF5500
AAFFFFFFAAFFFFFFAAFFFF55FF55AA55FFFF55AAFF00AA55AAFFFFFFFF
FFFFFFFFFF000000AAAAAAFF00AA55FFFFFF5555FFAA00FF55AAAA55AAFFFF5555AA55FF
FF550000FFAA55AAFFAAAAAAAAFF55FFAAAAAAAAFFAA55AAFF000055FFFF55AA5555FFFF
AA55AAAA55FF00AAFF5555FFFFFF55AA00FFAAAAAA000000FFFFFFFFFF
FFFFFFFFFFFFAAFFFF00FFFFFFAA5500FF55555555FFAAFF00000000FFFFFFFF55FFAAAA
55AA000055FFAAAAAA55FFAA55FF55FF55AAFF55AAAAAAFF550000AA55AAAAFF55FFFFFF
FF00000000FFAAFF55555555FF0055AAFFFFFF00FFFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFF00AAFFFFFFFFFF000055FFFF55FFFFFF005555005555AA55AA5500FFFF
000000555555AAFF55AA00FFFF555555FFFF00AA55FFAA555555000000FFFF0055AA55AA
555500555500FFFFFF55FFFF550000FFFFFFFFFFAA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55AAAA00FFAAFFFF5555FFFFFFFFFFAAAAFFFF55FFAAAAAAFFFFFF
FFAAFFFF55FFFF0055AAFFFFFFFF55FFFFFFFFAA5500FFFF55FFFFAAFFFFFFFFAAAAAAFF
55FFFFAAAAFFFFFFFFFF5555FFFFAAFF00AAAA55AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000AAFF5555FFFF5555AA5555AAFF5555AA00FFFF00FFAA00
AAFF5555FFFFFFFFAAAAAA5555FF55FF5555AAAAAAFFFFFFFF5555FFAA00AAFF00FFFF00
AA5555FFAA5555AA5555FFFF5555FFAA00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFFAA55555555FF55FFFF0000FFFFFF55FFAAFF00AA00FFFF
AA55555555FF5555FFAA55FFFF555555FFFF55AAFF5555FF55555555AAFFFF00AA00FFAA
FF55FFFFFF0000FFFF55FF55555555AAFFFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AAFF55FFFF55FF55FF55550055FF555555FFAA000000AAAA
55FFFF55FFFFFF55FF55AA00AAAAFFAAAA00AA55FF55FFFFFF55FFFF55AAAA000000AAFF
555555FF55005555FF55FF55FFFF55FFAA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55AA00FFAAAA5500FF0000AA5555555555FFAAFFFFAA55
FFFFFFFF5500FF55FF55FFAAFF55AA55FFAAFF55FF55FF0055FFFFFFFF55AAFFFFAAFF55
55555555AA0000FF0055AAAAFF00AA55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000AAAAAAAAFFFFFFAAFF55FFFF55FFFFFF0055FFAA
AA5555AAAAFFFFFF555555AAFF000000FFAA555555FFFFFFAAAA5555AAAAFF5500FFFFFF
55FFFF55FFAAFFFFFFAAAAAAAA000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFF00AAAA55FF55FF555555FF550055AA55
FFAAAAFF55AAAA00FF0000FFFFFFAAFFFFFF0000FF00AAAA55FFAAAAFF55AA550055FF55
5555FF55FF55AAAA00FFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFFFFFFAA55FFFFFF5555555555FFFFAAAAAA
FF00FFFFFF55AAFFFFFFAAFF00AAAAAA00FFAAFFFFFFAA55FFFFFF00FFAAAAAAFFFF5555
555555FFFFFF55AAFFFFFFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAA00FFFF5555FF55FFFF55FFFFFFFF00FF
FFFFAA00FFAAAAAA00AAFF55000000000055FFAA00AAAAAAFF00AAFFFFFF00FFFFFFFF55
FFFF55FF5555FFFF00AAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000AAFF0000FF55FF00AA5555FF005555
AA55AAFFFFFF00FFFFAA55AA0000550000AA55AAFFFF00FFFFFFAA55AA555500FF5555AA
00FF55FF0000FFAA00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAA55550055FFFFFFAA5500AAFFFF55
FFAAAAAA00AAFFFFFFFF000000555555000000FFFFFFFFAA00AAAAAAFF55FFFFAA0055AA
FFFFFF55005555AAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF55FFFFAAAA5555AAFFAAFF5555FF
FFFF00FFFFAA5555FF5500005555555555000055FF5555AAFFFF00FFFFFF5555FFAAFFAA
5555AAAAFFFF55FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA00FFAA55FFFF55AA55FF55FFFF
FFFFFFAA00FFFF55FF0000555555555555550000FF55FFFF00AAFFFFFFFFFF55FF55AA55
FFFF55AAFF00AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000AAAAAAFF00AA55FFFFFF5555
FF5555AAFFFFFFFF55005555555555555555550055FFFFFFFFAA5555FF5555FFFFFF55AA
00FFAAAAAA000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFFFAA5500FF555555
55FFFF55AAAA55AAAAFFFF55FFFF55FFFF55FFFFAAAA55AAAA55FFFF55555555FF0055AA
FFFFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFFFFFFFF000055FFFF55
FFFFFFFF55AAFFAA55FF0055AA555555AA5500FF55AAFFAA55FFFFFFFF55FFFF550000FF
FFFFFFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAA00FFAAFFFF5555FF
FFFFFFFFFF55AA55FFFFFFAAAAAAFFAAAAAAFFFFFF55AA55FFFFFFFFFFFF5555FFFFAAFF
00AAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000AAFF5555FFFF55
55AA5555FF55FFAAAA5555FFAA55FF55AAFF5555AAAAFF55FF5555AA5555FFFF5555FFAA
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAA55555555FF55
FFFF0000FF55FF55AAFFAAAA55FFFFFF55AAAAFFAA55FF55FF0000FFFF55FF55555555AA
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF55FFFF55FF55
FF55550055FFFFFF55AA55FFAAAA55AAAAFF55AA55FFFFFF55005555FF55FF55FFFF55FF
AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA00FFAAAA55
00FF0000AA5555FF000000FF55AAFFAA55FF000000FF5555AA0000FF0055AAAAFF00AA55
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000AAAAAAAA
FFFFFFAAFF55FFFFFFAAFFFFFF55AA55FFFFFFAAFFFFFF55FFAAFFFFFFAAAAAAAA000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFF
00AAAA55FF55FF5555FFAA00FFAAAAAAFF00AAFF5555FF55FF55AAAA00FFFF00FFFFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFFFF
FFAA55FFFFFF55555555AAFFFFFF00FFFFFFAA55555555FFFFFF55AAFFFFFFFFAA00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAA
00FFFF5555FF55FFFF55FFAA00FFAAFF00AAFF55FFFF55FF5555FFFF00AAAA55AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00AAFF0000FF55FF555555FFAAFF00FFAAFF555555FF55FF0000FFAA00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
FFAA55550055FFFFFF55FFFFFF00AA00FFFFFF55FFFFFF55005555AAFFFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
AAFF55FFFFAAAA55AA5500FF5500000055FF0055AA55AAAAFFFF55FFAA00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55AA00FFAA55FFFF000055FFFFAAFFFF550000FFFF55AAFF00AA55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000AAAAAAFF00555500AAFF00FFAA00555500FFAAAAAA000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFF00FFFFFFAAAAFFFF00AA00FFFFAAAAFFFFFF00FFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00AAFFFFFFFFFF00FF5500000055FF00FFFFFFFFFFAA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA55AAAA00FFAAFF0000550000FFAAFF00AAAA55AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000AAFF55005555550055FFAA00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFFFAA55AA0000FF0000AA55AAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00AAFF55FFAAFFFFFFAAFF55FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55AA00FFFFFFFFFF00AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000AAAA55AAAA000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFF00FF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AAFFFFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.383947 0.97619 0.471257 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0055AAFFAAFFFF00FF5555AAFF00AAFFAAFFFF5555AA550055FFAAAA5555FFFFFFFFAA
FFFFFFAAAAAAFFAA00FFFFFF00FF00FF00FFFFFF00AAFFAAAAAAFFFFFFAAFFFFFFFF5555
AAAAFF550055AA5555FFFFAAFFAA00FFAA5555FF00FFFFAAFFAA5500FF
FFFFAAAA00FF555500AAFFAAAA0000FFFFFF00AAFFAAAAAAFFFF5555AAFFAAAA55AAAA55
55005555AA5555FF0000AA00005555550000AA0000FF5555AA5555005555AAAA55AAAAFF
AA5555FFFFAAAAAAFFAA00FFFFFF0000AAAAFFAA005555FF00AAAAFFFF
FFFFFF0055AAAAFFAAFF5555AA550000AA0000FF5555AAFF5555FFFF550055FFAAAAAAAA
FFAAFFAAAAAAFFAA005500FF0000000000FF005500AAFFAAAAAAFFAAFFAAAAAAAAFF5500
55FFFF5555FFAA5555FF0000AA000055AA5555FFAAFFAAAA5500FFFFFF
FFFFFFFFAAAA00AA00AAFFAAAAAAFFFFAA5500AAFFAAAA00000000AAFFAAFFAA00AAAAAA
00FFFFFF00FFFFFF00000055555555555555000000FFFFFF00FFFFFF00AAAAAA00AAFFAA
FFAA00000000AAAAFFAA0055AAFFFFAAAAAAFFAA00AA00AAAAFFFFFFFF
FFFFFFFFFF0055AAFFFF00AAAAAAAA55AAFFAAFF5555AA55000055AA55AAFF00FF00FF55
0000AAFF0000AA0000FF000000000000000000FF0000AA0000FFAA000055FF00FF00FFAA
55AA55000055AA5555FFAAFFAA55AAAAAAAA00FFFFAA5500FFFFFFFFFF
FFFFFFFFFFFFAAAA00FFAAFF5500FF55FFAA00AAFFAAAAAAFFFFAAAAAAFF55555500AAFF
AAFFFF00AA5500FF0000AA550000FF000055AA0000FF0055AA00FFFFAAFFAA00555555FF
AAAAAAFFFFAAAAAAFFAA00AAFF55FF0055FFAAFF00AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFF0055AAAA000000FFAAAA555555AAAAAAAA0000AAAAAA0000000000FFFF
FF00AA0055FFFFAA0055AAFFAAFFFFFFAAFFAA5500AAFFFF5500AA00FFFFFF0000000000
AAAAAA0000AAAAAAAA555555AAAAFF000000AAAA5500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA00AA550000AAAAAAFFAAAAAAAA00AA5500FFFF0000550000FFAA
0000FFFFAAAA55AAFFFF55AAAAAA55AAAAAA55FFFFAA55AAAAFFFF0000AAFF0000550000
FFFF0055AA00AAAAAAAAFFAAAAAA000055AA00AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0055AAFFAAFFFF00FF5555AAFF5500AAAAFFFFFFFFAAFFAAFFFFFF
0000FFAA00AAAAFF5555FFFF00FF55FF00FFFF5555FFAAAA00AAFF0000FFFFFFAAFFAAFF
FFFFFFAAAA0055FFAA5555FF00FFFFAAFFAA5500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA00FF555500AAFFAAAA000000FF55AAAA55AAAA00FFFFFFFF
FFAAFF0055AA5555FFFF555500AAFFAA005555FFFF5555AA5500FFAAFFFFFFFFFF00AAAA
55AAAA55FF000000AAAAFFAA005555FF00AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0055AAAAFFAAFF5555AA550000FFAAAAAAAAFF5500AAFF00AA
00FFFFFFAAAAAAFFAA00000000FFFFFF00000000AAFFAAAAAAFFFFFF00AA00FFAA0055FF
AAAAAAAAFF000055AA5555FFAAFFAAAA5500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA00AAFFAAAAAAFFFFAA00AAAA00AAFFAAFF555555
AA0000AA00AAAAAA55555555555500555555555555AAAAAA00AA0000AA555555FFAAFFAA
00AAAA00AAFFFFAAAAAAFFAA00AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0055AAFFFF00AAAAAAAA55AAFFFF00FF005555AAAAFFAA
AA005500FF0055FFAAAAFFAAAAFFAAFFAAAAFFAAAAFF5500FF005500AAAAFFAAAA555500
FF00FFFFAA55AAAAAAAA00FFFFAA5500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FFAAFF5500FF55FFAA0000FFAAFFAAAAAA00FF
FF000000FFAAFFAA00AAAA5555AAAAAA5555AAAA00AAFFAAFF000000FFFF00AAAAAAFFAA
FF0000AAFF55FF0055FFAAFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AAAA000000FFAAAA55555555FFAA00AAAA0055
55000055AAAAAA555555AAFFAAAAAAAAAAFFAA555555AAAAAA550000555500AAAA00AAFF
55555555AAAAFF000000AAAA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA550000AAAAAAFFAAAAFF005500FFFFAA
AAFFFFAAAAAAAAAAFFAAAAAA5555AA5555AAAAAAFFAAAAAAAAAAFFFFAAAAFFFF005500FF
AAAAFFAAAAAA000055AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AAFFAAFFFF00FF5555AAFF0000005555FF
AA55AAAAAAAAAAAA00FF55AAFFAAAAAAFFAA55FF00AAAAAAAAAAAA55AAFF5555000000FF
AA5555FF00FFFFAAFFAA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FF555500AAFFAAAA00005500000000
AAAAFF5500FFFF0055AAAAFF5555AA5555FFAAAA5500FFFF0055FFAAAA00000000550000
AAAAFFAA005555FF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AAAAFFAAFF5555AA55000000550000
FF55AAAAFFFFFFFFAAAA00AAFFAAAAAAFFAA00AAAAFFFFFFFFAAAA55FF00005500000055
AA5555FFAAFFAAAA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA00AAFFAAAAAAFFFFAAFFAAFF
FFFF5500FFAA00FFAA555555AAAAAAAAAA555555AAFF00AAFF0055FFFFFFAAFFAAFFFFAA
AAAAFFAA00AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AAFFFF00AAAAAAAA55AA55AAFF
00AAFFAAFF00FF00AAAAFFAAAAAAAAAAAAAAFFAAAA00FF00FFAAFFAA00FFAA55AA55AAAA
AAAA00FFFFAA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FFAAFF5500FF55FFAAAA00
FF00FFAA55AA0000FFFF00AAAAAA00AAAAAA00FFFF0000AA55AAFF00FF00AAAAFF55FF00
55FFAAFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AAAA000000FFAAAA55FF00
00AA55AAFFAA5500AA0000FFFF005500FFFF0000AA0055AAFFAA55AA0000FF55AAAAFF00
0000AAAA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA550000AAAAAAFF00
0055FFFF00AAAAFFFF0000555500000055550000FFFFAAAA00FFFF550000FFAAAAAA0000
55AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AAFFAAFFFF00FFFFFF
AAFFAA0000FF55AAAA5500000000FF0000000055AAAA55FF0000AAFFAAFFFFFF00FFFFAA
FFAA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FF55550000AA00
FFFFFF0000FFAAAAAAAAFFFFAAFFFFFFAAFFFFAAAAAAAAFF0000FFFFFF00AA00005555FF
00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AAAAFFAAFFFF00
00AA0000FF00AAAAAA00AA00FFFFFFFFFF00AA00AAAAAA00FF0000AA0000FFFFAAFFAAAA
5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA00AA0000
FF0055AA0000FFFF0055AAFFFFFFFFFFFFFFAA5500FFFF0000AA5500FF0000AA00AA00AA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AAFFFF0000
FFAAFFAA550000AAFFFF55005555FF55550055FFFFAA000055AAFFAAFF0000FFFFAA5500
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FFAAFF
FFFF00AAAAFFFFAA55AAAAFFFF55FF55FFFFAAAA55AAFFFFAAAA00FFFFFFAAFF00AAAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AAAA00
FFAA0055FF00AAFF55FF005555FFFFFF555500FF55FFAA00FF5500AAFF00AAAA5500FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA
55AAFFFF555555AAAAFF00000000AA00000000FFAAAA555555FFFFAA55AA00AAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AA
FFAA55AAAAFFAAAAAA00FF0000FF00FF0000FF00AAAAAAFFAAAA55AAFFAA5500FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
00FF55FF00FFAA55FFAAFF00005555550000FFAAFF55AAFF00FF55FF00AAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
55AAAAFF0000AAAAFF00FFAAFFFF55FFFFAAFF00FFAAAA0000FFAAAA5500FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAA00AA0055AAFF555555FFAA000000AAFF555555FFAA5500AA00AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0055AAFFFF55AAAAFFAAAA5555555555AAAAFFAAAA55FFFFAA5500FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAA00FFAAAAAAAA55FFAAAAFFAAAAFF55AAAAAAAAFF00AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0055AAAA00AAAAAAFF00FFFFFF00FFAAAAAA00AAAA5500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAA00AA5555AAFF0000AA0000FFAA5555AA00AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0055AAFFAAAA0000FF00FF0000AAAAFFAA5500FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAA00FF550000FFAAFF000055FF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0055AAAAFFFFAA00AAFFFFAAAA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA00AAFF005500FFAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0055AAFF000000FFAA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA0000550000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.479988 0.200176 0.567299 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FF0055FFAAAA00FFAAAAAA00AAFF0000000055FF555555AAAA55AA55AA55FFAAAA
55FF0000FFFF0000555555FF0000550000FF5555550000FFFF0000FF55AAAAFF55AA55AA
55AAAA555555FF5500000000FFAA00AAAAAAFF00AAAAFF5500FF0000FF
FFFF00FFAA5555FFFF55AAAAFFAAAAAAFF00FFFF00FF5555AA55555555AA0000FF555555
55AAAAAAAA55AAFF550000AAFF55AA55FFAA000055FFAA55AAAAAAAA55555555FF0000AA
55555555AA5555FF00FFFF00FFAAAAAAFFAAAA55FFFF5555AAFF00FFFF
FFFFFF00AA5555AAAA55555555FFFF55FF55AAAA55FF5500000055550000FFFF00AA0000
555555555555AA00FF55AAFFAA000000AAFFAA55FF00AA5555555555550000AA00FFFF00
00555500000055FF55AAAA55FF55FFFF55555555AAAA5555AA00FFFFFF
FFFFFFFF000055555555005555AAAA5555FF0000FF5555AAFFFF0055FFAA55AAAAAAFFFF
005500550055FFFFAA0000FFAAAAAAAAAAFF0000AAFFFF550055005500FFFFAAAAAA55AA
FF5500FFFFAA5555FF0000FF5555AAAA555500555555550000FFFFFFFF
FFFFFFFFFF00FF5500FF55AA5555555500FFAAFF55550055AAAA55FF00AA5555555555FF
55AA55FF00FF5555FFFFAAFF0000000000FFAAFFFF5555FF00FF55AA55FF5555555555AA
00FF55AAAA55005555FFAAFF0055555555AA55FF0055FF00FFFFFFFFFF
FFFFFFFFFFFF00AAAAAA555555005500FFFFFF5555AA55FF000000AAFFFF55000055FF00
AA005555FFAA00AAAA55AA00FFFFAAFFFF00AA55AAAA00AAFF555500AA00FF55000055FF
FFAA000000FF55AA5555FFFFFF005500555555AAAAAA00FFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF0055FF00FF55AAAA55AA555555AAAAAAAAAAFF00AAAAAAAA00FF
FF55AA5555FFFF0000FF55FFAA00FF00AAFF55FF0000FFFF5555AA55FFFF00AAAAAAAA00
FFAAAAAAAAAA555555AA55AAAA55FF00FF5500FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFAA5555FFAA00000000AA5555000000FF0000FFAAFFAAAAFFAAFF
00AA0055FF00AAFFFFAA00AAFFAA55AAFFAA00AAFFFFAA00FF5500AA00FFAAFFAAAAFFAA
FF0000FF0000005555AA00000000AAFF5555AAFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00AA5555AAAAFFFFAAFFFF5500FFFFAA55AAFF555555FFFF555555
FFAAAAAA00FFFF5555FFFFAAAA550055AAAAFFFF5555FFFF00AAAAAAFF555555FFFF5555
55FFAA55AAFFFF0055FFFFAAFFFFAAAA5555AA00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000055555555FF55FF5555AAFF00AA555555FF005555FF550055
FF55FFFF55AAAA5555AAAA5500AAAAAA0055AAAA5555AAAA55FFFF55FF550055FF555500
FF555555AA00FFAA5555FF55FF555555550000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF5500FF5555AAAA0000FFAA55000055FF55AA5555FF00FF
5555AAAA55555555AA5500AAAAAAFFAAAAAA0055AA55555555AAAA5555FF00FF5555AA55
FF55000055AAFF0000AAAA5555FF0055FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AAAAAA555500AA55FFAA0055FFAA5555FF0000AAAA55FF
55000000005555AA5500FFFF55FFFFFF55FFFF0055AA55550000000055FF55AAAA0000FF
5555AAFF5500AAFF55AA005555AAAAAA00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0055FFAAAA00FF00FF55555500FFAAFFFF55FF00
AAAAAAAAAAAA0000FF55AAAA5555FF5555AAAA55FF0000AAAAAAAAAAAA00FF55FFFFAAFF
00555555FF00FF00AAAAFF5500FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA5555FFFF55AAAAAA5555AA55FF55FF5555AAAA
AAFFAAAAFFAAAAAAAA55555555AA55AA55555555AAAAAAAAFFAAAAFFAAAAAA5555FF55FF
55AA5555AAAAAA55FFFF5555AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA5555AAAA55555555550000FF5555AAAA000000
00FFAAAAFF0000000000AA000055AA550000AA0000000000FFAAAAFF00000000AAAA5555
FF00005555555555AAAA5555AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055555555005555AA55FFAA00AAAAFFAAFFFF
AAFF0000FFAAFFFFAAFF55FFAA555555AAFF55FFAAFFFFAAFF0000FFAAFFFFAAFFAAAA00
AAFF55AA555500555555550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF5500FF55AA555555AAAAFF55FFFFFF5555
FFFFFF00FFAAAA55AA00FF555555AA555555FF00AA55AAAAFF00FFFFFF5555FFFFFF55FF
AAAA555555AA55FF0055FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAA555555005500AA55AA55AAAA5555
AAAA55AAFF0000FF55FFAA00AA000000AA00AAFF55FF0000FFAA55AAAA5555AAAA55AA55
AA005500555555AAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0055FF00FF55AA00AA5555555500
00000055AAAAAAAA5555FFFFAAAAAAAAAAFFFF5555AAAAAAAA550000000055555555AA00
AA55FF00FF5500FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA5555FFAA0000FFFF55005500FF
FFAA55FF000000FF0055FF55555555555555FF5500FF000000FF55AAFFFF00550055FFFF
0000AAFF5555AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA5555AAAAFFFFAA00FF55AA55FF
555555AAAAAAAAAA55FF00AAAA00AA00AAAA00FF55AAAAAAAAAA555555FF55AA55FF00AA
FFFFAAAA5555AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055555555FF55FFAA0000FF55
55AA55555555555555AAAAAAFFAAFFAAFFAAAAAA55555555555555AA5555FF0000AAFF55
FF555555550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF5500FF5555AAAAFFFFAA00
AA005500550055005555555555FFFFFF555555555500550055005500AA00AAFFFFAAAA55
55FF0055FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAA555500AA55AAAAFF
FF55AA55FF00FF55AA5555AA5555FF5555AA5555AA55FF00FF55AA55FFFFAAAA55AA0055
55AAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0055FFAAAA0055AA
AA555555AAAAAA555555AA550055FF550055AA555555AAAAAA555555AAAA5500AAAAFF55
00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA5555FFFF55AA55
00AAAA0000000000AA0000FF55AA55AA55FF0000AA0000000000AAAA0055AA55FFFF5555
AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA5555AAAA555555
AAFFAAAAAAAAAAAAAAFFFF00AA005500AA00FFFFAAAAAAAAAAAAAAFFAA555555AAAA5555
AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000555555550055
00AAFFAAAAFFAAAAFFAA00FFFF55AA55FFFF00AAFFAAAAFFAAAAFFAA0055005555555500
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF5500FF55AA
55FFFFFF55FF55FFFFFF55AAAA555555AAAA55FFFFFF55FF55FFFFFF55AA55FF0055FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAA5555
55AAAA55AA55AA55AAAA55555555AA55555555AAAA55AA55AA55AAAA555555AAAAAA00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0055
FF000000AA555555AA005555AA555555AA555500AA555555AA000000FF5500FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA55
55FFAAFFFF550055FFFF00555555AA55555500FFFF550055FFFFAAFF5555AAFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55
55AAAAFF00AAAAAA00FFAA55550000005555AAFF00AAAAAA00FFAAAA5555AA00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
55555555FFAAAAFFAAFF0000AAAAAAAAAA0000FFAAFFAAAAFF555555550000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF5500FF55555555FFFFFF00FF000000FF00FFFFFF55555555FF0055FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00AAAAAA555500FF5555FF55AAAAAAAAAA55FF5555FF005555AAAAAA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF0055FFAA00AAAA55555555555555AAAA00AAFF5500FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFAA5555FFFF000000AAAA00AAAA000000FFFF5555AAFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00AA5555AAAA55FFAAFFAAAAAAFFAAFF55AAAA5555AA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000055555555AAAAFF000000FFAAAA555555550000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF5500FF55FFFFFFAAFFFFFF55FF0055FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00AAAAAA5555FF555555FF5555AAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF0055FF550055FF5500FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFAA5555FF00FF5555AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00AA5555AAAAAA5555AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000055555555550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF550055FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.479988 0.39418 0.567299 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000055AA555555FF0000AAFFAA00AAAA00AA55FFFFFF55AA000000AAFFFFAAAAAAAAAA
AAAA00AAAA55FFAA00000000AAAA00AAAA00000000AAFF55AAAA00AAAAAAAAAAAAAAFFFF
AA000000AA55FFFFFF55AA00AAAA00AAFFAA0000FF555555AA550000FF
FFFF00FF00AA5500AAAAAAAA55550000AAFF555555AA55555500000000AAAA0000AA00FF
AAAAFFFF555555AAAAAAAAAAAAFFAAFFAAAAAAAAAAAA555555FFFFAAAAFF00AA0000AAAA
00000000555555AA555555FFAA00005555AAAAAAAA0055AA00FF00FFFF
FFFFFF00550055AAFFAAAAFF0000FFFFAAAA0055AA0000FF000000000000AAFF55AAAAAA
0000AAAA0055AA00FFAAAAFFAA00AA00AAFFAAAAFF00AA5500AAAA0000AAAAAA55FFAA00
0000000000FF0000AA5500AAAAFFFF0000FFAAAAFFAA55005500FFFFFF
FFFFFFFF000055AAAA0000AAAAAAAA00AA000000FFAAFF550000000000005555AA0000AA
FFFFAA000055AAAAAA0000AAAAFF55FFAAAA0000AAAAAA550000AAFFFFAA0000AA555500
000000000055FFAAFF000000AA00AAAAAAAA0000AAAA550000FFFFFFFF
FFFFFFFFFF00FF00AAFFFFAAAAFFAAAAAAFFFFAA5555FF0000000000000055AA00000000
AAAA00000000FFAAAAFF55AAAA555555AAAA55FFAAAAFF00000000AAAA00000000AA5500
000000000000FF5555AAFFFFAAAAAAFFAAAAFFFFAA00FF00FFFFFFFFFF
FFFFFFFFFFFF00550055FF00AA00AA0000AAAA0000FF005500000000000055AAAAAAAAAA
AA55AAFFFFAA5555FF5500AA0000FF0000AA0055FF5555AAFFFFAA55AAAAAAAAAAAA5500
00000000005500FF0000AAAA0000AA00AA00FF55005500FFFFFFFFFFFF
FFFFFFFFFFFFFF000055AA55FFFFAAAAAAAAFF00FFFFFF0000000000000000FFAA0000AA
FF0000AAAA0000FF0055AAFF00FFFFFF00FFAA5500FF0000AAAA0000FFAA0000AAFF0000
000000000000FFFFFF00FFAAAAAAAAFFFF55AA550000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00AA5555AAAAFF00AAAAAA00AAAAAAAAAAAAAAAAAAAA00FFFF00
AAAAAAAAFF00FFFFFF0000AAAAAA00AAAAAA0000FFFFFF00FFAAAAAAAA00FFFF00AAAAAA
AAAAAAAAAAAAAA00AAAAAA00FFAAAA5555AA00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00550055AA0000AAAAAAFFAAAAAAFFAA0000AA00FFAAAAFFFFFFFF
00AA0000AAAAAA00AAAAAAAAFFAAAAAAFFAAAAAAAA00AAAAAA0000AA00FFFFFFFFAAAAFF
00AA0000AAFFAAAAAAFFAAAAAA0000AA55005500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000055AAAAAAAAFFAA00AAFFAA00AAFF55AAAAAA0000AAAA00AA
AAAAFFFFAAAAFF00FFAA0000AAAAFFAAAA0000AAFF00FFAAAAFFFFAAAAAA00AAAA0000AA
AAAA55FFAA00AAFFAA00AAFFAAAAAAAA550000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00AAFFAAAA000000AAAAFF55FF0000AAFF00FFFF55FFAA
0000AAAA0000AAAAAA00000000AA00AA00000000AAAAAA0000AAAA0000AAFF55FFFF00FF
AA0000FF55FFAAAA000000AAAAFFAA00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00550055FFFF55AAFF555500FF00550000AAAAAA00AA5555
000000AAFF55AAAAFF00FFFFAAFFAAFFAAFFFF00FFAAAA55FFAA0000005555AA00AAAAAA
00005500FF005555FFAA55FFFF55005500FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000055AA555555FF0000FFFFFF00000000AA000000AA55
0000005555AA0000AAAAAA00AA00AA00AA00AAAAAA0000AA555500000055AA000000AA00
000000FFFFFF0000FF555555AA550000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00AA5500AAAAAAAA00AAAAAAAAAAAAFFFFAAFF00
00000055AA00FFFF00AAFF00FFAA55AAFF00FFAA00FFFF00AA5500000000FFAAFFFFAAAA
AAAAAAAA00AAAAAAAA0055AA00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00550055AAFFAAAAFF00FFAAAAFFAA00FF550055FF
AAFF55AA00FFFFFFFF00AAAAAA00FF00AAAAAA00FFFFFFFF00AA55FFAAFF550055FF00AA
FFAAAAFF00FFAAAAFFAA55005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055AAAA0000AAAAAA0000AAAA55FF000000FF
5555AA00FFFFFFFFFFFF00AA00FFFFFF00AA00FFFFFFFFFFFF00AA5555FF000000FF55AA
AA0000AAAAAA0000AAAA550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00AAFFFFAAAAFFAAFF555500AAAAAAAAAA
0055AAAAAA00AAAA00AAAAAAFFFFFFFFFFAAAAAA00AAAA00AAAAAA5500AAAAAAAAAA0055
55FFAAFFAAAAFFFFAA00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00550055FF00AA00AA00AA550000AAFFAA00
0055AAAAFFAAFFAAAAAAFF00AAAA00AAAA00FFAAAAAAFFAAFFAAAA550000AAFFAA000055
AA00AA00AA00FF55005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055AA55FFFFAAAAAA55000000AAAAFF
FF0000AA00AA00AA0000AAAAAAFFAAFFAAAAAA0000AA00AA00AA0000FFFFAAAA00000055
AAAAAAFFFF55AA550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00AA5555AAAAFF0000000000AA00
AAAAAAAAFFFF55AAAAAAAAFFAA00AA00AAFFAAAAAAAA55FFFFAAAAAAAA00AA0000000000
FFAAAA5555AA00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00550055AA0000AAAAAAAAAAAAAAFF
FF55550055FF0000AA0000AAAAFF55FFAAAA0000AA0000FF55005555FFFFAAAAAAAAAAAA
AA0000AA55005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055AAAAAAAAFFAAAAFFAAAA55
55AA005500AAAAAAAAFFFFAAAA555555AAAAFFFFAAAAAAAA005500AA5555AAAAFFAAAAFF
AAAAAAAA550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00AAFFAAAA0000AAAAFF00
00FFAA550000AAFFAAAA00AA0000FF0000AA00AAAAFFAA000055AAFF0000FFAAAA0000AA
AAFFAA00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00550055FFFF55AAFF00AAAA
AAAA0000FFFF00AAAA55AAFF00FFFFFF00FFAA55AAAA00FFFF0000AAAAAAAA00FFAA55FF
FF55005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055AA555555FF00FFAA
AAFF00FFFFFFFFAA00FF00AAAAAA00AAAAAA00FF00AAFFFFFFFF00FFAAAAFF00FF555555
AA550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00AA5500AAAAAA00
00AAAAAA00AAAA00FFFFFFAA00FFAAFF00AAFFFFFF00AAAA00AAAAAA0000AAAAAA0055AA
00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00550055AAFFAAAAFF
FFAAAAFF00FFAAAAAA00AAAAFF550055FFAAAA00AAAAAAFF00FFAAAAFFFFAAAAFFAA5500
5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055AAAA0000AA
AA0000AAAAAA0000AAFFFF55FF000000FF55FFFFAA0000AAAAAA0000AAAA0000AAAA5500
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00AAFFFFAA
AAFFFF00AA00FFFF00AAAA0055FFAAFF5500AAAA00FFFF00AA00FFFFAAAAFFFFAA00FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00550055FF00
AA00AAAAAAFFFFFFFFAA000000FF55FF000000AAFFFFFFFFAAAAAA00AA00FF55005500FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055AA55
FFFFAA0000AAAA00AAAAFFFFAA555555AAFFFFAAAA00AAAA0000AAFFFF55AA550000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00AA
5555AAAAAAAA55AAFF00AAAA0000FF0000AAAA00FFAA55AAAAAAAA5555AA00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005500
55AA0000AA00FF00AAAAAAFF00FFFFFF00FFAAAAAA00FF00AA0000AA55005500FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
55AAAAAAAAFFFFFFAA0000AAAAAA00AAAAAA0000AAFFFFFFAAAAAAAA550000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00AAFFAA00AAAA00000000AAFF00FFAA00000000AAAA00AAFFAA00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00550055FFFFAA000000000000AAAAAA000000000000AAFFFF55005500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000055AA555500000000000000AA000000000000005555AA550000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00AA5500000000000055005500000000000055AA00FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00550055AAFFFFAAFFFF000000FFFFAAFFFFAA55005500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000055AAAA00AA00AAAAAAAAAA00AA00AAAA550000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00AAFFFF55AAAAFFAAAA55FFFFAA00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00550055FF0000AA00AA0000FF55005500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000055AA55FFAAAAAAFF55AA550000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00AA5555FF5555AA00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00550055AA00AA55005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000055AAAAAA550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF00AA00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.479988 0.588183 0.567299 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FF00AA0000000055FFFF55AAAA55AAAAFF00FFFFAAAAAA55AA00AA5500AAFFAA
55FF55AA55FF00AA00555500AA000000AA00555500AA00FF55AA55FF55AAFFAA0055AA00
AA55AAAAAAFFFF00FFAAAA55AAAA55FFFF5500000000AA00FF000000FF
FFFF00FFFFFFAAAAAAAAAAAA5555AAAAFFAA0000AAAAAA00AA0000FFAAAAAAFF00FF0055
AAAA00FF00AAAAAAFF5555FFAAAAAAAAAAFF5555FFAAAAAA00FF00AAAA5500FF00FFAAAA
AAFF0000AA00AAAAAA0000AAFFAAAA5555AAAAAAAAAAAAFFFFFF00FFFF
FFFFFF0055FF000055555500000000AA00AA55FFAAAAFFAAFFAAFF55000055AA55FF00FF
AAAAFFFFFF00005555AAAA55555555555555AAAA55550000FFFFFFAAAAFF00FF55AA5500
0055FFAAFFAAFFAAAAFF55AA00AA000000005555550000FF5500FFFFFF
FFFFFFFF00AAAAAAAA55AAAAAAAAAAAAFF55FF5500AA00AA555500FFAAFF555555FF00FF
55FFFFFFFFFFAAFF00AA000000000000000000AA00FFAAFFFFFFFFFF55FF00FF555555FF
AAFF005555AA00AA0055FF55FFAAAAAAAAAAAA55AAAAAAAA00FFFFFFFF
FFFFFFFFFF000055000000AA0000555555AAAA00FFFF55AA00FFAA555555AAAA55AA55FF
00AAAA00AAAA0055FFAAAAAAAAAAAAAAAAAAAAAAFF5500AAAA00AAAA00FF55AA55AAAA55
5555AAFF00AA55FFFF00AAAA5555550000AA000000550000FFFFFFFFFF
FFFFFFFFFFFF00FFAAFFFFAAAAAAAA55AAAAFFAA5555AAAAFF550000000000AA00FF00AA
AAAAFFAAFFAAAAAA55555555555555555555555555AAAAAAFFAAFFAAAAAA00FF00AA0000
00000055FFAAAA5555AAFFAAAA55AAAAAAAAFFFFAAFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF0055AA555555555555FFFF55000000005555AAAAAAAAAAAAAAFFFFFF00
00AA00AA555555000000000000000000000000000000555555AA00AA0000FFFFFFAAAAAA
AAAAAAAA55550000000055FFFF555555555555AA5500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00AA55AAAA55AAAA5555AAAAAAAAAAAA55AA000055550055AA5555AA
FF55FFAAAA55AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA55AAAAFF55FFAA5555AA550055
550000AA55AAAAAAAAAAAA5555AAAA55AAAA55AA00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF00AA000000005555550000FFAAAAAAAA55AAFF00000000
FF5555AA00000055550000FF0000AA0000FF00005555000000AA5555FF00000000FFAA55
AAAAAAAAFF000055555500000000AA00FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFAAAAAAAAAAAA55AAAAAAAA0000AA000000AAAAAAAAAA
AA00FFAAAAAAAAAA55AAFFFFFFAAFFAAFFFFFFAA55AAAAAAAAAAFF00AAAAAAAAAAAA0000
00AA0000AAAAAAAA55AAAAAAAAAAAAFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0055FF0000555555000000AA0000FFFFAAAAAAAAAAFFAAAAFF
AAAAAA00555555000000AAAA00AA00AA00AAAA00000055555500AAAAAAFFAAAAFFAAAAAA
AAAAFFFF0000AA0000005555550000FF5500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAA55AAAAAAAAAAFF55AA5555550000AA555500AA
AAFFAAAAAA55AAAAAAAAAAFFAAFFAAFFAAFFAAAAAAAAAA55AAAAAAFFAAAA005555AA0000
555555AA55FFAAAAAAAAAA55AAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000055000000AA00005555AAAAFF00AAFFFFAAAA55AAFF
AAAA0055000000555500AA555500FF005555AA0055550000005500AAAAFFAA55AAAAFFFF
AA00FFAAAA55550000AA000000550000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAFFFFAAAAAAAA55AA0055FFAAAA00AA00000055
FFFF55AAAAAAAAAA55AAFFAA00FFFFFF00AAFFAA55AAAAAAAAAA55FFFF55000000AA00AA
AAFF5500AA55AAAAAAAAFFFFAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AA555555555555FFFF00AAAAFFAAFFAAFFFF00
AAAA00FF0000AA000000AAAAFFFFFFFFFFAAAA000000AA0000FF00AAAA00FFFFAAFFAAFF
AAAA00FFFF555555555555AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AAAA55AAAA5555AAFFAAAA0055FFFFFFFF
AAAAFFFFFFAAFFAAFFFF0000AAAA00AAAA0000FFFFAAFFAAFFFFFFAAAAFFFFFFFF5500AA
AAFFAA5555AAAA55AAAA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00AA0000000055FFFF55AAAA00AAAA
0000AAAA00AA00AA00AAAAAAAAFFAAFFAAAAAAAA00AA00AA00AAAA0000AAAA00AAAA55FF
FF5500000000AA00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFAAAAAAAAAAAA5555AAAAFFAAFFAA
AAAAAAFFAAFFAAFFAA550000AA555555AA000055AAFFAAFFAAFFAAAAAAAAFFAAFFAAAA55
55AAAAAAAAAAAAFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF000055555500000000AA00AA00AA
0000AA00AA00AA00AA00FFFFAAAA55AAAAFFFF00AA00AA00AA00AA0000AA00AA00AA0000
00005555550000FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAA55AAAAAAAAAAAAFF55FFAA
AAAAAAFF55FFAAAAAAFFFFFFFF55FF55FFFFFFFFAAAAAAFF55FFAAAAAAAAFF55FFAAAAAA
AAAAAA55AAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055000000AA0000555555AAAA00
550055AA55AA550055AA5555AA55AA55AA5555AA550055AA55AA55005500AAAA55555500
00AA000000550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAFFFFAAAAAAAA55AAAAFFAA
55AAFF000000FFAAFF00000000AAFFAA00000000FFAAFF000000FFAA55AAFFAAAA55AAAA
AAAAFFFFAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AA555555555555FFFF5500
000055FFAAFF550055FFAAFF55AA00AA55FFAAFF550055FFAAFF5500000055FFFF555555
555555AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AAAA55AAAA5555AAAA
AAAAAA555555AAAAAA555500FFAAAAAAFF005555AAAAAA555555AAAAAAAAAA5555AAAA55
AAAA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00AA0000000055
55555555FF555500AA00FFAA5555555555AAFF00AA005555FF555555555500000000AA00
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFAAAAAAAAAAAA
55AAAA55AA55AAAAAAFF550000000000000055FFAAAAAA55AA55AAAA55AAAAAAAAAAAAFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF000055555500
0000AA00FF00AA005555AAAAAAAAAAAAAAAAAA555500AA00FF00AA0000005555550000FF
5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAA55AAAA
AAAAAAFFFFFFAAAAAA55AA00005555550000AA55AAAAAAFFFFFFAAAAAAAAAA55AAAAAAAA
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055000000AA
00005555AA55550000FFAAAAAAAA55AAAAAAAAFF00005555AA55550000AA000000550000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAFFFFAA
AAAAAA55AA00FFAAFF550000AA000000AA000055FFAAFF00AA55AAAAAAAAFFFFAAFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AA5555
55555555FFFF0055AA55AAFF55FFAAFF55FFAA55AA5500FFFF555555555555AA5500FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AA
AA55AAAA5555AAFF00000055FF550055FF55000000FFAA5555AAAA55AAAA55AA00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FF00AA0000000055FFAAFF5555AAAAAA5555FFAAFF5500000000AA00FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFAAAAAAAAAAAA555555AAAA550055AAAA555555AAAAAAAAAAAAFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
55FF0000555555000000000055AAAAAA5500000000005555550000FF5500FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00AAAAAAAA55AAAAAAAAAAAAAA550055AAAAAAAAAAAAAA55AAAAAAAA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000055000000AA0000AA0055AAAAAA5500AA0000AA000000550000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFAAFFFFAAAAAAAAFF5555555555FFAAAAAAAAFFFFAAFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0055AA555500005555AAAA55AAAA555500005555AA5500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00AA55AAAAAAAA55AA000000AA55AAAAAAAA55AA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF0000FFAAAAAAAAAAFF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFAA55555555555555AAFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0055FF000000000000000000FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00AAAAAAAAAAAAAAAAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000550000AA0000550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFAAFF55FFAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0055AA55AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.479988 0.782187 0.567299 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000AAAAAAAAFF5500AAFF55AA55AAAA55555555FFAA55AAAA000000AA0000AAAAAA00
00AA5555AAFF00AAAAFFFFFFAA55AA55AAFFFFFFAAAA00FFAA5555AA0000AAAAAA0000AA
000000AAAA55AAFF55555555AAAA55AA55FFAA0055FFAAAAAAAA0000FF
FFFF00FF55FF0055AAAAAA005555AAAA00AA0000AA0055FF55FFFFAAFFFF55AAFFAAAAFF
FF005555FFFFFFAAAA0055AA00AA00AA00AA5500AAAAFFFFFF555500FFFFAAAAFFAA55FF
FFAAFFFF55FF5500AA0000AA00AAAA555500AAAAAA5500FF55FF00FFFF
FFFFFF0000AA55FF55FFFF55AAAA5555AAFFAA55FFFFAA005500AA55555555FFFFFF5500
AA55FF5555555555AA55FF55FFAAAAAAFF55FF55AA5555555555FF55AA0055FFFFFF5555
5555AA005500AAFFFF55AAFFAA5555AAAA55FFFF55FF55AA0000FFFFFF
FFFFFFFF00FF55555500AA55AA5555000000FF55555555AAFF00FF5555FF5555555555FF
AAAA550000AA0000AAAA550000FF55FF000055AAAA0000AA000055AAAAFF5555555555FF
5555FF00FFAA55555555FF0000005555AA55AA00555555FF00FFFFFFFF
FFFFFFFFFF0000AA00FFFF5555AAAA55FFAA5500005555FFFFFF0000AA005500550000AA
5555AAAAAAAAFF55AA5555FFAA550055AAFF5555AA55FFAAAAAAAA5555AA000055005500
AA0000FFFFFF5555000055AAFF55AAAA5555FFFF00AA0000FFFFFFFFFF
FFFFFFFFFFFF00FF55AA005555FFFF555555AAAAAAAA55AA0055AAFFFF55AAAAAA55FFAA
AA55AA5555AA550055FF555555AAAAAA555555FF550055AA5555AA55AAAAFF55AAAAAA55
FFFFAA5500AA55AAAAAAAA555555FFFF555500AA55FF00FFFFFFFFFFFF
FFFFFFFFFFFFFF0000AAAAAA55AA005555000000000000AAAAAA55555555FFFF550055AA
5555FF00AA00AAFF555555FF5555AA5555FF555555FFAA00AA00FF5555AA550055FFFF55
555555AAAAAA000000000000555500AA55AAAAAA0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF55FF00AAAAAA55AAFFFFAAFFFFAAAA00AAFF00AA0055AAAAAA55
550055AAFFAA555555FF555555FF55FF555555FF555555AAFFAA55005555AAAAAA5500AA
00FFAA00AAAAFFFFAAFFFFAA55AAAAAA00FF55FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000AA55FFFF55FF5500AA55555555AA55FFFFFFAAAAAA5555AA55
AAAAAA555555AAAA55AA0000AA005500AA0000AA55AAAA555555AAAAAA55AA5555AAAAAA
FFFFFF55AA55555555AA0055FF55FFFF55AA0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF5555555500AAFF550000AA00FF5555555555AA5555FF5500
00000000AA0000000055FFAAFFAA55AAFFAAFF5500000000AA000000000055FF5555AA55
55555555FF00AA000055FFAA0055555555FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000AA00FFAA555555FFAAFFAA55000055550000005500AAFF
FFAAFF55AA55FFAAFF555555AA00AA00AA555555FFAAFF55AA55FFAAFFFFAA0055000000
5555000055AAFFAAFF555555AAFF00AA0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF55AA00AA0000AA555555AAAAAAAA55AAFF55AAAAAA00
55AA5500000055AA5500005555AAFFAA5555000055AA5500000055AA5500AAAAAA55FFAA
55AAAAAAAA555555AA0000AA00AA55FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000AAAAAAFF55AA55AAAA5555AA5555FF000055FFFF55
AAAA00FFFFAA55AA55AAFF5555FFFFFF5555FFAA55AA55AAFFFF00AAAA55FFFF550000FF
5555AA5555AAAA55AA55FFAAAAAA0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FF0000AAAA5555AAAA55550055AAFF55555555
FFFF55AA0055FF55FF5500AA0000FF0000AA0055FF55FF5500AA55FFFF55555555FFAA55
005555AAAA5555AAAA0000FF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA55FFAAAA0000AAAA00FFAA55AA5500555500
00FF00AAAAAA550000FFAAFFAAFFFFFFAAFFAAFF000055AAAAAA00FF000055550055AA55
AAFF00AAAA0000AAAAFF55AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF555555AA55FFAAAAFFFFFF5555AAAAAA55AA
FFFFFFAAAA00AAFF55AA00AA5555555555AA00AA55FFAA00AAAAFFFFFFAA55AAAAAA5555
FFFFFFAAAAFF55AA555555FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA00FF555555AA5500AA55AAAAFFAAAA55
55555555AA55FF0000AAAAAA0000AA0000AAAAAA0000FF55AA5555555555AAAAFFAAAA55
AA0055AA555555FF00AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55AA0000AA00AAFF550055FFFFFF5500
00555500000055AAFFFF55FFFFAAFFAAFFFF55FFFFAA550000005555000055FFFFFF5500
55FFAA00AA0000AA55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AAAAAAAAFF5500AAFF5555555555FF
AA55AAAAAAAAAA5555555500AA555555AA0055555555AAAAAAAAAA55AAFF5555555555FF
AA0055FFAAAAAAAA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FF0055AAAAAA00555500550055
AA55AA5555AA5555FF5555FFAAAA55AAAAFF5555FF5555AA5555AA55AA55005500555500
AAAAAA5500FF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA55FF55FFFF55AAAA55FF55AA
AA0000005555AAAA5500555555AA55AA5555550055AAAA5555000000AAAA55FF55AAAA55
FFFF55FF55AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55555500AA55AA555500AAFF
AAAAAAAAAA55AA5555FFAA000055FF550000AAFF5555AA55AAAAAAAAAAFFAA005555AA55
AA00555555FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA00FFFF5555AAAA55FFFF
FF55FFFF55000000555555AAFF555555FFAA55555500000055FFFF55FFFFFF55AAAA5555
FFFF00AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55AA005555FFFF555555
555500AA55AAFF55AAAA55AA5500550055AA55AAAA55FFAA55AA005555555555FFFF5555
00AA55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AAAAAA55AA00555500
00AAFFFF5555AA00000000AAAA55FF55AAAA00000000AA5555FFFFAA0000555500AA55AA
AAAA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FF00AAAAAA55AA
FF5500AA55AAAAFFFFAA55FFFF555555FFFF55AAFFFFAAAA55AA0055FFAA55AAAAAA00FF
55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA55FFFF55FF55
00AAFF55FF55FFFFFFFF55555555FF55555555FFFFFFFF55FF55FFAA0055FF55FFFF55AA
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF5555555500AA
FF5500AA005555555555550000555555000055555555555500AA0055FFAA0055555555FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA00FFAA55
5555FFAAAAAA55AAAA55AAAAAAAA55AAAAAAAA55AAAA55AAAAAAFF555555AAFF00AA0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55AA00AA
000055AA5555AAAAFFAA00AAAA00AA00AAAA00AAFFAAAA5555AA550000AA00AA55FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AAAAAA
FF55AAAA0000AAAA0055FFAAAAFF55FFAAAAFF5500AAAA0000AAAA55FFAAAAAA0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FF
0000AAAAFFFFAAAAFF555555AA550055AA555555FFAAAAFFFFAAAA0000FF55FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA
55FFAAAA0055AA555555FF5555AAAAAA5555FF555555AA5500AAAAFF55AA0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
555555AA55FF5500005500AA00FF55FF00AA0055000055FF55AA555555FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00AA00FF555555FFAA55AAFFAA550055AAFFAA55AAFF555555FF00AA0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF55AA00005500AAAA555555AAAAAA555555AAAA00550000AA55FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000AAAAAAAA55FFFF555500000000005555FFFF55AAAAAAAA0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF55FF005500AA55AAAAAAAAAAAAAA55AA005500FF55FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000AA55FF55AA55AA5555AA5555AA55AA55FF55AA0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF55555500FFAAAA55AA55AAAAFF00555555FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000AA00FFFFFF5500000055FFFFFF00AA0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF55AA0055AAAAAAAAAA5500AA55FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000AAAAAA5555AA5555AAAAAA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF55FF00AAFFAA00FF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000AA55FFFFFF55AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF5555555555FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00005500550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.479988 0.97619 0.567299 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00000000FFFF00AA55FF0000FFFF55555500AAAAAAAAAAFFFF00000000AAFFFFFFFFAA
55FFFFFF00FFFF000000AAAA00FFFFFF00AAAA000000FFFF00FFFFFF55AAFFFFFFFFAA00
000000FFFFAAAAAAAAAA00555555FFFF0000FF55AA00FFFF00000000FF
FFFF00AAFFFFFFFFAAAA00000000AA00AAAA00FF0000FF0000AA00FFAA55FFFFFFFFFFFF
550055000000AA00FFFF0000FFFFFFFFFF0000FFFF00AA000000550055FFFFFFFFFFFF55
AAFF00AA0000FF0000FF00AAAA00AA00000000AAAAFFFFFFFFAA00FFFF
FFFFFF000055550000FF00AAFFFFAAAAAAFFAA00000000AAFF000000AA55550000550000
AAAAAA00FFFF000000AA00FFFFFFFFFFFFFF00AA000000FFFF00AAAAAA00005500005555
AA000000FFAA00000000AAFFAAAAAAFFFFAA00FF000055550000FFFFFF
FFFFFFFF00AAAA00FFFFFF00005500AA550000FFFFAA55FFFFFFAA55AA00AAAAAAAA00FF
AAAAFFAA0000AAFFFF0000005555005555000000FFFFAA0000AAFFAAAAFF00AAAAAAAA00
AA55AAFFFFFF55AAFFFF000055AA00550000FFFFFF00AAAA00FFFFFFFF
FFFFFFFFFF0000FFFFFFFFFF00FF55AA00AAFFFFFFFF550000AA0055FFFF0000FF000000
AA550000FFFF00005555FFAA00AAAAAA00AAFF55550000FFFF000055AA000000FF0000FF
FF5500AA000055FFFFFFFFAA00AA55FF00FFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFF00AA0000AA000000AAAAFF0000AA000055FFAAFFAA00AA00000000AAFFFF
AAAA00FFFFFFFF00AAAA0000FFFF55FFFF0000AAAA00FFFFFFFF00AAAAFFFFAA00000000
AA00AAFFAAFF550000AA0000FFAAAA000000AA0000AA00FFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFF00AA5500000000FFAA00AA00555555FFFF00FFAA005500
00FF00AA0000AA00FF00000000AA00AA00000000FF00AA0000AA00FF00005500AAFF00FF
FF55555500AA00AAFF0000000055AA00FFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00AAFFFFFFFFAAAA00FFFFAA0000FFFF5555AA5555000000AA55FF00
FFFFFF00000000FFFFFF00FFFF000000FFFF00FFFFFF00000000FFFFFF00FF55AA000000
5555AA5555FFFF0000AAFFFF00AAAAFFFFFFFFAA00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000055550000FF00AA0000FFAA0000AAAA0055FF00FFFFAAAA0000
00AA000000000000AA0000005555FF5555000000AA000000000000AA000000AAAAFFFF00
FF5500AAAA0000AAFF0000AA00FF000055550000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00AAAA00FFFFFF00000000AA55AAFFAAAAAA000000AA0055AAFF
FF0000000000000000FFFF00FF550055FF00FFFF0000000000000000FFFFAA5500AA0000
00AAAAAAFFAA55AA00000000FFFFFF00AAAA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FFFFAAAA005555555555FF555555FF0000
AA00FFFF00AAFFFF00AA00000055FF55000000AA00FFFFAA00FFFF00AA0000FF555555FF
555555555500AAAAFFFF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AA0000AA000000AA0055AAAA00AAAA00AA00AAAA000000
00FFFFFFFF0000AA00FF00AAFF550055FFAA00FF00AA0000FFFFFFFF00000000AAAA00AA
00AAAA00AAAA5500AA000000AA0000AA00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF00AA55FF0000FFFF55FF55FF55FFFF00FF
AA0000AA00000000FFFFFF0000AAAAAA0000FFFFFF00000000AA0000AAFF00FFFF55FF55
FF55FFFF0000FF55AA00FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFFFFFFAAAA00000000AA00AA00AA00AA000000
55AAFFFF5555FFAA0000AA00FFFF55FFFF00AA0000AAFF5555FFFFAA55000000AA00AA00
AA00AA00000000AAAAFFFFFFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055550000FF00AAFFFFAAAAAAFFFF555555FF55
55AA0000AAAA0000FFFF000000AA00AA000000FFFF0000AAAA0000AA5555FF555555FFFF
AAAAAAFFFFAA00FF000055550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAA00FFFFFF00005500AA550000AAAA00AA00
AAAAFFFF0000FFAA0000AAFFFF000000FFFFAA0000AAFF0000FFFFAAAA00AA00AAAA0000
55AA00550000FFFFFF00AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FF55AA00AAFFFF55FF55FF
55FFFFFFFFAA0000FFFF00005555FF55550000FFFF0000AAFFFFFFFF55FF55FF55FFFFAA
00AA55FF00FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA0000AA000000AAAAFF0000AA00AA00AA
00AA00005500AAFFFFFFFF00FF550055FF00FFFFFFFFAA00550000AA00AA00AA00AA0000
FFAAAA000000AA0000AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF00AA5500000000FFFF5555
55FFFF00FF55AA0000AA000000AAAAAA000000AA0000AA55FF00FFFF555555FFFF000000
0055AA00FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFFFFFFAAAA00FFFFAA0000AAAA
00AA000000AAAAFFFF0000000000FF0000000000FFFFAAAA000000AA00AAAA0000AAFFFF
00AAAAFFFFFFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055550000FF00AA0000FFAA0055
AAAAFFFF00FF0000AA00FFFF00FFFFFF00FFFF00AA0000FF00FFFFAAAA5500AAFF0000AA
00FF000055550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAA00FFFFFF00000000AA55AA
5500AA000000AAFFFF5555000000AA0000005555FFFFAA000000AA0055AA55AA00000000
FFFFFF00AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FFFFAAAA00
55FFAAAAAAAA550000AAAA00FFAAFFAAFF00AAAA000055AAAAAAAAFF5500AAAAFFFF00FF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA0000AA000000AA0055AA
AA0000FF0000FF5555FFFF555500AA005555FFFF5555FF0000FF0000AAAA5500AA000000
AA0000AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF00AA55FF00
00FFAA00000000AAAA0000AAAA00FF00AAAA0000AAAA00000000AAFF0000FF55AA00FFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFFFFFFAAAA0000
0000AA55AAFFFF0000FFFF0000FFFFFF0000FFFF0000FFFFAA55AA00000000AAAAFFFFFF
FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055550000FF00AA
FFFFAAAA005500000000AA00FFFFFFFFFF00AA000000005500AAAAFFFFAA00FF00005555
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAA00FFFFFF00
005500AA55AA55FF55AAAAFFFFFFFFFFFFFFAAAA55FF55AA55AA00550000FFFFFF00AAAA
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
00FF55AA00AA555500FF000055550055550000FF005555AA00AA55FF00FFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA0000AA00
0000AAAAFFFF5500FFFFFFAA00AAAAAA00AAFFFFFF0055FFFFAAAA000000AA0000AA00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FF00AA55005500FFFFFFFFFF5555555555FFFFFFFFFF00550055AA00FFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF
FFFFAAAA00FF555500550000AAAA00AAAA000055005555FF00AAAAFFFFFFFFAA00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055
550000FF00AA00AAAAAA00FFFF55FF55FFFF00AAAAAA00AA00FF000055550000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA
AA00FFFFFF000000FF000000AA00AA00AA000000FF000000FFFFFF00AAAA00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFF00FFFFFFAA55AA00FF00AA55AAFFFFFF00FFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00AA0000AA000000555500AAAAFFFFFFAAAA005555000000AA0000AA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFF00AAAA00FF0000AA0000FF00AAAA00FFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00AAFFFFFFFF0000FFFFFFAAFFAAFFFFFF0000FFFFFFFFAA00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000555500000000555500AA0055550000000055550000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00AAAA00FFFF00AAAA00FF00AAAA00FFFF00AAAA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFF0000FFFFFF0000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00AA0000AA00FFFFFFFFFF00AA0000AA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00AAFFFFFFFFFFFFFFFFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000550000550000550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00AAAA55AA55AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF55FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AA00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.57603 0.200176 0.66334 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00555555AA00FFAA55000000AA005555AA5555555555AA000000555500AAFFFF00AA00
00AAAA000055FFAA55AA005500FFFFFF005500AA55AAFF550000AAAA0000AA00FFFFAA00
5555000000AA5555555555AA555500AA00000055AAFF00AA55555500FF
FFFFAA00FFFF550055AAFFFFAAFFAAFF00AA55AAAA55FFAAAA00AAAAAAAA00555500FF00
55FFFF5500FFFFFF555555AAFFFFFFFFFFAA555555FFFFFF0055FFFF5500FF00555500AA
AAAAAA00AAAAFF55AAAA55AA00FFAAFFAAFFFFAA550055FFFF00AAFFFF
FFFFFF550000AAFFFF000055555500AA00AA55FFFF555500AA555555555555AAAA555500
FFFFFFFF0055005555FF55AA0000550000AA55FF5555005500FFFFFFFF005555AAAA5555
55555555AA005555FFFF55AA00AA005555550000FFFFAA000055FFFFFF
FFFFFFFF0055FFFFFFFFAAFF00FFAAFFAAFFAA0000AAFF0055AAAAAA55AAFF0000FFFF00
5500550055FFAAFF00AA00FF0055FF5500FF00AA00FFAAFF550055005500FFFF0000FFAA
55AAAAAA5500FFAA0000AAFFAAFFAAFF00FFAAFFFFFFFF5500FFFFFFFF
FFFFFFFFFFAA0000555500AA00AA0055555500AAAA005555AAFFAAAAFF0000AAAA0000AA
AAAA00FF555500AA00AA555500FFFFFF005555AA00AA005555FF00AAAAAA0000AAAA0000
FFAAAAFFAA555500AAAA0055555500AA00AA0055550000AAFFFFFFFFFF
FFFFFFFFFFFF5500FFAA00AA555555AAFF5555AA0055FFAA005555555500FF55FFFFAAFF
AAAAFFFFFF00AAAAFFFF55AAFFFFFFFFFFAA55FFFFAAAA00FFFFFFAAAAFFAAFFFF55FF00
5555555500AAFF5500AA5555FFAA555555AA00AAFF0055FFFFFFFFFFFF
FFFFFFFFFFFFFF00555555AA00FFAA5500000000FF555500AAAA55AAAAAA000000AA0055
555555005500FF00005555FFFFFFFFFFFFFF55550000FF0055005555555500AA000000AA
AAAA55AAAA005555FF0000000055AAFF00AA55555500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00FFFF550055AAFFFFAAFFFFFF00AAAAFFAA0055AA00AAAA0055FF
5555FFAAFF550055FF00FFFFFFFFFFFFFFFFFF00FF550055FFAAFF5555FF5500AAAA00AA
5500AAFFAAAA00FFFFFFAAFFFFAA550055FFFF00AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF550000AAFFFF0000555555005500FF000055AA55AA00AA5500FFFF
FF00AA005555FF00AA00AA00005500550000AA00AA00FF555500AA00FFFFFF0055AA00AA
55AA550000FF0055005555550000FFFFAA000055FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055FFFFFFFFAAFF00FFAAFF005500FF555555FFFFAAAA555500
00AAAAFFFF00AA00AA555555AA55AA55AA555555AA00AA00FFFFAAAA00005555AAAAFFFF
555555FF005500FFAAFF00FFAAFFFFFFFF5500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA0000555500AA00AA005555AAAA0000000000AA0055AAFF55
00FF00005500FF0055AAAA55AA00FF00AA55AAAA5500FF00550000FF0055FFAA5500AA00
00000000AAAA555500AA00AA0055550000AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5500FFAA00AA555555AAFF55FFFFAAFFFFAAFFAAFF0000AA
FFFFFFAAFF005555AAFFAAAAAAFFFFFFAAAAAAFFAA555500FFAAFFFFFFAA0000FFAAFFAA
FFFFAAFFFF55FFAA555555AA00AAFF0055FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00555555AA00FFAA55000000AA00555500AA005555AA55
000055555500FFAA00555555555500555555555500AAFF00555555000055AA555500AA00
555500AA00000055AAFF00AA55555500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF550055AAFFFFAAFFAAFF00AAAAFFFF00AA55
AA5555FFAA00AA0055FF55AAFF55AA55FFAA55FF5500AA00AAFF5555AA55AA00FFFFAAAA
00FFAAFFAAFFFFAA550055FFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000AAFFFF000055555500AA00AA550000AAAAFF
0000000055AA5500FFFFFF0000AAFFAA0000FFFFFF0055AA5500000000FFAAAA000055AA
00AA005555550000FFFFAA000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFFFFFFAAFF00FFAAFFAAFFAA5555AA0055
55AA5555AAFFAA5555005555AA550055AA5555005555AAFFAA5555AA555500AA5555AAFF
AAFFAAFF00FFAAFFFFFFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000555500AA00AA0055555500AAFF55FF00
AAFFAA55FFFFFF55AAAA00FFFF55AA55FFFF00AAAA55FFFFFF55AAFFAA00FF55FFAA0055
555500AA00AA0055550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFAA00AA555555AAFF5555AA00000055
FFFFFF55550000AAFFAAAA0000AAFFAA0000AAAAFFAA00005555FFFFFF55000000AA5555
FFAA555555AA00AAFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555AA00FFAA5500000000FF5500FF
FFFFFFFF00AAAA0055555555AA550055AA5555555500AAAA00FFFFFFFFFF0055FF000000
0055AAFF00AA55555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF550055AAFFFFAAFFFFFF0055
5500005555AA0055FFAA00FFFF55AA55FFFF00AAFF5500AA55550000555500FFFFFFAAFF
FFAA550055FFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000AAFFFF0000555555005500FF
AA00AAAAAA5500FFFFFF550000AAFFAA000055FFFFFF0055AAAAAA00AAFF005500555555
0000FFFFAA000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFFFFFFAAFF00FFAAFF0055
5555AA0055AAFFFFFFFFFF0055FFFFFF5500FFFFFFFFFFAA5500AA55555500FFAAFF00FF
AAFFFFFFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000555500AA00AA005500FF
AA55FFFFAA55000055005500FFFFFFFFFF00550055000055AAFFFF55AAFF005500AA00AA
0055550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFAA00AA555555AAFFFF
FF55550055AAFFFFAA00AAFFFFFFFFFFFFFFAA00AAFFFFAA55005555FFFFFFAA555555AA
00AAFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555AA00FFAA550000
AA00FFFFAA550000AA5555550000550000555555AA000055AAFFFF00AA000055AAFF00AA
55555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF550055AAFFFF
AAAA000055AAAA00AA55AAFF0055FF5500FFAA55AA00AAAA550000AAAAFFFFAA550055FF
FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000AAFFFF000055
00AA5555AAAAFFAAFFAA005500FFFFFF005500AAFFAAFFAAAA5555AA00550000FFFFAA00
0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFFFFFFAAFF
0055AAAA5500AA00555555AAFFFFFFFFFFAA55555500AA0055AAAA5500FFAAFFFFFFFF55
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000555500AA
00AAFFAAAAAA0055FF5555FFFFFFFFFFFFFF5555FF5500AAAAAAFFAA00AA0055550000AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFAA00AA
55555500AA5500FFFFFF00AA0000550000AA00FFFFFF0055AA00555555AA00AAFF0055FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555AA
00FFFF0055AAAA00005500FF0055FF5500FF00550000AAAA5500FFFF00AA55555500FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF
55005500FFAAAAFFFFAA555500FFFFFF005555AAFFFFAAAAFF00550055FFFF00AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000
AAFFFF00555555550055AAAA5555005555AAAA55005555555500FFFFAA000055FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055
FFFFFFFFAA55FF5555AAAAFFAA55AA55AAFFAAAA5555FF55AAFFFFFFFF5500FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
0000550000FFFFFF00AA550055AAFFAA550055AA00FFFFFF0000550000AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
5500FFAAFFFFFFFFFFAAAA5555FFFFFF5555AAAAFFFFFFFFFFAAFF0055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF005555550055000055AA00FFFFFFFFFF00AA550000550055555500FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA00FFFFAA00AAAAAAFFFFFFFFFFFFFFAAAAAA00AAFFFF00AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF550000AA555555555500005500005555555555AA000055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0055FFFF00AAFF5555AA55AA5555FFAA00FFFF5500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA000055FFFFFF00AA55AA00FFFFFF550000AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF5500FFFFFFFFFFAAAAAAFFFFFFFFFF0055FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00550000550000FF00005500005500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00AAAAAA00AA00AAAAAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5500AA5500FF0055AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055AAFFFFFFAA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA5500550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AA55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.57603 0.39418 0.66334 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0055AAAAAAAAAAAA00AA5500FFFF00550000AA00AA00FF55FFAAAAAAAAFF55AA0000FF
FFFFFFFF55AAFFFFAAFF55AAFFAAFFAAFFAA55FFAAFFFFAA55FFFFFFFFFF0000AA55FFAA
AAAAAAFF55FF00AA00AA00005500FFFF0055AA00AAAAAAAAAAAA5500FF
FFFFAA550055AA0000FFAAAAAA5555AAAAAA55AA00FF00AAAAAA0000555555AAFFAAFFFF
FFFFFFFFFF0000000055FFAAAA000000AAAAFF5500000000FFFFFFFFFFFFFFAAFFAA5555
550000AAAAAA00FF00AA55AAAAAA5555AAAAAAFF0000AA550055AAFFFF
FFFFFF55AAAAAAFF00AAAAFFAAAAAAAAFFAAAAAAFFFFFFAAAAFFAAFF00FFFF000000AAAA
00AAAA00AAAA55AAAA55FF0000FFAAFF0000FF55AAAA55AAAA00AAAA00AAAA000000FFFF
00FFAAFFAAAAFFFFFFAAAAAAFFAAAAAAAAFFAAAA00FFAAAAAA55FFFFFF
FFFFFFFF0000AA00AAFFAAAA005555000000AA0000000000AA555555AAAA00AAFFFFAAAA
FF0000AAFFAAAAAAFFAA5555FF550055FF5555AAFFAAAAAAFFAA0000FFAAAAFFFFAA00AA
AA555555AA0000000000AA000000555500AAAAFFAA00AA0000FFFFFFFF
FFFFFFFFFFAAFFAA00000055AAAAAAAA55AAAAFFFFAA00FFAAAAAAAAAAFFAA0000000055
00FFAA0000005500AAAAFF55AA55FF55AA55FFAAAA0055000000AAFF005500000000AAFF
AAAAAAAAAAFF00AAFFFFAAAA55AAAAAAAA55000000AAFFAAFFFFFFFFFF
FFFFFFFFFFFF5500AAFFFFAA55000055AAFFAAAA00AA55AA5500005500AAAAFF00AAFFFF
00AAAAFFFFAAFF55555500FFFF55AA55FFFF00555555FFAAFFFFAAAA00FFFFAA00FFAAAA
0055000055AA55AA00AAAAFFAA55000055AAFFFFAA0055FFFFFFFFFFFF
FFFFFFFFFFFFFF00AA00AAAAFF5555FFAAAA0000FFAAAAAAFF5555FFAA0055AA55AA00AA
AA5500000000AAAAAAAAAA5555AAFFAA5555AAAAAAAAAA0000000055AAAA00AA55AA5500
AAFF5555FFAAAAAAFF0000AAAAFF5555FFAAAA00AA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA5500AAAAAAAA0055AAAA5555005500FFFF005555FFAAAAAAFFFF
55FFAAFFFFAA0000FF0000FFFF000000FFFF0000FF0000AAFFFFAAFF55FFFFAAAAAAFF55
5500FFFF0055005555AAAA5500AAAAAAAA0055AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55FFAA0055555555FFAAAAFF55AAAAAA5555AAAAAAAA0000AA00AA
AAAA00000000AAFFFFFFAA00AAAA55AAAA00AAFFFFFFAA00000000AAAAAA00AA0000AAAA
AAAA5555AAAAAA55FFAAAAFF5555555500AAFF55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055AAAAAAAAAAAA0000AAAAAAFFAAAAAAAAFFAAAAFF00AA55AA
0000AAFFFFAA0000000000AAFFAAAAAAFFAA0000000000AAFFFFAA0000AA55AA00FFAAAA
FFAAAAAAAAFFAAAAAA0000AAAAAAAAAAAA5500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA550055AA0000FFAA0000AA555555550000005500FFAAAAAA
FF00AA5555AA00FFAAFF00AA5555555555AA00FFAAFF00AA5555AA00FFAAAAAAFF005500
000055555555AA0000AAFF0000AA550055AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AAAAAAFF00AAAAFFFFAAAAAAAAAAAA55AAAAAA55550055
00FFAAAAAAAAFF005500FFAAAAAAAAAAAAAAFF005500FFAAAAAAAAFF0055005555AAAAAA
55AAAAAAAAAAAAFFFFAAAA00FFAAAAAA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000AA00AAFFAAAA00AA5500AA0055AAFFAAAAFF55AAAA
AA555555555555AAAAAA555555555555555555AAAAAA555555555555AAAAAA55FFAAAAFF
AA5500AA0055AA00AAAAFFAA00AA0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA00000055AAAAFF555555FFAAAA0000AAAAAAFF
AAAAAAAAAAAAAAAAFFAAAAAAAAAAAAAAAAAAAAAAFFAAAAAAAAAAAAAAAAFFAAAAAA0000AA
AAFF555555FFAAAA55000000AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAFFFFAA5500AAAAAAAAAA0000FFAA00555555
AA0000AA550000FF0055AA005500AA005500AA5500FF000055AA0000AA55555500AAFF00
00AAAAAAAAAA0055AAFFFFAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00AAAAFF555555555500AAFF0055AAAAAAAA
AAFFFFAAAAAA55AA55AAFFAAFF555555FFAAFFAA55AA55AAAAAAFFFFAAAAAAAAAA5500FF
AA005555555555FFAAAA00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500AAAAAAAAAAAAAA5500FFAA5500AA00
00AAAA0000AA55FFFF000000AAAAAAAAAA000000FFFF55AA0000AAAA0000AA0055AAFF00
55AAAAAAAAAAAAAA0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA00555555550055AAFFFFFF55AAAAFF
FFAAAAFFFFAAAAAA00AAFFFFAAAAFFAAAAFFFFAA00AAAAAAFFFFAAAAFFFFAAAA55FFFFFF
AA55005555555500AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AAAAAAAAAAAA55FFFFFFFFFF0000AA
AA0055AA55550000FFAAAA00AA000000AA00AAAAFF00005555AA5500AAAA0000FFFFFFFF
FF55AAAAAAAAAAAA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055AA0000FFFFFFFFFFFFFFAA00
55AAAAAAFF55AAAA55555555FFFFAAFFFF55555555AAAA55FFAAAAAA5500AAFFFFFFFFFF
FFFF0000AA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAAAAFF00AAAA00AAAA00AAAAFF
FF00005555AAFFAAAAAAAAAAAA00AA00AAAAAAAAAAAAFFAA55550000FFFFAAAA00AAAA00
AAAA00FFAAAAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA00AAFFAAAA5500AAFFAAAA
00AAFFFF00FF005555550000FF00AA00FF000055555500FF00FFFFAA00AAAAFFAA0055AA
AAFFAA00AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA00000055AAFF000000FF
00AA5555AAAA00FFFF00FFAA00AAFFAA00AAFF00FFFF00AAAA5555AA00FF000000FFAA55
000000AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAFFFFAA5500FFAAFFFF
FFAAAAAAAAFFAA00AAAA555555FFFFFF555555AAAA00AAFFAAAAAAAAFFFFFFAAFF0055AA
FFFFAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00AAAAFF5555AA00AA
AA0000AA000000AAFFAAAAAAAAAA00AAAAAAAAAAFFAA000000AA0000AAAA00AA5555FFAA
AA00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500AAAAAAAAFF00
00FFAAFFAAFFFFAAAA00005500AA55AA00550000AAAAFFFFAAFFAAFF0000FFAAAAAAAA00
55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA0055555555AA
AA555555AA00AAAAFFAAFF00FFAAAAAAFF00FFAAFFAAAA00AA555555AAAA5555555500AA
FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AAAAAAAAAAAA
FFAA55FFAAAA55000000AAAA5555555555AAAA00000055AAAAFF55AAFFAAAAAAAAAAAA55
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055AA0000
AAAAFF550055AAFF00AAFFAAAAAAAAAAAAAAFFAA00FFAA550055FFAAAA0000AA550055AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAAAAFF00
AA0055FFAAFF55FF00AA00AA0000550000AA00AA00FF55FFAAFF5500AA00FFAAAAAA55FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA00AA
FFAAFF5500AAAAAA00FF00AA55AAAAAA55AA00FF00AAAAAA0055FFAAFFAA00AA0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA00
000055FFAAFFAAAAFFFFFFAAAAAAFFAAAAAAFFFFFFAAAAFFAAFF55000000AAFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA
FFFFAA555500FF0000000000FF000000FF0000000000FF005555AAFFFFAA0055FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA
00AAAAFF55AAAA00FFAAFF00AAAA55AAAA00FFAAFF00AAAA55FFAAAA00AA00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AA5500AAAAAAFFAA00AA00AAFFAAAAAAFFAA00AA00AAFFAAAAAA0055AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
55FFAA00555555AA00FF00AA5555555555AA00FF00AA55555500AAFF55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0055AAAAAAAAAAFFFFFFAAAAAAAAAAAAAAFFFFFFAAAAAAAAAA5500FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA5500AA5500AAAA00AA5500AA0055AA00AAAA0055AA0055AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55AAAAFF55555555FFFF00AA00FFFF55555555FFAAAA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000AAAAAAAAAAAA00AAFFAA00AAAAAAAAAAAA0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFFAAAAFFAAAAFF000000FFAAAAFFAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF5500AA555500AAAA55AAAA005555AA0055FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00AA55FFAAFFAAAAAAFFAAFF55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAAA000000FF000000AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55FFFFAAFFFFFFAAFFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055FFFFFFFFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA5555AA5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AAFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.57603 0.588183 0.66334 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000550000555555AA55AAFFFF0000FFFF00000000005500FFFFAA55FF00AAAA0000
AAAAAAAA55AA555555AA00005555FF55550000AA555555AA55AAAAAAAA0000AAAA00FF55
AAFFFF00550000000000FFFF0000FFFFAA55AA555555000055000000FF
FFFFAAFF00FF0000550000005555AA55AAAA00AA55AAAA55AAFFFFFFFF55AA5500555555
5500555500000055000000FF00FFFFFF00FF00000055000000555500555555550055AA55
FFFFFFFFAA55AAAA55AA00AAAA55AA5555000000550000FF00FFAAFFFF
FFFFFF5500AAAA550000FF000055005500555555000000005555AA5555AAFFAA55000055
0000FFFF0000FF00FF00AA555555AA555555AA00FF00FF0000FFFF000055000055AAFFAA
5555AA555500000000555555005500550000FF000055AAAA0055FFFFFF
FFFFFFFF0000000055AAAA00FF00FF00FF00FFFF0000FF00005500550000AAAAFF5555FF
AA00FF5500AA555555AA000055000000550000AA555555AA0055FF00AAFF5555FFAAAA00
005500550000FF0000FFFF00FF00FF00FF00AAAA5500000000FFFFFFFF
FFFFFFFFFFAAFF0000555500AAAA555555AA00AAAA5500FF000055AAFF000000AAAAAAAA
0000FF55AA000055000000FF00FFAAFF00FF000000550000AA55FF0000AAAAAAAA000000
FFAA550000FF0055AAAA00AA555555AAAA0055550000FFAAFFFFFFFFFF
FFFFFFFFFFFF5500AA55FFAA000000550000AAFFAAAAAA555555FFAAAA00FF0000AA0000
00FF00550055AAAAAA55AAAA00FF55FF00AAAA55AAAAAA55005500FF000000AA0000FF00
AAAAFF555555AAAAAAFFAA000055000000AAFF55AA0055FFFFFFFFFFFF
FFFFFFFFFFFFFF00000055FFFFAAFF00FF0000AAAAFFAAAAAAAAAA0000AA555555FFFFAA
FFFFFFAA550000000000555500AAAAAA005555000000000055AAFFFFFFAAFFFF555555AA
0000AAAAAAAAAAFFAAAA0000FF00FFAAFFFF55000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF00FF550055FF5500AAFFAAAA000000000000FFAAAAAAAAAA00AA
00AAAA000055AA00FFAAFF55AA000000AA55FFAAFF00AA550000AAAA00AA00AAAAAAAAAA
FF000000000000AAAAFFAA0055FF550055FF00FFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5500AAAAAA55FF00FFAAAA0000AA55AAAA55AAAA00000000AA0055
55550055AAAAAAFFFFFF55000000FF00000055FFFFFFAAAAAA550055555500AA00000000
AAAA55AAAA55AA0000AAAAFF00FF55AAAAAA0055FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000055FF55005555555500000000555500AA55AAAAFF00
FFFF000055550055FF005500AA55AA55AA005500FF550055550000FFFF00FFAAAA55AA00
555500000000555555550055FF550000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFF0000FFFFFF000055000055AAAA55AAFF5555000000AAAA
5555AA00FFFF000055FF55AAAAFF55FFAAAA55FF550000FFFF00AA5555AAAA0000005555
FFAA55AAAA550000550000FFFFFF0000FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5500AA5555AA55AAAAAA55000000005555AAFF5555555500
55000000FF5500AAFF55000000AAAAAA00000055FFAA0055FF000000550055555555FFAA
55550000000055AAAAAA55AA5555AA0055FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000005500550055550000FFAA00550000AAAAAAAAAAAA
55FF555555AAFFFF550000FF0000000000FF000055FFFFAA555555FF55AAAAAAAAAAAA00
005500AAFF0000555500550055000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FF00FF00FFFFAA00AA00FFFFAA000000000000
0055FFAA55FFFFFFFF0000FF5555555555FF0000FFFFFFFF55AAFF5500000000000000AA
FFFF00AA00AAFFFF00FF00FF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAAA5555FF0055555500AAAA0000FF0000FF00
00FFFFFF55AA5555AA5500AAAAAAAAAAAAAA0055AA5555AA55FFFFFF0000FF0000FF0000
AAAA0055555500FF5555AAAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000005500FF00FFFF000000AA5500FF00AAAA
55AA5555AAFFAA55FFFF000000000000000000FFFF55AAFFAA5555AA55AAAA00FF0055AA
000000FFFF00FF005500000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF000055AA5500FF555555550000FF555500
5500550000AAAAFF5500FFAAFFFFAAFFFFAAFF0055FFAAAA0000550055005555FF000055
555555FF0055AA550000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA55FFFF00AAAAAAAAAAAA5500FFFF00
0055AAFF000000AAAAAA555500FF55FF005555AAAAAA000000FFAA550000FFFF0055AAAA
AAAAAAAA00FFFF55AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000055FF000000000000000055AA5555
55FFAAAA00FF00000000005500AAAAAA00550000000000FF00AAAAFF555555AA55000000
0000000000FF55000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FF5555555555555555FFAAAAAA
AAAA0000AA555555555555FFAA000000AAFF555555555555AA0000AAAAAAAAAAFF555555
5555555555FF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAAAAAAAAAAAAAAAAAAA000000
000000FFAAAAAAAAAAAAAAAA0000FF0000AAAAAAAAAAAAAAAAFF000000000000AAAAAAAA
AAAAAAAAAAAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000AA00FFAA
FFFFAA00AA00000000000000AA55AA55AA00000000000000AA00AAFFFFAAFF00AA000000
00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0000FF0000FF000000FF55
FF0055555500AA55AAAA55AAAAFF55FFAAAA55AAAA55AA0055555500FF55FF000000FF00
00FF0000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA55555555AA00FF0055
00FF00FFFF0000005555000000AAAAAA0000005555000000FFFF00FF005500FF00AA5555
5555AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000550000555555AAAA
AA555555AA55AA00550000FFAA000000AAFF00005500AA55AA555555AAAAAA5555550000
55000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FF000055000000
0000550000005555FFAAFF00555555555500FFAAFF5555000000550000000000550000FF
00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAAA550000FF00
00FF00FF0000FFFF005555AAAAAAAAAAAAAA555500FFFF0000FF00FF0000FF000055AAAA
0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000055AAAA00
FF0055AA5500AAAA00550000000000000000005500AAAA0055AA5500FF00AAAA55000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0000555500
AAAA55FFFF00000000FFFFAA00FFAAFF00AAFFFF00000000FFFF55AAAA0055550000FFAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA55FFAA
00000055FF0000FF00AAAA0000FF55FF0000AAAA00FF0000FF55000000AAFF55AA0055FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000055FF
FFAAFF00FF5555FF00000000FF005500FF00000000FF5555FF00FFAAFFFF55000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FF
550055FF55000055FF55555555AAAAAA55555555FF55000055FF550055FF00FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA
AAAA55FF00FFAAFF55000055000000000055000055FFAAFF00FF55AAAAAA0055FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000055FF550055FFAAFFFF00AA55AA00FFFFAAFF550055FF550000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
FF0000FFFFFF000055FFFFFFFFAAAAAAFFFFFFFF550000FFFFFF0000FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
5500AA5555AA55AAAAAA00AAAA000000AAAA00AAAAAA55AA5555AA0055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000055005500555500AA0000FF0000AA00555500550055000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFF00FF00FF00FFFFAAAA55AA55AAAAFFFF00FF00FF00FFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5500AAAA5555FF005555000000555500FF5555AAAA0055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000005500FF00FFFFAAFFFF00FF005500000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFF000055AA5500FF55FF0055AA550000FFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF5500AA55FFFF00AAAAAA00FFFF55AA0055FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000055FF0000000000FF55000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF00FF5555555555FF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5500AAAAAAAAAAAAAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000AA00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFF00AA00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5500AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.57603 0.782187 0.66334 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00AA55005555AA005500AAFFFFFF00000055FFAA55555500005555AAFF55AAFFFF5555
55AAFFAAAA0055FF55AA5500FF55FF55FF0055AA55FF5500AAAAFFAA555555FFFFAA55FF
AA55550000555555AAFF55000000FFFFFFAA005500AA55550055AA00FF
FFFFAAAAAA55FFAAAA5555FFFFFFFFFFAA00FFFFFF55AAFF5555FF00550055FFFFFFFF00
55FFFFFF55FF550055FFFF00AA555555AA00FFFF550055FF55FFFFFF5500FFFFFFFF5500
5500FF5555FFAA55FFFFFF00AAFFFFFFFFFF5555AAAAFF55AAAAAAFFFF
FFFFFF55FFFF00005500FFFFFFFFFFFFFF5555550055FFFFFF0055AAAAAA555555555555
FF0000AA555555AAAA0000FFAAAA00AAAAFF0000AAAA555555AA0000FF555555555555AA
AAAA5500FFFFFF5500555555FFFFFFFFFFFFFF00550000FFFF55FFFFFF
FFFFFFFF0000FFAAFF55555555555500AA55FFAA55AA55005555FFAAAAFFAA5555AA5555
AA00FFAAAAAAAAAAFFAAFFFFFF55FF55FFFFFFAAFFAAAAAAAAAAFF00AA5555AA5555AAFF
AAAAFF55550055AA55AAFF55AA00555555555555FFAAFF0000FFFFFFFF
FFFFFFFFFFAA00005555AA5555AA5555FFFF000055FFFF00AAAA000055005500FFFF55AA
FFAA000055000055005500AA5500FF0055AA005500550000550000AAFFAA55FFFF005500
550000AAAA00FFFF550000FFFF5555AA5555AA55550000AAFFFFFFFFFF
FFFFFFFFFFFF5555FF005500FF55FF00555555FF55005555FFFF5555FFAAFF55550055FF
FFFF5555FF00AAFF5555AAAAFF555555FFAAAA5555FFAA00FF5555FFFFFF55005555FFAA
FF5555FFFF55550055FF55555500FF55FF005500FF5555FFFFFFFFFFFF
FFFFFFFFFFFFFF005555FF00AA00AA55AA5555AA00AAFF55005555AA550000AAAA00FFFF
FFFFFF005555FFFFFF00550000AAAAAA00005500FFFFFF555500FFFFFFFFFF00AAAA0000
55AA55550055FFAA00AA5555AA55AA00AA00FF555500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA555555FFFFAAAAAAFF550000005555AAAAAAAAFF5555FFFF555555
0055AA00FF5500555555FFAAFFFF55FFFFAAFF5555550055FF00AA5500555555FFFF5555
FFAAAAAAAA555500000055FFAAAAAAFFFF555555AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5500FFFFFFFF55FFFFFF00AAFFFF00550000550055FF0000AAAAAA
00FFFF555555AAAAAAAA00550055AA55005500AAAAAAAA555555FFFF00AAAAAA0000FF55
005500005500FFFFAA00FFFFFF55FFFFFFFF0055FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00AA55005555AA005555FFFFFFFFAA55AAAAAA555555FF55FFFF
55555555AA55FFFF55FFFFAA55AAFFAA55AAFFFF55FFFF55AA55555555FFFF55FF555555
AAAAAA55AAFFFFFFFF555500AA55550055AA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAAA55FFAAAA55FF0000AA000055FFFF55FF00FFFFFF0000
FF5500FFFF55005555AA000055FFFFFF550000AA55550055FFFF0055FF0000FFFFFF00FF
55FFFF550000AA0000FF55AAAAFF55AAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55FFFF00005500FF00AAFFAA00FFFFFFFF000000FF000000
00AAAA550055FF55AAFFAA00FFFFFFFFFF00AAFFAA55FF550055AAAA00000000FF000000
FFFFFFFF00AAFFAA00FF00550000FFFF55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFAAFF555555FFFFFF555555555555FF555555FF55
55FFFF55AAAA0055FFFFFF55555555555555FFFFFF5500AAAA55FFFF5555FF555555FF55
5555555555FFFFFF555555FFAAFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00005555AA555500AA55FF00FFFF005555AA555555
AA550055FFFF5555AA0000AAAAAA00AAAAAA0000AA5555FFFF550055AA555555AA555500
FFFF00FF55AA005555AA55550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF005500FFFFAAAA000000AA55AAFF55FF00FF
FF55AAAA0000FF550000000055000000550000000055FF0000AAAA55FFFF00FF55FFAA55
AA000000AAAAFFFF005500FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555FF00AA0055000000000055FFFFFF000000
FF005500000000FFFFAAFF00AAAA55AAAA00FFAAFFFF000000005500FF000000FFFFFF55
00000000005500AA00FF555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555555FFFFAA55AAAA55AAAA00555555FF55
5555FF00AAFF00AA005500AAFFAAAAAAFFAA005500AA00FFAA00FF555555FF55555500AA
AA55AAAA55AAFFFF555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFFFFFFF55000055FFFF5555AA555555
AA555555FFFFFFAAAA5555FFFFFF55FFFFFF5555AAAAFFFFFF555555AA555555AA5555FF
FF55000055FFFFFFFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55005555AAAA55555500FF55FF00FF
55FFAA55555555000055FF0000AA00AA0000FF55000055555555AAFF55FF00FF55FF0055
5555AAAA55550055AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55FFAAAAFF55AAFFFFFF000000
FFFFFF5500FF55AAAA555555FF55FF55FF555555AAAA55FF0055FFFFFF000000FFFFFFAA
55FFAAAAFF55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFF0000550055FFFFFFFFFFAAFF
FFFFFFFF00AA55FFFF55AA555500FF005555AA55FFFF55AA00FFFFFFFFFFAAFFFFFFFFFF
5500550000FFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFAAFF5555AA005555005500
5555555555FFFF0000FFFF55AAFFFFFFAA55FFFF0000FFFF5555555555005500555500AA
5555FFAAFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00005555AAFFAAFF55AAAAAA
55FF00FF550055AAAA550055FFFFFFFFFF550055AAAA550055FF00FF55AAAAAA55FFAAFF
AA55550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF005500550055FFFF55
FF000000AAAA55FFFF55AAAA0000FF0000AAAA55FFFF55AAAA000000FF55FFFF55005500
5500FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555FF00AAAA55555500
FF00AAFFFF55FF0000FFFF55FF555555FF55FFFF0000FF55FFFFAA00FF00555555AAAA00
FF555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555555FFFF5500FF55
5555FFFFFFFF00000000AA555555AA555555AA00000000FFFFFFFF555555FF0055FFFF55
5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFFFFFFF00AA55
FFAA5500555555FF5555FFFF00FF55FF00FFFF5555FF5555550055AAFF55AA00FFFFFFFF
0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55005555FFFF
000055FF5500FFFFFF0055AA00FF00FF00AA5500FFFFFF0055FF550000FFFF55550055AA
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55FF0000
AAFF0055AA55AA0055AAAAAAFF000000FFAAAAAA5500AA55AA5500FFAA0000FF55AAAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFF000000
005555FFAAAAAAFF005500005555FF555500005500FFAAAAAAFF555500000000FFFF55FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFAAFF
00AAAA0055000055AAAAAA55AA555555AA55AAAAAA5500005500AAAA00FFAAFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000055
55FFFF5555AAAA55FFFF55FFAAAA00AAAAFF55FFFF55AAAA5555FFFF55550000AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF
00555555AAFFAAAA0000FFFFFF55FF55FFFFFF0000AAAAFFAA55555500FF5555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055
55FF0055FFFFFF55FF5555555500FF0055555555FF55FFFFFF5500FF555500FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
555555FF0000AA00AA00AAAAAA00FF00AAAAAA00AA00AA0000FF555555AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
5500FFFFFFAAFFAAFFAAFFAAAAFFFFFFAAAAFFAAFFAAFFAAFFFFFF0055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00AA5500550055005500550000FF0000550055005500550055AA00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAAA5555FF00AAAA55FF555555FF55AAAA00FF5555AAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55FFFF005555FFFF5500AAAAAA0055FFFF555500FFFF55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFAA55555555AAAAFFAAAA55555555AAFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA000055FF00FF55FFFFFF55FF00FF550000AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF5555FF000000FFFFFFFFFF000000FF5555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF005555FF55555500555555FF555500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA555555AA55FF55AA555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5500FFFF550055FFFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00AA0055FF5500AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA555555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55FF00FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.57603 0.97619 0.66334 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FF00FF00FF5555FFFFAA55FFFFAA00FF55FFAAFFFF55555555FFFFFFFFAA0000FF
55AA5500AAFF555555AA00AAAAFFAAFFAAAA00AA555555FFAA0055AA55FF0000AAFFFFFF
FF55555555FFFFAAFF55FF00AAFFFF55AAFFFF5555FF00FF00FF0000FF
FFFF00FFAA55AAFF0000FFAA0000FF55005500FF005555FF00000000FF5500FF55FFAA55
AA0000FFFF55555555550000AA00AA00AA00005555555555FFFF0000AA55AAFF55FF0055
FF00000000FF555500FF00550055FF0000AAFF0000FFAA55AAFF00FFFF
FFFFFF0055555500FFFFAA00005500FF00FF00FF55AA0055FFAAFFFFAA005500FF005555
55000055FF00000000000055005500550055000000000000FF55000055555500FF005500
AAFFFFAAFF5500AA55FF00FF00FF00550000AAFFFF0055555500FFFFFF
FFFFFFFF0000FF00FF5555000055AAFF00FFAA5555550000FFAAAA55550000FFFFFF0000
00005500AAFFFF00FFFF00FF00FF00FF00FF00FFFF00FFFFAA005500000000FFFFFF0000
5555AAAAFF0000555555AAFF00FFAA5500005555FF00FF0000FFFFFFFF
FFFFFFFFFF00FFAA55AA0055000000AAAAAA00000000FFFF00AA0000FF00FFFFFFFFFF00
FFFF00005555AAAAAA55AAFF00FFAAFF00FFAA55AAAAAA55550000FFFF00FFFFFFFFFF00
FF0000AA00FFFF00000000AAAAAA0000005500AA55AAFF00FFFFFFFFFF
FFFFFFFFFFFF005555550000FFFFAAFFAAAAFFFFAAFF5555AAFFAAFFFFFFAA00FFAA00FF
FFFFFF00FF0000AA000000AAFF550055FFAA000000AA0000FF00FFFFFFFF00AAFF00AAFF
FFFFAAFFAA5555FFAAFFFFAAAAFFAAFFFF000055555500FFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF00FFFFFFFF55005555AAAAFF000000AAFFAA00AAAAFFFFFF55AA
5555FF00FF55AAFFAAFFFFAAAA005500AAAAFFFFAAFFAA55FF00FF5555AA55FFFFFFAAAA
00AAFFAA000000FFAAAA55550055FFFFFFFF00FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFAA55AAAA00FF00FF0000AA00FFFFAAFFAA0000555500FFAA0055
555555AAFF0000AAAAFF005555000000555500FFAAAA0000FFAA5555555500AAFF005555
0000AAFFAAFFFF00AA0000FF00FF00AAAA55AAFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00555555005500FFFFFFAAFFAAFF005555FFFF00FF000055FFFF00
00FF0000AAFFFFAAAAFF00FF0000550000FF00FFAAAAFFFFAA0000FF0000FFFF550000FF
00FFFF555500FFAAFFAAFFFFFF00550055555500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF00FF00FF5555FFFFFF550000FF00AAFFFFFF00FF0055FF
AA55AAFF55FF00555500FFFFFF00FF00FFFFFF00555500FF55FFAA55AAFF5500FF00FFFF
FFAA00FF000055FFFFFF5555FF00FF00FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFAA55AAFF0000FFAA00FF00FFFFFFAAAA00FFAAFF00FF00
55555500FF005500AA55FF00AAFFFFFFAA00FF55AA005500FF0055555500FF00FFAAFF00
AAAAFFFFFF00FF00AAFF0000FFAA55AAFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055555500FFFFAA000055FFAA00FFAAAAFF555500FFFFFF
000000FFFFFF0000555555AAFFAA00AAFFAA5555550000FFFFFF000000FFFFFF005555FF
AAAAFF00AAFF550000AAFFFF0055555500FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF5555000055AAAAFFFFFF55FF0000FFFFFFFF
FFAAFFFFFFFFFF00FF000000AAFFAAFFAA000000FF00FFFFFFFFFFAAFFFFFFFFFF0000FF
55FFFFFFAAAA5500005555FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA55AA0055000000AA00FF555555FFAA55AA5555
FF55FF00AAAA00FFFFFF00FFFF550055FFFF00FFFFFF00AAAA00FF55FF5555AA55AAFF55
5555FF00AA0000005500AA55AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555550000FFFFAAFFAAFF0000FF0055555500AA
555555FFAAAAFFFFFFFFFFAA00FF00FF00AAFFFFFFFFFFAAAAFF555555AA0055555500FF
0000FFAAFFAAFFFF000055555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF550055FFAAFF00FF00000055
55555555FFFF5555FF5555FFFF005500FFFF5555FF5555FFFF5555555555000000FF00FF
AAFF550055FFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA55AAAA00FF00FF005555AAFF00FFFF00
00FF0000FF5500AA55AA0055FF00FF00FF5500AA55AA0055FF0000FF0000FFFF00FFAA55
5500FF00FF00AAAA55AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555005500FFFFFF000000AAFF5555AA
FFFFFFAAFF00005555550000FFAA55AAFF00005555550000FFAAFFFFFFAA5555FFAA0000
00FFFFFF00550055555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF5555FFAAFF55FF000000
AAAA00AA00FFFF000000FFFF0055555500FFFF000000FFFF00AA00AAAA000000FF55FFAA
FF5555FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA55AAFF0000FFAAAA5500FFFFAA
FFAAAAAAFFFFFFFF00FFFFFFFF000000FFFFFFFF00FFFFFFFFAAAAAAFFAAFFFF0055AAAA
FF0000FFAA55AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055555500FFFFAA0000AA55FF00AA
00AA0000AAAA00AAFFFFFFFFFFFFAAFFFFFFFFFFFFAA00AAAA0000AA00AA00FF55AA0000
AAFFFF0055555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF55550000555555FFAA
AAAAFFFFAAAAFF55FF00AAAA00FF55FF00AAAA00FF55FFAAAAFFFFAAAAAAFF5555550000
5555FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA55AA005500000000FF55
FFFF5555FFFF555555FFAAAAFF555555FFAAAAFF555555FFFF5555FFFF55FF0000000055
00AA55AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555550000FFFFAAFF5555
55FF0000FF5555555555FFFF5555555555FFFF5555555555FF0000FF555555FFAAFFFF00
0055555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFF555555
5555FFAAFF0000000000FF55555555555555FF0000000000FFAAFF5555555555FFFFFFFF
00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA55AAAA00FF0000
0000FF55FF00FFFFAAFF555555555555555555FFAAFFFF00FF55FF00000000FF00AAAA55
AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555005500FFFF
AAFF555555AAFF00AA00FF000000FF000000FF00AA00FFAA555555FFAAFFFF0055005555
5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF55
5500FF000000AAAAAAFFFFFF00FFFFFF00FFFFFFAAAAAA000000FF005555FF00FF00FF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA55AAFF00
00FFFFFFAAFFFF55FFFFFFFFFFAA00AAFFFFFFFFFF55FFFFAAFFFFFF0000FFAA55AAFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055555500FF
FFAA00AAFFAA00FF00AAAA00FFAAAAAAFF00AAAA00FF00AAFFAA00AAFFFF0055555500FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF
55550000AAAAFFFFFFAAAAFFFFFF55FFFFFFAAAAFFFFFFAAAA00005555FF00FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA55
AA00550000AA00FF55005555FF555555FF55550055FF00AA00005500AA55AAFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555
550000FFFFAAAAAA005500AA5555555555AA005500AAAAAAFFFF000055555500FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00FFFFFFFF55FFFF0000555555555555550000FFFF55FFFFFFFF00FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFAA55AAAA00FF00AAFFFF000000FF000000FFFFAA00FF00AAAA55AAFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00555555005500FFFF5555FFAAFFFFFFAAFF5555FFFF00550055555500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF00FF00FF55555555FFFFFFFFFF55555555FF00FF00FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFAA55AAFF00000000FFAA00AAFF00000000FFAA55AAFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0055555500FFFFAAFF5500550055FFAAFFFF0055555500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FF00FF555500FF00FF00FF005555FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFAA55AA005500FFFFFF005500AA55AAFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF005555550000FFFFFFFFFF000055555500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFAA55AAAA00AAAA55AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0055555500550055555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFAA55AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.672071 0.200176 0.759381 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000AAAAAA5555FFFFFF55AAFFAA5500AAAAAA0055FFFFAA0055FF5555FFFF55FFAA55
55FF5500FF005555FF5555FFFFFFAAFFFFFF5555FF555500FF0055FF5555AAFF55FFFF55
55FF5500AAFFFF5500AAAAAA0055AAFFAA55FFFFFF5555AAAAAA0000FF
FFFFAAFFAAAAFF55AAAA55AA550000FFFFAAAAFFAAFF5555FFFFAA55AAFF5555FF00AA55
55AAAA00005555AA55AA5555FF555555FF5555AA55AA55550000AAAA5555AA00FF5555FF
AA55AAFFFF5555FFAAFFAAAAFFFF000055AA55AAAA55FFAAAAFFAAFFFF
FFFFFF55555555FF0000FF55FFAAFFFFFFFF55FF55FF55AAFF00AA555555FF00FFAAFFAA
555555550055FFAAAAAAFF55AAAAAAAAAA55FFAAAAAAFF550055555555AAFFAAFF00FF55
5555AA00FFAA55FF55FF55FFFFFFFFAAFF55FF0000FF55555555FFFFFF
FFFFFFFF0055FFAA00000055FF55FF5555FF55AAAA00FFFF555500AAAA00AAFFFFFF5555
55AA55FFAAFF5555555555FFAAAAFFAAAAFF5555555555FFAAFF55AA555555FFFFFFAA00
AAAA005555FFFF00AAAA55FF5555FF55FF55000000AAFF5500FFFFFFFF
FFFFFFFFFFAA55AA000000AAAA55FF55AAFF00FF0000AAFF00FFFFAAAAFFFF5555FF55AA
555555AAAAFF0055FFAA55FF55FFFFFF55FF55AAFF5500FFAAAA555555AA55FF5555FFFF
AAAAFFFF00FFAA0000FF00FFAA55FF55AAAA000000AA55AAFFFFFFFFFF
FFFFFFFFFFFF55AA0000AA0055AA55AA55000000555500AAFFFFFFFF55FF5555AA55AAFF
AA55FF0000FFAAFF555555AAAAAA55AAAAAA555555FFAAFF0000FF55AAFFAA55AA5555FF
55FFFFFFFFAA00555500000055AA55AA5500AA0000AA55FFFFFFFFFFFF
FFFFFFFFFFFFFF0000AA005555AA00AA5555005555AAFFFF5555FF5555AAAA00AA55FFFF
FF550000000055AAAAAAAAAAFFAAAAAAFFAAAAAAAAAA550000000055FFFFFF55AA00AAAA
5555FF5555FFFFAA5555005555AA00AA555500AA0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFAAFF5500AA0055FFAAFF55AA00FFAA5555FF00FF0000AA55FF55
55FFAAFFFFAAFF55FFFF55FFFFFF55FFFFFF55FFFF55FFAAFFFFAAFF5555FF55AA0000FF
00FF5555AAFF00AA55FFAAFF5500AA0055FFAAFFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555555FFAAFFAAFF555555FF00000055AAFF5555000000AA55FF55
AA55AA00FFAAAA55FF5555AAAA55AA55AAAA5555FF55AAAAFF00AA55AA55FF55AA000000
5555FFAA55000000FF555555FFAAFFAAFF555555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055FF55FF55FF5500FF5555005555AA00FF5500555500AAAA55
5555AA000055AA00AAFF5500AA555555AA0055FFAA00AA550000AA555555AAAA00555500
55FF00AA5555005555FF0055FF55FF55FF5500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55AA55AA55AAFFFFFF005555AAFFAAFF005555AAFFFF55FF
AA5555550055FFFFAAAA555500AAAAAA005555AAAAFFFF5500555555AAFF55FFFFAA5555
00FFAAFFAA555500FFFFFFAA55AA55AA55AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AA00AA55FFFFFFFFFFAA555555FFFFFFAA555555FF55AA
AAFF55AAFFFF00AAFFAAAAAA0000FF0000AAAAAAFFAA00FFFFAA55FFAAAA55FF555555AA
FFFFFF555555AAFFFFFFFFFF55AA00AA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000AA5555FF5555FF55FFAA5555FF555555AA5555FFAA
AAFF00FF00AAFFFF55555555550055005555555555FFFFAA00FF00FFAAAAFF5555AA5555
55FF5555AAFF55FF5555FF5555AA0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA55FF55AA55AA55AA00AAAA5555AAFFAA5555FF
FF55550000AA55AAAAAAAAAA00AA00AA00AAAAAAAAAA55AA00005555FFFF5555AAFFAA55
55AAAA00AA55AA55AA55FF55AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555AAAAAAFF55FF000000FF00FFFF555555AA55
AAAAAA0000AA5555555555555500AA0055555555555555AA0000AAAAAA55AA555555FFFF
00FF000000FF55FFAAAAAA555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFF55FF5500000000005555FF5500FF55FF
AAAAFFAAFFFF55AA5555AA55FFAAFFAAFF55AA5555AA55FFFFAAFFAAAAFF55FF0055FF55
55000000000055FF55FFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAA00FFFFAAFFFFAAFF55AAAA000055FF
55FFFFFF5555FFAAAA00AA55FF55FF55FF55AA00AAAAFF5555FFFFFF55FF550000AAAA55
FFAAFFFFAAFFFF00AAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA005555FF55FF555555FFAAAAFFFFAA55
AA55AAAA5555AAAAFFAAFFAA55AA55AA55AAFFAAFFAAAA5555AAAA55AA55AAFFFFAAAAFF
555555FF55FF555500AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AAAAAA5555FFAA55FF55FFFFFFFF55
00AAAAFFAA55555555FFFFFF55AA00AA55FFFFFF55555555AAFFAAAA0055FFFFFFFF55FF
55AAFF5555AAAAAA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAAAFF55AAAAFF5555AAAA55AAAA
0000FF00AA5555AA55FF5555FF000000FF5555FF55AA5555AA00FF0000AAAA55AAAA5555
FFAAAA55FFAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555FF0000FFAA55FFFF55AA00
55550000AA55FFAAAAAA55FFAA000000AAFF55AAAAAAFF55AA0000555500AA55FFFF55AA
FF0000FF55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFAA00000055AA55AAAA0055
55AAFFFFAAAAAA5500AA5555FFFFAAFFFF5555AA0055AAAAAAFFFFAA555500AAAA55AA55
000000AAFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA000000AAAAFF55FFFFAA
555555FF55FFFF550055AA55FF555555FF55AA550055FFFF55FF555555AAFFFF55FFAAAA
000000AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA0000AA0055AAAA00FFAA
AAAAAAAA5555FF550055FFFF00AAAAAA00FFFF550055FF5555AAAAAAAAAAFF00AAAA5500
AA0000AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA005555AA005555FF
FF55FFFF55AA55AAFFFF00AAFFFF55FFFFAA00FFFFAA55AA55FFFF55FFFF555500AA5555
00AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAFF5500AA00AAAA
55AA55AAAAAAFF55FF555500AAFF00FFAA005555FF55FFAAAAAA55AA55AAAA00AA0055FF
AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFAAFFAAFFAA
AA0055FFFF55FF55AAAA00AA0055005500AA00AAAA55FF55FFFF5500AAAAFFAAFFAAFF55
5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF55FF55FF55
FFFFAA55AAAAAA5555555500AA00AA00AA0055555555AAAAAA55AAFFFF55FF55FF55FF55
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA55AA55AA
FF00AA5555555555AA55FFAAFFAAFFAAFFAAFF55AA5555555555AA00FFAA55AA55AA55AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00AA55FF
FFFFAAAAAAAAAAAA0055FF55FF55FF55FF55FF5500AAAAAAAAAAAAFFFFFF55AA00AA55FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA5555
FF555555555555555500FFAA55AA55AA55AAFF005555555555555555FF5555AA0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA55
FF55AA5555AAFF55AAFFFFFF55AA00AA55FFFFFFAA55FFAA5555AA55FF55AAFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555
AAAAAAFF5500AAFF55FF5555FF000000FF5555FF55FFAA0055FFAAAAAA555555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055
FFFF55FF550055AAAAAA55FFAA000000AAFF55AAAAAA550055FF55FFFF5500FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
55AAAA00FFFFAA5500AA5555FFFFAAFFFF5555AA0055AAFFFF00AAAA55AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
55AA005555FF55FFAAFFAA55FF555555FF55AAFFAAFF55FF555500AA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000AAAAAA5555FFFFFF55AAAA00AAAA55FFFFFF5555AAAAAA0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFAAAAFF55AAAA55AA5500AA0055AA55AAAA55FFAAAAFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55555555FF0000FF55FFAAFFAAFF55FF0000FF55555555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0055FFAA00000055FF55FF55FF55000000AAFF5500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA55AA000000AAAA55FF55AAAA000000AA55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF55AA0000AA0055AA55AA5500AA0000AA55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000AA005555AA00AA555500AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFAAFF5500AA0055FFAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555555FFAAFFAAFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055FF55FF55FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55AA55AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AA00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.672071 0.39418 0.759381 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00AA00FF0000FF00FF00FFFFAAAAAA55AAAAFF555555FF00FFFFFFFFFF555555FF55AA
FFFF00000000FF55FF00AAFF00AAFFAA00FFAA00FF55FF00000000FFFFAA55FF555555FF
FFFFFFFF00FF555555FFAAAA55AAAAAAFFFF00FF00FF0000FF00AA00FF
FFFFAAAA005555AAAA00555555FFFF55FFAAAAFF00FFFF0000AAFF00AA55AAFF55AAAAAA
FF0000AA0000AA55FF550000FF55FF55FF000055FF55AA0000AA0000FFAAAAAA55FFAA55
AA00FFAA0000FFFF00FFAAAAFF55FFFF55555500AAAA555500AAAAFFFF
FFFFFF55FF00FFFF55FF00FFFF0000FFFFFF55FF5500AA55550000FF55FFAAAA55FFFF55
FF5500550055FFFF000000AA00FFFFFF00AA000000FFFF5500550055FF55FFFF55AAAAFF
55FF00005555AA0055FF55FFFFFF0000FFFF00FF55FFFF00FF55FFFFFF
FFFFFFFF00AA00FF00FFAAFF00AAAA00FF000000FFFFAAAAAAAA00AA55FF55FFFF00AA55
FF55AA55FF00FF0000AA000055555555550000AA0000FF00FF55AA55FF55AA00FFFF55FF
55AA00AAAAAAAAFFFF000000FF00AAAA00FFAAFF00FF00AA00FFFFFFFF
FFFFFFFFFFAAAA005555FFFFFFAAAAFFFFFFAAFFFFFFFF55FFFF55000000FFFFFFFFAAAA
AA55FFFF00AA0055550000AAAAAAAAAAAAAA0000555500AA00FFFF55AAAAAAFFFFFFFF00
000055FFFF55FFFFFFFFAAFFFFFFAAAAFFFFFF555500AAAAFFFFFFFFFF
FFFFFFFFFFFF55FF00FFFFFFFFFF55FF5555FFFFFFFFFFFF00AAFF550055FF555555FFFF
55FFAA00FF55FF00FFFFAAFFAAAAFFAAAAFFAAFFFF00FF55FF00AAFF55FFFF555555FF55
0055FFAA00FFFFFFFFFFFF5555FF55FFFFFFFFFF00FF55FFFFFFFFFFFF
FFFFFFFFFFFFFF00AA00FF0000FF00FF00FFFFFFFFFFFFFFFFAAAA55FF00FF00FFFF00AA
55FF55FF000000FF5555FFFFFF55FF55FFFFFF5555FF000000FF55FF55AA00FFFF00FF00
FF55AAAAFFFFFFFFFFFFFFFF00FF00FF0000FF00AA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA005555AAAA00555555555555555555FFFF55AA00AA5555FF5500
0000FFFFFFAAFFFFFF00FF0000FFFFFF0000FF00FFFFFFAAFFFFFF00000055FF5555AA00
AA55FFFF55555555555555555500AAAA555500AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55FF00FFFF55FF00FFFF00FFFF00FFFF0000FFFF5500000000FFFF
AAFFFFFFFFFF555555FF00AAAA00FF00AAAA00FF555555FFFFFFFFFFAAFFFF0000000055
FFFF0000FFFF00FFFF00FFFF00FF55FFFF00FF55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00AA00FF00FFAAFF00AA00FFAAFF00AA0000FF00FF5500FF5555
FFFFFFFFFFFFFF00FFFFFFAAAAFFFFFFAAAAFFFFFF00FFFFFFFFFFFFFF5555FF0055FF00
FF0000AA00FFAAFF00AA00FFAAFF00FF00AA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA005555FFFFFFAAAA005500AAAAFFFFAA00AA55FF000000
00FF00AAFF00AA555555FF55FFFFFFFFFF55FF555555AA00FFAA00FF00000000FF55AA00
AAFFFFAAAA005500AAAAFFFFFF555500AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55FF00FFFFFFFFFF55FF00FF55FFFFFFFF55000000FF5500
55FF550000FF55FFAA55FF55AA00FF00AA55FF55AAFF55FF000055FF550055FF00000055
FFFFFFFF55FF00FF55FFFFFFFFFF00FF55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00AA00FF0000FF00FFAAFF00FF0000FF00FF5500FF00FF
55AAAAAA0000FFFFFF55AAAAAAFFFFFFAAAAAA55FFFFFF0000AAAAAA55FF00FF0055FF00
FF0000FF00FFAAFF00FF0000FF00AA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA005555AAAA005500AAAA555500AAAA55FF0000AA
FF55FFFF5500FF0000FFFF55FFFFFFFFFF55FFFF0000FF0055FFFF55FFAA0000FF55AAAA
005555AAAA005500AAAA555500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00FFFF55FF00FF55FFFF00FF55FFFF00AA0000
55AAFF000000AA5555AA00FFFFFFFFFFFFFF00AA5555AA000000FFAA550000AA00FFFF55
FF00FFFF55FF00FF55FFFF00FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00FF00FFAAFF00FF00AA00FFFFFFFFAAAA00
000055AA555500000000555555555555555555000000005555AA55000000AAAAFFFFFFFF
00AA00FF00FFAAFF00FF00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA005555FFFFFFAA00005555FF5555FFFF55
0055FFAAAAAAAA0000AAAAAAAAAAAAAAAAAAAAAA0000AAAAAAAAFF550055FFFF5555FF55
550000AAFFFFFF555500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00FFFFFFFFFF5500FFFF00000000FF00
FF55AAAAFFAAAAFFFFAAAAFFAAAAFFAAAAFFAAAAFFFFAAAAFFAAAA55FF00FF00000000FF
FF0055FFFFFFFFFF00FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00FF0000FF00FF5555FF005555AAAA
00FFFF55FF55FFFFFFFF55FF55FFFFFF55FF55FFFFFFFF55FF55FFFF00AAAA555500FF55
55FF00FF0000FF00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA005555AAAA00FFFF00AAAAAAAAFF
AAFF000000FFFFFFFFFFFF000000FF000000FFFFFFFFFFFF000000FFAAFFAAAAAAAA00FF
FF00AAAA555500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00FFFF55FF0000FF55FFFF55FF
55FF5500FF555555FF5555FF0055FF5500FF5555FF555555FF0055FF55FF55FFFF55FF00
00FF55FFFF00FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00FF00FFAAFFFFFF00AA55FF
55AAAAAA00FFFF00FF00FFFFFFAA55AAFFFFFF00FF00FFFF00AAAAAA55FF55AA00FFFFFF
AAFF00FF00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA005555FFFFFFFFFFAAAAAA
55FFFF55FF0000FF555500AA5500000055AA005555FF0000FF55FFFF55AAAAAAFFFFFFFF
FF555500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00FFFFFFFFFFFFFF55FF
FF00AA55FF5500FF00FFFFAAAAAA00AAAAAAFFFF00FF0055FF55AA00FFFF55FFFFFFFFFF
FFFF00FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00FF0000FFAA00FFFF
FFFFAAAAAA55FF00AA00FFAAAAFFAAFFAAAAFF00AA00FF55AAAAAAFFFFFFFF00AAFF0000
FF00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA005555AAAAFFFFFF
FFFFFF55FFFF00AAAAFFFFFF55FF55FF55FFFFFFAAAA00FFFF55FFFFFFFFFFFFAAAA5555
00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00FFFF55FF5555
FF5555FFAA00FF55FFFFFFFFFF000000FFFFFFFFFF55FF00AAFF5555FF5555FF55FFFF00
FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00FF00FF00FF
FFFF00FFAAAA00FFFFFFFFFFFFFFAAFFFFFFFFFFFFFF00AAAAFF00FFFFFF00FF00FF00AA
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA005555FF00
AA55AA55000055555555FF5555FF55FF5555FF55555555000055AA55AA00FF555500AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00FFFFFF
AAAAAAFF5500FFFF00FFFFFF00FF00FF00FFFFFF00FFFF0055FFAAAAAAFFFFFF00FF55FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00FF00
00550000FFFFAA0055FF5555FF00AA00FF5555FF5500AAFFFF0000550000FF00AA00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055
55AAFFFFAA005500FFFFFF00FF005500FF00FFFFFF005500AAFFFFAA555500AAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00
FFFF5555FFFFAA5555FF5555AA000000AA5555FF5555AAFFFF5555FFFF00FF55FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA
00FF00FFFFFFFF55AAFF00FFFF550055FFFF00FFAA55FFFFFFFF00FF00AA00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AA005555555555FFAAAA555555FFAAFF555555AAAAFF555555555500AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
55FF00FFFF00FFFFFF55FFAA55FF55FF55AAFF55FFFFFF00FFFF00FF55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00AA00FFAAFF0000FFFFFF55AAAAAA55FFFFFF0000FFAAFF00AA00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAA005500AAAA00FF00000055000000FF00AAAA005500AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55FF00FF55FFFFAA00AA000000AA00AAFFFF55FF00FF55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00AA00FFFFFFFF550000AA000055FFFFFFFF00AA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAA00FFAA00FFFFAAFFAAFFFF00AAFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF55FF00005555FF55FF55FF55550000FF55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00AA00000000FFFFFF00000000AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA0000AAAA55AAAA0000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55FF00550000005500FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00AAAAAA00AAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFFAAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55FF55FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.672071 0.588183 0.759381 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00000000005500000055FF0000FF5500AA55AA00000000000000AAAA55AA0000AAAAAA
AAAA0000AA00FF555555AA5500AA55AA0055AA555555FF00AA0000AAAAAAAAAA0000AA55
AAAA00000000000000AA55AA0055FF0000FF55000000550000000000FF
FFFFAAFFFFAAFF5500AAAAAA5555AAAAAA000000AA55555555555555000000AA55000055
0000AAAA0000FFAA55FFAAAAAA000000AAAAAAFF55AAFF0000AAAA000055000055AA0000
0055555555555555AA000000AAAAAA5555AAAAAA0055FFAAFFFFAAFFFF
FFFFFF5555FFFFFF0000AA00000000555500AAAA000000000000000000FF55000000FF00
FF0000AA0055FF55FFAA000055555555550000AAFF55FF5500AA0000FF00FF00000055FF
000000000000000000AAAA00555500000000AA0000FFFFFF5555FFFFFF
FFFFFFFF00FFAA00FF550000FF5500FFFF0000AA00AA55555555555555AAAAAA0055AAAA
00FF005500FFFFFF00AA00AAAAAAAAAAAAAA00AA00FFFFFF005500FF00AAAA5500AAAAAA
55555555555555AA00AA0000FFFF0055FF000055FF00AAFF00FFFFFFFF
FFFFFFFFFFAA0000FFAA5555AAAAAA00FFAAFFFF55000000000000000000AA0000FFFF55
FF00AAAAAA00FFAA005500AA0000AA0000AA005500AAFF00AAAAAA00FF55FFFF0000AA00
000000000000000055FFFFAAFF00AAAAAA5555AAFF0000AAFFFFFFFFFF
FFFFFFFFFFFF5500AAFFAA55FFFF55FF00AA00FFAA5555555555555555555500AA55AAAA
AA550000555555FFFFAA550000FF55FF000055AAFFFF555555000055AAAAAA55AA005555
5555555555555555AAFF00AA00FF55FFFF55AAFFAA0055FFFFFFFFFFFF
FFFFFFFFFFFFFF0000AAFFAA55AAAAAA550000FFAAAAAAAAAAAAAAAAAAAAAAAA000000AA
000000FF00FFFF00AAFFAA5555AAAAAA5555AAFFAA00FFFF00FF000000AA000000AAAAAA
AAAAAAAAAAAAAAAAAAFF000055AAAAAA55AAFFAA0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFAA000000AA000000FF5555005555000055000055550000FF0000
AA5555AAAA00FFAAFFAA00000000AA00000000AAFFAAFF00AAAA5555AA0000FF00005555
00005500005555005555FF000000AA000000AAFFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555500FF005500AAAA00FFFF00000000FF00FF00000000FF00AAAA
00000000555555FFFFFF5500FF005500FF0055FFFFFF55555500000000AAAA00FF000000
00FF00FF00000000FFFF00AAAA005500FF005555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00AAAAAA0000AAAA55AA0055FF00AAAA55555555AAAA0000
AA5500AAAAAAAAAA55AAAAAA00FF00FF00AAAAAA55AAAAAAAAAA0055AA0000AAAA555555
55AAAA00FF5500AA55AAAA0000AAAAAA00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00AA0000AA5555000000AAAAAA5555000000000000AA0055
FFFF00550000AA000000AA0000FFAAFF0000AA000000AA00005500FFFF5500AA00000000
00005555AAAAAA0000005555AA0000AA00AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF550055AA00000000FF0000AA00000000FF0055FF005555AA
FF00AAAAAA00555555555500FF00AA00FF00555555555500AAAAAA00FFAA555500FF5500
FF00000000AA0000FF00000000AA550055FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000AA5500AA55AA005500FF5500AAFFFF00AAAAAAAA
FF00550000AAAAAAAAAAAAAA00FF55FF00AAAAAAAAAAAAAA00005500FFAAAAAAAA00FFFF
AA0055FF005500AA55AA0055AA000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55AA00000055AAFFFFFF0000AAFF00550000AA
00FF00FF000055005555005555AAAAAA555500555500550000FF00FF00AA00005500FFAA
0000FFFFFFAA55000000AA55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFAAAA0055FFAAAA55AAAA00AA00FF00FF5500
55AAAA00FF000000FFFF000000005500000000FFFF000000FF00AAAA550055FF00FF00AA
00AAAA55AAAAFF5500AAAAFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAAAFFFF00AA000000AA005500AAFFFFFF00
00005555AAAA00AAAA55AA5500AAAAAA0055AA55AAAA00AAAA5555000000FFFFFFAA0055
00AA000000AA00FFFFAAAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AAFF000055AA005500FFFFAAAA55AAAA
00AAAAAAAAFFAAFFAAAAAAFF5500550055FFAAAAAAFFAAFFAAAAAAAA00AAAA55AAAAFFFF
005500AA550000FFAA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA00FF00000055FFAAFF00AA000000AA
00AA00005555FFFFFF55FFFFFF000000FFFFFF55FFFFFF55550000AA00AA000000AA00FF
AAFF55000000FF00AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AAAA5500FF00FFAAAA550000FF0055
555500AAAAAAAA55AAAAAA55AAAA00AAAA55AAAAAA55AAAAAAAA0055555500FF000055AA
AAFF00FF0055AAAA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAAAAA00FF5555000000FF00AAAA
AAAAAA0000AA000000AA000000AA00AA000000AA000000AA0000AAAAAAAAAA00FF000000
5555FF00AAAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555000055AAAAAAAA00AA55AA0000
AA0000AA555500FF005500FF0055555500FF005500FF005555AA0000AA0000AA55AA00AA
AAAAAA5500005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000AA0000AAAAFF55FF00
5500AAAAFF55AA00FF00FF00AAAAAAAAAA00FF00FF00AA55FFAAAA005500FF55FFAAAA00
00AA000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAAA0000FF55FFFFFF00AA
AAAA0000AAFF55FF00AAAA550000AA000055AAAA00FF55FFAA0000AAAAAA00FFFFFF55FF
0000AAAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500555555AAAAAA55AAAA00
005500AAAAFF00FFAAFFAAAAAA005500AAAAAAFFAAFF00FFAAAA00550000AAAA55AAAAAA
5555550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000550000005500
AAAAAA0000AAFFFFFF55550000AAAAAA00005555FFFFFFAA0000AAAAAA00550000005500
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAAFF5500AAAAAA
00005500AAAAFF00AAFF55AA5500550055AA55FFAA00FFAAAA00550000AAAAAA0055FFAA
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFFFFF0000AA00
00FF00FF55FFFFFFAAAA55FFFF000000FFFF55AAAAFFFFFF55FF00FF0000AA0000FFFFFF
5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA00FF550000
FF5555AAAAAA55AAAAFFAA55AAAA00AAAA55AAFFAAAA55AAAAAA5555FF000055FF00AAFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000FFAA5555
AAAAAAAAFFAAAAAAFFAA000000555555000000AAFFAAAAAAFFAAAAAAAA5555AAFF0000AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAFFAA55
FFFF55FFFFFF55FFFFFF5500AAAAAAAAAA0055FFFFFF55FFFFFF55FFFF55AAFFAA0055FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AAFFAA
55AAAAAA55AAAAAA55AAAAAA0000550000AAAAAA55AAAAAA55AAAAAA55AAFFAA0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA00
0000AA000000AA000000555500FF00FF005555000000AA000000AA000000AAFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500
FF005500AA550000FF00000000FFAAFF00000000FF000055AA005500FF005555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00AAAAAA000000FF00AA5500FF00AA00FF0055AA00FF000000AAAAAA00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
00AA0000AA5555AAAA000000FFAAFFAAFF000000AAAA5555AA0000AA00AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
550055AA000000005555555555FFFFFF555555555500000000AA550055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000AA5500AAAAAAAAAAAAAA55AAAAAAAAAAAAAA0055AA000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFF55AA0000AA000055000000550000AA0000AA55FFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5555FFAAAA00AA00AAAAAA00AAAAAA00AA00AAAAFF5555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFAAAAFFFF550000AA00AA000055FFFFAAAAFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA0000AAFF00FF0055555500FF00FFAA0000AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF5500AA00FF00AAAAAAAAAA00FF00AA0055FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000AAAA550000AA000055AAAA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFAAAAAA005500AAAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55550000AAAAAA00005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF0000550000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00AAAAAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5500550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.672071 0.782187 0.759381 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00AAAAAA0000555500550055AA555500AA5555AAAAAAAAAAAA5500005555555555AA55
55000000FF55AAAA5500FF00550000005500FF0055AAAA55FF0000005555AA5555555555
000055AAAAAAAAAAAA5555AA005555AA5500550055550000AAAAAA00FF
FFFFAAAAFF0000FFFF00000055FFFF00FF00AAAAAA55AAAAFFAAAA0055AA5555AA55FFFF
00FF00005555AAAA55555500000055000000555555AAAA55550000FF00FFFF55AA5555AA
5500AAAAFFAAAA55AAAAAA00FF00FFFF55000000FFFF0000FFAAAAFFFF
FFFFFF5555000055550000FF0055550000AA55AAAA5555FFFFFF555555AAAAAAAA555500
55005500AAAAAA55AA55FF0000FF00FF0000FF55AA55AAAAAA00550055005555AAAAAAAA
555555FFFFFF5555AAAA55AA0000555500FF0000555500005555FFFFFF
FFFFFFFF005500000000550055AA55555555FFAAAAFF5500555500FF55AAAA55AAAA00AA
555555AA00FFAAAAAA5555000055555500005555AAAAAAFF00AA555555AA00AAAA55AAAA
55FF0055550055FFAAAAFF55555555AA550055000000005500FFFFFFFF
FFFFFFFFFFAA550000FF0055AA55AA55FF005555FFFFFF000000005555AAAA5555FFFFAA
AAAAAAAAFFFFFF5555FF00FF0000000000FF00FF5555FFFFFFAAAAAAAAAAFFFF5555AAAA
555500000000FFFFFF555500FF55AA55AA5500FF000055AAFFFFFFFFFF
FFFFFFFFFFFF55AA00555555AAAAAA555500000000AA0000550000FF55AAAAFF55005555
FF5555FFFFFFFFFF00555555000055000055555500FFFFFFFFFF5555FF55550055FFAAAA
55FF0000550000AA000000005555AAAAAA55555500AA55FFFFFFFFFFFF
FFFFFFFFFFFFFF00AA5555AA55AAAAFF55000055AA00FF000000550055FF555500FF00FF
FFFF0055550055550000000000FF00FF0000000000555500555500FFFFFF00FF005555FF
550055000000FF00AA55000055FFAAAA55AA5555AA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAAAAA5555FFFFFF0000FF55555500005500FF005555AA55005500
555500000000FFFF00005500005555550000550000FFFF00000000555500550055AA5555
00FF00550000555555FF0000FFFFFF5555AAAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555FFFF0055550055AA0000000000FF00550055AA55FFFF000000
FF550000550000AA005500FF0000000000FF005500AA000055000055FF000000FFFF55AA
55005500FF0000000000AA5500555500FFFF5555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00555500000000FF5555555555555500000055FF550055555555
5500FF000000FF00AA5555550000550000555555AA00FF000000FF0055555555550055FF
5500000055555555555555FF00000000555500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55555555555500FFFF00FFFF00FF0000FFFFFF0000000000
0000555555555500AAFF5500FF000000FF0055FFAA00555555555500000000000000FFFF
FF0000FF00FFFF00FFFF00555555555555AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AA5555AA5555550055005555550000555500550000FF00
005500FFFF00FFFFAA0000005555555555000000AAFFFF00FFFF00550000FF0000550055
550000555555005500555555AA5555AA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAA55FF00FF005500FFFF000055FF000000550055
00000055550000AA00FF0000FF55AA55FF0000FF00AA00005555000000550055000000FF
550000FFFF005500FF00FF55AAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00555555000000555500AA55550000FF00FF00
FF0000FF5500AA55AA0000550055FF5500550000AA55AA0055FF0000FF00FF00FF000055
55AA00555500000055555500FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500000000005500000000FFAA5555555500AA00
5555555500FF00AAAA55000000FFFFFF00000055AAAA00FF005555555500AA0055555555
AAFF000000005500000000005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00550000550000005500005555FFAA5555AA00FF
00FFFF00550055AAAA5555555555005555555555AAAA55005500FFFF00FF00AA5555AAFF
55550000550000005500005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55000000FF0000005500FFFFFF55AA55AA00
005555000000FF5555FF00FFFF005500FFFF00FF5555FF00000055550000AA55AA55FFFF
FF0055000000FF00000055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA0055005500AA555555005555AAAAAA55
00000000550000AAAA0000555500000055550000AAAA0000550000000055AAAAAA555500
555555AA0055005500AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA555555AA00FFFF00FF0055FFFF55FF
0000FF00000055AAAA5500000000550000000055AAAA55000000FF0000FF55FFFF5500FF
00FFFF00AA555555AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAA5500555555000000AA00AA
0055005500AA55FFFF55AA00550000005500AA55FFFF55AA0055005500AA00AA00000055
55550055AAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFFF55000000000055AA00FF00
AA555555AA00FFFFFFFF00AA5555555555AA00FFFFFFFF00AA555555AA00FF00AA550000
00000055FFFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555500FF00005500AAAAFFFFFF
AAAA00AAAA550055550055AAAAAAAAAAAAAA550055550055AAAA00AAAAFFFFFFAAAA0055
0000FF00555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55555500AA555555FFFFFFFF
FF555555FF5500000000FFFF55FF55FF55FFFF0000000055FF555555FFFFFFFFFF555555
AA00555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA555555FF00FFFFFFFFFF
FFFF00FFFFFF0000FF0000AA00AA00AA00AA0000FF0000FFFFFF00FFFFFFFFFFFFFF00FF
555555AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAA00005555005555
00555555005555555500AA55AA00FF00AA55AA0055555555005555550055550055550000
AAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF0000FFFF000000
00FFFF00FF00FFFF00FF00AAAA550055AAAA00FF00FFFF00FF00FFFF00000000FFFF0000
FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555000055550000FF
0000AA0055555500550055AAAA555555AAAA5500550055555500AA0000FF000055550000
5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055000000005500
55AA00FF00FFFF000000FFFF5555AA5555FFFF000000FFFF00FF00AA5500550000000055
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550000FF0055
AA55AA00005555000055005555AAFFAA55550055000055550000AA55AA5500FF000055AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00555555
AAAAAA5500000000FF0055AA55FFFFFF55AA5500FF0000000055AAAAAA55555500AA55FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA5555AA
55AAAA55555555555500AAAA5555005555AAAA00555555555555AAAA55AA5555AA00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA
5555FFFF00FF55AA555555FFFF005500FFFF555555AA55FF00FFFF5555AAAAAAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF
FF0055550000AAAA55FF005555000000555500FF55AAAA0000555500FFFF5555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055
550000000055AAAA55550000000055000000005555AAAA5500000000555500FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
555555555555AAAAFF550000FF000000FF000055FFAAAA555555555555AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
55AA5555AA5555FFFFFF000055555555550000FFFFFF5555AA5555AA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00AAAA00FF55005555000055FF00FF55000055550055FF00AAAA00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAFFFFFF00000000FF0055555500FF00000000FFFFFFAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5555005555555555550000000000555555555555005555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF005500FF55AA55FF0000550000FF55AA55FF005500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA550055FF550055000000550055FF550055AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF55AA00AA00AA5555555555AA00AA00AA55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00AA55AA00FFFF00FFFF00AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAAA55005555550055AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555FF0000000000FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF005555555555555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55FF00FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5500550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.672071 0.97619 0.759381 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00AA5555AA5555FFAA5500FF555555AAAA5555FFAA555555555500AA000000AAFF55FF
55FFFF555555AAAAAAFFFF55FFFFAAFFFF55FFFFAAAAAA555555FFFF55FF55FFAA000000
AA005555555555AAFF5555AAAA555555FF0055AAFF5555AA5555AA00FF
FFFFAAAAAAAAFF55AA550000AAAA55FFAAAAFF5555AA00FFAA55FFAAFFAAFFFFAAAA00FF
55AA5555FF5555555555AA55AA555555AA55AA5555555555FF5555AA55FF00AAAAFFFFAA
FFAAFF55AAFF00AA5555FFAAAAFF55AAAA000055AA55FFAAAAAAAAFFFF
FFFFFF55FFFF550000FFFFAAFFAAAA55555555AAAAAAFFFFFF5555AA00AA5555AA005555
AAAAFF55AA55FFAA55AAFFAA5500000055AAFFAA55AAFF55AA55FFAAAA555500AA5555AA
00AA5555FFFFFFAAAAAA55555555AAAAFFAAFFFF000055FFFF55FFFFFF
FFFFFFFF0055FFAAFFFFFFFF5500AA55AAAAAAAAFFAAAA00AAAAAAAAFFFF55AAFFAAFF55
555555AAFFAA555555FFFFFF5555005555FFFFFF555555AAFFAA55555555FFAAFFAA55FF
FFAAAAAAAA00AAAAFFAAAAAAAA55AA0055FFFFFFFFAAFF5500FFFFFFFF
FFFFFFFFFFAA555555AA5555AAFFFF555555555555AA00555555555555AA55AA00AA5555
FFAA55AA00AA55FFAA5555AA55FFAAFF55AA5555AAFF55AA00AA55AAFF5555AA00AA55AA
55555555555500AA555555555555FFFFAA5555AA555555AAFFFFFFFFFF
FFFFFFFFFFFF5555FF55FF55AA00AAAAAAAA55FFAA005555FF5555FF555555FFFFAAAAAA
555555FFFFAAAA555555FFAAAA555555AAAAFF555555AAAAFFFF555555AAAAAAFFFF5555
55FF5555FF555500AAFF55AAAAAAAA00AA55FF55FF5555FFFFFFFFFFFF
FFFFFFFFFFFFFF00AAAA5555FFFFAAAAFFAAAA555555000055FF55AA55AAAA5555AA0055
AAAA55AA55555555FFAA55555555FF55555555AAFF55555555AA55AAAA5500AA5555AAAA
55AA55FF550000555555AAAAFFAAAAFFFF5555AAAA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAFF55AA55555555AA0055000000AA00FF555555FFFF55AAFFAAFF
0000FFAAAA55FF5555AA00FFAA55AA55AAFF00AA5555FF55AAAAFF0000FFAAFFAA55FFFF
555555FF00AA0000005500AA55555555AA55FFAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55FF00AA55AAAA55FFFFAA0000AA005555AAFF5555AA55AA00AA55
550055FFFF5555AAAAAAFFFFFF555555FFFFFFAAAAAA5555FFFF55005555AA00AA55AA55
55FFAA555500AA0000AAFFFF55AAAA55AA00FF55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00555555FFFF5555AA5500555555000055AA55FFAAAAAAFFFF55
AAFFFF0055FF5555555555AA5555FF5555AA5555555555FF5500FFFFAA55FFFFAAAAAAFF
55AA5500005555550055AA5555FFFF55555500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55FF5500FFFF00005555FFAA0000AAFFAA5555555555AA55
FFFFFFFFAA00AAFF5555FF55FFAA00AAFF55FF5555FFAA00AAFFFFFFFF55AA5555555555
AAFFAA0000AAFF55550000FFFF0055FF55AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5555AAFFFFFFFFAAFF5555AA0000AA555555FFAA55AAFFAA
5555AA55555500AAAA55AA55AA550055AA55AA55AAAA00555555AA5555AAFFAA55AAFF55
5555AA0000AA5555FFAAFFFFFFFFAA5555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00AA5555AA555555AAAAAAFFFFAAAAAAAA555555FFFFFF
55AAFFAA55AAFFFF55FF55FF55FFAAFF55FF55FF55FFFFAA55AAFFAA55FFFFFF555555AA
AAAAAAFFFFAAAAAA555555AA5555AA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAFF55AAAAFFAAAA00AA5500AA55FF5555AA55
55FFFFFF555555AA55FF00AAAA555555AAAA00FF55AA555555FFFFFF5555AA5555FF55AA
0055AA00AAAAFFAAAA55FFAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFF550000FF0055AA0000FFFFAAAA5555FFAAAA
AAAA00AAAA55AAAAFF0055555555FF5555555500FFAAAA55AAAA00AAAAAAAAFF5555AAAA
FFFF0000AA5500FF000055FFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFAAFFFFFFAA00555500FF55FFFF00AAAAFF
AAAAFFFF55FF55FFFFFFAA55FF55AA55FF55AAFFFFFF55FF55FFFFAAAAFFAAAA00FFFF55
FF00555500AAFFFFFFAAFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555555AA55555500005555AAAA00AA0055AA
5500AAAA00FF5555AA555555FF00FF00FF555555AA5555FF00AAAA0055AA5500AA00AAAA
55550000555555AA555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF55FF55AAFFFFAA55AA005555550000
FFFFAAAAFFFFFF00AA55FFAA00AA00AA00AAFF55AA00FFFFFFAAAAFFFF000055555500AA
55AAFFFFAA55FF55FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAA5555FFFFFFFF55AA000000005555
00FF55FFFFFFFFFFAAAA55555500AA00555555AAAAFFFFFFFFFF55FF00555500000000AA
55FFFFFFFF5555AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55AA5555AA55AA0000AA000000
00AAAA5555AA5555AA0055000055555500005500AA5555AA5555AAAA00000000AA0000AA
55AA5555AA55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00AA55AAAAFF0000AA00555500
55555555FF55FF55AA0000555500000055550000AA55FF55FF5555555500555500AA0000
FFAAAA55AA00FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555FFFF5500555555000055
55FFAA55AA55AA55FFFFAAFF5555005555FFAAFFFF55AA55AA55AAFF5555000055555500
55FFFF55555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF5500FFFFAA55AAFFFFAA
55AA550000FFAAAAAA00AA5555FFAAFF5555AA00AAAAAAFF000055AA55AAFFFFAA55AAFF
FF0055FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAFFFFFFFF555555AA55
0000FFAAFFFFFF55FFFFAAAAAA555555AAAAAAFFFF55FFFFFFAAFF000055AA555555FFFF
FFFFAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA5555AA5555FFAA5500
00AA00AA5555AA55AA5555555555FF5555555555AA55AA5555AA00AA000055AAFF5555AA
5555AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAFF55AA550000
AA00555555FF55FF55FF55AAAA55AA55AAAA55FF55FF55FF55555500AA000055AA55FFAA
AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFF550000FFFFAA
FFAAFF5555FF00FF55AA55FFFF555555FFFF55AA55FF00FF5555FFAAFFAAFFFF000055FF
FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFAAFFFFFFFF
5500AAAAAA555500FFFF55AA5555FF5555AA55FFFF005555AAAAAA0055FFFFFFFFAAFF55
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555555AA5555
AAFFFF55FFFF00AA00AAAAAAFF55AA55FFAAAAAA00AA00FFFF55FFFFAA5555AA555555AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF55FF55
AA00AAAAAA00AA005555555555AAFFAA555555555500AA00AAAAAA00AA55FF55FF5555FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAA5555
FFFFAAAAFFAAFFAAFF55AAAA55FFFFFF55AAAA55FFAAFFAAFFAAAAFFFF5555AAAA00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55
AA55555555AA00AA5555FFFF5555AA5555FFFF5555AA00AA55555555AA55FFAAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00
AA55AAAA55FFFFAAAAAAAA00AAFF55FFAA00AAAAAAAAFFFF55AAAA55AA00FF55FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055
5555FFFF55AA55555555555500AAAAAA00555555555555AA55FFFF55555500FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
55FF5500FFAAAA55AAAA55AAFFFF55FFFFAA55AAAA55AAAAFF0055FF55AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
5555AAFFFFFF55FFAAAAFF55FF005500FF55FFAAAAFF55FFFFFFAA5555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00AA5555AA55AA5500AAAAAA000000AAAAAA0055AA55AA5555AA00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAAAAAFF000055555555550055555555550000FFAAAAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55FFFF55005555FF5555FFAAFF5555FF55550055FFFF55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0055FFAAFF5555AAAA555555AAAA5555FFAAFF5500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA555555AAFF55FFFF00FFFF55FFAA555555AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF5555FF55FF00FF550055FF00FF55FF5555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00AAAA555500FFAAFF005555AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAFF555500FF005555FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55FF00AAFFFFFFAA00FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00555555AA55555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55FF55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AA55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.768113 0.200176 0.855423 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FFFF00AAAAAA00FFFFAAAAAA00FF5555FFFFAAAAAAAAAA00AAAAAAAA5555555555
00550055AA00FF00FFFFFFAAAAFF55FFAAAAFFFFFF00FF00AA550055005555555555AAAA
AAAA00AAAAAAAAAAFFFF5555FF00AAAAAAFFFF00AAAAAA00FFFF0000FF
FFFFAAFF00AAAAAAAAAA00FFAAAAFF550000AA00FFAAAAAAAAAAFFFF00FF0000AA0000AA
00AA00AA0055FF5500000000FF00AA00FF0000000055FF5500AA00AA00AA0000AA0000FF
00FFFFAAAAAAAAAAFF00AA000055FFAAAAFF00AAAAAAAAAA00FFAAFFFF
FFFFFF00AAAAAAAAAAFFAAFF00FF00AA00AAAAAA00FFFF00FFFF00AAFFFFFFAAFFAAFFFF
5500AAAAAA000000AAAA00AAAA555555AAAA00AAAA000000AAAAAA0055FFFFAAFFAAFFFF
FFAA00FFFF00FFFF00AAAAAA00AA00FF00FFAAFFAAAAAAAAAA00FFFFFF
FFFFFFFFAAAAAAAAAAFF000055FF5500AAAAAAAAAA00FFAAFF00AAAAFF00AAFFAA005500
00AAAAAAAAAA00AAAAAAFFFF0000AA0000FFFFAAAAAA00AAAAAAAAAA00005500AAFFAA00
FFAAAA00FFAAFF00AAAAAAAAAA0055FF550000FFAAAAAAAAAAFFFFFFFF
FFFFFFFFFF0000FFFF00AAAA000000AAAAAAAAAAAAAA00FF00AAAAFFAA00AA55AA00AA00
AAAAAAAAAAAAFFFF0000FFAA00AAAAAA00AAFF0000FFFFAAAAAAAAAAAA00AA00AA55AA00
AAFFAAAA00FF00AAAAAAAAAAAAAA000000AAAA00FFFF0000FFFFFFFFFF
FFFFFFFFFFFFAAFF00AAAAAAAA00AAAAAAFFAAAAFFAAAA00FF55FFFFFF5500AA0055FFFF
AAAAAAAAAAAAFF00AAAA00FFFFAAAAAAFFFF00AAAA00FFAAAAAAAAAAAAFFFF5500AA0055
FFFFFF55FF00AAAAFFAAAAFFAAAAAA00AAAAAAAA00FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFF00AAAAAAAAAAFFFF55FFFFFF000000FFFFAA0000550000AAAAAA000000
00FFFF00FFFF00AAAAAAAA00FFAAAAAAFF00AAAAAAAA00FFFF00FFFF00000000AAAAAA00
00550000AAFFFF000000FFFFFF55FFFFAAAAAAAAAA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAAAAAAAFF00AA00FFAA00AAAA00FFAAAA00AA00AAAAAAAAAA00AA
AA00FFAAFF00AAAAAAAAAAAA00FF00FF00AAAAAAAAAAAA00FFAAFF00AAAA00AAAAAAAAAA
00AA00AAAAFF00AAAA00AAFF00AA00FFAAAAAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF00AAAAAA00FFFFAAAAAA00FFFF5500AAAAAAAAAAAAFFFF
00FF555555FF0000FFFF00FFFFAA00AAFFFF00FFFF0000FF555555FF00FFFFAAAAAAAAAA
AA0055FFFF00AAAAAAFFFF00AAAAAA00FFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF00AAAAAAAAAA00FFAAAAFF55000000AAAAFFAAAAAAFF5555
FF00AA0000AAFFFFAA00FF5555FFAAFF5555FF00AAFFFFAA0000AA00FF5555FFAAAAAAFF
AAAA00000055FFAAAAFF00AAAAAAAAAA00FFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AAAAAAAAAAFFAAFF00FF00AA00AAAA0055AAAAAAFF555500
5500FFFFAAFFAA00FFFFAA0000AAFFAA0000AAFFFF00AAFFAAFFFF0055005555FFAAAAAA
5500AAAA00AA00FF00FFAAFFAAAAAAAAAA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAFF000055FF5500AAAAAAAA0000FF000000AA00
AA00AAFF00FFAAAA00FFAAAA00AA55AA00AAAAFF00AAAAFF00FFAA00AA00AA000000FF00
00AAAAAAAA0055FF550000FFAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00AAAA000000AAAAAAAAAAAA00AAFFFFAAFF55
00AAAAAA5555FFAAAA00FFFF5500AA0055FFFF00AAAAFF5555AAAAAA0055FFAAFFFFAA00
AAAAAAAAAAAA000000AAAA00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00AAAAAAAA00AAAAAAFFAAAAFFAAFFAA00FF00AA
00AA5500AA000000FF00550000AAAAAA00005500FF000000AA0055AA00AA00FF00AAFFAA
FFAAAAFFAAAAAA00AAAAAAAA00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAAAAFFFF55FFFFFF000000FFAAAA00FF55
AA550055FFAAFFFFAA00AA00AAAAAAAAAA00AA00AAFFFFAAFF550055AA55FF00AAAAFF00
0000FFFFFF55FFFFAAAAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAFF00AA00FFAA00AAAA00FF00FF5555
00AA00AA00FFFFFFFF5500AAAAAAAAAAAAAA0055FFFFFFFF00AA00AA005555FF00FF00AA
AA00AAFF00AA00FFAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00AAAAAA00FFFFAAAAAA00FF555500
55FFAAFF550000000000AAAAAAAAAAAAAAAAAA000000000055FFAAFF55005555FF00AAAA
AAFFFF00AAAAAA00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00AAAAAAAAAA00FFAAAAFF550000AA00
AA00FF00AA00AAAA00AAAAAAAAAAAAAAAAAAAAAA00AAAA00AA00FF00AA00AA000055FFAA
AAFF00AAAAAAAAAA00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAAAAFFAAFF00FF00AA00AAAAAA
0055FF5500AAAAAAAA0055AAFFAAAAAAFFAA5500AAAAAAAA0055FF5500AAAAAA00AA00FF
00FFAAFFAAAAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAFF000055FF5500AAAAAAAA
AA000000AAAAAAAAAAAA0000FFAAAAAAFF0000AAAAAAAAAAAA000000AAAAAAAAAA0055FF
550000FFAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00AAAA000000AAAAAAAAFF
AAAA00AAAAAAAAAAAAAAAA00AAFF55FFAA00AAAAAAAAAAAAAAAA00AAAAFFAAAAAAAA0000
00AAAA00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00AAAAAAAA00AAAAAAFFAAAA
5500AAAAAAAAAAAAAAAAAAFFFF00AA00FFFFAAAAAAAAAAAAAAAAAA0055AAAAFFAAAAAA00
AAAAAAAA00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAAAAFFFF55FFFFFF00
00AAAAAAAAAAAAFFAAAAAAFF00AAAAAA00FFAAAAAAFFAAAAAAAAAAAA0000FFFFFF55FFFF
AAAAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAFF00AA00FFAA00
AAAAAAAAAAFFAAAA55FFFF00AAAAAAAAAA00FFFF55AAAAFFAAAAAAAAAA00AAFF00AA00FF
AAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00AAAAAA00FFFF
AAAAFFAAAAAA5500AA00FFAAFFAAAAAAFFAAFF00AA0055AAAAAAFFAAAAFFFF00AAAAAA00
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00AAAAAAAAAA00FF
AAAAFF00FF0000AAAAAA00FFFFFF00FFFFFF00AAAAAA0000FF00FFAAAAFF00AAAAAAAAAA
00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAAAAFFAAFF
00FFFFFFAA00AAAAAAAAAA00FFAA00AAFF00AAAAAAAAAA00AAFFFFFF00FFAAFFAAAAAAAA
AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAFF0000
55FF5555FFFFAAAAAAFFAA5555FFAAFF5555AAFFAAAAAAFFFF5555FF550000FFAAAAAAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00AAAA
000000AA00FFAAAAAAFF0000AA00FF00AA0000FFAAAAAAFF00AA000000AAAA00FFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00AAAAAA
AA00AAAAAA00FF00FF00AAAA0055FF5500AAAA00FF00FF00AAAAAA00AAAAAAAA00FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAA
AAFFFF55AA00AAFFFFFFAAAAAA000000AAAAAAFFFFFFAA00AA55FFFFAAAAAAAAAA00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA
AAFF00AA0055FFFFFFFFFF00FFFFAAFFFF00FFFFFFFFFF5500AA00FFAAAAAAAAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FF00AAAAAA00005500000055FF555555FF55000000550000AAAAAA00FFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
00AAAAAAAAAA00AA00AAAA000000AA000000AAAA00AA00AAAAAAAAAA00FFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
AAAAAAAAAAFFAAFFAAFFAAAA00AAAAAA00AAAAFFAAFFAAFFAAAAAAAAAA00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAAAAAAAAFF000055AAAAFFAAFF55FFAAFFAAAA550000FFAAAAAAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFF00AAAA0000FFFFFF00AA00FFFFFF0000AAAA00FFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFF00AAAAAAAA00AAFF00AAAAAA00FFAA00AAAAAAAA00FFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00AAAAAAAAAAFFFF00AAAAAAAAAA00FFFFAAAAAAAAAA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAAAAAAAFF00AAAAAAAAAAAAAA00FFAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF00AAAAAAAAAAAAAAAAAA00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFF00AAAAAAAAAAAAAAAAAAAAAA00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00AAAAAAAAAAAAAAAAAAAAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAAAAAAAFF55FFAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF00AA00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF00AAAAAA00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AAAAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.768113 0.39418 0.855423 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FF0000AAAAAAAA55AAAA00AAAAAAAAAA55AAAAAA55AAAAAAAAFF55AAAA00AA55
00005555AA55AAAAAAFF005500FFFFFF005500FFAAAAAA55AA5555000055AA00AAAA55FF
AAAAAAAA55AAAAAA55AAAAAAAAAA00AAAA55AAAAAAAA0000FF000000FF
FFFFAAFFFFFFAAFFAAAAAAAA55FFFFAA55FFFF55AAAAAAAAAA55FFFF55AA55AAFFAAFF55
555555FF55AAAAAAFF5500AAFFFFFFFFFFAA0055FFAAAAAA55FF55555555FFAAFFAA55AA
55FFFF55AAAAAAAAAA55FFFF55AAFFFF55AAAAAAAAFFAAFFFFFFAAFFFF
FFFFFF005500FFFFFF55FFFF5555AA55FF5500FFAAAAAAAAAAAA5555AAAAAA55FF00FF55
55FF5555AAAAAAAAAA0000FFFFFFFFFFFFFF0000AAAAAAAAAA5555FF5555FF00FF55AAAA
AA5555AAAAAAAAAAAAFF0055FF55AA5555FFFF55FFFFFF005500FFFFFF
FFFFFFFFAA005500FF5555AA55AAAAAA555500AAAAAAAAAAAAFF5555FFAAAAAA555555AA
AA5555FF55FFFF55FFAAFFFFFFFFFFFFFFFFFFAAFF55FFFF55FF5555AAAA555555AAAAAA
FF5555FFAAAAAAAAAAAA005555AAAAAA55AA5555FF005500AAFFFFFFFF
FFFFFFFFFF0000AA5555FF55FF55AAFFAA0000FFFF55AAFFAAAA0000AAAAAAAAAA55AAAA
AAAA55AA55AA555500FFFFFFFFFFFFFFFFFFFFFF005555AA55AA55AAAAAAAA55AAAAAAAA
AA0000AAAAFFAA55FFFF0000AAFFAA55FF55FF5555AA0000FFFFFFFFFF
FFFFFFFFFFFFAAFF5555FF00AAAA55FF00FF000055FF55AA55FFFFAAFFAAAAFF55FF55AA
FF55FF55FF55AAAA5500FF55000055000055FF0055AAAA55FF55FF55FFAA55FF55FFAAAA
FFAAFFFF55AA55FF550000FF00FF55AAAA00FF5555FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFF0055550000FFFF5555AA00AA550055FF55FF5500FFFFFF00FF5555AAAA
AA00FF5555AAAAAAFF000000AA550055AA000000FFAAAAAA5555FF00AAAAAA5555FF00FF
FFFF0055FF55FF550055AA00AA5555FFFF0000555500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00FF0000005555FFFFAAAA550055FF550055AA5555AA00AAFF00FF
FF00005555FFAA55FF0000FF00FFAAFF00FF0000FF55AAFF55550000FFFF00FFAA00AA55
55AA550055FF550055AAAAFFFF5555000000FF00AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF0000AA00AAAAAAAA5500550055AAAAAA55AAFFFF0055AA
555555550055FFAA00AA550000FF55FF000055AA00AAFF550055555555AA5500FFFFAA55
AAAAAA5500550055AAAAAAAA00AA0000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFFFFAAFFAAFF55FFAAAA550055AAAAAAAAAA55FF0055AAAA
AA55AAAA550055FFFFAA55AA0055FF5500AA55AAFFFF550055AAAA55AAAAAA5500FF55AA
AAAAAAAA550055AAAAFF55FFAAFFAAFFFFFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF005500FFFFFF550055FFFF555555FFAAAAAAAAAA555555FFFF
00FFAAAAAA550055FF00FFAA5500550055AAFF00FF550055AAAAAAFF00FFFF555555AAAA
AAAAAAFF555555FFFF550055FFFFFF005500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA005500FF555555000055550055FFFF55FFFF5555FF5500
00FF55FFAAAA55005500AAAAAA550055AAAAAA00550055AAAAFF55FF000055FF5555FFFF
55FFFF550055550000555555FF005500AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000AA5555FF555555550055AAAA00AA00AAAA55AA55AA
00550055FFAA55AA00FF00FFFF555555FFFF00FF00AA55AAFF55005500AA55AA55AAAA00
AA00AAAA550055555555FF5555AA0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555FF00AAFF00AA55AAFFAAFFAAFF55FF55FF55
AA00FF00AAAAFF00FF0055AA5555FF5555AA5500FF00FFAAAA00FF00AA55FF55FF55FFAA
FFAAFFAA55AA00FFAA00FF5555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055550000FFFFFFAAAA55FF00FF55AA55AA55AA55
AAFFFFFFAA55FF000055AAAAAA55AA55AAAAAA550000FF55AAFFFFFFAA55AA55AA55AA55
FF00FF55AAAAFFFFFF0000555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF00000055FFAAAA555555AAAAAA55FF55AA
AAAA00AAAAAA55555555FFFF55FF55FF55FFFF55555555AAAAAA00AAAAAA55FF55AAAAAA
555555AAAAFF55000000FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000AAAAAAAA55AAAAFFAAAA5555FF
FF00FF00FFFF5555FF5555AA55AA55AA55AA5555FF5555FFFF00FF00FFFF5555AAAAFFAA
AA55AAAAAAAA0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAAFFAAAAAAAA55FFFFFF55AAAA55
55AA00AA5555AAAA5555FF55FF55FF55FF55FF5555AAAA5555AA00AA5555AAAA55FFFFFF
55AAAAAAAAFFAAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005500FFFFFF55FFFF5555AA5555FFFF55
55FFAAFF5555FFAAAA55AA55AA55AA55AA55AA55AAAAFF5555FFAAFF5555FFFF5555AA55
55FFFF55FFFFFF005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005500FF5555AA55AAAAFF00AAAA00
00AAAAAA0000AAAAAAAA55FF55AAAAAA55FF55AAAAAAAA0000AAAAAA0000AAAA00FFAAAA
55AA5555FF005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA5555FF55FF55FFFFFFAAAAFF
FFAAAAAAFFFFAA55FFFF5555AAAAAAAAAA5555FFFF55AAFFFFAAAAAAFFFFAAAAFFFFFF55
FF55FF5555AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555FF00AAAA5555AA55FFFF
FFFF00FFFFFFFF5555AA55AAAAAAAAAAAAAA55AA5555FFFFFFFF00FFFFFFFF55AA5555AA
AA00FF5555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055550000FFFF5555FFAA00AA
AA00AA5555AA5555FF55FF55FFFF00FFFF55FF55FF5555AA5555AA00AAAA00AAFF5555FF
FF0000555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF0000005555FF00FF00
FFFFAA55AAAAAA55AA55AA55AA555555AA55AA55AA55AAAAAA55AAFFFF00FF00FF555500
0000FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000AA00AA5555
55AA55FF55FFAAAA55FF55AAAAAA55AAAAAA55FF55AAAAFF55FF55AA555555AA00AA0000
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAAFFAAFF5555
FF55FF550055FFAA55AA55AAFFAA55AAFFAA55AA55AAFF550055FF55FF5555FFAAFFAAFF
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005500FFFFFF550055
55AAAA00FF00AAAAAA55FF55AA55FF55AA55FF55AAAAAA00FF00AAAA55550055FFFFFF00
5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005500FF555555
FF55AAFFFFFFAAAAAAAA5555FFAA00AAFF5555AAAAAAAAFFFFFFAA55FF555555FF005500
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA5555FF55
55AAAAAA00AAAAAAAAFF5555FF00FF00FF5555FFAAAAAAAA00AAAAAA5555FF5555AA0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555FF00
AAFFAAAAFFFF55FFFF005555FF000000FF555500FFFF55FFFFAAAAFFAA00FF5555FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055550000
FFFFFF55AA5555FF0055AAAA5555555555AAAA5500FF5555AA55FFFFFF0000555500FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF00
000055FF55FF5555AA00FFFF5555FF5555FFFF00AA5555FF55FF55000000FF00AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FF0000AAAA5555FF55AA00AAAA55AA55AAAA00AA55FF5555AAAA0000FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
FFFFAAFFAAAA55AA55AAFFFF55AAAAAA55FFFFAA55AA55AAAAFFAAFFFFFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
5500FFFFFF55FF55AAAAAA00AAFF55FFAA00AAAAAA55FF55FFFFFF005500FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA005500FF5555AAAAAAAAFFFF550055FFFFAAAAAAAA5555FF005500AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000AA5555FF55FFAA55FF0055555500FF55AAFF55FF5555AA0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFF5555FF00AAAAAA55555500555555AAAAAA00FF5555FFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0055550000FFFF00FFAA00FF00AAFF00FFFF0000555500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA00FF00005500AAAAFFFFFFAAAA00550000FF00AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00AA55FFFFFFFFFF55AA00FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFFFFFAAAA5555AA5555AAAAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF005500FFFF00AAFFAA00FFFF005500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00550000FFFFFF00005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000AA5500000055AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF5555555555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00555500555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.768113 0.588183 0.855423 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FF0000FFAAFFAAFFAAAA00FF55FF55FF000000FFFFAAAAAA55AA55FFAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFF55
AA55AAAAAAFFFF000000FF55FF55FF00AAAAFFAAFFAAFF0000FF0000FF
FFFFAA00AAFFFFFF005555AAFFAA00AA555555AAAA55AA55550055555500AAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA00
555555005555AA55AAAA555555AA00AAFFAA555500FFFFFFAA00AAFFFF
FFFFFF00AA00AAAA00FF0000AAAAFFFF000000FFFF0000AA5500000000FFAAAAAAAAAAAA
AAFFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFFAAAAAAAAAAAAAAFF
0000000055AA0000FFFF000000FFFFAAAA0000FF00AAAA00AA00FFFFFF
FFFFFFFFAA55AAFFAA00AAFF00FFFFFFFFAAFFFFFFFFAA00000055000055FFAAAAAAAAFF
55AA55FFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFF55AA55FFAAAAAAAAFF55
000055000000AAFFFFFFFFAAFFFFFFFF00FFAA00AAFFAA55AAFFFFFFFF
FFFFFFFFFF0000AAAAAA55FF00AAAA00AAAAAA00AAAA0000550000005500AAAAAAAAAAAA
00555555AAFFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFFAA55555500AAAAAAAAAAAA00
55000000550000AAAA00AAAAAA00AAAA00FF55AAAAAA0000FFFFFFFFFF
FFFFFFFFFFFFAA0000AA0055FF55FFFFAAAAAAFFFF55FF555555FF555555FFAAAAAAAAAA
FF00000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA00000000FFAAAAAAAAAAFF55
5555FF555555FF55FFFFAAAAAAFFFF55FF5500AA0000AAFFFFFFFFFFFF
FFFFFFFFFFFFFF00AAFF555555AA00AAAAFFAAAA00AA5555555555AA0055AA55FFAA55FF
FFFFAAFFFFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFFFFAAFFFFFF55AAFF55AA55
00AA5555555555AA00AAAAFFAAAA00AA555555FFAA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55555555550000AA00AA000055555555555555000000AA555500AA
AA00AA00AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA00AA00AAAA005555AA0000
00555555555555550000AA00AA00005555555555AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF0000FFAAFFAAFFAA00FF0000FF0000FF00AAFFFF0000FFAA
AAFF00FFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFF00FFAAAAFF0000FFFFAA
00FF0000FF0000FF00AAFFAAFFAAFF0000FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA00AAFFFFFF005555AAFFFFFFAA00AAFFFFFFAAAA00AAFFFFFF
55FF00AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA00FF55FFFFFFAA00AAAA
FFFFFFAA00AAFFFFFFAA555500FFFFFFAA00AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AA00AAAA00FF0000AAAA00AA00FFFFFFFFFF00FFAA5555AA
5500FFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFF0055AA5555AAFF00FF
FFFFFFFF00AA00AAAA0000FF00AAAA00AA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55AAFFAA00AAFF00FFFFAAAA5555AA5555AAAA0000FF00
FF00AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA00FF00FF0000AAAA55
55AA5555AAAAFFFF00FFAA00AAFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000AAAAAA55FF00AAAA0000AA550055AA0000AAFF0055
00FFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFF005500FFAA0000AA
550055AA0000AAAA00FF55AAAAAA0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AA0055FF55FFFFAA00000055AAFFFFAAAA00FF
00AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA00FF00AAAAFFFFAA
55000000AAFFFF55FF5500AA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF555555AA00AAAAFFFFAA005555AA55FFAA00
AAFFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFFAA00AAFF55AA5555
00AAFFFFAAAA00AA555555FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55555555550000AA00AAAAFF000000AA555500
00AAAAFFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFFAAAA00005555AA000000
FFAAAA00AA00005555555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFAAFFAAFFAAAA00FFAA000000FF
AA0000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA0000AAFF000000AAFF00
AAAAFFAAFFAAFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFFFFFF005555AAFFAA00AA00FFAA00
AA00FFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFF00AA00AAFF00AA00AA
FFAA555500FFFFFFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00AAAA00FF0000AAAAFFFF00AAAAFF
FF00AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA00FFFFAAAA00FFFFAA
AA0000FF00AAAA00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFFAA00AAFF00FFFFFFFFAAAAAA
00AAFF55FFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFF55FFAA00AAAAAAFFFFFFFF
00FFAA00AAFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AAAAAA55FF00AAAA00AAAAAAAA
FFFF5500AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA0055FFFFAAAAAAAA00AAAA
00FF55AAAAAA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AA0055FF55FFFFAAAAAAAA
AA00AA55AAFFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFFAA55AA00AAAAAAAAAAFFFF55
FF5500AA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF555555AA00AAAAFFAAAA
AAFFFF0000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA0000FFFFAAAAAAFFAAAA00AA
555555FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55555555550000AA00AA00
00AAAA00FFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFF00AAAA0000AA00AA000055
55555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFAAFFAAFFAA
00FFFF00AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA00FFFF00AAFFAAFFAAFF00
00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFFFFFF005555AA
FFFFFFFFAAAAAAAAAAAAAAFFAAAAAAAAAAFFAAAAAAAAAAAAAAFFFFFFFFAA555500FFFFFF
AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00AAAA00FF0000
AAAA00AAAAFFAAAAFFAAAAAA0000AA0000AAAAAAFFAAAAFFAAAA00AAAA0000FF00AAAA00
AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFFAA00AAFF
00FFFFAAAAAA0000AAAAFFAA55AAAAAA55AAFFAAAA0000AAAAAAFFFF00FFAA00AAFFAA55
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AAAAAA55FF
00AAAA0000AA00FFAAAAAA000000AA000000AAAAAAFF00AA0000AAAA00FF55AAAAAA0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AA0055
FF55FFAAFFFF00AAAAAAAAFFFFAAFFAAFFFFAAAAAAAA00FFFFAAFF55FF5500AA0000AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF5555
55AA00AA00AAAA55FFAAAAAA00AA00AA00AAAAAAFF55AAAA00AA00AA555555FFAA00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555555
55550000AAFF55AA00AA0000AAFFAAFFAA0000AA00AA55FFAA00005555555555AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
0000FFAAFF5500AA00FFFFAAFF550055FFAAFFFF00AA0055FFAAFF0000FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00
AAFFFFFF5500AAFFAA00AAAAAA005500AAAAAA00AAFFAA0055FFFFFFAA00AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
AA00AAAA00550055FFAA0000AA00FF00AA0000AAFF55005500AAAA00AA00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55AAFFAA005500AAAAAA55AAFFFFFFAA55AAAAAA005500AAFFAA55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000AAAAAA550000AA0000FFFFFFFFFF0000AA000055AAAAAA0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA0000AA00550000AAFFFFFFFFFFFFFFAA00005500AA0000AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00AAFF555555FF55AA5555AA5555AA55FF555555FFAA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA5555555555AA0000FF00FF0000AA5555555555AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF000000AAFF005500FFAA000000FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA00AAFFFFAAAA00FF00AAAAFFFFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00AA00AAAAAAFFFFFFAAAAAA00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55AAFFAAAA00AAAAFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000AAAAFFAAFFAAAA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA0000AAAAAA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AAFF55FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.768113 0.782187 0.855423 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00AAFFFFFFFF55FFFFFF550000AAFF555500AA55FFFFFFFFFFFF55AAFFAAAAAA55FFFF
AA00AA0000FFAAAAFFAAAAFFAAAAFFAAAAFFAAAAFFAAAAFF0000AA00AAFFFF55AAAAAAFF
AA55FFFFFFFFFFFF55AA005555FFAA000055FFFFFF55FFFFFFFFAA00FF
FFFFAAAA5555FF55AA5555AAFFFFAAAA55FFAAFFAA5555AAAA55AA55FFFFFF55FFFF00AA
FFAAFFAAFFFFFF55FF55FFFFFF55FF55FFFFFF55FF55FFFFFFAAFFAAFFAA00FFFF55FFFF
FF55AA55AAAA5555AAFFAAFF55AAAAFFFFAA5555AA55FF5555AAAAFFFF
FFFFFF55FFAA55AAFFAA55FFFFFFFF55FFAA0055FFFF00FF000000FFFFFFFFFF00AAFFFF
5500AAFFAA00FF55AA55FF5500FFFFFF0055FF55AA55FF00AAFFAA0055FFFFAA00FFFFFF
FFFF000000FF00FFFF5500AAFF55FFFFFFFF55AAFFAA55AAFF55FFFFFF
FFFFFFFF00AA55FFFFFF55AA5555FF55AAAAFFFF00AAFFFFFFAAFFFFFFFFFFFFFFAAAA00
FFFFAAAA005555AAFFAA55AAFFFFFFFFFFAA55AAFFAA555500AAAAFFFF00AAAAFFFFFFFF
FFFFFFAAFFFFFFAA00FFFFAAAA55FF5555AA55FFFFFF55AA00FFFFFFFF
FFFFFFFFFFAAAAAA5555FFAAAAAAAA55FFFF550000AA55AA555555AA5555AAAA55AA0055
55AAAAFFAAFF55AA00AA55FFFFFFFFFFFFFF55AA00AA55FFAAFFAAAA555500AA55AAAA55
55AA555555AA55AA000055FFFF55AAAAAAAAFF5555AAAAAAFFFFFFFFFF
FFFFFFFFFFFF55FFFF00FFAAAAFFAAAAAA55AAFFFFAAAAAAFF55AAFFAA55FFFF55AA0000
0000FF0055AA55FFFFAAAAAA5555AA5555AAAAAAFFFF55AA5500FF00000000AA55FFFF55
AAFFAA55FFAAAAAAFFFFAA55AAAAAAFFAAAAFF00FFFF55FFFFFFFFFFFF
FFFFFFFFFFFFFF00AAFFFFFF55FF0000FF00FF00AAAAFFAAAA55FFFFFF55AAAA55FFFFAA
FFFFAA000000FFFFFFFF55FFFF00FF00FFFF55FFFFFFFF000000AAFFFFAAFFFF55AAAA55
FFFFFF55AAAAFFAAAA00FF00FF0000FF55FFFFFFAA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA5555FFAA0000AAFFFFFFAAAAFF0000FFFFFFFFFF0000FFFFFFFF
5555FFFFAAFFFFFFFFFFFF00AAFFFFFFAA00FFFFFFFFFFFFAAFFFF5555FFFFFFFF0000FF
FFFFFFFF0000FFAAAAFFFFFFAA0000AAFF5555AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55FFAA55AA0000AA5555FF55FFFFFFAAFF0055FF55005555FF5555
FFAA5555FFFFFFFFFFFFFFFFAAAA00AAAAFFFFFFFFFFFFFFFF5555AAFF5555FF55550055
FF5500FFAAFFFFFF55FF5555AA0000AA55AAFF55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00AA55FFFFAAFFAA55FF00FF5555FFFFFFAA55AAFFFF00FFAA55
FF55FFAA55AA55AAAA55AAAA5500AA0055AAAA55AAAA55AA55AAFF55FF55AAFF00FFFFAA
55AAFFFFFF5555FF00FF55AAFFAAFFFF55AA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAAA555555FFFF005555FFAA5555AAAAFF55FF55550000FF
FFFF00AA55FFFF0000FFFF55FFAAFFAAFF55FFFF0000FFFF55AA00FFFFFF00005555FF55
FFAAAA5555AAFF555500FFFF555555AAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55FFFF00FFFFFFFFAA55FF55FFAA5500AAAAAA55FFAAFFFF
FFFFFFAAAAAA55550055FF00FF55FF55FF00FF55005555AAAAAAFFFFFFFFFFAAFF55AAAA
AA0055AAFF55FF55AAFFFFFFFF00FFFF55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFFFFFFFFFF55AA55FF55FFAAFFAAAAFF5500AAAA
5555FF0000FF00FFFFAA555500FFFFFF005555AAFFFF00FF0000FF5555AAAA0055FFAAAA
FFAAFF55FF55AA55FFFFFFFFFFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555FF55000000FFFFFF00AA55555555FFAAFFAA
AAAAAA0000AAFFFFFFFF55AAFFFFFFFFFFAA55FFFFFFFFAA0000AAAAAAAAFFAAFF555555
55AA00FFFFFF00000055FF5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA55AAFFFFAAFF00AAFFFF55AAFF55AAAAFF00
00FF0000AA0055FF00AAFF55FF005500FF55FFAA00FF5500AA0000FF0000FFAAAA55FFAA
55FFFFAA00FFAAFFFFAA55AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55FFFFFFFF555500AAAA55FFFFFF0000FFAA
FFFFFFAAFFAAFF555500AAAAAA000000AAAAAA005555FFAAFFAAFFFFFFAAFF0000FFFFFF
55AAAA005555FFFFFFFF55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA5555FF00FFFFAAAAFF5500FFAAFFFFFF
5555FF55FF55FF55AAFFFF55FFFFAAFFFF55FFFFAA55FF55FF55FF5555FFFFFFAAFF0055
FFAAAAFFFF00FF5555AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFF00FFAAFF00AA55000000AAFFAA00AA
FF55AAAAAA55FF55AA00AAAAAA00FF00AAAAAA00AA55FF55AAAAAA55FFAA00AAFFAA0000
0055AA00FFAAFF00FFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFFFF550055AAFFFFAAFFAA005555
55FFAAAAFFAA55AAFFAAFFAAAAFFFFFFAAAAFFAAFFAA55AAFFAAAAFF55555500AAFFAAFF
FFAA550055FFFFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555FFAAFF55FF555555FFFFAA55
FFAA0055AAAAFF55FF55FF55FFFFFFFFFF55FF55FF55FFAAAA5500AAFF55AAFFFF555555
FF55FFAAFF5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA55AA00FFFFFF00FFFFFFFF55
AAAAFFFF0000FF55AAAAAA55FF005500FF55AAAAAA55FF0000FFFFAAAA55FFFFFFFF00FF
FFFF00AA55AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55FFFFAA00AAFFFFFFFFFFFF
0000FFAA0000AAAAAAFFAAAAAA000000AAAAAAFFAAAAAA0000AAFF0000FFFFFFFFFFFFAA
00AAFFFF55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55555500AAAA5555AAAA
0000AAFFAAFFFF55FFFFFF55FFFFAAFFFF55FFFFFF55FFFFAAFFAA0000AAAA5555AAAA00
555555AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFF00FFFFAAAAFF55AA00
555500AAFFAA00FFFFFFFFFF00AAFFAA00FFFFFFFFFF00AAFFAA00555500AA55FFAAAAFF
FF00FFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFFFFFF55FF55AA00
000000AA55AA000055FF550000AA55AA000055FF550000AA55AA00000000AA55FF55FFFF
FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555FF55AA55FFFF
AAFFFFAAAAAAFFFFAA55AAFFFFAAAAAAFFFFAA55AAFFFFAAAAAAFFFFAAFFFF55AA55FF55
55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA55AAFFAA5555
FFFFFFFF55FFFFFFFF55AA00AAAAFFAAAA00AA55FFFFFFFF55FFFFFFFF5555AAFFAA55AA
FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55FFFFFF55AA
FF0055FF00FFAA00AAAAAAFFFF55FF55FFFFAAAAAA00AAFF00FF5500FFAA55FFFFFF55AA
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA5555FFAA
AA0000005555FFFFAAAAFFAA00FFFFFF00AAFFAAAAFFFF5555000000AAAAFF5555AAAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFF00FFAA
AAFFFFAAFF55AAAA0055AAAAFFFFFFFFFFAAAA5500AAAA55FFAAFFFFAAAAFF00FFFF55FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFFFF
55FF0055AAAAAAFFAAFF55FFFFFFFFFFFFFF55FFAAFFAAAAAA5500FF55FFFFFFAA00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555
FFAA000000FF000055AA55FF0055FF5500FF55AA550000FF000000AAFF5555AAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA
55AA0000AA00AA000000FFFFFFAA55AAFFFFFF000000AA00AA0000AA55AAFF55FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA
55FFFFAAFFAAFFAAFFFFAA00FFAAAAAAFF00AAFFFFAAFFAAFFAAFFFF55AA00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAAA00AA55AA00FF00AAAAFFFFFF55FFFFFFAAAA00FF00AA55AA00AAAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
55FFFFAAAAAAFFFFFFAAAAFF00AAAAAA00FFAAAAFFFFFFAAAAAAFFFF55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00AAFFAAAAFF00AAAAFFAA0000FF0000AAFFAAAA00FFAAAAFFAA00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAA5500AAFFFF55FF0000AA00AA0000FF55FFFFAA0055AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55FFAAFFAA00FFFFFFAAFFAAFFAAFFFFFF00AAFFAAFF55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00AA55AA000055FF55FF55FF55FF550000AA55AA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAAFFFFAA55AAFF00FFAA55AAFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF55FFFFFFFF55AA00AA00AA55FFFFFFFF55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00AAAA55AAFFAAFFAAFFAA55AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAFF55FF55FF55FF55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55FF00FF55AA55FF00FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF005555AAFFAA555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55FFFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AA55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.768113 0.97619 0.855423 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF005555FFFFAAAAAAFF5555AAFF55AA0000AA5555AA5555550055FFAAFFAAAAFF555555
AA00AA5555AAFFFFAAFFAAFF55FFFFFF55FFAAFFAAFFFFAA5555AA00AA555555FFAAAAFF
AAFF5500555555AA5555AA0000AA55FFAA5555FFAAAAAAFFFF555500FF
FFFFAA55FF555555AA55AAFF55FF55AA0000AAAAAAAAFF55AAFFFF00AAAA5555AAAAAAAA
AAFFFF55AAFFAA00FF5555AAAAAA55AAAAAA5555FF00AAFFAA55FFFFAAAAAAAAAA5555AA
AA00FFFFAA55FFAAAAAAAA0000AA55FF55FFAA55AA555555FF55AAFFFF
FFFFFF55AAAAAAAAAAFF55FF55AAAAAAFFFFAAAAFFAAAA55FFFFFFFFAAAAFF55AA555555
AA55AAAAAAFF0000AAFF55AA00AAAAAA00AA55FFAA0000FFAAAAAA55AA555555AA55FFAA
AAFFFFFFFF55AAAAFFAAAAFFFFAAAAAA55FF55FFAAAAAAAAAA55FFFFFF
FFFFFFFF0055FFFF55FF55AAAAAA00AAAA55AA00AAFFAAAAAA55AAAA555555FFAAAAAAAA
AAFF55FFFF55550055AAAAAAFFFF55FFFFAAAAAA55005555FFFF55FFAAAAAAAAAAFF5555
55AAAA55AAAAAAFFAA00AA55AAAA00AAAAAA55FF55FFFF5500FFFFFFFF
FFFFFFFFFFAA55AAAAAA55FFFF550055FFFF0000AA55AA5555AAFFAAAAAAAAAA5555AA00
55FF55AAAA55FFAAFF55FF00550000005500FF55FFAAFF55AAAA55FF5500AA5555AAAAAA
AAAAFFAA5555AA55AA0000FFFF550055FFFF55AAAAAA55AAFFFFFFFFFF
FFFFFFFFFFFF55AA00AAAAAA55AAFFFF00AAFFFFAAAAAAFF55AA55AA00AAAAFFAA55FFFF
AA55AAFFAAAAAA5555FFAA000000AA000000AAFF5555AAAAAAFFAA55AAFFFF55AAFFAAAA
00AA55AA55FFAAAAAAFFFFAA00FFFFAA55AAAAAA00AA55FFFFFFFFFFFF
FFFFFFFFFFFFFF00555555AA55FFFFFFFFAAAA55AA555555FFAAAAAA0000FF00AA55FF55
55AAFFAA00AAAAFF55AAAAFFFFAAFFAAFFFFAAAA55FFAAAA00AAFFAA5555FF55AA00FF00
00AAAAAAFF555555AA55AAAAFFFFFFFF55AA55555500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55FFAAAAAA55AAAA5555AAFFAA55FFAA00AAAA0000AAFFFF55AAAA
AAAAFF0000AA5555FFAAAAFF00AA55AA00FFAAAAFF5555AA0000FFAAAAAAAA55FFFFAA00
00AAAA00AAFF55AAFFAA5555AAAA55AAAAAAFF55AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55AAAAFFAAAAAAFFAA55FFFFFF55AAAAFFFF55005555AAAA55FFFF
55FFFFFFAAFFAA55FF55FFFFFFAAAAAAFFFFFF55FF55AAFFAAFFFFFF55FFFF55AAAA5555
0055FFFFAAAA55FFFFFF55AAFFAAAAAAFFAAAA55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055FF5500FF00AAAAAA55AAAAAAFFAA00FFFFAA55FFFF55AAAA
55FF5555FFFFFF55AAAAAA55AAAAFFAAAA55AAAAAA55FFFFFF5555FF55AAAA55FFFF55AA
FFFF00AAFFAAAAAA55AAAAAA00FF0055FF5500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55AAFFFFFFAAAAFFAA555555AAAAFFFFFFFF55AAAA55FFFF
55AAAAAAAA55AAAAAAFFAAAAAA005500AAAAAAFFAAAAAA55AAAAAAAA55FFFF55AAAA55FF
FFFFFFAAAA555555AAFFAAAAFFFFFFAA55AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AA00FFAA00AA55AA55FFAA555555FF5555FFAAAAFF5555
FFAAAAFFAAAAAAFFAAAA5555AA000000AA5555AAAAFFAAAAAAFFAAAAFF5555FFAAAAFF55
55FF555555AAFF55AA55AA00AAFF00AA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF005555FFFFAAAAAAFF5555AAFF55AAAAAAAA5555AAAAAA
AA5555AAAA0055AAAAFFAA55FFFFAAFFFF55AAFFAAAA5500AAAA5555AAAAAAAA5555AAAA
AAAA55FFAA5555FFAAAAAAFFFF555500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF555555AA55AAFF55FF55AA00AAAAFF55AA5555
AA55FFAAAA000000FF00AA55FF555555FF55AA00FF000000AAAAFF55AA5555AA55FFAAAA
00AA55FF55FFAA55AA555555FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAAAAAAAAFF55FF55AAAAAAFFFF55FF55AA55FF
AAAAAA5500AA0000AAFFFF55AAAAAAAAAA55FFFFAA0000AA0055AAAAAAFF55AA55FF55FF
FFAAAAAA55FF55FFAAAAAAAAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFF55FF55AAAAAA00AAAA55AAFF00FF55AA
AA0055FFAAFFAAFFFF5555FFAAAAFFAAAAFF5555FFFFAAFFAAFF5500AAAA55FF00FFAA55
AAAA00AAAAAA55FF55FFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAAAA55FFFF550055FFFF00005555FFAA
AAFFFF00AA55AA00FFAA55FF55FFFFFF55FF55AAFF00AA55AA00FFFFAAAAFF55550000FF
FF550055FFFF55AAAAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00AAAAAA55AAFFFF00AAFFFFAA55FF55
FFFFFFFFAAAAAAFFFFFF55AAAAAA55AAAAAA55FFFFFFAAAAAAFFFFFFFF55FF55AAFFFFAA
00FFFFAA55AAAAAA00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555AA55FFFFFFFFAAAA55AA55FF55
AAAA55AAAAFFAAAA55AAAAAAFFAAAAAAFFAAAAAA55AAAAFFAAAA55AAAA55FF55AA55AAAA
FFFFFFFF55AA55555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAAAAAA55AAAA5555AAFFAA55AA
FFAAAAAAFFAA00AAAAAAFFAAAA555555AAAAFFAAAAAA00AAFFAAAAAAFFAA55AAFFAA5555
AAAA55AAAAAAFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAAFFAAAAAAFFAA55FFFFFF55AA
00FF0055FF550055AA00AAFFAAAAAAAAAAFFAA00AA550055FF5500FF00AA55FFFFFF55AA
FFAAAAAAFFAAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF5500FF00AAAAAA55AAAAAA
FFFFFFAA55AAFFFF0000AAAA5555555555AAAA0000FFFFAA55AAFFFFFFAAAAAA55AAAAAA
00FF0055FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFFFFFFAAAAFFAA555555
AAAA55AA55FFFFFFFFAAFFAAAAAAAAAAAAAAFFAAFFFFFFFF55AA55AAAA555555AAFFAAAA
FFFFFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00FFAA00AA55AA55FFAA
5555AAFFAA55AAAA55AA55AA5555555555AA55AA55AAAA55AAFFAA5555AAFF55AA55AA00
AAFF00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555FFFFAAAAAAFF5555
AAFF55FF55FFAAAAFF55FFAAAAAAAAAAAAAAFF55FFAAAAFF55FF55FFAA5555FFAAAAAAFF
FF555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF555555AA55AAFF
55FF55AAAAAA5555AAAAAA55555555555555AAAAAA5555AAAAAA55FF55FFAA55AA555555
FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAAAAAAAAFF55FF
55AAAAAAFFAAAAAAAAFFAAAAAAAAAAAAAAAAAAFFAAAAAAAAFFAAAAAA55FF55FFAAAAAAAA
AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFF55FF55AA
AAAA00AA55AA555555AAAAFFAAAAFFAAAAFFAAAA555555AA55AA00AAAAAA55FF55FFFF55
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAAAA55FF
FF550055FFAAAAAAAAAAFFAA00AA55AA00AAFFAAAAAAAAAAFF550055FFFF55AAAAAA55AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00AAAAAA
55AAFFFF00AA5555555555FFFFAAAAAAFFFF5555555555AA00FFFFAA55AAAAAA00AA55FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555AA
55FFFFFFFFAAAAAAAAAAAAAA55AA00AA55AAAAAAAAAAAAAAFFFFFFFF55AA55555500FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAA
AAAA55AAAA5555AA00AA5555AAFFAAFFAA5555AA00AA5555AAAA55AAAAAAFF55AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA
FFAAAAAAFFAA55FFFFAAAAAAAA00FF00AAAAAAAAFFFF55AAFFAAAAAAFFAAAA55FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055
FF5500FF00AAAAAA55AA00AAAAFFFFFFAAAA00AA55AAAAAA00FF0055FF5500FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
55AAFFFFFFAAAAFFAA555500AAAA55AAAA005555AAFFAAAAFFFFFFAA55AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
55AA00FFAA00AA55AA55FFAAFFAAAAAAFFAAFF55AA55AA00AAFF00AA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF005555FFFFAAAAAAFF5555AAAAFFAAAA5555FFAAAAAAFFFF555500FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA55FF55555555AAAAAAAA005500AAAAAAAA55555555FF55AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55AAAAAAAAAAAA0055AA000000AA5500AAAAAAAAAAAA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0055FFFF55FFFFAA5555005555AAFFFF55FFFF5500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA55AAAAAA55AA55FFAAFF55AA55AAAAAA55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF55AA00AAAAAAFF555555FFAAAAAA00AA55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0055555555AAAAAAAAAA5555555500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55FFAA5555AA5555AAFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55AAAAFF55AA55FFAAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055FF55AA55FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55AAFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AA55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.864154 0.200176 0.951464 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000FF00AA00FFFFFFAAAA5500AAAA55AA00FF00550055AAAA000000000000FFFFAA
00FFFF55550000000000FF00AAAAFFAAAA00FF00000000005555FFFF00AAFFFF00000000
0000AAAA55005500FF00AA55AAAA0055AAAAFFFFFF00AA00FF000000FF
FFFF0055FFFFAA00000000005500AAAA55AA00FFFFFF0000AA55AAAA00AA00AAAAAAFFAA
00000000FF005555AAFFFFFF00AAFFAA00FFFFFFAA555500FF00000000AAFFAAAAAA00AA
00AAAA55AA0000FFFFFF00AA55AAAA00550000000000AAFFFF5500FFFF
FFFFFF0000000055FFAA555500AAAA55AA00FFFFFFFFFFAA55AA00FFAA55AAFF00AAFFAA
0000AA000000AA550000000000AAFFAA000000000055AA000000AA0000AAFFAA00FFAA55
AAFF00AA55AAFFFFFFFFFF00AA55AAAA005555AAFF5500000000FFFFFF
FFFFFFFF0055FF00000055AA00005500AAFFFFFFFFFFFF555555FFAAAA55000000AAFFAA
00AAAA5555AA55AA0000AA0000AAFFAA0000AA0000AA55AA5555AAAA00AAFFAA00000055
AAAAFF555555FFFFFFFFFFFFAA00550000AA55000000FF5500FFFFFFFF
FFFFFFFFFF000000AAAA0055005555550000000000000000FF0000005500AAAA00AAFFAA
00005500AA55AA00FFFFAA0000AAFFAA0000AAFFFF00AA55AA00550000AAFFAA00AAAA00
55000000FF0000000000000000555555005500AAAA000000FFFFFFFFFF
FFFFFFFFFFFF0055FF5555AA00AA5500AAAAAAAA00AAAA000000AAAA005555FF55000000
555500AA00FF00AAAAFFAA0000AAFFAA0000AAFFAAAA00FF00AA00555500000055FF5555
00AAAA000000AAAA00AAAAAAAA0055AA00AA5555FF5500FFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF00AA00FF005500005500550000AA00005500FF000000FFFF00
55AA00AAFFFFFF00AAFFAA0000AAFFAA0000AAFFAA00FFFFFFAA00AA5500FFFF000000FF
00550000AA000055005500005500FF00AA00FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0055FFFFAA000000AA5555AA00AA5555AAAA0000FFFF5500FFFFFFFF
00005555FFFFFF550000005555000000555500000055FFFFFF55550000FFFFFFFF0055FF
FF0000AAAA5555AA00AA5555AA000000AAFFFF5500FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000055FFAA55AA0055005500AA55AAAA00000000FFFFFFFFFF
5500FF0000000000FFFF0055AA00AA00AA5500FFFF0000000000FF0055FFFFFFFFFF0000
0000AAAA55AA0055005500AA55AAFF5500000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055FF00000055AAAA005555550000FFAA0000AA000000000000
00FFFFFF005555AAFFAAAA00550055005500AAAAFFAA555500FFFFFF00000000000000AA
0000AAFF000055555500AAAA55000000FF5500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000AAAA00550000AA5500AA0000005555AAAA0000AAAAAA
0000000000AA550000005500FF00FF00FF005500000055AA0000000000AAAAAA0000AAAA
5555000000AA0055AA00005500AAAA000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055FF5555AA00AA00FF00FFAA555500AA55AAAA00005500
00AA0000AA00FF00555500AAAAFFFFFFAAAA00555500FF00AA0000AA0000550000AAAA55
AA005555AAFF00FF00AA00AA5555FF5500FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00AA00FFFFFFAAAA5500AAAA5500005555AA00
AAAA55FFAA000000AA5500550000000000550055AA000000AAFF55AAAA00AA5555000055
AAAA0055AAAAFFFFFF00AA00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFFAA00000000005500AAAA55AA0000AA550000
AAFF0000005555AAFF0000AA5555005555AA0000FFAA5555000000FFAA000055AA0000AA
55AAAA00550000000000AAFFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000055FFAA555500AAAA55AA00FFFF00AA5555
000000AA00AA55000000AAAA5500AA0055AAAA00000055AA00AA0000005555AA00FFFF00
AA55AAAA005555AAFF5500000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF00000055AA00005500AAFFFFFF550000FF
00FFFFAA000055AA5555000055AA55AA5500005555AA550000AAFFFF00FF000055FFFFFF
AA00550000AA55000000FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000AAAA0055005555550000000000FFFFAA
AAAAFFAA0000AA55AA005555AA00FF00AA555500AA55AA0000AAFFAAAAAAFFFF00000000
00555555005500AAAA000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF5555AA00AA5500AAAAAAAA00000000
5500000055FFAA00550055AA00FFFFFF00AA55005500AAFF550000005500000000AAAAAA
AA0055AA00AA5555FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00AA00FF0055000055005555AA
5500FFFF00000055555500AAFFFFFFFFFFAA00555555000000FFFF0055AA555500550000
5500FF00AA00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFFAA000000AA5555AA00AA5500
00FFFFFFFF00555555555500000000000000555555555500FFFFFFFF000055AA00AA5555
AA000000AAFFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000055FFAA55AA0055005500AA
000000000000AA5500AA550055550055550055AA0055AA000000000000AA0055005500AA
55AAFF5500000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF00000055AAAA0055555500
00AAAA00AA000055AAFF0000AA550055AA0000FFAA550000AA00AAAA000055555500AAAA
55000000FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000AAAA00550000AA5500AA
000055005500555555FFFFAA55AA00AA55AAFFFF555555005500550000AA0055AA000055
00AAAA000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF5555AA00AA00FF00FF
AA555555AA0000FF0000000055AAAAAA5500000000FF0000AA555555AAFF00FF00AA00AA
5555FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00AA00FFFFFFAA
AA5500AA55AAFFFF5500FFFF0000550000FFFF0055FFFFAA55AA0055AAAAFFFFFF00AA00
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFFAA0000000000
5500AAAA5500000000FFFFFF5500FF0055FFFFFF0000000055AAAA00550000000000AAFF
FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000055FFAA5555
00AAAA55AA0000AA0000000000FFFFFF0000000000AA0000AA55AAAA005555AAFF550000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF00000055AA
00005500AAFF550000AA00AAAAAAFFAAAAAA00AA000055FFAA00550000AA55000000FF55
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000AAAA0055
00555555000000FFFFAA000055000000550000AAFFFF000000555555005500AAAA000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF5555AA
00AA5500AAAA00000000555500AA00AA00555500000000AAAA0055AA00AA5555FF5500FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00
AA00FF00550000AA0000AA55005500550055AA0000AA00005500FF00AA00FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFF
AA000000AA5555AAAAAAAA550055AA550055AAAAAAAA5555AA000000AAFFFF5500FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0055FFAA55AA005500005500AA005500AA005500005500AA55AAFF5500000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055
FF00000055AAAA00555500AAAA555555AAAA00555500AAAA55000000FF5500FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000AAAA00550000AA5500550000FF0000550055AA00005500AAAA000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0055FF5555AA00AA00FF00FF00FFFFFF00FF00FF00AA00AA5555FF5500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FF00AA00FFFFFFAAAAAAFFAAAAAAFFFFFF00AA00FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0055FFFFAA000000000055000000550000000000AAFFFF5500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000055FFAA555500AAAAAA005555AAFF5500000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0055FF00000055AA0000550000AA55000000FF5500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000AAAA005500555555005500AAAA000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0055FF5555AA0000FF0000AA5555FF5500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FF00AA000000AA00FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0055FFFFAA00AA00AAFFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000055FF5500000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055FF000000FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000AA000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.864154 0.39418 0.951464 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00AAFFFF000000FF555555FFAAAA00AA55FF5500FFFF0055FF00AAAAAAFFFF555555AA
55AAAAAAAA5555FF5500FF55555555555555FF0055FF5555AAAAAAAA55AA555555FFFFAA
AAAA00FF5500FFFF0055FF55AA00AAAAFF555555FF000000FFFFAA00FF
FFFF0055550000550055AA005555AA55FF00AA00FFFF55FFAA000055FF00555500AA55AA
5500FF5500FF00AA00FFFF55555555555555FFFF00AA00FF0055FF0055AA55AA00555500
FF550000AAFF55FFFF00AA00FF55AA555500AA5500550000555500FFFF
FFFFFF00AAFFFF000000FF55AAAA5555FFFF00550055555500FFFFAA000000FFAA5555FF
000000AAFFFFFF005500555555555555555555005500FFFFFFAA000000FF5555AAFF0000
00AAFFFF00555555005500FFFF5555AAAA55FF000000FFFFAA00FFFFFF
FFFFFFFF0055550000550055AA555555FFFFFF000055AA00FFFFFF550000550055FF5555
00000055FFFFFF55AAAAAA55AAAA55AAAA55AAAAAA55FFFFFF550000005555FF55005500
0055FFFFFF00AA550000FFFFFF555555AA5500550000555500FFFFFFFF
FFFFFFFFFF00AAFFFF000000FF555555FFFF55FFAA55AA55FFFF55FF55AAFF00FFAAAA55
AAFFFFAA0000AA00FF5500FF0055FF5500FF0055FF00AA0000AAFFFFAA55AAAAFF00FFAA
55FF55FFFF55AA55AAFF55FFFF555555FF000000FFFFAA00FFFFFFFFFF
FFFFFFFFFFFF0055550000550055AA00555500AA00AA5555FFFF555500AAAAFFFF5500FF
00555500FFFF00550055AAFFAA550055AAFFAA55005500FFFF00555500FF0055FFFFAAAA
005555FFFF5555AA00AA00555500AA5500550000555500FFFFFFFFFFFF
FFFFFFFFFFFFFF00AAFFFF000000FF55AAAA55FF00FF5555550055AAAAAA00AA0000FFFF
55AAAA55FFFFFF000000FF55FF000000FF55FF000000FFFFFF55AAAA55FFFF0000AA00AA
AAAA5500555555FF00FF55AAAA55FF000000FFFFAA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0055550000550055AA5555550000AA55AAAAAA5555AA55FF00FFFFFF
5555AA5500555500000055555500000055555500000055550055AA5555FFFFFF00FF55AA
5555AAAAAA55AA0000555555AA5500550000555500FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00AAFFFF000000FF555555FFAA555555AA55555555AAAAFFFFFFFF
555555AAAAAA5500005500AA5500000055AA0055000055AAAAAA555555FFFFFFFFAAAA55
555555AA555555AAFF555555FF000000FFFFAA00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055550000550055AA005555AAAA55AA55AA0055AA5555005555
00AA55AA5555AAAAAAAA55FF0000000000FF55AAAAAAAA5555AA55AA005555005555AA55
00AA55AA55AAAA555500AA5500550000555500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AAFFFF000000FF55AAAA5555AAAA00FF55AA00AA550000FF
AA555555AAAA5555AA5555550000000000555555AA5555AAAA555555AAFF000055AA00AA
55FF00AAAA5555AAAA55FF000000FFFFAA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055550000550055AA555555FF00550055AA55FF00000055
55AAAA55AA55555555AAAA55000000000055AAAA55555555AA55AAAA5555000000FF55AA
55005500FF555555AA5500550000555500FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF000000FF555555FFFF000000FF555500000055
AA00AAAA555555555555AA55000000000055AA555555555555AAAA00AA550000005555FF
000000FFFF555555FF000000FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0055550000550055AA00555500000000AA5500000000
FF55AA55555555555555FF00000000000000FF55555555555555AA55FF0000000055AA00
000000555500AA5500550000555500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF000000FF55AAAA55FFAA55FF0000550000
00AA5555555555FF55555500000000000000555555FF5555555555AA000000550000FF55
AAFF55AAAA55FF000000FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055550000550055AA55555500FFAAAAAAAA55FF
AA555555FF55555500AA550000000000000055AA00555555FF555555AAFF55AAAAAAAAFF
00555555AA5500550000555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF000000FF555555FFAAAA00AAAA0055
55AAAA550055AAAA55FF000000000000000000FF55AAAA550055AAAA555500AAAA00AAAA
FF555555FF000000FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055550000550055AA005555AA55FF005500
AA5555AAAAAA5555AA0000000000000000000000AA5555AAAAAA5555AA005500FF55AA55
5500AA5500550000555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF000000FF55AAAA5555FFFF0000
55FF5555AA5555FF55000055000000000055000055FF5555AA5555FF550000FFFF5555AA
AA55FF000000FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055550000550055AA555555FFFFFF00
FFAAAA5500FFAA0000FFFF00000000000000FFFF0000AAFF0055AAAAFF00FFFFFF555555
AA5500550000555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF000000FF555555FFFF55FF
AAAA00AAFFFF5500005555000000550000005555000055FFFFAA00AAAAFF55FFFF555555
FF000000FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055550000550055AA00555500AA
00AAAAAA0000AAFFFF0000FFFFAA55AAFFFF0000FFFFAA0000AAAAAA00AA00555500AA55
00550000555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF000000FF55AAAA55FF
00FF5500FFFF0055550000555500FF0055550000555500FFFF0055FF00FF55AAAA55FF00
0000FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055550000550055AA555555
0000AA55FFFF55AAAA55FFAA00FFFFFF00AAFF55AAAA55FFFF55AA0000555555AA550055
0000555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF000000FF555555
FFAA5555550055AA55555500FFFF55FFFF00555555AA5500555555AAFF555555FF000000
FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055550000550055AA00
5555AAAA55AAFF0055AA005500555555005500AA5500FFAA55AAAA555500AA5500550000
555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF000000FF55
AAAA5555AAAA000000FF55AAAAAA55AAAAAA55FF000000AAAA5555AAAA55FF000000FFFF
AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055550000550055
AA555555FF00550000555555AA555555AA55555500005500FF555555AA55005500005555
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF000000
FF555555FFFF00000055AAAA5555555555AAAA55000000FFFF555555FF000000FFFFAA00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555000055
0055AA00555500000055AA55555555555555AA55000000555500AA5500550000555500FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF00
0000FF55AAAA55FFAA55AA55AAAA55AAAA55AA55AAFF55AAAA55FF000000FFFFAA00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555500
00550055AA55555500FF0055AA555555AA5500FF00555555AA5500550000555500FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF
FF000000FF555555FFAAAAAA5555555555AAAAAAFF555555FF000000FFFFAA00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055
550000550055AA005555AA55555555555555AA555500AA5500550000555500FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
AAFFFF000000FF55AAAA555555555555555555AAAA55FF000000FFFFAA00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0055550000550055AA5555555555555555555555AA5500550000555500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00AAFFFF000000FF555555FF555555FF555555FF000000FFFFAA00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0055550000550055AA00555555555500AA5500550000555500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00AAFFFF000000FF55AAAA55AAAA55FF000000FFFFAA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0055550000550055AA555555AA5500550000555500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00AAFF55AAAAAA5555555555AAAAAA55FFAA00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00555555AA55555555555555AA55555500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00AA55AA55AAAA55AAAA55AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0055AA55AA555555AA55AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00AAAA5555555555AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055FF555555FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AA00FF00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.864154 0.588183 0.951464 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF0000FFFF00FFFFFFFFFF005555
FFFFFFFFFFFFFFFFFFFF00AAAAFFFFFFAAAA00FFFFFFFFFFFFFFFFFFFF555500FFFFFFFF
FF00FFFF0000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFF005555FFAAFF5555FFAA000000
FFFFFFFFFFFF00FFFF00FF55FFFF00FFFF55FF00FFFF00FFFFFFFFFFFF000000AAFF5555
FFAAFF555500FFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFAA000000FFFF55555555FFFFAAFF
FF00FFFFFFFFFFAA00FF55AA00FFAAFF00AA55FF00AAFFFFFFFFFF00FFFFAAFFFF555555
55FFFF000000AAFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFAAAA0000AAFF00000000FFFFFF55
55FF00FFFF00AAFFAAFF000055FF55FF550000FFAAFFAA00FFFF00FF5555FFFFFF000000
00FFAA0000AAAAFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFFFAAFFAA00AA00AA00FFFF00
00FFFFAA00FF55FF55FF5500FF00FF00FF0055FF55FF55FF00AAFFFF0000FFFF00AA00AA
00AAFFAAFFFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFAAAAAAFFFF550000AAFF00
5555FF55FF00FF00FF00AA5555FF00FF5555AA00FF00FF00FF55FF555500FFAA000055FF
FFAAAAAAFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF55FFFF00FF0055FFFF00
55AA00FF00AA00FF55550000FF00AA00FF00005555FF00AA00FF00AA5500FFFF5500FF00
FFFF55FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FF00FFFFAA0000FFAA00
000055FFAAFFAAFF000000AA00FF55FF00AA000000FFAAFFAAFF55000000AAFF0000AAFF
FF00FF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF00FF5555FFFFAAFF55FF
00555555FFFFFF555500FF55FF00FF00FF55FF005555FFFFFF55555500FF55FFAAFFFF55
55FF00FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFAAFF0000FFFFFF555555
FF000000FFFFFF0000FF555555FF00FF555555FF0000FFFFFF000000FF555555FFFFFF00
00FFAAFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFAAFFFFFFFF0000FF
00AAAA00AAFF00AAAA00FF0000FFAAFF0000FF00AAAA00FFAA00AAAA00FF0000FFFFFFFF
AAFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFAAFF
55000055FFFFFFAAAAFFFFFFAAFF55FFAAFFFFFFAAAAFFFFFF55000055FFAAFFFFFFFFFF
FF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF55
555500FF00AAFF55FFFF00FFFF555555FFFF00FFFF55FFAA00FF00555555FFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFFFFF00FF
000000AAFFFF555555FFAAFF5555555555FFAAFF555555FFFFAA000000FF00FFFFFFFF00
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF00FFFF00FF55
550055FFFFFF000000FFFF55555555555555FFFF000000FFFFFF55005555FF00FFFF00FF
5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFAAFF00AA00FF
0000AA55FFAA00AA00AAFF00000000000000FFAA00AA00AAFF55AA0000FF00AA00FFAAFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFAAFFAAFF
55005500AAFFAAFFAAFFAA0000AA00AA0000AAFFAAFFAAFFAA00550055FFAAFFAAFF55FF
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFF55
AA0000FF55FF55FF55FF55FF0055005500FF55FF55FF55FF55FF0000AA55FFFFFF555555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00
0055FF00FF00FF00FF00AA55AA550055AA55AA00FF00FF00FF00FF550000FFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFF00
555555FF00AA00FF555500000055AA550000005555FF00AA00FF55555500FFFFFFFFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFAA00
000000FFFFAAAA00FF0000AAAA005500AAAA0000FF00AAAAFFFF00000000AAFF5555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFAAAA
0000AA00FFFF55FF00FF550000555555000055FF00FF55FFFF00AA0000AAAAFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FF
FFAAFFAAFF00AA55FF00FF00555555555500FF00FF55AA00FFAAFFAAFFFF55FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555
FFAAAAAAFF550000FFFFAA00000000000000AAFFFF000055FFAAAAAAFF555555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFF55FFFF0000AA00FFAAAA0000AA0000AAAAFF00AA0000FFFF55FFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
FF00FF00FFFFAAFFAAFF55FFFFAAFFAAFFFF55FFAAFFAAFFFF00FF00FFFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
55FF00FF5555FFFFFF555555FFAAAAAAFF555555FFFFFF5555FF00FF5555FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFAAFF0000FFFFFF000000FFFF55FFFF000000FFFFFF0000FFAAFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAFF55FFAAFFFFFFFFFFAAFFFF00FF00FFFFAAFFFFFFFFFFAAFF55FFAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF555555FFFFFFFFFFFFFF5555FF00FF5555FFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFF0000FFAAFF0000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFF00FFFFFFFFFFFFAAFF55FFAAFFFFFFFFFFFF00FFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5555FF00FFFF00FFFFFF555555FFFFFF00FFFF00FF5555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFAAFF00AA00FFFF000000FFFF00AA00FFAAFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAFF55FFAAFFAAFF5555AA5555FFAAFFAAFF55FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF555555FFFFFF55AA005500AA55FFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFF00005555550000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFFFFFFF00555555555500FFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5555FFAA00000000000000AAFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFAAAA0000AA0000AAAAFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF55FFFFAAFFAAFFFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555555FFAAAAAAFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFF55FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFF00FF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5555FF00FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFAAFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.864154 0.782187 0.951464 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00005500550055FF0055FFFFFF5500FF55005500550000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFAAFF00000055AAAAAAAAAA55000000FFAAFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFF55AA0000FFAAAA00AAAAFF0000AA55FFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAFF55AAAA0000FFFF550055FFFF0000AAAA55FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55AAAAFFAAFFFF00FFAAFF00FFFFAAFFAAAA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00AAAAFF55000055AAFFAA55000055FFAAAA00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAAFF55555555FFFFFF55555555FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF550000000000005500000000000055FFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000055000000AA0000FF000000FF0000AA000000550000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAFF0000AA00AA00005555550000AA00AA0000FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF005500AA555555AA0000000000AA555555AA005500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FF5555FF55005555550055FF5555FF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFFFF00AAFF555555FF555555FFAA00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00550000AAAAAA55AAAAAA55AAAAAA00005500FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000AA00AAAA00FF55FF00AAAA00AA000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF005555AA5500000055AA555500FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFAA00FF5555555555FF00AAFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFF55AA550000000000000055AA55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55AAAA00FF0000AA0000FF00AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFAAAAFFFFFFAAFFAAFFFFFFAAAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000055FFFFFFFF005500FFFFFFFF550000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAFF00FFFFFF000000FFFFFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF005500550000555555000055005500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF00AA55AA0000000000AA55AA00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00005555AAAA0000AA0000AAAA55550000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAFF00AAAA0055AA5500AAAA00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00550055FFFFAA00AAFFFF55005500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA0000005500FF0055000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00555500AAFFFFFFAA00555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000AAAAAAAAAA00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAFFFFAAAAFFAAAAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55AAFFAAAAAAFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00AAAAAAFFAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF0055FFFFFF5500FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000055AAAAAAAAAA550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFAAAAFFAAAAFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF55FFFFFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AAAAAAAAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFAAAAFFAAAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000055FF00FF550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFF00FF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00550055005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.864154 0.97619 0.951464 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAAAAA55
AAAAAA5555555555AA0000AA55FFAAFF55AA0000AA5555555555AAAAAA55AAAAAA00AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA5555
55AA555555555500AAAA55AA5500000055AA55AAAA005555555555AA555555AA5555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000AA
000000AA550055AAAA00AA555555FF555555AA00AAAA550055AA000000AA000000FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA55AAAA55
55FF5555AA00FF0055FF5500AA005500AA0055FF5500FF00AA5555FF5555AAAA55AAFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555555AA55
00550055AA55AAFF000055AAAA00FF00AAAA550000FFAA55AA5500550055AA555555AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055555555AA
00FF00AA555555AAFF00AA5555AAAAAA5555AA00FFAA555555AA00FF00AA5555555500FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00555555
AAAAAA5555555555AAFF00555555AA55555500FFAA5555555555AAAAAA55555500AA00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAAA550055
55AA55555555555555AAFF0000AA00AA0000FFAA55555555555555AA55550055AAAAFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555AA00FF
000000FF0000FF0000AAAAAA55AA55AA55AAAAAA0000FF0000FF000000FF00AA5555AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555AAAA
AA55AAAAAA55AAFF00AAAA00AA555555AA00AAAA00FFAA55AAAAAA55AAAAAA55555500FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA0000AAAA
00AA00AAAA0055FFAAFFAAAA5555555555AAAAFFAAFF5500AAAA00AA00AAAA0000AA00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAA55AA55
55FF00AAAA00FF00FF55AA55555555555555AA55FF00FF00AAAA00FF5555AA55AAAA00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA000000
FF00FFAAAAFF00FFAA5500FF0000FF0000FF0055AAFF00FFAAAAFF00FF000000AAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF5555
FFAAFF55FF00FFAA555555FFAAFFFFFFAAFF555555AAFF00FF55FFAAFF5555FF55FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00005555
00000055AAFFFF005555550000005500000055555500FFFFAA5500000055550000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055
55FF555555AAFF5555555555FF555555FF5555555555FFAA555555FF555500AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555
550000AA00000055555555550000FF00005555555555000000AA0000555555FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
AA55AAAAFFFFAA0055555500AAFF00FFAA0055555500AAFFFFAAAA55AA0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
00AA00AAAAAAAA00FF0000AAFFAA55AAFFAA0000FF00AAAAAAAA00AA00AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
5555AAAA00AAAA00FFFFAAFFAA555555AAFFAAFFFF00AAAA00AAAA5555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000AAAAFF0055FF55AAFFAA5555555555AAFFAA55FF5500FFAAAA0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAFFAAAAAA550000AAAAAA0000FF0000AAAAAA000055AAAAAAFFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF55AA5555AA00FFAAAA00AAFF00FFAA00AAAAFF00AA5555AA55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00555555AAAAAA00AAFFAA55AAFFAA00AAAAAA55555500FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA55AA0000AAAA00AAFFAA555555AAFFAA00AAAA0000AA55AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0055AA55AAAAFFAAFFAA5555555555AAFFAAFFAAAA55AA5500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00AA00AA5555AAFFAA55555555555555AAFFAA5555AA00AA00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00AAAA555500AAAAAA00555555555500AAAAAA005555AAAA00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAA0000AAFFAAAAFF0000AA0000FFAAAAFFAA0000AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF55FF5555AAFFAAAAAA55AA55AAAAAAFFAA5555FF55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000555555AAFFAAAA000000AAAAFFAA5555550000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA00555555AAFFAAAA55AAAAFFAA55555500AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF55555500AAAAAA00AA00AAAAAA00555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF00AAAAFFAAFFAAFFAAAA00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAFF5555AA55FFFFFF55AA5555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF55AA000000FFFFFF000000AA55FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA5500FFAA00FFFFFF00AAFF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0055AAAAAA00FFFFFF00AAAAAA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00AA00AAAA00FFFFFF00AAAA00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00AAAA5555AAAAAAAAAA5555AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA0000AAAA00AAAA0000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55FF5555AA55AA5555FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000555500FF0055550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA0055AAAAAA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF555555AA555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000AA00AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFFAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.960195 0.200176 1.04751 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00FF00AAFFAAAAAAAAAA000000AAAAFFFF00FFAAAAAA00AAAAAA0000AAAA00FFFF00FF
FFFFAAAAFF55AAAA555555FF00AAAAAA00FF555555AAAA55FFAAAAFFFFFF00FFFF00AAAA
0000AAAAAA00AAAAAAFF00FFFFAAAA000000AAAAAAAAAAFFAA00FF00FF
FFFFAAAA550000FF000000FFAA00FF00005555FFFF00FFFFAA55FFAAFF0000FFAAAAFFFF
FFFFFF0000AAAAAAAA00AAAAFF000000FFAAAA00AAAAAAAA0000FFFFFFFFFFAAAAFF0000
FFAAFF55AAFFFF00FFFF55550000FF00AAFF000000FF000055AAAAFFFF
FFFFFF00FF5555FFFFAAFFFF55AAAAFF00AAAA0000AAFFAAAAAA000000AAFFFFFF000055
550000AAFF000000FF00AA55FFFFAAFFFF55AA00FF000000FFAA000055550000FFFFFFAA
000000AAAAAAFFAA0000AAAA00FFAAAA55FFFFAAFFFF5555FF00FFFFFF
FFFFFFFFAAAA00AA0000005500FF0000AAFF55AAAA5500000000FFAA00FFFF55FFFFAA00
AAAA55AAFFAAFF00AA00FF00550000005500FF00AA00FFAAFFAA55AAAA00AAFFFF55FFFF
00AAFF0000000055AAAA55FFAA0000FF0055000000AA00AAAAFFFFFFFF
FFFFFFFFFF00FFAA55AAAA5555FFFFAAFF55FF0000FF5555FF555500AAFFAAAA000055AA
AAAAAA005500AA00FFFFAAAA5555FF5555AAAAFFFF00AA005500AAAAAAAA550000AAAAFF
AA005555FF5555FF0000FF55FFAAFFFF5555AAAA55AAFF00FFFFFFFFFF
FFFFFFFFFFFFAAAAAA0055AA5555000000AAAAFFFFAAAA00AA00AAAA550055AAFF00AAAA
AAAAAAAA5555FFAAFFAAAAAAAA00AA00AAAAAAAAFFAAFF5555AAAAAAAAAAAA00FFAA5500
55AAAA00AA00AAAAFFFFAAAA0000005555AA5500AAAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00AAAAAA00AAFFFFAA55FFFF55AAFFFF00AA55FF00AAAAAAFF0000
FFFF0000FF5500000055AA0055AAAAAA5500AA5500000055FF0000FFFF0000FFAAAAAA00
FF55AA00FFFFAA55FFFF55AAFFFFAA00AAAAAA00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA5500AA55AAFFAAAAAA0000AAAAAAFFAA0055FFFFAA5500AA00FF
AAAAFF00AA00AAFF00AAAAAA5555555555AAAAAA00FFAA00AA00FFAAAAFF00AA0055AAFF
FF5500AAFFAAAAAA0000AAAAAAFFAA55AA0055AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF555555AAFFAA55FFAAFFFF00FFFFFF00AAAAFFAA5555FFAA00
00FFFF555555FFAAAA5500AA5555AA5555AA0055AAAAFF555555FFFF0000AAFF5555AAFF
AAAA00FFFFFF00FFFFAAFF55AAFFAA555555FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA00AAAAAAFF550000005555FFFFFF5555555500AAAA0000FF
AA0000AAAA00AA0055AA55AA00AAAAAA00AA55AA5500AA00AAAA0000AAFF0000AAAA0055
555555FFFFFF555500000055FFAAAAAA00AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFAA55FFAAAA00FFAA00AAAAFFAAAA00AAAA00FF00FFAA00
00FFAAFF55AAAAAA555555AAFFFF00FFFFAA555555AAAAAA55FFAAFF0000AAFF00FF00AA
AA00AAAAFFAAAA00AAFF00AAAAFF55AAFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAAAA0000FFFFAAAAAA55FFAAAAAAAA55FFAAFFAA0000FF
AA000000AAAAAAAAAA00AAAAAAFFAAFFAAAAAA00AAAAAAAAAA000000AAFF0000AAFFAAFF
55AAAAAAAAFF55AAAAAAFFFF0000AAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00AAFFAAAAAAAAAA00000000FF0055555500AAFFFF
FF00AAFFFF00FFFF00FFAA55FFAAAAAAFF55AAFF00FFFF00FFFFAA00FFFFFFAA00555555
00FF00000000AAAAAAAAAAFFAA00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA550000FF000000FFAA00FFAAAA5555AA55AA0000
5555FFAAAAFFFFFFFFAAAAAA0000FF0000AAAAAAFFFFFFFFAAAAFF55550000AA55AA5555
AAAAFF00AAFF000000FF000055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF5555FFFFAAFFFF55AAAAFF55AA555555AAFF00
AAAA00000000AA0000AA55FFAAFFFFFFAAFF55AA0000AA00000000AAAA00FFAA555555AA
55FFAAAA55FFFFAAFFFF5555FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA0000005500FF0000AAAAAA00AAAAAAFF
00FFFFAAFFFFAA55AAAAAA000000AA000000AAAAAA55AAFFFFAAFFFF00FFAAAAAA00AAAA
AA0000FF0055000000AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA55AAAA5555FFFFAAFF55AAFFFF00FFFF
55550000005500AAAAAAAAAA55AAAAAA55AAAAAAAAAA00550000005555FFFF00FFFFAA55
FFAAFFFF5555AAAA55AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA0055AA5555000000AAAAAAFFAAFFAA
AA00AAFF00AAAA5500AA5500AAAAAAAAAA0055AA0055AAAA00FFAA00AAAAFFAAFFAAAAAA
0000005555AA5500AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00AAAAAA00AAFFFFAA55FFAAAAAAFF
55AAAAAAFF0000FF555555AAAAAAAAAAAAAA555555FF0000FFAAAAAA55FFAAAAAAFF55AA
FFFFAA00AAAAAA00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500AA55AAFFAAAAAA0000000000
AAAAAAAAAAFFFFAAAA00AAAAAAAAAAAAAAAAAA00AAAAFFFFAAAAAAAAAA0000000000AAAA
AAFFAA55AA0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF555555AAFFAA55FFAA00FFAAFF
000000FF0000AA0055AAAAAAAAAAAAAAAAAAAAAA5500AA0000FF000000FFAAFF00AAFF55
AAFFAA555555FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAAAAFF550000FFAAAAAA
FF00AAFFAA00FF00AAAAAAAAAAAAAAAAAAAAAAAAAA00FF00AAFFAA00FFAAAAAAFF000055
FFAAAAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA55FFAAAA00FFAAAAAAAA
AAFF000055AAAAFF00FF00FFFF00FF00FFFF00FF00FFAAAA550000FFAAAAAAAAAAFF00AA
AAFF55AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA0000FFFFAAAAAAAAAA
AAAAFF00AAAAAAAAFFFFFFAAAAFFFFFFAAAAFFFFFFAAAAAAAA00FFAAAAAAAAAAAAAAFFFF
0000AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00AAFFAAAAAAAAAAAA
AAAAAAFFFF00FF0000AA00000000AA00000000AA0000FF00FFFFAAAAAAAAAAAAAAAAAAFF
AA00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA550000FF000000FF
FF00FFFFFFFFAAAA55AAFFFFAA00FF00AAFFFFAA55AAAAFFFFFFFF00FFFF000000FF0000
55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF5555FFFFAAFFFF
FFFFAAAAFFAAAAAAAA00555500AAFFAA00555500AAAAAAAAFFAAAAFFFFFFFFAAFFFF5555
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA00000055
0000AA550000FF00FF00AAAA00FFFFFF00AAAA00FF00FF000055AA000055000000AA00AA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA55AAAA55
55FF55AA55AAAAFFFF55555555FFFFFF55555555FFFFAAAA55AA55FF5555AAAA55AAFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA0055AA
555500FF0055AA0000AAAA00AAAAFFAAAA00AAAA0000AA5500FF005555AA5500AAAAAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00AAAA
AA00AAFFAA00AA55AAAAAAAA5500AA0055AAAAAAAA55AA00AAFFAA00AAAAAA00FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500
AA55AA0000FFAA555555555555AAAAAA555555555555AAFF0000AA55AA0055AAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55
5555AAFFFFAAAAAA00AAAA00AAAAAAAAAA00AAAA00AAAAAAFFFFAA555555FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
00AAAAAAFFAA55FFAAFF55AAAAAAAAAAAAAA55FFAAFF55AAFFAAAAAA00AAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFAA55FFAAAAAA000000AAAAAAAAAAAAAAAAAA000000AAAAAAFF55AAFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAAAA00000000FFAAFF00FFFF00FF00FFFF00FFAAFF00000000AAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00AAFFFFAAAAAAFFFF55FF55FF55FFFFAAAAAAFFFFAA00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAA55FFFFFF000000AA00AA00AA00AA000000FFFFFF55AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF55FFFFFFAA00FFFFAA55AAFFFF00AAFFFFFF55FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAA0000555555FFFF55AA55FFFF5555550000AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFAA00AAAA0000AAAAAA0000AAAA00AAFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAAAA55FFAA00FF00FF00AAFF55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF005500AAFFAAFFAA005500FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA5555FFAAAAAAFF5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF55000000000055FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA00FFAAFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFAAAAAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.960195 0.39418 1.04751 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55555555AAAAAAAA55AA55AAAAAAAA00AA
000000AA5555AA0000AAAA55FFFFFFFFFF55AAAA0000AA5555AA000000AA00AAAAAAAA55
AA55AAAAAAAA55555555FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAA55AAAA55FF55AAAA5555AA00
FF0000AAAAAAAA0000AAAA55FFFFFFFFFF55AAAA0000AAAAAAAA0000FF00AA5555AAAA55
FF55AAAA55AAAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAAA00AAAAAA00FFFFFF00AAAAAAAA00
0000AA5555AAAA0000AAAA55FFFFFFFFFF55AAAA0000AAAA5555AA000000AAAAAAAA00FF
FFFF00AAAAAA00AAAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF555555AAAA0000000000AAAA5555AA
0000AAAAAAAA55555555AA55FFFFFFFFFF55AA55555555AAAAAAAA0000AA5555AAAA0000
000000AAAA555555FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAA55555555555555AAAAAAAA
0000AAAA55AAAAAAAAAAAA55FFFFFFFFFF55AAAAAAAAAAAA55AAAA0000AAAAAAAA555555
55555555AAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA55AAAAAAAAAAAAAAAAAA55AAAA
005555AAAAAA5555AA55AA55FFFFFFFFFF55AA55AA5555AAAAAA555500AAAA55AAAAAAAA
AAAAAAAAAA55AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55AAAA00AAAA55AA55AAAAAA00
AA55FFAA00AAFF55AAAAAA55FFFFFFFFFF55AAAAAA55FFAA00AAFF55AA00AAAAAA55AA55
AAAA00AAAA55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA555555AA55FF00FF5555AA
00FFFF555555FFFF00AAAA55FFFFFFFFFF55AAAA00FFFF555555FFFF00AA5555FF00FF55
AA555555AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAAAAAAAAA55FFFFAAAAAAAA
000000005500000000AAAA55FFFFFFFFFF55AAAA000000005500000000AAAAAAAAFFFF55
AAAAAAAAAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF5555AAAA55FFFF5500FF55
555555550000AA0000AAAA55FFFFFFFFFF55AAAA0000AA00005555555555FF0055FFFF55
AAAA5555FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA00FFFFFFFF000000
5500005500AA55555555AA55FFFFFFFFFF55AA55555555AA0055000055000000FFFFFFFF
00AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAAA000000000000AA00
0055550000AAAAAAAAAAAA55FFFFFFFFFF55AAAAAAAAAAAA000055550000AA0000000000
00AAAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF5555555555555555AA
00550000AA00AAAA5555AA55FFFFFFFFFF55AA5555AAAA00AA00005500AA555555555555
5555FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAAAAAAAAAA
005500AA555555AAAAAAAA55FFFFFFFFFF55AAAAAAAA555555AA005500AAAAAAAAAAAAAA
AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA55AA5555AAAA55
550000AAAAAAAAAA5555AA55FFFFFFFFFF55AA5555AAAAAAAAAA00005555AAAA5555AA55
AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55AAAAAAAA00FF
FF0000AAAA5555AAAAAAAA55FFFFFFFFFF55AAAAAAAA5555AAAA0000FFFF00AAAAAAAA55
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55AAAA0000
0000AA00AAAAAAAA00AAAA55FFFFFFFFFF55AAAA00AAAAAAAA00AA00000000AAAA55AAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAAAAA00AA00
00FF005555AAAA555555AA55FFFFFFFFFF55AA555555AAAA555500FF0000AA00AAAAAA55
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF5555AA00FF
000000FFFF00AAAAAAAAAA55FFFFFFFFFF55AAAAAAAAAA00FFFF000000FF00AA5555FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA0000
00AA00000000AAAA5555AA55FFFFFFFFFF55AA5555AAAA00000000AA000000AAAAAAAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAAA0000
AA00AA0000FF00AAAAAAAA55FFFFFFFFFF55AAAAAAAA00FF0000AA00AA0000AAAA5555FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF555555
55AA00FF000000FF5555AA55FFFFFFFFFF55AA5555FF000000FF00AA55555555FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA
AAAA000000AA0000005500FFFFFFFFFFFFFF0055000000AA000000AAAAAAAAAAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA55
AAAA0000AA55AA0055AAFFFFFFFFFFFFFFFFFFAA5500AA55AA0000AAAA55AA5555FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55
AAAA0000AAAAAA000055FFFFFFFFFFFFFFFFFF550000AAAAAA0000AAAA55FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
AA55555555AAAA0000FFFFFFFFFFFFFFFFFFFFFF0000AAAA55555555AAAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555
AAAAAAAAAAAA00AA00000000000000000000000000AA00AAAAAAAAAAAA5555FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF5555AAAA00AA00AA0000FF0000AA0000FF0000AA00AA00AAAA5555FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAAAAAA00FF00AA55AA000000AA00AA000000AA55AA00FF00AAAAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
5555AAAA000000AAAAAA0000AA00FF00AA0000AAAAAA000000AAAA5555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF5555555555AAAA0000AAFFFFFFAA0000AAAA5555555555FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAAAAAAAAAAA00AA0055FFFFFF5500AA00AAAAAAAAAAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF5555AA55AAAA00AA555500000000005555AA00AAAA55AA5555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFAA5555AA00FFFF0000AA0000FFFF00AA5555AAFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAA55FFAA00000000AA55AA00000000AAFF55AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF5555AAFFAA00555500AAAAAA00555500AAFFAA5555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFAAAA0000550055FF5500550000AAAAFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAA5555550000FFFFFF0000555555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF5555AAFF55AA0000000000AA55FFAA5555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFAAAAAA0000FF0000AAAAAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA5555AA000000AA5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF5555AAFF5555555555FFAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFAAAAAAAAAAAAAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA5555FF5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5555AAFF55FFAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFAAAAAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5500FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.960195 0.588183 1.04751 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00AA55AA
00AA0000FFFFFF0055FFFF55AA000000AA55FFFF5500FFFFFF0000AA00AA55AA00FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000AAAA55
5555AA0000000000FFFFFFFF0055555500FFFFFFFF0000000000AA555555AAAA000055FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555AA55
AAAA55550055AA00000000005555FF55550000000000AA55005555AAAA55AA55555555FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA55AA55
AA5555FFAAFF00555555005555FF55FF55550055555500FFAAFF5555AA55AA55AAAA55FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA55AA55
FF00FFFF550000AAFF00FF00FFAAAAAAFF00FF00FFAA000055FFFF00FF55AA55AA5555FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF5555AA
AAFFFFFFFF0000AAAAFFFFFFAAAA00AAAAFFFFFFAAAA0000FFFFFFFFAAAA5555FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF
005500000000FF0055FFFFFF5500FF0055FFFFFF5500FF000000005500FF55AAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFFF
FFAA0000FF000000FFFFFFFFFF000000FFFFFFFFFF000000FF0000AAFFFFFF0055FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
5500FF0000555555000000000000AA0000000000005555550000FF0055000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
FF000000FF00FFFF0000AA0000AA00AA0000AA0000FFFF00FF000000FFFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500
0000AA005500550000FF00555500FF00555500FF000055005500AA00000055FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555
555555AA00FF00AA550000FFFF000000FFFF000055AA00FF00AA5555555555FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA
AAAA55FF000000FF555500550000FF000055005555FF000000FF55AAAAAA55FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555
AA5555FFFFAAFFFFFF00AA55AA000000AA55AA00FFFFFFAAFFFF5555AA5555FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF5555FFFF5500000000AAAA5555555555AAAA0000000055FFFF5555FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAA55FFFF55AA0000AA5555AAAA55AAAA5555AA0000AA55FFFF55AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
5500FFFFFFFF00555500FFFF0055FF5500FFFF00555500FFFFFFFF0055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000550000AAFF00000000FFFFFF00000000FFAA000055000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFF0000AAAAFFFFAAFFFFFFFFFFAAFFFFAAAA0000FFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF55000000FF0055FFFF55000000000055FFFF5500FF00000055FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF555555550000FFFFFFFF0000AA0000FFFFFFFF000055555555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF5555FF55AA000000000000AA00AA000000000000AA55FF5555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF55AAFFAA5555550055555500FF0055555500555555AAFFAA55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF005500FFFF00FF00FFFF000000FFFF00FF00FFFF005500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA000055005500550000FF000055005500550000AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF5500AA55AA00FF00FF000000FF00FF00AA55AA0055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF555555AAAA0055005500AA0055005500AAAA555555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF5555FF5500FF00AA55AA00AA55AA00FF0055FF5555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF55AAFFAA005500AAAA555555AAAA005500AAFFAA55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF005500FF00AA5555AAAAAA5555AA00FF005500FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA000000AAAAAAAA00AAAAAAAA000000AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF5500AA5500FF5500FF0055FF0055AA0055FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF555555AAFFFFFF000000FFFFFFAA555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF5555FF5500000000FF0000000055FF5555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF55AAFFAA0000FF000000FF0000AAFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF005500FF00005555550000FF005500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA000000AA55FF55AA000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF5500AA5500FFFFFF0055AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF555555AAFFFFFFFFFFAA555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF5555FF55000000000055FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55AAFFAA0000FF0000AAFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF005500FF000000FF005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA00005555550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55005555FF55550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF555555FF55FF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFAAAAAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5500FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.960195 0.782187 1.04751 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000AA00000000555555AAAAFFFFAA00FF00AAAA55555555555555AA55FF5555005555
55AA00FFFFFFFF00AA5555555555555555555555AA00FFFFFFFF00AA555555005555FF55
AA55555555555555AAAA00FF00AAFFFFAAAA55555500000000AA0000FF
FFFF00FF55AAFFFF0000AA00AAAA55AA55FF55AA555555555555555555AA00FF00000055
5500FFFF5555FFFF00555555555555555555555500FFFF5555FFFF005555000000FF00AA
555555555555555555AA55FF55AA55AAAA00AA0000FFFFAA55FF00FFFF
FFFFFF00AA5555FFFF00FF55AA555555AA00FF0055555555555555555555AAFF00FFFF00
00FFFF55555555FFFF0000555555555555550000FFFF55555555FFFF0000FFFF00FFAA55
55555555555555555500FF00AA555555AA55FF00FFFF5555AA00FFFFFF
FFFFFFFF00555555FFFF00AA5555555500FFFFFF0000555555555555555555AAAAAA55AA
FFFF555500005555FFFF00FF0000FF0000FF00FFFF555500005555FFFFAA55AAAAAA5555
555555555555550000FFFFFF0055555555AA00FFFF55555500FFFFFFFF
FFFFFFFFFF0000AA00FFAA5555550000FFFFFF55FFAA55005555555555555555AA555555
AAAA550000000055AAAAFF55FFAAFFAAFF55FFAAAA550000000055AAAA555555AA555555
55555555550055AAFF55FFFFFF0000555555AAFF00AA0000FFFFFFFFFF
FFFFFFFFFFFF00FF55AAAA0000FF00FFFFFF555555FF000000550000555500AA00AA0000
FF5500000000000055FF00AA55AA55AA55AA00FF5500000000000055FF0000AA00AA0055
55000055000000FF555555FFFFFF00FF0000AAAA55FF00FFFFFFFFFFFF
FFFFFFFFFFFFFF00AA5555AAFFFFFF00AAFF0000AA55AAFFFF00000000FF00FF55AA55FF
AA0000000000000000FFAA555500FF005555AAFF0000000000000000AAFF55AA55FF00FF
00000000FFFFAA55AA0000FFAA00FFFFFFAA5555AA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00555555AAAAFFAA5555FFAA555555AAAA55FFAAFFFFFF00AA555555
FF00FFFF00FFFFAA55FF550000FFFFFF000055FF55AAFFFF00FFFF00FF555555AA00FFFF
FFAAFF55AAAA555555AAFF5555AAFFAAAA55555500FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000AA00AAAA55555555FF0000AA5555AA00FF5555FFFF00555555
55FFAA00FFFF5555AA00FF00FFFFFFFFFF00FF00AA5555FFFF00AAFF5555555500FFFF55
55FF00AA5555AA0000FF55555555AAAA00AA0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF55AA555555555555FFAA55555555AAFF0000AAFF00FF0000
AA55AA55FF55555500FFFFFFAAAAFFAAAAFFFFFF00555555FF55AA55AA0000FF00FFAA00
00FFAA55555555AAFF555555555555AA55FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AA5555555555555555FF0000555555AAAAAAAA00FFFFFFAA
555555AA00FF0000FFFFFF5555AA55AA5555FFFFFF0000FF00AA555555AAFFFFFF00AAAA
AAAA5555550000FF5555555555555555AA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00555555550000555555FFAA55005555AA5555AAFFAAAA55
55555555AAFFAAFF55FF55555500FF00555555FF55FFAAFFAA5555555555AAAAFFAA5555
AA55550055AAFF55555500005555555500FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000AA00000000555555FF000000AA55555555AAAA00AA
0055555555AAAA00FF00AA0000FFFFFF0000AA00FF00AAAA5555555500AA00AAAA555555
55AA000000FF55555500000000AA0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55AAFFFF0000AA00FFFFAA555500555555AA55FF
00FF0000AA00AAAAAA55FF00FFFFFFFFFF00FF55AAAAAA00AA0000FF00FF55AA55555500
5555AAFFFF00AA0000FFFFAA55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA5555FFFF00FF55AAAA5555000000555555AA00
FFFFFF00FF55AA5555AA00FFFFFFFFFFFFFF00AA5555AA55FF00FFFFFF00AA5555550000
005555AAAA55FF00FFFF5555AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555FFFF00AA5555AA0000000000555500FF
FFFFFFFF00AA55555555AAFF00AAFFAA00FFAA55555555AA00FFFFFFFFFF005555000000
0000AA5555AA00FFFF55555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA00FFAA55555500FFFFAAFFFF0000FFFF
FFFFFFFFFF005555550055FF55AA55AA55FF550055555500FFFFFFFFFFFFFF0000FFFFAA
FFFF00555555AAFF00AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55AAAA0000FF00FFAA00AAFF00FFFFFF
FFFFFFFFFFFF0000FF00FF00AA555555AA00FF00FF0000FFFFFFFFFFFFFFFFFF00FFAA00
AAFF00FF0000AAAA55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA5555AAFFFFFF00AAAAAA00FFFFFFFF
FFFFFF5555FFFF00FFAAFFAA5555555555AAFFAAFF00FFFF5555FFFFFFFFFFFFFF00AAAA
AA00FFFFFFAA5555AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555AAAAFFAA5555AA55FF55FFFF
FFFF55555555FFFF00AAAA55555555555555AAAA00FFFF55555555FFFFFFFF55FF55AA55
55AAFFAAAA55555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA00AAAA55555555AA00FF00AA
FFAA0055555555FF55AA555555555555555555AA55FF5555555500AAFFAA00FF00AA5555
5555AAAA00AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55AA555555555555AAFFAA55
55FF00FF0000FF00AA5555555555555555555555AA00FF0000FF00FF5555AAFFAA555555
555555AA55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA5555555555555555AAAA00
00AAFF55FFAAFFAA55555555555555555555555555AAFFAAFF55FFAA0000AAAA55555555
55555555AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055555555000055AA00AAAA
AAAA00FF00AAAA555555555555555555555555555555AAAA00FF00AAAAAAAA00AA550000
5555555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA00000000FF55AA55
55AA55FF55AA5555555555555555555555555555555555AA55FF55AA5555AA55FF000000
00AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55AAFFFF00AA5555
5500FF00AA55555555555555555555555555555555555555AA00FF00555555AA00FFFFAA
55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA5555FFFF005500
55AAFFAA555555555555555555555555555555555555555555AAFFAA55005500FFFF5555
AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555FFFF0000
00AAAA5555555555555555555555555555555555555555555555AAAA000000FFFF555555
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA00FFAAFF
55AA55555555555555555555555555555555555555555555555555AA55FFAAFF00AA0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55AAAA00
FF005555555555550055555555555555555555550055555555555500FF00AAAA55FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA5555AA
FFAA550055555500000055550000FF000055550000005555550055AAFFAA5555AA00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555
AAAA000000FF0000000000FF00FFFFFF00FF0000000000FF000000AAAA55555500FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA
00AAAAAAAAAA55FFAAFF55AAAAAAFFAAAAAA55FFAAFF55AAAAAAAAAA00AA0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
55AA5555AA555555FF00AA5555AA55AA5555AA00FF555555AA5555AA55FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
AA55555555AA0000FFAA55555500FF00555555AAFF0000AA55555555AA00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
005555555555AAFF5555AA0000FFFFFF0000AA5555FFAA555555555500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000AA0000FF55555555AAFFFFFFFFFFAA55555555FF0000AA0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF55AAFF0000555555AAAAFFAAAA5555550000FFAA55FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00AA5555FFAA55005555AA55AA55550055AAFF5555AA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00555555FF000000AA555555AA000000FF55555500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000AA00FFFFAA5555555555AAFFFF00AA0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF55AAAA55555555555555AAAA55FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00AA5555AA0000FF0000AA5555AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00555555AAFFFFFFAA55555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000AA00AAFFAA00AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF55AA55AA55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AA555555AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.960195 0.97619 1.04751 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FFFFAA0000FF00FF555555AA00AAFFFFFF5555AAAA5555AA00AA0000FFFF0000FF
FFAAFFAAFFFFFFAA55FF55AAFFAA55AAFFAA55FF55AAFFFFFFAAFFAAFFFF0000FFFF0000
AA00AA5555AAAA5555FFFFFFAA00AA555555FF00FF0000AAFFFF0000FF
FFFF00FF55FF55AAFFAA5555555555FFAA00AAAA0000AAFF0000FFAAFF00FFFFFFFF00FF
55FF55FF55FFFF555555AA00FF555555FF00AA555555FFFF55FF55FF55FF00FFFFFFFF00
FFAAFF0000FFAA0000AAAA00AAFF5555555555AAFFAA55FF55FF00FFFF
FFFFFF005555AA00FF55555555555555AAAAAA55AAFF5555AAFFFF5555AAFFAAAAFFAA55
5555AA00AA5555AA0000FFAA5555555555AAFF0000AA5555AA00AA555555AAFFAAAAFFAA
5555FFFFAA5555FFAA55AAAAAA55555555555555FF00AA555500FFFFFF
FFFFFFFF0000FFAA555555555555555555FF555555FF0000FFAAAA0000AAFFAA00FF5555
555555FFAA0000FFAAFFFF55555555555555FFFFAAFF0000AAFF5555555555FF00AAFFAA
0000AAAAFF0000FF555555FF555555555555555555AAFF0000FFFFFFFF
FFFFFFFFFF00FF5555555555555555555555AA0000FF55AAFFAA00FFFFAA00AAFF550000
55555555AAAAAAAA00FF550000555555000055FF00AAAAAAAA55555555000055FFAA00AA
FFFF00AAFFAA55FF0000AA5555555555555555555555FF00FFFFFFFFFF
FFFFFFFFFFFF0055550000AA550000555500AAFFFF0055AAAAFF00FF55FF55AAAA000000
00FF0000AAFF00AAFF5500000000FF0000000055FFAA00FFAA0000FF00000000AAAA55FF
55FF00FFAAAA5500FFFFAA005555000055AA0000555500FFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFAA00000000AA55FF55FF00FF00AAFFAA555555AA00FFAAFF55
AAFFAA55FF55FFAA00AA55FFAAFFFFFFAAFF55AA00AAFF55FF55AAFFAA55FFAAFF00AA55
5555AAFFAA00FF00FF55FF55AA00000000AAFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF55FF55AAFFFF00AA555500FFFFFF00AAAA550000FFAAFFAA00AA
00FF555555AA00AAFF555555AAAAFFAAAA555555FFAA00AA555555FF00AA00AAFFAAFF00
0055AAAA00FFFFFF005555AA00FFFFAA55FF55FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF005555AA00FF55FFAA0000FFFF55FFFFAA00FF00FFFF5555AAAAAA
55FF0000AA55AAFF0055555555FF55FF5555555500FFAA55AA0000FF55AAAAAA5555FFFF
00FF00AAFFFF55FFFF0000AAFF55FF00AA555500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFAA555555AAAAAAAA00AA5555AAAAAAFFFF55005555FF55
5555AAFF555555FF00FF0000AA555555AA0000FF00FF555555FFAA555555FF55550055FF
FFAAAAAA5555AA00AAAAAAAA555555AAFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF5555555555FF5555FFAA0000AAFF00AAAA000000AA5555
0055AAAA00555555AAFFAAFF5555005555FFAAFFAA55555500AAAA55005555AA000000AA
AA00FFAA0000AAFF5555FF5555555555FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055550000AA55555500FFAA55FF55FFAA00FFFFAA55AA00
0000AAFF00FF0000FFAAAA55550000005555AAAAFF0000FF00FFAA000000AA55AAFFFF00
AAFF55FF55AAFF00555555AA0000555500FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFAA0000FF00FF555555AA00AAFFFFFF555555FF
AAFF5555AAFFAAFF55FF555500000000005555FF55FFAAFFAA5555FFAAFF555555FFFFFF
AA00AA555555FF00FF0000AAFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FF55AAFFAA5555555555FFAA00AAAA0000AA55
55FF0000FFAAAA555555AA00000000000000AA555555AAAAFF0000FF5555AA0000AAAA00
AAFF5555555555AAFFAA55FF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555AA00FF55555555555555AAAAAA55AAFF5555
5500FFFFAAAA55AA0000FFAAFFFF00FFFFAAFF0000AA55AAAAFFFF00555555FFAA55AAAA
AA55555555555555FF00AA555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFAA555555555555555555FF555555FF0000
FF00FF55FF555555FFAAFFAA00AAAAAA00AAFFAAFF555555FF55FF00FF0000FF555555FF
555555555555555555AAFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF5555555555555555555555AA0000FF55AA
FFAA555555AA0000FF5555AAAAAA55AAAAAA5555FF0000AA555555AAFFAA55FF0000AA55
55555555555555555555FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055550000AA550000555500AAFFFF0055AA
AAFF0000AA55AAFF55005555FF555555FF55550055FFAA55AA0000FFAAAA5500FFFFAA00
5555000055AA0000555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFAA00000000AA55FF55FF00FF00
AAFFAAFF555555FF000000AA5555555555AA000000FF555555FFAAFFAA00FF00FF55FF55
AA00000000AAFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FF55AAFFFF00AA555500FFFFFF
00AAAA5555000055FFAAFF55555555555555FFAAFF5500005555AAAA00FFFFFF005555AA
00FFFFAA55FF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555AA00FF55FFAA0000FFFF55FF
FFAA00FF00000000AAAA555555555555555555AAAA00000000FF00AAFFFF55FFFF0000AA
FF55FF00AA555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFAA555555AAAAAAAA00AA55
55AAAAAAFFFFAA55FF5555555555555555555555FF55AAFFFFAAAAAA5555AA00AAAAAAAA
555555AAFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF5555555555FF5555FFAA00
00AAFF00AAAA00FF00555555555500555555555500FF00AAAA00FFAA0000AAFF5555FF55
55555555FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055550000AA55555500FFAA
55FF55FFAA00FFFFFF0000555500000055550000FFFFFF00AAFF55FF55AAFF00555555AA
0000555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFAA0000FF00FF55
5555AA00AAFFFFFFFFFF00FF0000000000FF00FFFFFFFFFFAA00AA555555FF00FF0000AA
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FF55AAFFAA5555
555555FFAA00AAAA00AAAAAAFFFF00FFFFAAAAAA00AAAA00AAFF5555555555AAFFAA55FF
55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555AA00FF555555
55555555AAAAAA55AAFF00AAFFAAAAAAFFAA00FFAA55AAAAAA55555555555555FF00AA55
5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFAA55555555
5555555555FF555555FFFF00AAAA55AAAA00FFFF555555FF555555555555555555AAFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF5555555555
555555555555AA0000FF55FFAA00FF00AAFF55FF0000AA5555555555555555555555FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055550000AA
550000555500AAFFFF0055AA55AAFFAA55AA5500FFFFAA005555000055AA0000555500FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFAA
00000000AA55FF55FF00FF00AA55AA55AA00FF00FF55FF55AA00000000AAFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FF
55AAFFFF00AA555500FFFFFF00AA55AA00FFFFFF005555AA00FFFFAA55FF55FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555
AA00FF55FFAA0000FFFFFFFFFF00AA00FFFFFFFFFF0000AAFF55FF00AA555500FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFAA555555AAAAAAAA00AAAAFFAA55AAFFAAAA00AAAAAAAA555555AAFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF5555555555FF5555FFAA00FF555555FF00AAFF5555FF5555555555FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0055550000AA55555500FFAA5555555555AAFF00555555AA0000555500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFAA0000FF00FF55555555555555FF00FF0000AAFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF55FF55AAFFAA555555555555555555AAFFAA55FF55FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF005555AA00FF5555555555555555555555FF00AA555500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFAA55555555555555555555555555AAFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF555555005555005500555500555555FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF005555000000FF00FF00FF000000555500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFAAFFAAFFAAFFAAFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF55FF55FF55FF55FF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF005555AA00AA00AA555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFAA55AAFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF555555FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.05624 0.200176 1.14355 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00AA00FF00AAFFFFFFFF005500AAFF00AA00AAAA55AA5500AA00550000AA00AAAAAAAA
AA00000000AAAAFFFFFF00FF5555005555FF00FFFFFFAAAA00000000AAAAAAAAAA00AA00
005500AA0055AA55AAAA00AA00FFAA005500FFFFFFFFAA00FF00AA00FF
FFFF0055555500000000FF00FFAA5555550000AAAA00FF555500FFFFAAAAAA00005500FF
550055550055FF0000FF00FF00AAFFAA00FF00FF0000FF550055550055FF00550000AAAA
AAFFFF005555FF00AAAA0000555555AAFF00FF0000000055555500FFFF
FFFFFF00AAFFFF00FFFF0000AA5555FF5555005500FFFFFFAA00000000550000AA00FFFF
FFAAAA55AAFF0000AA0055555500000055555500AA0000FFAA55AAAAFFFFFF00AA000055
00000000AAFFFFFF0055005555FF5555AA0000FFFF00FFFFAA00FFFFFF
FFFFFFFF0055AA00000000AA00AAFFFFFFAAFFAA00000000005555005555FFAAAA000000
000055FF5500AA00005555FF5555005555FF55550000AA0055FF550000000000AAAAFF55
550055550000000000AAFFAAFFFFFFAA00AA00000000AA5500FFFFFFFF
FFFFFFFFFF00AAAAAAFFAA5555000000000055AA55FFAAAAAAFFFFAAAA55AA00AAAAFFAA
AAAAFFFFFFAAAA0000AAFFFFFFAAFFAAFFFFFFAA0000AAAAFFFFFFAAAAAAFFAAAA00AA55
AAAAFFFFAAAAAAFF55AA5500000000005555AAFFAAAAAA00FFFFFFFFFF
FFFFFFFFFFFF00550000FF5555FFAAAAFF55AAAA00FF00550000000055FF550055000000
55000000000055FFFF5500AA5500FF0055AA0055FFFF55000000000055000000550055FF
55000000005500FF00AAAA55FFAAAAFF5555FF00005500FFFFFFFFFFFF
FFFFFFFFFFFFFF00AA0000FFAA005500FF00AAAA0000FFFFAAAAAAAAFFFFFFAA55AAFF55
AAAAAAAAAAAAFFFFFFFFAAAA00FFFFFF00AAAAFFFFFFFFAAAAAAAAAAAA55FFAA55AAFFFF
FFAAAAAAAAFFFF0000AAAA00FF005500AAFF0000AA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00555500AAAAFFFF0000AAAA0000AA55000055FF000000FF5555AA00
FF5500005500000000000055FFFFFFFFFF5500000000000055000055FF00AA5555FF0000
00FF55000055AA0000AAAA0000FFFFAAAA00555500FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00AAFF5500000000AA00AAAAAAAA00FFFF55555500555555FF5500
55AAAAFFAAFF55FFAAAAAAFFFFFFFFFFFFFFAAAAAAFF55FFAAFFAAAA550055FF55555500
555555FFFF00AAAAAAAA00AA0000000055FFAA00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055AAAAAAFFAA555500005500FFFFFFFFAA00FFFFAAFFFFFFAA
55AA555555AA00FF00550000FF000000FF00005500FF00AA555555AA55AAFFFFFFAAFFFF
00AAFFFFFFFF005500005555AAFFAAAAAA5500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AAAA00AA5555FF55AAFFFF000000000055555555AA0055AA
55AA55AAAA555500AA00FFFF0000AA0000FFFF00AA005555AAAA55AA55AA5500AA555555
550000000000FFFFAA55FF5555AA00AAAA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00550055FF555555FF0000FFFF00FFFF00AAFF00AAAAAA55
55FF00AAAA00FFAAAA00000000AA00AA00000000AAAAFF00AAAA00FF5555AAAAAA00FFAA
00FFFF00FFFF0000FF555555FF55005500FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00AA00FF00AAFFFFFF55AA0055555555000000AAAA00AA
FF0000AAAA00000055005555005500550055550055000000AAAA0000FFAA00AAAA000000
5555555500AA55FFFFFFAA00FF00AA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00555555000000FF00AAAAFFFFAA00FFFF55AA555500
0000AA00AAAAAAFFAAFF5555FFAAFFAAFF5555FFAAFFAAAAAA00AA0000005555AA55FFFF
00AAFFFFAAAA00FF00000055555500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF00FFFFFF550000000055555555FF00AAFF
AAAAAA00005500FF0055AAAA5500FF0055AAAA5500FF00550000AAAAAAFFAA00FF555555
550000000055FFFFFF00FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AA00000000FFAAAAAAFF5555FF55555500FF
00550000AA00FFFFFF00AAAA00FFFFFF00AAAA00FFFFFF00AA00005500FF00555555FF55
55FFAAAAAAFF00000000AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAFFAA5500FF5500AAFFFFFFAAFFFF00
00AAFF55FF00FF000000AAAA0000FF0000AAAA000000FF00FF55FFAA0000FFFFAAFFFFFF
AA0055FF0055AAFFAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00550000FF555500AAFF5500AA5500FF0000
AA00AA55AA000000AA0000550055555500550000AA000000AA55AA00AA0000FF0055AA00
55FFAA005555FF00005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA0000FFAA000055AAAAAA00FFFFFF55
AA55FF00AAAAAAFF55005555FFFFAAFFFF55550055FFAAAAAA00FF55AA55FFFFFF00AAAA
AA550000AAFF0000AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555500AAAAFFAA00AAAA000000FF00
AAAA550055000055AAAAAA55AA005500AA55AAAAAA550000550055AAAA00FF000000AAAA
00AAFFAAAA00555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF550000005555AA55FFFF0000
AAAA00FFFFAAAAAA5555AA55AA55FF55AA55AA5555AAAAAAFFFF00AAAA0000FFFF55AA55
5500000055FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AAAAAAFFAA00FF5555555500
550000AA55000055FF5555AAAA00FF00AAAA5555FF55000055AA0000550055555555FF00
AAFFAAAAAA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAA00AA555500AAFFFFAAFF
AAFFAAAA00FFFF555555FF5500FFFFFF0055FF555555FFFF00AAAAFFAAFFAAFFFFAA0055
55AA00AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00550055FF55550000000055
AA55000055555555FF555555FFFFFFFFFF555555FF55555555000055AA55000000005555
FF55005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00FF00AAFFAAAAFF55
55AAAAAAFFFFAA00FF00AAFF0000FF0000FFAA00FF00AAFFFFAAAAAA5555FFAAAAFFAA00
FF00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555550000005500AA
FF00550000000055555500FF00FFFFFF00FF00555555000000005500FFAA005500000055
555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF00FFFFAAAA
005555FFAAAAAAFFFFAA0000FFFFFFFFFF0000AAFFFFAAAAAAFF555500AAAAFFFF00FFFF
AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AA0000000055
FFFFAA0055000055AA00AA000000FF000000AA00AA5500005500AAFFFF5500000000AA55
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAFFAA55
AA0055FFFFAAAAAA55550000AA000000AA00005555AAAAAAFFFF5500AA55AAFFAAAAAA00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00550000FF55
55AAFF0000005500FFAA0000AAAAAAAAAA0000AAFF0055000000FFAA5555FF00005500FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA0000FF
AA00AA55FFFF00AA0055FFAA5555AA5555AAFF5500AA00FFFF55AA00AAFF0000AA00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555500
AAAAAA00FF0000AAAAAA5500FFAA00AAFF0055AAAAAA0000FF00AAAAAA00555500FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF
550000555555005500FF555500AAAAAA005555FF005500555555000055FFAA00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055
AAAAAAFFFFAAFF555500AAFFFF005500FFFFAA005555FFAAFFFFAAAAAA5500FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
AAAA00AA5500FF00AAFF5500AA55FF55AA0055FFAA00FF0055AA00AAAA00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00550055FF55AA000055AAAAAA00FF00AAAAAA550000AA55FF55005500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00AA00FF00AAAAAAFF005500FFFFFF005500FFAAAAAA00FF00AA00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0055555500005500AA00FFFFFFFFFF00AA0055000055555500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00AAFFFF00FFAAAA00000000000000AAAAFF00FFFFAA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0055AA00000055FFAAAAFFAAAAFF55000000AA5500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00AAAAAAFFAA005500FF005500AAFFAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00550000005555FFFFFF55550000005500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00AA0000AAFFFFFFFFFFAA0000AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00555500000000000000555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00AAFFAAAAFFAAAAFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055AA555555AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AAAA55AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.05624 0.39418 1.14355 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00FFFFFF0000AAAAAAFFFFFFFFFF55FFFFFFFFFFFF55FFAAFF00FFFFAA0000AA00FFFF
000000AA00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00AA000000FFFF00AA0000AA
FFFF00FFAAFF55FFFFFFFFFFFF55FFFFFFFFFFAAAAAA0000FFFFFF00FF
FFFFAAAAFF0000FFFF00FFAAAAFF00AAAAFFAAAAFFAA00AAFF555555FFFF0000FFFFAA00
FF0000FFFFAA00FFFFFFFFFF55FFFFFF55FFFFFFFFFF00AAFFFF0000FF00AAFFFF0000FF
FF555555FFAA00AAFFAAAAFFAAAA00FFAAAAFF00FFFF0000FFAAAAFFFF
FFFFFF00FFAAFFFFFFFFAAAAAAAAFFFF00FFAA55FFFF000000AAAA00AAFFAAFFFF55FFAA
FFAAFFFFFFFF0000AA0000AA00AAFFAA00AA0000AA0000FFFFFFFFAAFFAAFF55FFFFAAFF
AA00AAAA000000FFFF55AAFF00FFFFAAAAAAAAFFFFFFFFAAFF00FFFFFF
FFFFFFFFAAAAAAFFAA00FFFF00FFFFFFFFAAAAAA0000AA5500000000FFFF55AAAA5555FF
AAAAAAFFAA0000FF00FF000000FFFFFF000000FF00FF0000AAFFAAAAAAFF5555AAAA55FF
FF0000000055AA0000AAAAAAFFFFFFFF00FFFF00AAFFAAAAAAFFFFFFFF
FFFFFFFFFF00FFFFFF0000AAFFFFFFFFFFFF00FFFFAAFF55000055AA0000AAAAAAAA00AA
FF55AAFFAA5500AAFFFFFFAAFFFFFFFFFFAAFFFFFFAA0055AAFFAA55FFAA00AAAAAAAA00
00AA55000055FFAAFFFF00FFFFFFFFFFFFAA0000FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFAAAAFF0000FFFFFFFFFFFFFFFFAAAA55FF55000055FFAAFFFF00FFFF0000
00AAAAAAFF55000000AA00FFFFFFFFFFFFFF00AA00000055FFAAAAAA000000FFFF00FFFF
AAFF55000055FF55AAAAFFFFFFFFFFFFFFFF0000FFAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFAAFFFFFFFF55FFFFFFFFFF00FF55FF0000FF55FFAAAAFFFFFFFFAA
FFFF00FFFF55000055AAFFFFFFFFFFFFFFFFFFAA55000055FFFF00FFFFAAFFFFFFFFAAAA
FF55FF0000FF55FF00FFFFFFFFFF55FFFFFFFFAAFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAAAFFAA00FF5555FFFFFFFFAA00AAFFFFAA00AAFF55AAAAFFAAAA
AAFF0000AA00AA5500FFFFFFFFFFFFFFFFFFFFFF0055AA00AA0000FFAAAAAAFFAAAA55FF
AA00AAFFFFAA00AAFFFFFFFF5555FF00AAFFAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFF0000AAAA0000AA000000FFFFFFFF000000AAAAAAAAFF55
AAFF0000FFFFAA555555FFFFFFFFFFFFFFFFFF555555AAFFFF0000FFAA55FFAAAAAAAA00
0000FFFFFFFF000000AA0000AAAA0000FFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAFF0000FFFF0000FFFFAAFFFFFF55FFFFAAFFFF00FFFF00AA
AAAAFFFFAAAA55FF0055FFFFFFFFFFFFFFFFFF5500FF55AAAAFFFFAAAAAA00FFFF00FFFF
AAFFFF55FFFFFFAAFFFF0000FFFF0000FFAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFAAFFFFFFFFAAFFAAAAAAFFAA00AA00FFFFFFFFAA0000FF
FF00FFAAAAAAAA000055FFFFFFFFFFFFFFFFFF550000AAAAAAAAFF00FFFF0000AAFFFFFF
FF00AA00AAFFAAAAAAFFAAFFFFFFFFAAFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAA00FFFFFF00FFFFFF000000FFAAAAFF00FF0000
AAFFFFFF00FFFF0000FF55FFFFFFFFFFFFFF55FF0000FFFF00FFFFFFAA0000FF00FFAAAA
FF000000FFFFFF00FFFFFF00AAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000AAFF0000AAFFAAFFFFAAAAAAAAFFFFFFAA
FF55FFFFFFAAAAFFFFAA00AA0000AA0000AA00AAFFFFAAAAFFFFFF55FFAAFFFFFFAAAAAA
AAFFFFAAFFAA0000FFAA0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF0000FFFFFFAAFF55FFAA00FFFF00FFFFFFFF55
AAAA00FFAAAAAAAAFF00FF00FF000000FF00FF00FFAAAAAAAAFF00AAAA55FFFFFFFF00FF
FF00AAFF55FFAAFFFFFF0000FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAFFFFFFFF55AAAA00FFFFAAAAFFFF55FF55FF
00FFFFAAAAAAAAAAAAFFFFFFAA005500AAFFFFFFAAAAAAAAAAAAFFFF00FF55FF55FFFFAA
AAFFFF00AAAA55FFFFFFFFAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAA00FF55AAFFFFFFFF00FFAA00AA00AA
FFFFFFFF00FFFF00FFFFFFFF55AA00AA55FFFFFFFF00FFFF00FFFFFFFFAA00AA00AAFF00
FFFFFFFFAA55FF00AAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000AAAAAAFFAAAAFFFFFF000000FF
FFFFFFFFFFAAAAFFFF55FF55FF00FF00FF55FF55FFFFAAAAFFFFFFFFFFFF000000FFFFFF
AAAAFFAAAAAA0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF0000FFFF00FFAA55FFFFFFFFAAFFFF
FFFFFF55FFFF00FFAA00AA00AAFFFFFFAA00AA00AAFF00FFFF55FFFFFFFFFFAAFFFFFFFF
55AAFF00FFFF0000FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAFFFFFFFFAAAAAA0000AA00FFFFFF
FF5555FF00AAFFFFFF000000FFFFFFFFFF000000FFFFFFAA00FF5555FFFFFFFF00AA0000
AAAAAAFFFFFFFFAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAA00FFFF00FF000000FFAA00
00AAAA0000FFFF55FFFFAAFFFFFFFFFFFFFFAAFFFF55FFFF0000AAAA0000AAFF000000FF
00FFFF00AAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000AAFFFFFFAAFFFFFF00
00FFFF0000FFAA00AAFF00FFAAAAFFAAAAFF00FFAA00AAFF0000FFFF0000FFFFFFAAFFFF
FFAA0000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF0000FFFFFFFF55AAAAFFAA
FFFFFFFFAAFF00FF00FFAAFF00FFFFFF00FFAAFF00FF00FFAAFFFFFFFFAAFFAAAA55FFFF
FFFF0000FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAFFFFFF5555FF00FFFF55
AAAAFFAAAAAAFFFFFFAAAAAAFFFFFFFFFFAAAAAAFFFFFFAAAAAAFFAAAA55FFFF00FF5555
FFFFFFAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAA00AAAAFFFF55FF
00FFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFF00FF55FFFFAAAA00
AAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00000000AA00AA
FFFFFFFFFFAAAAFFAAAAFFFFFFFFFFFFFFFFFFAAAAFFAAAAFFFFFFFFFFAA00AA00000000
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF0000FF000000FF
FFFFFF55FF55AAFF00FFFFFFFFFFFFFFFFFFFFFF00FFAA55FF55FFFFFFFF000000FF0000
FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAFFFFFFAAFFFF
FF5555FF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FF5555FFFFFFAAFFFFFFAA
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAAAAAAFF
AA00AAAAFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFAAAA00AAFFAAAAAAFFAAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF
FF00000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00000000FFFFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF0000AA
0000FF0000FFFFFFFFFFFF55FFFFFFFFFF55FFFFFFFFFFFF0000FF0000AA0000FFAAAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAFFFF
0000FFAAFFFFFFFF55550055FFFFFFFFFF55005555FFFFFFFFAAFF0000FFFFAAFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF
AAFFFFFF00AA0000AAAA0055FFFFFFFFFF5500AAAA0000AA00FFFFFFAAFFAAAAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF00AA00FF00FF00000000FF5555FF5555FF00000000FF00FF00AA00FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
FF000000FFAAFFAAFFFFAAFF0055FF5500FFAAFFFFAAFFAAFF000000FFAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFAAFFFFAAAAAAFF5555FFAA0055FF5500AAFF5555FFAAAAAAFFFFAAFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAAAAFF00FFFF00AAAA00000055FF55000000AAAA00FFFF00FFAAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFAAAAFFFF00FF000055FF550000FF00FFFFAAAAFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAFF00FFFFFFFFAA0055AA55AA5500AAFFFFFFFF00FFAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFAAFF00AA000000FF55AA55FF000000AA00FFAAFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAAAFFFF0000FF00AAAAAA00FF0000FFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFAAFF0000000000FFAAFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAAFFAAAAAAFFFFAAFFFFAAAAAAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFAA55FFAA000000AAFF55AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAAA000000FF000000AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFAAFFFFFFAAFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA55FFFFFF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF55FF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.05624 0.588183 1.14355 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000AAAA00AAFFFFFFAAAAAAAAAA0000AAFFAA00550000000000AAFF0000AA00FFFFAA
55555555AAAA000000FFFF00FFFFFFFFFF00FFFF000000AAAA55555555AAFFFF00AA0000
FFAA00000000005500AAFFAA0000AAAAAAAAAAFFFFFFAA00AAAA0000FF
FFFFAAFF5555AAAAFFAAAAAAAAAAAAAA00AAFFAA00AA00AAAA00AAAAAAFFFFAA00AA5500
000000AA00FFFFAAFFFFFFFFAAAAFFAAAAFFFFFFFFAAFFFF00AA0000000055AA00AAFFFF
AAAAAA00AAAA00AA00AAFFAA00AAAAAAAAAAAAAAFFAAAA5555FFAAFFFF
FFFFFF0000AA00FFAAAAAA55AAAAAAAAAA00FF00AAAAAA00FFFFAA00FFFF55FF550000AA
AA00AAAAAA0055AAAAFFAAAAFF00FF00FFAAAAFFAAAA5500AAAAAA00AAAA000055FF55FF
FF00AAFFFF00AAAAAA00FF00AAAAAAAAAA55AAAAAAFF00AA0000FFFFFF
FFFFFFFFAAFF5500AAFF00AA00FFFF00AAFFFFFFAA00FFAAFFAAAA5555555500AA00AAAA
AA5555FFAA00AA00FFFF55AAFFAAFFAAFFAA55FFFF00AA00AAFF5555AAAAAA00AA005555
5555AAAAFFAAFF00AAFFFFFFAA00FFFF00AA00FFAA0055FFAAFFFFFFFF
FFFFFFFFFF0000AAAA5500FFAAFFAAAA00FF0000FFFFAAAAAAFF00AA000000AAAAAA00FF
AA000000FFFFAA555555550000FFFFFF000055555555AAFFFF000000AAFF00AAAAAA0000
00AA00FFAAAAAAFFFF0000FF00AAAAFFAAFF0055AAAA0000FFFFFFFFFF
FFFFFFFFFFFFAAFF555500FF00FF00AAFFFFFFAAFFAAAAAA55AA00AAFFFFAAFF00FFFFAA
AAAA00AAAAFFAA000000AA00AAAAFFAAAA00AA000000AAFFAAAA00AAAAAAFFFF00FFAAFF
FFAA00AA55AAAAAAFFAAFFFFFFAA00FF00FF005555FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFF0000AA00AA555555AAFFAAAAFF0000550000AAFFFF0000FFFFFFAAAAFF
00FFAAFF00AA55AA5555AAAA00FFFFFF00AAAA5555AA55AA00FFAAFF00FFAAAAFFFFFF00
00FFFFAA0000550000FFAAAAFFAA555555AA00AA0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF55000000AA00FF00FFAAAA00AA00AAAAAAFFAAFFFFFFFFFF00AA
555555FFFFAA00005555000055FFFFFF55000055550000AAFFFF555555AA00FFFFFFFFFF
AAFFAAAAAA00AA00AAAAFF00FF00AA00000055FFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000AAAA00AAFFFFFFAAAAAAAA00FF5555FF55FF55FFFFFF55FF00
AA000000FF00AAAA0000AAAA0000FF0000AAAA0000AAAA00FF000000AA00FF55FFFFFF55
FF55FF5555FF00AAAAAAAAFFFFFFAA00AAAA0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF5555AAAAFFAAAAAAAAAAAA00555500AA00555555555500AA
AAAA00AAAAFFFF00AAAA00FFFFAAFFAAFFFF00AAAA00FFFFAAAA00AAAAAA005555555555
00AA00555500AAAAAAAAAAAAFFAAAA5555FFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000AA00FFAAAAAA55AAAAAAAA0000AAAAAA0000000000AAAA
AAAAAA00FFFFFFFFAA55AA5500AAFFAA0055AA55AAFFFFFFFF00AAAAAAAAAA0000000000
AAAAAA0000AAAAAAAA55AAAAAAFF00AA0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF5500AAFF00AA00FFFF00AAAA00FFAA00AAAA00AAAAAA
AA55FFAAFFAAAAFFAA00005555AAFFAA55550000AAFFAAAAFFAAFF55AAAAAAAA00AAAA00
AAFF00AAAA00FFFF00AA00FFAA0055FFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000AAAA5500FFAAFFAAAA00FFFFAAAAAA00FFAAFF00FF
AA0000FFFFFF00FF00AAAA0000AAFFAA0000AAAA00FF00FFFFFF0000AAFF00FFAAFF00AA
AAAAFFFF00AAAAFFAAFF0055AAAA0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF555500FF00FF00AAFFFFFFFF00FFFFAAAAAAFFFF
FF0055FFFFFF5500AAAAAAAA00AAFFAA00AAAAAAAA0055FFFFFF5500FFFFFFAAAAAAFFFF
00FFFFFFFFAA00FF00FF005555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA00AA555555AAFFAAAAFFAAFFAAAAAAAAAAFF
AAAA0000FF0000AAAAAAAAAAAA00FF00AAAAAAAAAAAA0000FF0000AAAAFFAAAAAAAAAAFF
AAFFAAAAFFAA555555AA00AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55000000AA00FF00FFAAAAAAFF00AAFF5555
55FFAAFFFFFFAAFF55AAFF00AAFFFFFFAA00FFAA55FFAAFFFFFFAAFF555555FFAA00FFAA
AAAAFF00FF00AA00000055FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AAAA00AAFFFFFFAAAAAAAAAAFFFF000000
0000FFAAAAFFAA55005500AAAAAAFFAAAAAA00550055AAFFAAAAFF0000000000FFFFAAAA
AAAAAAFFFFFFAA00AAAA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555AAAAFFAAAAAAAAAAAAAAFFAAFFFF
AAFFFFFF00FF00AA00AA00AAFF00FF00FFAA00AA00AA00FF00FFFFFFAAFFFFAAFFAAAAAA
AAAAAAAAFFAAAA5555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA00FFAAAAAA55AAAAAAAAAAFF0000
FFFFFFFFFFAAAA00FF5555AAFFAAFFAAFFAA5555FF00AAAAFFFFFFFFFF0000FFAAAAAAAA
AA55AAAAAAFF00AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5500AAFF00AA00FFFF00AAFFAAFF
FF55FFFFFF5555FF0000AA00FF00FF00FF00AA0000FF5555FFFFFF55FFFFAAFFAA00FFFF
00AA00FFAA0055FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AAAA5500FFAAFFAAAA00FF00FF
000000FF0000AA0055FF00AAAAFFFFFFAAAA00FF5500AA0000FF000000FF00FF00AAAAFF
AAFF0055AAAA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF555500FF00FF00AAFFFFFFAA
AA00AAAAFFFFAA555500AAAAAAAAFFAAAAAAAA005555AAFFFFAAAA00AAAAFFFFFFAA00FF
00FF005555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA00AA555555AAFFAAAAFF
00FF55AAAAFFAA0000AAAAAA55AAFFAA55AAAAAA0000AAFFAAAA55FF00FFAAAAFFAA5555
55AA00AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55000000AA00FF00FFAA
AA005555FFAAAAAA00AAFF00AA00FF00AA00FFAA00AAAAAAFF555500AAAAFF00FF00AA00
000055FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AAAA00AAFFFFFFAAAA
AAAA000000FFFF00AAAA5500FFAAFFAAFF0055AAAA00FFFF000000AAAAAAAAFFFFFFAA00
AAAA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555AAAAFFAAAAAA
AAAAAA00AAAAFFAAFF555500FF00FF00FF005555FFAAFFAAAA00AAAAAAAAAAAAFFAAAA55
55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA00FFAAAAAA55
AAAAAAAA00FFFFFF000000AAAAFFFFFFAAAA000000FFFFFF00AAAAAAAA55AAAAAAFF00AA
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5500AAFF00AA
00FFFF00AAAAFFAAAA00AAAAAAAAFFAAAAAAAA00AAAAFFAAAA00FFFF00AA00FFAA0055FF
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AAAA5500FF
AAFFAAAA00FFAAAAAAAA00FFAA00FF00AAFF00AAAAAAAAFF00AAAAFFAAFF0055AAAA0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF555500FF
00FF00AAFFFFFF00AAFF5500AAFFFFFFAA0055FFAA00FFFFFFAA00FF00FF005555FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA00AA
555555AAFFAAAAFFFF0000AAAAAAFFAAAAAA0000FFFFAAAAFFAA555555AA00AA0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5500
0000AA00FF00FFFFFFFFAAFF00FFFFFF00FFAAFFFFFFFF00FF00AA00000055FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA
AA00AAFFFFFFAAAAFFAAAAAAFFFFFFFFFFAAAAAAFFAAAAFFFFFFAA00AAAA0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
5555AAAAFFAAAAAAAAFF00FFAAAAFFAAAAFF00FFAAAAAAAAFFAAAA5555FFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00AA00FFAAAAAA55AAAAFFFFFF00FF00FFFFFFAAAA55AAAAAAFF00AA0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAFF5500AAFF00AA00FFAAAAFFAAFFAAFFAAAAFF00AA00FFAA0055FFAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000AAAA5500FFAAFFAA00FF00FF00FF00AAFFAAFF0055AAAA0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFF555500FF00FF00AAAAFFFFFFAAAA00FF00FF005555FFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000AA00AA555555AAAAAAFFAAAAAA555555AA00AA0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAFF5500000000AAFF00FF00FFAA0000000055FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000AAAA00AAAAAAFFFFFFAAAAAA00AAAA0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFF5555AAAAAAAAFFAAAAAAAA5555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000AA00FFAA00FF00AAFF00AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF5500AAFFFFFFAA0055FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000AAAAAAFFAAAAAA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF55AAFFAA55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000AAFFAA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.05624 0.782187 1.14355 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00FFAAAA55AAFFFFFFAAAAAA5500AA550000AAAA0055555500000000AA005555555555
550000005555005500AAAAAAAAAAAAAAAAAAAAAA005500555500000055555555555500AA
0000000055555500AAAA000055AA0055AAAAAAFFFFFFAA55AAAAFF00FF
FFFFAAAAAAAA55FFFFFF55AA555500AAAA5500AAAA005500555555555555AA0000550000
5500AA550055555500AAAAAAAAAAAAAAAAAAAAAA005555550055AA00550000550000AA55
5555555555005500AAAA0055AAAA005555AA55FFFFFF55AAAAAAAAFFFF
FFFFFF00FF55AAAAFFAAAA55550055AA555500AAAA00555555005500005555AA00555555
5500AAAA5500005500AAAAAA00AAAAAA00AAAAAA0055000055AAAA005555555500AA5555
0000550055555500AAAA005555AA55005555AAAAFFAAAA55FF00FFFFFF
FFFFFFFFAAAA55FFAAAAAAAA55AA0000005500AAAA00550055555500AA55AAAA00550000
555555AA55AA00555555AA555555AA555555AA55555500AA55AA55555500005500AAAA55
AA00555555005500AAAA0055000000AA55AAAAAAAAFF55AAAAFFFFFFFF
FFFFFFFFFF00FFAAAAAAAAAAAA555555555500AAAA0055555500555555AAAAAA00555555
550000AAAA555555005555AAAA55AA55AAAA555500555555AAAA00005555555500AAAAAA
5555550055555500AAAA005555555555AAAAAAAAAAAAFF00FFFFFFFFFF
FFFFFFFFFFFFAAAAAAAAAAAAAA000055000055AA5555550000AA55AAAA5555AA55005500
55555555AA55AAAA55005555AA55AA55AA55550055AAAA55AA5555555500550055AA5555
AAAA55AA0000555555AA550000550000AAAAAAAAAAAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF55AA5555AA005500AA55AA55AAAA5500AAAA5555AAAA555500AA00
5555005555AAAAAAAA55005555AAAAAA55550055AAAAAAAA555500555500AA005555AAAA
5555AAAA0055AAAA55AA55AA005500AA5555AA55FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA55FF5555AA00FF00FFAA55AA555500AAAAAA55AA55550055AA55
00555555000000000000AA55AAAAAAAAAA55AA0000000000005555550055AA55005555AA
55AAAAAA005555AA55AAFF00FF00AA5555FF55AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFAAAA55AAFFFFFFAAAAAA55550055AA5555AAAA0000AA55AA55
AA00005555555555555555AAAAAAAAAAAAAA55555555555555550000AA55AA55AA0000AA
AA5555AA55005555AAAAAAFFFFFFAA55AAAAFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAAAA55FFFFFF55AA55550055AAAAAA55AA55555555AAAAAA
5555555500005500005500000000000000000055000055000055555555AAAAAA55555555
AA55AAAAAA55005555AA55FFFFFF55AAAAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF55AAAAFFAAAA55550055AAAAAAAAAA555500005555AA55
5500005500AA55AA00555555555555555555555500AA55AA005500005555AA5555000055
55AAAAAAAAAA55005555AAAAFFAAAA55FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA55FFAAAAAAAA55AA0000000000000055555555000000
5555555500AAAA555555005555005500555500555555AAAA005555555500000055555555
00000000000000AA55AAAAAAAAFF55AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAAAAAAAAAAA555555555555555555000055555555
550000555555AA55AAAA55005500AA00550055AAAA55AA55555500005555555555000055
5555555555555555AAAAAAAAAAAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAAAA000055000055000055555555005500
55555555005555AAAAAAAA550055AA550055AAAAAAAA5555005555555500550055555555
0000550000550000AAAAAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55AA5555AA005500AA55AA005555005500AA00
5500555500AA000000000000AA55AA55AA000000000000AA005555005500AA0055005555
00AA55AA005500AA5555AA55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF5555AA00FF00FFAA550000AA55AA00AA
55AA0000AA5555555555555555AAAAAA5555555555555555AA0000AA55AA00AA55AA0000
55AAFF00FF00AA5555FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAAA55AAFFFFFFAAAAAA5500AAAA555555
AAAA0055AA55AAAA55AAAA55AAAAAAAAAA55AAAA55AAAA55AA5500AAAA555555AAAA0055
AAAAAAFFFFFFAA55AAAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA55FFFFFF55AA555500AAAAAA55AA
AAAA005555AAAAAAAA5555AAAAAAAAAAAAAA5555AAAAAAAA555500AAAAAA55AAAAAA0055
55AA55FFFFFF55AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55AAAAFFAAAA55550055AA5555AAAA
AA00AA55AAAAAAAAAAAA55AA5555AA5555AA55AAAAAAAAAAAA55AA00AAAAAA5555AA5500
5555AAAAFFAAAA55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FFAAAAAAAA55AA0000005555AA
555555AAAAAAAAAAAAAAAA55550000005555AAAAAAAAAAAAAAAA555555AA5555000000AA
55AAAAAAAAFF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAAAAAAAAAAA55555555550000
005500000000000000000000555555555500000000000000000000550000005555555555
AAAAAAAAAAAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAAAA000055000055AA
0055555555555555555555555500550055555555555555555555555500AA550000550000
AAAAAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55AA5555AA005500AA55AA
5500005500550055005500555500AA0055550055005500550055000055AA55AA005500AA
5555AA55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF5555AA00FF00FFAA
55AA0055555500AA005555550055AA550055555500AA0055555500AA55AAFF00FF00AA55
55FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAAA55AAFFFFFFAAAA
AA5555550000AA555555000055AAAAAA550000555555AA0000555555AAAAAAFFFFFFAA55
AAAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA55FFFFFF55AA
55550055555555AAAA55AA005555AA555500AA55AAAA55555555005555AA55FFFFFF55AA
AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55AAAAFFAAAA55
550055AAAA55AAAAAAAA555555000000555555AAAAAAAA55AAAA55005555AAAAFFAAAA55
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FFAAAAAAAA
55AA00000000AAAAAAAA000055555555550000AAAAAAAA00000000AA55AAAAAAAAFF55AA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAAAAAAAAA
AA555555555555AA5555AA00550055005500AA5555AA555555555555AAAAAAAAAAAAFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAA
AA00005555005555AAAA55555500AA00555555AAAA55550055550000AAAAAAAAAAAAAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55AA55
55AA00550055AAAA5555AAAA55AA00AA55AAAA5555AAAA55005500AA5555AA55FF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF
5555AA00FF00AAAA0000AAAAAA555555AAAAAA0000AAAA00FF00AA5555FF55AAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA
AA55AAFFFFFFAA55555555AA5555005555AA55555555AAFFFFFFAA55AAAAFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
AAAA55FFFFFF5500555500000055555500000055550055FFFFFF55AAAAAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF55AAAAFFAAAA550055555555550055555555550055AAAAFFAAAA55FF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAA55FFAAAAAAAA55005555005555550055550055AAAAAAAAFF55AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFAAAAAAAAAAAA5500555555005555550055AAAAAAAAAAAAFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAAAAAAAAAAAAA550000555555000055AAAAAAAAAAAAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF55AA5555AA55AA0055005500AA55AA5555AA55FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAA55FF5555AAAA0055555500AAAA5555FF55AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFAAAA55AA55555500555555AA55AAAAFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAAAAAA555500555555005555AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF55AAAA5500550055AAAA55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA55FFAA005500AAFF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFAAAA005500AAAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA00AA55AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0055AA55AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.05624 0.97619 1.14355 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0055550055FFFFFF005500000000000000FFFF55550000AA555500FF000000000055FF
FFAA00FF000055FF5500555500FFFFFF0055550055FF550000FF00AAFFFF550000000000
FF005555AA00005555FFFF000000000000005500FFFFFF5500555500FF
FFFFAA00FF00AA0000AAAA5500FF0055AA555500000000FF00FFAA0055555555555555FF
FFFF005500FF00AA00FF00AAFFFFFFFFFFAA00FF00AA00FF005500FFFFFF555555555555
5500AAFF00FF000000005555AA5500FF0055AAAA0000AA00FF00AAFFFF
FFFFFF005555AAFFFFAA55FF550055FF55AAAA5500FF000055FFFF000000000000000000
555500AAFFFFFFAA555500FFFFFFFFFFFFFF005555AAFFFFFFAA00555500000000000000
0000FFFF550000FF0055AAAA55FF550055FF55AAFFFFAA555500FFFFFF
FFFFFFFFAA00FFFFFFFF00AA00FF00AA00FFFF00AAAAFFFFAA000055FF0000FF0000FF00
000000FFFFFFFFFF00AAFFFFFFFFFFFFFFFFFFAA00FFFFFFFFFF00000000FF0000FF0000
FF550000AAFFFFAAAA00FFFF00AA00FF00AA00FFFFFFFF00AAFFFFFFFF
FFFFFFFFFF005555005555AAFFFFFFAA55000055AAFF55FFFF0055AAAAFFFFAAAA005555
AA5500AA0000550000FFFFFFFFFFFFFFFFFFFFFF0000550000AA0055AA555500AAAAFFFF
AAAA5500FFFF55FFAA55000055AAFFFFFFAA555500555500FFFFFFFFFF
FFFFFFFFFFFFAA00FF00AAFF55FFFFFF00AAAA00FFFF55550000FFAA55FFFFFF00FF00AA
FF5555AAFFFFAA0055FFFFFF55FFFFFF55FFFFFF5500AAFFFFAA5555FFAA00FF00FFFFFF
55AAFF00005555FFFF00AAAA00FFFFFF55FFAA00FF00AAFFFFFFFFFFFF
FFFFFFFFFFFFFF005555AAFFAA00005500FFFF005500000000FF55FFAA0000AA005555AA
FFAA00FFFFFFFF000000550000005500000055000000FFFFFFFF00AAFFAA555500AA0000
AAFF55FF000000005500FFFF00550000AAFFAA555500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00FFFFFF0055AAAA0000AAAA5500FF005555FFFF0000FFFFAA00FF
FFFF000055550000FF000000FF000000FF000000FF000055550000FFFFFF00AAFFFF0000
FFFF555500FF0055AAAA0000AAAA5500FFFFFF00AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0055550055FF55AAFFFFAA55FF550055FF55550000FF55FFFF0000
550000FF5555FF0000AAAA005500FF005500AAAA0000FF5555FF0000550000FFFF55FF00
005555FF550055FF55AAFFFFAA55FF5500555500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA00FF00AA00FFFFFFFF00AA00FF00AA00FFAAFFFF55550000FF
00AAAA0000000055FF00FFFFAA005500AAFFFF00FF5500000000AAAA00FF00005555FFFF
AAFF00AA00FF00AA00FFFFFFFF00AA00FF00AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF005555AAFFFFFFFFFFFFAA555500FFFFAAAAAAFFAA00FF0055
00FFFF0000FF00000055FFFFFF000000FFFFFF55000000FF0000FFFF005500FF00AAFFAA
AAAAFFFF005555AAFFFFFFFFFFFFAA555500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00FFFFFFFFFFFFFFFF00AAFFFFFFFF00FFFFFF0000AAAA
55550055AA0000FF000000550000FF000055000000FF0000AA55005555AAAA0000FFFFFF
00FFFFFFFFAA00FFFFFFFFFFFFFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00555500555500005500FFFFFFFFFF550000AA00AAAAAA
AA55AA55AAFFFFAAAA0055AAAA005500AAAA5500AAAAFFFFAA55AA55AAAAAAAA00AA0000
55FFFFFFFFFF00550000555500555500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF00AAFFFFAA0055000055000000FF00FF00FFFF
00FFAA55AAFFAAAAAAAA00FFFF000000FFFF00AAAAAAAAFFAA55AAFF00FFFF00FF00FF00
00005500005500AAFFFFAA00FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555AAFFAAAAAA00FF000000FF0000AAAAFFFFFF
FFAAAAAA55FFFF00FFFF00005500FF00550000FFFF00FFFF55AAAAAAFFFFFFFFAAAA0000
FF000000FF00AAAAAAFFAA555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFFFF00FFFFAAAA00AAAAFFFFAA55FFFFFF
FF55AAFF55550055FFFF5500AAFFFFFFAA0055FFFF55005555FFAA55FFFFFFFF55AAFFFF
AAAA00AAAAFFFF00FFFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055550055FFFFFF00FF00FFFFFFFF00AA0000
AA00FFFF5555FF00AA000000FFFFFFFFFF000000AA00FF5555FFFF00AA0000AA00FFFFFF
FF00FF00FFFFFF5500555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF00AA0000AAAAFFFFFFFFFFFFAA5555
AAFFFFFF5555FFFFAA5500FF55FFFFFF55FF0055AAFFFF5555FFFFFFAA5555AAFFFFFFFF
FFFFAAAA0000AA00FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555AAFFFFAA55FFFFFFFFFFFFFF00AA
FF55FFFF5555FFFF55AAAA000000AA000000AAAA55FFFF5555FFFF55FFAA00FFFFFFFFFF
FFFF55AAFFFFAA555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFFFFFF00AA0000AA00005500FF
FF5555000000005555FFAA5500FF00FF0055AAFF5555000000005555FFFF00550000AA00
00AA00FFFFFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555005555AAFFFFAA5500AAFFFF
55FF555555555555FF55FFAA0055555500AAFF55FF555555555555FF55FFFFAA0055AAFF
FFAA555500555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF00AAFF55FFFF00AAAAAAFF
AA0000000000000000AAFFAA5555FF5555AAFFAA0000000000000000AAFFAAAAAA00FFFF
55FFAA00FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555AAFFAA000055FFAA55FF
FF0055AA5555AA5500FFFFFF00AAFFAA00FFFFFF0055AA5555AA5500FFFF55AAFF550000
AAFFAA555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFFFF0055AAAAFF5555
0055FF55AAAA55FF5500555500FFFFFF0055550055FF55AAAA55FF55005555FFAAAA5500
FFFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055550055FF55AAFFAA00
FF00AA00FFFF00AA00FF00AAFFFFFFFFFFAA00FF00AA00FFFF00AA00FF00AAFFAA55FF55
00555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF00AA00FFFFFF00
5555AAFFFFFFFFAA555500FFFFFFFFFFFFFF005555AAFFFFFFFFAA555500FFFFFF00AA00
FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555AAFFFFFFFFFF
AA00FFFFFFFFFFFF00AAFFFFFFFFFFFFFFFFFFAA00FFFFFFFFFFFF00AAFFFFFFFFFFAA55
5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFFFFFFFFFF
FF0000550000550000FFFFFF55FFFFFF55FFFFFF0000550000550000FFFFFFFFFFFFFF00
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555500555500
0055FF00AAAA00FF0055005555FFFFFF5555005500FF00AAAA00FF550000555500555500
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF00AAFF
FFAA0000FFFF0000AA55AA55AAAAFFAAAA55AA55AA0000FFFF0000AAFFFFAA00FF00AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555AAFF
AAAAAA00555500AAAAAA55FF55AAFFAA55FF55AAAAAA00555500AAAAAAFFAA555500FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF
FF00FFFFAA00FF00FFFF00AA00FFFFFF00AA00FFFF00FF00AAFFFF00FFFFFF00AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555
0055FFFFFF005555550055AAFFFFFFFFFFAA550055555500FFFFFF5500555500FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00
FF00AA0000AAAA55AAAA00FFFFFFFFFFFFFF00AAAA55AAAA0000AA00FF00AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
5555AAFFFFAA55FF55AAFFFFFFFFFFFFFFFFFFAA55FF55AAFFFFAA555500FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA00FFFFFFFF00AA00FFFFFFFFFFFFFFFFFFFFFF00AA00FFFFFFFF00AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF005555005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFAA555500555500FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA00FF00AAFF55FFFFFFFFFFFFFFFFFFFFFF55FFAA00FF00AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF005555AAFFAA0000550055005500550000AAFFAA555500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA00FFFFFF0055AAAA00FF00AAAA5500FFFFFF00AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0055550055FF55AAFFFFFFAA55FF5500555500FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA00FF00AA00FFFFFFFFFF00AA00FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF005555AAFFFFFFFFFFFFFFAA555500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00FFFFFFFFFFFFFFFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0055550000550000555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA00FF000000FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF005500FF005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.15228 0.200176 1.23959 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF55FFAA000055FFFFFF55AA55FF000000AAFFFF55FF5555FFFF55FF000055000000FFFF
FFFFAAAAAAFFFFFF0000FFFF5555005555FFFF0000FFFFFFAAAAAAFFFFFFFF0000005500
00FF55FFFF5555FF55FFFFAA000000FF55AA55FFFFFF550000AAFF55FF
FFFF0055AAAAFFFFFFFFFF000055FFFF55555500FFFFFF00FF550000AAFFAAFFAAAA5555
0055555555550055FFFF550055000000550055FFFF55005555555555005555AAAAFFAAFF
AA000055FF00FFFFFF00555555FFFF550000FFFFFFFFFFAAAA5500FFFF
FFFFFF55AA0055FF005555AAAAFFFFFFFFAAFF55FF005555FF00FFAA0055555500AA55FF
AAAAAAAAAAAAAAFFFFFFFFAAAAAAFFAAAAAAFFFFFFFFAAAAAAAAAAAAAAFF55AA00555555
00AAFF00FF555500FF55FFAAFFFFFFFFAAAA555500FF5500AA55FFFFFF
FFFFFFFF00000055FFFF00FF0000AAAA0000FF55AA55AAFFFFFF5500AAFF55AAFF000055
5555555555555555AA555500AA550055AA005555AA5555555555555555550000FFAA55FF
AA0055FFFFFFAA55AA55FF0000AAAA0000FF00FFFF55000000FFFFFFFF
FFFFFFFFFF55FFFF0055FFFFFF55555555FFFFFF000055AA5555000000FF55AA00000000
550000550000550000FFFF00AA55FF55AA00FFFF00005500005500005500000000AA55FF
0000005555AA550000FFFFFF55555555FFFFFF5500FFFF55FFFFFFFFFF
FFFFFFFFFFFF0055FFFF0055550000550000AA0000000055AAFF55FF55550000FFAAAAFF
AAFFAAAAAA55AAFF00AA000000FFFFFF000000AA00FFAA55AAAAAAFFAAFFAAAAFF000055
55FF55FFAA5500000000AA0000550000555500FFFF5500FFFFFFFFFFFF
FFFFFFFFFFFFFF55AA5555FFAA55AAAAAAFF00000000000055AA55FF00FFFF555500AA55
555500AA550000FF555555FF5555005555FF555555FF000055AA00555555AA005555FFFF
00FF55AA55000000000000FFAAAAAA55AAFF5555AA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00005500FF00FF0000FF5555FFFF55FFFF000055FFFFFFFFAAFF0000
55000000FFFF5555AAFFFF00550000005500FFFFAA5555FFFF000000550000FFAAFFFFFF
FF550000FFFF55FFFF5555FF0000FF00FF00550000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55FFAA000000AAFF00550000AAAAAA00000000555500555555AAAA
55FF55FF5500FFFF0000AAAAFF55FF55FFAAAA0000FFFF0055FF55FF55AAAA5555550055
5500000000AAAAAA00005500FFAA000000AAFF55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055AAAAFF0000AAFFFF5555555555FFFF55FFAAFFAAFF55AA00
5500FFFFFFAA0000AAFF0000FF55AA55FF0000FFAA0000AAFFFFFF005500AA55FFAAFFAA
FF55FFFF5555555555FFFFAA0000FFAAAA5500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AA0055FF55555500550000550000AAAAAA005555550000FF
AAFF0055FF00000000FF5555FF00FF00FF5555FF00000000FF5500FFAAFF000055555500
AAAAAA00005500005500555555FF5500AA55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000055FFAAFF55FFAA00FFFF5555555555FFAA55FF5555
AA0000005555FF55FF55000055FFFFFF55000055FF55FF5555000000AA5555FF55AAFF55
55555555FFFF00AAFF55FFAAFF55000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF55FFFF0055AA55FF000000AAAAAAAAAAAAAA005500FFFF
00000000005500FFFFFFAAAAFFFFFFFFFFAAAAFFFFFF00550000000000FFFF005500AAAA
AAAAAAAAAA000000FF55AA5500FFFF55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFF00005555FF555555555555555555FFAA0000
AAFF00AAFFAAFF0055FF0000FF550055FF0000FF5500FFAAFFAA00FFAA0000AAFF555555
555555555555FF55550000FFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5555FFFF00FF55AAFFFF00FFFFAA55FF000000
00FF555555AA00000055FF5555AAFFAA5555FF55000000AA555555FF00000000FF55AAFF
FF00FFFFAA55FF00FFFF5555AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00005500FF55FF00FF0055FF5500FF00FF5555FF
5555AAFFFF000000000055FFAA550055AAFF550000000000FFFFAA5555FF5555FF00FF00
55FF5500FF00FF55FF00550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA000055FFFFFF55AA55FFFFFF55000055
FFAA550055FF5555FFFF55AA5500000055AA55FFFF5555FF550055AAFF55000055FFFFFF
55AA55FFFFFF550000AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AAAAFFFFFFFFFF00005555AA55FFFF55
AA5500000055FFAA55550000FFFF55FFFF00005555AAFF5500000055AA55FFFF55AA5555
0000FFFFFFFFFFAAAA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA0055FF005555AAAAFFFF0000555500
00FFFF55FFFF0055AAFF55FF5500550055FF55FFAA5500FFFF55FFFF000055550000FFFF
AAAA555500FF5500AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000055FFFF00FF0000AA00FFAA55FF
555500FFFFFFFF55AA000055FFAAAAAAFF550000AA55FFFFFFFF005555FF55AAFF00AA00
00FF00FFFF55000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFF0055FFFFFF555555FF000055
FFAAFF005555005500AAFFAA5555555555AAFFAA005500555500FFAAFF550000FF555555
FFFFFF5500FFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFF00555500005500FFAAAA
AA005555FFAAFFAAFF0000AA55FFAAFF55AA0000FFAAFFAAFF555500AAAAAAFF00550000
555500FFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5555FFAA55AAAAAA555555
5555FFAA555555AA00AAFF00005555550000FFAA00AA555555AAFF5555555555AAAAAA55
AAFF5555AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00005500FF00FF0000FFFF00
FFFF0055AAFFFF000000FF55FFFFAAFFFF55FF000000FFFFAA5500FFFF00FFFF0000FF00
FF00550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA000000AAFF0055FF
5500FFAA550055FF55FFFFFF0055555500FFFFFF55FF550055AAFF0055FF5500FFAA0000
00AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AAAAFF0000AAFF55
000000AA55FF55AA55FF0055FFFFAAFFFF5500FF55AA55FF55AA00000055FFAA0000FFAA
AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA0055FF55555500
00000000FFFFFF000055FFFF0055555500FFFF550000FFFFFF0000000000555555FF5500
AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000055FFAAFF55
FF55FFFF55005555FFFF0055FFFFAAFFFF5500FFFF55550055FFFF55FF55FFAAFF550000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFF0055AA55
FF00FF55000000550055FFFF0055555500FFFF55005500000055FF00FF55AA5500FFFF55
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFF0000
5555FF00FFAAAA55FF55AA5555FFAAFF5555AA55FF55AAAAFF00FF55550000FFFF5500FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5555FF
FF00FF55FF0000FFFFFF00005500FF00550000FFFFFF0000FF55FF00FFFF5555AA55FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00005500
FF55FF00FF5555FF0055FF55FFAA00AAFF55FF5500FF5555FF00FF55FF00550000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA
000055FF55000055FF55AA55FF000000FF55AA55FF55000055FF550000AAFF55FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055
AAAAFFFFFFAA00FFFFFF00005555FF55550000FFFFFF00AAFFFFFFAAAA5500FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
AA0055FF0055AAAA0000AAFFAAFFFFFFAAFFAA0000AAAA5500FF5500AA55FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000055FFFF0000FFAA005555550055555500AAFF0000FFFF55000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55FFFF0055FF55FF0000005500000055000000FF55FF5500FFFF55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0055FFFF005500FFAAAAFF55FF55FFAAAAFF005500FFFF5500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55AA5555FFAA00AA5500FFFFFF0055AA00AAFF5555AA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00005500FF00AA55FFFFFFFFFF55AA00FF00550000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55FFAA000000FFFFFFFFFFFFFF000000AAFF55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0055AAAAFF00555500555500FFAAAA5500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55AA005555FFAA55AAFF555500AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000005500FF00FF0055000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55FFFFAA000000AAFFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00555555FF55555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AAFFFFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.15228 0.39418 1.23959 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FF00FFAAFFFFFF00550000FFFFFFFFFFAAFF005555000000000000FF000000FFFF
FFFF00FFAAAAFFFF00000000FF00FF00FF00000000FFFFAAAAFF00FFFFFFFF000000FF00
0000000000555500FFAAFFFFFFFFFF00005500FFFFFFAAFF00FF0000FF
FFFF00FFAAAA55555555FFFFAAAAFF0000FF000000FFFFAAFF55AAFF55FFFFFF00FFFFFF
FFFFFF00000000FFAAAAAAAAFF00FF00FFAAAAAAAAFF00000000FFFFFFFFFFFF00FFFFFF
55FFAA55FFAAFFFF000000FF0000FFAAAAFFFF55555555AAAAFF00FFFF
FFFFFF00000000AA0000AAFF0055FF55AAFF00FFFF0000FF555500FFAAFF0000FFFFFFFF
FFFFFFFF00FFFF000000000000FFFFFF000000000000FFFF00FFFFFFFFFFFFFFFF0000FF
AAFF005555FF0000FFFF00FFAA55FF5500FFAA0000AA00000000FFFFFF
FFFFFFFF00FFFF0055000000FFFFAA000000FFFFFFFF00FFAAFFFF000000FFFF0000FF00
AAFF0000FFFFFFFF55FFAA55FFFFFFFFFF55AAFF55FFFFFFFF0000FFAA00FF0000FFFF00
0000FFFFAAFF00FFFFFFFF000000AAFFFF0000005500FFFF00FFFFFFFF
FFFFFFFFFF0000FFFFAA55FFAA0055FFAAAAAA55AAAA55FF5500AA55FFFF0000FFFF0000
55FF55AAFF0000FFAAFF00555555FF55555500FFAAFF0000FFAA55FF550000FFFF0000FF
FF55AA0055FF55AAAA55AAAAAAFF5500AAFF55AAFFFF0000FFFFFFFFFF
FFFFFFFFFFFF00FFAA00AA0055FFFFAA00AAAA00000000AAFFFF00555555FFFF00AA55FF
FFAA000000FFFF000000FFFFAAFFFFFFAAFFFF000000FFFF000000AAFFFF55AA00FFFF55
555500FFFFAA00000000AAAA00AAFFFF5500AA00AAFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF00000055FFAAFF00000055FF00FFFF55FF0000FFFFAAFFFFFFFF005555
55FF00FFFF0000FFFF00FF000000FF000000FF00FFFF0000FFFF00FF55555500FFFFFFFF
AAFFFF0000FF55FFFF00FF55000000FFAAFF55000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFAA00AAFFAAAAFFFFFF00AAFFFFFF00FF000000FF0000FFFFAA
FFFFFF5555FFFF0000FFFFFF00FFFFFF00FFFFFF0000FFFF5555FFFFFFAAFFFF0000FF00
0000FF00FFFFFFAA00FFFFFFAAAAFFAA00AAFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF55FF00000000FF000055FF5555FFFFFF00FFFFFF00FFAA00
AAFF00AA0000FFAAAAFF0000FFFFFFFFFF0000FFAAAAFF0000AA00FFAA00AAFF00FFFFFF
00FFFFFF5555FF550000FF00000000FF55FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFAAFF00FFFF00FFAAAAFFFFFFAAFF0000FFFFFFFFFF00AAAA
AA005500FFFF00000000FFFF0000FF0000FFFF00000000FFFF005500AAAAAA00FFFFFFFF
FF0000FFAAFFFFFFAAAAFF00FFFF00FFAAFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF00AAAA00FF000000FFFF0000FF00AA55FF00
55FFAAFF5555FFAA55FFFFFFFF00FF00FFFFFFFF55AAFF5555FFAAFF5500FF55AA00FF00
00FFFF000000FF00AAAA00FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF5500FFFFFF00FFFFFFFF00FFAAAA0000FF
FFAA00AAFFFFAA00AA00FF0000FFFFFF0000FF00AA00AAFFFFAA00AAFFFF0000AAAAFF00
FFFFFFFF00FFFFFF0055FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FFAAFFAA00FF00FF0000FF00FF0055FFFF00
00FF55FF0000FF55FF00FF00FFFFFFFFFF00FF00FF55FF0000FF55FF0000FFFF5500FF00
FF0000FF00FF00AAFFAAFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAAAAA555555AAFF00FF00FFFFFF0000555555FF
FF00AA00FFFF00AA00FFFFFF5555555555FFFFFF00AA00FFFF00AA00FFFF5555550000FF
FFFF00FF00FFAA555555AAAAAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000AA000000FFFFFF0000FF00FFFFAAFFFF
FFFF005500AA55FF00FF00AAFFFFAAFFFFAA00FF00FF55AA005500FFFFFFFFAAFFFF00FF
0000FFFFFF000000AA0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF55FFFF0000FFAAAAFF00FF000000FF
0000FFFFAAAA0000FFFFFF0055AA00AA5500FFFFFF0000AAAAFFFF0000FF000000FF00FF
AAAAFF0000FFFF55FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFAA00FFFF00AAAA00FFFFFF00FFFF
FF00FF000000005500AA550000AAAAAA000055AA005500000000FF00FFFFFF00FFFFFF00
AAAA00FFFF00AAFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA0055FFFFFFFF5500FFFFFFFFFF0000
FF00FFAAAAAAAAFFFF5500550000000000550055FFFFAAAAAAAAFF00FF0000FFFFFFFFFF
0055FFFFFFFF5500AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000005555555555550000FF0000FF00FF
FFFF000000000000FFAAFFAAFFAAAAAAFFAAFFAAFF000000000000FFFFFF00FF0000FF00
00555555555555000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFAAFFFFAAFFFF00FF00FFFFFF00
00FFAAAAAAAAAAAAAA5555FF0000000000FF5555AAAAAAAAAAAAAAFF0000FFFFFF00FF00
FFFFAAFFFFAAFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF5555FF0000FFFFFF555555FF
FF000000000000000000AA00FFFF00FFFF00AA000000000000000000FFFF555555FFFFFF
0000FF5555FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAFFFFFF55FF555555005555
FF55FFFF55AAFFAAAAFF550000FF00FF000055FFAAAAFFAA55FFFF55FF555500555555FF
55FFFFFFAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000AAFFFFAAFFAAFF
FFFFAA005555AAAA00AAFFFF55AAAAAA55FFFFAA00AAAA555500AAFFFFFFAAFFAAFFFFAA
0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF5555FF000000
FF000000555500FF55AA55AA0000000000AA55AA55FF005555000000FF000000FF5555FF
00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFAAFFFFFF00FF
FFFF00FFFFAAFFAA000000AAAAAAAAAAAAAA000000AAFFAAFFFF00FFFFFF00FFFFFFAAFF
00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAAA55555555FFFF
FFFFFF5555FF0000005500000000000000000055000000FF5555FFFFFFFFFF55555555AA
AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000AA0000AAFF
0000FFAAFFFFFF55FFFFAAAAFFAAAAAAFFAAAAFFFF55FFFFFFAAFF0000FFAA0000AA0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0055000000
FFFF000000FF0000AA55AA555555AA555555AA55AA0000FF000000FFFF0000005500FFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFAA55FF
AA00FFFF00FFAAAAAA000000AA000000AA000000AAAAAAFF00FFFF00AAFF55AAFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA00AA00
55FFFFFFFF00000000005500000055000000550000000000FFFFFFFF5500AA00AAFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000055FF
AAFF0000FF00FFFF55FFFFAAAAFFAAFFAAAAFFFF55FFFF00FF0000FFAAFF55000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFAA
00AAFFAAAA55FF555500AA5555AA00AA5555AA005555FF55AAAAFFAA00AAFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
55FF00000000AAFFFFAAAA0000AAAAAA0000AAAAFFFFAA00000000FF55FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
AAFF00FFFF00FF5555FF005500000000005500FF5555FF00FFFF00FFAAFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFF0000AA00FFFFAAAAAAAAAAFFFF00AA0000FFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFF55FF00FF00000000000000FF00FF55FFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF0000FFAAFF00FF00FFFF00FFFF00FF00FFAAFF0000FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFAAAAAA5555FFFFFF00AAFFAA00FFFFFF5555AAAAAAFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000AA00FF000055FF550000FF00AA0000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF00FF55FF55AAFFFFFFAA55FF55FF00FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFAA000000FF000000AAFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFAA0055FFFF00FF00FFFF5500AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000555555FFFFFF555555000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFAAFFFFFFFFFFAAFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF5555FF5555FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFAAFFFFFFAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.15228 0.588183 1.23959 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00AAAAAA55AAAAAA5555550000005500FF00FF00FFFFAA55AA555500000055AAAAAAAA
AAFFFF55AAAAAAFF00FF00AAAA55AA55AAAA00FF00FFAAAAAA55FFFFAAAAAAAAAA550000
005555AA55AAFFFF00FF00FF0055000000555555AAAAAA55AAAAAA00FF
FFFF00005500FF0000FF5500FFFF55FF00FFAAAA55FF5555550000AAAAAAAAAA00550000
55AAAA5555555555FFFFFF00005555550000FFFFFF5555555555AAAA5500005500AAAAAA
AAAA0000555555FF55AAAAFF00FF55FFFF0055FF0000FF00550000FFFF
FFFFFF00FF55FF55FFFFFFAAAA55AA55AAFF000055FF550055FFFF0000FF0000FFFFAA55
FF00005555AA5555AAAA55AAFF550055FFAA55AAAA5555AA55550000FF55AAFFFF0000FF
0000FFFF550055FF550000FFAA55AA55AAAAFFFFFF55FF55FF00FFFFFF
FFFFFFFF00AAAA5555FF55555555000000FFAAAAFFFFFFAA5555FF55FFFFFF55AAAA5500
FFAAAAAA000055550000555555FF00FF555555000055550000AAAAAAFF0055AAAA55FFFF
FF55FF5555AAFFFFFFAAAAFF00000055555555FF5555AAAA00FFFFFFFF
FFFFFFFFFF00005555AAAA0000AAAAAAFF55555555FF555555AA55AA55AAAA55555555AA
FF0000FF00FFFFAAFF55AA5555AAAAAA5555AA55FFAAFFFF00FF0000FFAA55555555AAAA
55AA55AA555555FF55555555FFAAAAAA0000AAAA55550000FFFFFFFFFF
FFFFFFFFFFFF00FF550000FFFF000055AAAA0000AAAA5555AA5500FF0055000000000000
FFAAAAAA55FF555555FF000000005500000000FF555555FF55AAAAAAFF00000000000055
00FF0055AA5555AAAA0000AAAA550000FFFF000055FF00FFFFFFFFFFFF
FFFFFFFFFFFFFF00AAAAAAAA55AAFF550000FFFF0000555500AAAAAA55FF00FFFF55FFAA
AA55000055FF550055FF55FFFF55AA55FFFF55FF550055FF55000055AAAAFF55FFFF00FF
55AAAAAA0055550000FFFF000055FFAA55AAAAAAAA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000055000000FFAAFF55AAAA55FFAAFFFF00005500FFAAAA55AA55AA
0055FFAA5555FF00FF5555AAAA555555AAAA5555FF00FF5555AAFF5500AA55AA55AAAAFF
00550000FFFFAAFF55AAAA55FFAAFF000000550000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF55FFFF555555FF0000FF555555FF55FFAAFFAA0055005500FF
00FF55555500FFAA55AA55555555AA55555555AA55AAFF00555555FF00FF0055005500AA
FFAAFF55FF555555FF0000FF555555FFFF55FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00AAAA55AA5555AAAAAAAA5555AA55AA55AA00FF00FF55FF00FF
AA55AA5555AAFF0000005555AA555555AA5555000000FFAA5555AA55AAFF00FF55FF00FF
00AA55AA55AA5555AAAAAAAA5555AA55AAAA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000055555500FF00005500555555000000FFFFFF5555AAAAAA
5500FF00555555FFFF55AA555555AA555555AA55FFFF55555500FF0055AAAAAA5555FFFF
FF00000055555500550000FF005555550000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF5500FFFFFF00FF55AA5555AAFFAA55AAAA5555000055
00FFFFFF005555AAAA555555AA555555AA555555AAAA555500FFFFFF005500005555AAAA
55AAFFAA5555AA55FF00FFFFFF0055FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAA55AAAAAA55555500FF00AA55555555AA55FFFF
AAAA55AAAAAA0000FF0055550000000000555500FF0000AAAAAA55AAAAFFFF55AA555555
55AA00FF00555555AAAAAA55AAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00005500FF0000FF5500FFFFFF00000000000055FF55
5555550000FF00FFFFFF0055FFFF00FFFF5500FFFFFF00FF000055555555FF5500000000
0000FFFFFF0055FF0000FF00550000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FF55FFFFFFAAAA55AAAAAAAAAAFF55AA55AA
5555AA55FFFFFF5555FF55AA55AAAAAA55AA55FF5555FFFFFF55AA5555AA55AA55FFAAAA
AAAAAA55AAAAFFFFFF55FF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAA5555FF5555555500005500AA55AA5500FF
00555555AAAA55AA5555FF000000FF000000FF5555AA55AAAA55555500FF0055AA55AA00
55000055555555FF5555AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00005555AAAA0000AAAAAAFFFF000000FF55FF
55AA55550000555555AA55AAFF55FF55FFAA55AA55555500005555AA55FF55FF000000FF
FFAAAAAA0000AAAA55550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF550000FFFF000055AAAA55FFAA55AA55
AA550055FFFF0055FF0000AA55AA55AA55AA0000FF5500FFFF550055AA55AA55AAFF55AA
AA550000FFFF000055FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAA55AAFF550000FF555555AA00
00FF55AA55AAAAFFFFFF00FF0055005500FF00FFFFFFAAAA55AA55FF0000AA555555FF00
0055FFAA55AAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055000000FFAAFF55AAAA000000FF
FF555500000055AAAA55AAFF00FF55FF00FFAA55AAAA550000005555FFFF000000AAAA55
FFAAFF000000550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FFFF555555FF0000FFFF55FF
5555AA55FFFF0055000000FFAA55AA55AAFF0000005500FFFF55AA5555FF55FFFF0000FF
555555FFFF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAA55AA5555AAAAAAAA55AA55
AA555555AAAA55FF00FFFF00AA555555AA00FFFF00FF55AAAA555555AA55AA55AAAAAAAA
5555AA55AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055555500FF00005500FF00
5500FF5500005555FFFFFFFF0000AA0000FFFFFFFF5555000055FF005500FF00550000FF
005555550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF5500FFFFFF00FF55AAAA
FFFF5555AAFFAAFFFFFFFFFFFF00FF00FFFFFFFFFFFFAAFFAA5555FFFFAAAA55FF00FFFF
FF0055FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAA55AAAAAA555555
55FF5500FF00AA55AAAA55AAAA55FF55AAAA55AAAA55AA00FF0055FF55555555AAAAAA55
AAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00005500FF0000FF5500
5555FF00FFAA55005500000055AA55AA55000000550055AAFF00FF55550055FF0000FF00
550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FF55FFFFFFAA
5555AAAAAA5500FFFFAAAAFF5500AA0055FFAAAAFFFF0055AAAAAA5555AAFFFFFF55FF55
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAA5555FF5555
55AA550000FF55FF55555555FF00FF00FF55555555FF55FF000055AA555555FF5555AAAA
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00005555AAAA00
000055FFAA55AA55AA555500FFAA55AAFF005555AA55AA55AAFF55000000AAAA55550000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF550000FF
FF00FF5555550000005555AAFF000000FFAA5555000000555555FF00FFFF000055FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAA
55AAFF0055FF00FFFF550055AAAAAAAAAA550055FFFF00FF5500FFAA55AAAAAAAA00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00005500
0000FFAA5555FFFFFFFFAA55555555555555AAFFFFFFFF5555AAFF000000550000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55
FFFF555555AA55AAAA55AA00000000000000AA55AAAA55AA555555FFFF55FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA
AA55AA55550000005500FF00FFFF55FFFF00FF00550000005555AA55AAAA00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0055555500FFFF00FF55AAAAAA55AA55AAAAAA55FF00FFFF005555550000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF5500FFFFFFFF55550000550055005500005555FFFFFFFF0055FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00AAAAAA55AAAA5555AAFFAAFFAAFFAAFFAA5555AAAA55AAAAAA00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00005500FF000000AA55AA00FF00AA55AA000000FF00550000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF55FF55FFFF000000FFFFFF000000FFFF55FF55FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00AAAA5555FF55FFAAAA55AAAAFF55FF5555AAAA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00005555AAAA00FF000000FF00AAAA55550000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF550000FFFFFF00FFFFFF000055FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00AAAAAAAA55AAAAAA55AAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000055000000FF000000550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF55FFAA55AAFF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00AAAA550055AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF55FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.15228 0.782187 1.23959 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00AA55AAFFAAAA00000000AA00AA00AA5500AAAA55FFFF55AAAA00FF0000AA55AAAAAA
55AA0000AA55AA55550000AAFFAA00AAFFAA00005555AA55AA0000AA55AAAAAA55AA0000
FF00AAAA55FFFF55AAAA0055AA00AA00AA00000000AAAAFFAA55AA00FF
FFFF00AA55AA55AAAAAAAAAAFF00FFAAAA5500000000FF5500AAFF00FF55AAFF00000000
00FFAAAAFF0000AA5500005555AAAAAA5555000055AA0000FFAAAAFF0000000000FFAA55
FF00FFAA0055FF0000000055AAAAFF00FFAAAAAAAAAA55AA55AA00FFFF
FFFFFF00AA55AA0000000000AAAAAA000000FFFF55FFFFFFAA55AA55FF0000AAAAAAAAAA
AAAA0000AAAAAAAA55000055AA000000AA55000055AAAAAAAA0000AAAAAAAAAAAAAA0000
FF55AA55AAFFFFFF55FFFF000000AAAAAA0000000000AA55AA00FFFFFF
FFFFFFFF00AA55AAFFAAAAAAAA55AAAAAAAAAA00AA5555AA55AA0000FF55FFAA0000AA00
00AAFFAAAA55AAAA55000055AAAAAAAAAA55000055AAAA55AAAAFFAA0000AA0000AAFF55
FF0000AA55AA5555AA00AAAAAAAAAA55AAAAAAAAFFAA55AA00FFFFFFFF
FFFFFFFFFF00AA55AA55AAAA55AA0000000000005555555500AAFFAA555555AAAAAAAA55
FFAA00AAFF00000000FFFF000000AA000000FFFF00000000FFAA00AAFF55AAAAAAAA5555
55AAFFAA0055555555000000000000AA55AAAA55AA55AA00FFFFFFFFFF
FFFFFFFFFFFF00AA55AA000000FFAAAAAAAAAAFFAAFFFFAAFFAA00AA0055AA00000000AA
55550000AAAAAAFFAA5555AAFFAA55AAFFAA5555AAFFAAAAAA00005555AA00000000AA55
00AA00AAFFAAFFFFAAFFAAAAAAAAAAFF000000AA55AA00FFFFFFFFFFFF
FFFFFFFFFFFFFF00AA55AAFFAAAA00000000AA00AA00AAAA555500000055AAAAAAFFAA55
AA00550000AA00FF5555555500FFAAFF0055555555FF00AA00005500AA55AAFFAAAAAA55
0000005555AAAA00AA00AA00000000AAAAFFAA55AA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00AA55AA55AAAAAAAAAAFF00FFAAAA55AA0055000055AAAA55AA55AA
00FFFFAAAAAA55FF0000FF000055FF550000FF0000FF55AAAAAAFFFF00AA55AA55AAAA55
00005500AA55AAAAFF00FFAAAAAAAAAA55AA55AA00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00AA55AA0000000000AAAAAA000000FFAA55000055AAAA550055AA
AAAA00AA000000FF55FFFFFF55AA00AA55FFFFFF55FF000000AA00AAAAAA550055AAAA55
000055AAFF000000AAAAAA0000000000AA55AA00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00AA55AAFFAAAAAAAA55AAAAAAAAAA0000FFFF00000000FFFFAA
00FFAAAA55FFAAAA0055FF0055AAAAAA5500FF5500AAAAFF55AAAAFF00AAFFFF00000000
FFFF0000AAAAAAAAAA55AAAAAAAAFFAA55AA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AA55AA55AAAA55AA0000000000005500FF55AAFFAA5555AA
AAAA000000FF55550000FF55AA000000AA55FF00005555FF000000AAAAAA5555AAFFAA55
FF0055000000000000AA55AAAA55AA55AA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AA55AA000000FFAAAAAAAAAAFFAAFF5500AA00AA0055AA
AA55AAFF55FF0000FFFF0055AAAAAAAAAA5500FFFF0000FF55FFAA55AAAA5500AA00AA00
55FFAAFFAAAAAAAAAAFF000000AA55AA00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AAFFAAAA00000000AA00AA00AA55FF55FF55AA00
00AA55AA5500FFFF5500FFFFAA000000AAFFFF0055FFFF0055AA55AA0000AA55FF55FF55
AA00AA00AA00000000AAAAFFAA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AA55AAAAAAAAAAFF00FFAAAA5500FF0055AAAA
AAFF000000FFFFFFFFAA5555AAAAAAAAAA5555AAFFFFFFFF000000FFAAAAAA5500FF0055
AAAAFF00FFAAAAAAAAAA55AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AA0000000000AAAAAA000000FFFFFF000000
00AAAAAAAAAA00AAAA00FF00000000000000FF00AAAA00AAAAAAAAAA00000000FFFFFF00
0000AAAAAA0000000000AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AAFFAAAAAAAA55AAAAAAAAAA00AAAAAAAA
FFAA00000000005555FFFFFF55AAFFAA55FFFFFF55550000000000AAFFAAAAAAAA00AAAA
AAAAAA55AAAAAAAAFFAA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AA55AAAA55AA00000000000055550055
55AAAAAAAAAAFFAAFFFFFFFFFFAA00AAFFFFFFFFFFAAFFAAAAAAAAAA5555005555000000
000000AA55AAAA55AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AA000000FFAAAAAAAAAAFFAAFFFF00
00FFAA000000AAAA5555AA5555AAAAAA5555AA5555AAAA000000AAFF0000FFFFAAFFAAAA
AAAAAAFF000000AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AAFFAAAA00000000AA00AA00AAAA
AAAA000055000000AA550055AA000000AA550055AA000000550000AAAAAAAA00AA00AA00
000000AAAAFFAA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AA55AAAAAAAAAAFF00FFAAAA55
AAAA55FFFFAAAAAAAA550000FFAAAAAAFF000055AAAAAAAAFFFF55AAAA55AAAAFF00FFAA
AAAAAAAA55AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AA0000000000AAAAAA000000
FFAA0055FF00AA00FFAAFFAA5555005555AAFFAAFF00AA00FF5500AAFF000000AAAAAA00
00000000AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AAFFAAAAAAAA55AAAAAAAA
AA000055AA55FF55AA55AA55AA005500AA55AA55AA55FF55AA550000AAAAAAAAAA55AAAA
AAAAFFAA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AA55AAAA55AA00000000
00005500AAFFFFFFAA00555555FFAAFF55555500AAFFFFFFAA0055000000000000AA55AA
AA55AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AA000000FFAAAAAAAA
AAFFAAFFAA00AAAA000055AA0055FF5500AA550000AAAA00AAFFAAFFAAAAAAAAAAFF0000
00AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AAFFAAAA00000000
AA00AA00AAFF5555FFFF00000055AA55000000FFFF5555FFAA00AA00AA00000000AAAAFF
AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AA55AAAAAAAAAA
FF00FFAAAA55555555AA55FFFF000000FFFF55AA55555555AAAAFF00FFAAAAAAAAAA55AA
55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AA0000000000
AAAAAA0000AA5500AA55AA00AAAAAAAAAA00AA55AA0055AA0000AAAAAA0000000000AA55
AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AAFFAAAAAA
AA55AAAAAAFF0000555555000000000000005555550000FFAAAAAA55AAAAAAAAFFAA55AA
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AA55AAAA
55AA000000AAAAAAFFFFAAFFAAAAAAAAAAFFAAFFFFAAAAAA000000AA55AAAA55AA55AA00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AA0000
00FFAAAAAAAA55AAAA00AA00AA000000AA00AA00AAAA55AAAAAAAAFF000000AA55AA00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AAFF
AAAA00000000AA55AAAAFF00FFAAAAAAFF00FFAAAA55AA00000000AAAAFFAA55AA00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AA
55AAAAAAAAAAFF000000AAAAAA000000AAAAAA000000FFAAAAAAAAAA55AA55AA00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55
AA0000000000AAAAAAAAAA55AAAAAAAAAA55AAAAAAAAAA0000000000AA55AA00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA
55AAFFAAAAAAAA55AAAA55AA0000000000AA55AAAA55AAAAAAAAFFAA55AA00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
AA55AA55AAAA55AA000000FFAAAAAAAAAAFF000000AA55AAAA55AA55AA00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00AA55AA000000FFAAAAAAAA0000AA0000AAAAAAAAFF000000AA55AA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00AA55AAFFAAAA00000000005500550000000000AAAAFFAA55AA00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00AA55AA55AAAAAAAAAAFFAAFFAAFFAAAAAAAAAA55AA55AA00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00AA55AA00000000AA00AA00AA00AA00000000AA55AA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00AA55AAFFAAAAAA55FF55FF55AAAAAAFFAA55AA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00AA55AA55AAAA5500FF0055AAAA55AA55AA00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00AA55AA000000FFFFFF000000AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00AA55AAFFAAAA00AAAAFFAA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00AA55AA55AAAAAA55AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00AA55AA000000AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00AA55AAFFAA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AA55AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.15228 0.97619 1.23959 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00AA55AA00FFFFAA00005500FFFFFFFFFFFF5500FFFFFFFF0055FFFFFF55000055FF55
0000AA5500AA00550000FFFFFFFFFFFFFFFFFF00005500AA0055AA000055FF55000055FF
FFFF5500FFFFFFFF0055FFFFFFFFFFFF00550000AAFFFF00AA55AA00FF
FFFF00AAAA550000AAFFAA555555005555000055FFFFFFFFFFFF0055000055FFFF550055
FFFF5555AAFF00FF55FFFFFFFFFFFFFFFFFFFFFF55FF00FFAA5555FFFF550055FFFF5500
005500FFFFFFFFFFFF550000555500555555AAFFAA000055AAAA00FFFF
FFFFFF00AAFFFF000000AAFFFFAAFF5500FFFF550000550000AA0055FFFF00555500FF00
555500FF555500AA00AA000055550055550000AA00AA005555FF00555500FF00555500FF
FF5500AA000055000055FFFF0055FFAAFFFFAA000000FFFFAA00FFFFFF
FFFFFFFF00AA0000FFFF555500000055FFFFFFFFAAAAFFFF55AAAAFFFFFFFF5500FFFFFF
0055FFFFFFAAFF555555FFFF5500FF0055FFFF555555FFAAFFFFFF5500FFFFFF0055FFFF
FFFFAAAA55FFFFAAAAFFFFFFFF550000005555FFFF0000AA00FFFFFFFF
FFFFFFFFFF00AA55005555AA55FFFF550000AA000000005500FFAA0000555500FFFFFFFF
FF00555500000055FF00555500FFFFFF00555500FF55000000555500FFFFFFFFFF005555
0000AAFF005500000000AA000055FFFF55AA55550055AA00FFFFFFFFFF
FFFFFFFFFFFF00AAAAAA00AAFFFFFFFFAA55FF55AAFFAAAA005555FFFF5500FFFFFFFFFF
FFFF0055FFAAAAFFFFFF5500FFFFFFFFFF0055FFFFFFAAAAFF5500FFFFFFFFFFFFFF0055
FFFF555500AAAAFFAA55FF55AAFFFFFFFFAA00AAAAAA00FFFFFFFFFFFF
FFFFFFFFFFFFFF00AAFF000000AA0000AAFFFFFFAA00000000FF55000055FFFFFFFFFFFF
FFFFFF5500000000555500FFFFFFFFFFFFFF0055550000000055FFFFFFFFFFFFFFFFFF55
000055FF00000000AAFFFFFFAA0000AA000000FFAA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00AA0055AA00FF000000AA000000FFFF0000AAAAAAFFFFFFFFFFFFFF
FFFFFFFFAAAAAAFF5500FFFFFFFFFFFFFFFFFF0055FFAAAAAAFFFFFFFFFFFFFFFFFFFFFF
AAAAAA0000FFFF000000AA000000FF00AA5500AA00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00AA5555FFFFFF00FF00AA55FFFFFFFF0000000000555500005555
005555000000000055FFFFFFFFFFFFFFFFFFFFFF55000000000055550055550000555500
00000000FFFFFFFF55AA00FF00FFFFFF5555AA00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00AAAA0000AA005500AAFFFFFFFFFFFF0000FFFF0055FFFF5500
FF0055FFAAAAAAAAAA0000555500550055550000AAAAAAAAAAFF5500FF0055FFFF5500FF
FF0000FFFFFFFFFFFFAA005500AA0000AAAA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AAFF55FF55FF000000550055550000FFFFFFFF55000055FF
FFFF5500000000000000FF0055FFAAFF5500FF0000000000000055FFFFFF55000055FFFF
FFFF000055550055000000FF55FF55FFAA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AA00AA00AA0055AAFFFF5500FF0000AA000055FFFF0055
005500FF00FFFF0000FFFFFF5500000055FFFFFF0000FFFF00FF0055005500FFFF550000
AA0000FF0055FFFFAA5500AA00AA00AA00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AA00FFFFAA000055FFFFFF000000FF00555500AA
AAAA005555550000FFFFFFFFFFAAAAAAFFFFFFFFFF000055555500AAAAAA00555500FF00
0000FFFFFF550000AAFFFF00AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAA550000AAFFAA55550000AA55FFFFFF5500FF00
AAFF00FF5500FF0000AA00005555FF55550000AA0000FF0055FF00FFAA00FF0055FFFFFF
55AA00005555AAFFAA000055AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF000000AAFFFFAAAAFF0055005500FFFFFF
00AA005500FFFFFF55AAAAFFAAFFFFFFAAFFAAAA55FFFFFF005500AA00FFFFFF00550055
00FFAAAAFFFFAA000000FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA0000FFFF55550000000055AA5500FFFFFFFF
FF555555AA00005500FFAA00000055000000AAFF00550000AA555555FFFFFFFFFF0055AA
55000000005555FFFF0000AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55005555AA55FFFF55AA55AA550000AA00
00AAAA00AAFFAAAA005555FFFF55AA55FFFF555500AAAAFFAA00AAAA0000AA000055AA55
AA55FFFF55AA55550055AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAA00AAFFFFFFFFAA00AAFFFF000000
FF00AAFFAA00000000FF55000055FF55000055FF00000000AAFFAA00FF000000FFFFAA00
AAFFFFFFFFAA00AAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF000000AA0000AAFFAA0000AA55FF
FFFF00AA00FF0000FFFFFFAAAAFFFFFFAAAAFFFFFF0000FF00AA00FFFFFF55AA0000AAFF
AA0000AA000000FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA0055AA00FF000000AAFF55AAAA00
00555555FFFFFF0000AA00000000AA00000000AA0000FFFFFF5555550000AAAA55FFAA00
0000FF00AA5500AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA5555FFFFFF00FF00AA00AAFF00
FFFFAAFFFFFFFFFF000000FFFF000000FFFF000000FFFFFFFFFFAAFFFF00FFAA00AA00FF
00FFFFFF5555AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAA0000AA005500AAFF555500
AA00000055550000AA55FFFFFFFF55FFFFFFFF55AA00005555000000AA005555FFAA0055
00AA0000AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF55FF55FF00000055FF00
0000FFFF0055FFAAAA55550000AA00AA00005555AAAAFF5500FFFF000000FF55000000FF
55FF55FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00AA00AA0055AAFFFFFF
00FFFFFFFF005555FF5500FFFF555555FFFF0055FF555500FFFFFFFF00FFFFFFAA5500AA
00AA00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AA00FFFFAA000055
555500550000FF550055FFFFFFFFAAFFFFFFFF550055FF000055005555550000AAFFFF00
AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAA550000AAFFAAAA
00AAAAFFFF0000AAAAAA000055000000550000AAAAAA0000FFFFAAAA00AAAAFFAA000055
AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF000000AAFF
000000005500AA55AAAA55FFFFAAAAAAFFFF55AAAA55AA005500000000FFAA000000FFFF
AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA0000FFFF5555
00AA55FFAAFF5555AAAA555500000000005555AAAA5555FFAAFF55AA005555FFFF0000AA
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55005555AA
55FF5500000055FF00AAFFFFAAAAAAAAAAFFFFAA00FF5500000055FF55AA55550055AA00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAA00AA
FFFFFFAAAAAAFFFFFF00AA00000000000000AA00FFFFFFAAAAAAFFFFFFAA00AAAAAA00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF0000
00AA0000000000550000FFAAAAAAAAAAAAAAFF0000550000000000AA000000FFAA00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA0055
AA00FFFF0000FF0055AA000000000000000000AA5500FF0000FFFF00AA5500AA00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55
55FFFFFFFF0000AA5555FFAAAAAAAAAAAAAAFF5555AA0000FFFFFFFF5555AA00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA
AA0000AA0000FF00AAAA000000000000000000AAAA00FF0000AA0000AAAA00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
AAFF55FF55FFFFFF5555FFAAAAAAAAAAAAAAFF5555FFFFFF55FF55FFAA00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00AA00AA00AA0000AAAA000000000000000000AAAA0000AA00AA00AA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00AA55AA00FFFF5555FFAAAAAAAAAAAAAAFF5555FFFF00AA55AA00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00AAAA550000AAAA000000000000000000AAAA000055AAAA00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00AAFFFF00000000FFFF00FF00FFFF00000000FFFFAA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00AA0000FFFF0000AA005500AA0000FFFF0000AA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00AA550055555555FFAAFF555555550055AA00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00AAAAAA00AAAA000000AAAA00AAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00AAFF00000000FF00000000FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00AA0055AA005500AA5500AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00AA5555FFAAFF5555AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00AAAA000000AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AAFF55FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AA00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.24832 0.200176 1.33563 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF550000000055AAAAFF0000FFAAFFFFAA000000FF000000FF55FFAA00AA0000AA0000FF
FFFF00FF0000FFFF5555AA0055FFFFFF5500AA5555FFFF0000FF00FFFFFF0000AA0000AA
00AAFF55FF000000FF000000AAFFFFAAFF0000FFAAAA550000000055FF
FFFFAAAAFF0000555500FFAAAA00000000AAFF000000FF00000055FFAA0000FF00FF0000
000000FF5555FF00550000AAFFFFFFFFFFAA00005500FF5555FF0000000000FF00FF0000
AAFF55000000FF000000FFAA00000000AAAAFF0055550000FFAAAAFFFF
FFFFFF00FF55FFFFAAFF00555500AAFFAA000000FF000000FF000055FFAA0055FFFFFF55
5555FF55000055FFFFAA00FFFFFFFFFFFFFF00AAFFFF55000055FF555555FFFFFF5500AA
FF550000FF000000FF000000AAFFAA00555500FFAAFFFF55FF00FFFFFF
FFFFFFFF5500000000AAAAFFFFAA000000AAFF00AAAAFFAA00AA55000000AAFFFFFFFFFF
AAFFFFFFAAAAFFFFFFFF000000000000000000FFFFFFFFAAAAFFFFFFAAFFFFFFFFFFAA00
000055AA00AAFFAAAA00FFAA000000AAFFFFAAAA0000000055FFFFFFFF
FFFFFFFFFFAAAAFF0000AA00AAAAAAFFAA000000FFFF005555550000FFAA000000000000
00AAAA00AA000000000000FF00AAFFAA00FF000000000000AA00AAAA00000000000000AA
FF000055555500FFFF000000AAFFAAAAAA00AA0000FFAAAAFFFFFFFFFF
FFFFFFFFFFFF00FF55FFFF0000AA000000AAFFAA00AAAAFFFFAAFF000000AAFFAA00FF00
AA55FFAAAAAAFFAA00FF000000FFFFFF000000FF00AAFFAAAAAAFF55AA00FF00AAFFAA00
0000FFAAFFFFAAAA00AAFFAA000000AA0000FFFF55FF00FFFFFFFFFFFF
FFFFFFFFFFFFFF5500000000FF00FF0000FFFFFF00AA00000000AAAAFFAA000000AA5555
55000000AA000000AA555555FFFFFFFFFF555555AA000000AA000000555555AA000000AA
FFAAAA00000000AA00FFFFFF0000FF00FF0000000055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAFF000000FF55FFFFFFFFFF55AA00FF00AA000000AAFFAA000055
0000FFAAAAAAFFAA00005500000000000000550000AAFFAAAAAAFF0000550000AAFFAA00
0000AA00FF00AA55FFFFFFFFFF55FF000000FFAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF55FFFF55000000000000005555FF00AA00FFAA000000AAFFAA
FF000000AA000000AAFFAAFF00AAFFAA00FFAAFFAA000000AA000000FFAAFFAA000000AA
FF00AA00FF55550000000000000055FFFF55FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF550000000055AAAAFF0000FFAAFFFFFF55AA00AA00FF0000AAAA
AA00FFAAAAAAFF0000AAAAAA00FFFFFF00AAAAAA0000FFAAAAAAFF00AAAAAA0000FF00AA
00AA55FFFFFFAAFF0000FFAAAA550000000055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFF0000555500FFAAAA00000000005555FFAA00AAFF00FF
FF000000AA000000FF00FFFF0000000000FFFF00FF000000AA000000FFFF00FFAA00AAFF
55550000000000AAAAFF0055550000FFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF55FFFFAAFF00555500AAFFAA0055000000AA55FF00AA
AA00FF0000AAFF000000FF5500AAFFAA0055FF000000FFAA0000FF00AAAA00FF55AA0000
005500AAFFAA00555500FFAAFFFF55FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF5500000000AAAAFFFFAA000000AAFFFF555555000000FF
FF000000FFAA555555FFFFFFAA000000AAFFFFFF555555AAFF000000FFFF000000555555
FFFFAA000000AAFFFFAAAA0000000055FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF0000AA00AAAAAAFFAA00000000550000FF00AA
AA0055AAAA0000550000000000AAFFAA0000000000550000AAAA5500AAAA00FF00005500
000000AAFFAAAAAA00AA0000FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FFFF0000AA000000AAFFAAAAFFFF5555AA00
00AAFFFF00FF000055AA00FFAA000000AAFF00AA550000FF00FFFFAA0000AA5555FFFFAA
AAFFAA000000AA0000FFFF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500000000FF00FF0000FFFFFF00FF5500005555
555500FF5555AAAAFFFF000000AAFFAA000000FFFFAAAA5555FF0055555555000055FF00
FFFFFF0000FF00FF0000000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF000000FF55FFFFFFFFFF550000FFAAFF
FFAAFF00550000AA00AAAAFFAA000000AAFFAAAA00AA00005500FFAAFFFFAAFF000055FF
FFFFFFFF55FF000000FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FFFF550000000000000055AAAA0000
0000AAAAFFFF555500AA000000AAFFAA000000AA005555FFFFAAAA00000000AAAA550000
000000000055FFFF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000000055AAAAFF0000FFAAFF55AA00
FF00AA000000005500AA00FF00AA00AA00FF00AA005500000000AA00FF00AA55FFAAFF00
00FFAAAA550000000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF0000555500FFAAAA0000005555
55AA0000FFAAAAFFFF55AA00AA55FF55AA00AA55FFFFAAAAFF0000AA555555000000AAAA
FF0055550000FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FFFFAAFF00555500AAFFAAFF
FFAA55AA00AA0000000055555500000055555500000000AA00AA55AAFFFFAAFFAA005555
00FFAAFFFF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500000000AAAAFFFFAA000000AA
AA000055555500AAFF0000550000FF0000550000FFAA005555550000AAAA000000AAFFFF
AAAA0000000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF0000AA00AAAAAAFFAAAA
AAAAFFAAFFFFAA000000FFAAFF000000FFAAFF000000AAFFFFAAFFAAAAAAAAFFAAAAAA00
AA0000FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FFFF0000AA000000AA
0000AAAAAA00AA00FF000000AAAAFFAAAA000000FF00AA00AAAAAA0000AA000000AA0000
FFFF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500000000FF00FF0000FF
FF55550055555500AAAAFF0000AA00AA0000FFAAAA00555555005555FFFF0000FF00FF00
00000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF000000FF55FFFF
FFFFAAFFAAFFFFAAAAAAAA00FF00FF00FF00AAAAAAAAFFFFAAFFAAFFFFFFFF55FF000000
FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FFFF55000000
000000AAAAAA00AA0000AA0055FFFFFF5500AA0000AA00AAAAAA00000000000055FFFF55
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000000055AAAA
FF0000FFFF00FFAA55AAAAAAFFFFFFFFFFAAAAAA55AAFF00FFFF0000FFAAAA5500000000
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00005555
00FFAA00AAAA55550000AA00000000000000AA00005555AAAA00AAFF0055550000FFAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FFFFAA
FF0055555500550000FF00FFAA00FF00AAFF00FF0000550055555500FFAAFFFF55FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500000000
AAAAFFFFAAFFAAFF000000FF55AA00AA55FF000000FFAAFFAAFFFFAAAA0000000055FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00
00AA00AAAAAA000000FF000000555555000000FF000000AAAAAA00AA0000FFAAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55
FFFF0000AA0000FF000000FF0000550000FF000000FF0000AA0000FFFF55FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500
000000FF00FFAA00AAFFAA00AAFFAAFFAA00AAFFAA00AAFF00FF0000000055FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAFF000000FF55AA000000AA55FF00FF55AA000000AA55FF000000FFAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF55FFFF550000AAFFAA000055FF550000AAFFAA000055FFFF55FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF550000000055AA000000AA5500000055AA000000AA550000000055FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAFF000055555555550000FF000055555555550000FFAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF55FFFFAAFFFFAAFF000000FFAAFFFFAAFFFF55FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF5500000000AAAA000000FF000000AAAA0000000055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAFF0000AA00FF000000FF00AA0000FFAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF55FFFF000000FF000000FFFF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5500000000FF000000FF0000000055FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAFFAA00AAFFAA00AAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF55AA000000AA55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF550000AAFFAA000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00FFFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.24832 0.39418 1.33563 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF55550000FF00555500FFFFFFFF000000FF00005555FFFF550000FFFF00FFFF0000AA00
00FF00FF0055FFFFFFFFFFFF5500FF0055FFFFFFFFFFFF5500FF00FF0000AA0000FFFF00
FFFF000055FFFF55550000FF000000FFFFFFFF00555500FF00005555FF
FFFF00FF000000FFFF000000000000FF000000FF00FFFFFFFF0000AAFF000000555500FF
000055AAAAFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFAAAA550000FF005555000000
FFAA0000FFFFFFFF00FF000000FF000000000000FFFF000000FF00FFFF
FFFFFF5555005555FF55FFFF55FFFF5555005555FFFFFFFFFFFF55FF00AA0000FFFF0000
00FF00FF55000000000000550000FF00005500000000000055FF00FF000000FFFF0000AA
00FF55FFFFFFFFFFFF5555005555FFFF55FFFF55FF5555005555FFFFFF
FFFFFFFF00FF00FFFFFFAA00FFFFFFFF00FF00FFFFFFFFFFFFFFFF00AA00AA00000000FF
000000FFAA5500AA0000FF00FF000000FF00FF0000AA0055AAFF000000FF00000000AA00
AA00FFFFFFFFFFFFFFFF00FF00FFFFFFFF00AAFFFFFF00FF00FFFFFFFF
FFFFFFFFFF555500000055FFFFFFFFFFFF5555000000550000550000FF55FF0000AA0000
55555555FF00FF00555555FFFFFF55FFFFFF55555500FF00FF555555550000AA0000FF55
FF0000550000550000005555FFFFFFFFFFFF550000005555FFFFFFFFFF
FFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFAAFFAAAAFF55FFFF0000FFAAFF0000FF55FF
FF00FFFF00AA00FF00FFFF00AAFF00FFAA00FFFF00FF00AA00FFFF00FFFF55FF0000FFAA
FF0000FFFF55FFAAAAFFAAFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFF
FFFFFFFFFFFFFF555500550000000000000055FF5500FFAAFF00AA005500FFAAAAFF00FF
AA00005500AAAAFF00000000FF555555FF00000000FFAAAA00550000AAFF00FFAAAAFF00
5500AA00FFAAFF0055FF550000000000000055005555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF0000AA0000AA55FF55AA00FF555500FF00FF00AAAA00FF00
AAAAFFAA5500FF555555555555FFAAFF555555555555FF0055AAFFAAAA00FF00AAAA00FF
00FF005555FF00AA55FF55AA0000AA0000FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55550000FF00555500FFFFFF005555FFAAFFAA000000FF55005500
55FF00AAAAAAFF00FFFF00FFFFAA00AAFFFF00FFFF00FFAAAAAA00FF5500550055FF0000
00AAFFAAFF555500FFFFFF00555500FF00005555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF000000FFFF0000000000FFFF00AAAA5555555555FFAAAAAA
FF555500FF550000AAFF00005500FF00550000FFAA000055FF005555FFAAAAAAFF555555
5555AAAA00FFFF0000000000FFFF000000FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5555005555FF55FFFF55FFFFFFFF5500FFFF00FFFFAA00AAAA
00FFFFAAAA55FFFF550000AA55FFFFFF55AA000055FFFF55AAAAFFFF00AAAA00AAFFFF00
FFFF0055FFFFFFFF55FFFF55FF5555005555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFAA00FFFFFFFFFFFF00005500AAFF0055AA55
5555FF5500FFFFFFFF0000AAAAAA55AAAAAA0000FFFFFFFF0055FF555555AA5500FFAA00
550000FFFFFFFFFFFF00AAFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555500000055FFFFFFFFFFFFFFFF55FFAAAA00FF00FF55
AAFFFFFF000000000000FF0055FF00FF5500FF000000000000FFFFFFAA55FF00FF00AAAA
FF55FFFFFFFFFFFFFFFF550000005555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFFFFFF00AAAA000000FFAA
5555FF5555005555005555FFFF00AA00FFFF5555005555005555FF5555AAFF000000AAAA
00FFFFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555005500000000000000550000AAAA00555555FF
00FFFFFF00FF00FFFF55AAFF00AA00AA00FFAA55FFFF00FF00FFFFFF00FF55555500AAAA
0000550000000000000055005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000AA0000AA55FFFF5500FF00FFFF00
AA00FFAA000000AAFF00FF555500FF005555FF00FFAA000000AAFF00AA00FFFF00FF0055
FFFF55AA0000AA0000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55550000FF00555500FFFFFFFF00005555FF55
FF000055FFFF55FF00AA00FFFF000000FFFF00AA00FF55FFFF550000FF55FF55550000FF
FFFFFF00555500FF00005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFF000000000000FF00FFFFFF
AA0000FFFFFFFF00AA5555000000AA0000005555AA00FFFFFFFF0000AAFFFFFF00FF0000
00000000FFFF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555005555FF55FFFF55FFFF5555000000
55FFFF5555FF555500FFFF0000AA00AA0000FFFF005555FF5555FFFF550000005555FFFF
55FFFF55FF5555005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFAA00FFFFFFFF00FF0000
FFFFFFFF00FFAAFF55FF55555500FF00555555FF55FFAAFF00FFFFFFFF0000FF00FFFFFF
FF00AAFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500000055FFFFFFFFFFFF555555
00000055005500FFAAFF00FFFF000000FFFF00FFAAFF00550055000000555555FFFFFFFF
FFFF550000005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFFFFFFFFFFFF00FF
FF55FFFFAAAAAAFF005500550000FF000055005500FFAAAAAAFFFF55FFFF00FFFFFFFFFF
FFFFFF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500550000000000000000AA
FF00FFAA00AAAA00FF00FF00FF000000FF00FF00FF00AAAA00AAFF00FFAA000000000000
000055005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000AA0000AA0055
FF55FF550055FF00005555FFFFFF55FFFFFF55550000FF550055FF55FF5500AA0000AA00
00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55550000FF00555500FF00
FFAAFF00FF00FFAAAAFFFF00AAFF00FFAA00FFFFAAAAFF00FF00FFAAFF00FF00555500FF
00005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFF000055
55FF00AA00FF00AAAA00FFAAAA00FF00AAAAFF00AAAA00FF00AA00FF55550000FFFF0000
00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555005555FF55FFFF
00FFAAAA000000AAAA000055FF000000FF550000AAAA000000AAAAFF00FFFF55FF555500
5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFAA00
FF00AAAA0000FF0055FFFF55AAAAFFAAAA55FFFF5500FF0000AAAA00FF00AAFFFFFF00FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500000055FF
FFFF5500FF000000FFFFFFFF0055FF5500FFFFFFFF000000FF0055FFFFFF550000005555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFF
FFFFFF000000FF000000000000FFFFFF000000000000FF000000FFFFFFFFFF0000FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555005500
00000000FF000055555555005555FF555500555555550000FF000000000055005555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
0000AA000000FF00FFFF00FF00FFFFFF00FF00FFFF00FF000000AA0000FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500
00FF0055555555FFFFFFFF555555FF555555FFFFFFFF5555555500FF00005555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
000000FFFFAAFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFAAFFFF000000FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
55005555FF550000000000005555FF555500000000000055FF5555005555FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFF0000AA0000FF00FFFFFF00FF0000AA0000FFFFFF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5555000000555500FF00005555FF55550000FF0055550000005555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF0000FFFF000000FF00FFFFFF00FF000000FFFF0000FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF555500550000FF00005555FF55550000FF000055005555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FF000000FF00FFFFFF00FF000000FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55550000FF00005555FF55550000FF00005555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF000000FF00FFFFFF00FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5555005555FFFFFFFFFF5555005555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555000000000000005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55550055005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.24832 0.588183 1.33563 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF55FFFF0055AA0055555555AAFF55005555AAAAAAAAAA55FFAA55AA55005500AAFFAAFF
0000AA555500FF550000AA00005555550000AA000055FF005555AA0000FFAAFFAA005500
55AA55AAFF55AAAAAAAAAA55550055FFAA5555555500AA5500FFFF55FF
FFFF0055FFFFAA000000005500AAAAAAFFFFAA00FFAA005500FFAA55AAFFAAFFAA00AA55
550055AAFFFF550000AA005555000000555500AA000055FFFFAA55005555AA00AAFFAAFF
AA55AAFF005500AAFF00AAFFFFAAAAAA005500000000AAFFFF5500FFFF
FFFFFF55AA5555FFFF55FFFFAAAA5500AAAA005555AA00005555AAAAAA555555AAAAFF00
FFFF55AA00AAAAAAFFAA00000000AA00000000AAFFAAAAAA00AA55FFFF00FFAAAA555555
AAAAAA55550000AA555500AAAA0055AAAAFFFF55FFFF5555AA55FFFFFF
FFFFFFFF00000055FF00FF5500AAFFFF5555FFFF00FFAAAAFFFF0000FFAAFFFF0000FF55
FF005500AA0055AAAA0055550055555500555500AAAA5500AA005500FF55FF0000FFFFAA
FF0000FFFFAAAAFF00FFFF5555FFFFAA0055FF00FF55000000FFFFFFFF
FFFFFFFFFF55FFFF005555AAFFAA00AAAAAAAA00AA00AAFF0055FFFF5500AAAA0000AAAA
AA000000AAFFAA55AAAAFFFFAAAAAAAAAAFFFFAAAA55AAFFAA000000AAAAAA0000AAAA00
55FFFF5500FFAA00AA00AAAAAAAA00AAFFAA555500FFFF55FFFFFFFFFF
FFFFFFFFFFFF0055FFFFAA5500FFAAAA55AA0055555500AAAAFFFFFFFFAAAA5500555555
555500555555AAAAAA55AA55555555555555AA55AAAAAA5555550055555555550055AAAA
FFFFFFFFAAAA0055555500AA55AAAAFF0055AAFFFF5500FFFFFFFFFFFF
FFFFFFFFFFFFFF55AA5555FFAAAA00FFAA550055000055555555AA5555AAAA55FFFF00FF
FFAAFFAAFFFFAA00FFAAFF00FFFFAAFFFF00FFAAFF00AAFFFFAAFFAAFFFF00FFFF55AAAA
5555AA555555550000550055AAFF00AAAAFF5555AA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000055FF555500FFAAFFAAFFAAAAAAAAAAAA55FFAA005500FF55FF
0055AA5500FF555500FF005555AA55AA555500FF005555FF0055AA5500FF55FF005500AA
FF55AAAAAAAAAAAAFFAAFFAAFF005555FF55000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55FFFF00550000AAAA555555AAAA55AA00FFAA5555550000AAAAAA
000000FFFF55000000AAAAFFFF000000FFFFAAAA00000055FFFF000000AAAAAA00005555
55AAFF00AA55AAAA555555AAAA00005500FFFF55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055FFFFAAAAFF0000005500AA55FF55FF0000550000AA00FFAA
0000AA00AAAAAAFFAAAA55AA5555005555AA55AAAAFFAAAAAA00AA0000AAFF00AA000055
0000FF55FF55AA0055000000FFAAAAFFFF5500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AA5555FF550055550000AAFFFFFF0055550000AA005555AA
AAFFAA0000FFAA00AAFF00FFAAFF55FFAAFF00FFAA00AAFF0000AAFFAAAA555500AA0000
555500FFFFFFAA000055550055FF5555AA55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000055FFAAAAAAAAFFAA00AAAA00005500555555000055
AAAA00555500FFAAAA555500FF005500FF005555AAAAFF00555500AAAA55000055555500
550000AAAA00AAFFAAAAAAAAFF55000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF55FFFF0055AA0055AA550055AAAAFFAAFFAAFFFFAAAAFF
55555500005555AA00FFFFAAAA000000AAAAFFFF00AA55550000555555FFAAAAFFFFAAFF
AAFFAAAA550055AA5500AA5500FFFF55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFFAA000055AAFFAA55AA00AA555555AA5500AA
AAAAAAAAFFAAFF555500FF55555500555555FF005555FFAAFFAAAAAAAAAA0055AA555555
AA00AA55AAFFAA550000AAFFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5555FFFF55AAAA005500AA0055000055AAFFAA
0055AAAA555555AAFFFF550000550055000055FFFFAA555555AAAA5500AAFFAA55000055
00AA005500AAAA55FFFF5555AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000055FF00FFAA000000AAFFAAFFAAAAAA5555
550000FFAA55FFAA00AAAAAAFFAAFFAAFFAAAAAA00AAFF55AAFF0000555555AAAAAAFFAA
FFAA000000AAFF00FF55000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFF005555AA0000AA00FF5555AAAA550000
55005555AAAAAA005555FF5555AA00AA5555FF555500AAAAAA55550055000055AAAA5555
FF00AA0000AA555500FFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFFAA55005555FFFFFFAA55AAAAAAFF
AAFFAA55FF555555000055FFAA550055AAFF550000555555FF55AAFFAAFFAAAAAA55AAFF
FFFF55550055AAFFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5555FFAAAAAAAA00AAAA55FF555555
AA00AAFFFFFFAA55FFFF55AA55AAFFAA55AA55FFFF55AAFFFFFFAA00AA555555FF55AAAA
00AAAAAAAAFF5555AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000055FF5555555500AAFFFFFFAAFF
555500AAAA00AAFFFFFFFF000055AA550000FFFFFFFFAA00AAAA005555FFAAFFFFFFAA00
55555555FF55000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFF0055000000555555AA555555
AAFFFF55555500AAAA00AAAAFFAA55AAFFAAAA00AAAA00555555FFFFAA555555AA555555
0000005500FFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFFAAAAFFAAFF55AAAAAAAA
AA5555AAFFFFAAAA550055AAAA005500AAAA550055AAAAFFFFAA5555AAAAAAAAAA55FFAA
FFAAAAFFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5555FF5500AAAAAA55AAAA
55000055AA555555FFAAAAAA5500550055AAAAAAFF555555AA55000055AAAA55AAAAAA00
55FF5555AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000055FFAAAA55AAAAAA55
AAFFAAAAAA55FFAA55555555FFAAAAAAFF55555555AAFF55AAAAAAFFAA55AAAAAA55AAAA
FF55000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFF0055AAAAAA55AAAA
AA555555FF55AA55AAFFFFAA5555555555AAFFFFAA55AA55FF555555AAAAAA55AAAAAA55
00FFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFFAA0055AAFF00
AAFFFF00FF55AAAAAA5555AAAAAAAAAAAAAA5555AAAAAA55FF00FFFFAA00FFAA5500AAFF
FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5555FFFFAA00AA
00FF550055FFAA0055AAFF55555555555555FFAA5500AAFF550055FF00AA00AAFFFF5555
AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000055FF00AA00
5555AAFFAA5555FFFF00AAAAAAAAAAAAAAAAAA00FFFF5555AAFFAA555500AA00FF550000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFF005555FF
FF00FF0055AAFFFFFFFF555555555555555555FFFFFFFFAA5500FF00FFFF555500FFFF55
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFF00FF
550055FFFF00AAAA00AAAAAAAAAAAAAAAAAAAAAA00AAAA00FFFF550055FF00FFFF5500FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA555500
FFFF55AA555500AAFFAA0055AAAA55AAAA5500AAFFAA005555AA55FFFF005555AA55FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000055
55AA55FF55AAFFAA00AAFFAA55AAAAAA55AAFFAA00AAFFAA55FF55AA5555000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFF
00FF00FF55AAAA005555FF000000FF000000FF555500AAAA55FF00FF00FFFF55FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055
FFFFFF550000FFAAAAAAAA0000AA00AA0000AAAAAAAAFF000055FFFFFF5500FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
AA5555AAFFAAAA0055AA00555500AA00555500AA5500AAAAFFAA5555AA55FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FF5555FFFFAA000000555555000000AAFFFF5555FF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55FFFF55000055FF0000AA0000550000AA0000FF55000055FFFF55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0055FFAAAAFF55005555550055005555550055FFAAAAFF5500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55AA5500AAAAAAFFFFAAFFAAFFAAFFFFAAAAAA0055AA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00005555555555AA55AA55AA55AA55555555550000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55FFAAFFFFAA55AAFF00FFAA55AAFFFFAAFF55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0055AA5555FFAA00AA00AAFF5555AA5500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55AAAAAAAA0055555500AAAAAAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFAA0000550000AAFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55FF00AA000000AA00FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF005555550055555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AAFF55FFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.24832 0.782187 1.33563 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF555500AAFFFF0000AA55550000AA0000AAAA0000AA00FFFFAA55FFFFFF55AA00AAFF00
FFAA00FF00AAAAFF00AA00FFFFFF00FFFFFF00AA00FFAAAA00FF00AAFF00FFAA00AA55FF
FFFF55AAFFFF00AA0000AAAA0000AA00005555AA0000FFFFAA005555FF
FFFF00FF00AAAA0000AAFFFF0000FFAAAAFF00AA000000AAAA00FFFFFFFFFF00AA00FF55
FF00AA00AA55AAAA000000AAAA00AA00AAAA000000AAAA55AA00AA00FF55FF00AA00FFFF
FFFFFF00AAAA000000AA00FFAAAAFF0000FFFFAA0000AAAA00FF00FFFF
FFFFFF5500000000AA00FF5500AA5555FF55000000FF00000000AAAA00AAAA000000AAAA
AA000000FFAAFF00AA0000AAFF000000FFAA0000AA00FFAAFF000000AAAAAA000000AAAA
00AAAA00000000FF00000055FF5555AA0055FF00AA0000000055FFFFFF
FFFFFFFF0000FF000000AAAAAAFF00FFFFFF0000AA555500AA00000000FFAA0000AA00FF
AA0000AA5555FF000000AA55AA550055AA55AA000000FF5555AA0000AAFF00AA0000AAFF
00000000AA005555AA0000FFFFFF00FFAAAAAA000000FF0000FFFFFFFF
FFFFFFFFFF55FF0000AA00FFAA00AA5555AA5500AAFFFF000000FF0000AAAA55000000FF
55555555FFAA55550000FFAAFF00FF00FFAAFF00005555AAFF55555555FF00000055AAAA
0000FF000000FFFFAA0055AA5555AA00AAFF00AA0000FF55FFFFFFFFFF
FFFFFFFFFFFF0055000000FF555555FFAAFF00FF00AAAA0000AA555500AAFF00FF0000AA
AAAAAAAAAA00FFFF0000FF5555AA00AA5555FF0000FFFF00AAAAAAAAAAAA0000FF00FFAA
005555AA0000AAAA00FF00FFAAFF555555FF0000005500FFFFFFFFFFFF
FFFFFFFFFFFFFF55AA0000AAAAAAAAAA00FF55FF00000000AA00FFFFAAAA555555AA0000
000000000000AAAA005555AAFF555555FFAA555500AAAA0000000000000000AA555555AA
AAFFFF00AA00000000FF55FF00AAAAAAAAAA0000AA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00AA00000000000000AAAAAA0000FF000000AAAA00FFAAFFFF00AA00
00AA0000FF00000000FFFF00AAAAAAAAAA00FFFF00000000FF0000AA0000AA00FFFFAAFF
00AAAA000000FF0000AAAAAA00000000000000AA00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555500AA0000AA0000000000AA00AA5500000000AAAA5555AA00FF
000000FF0055005500AAAA00000000000000AAAA0055005500FF000000FF00AA5555AAAA
0000000055AA00AA0000000000AA0000AA005555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FF00AA000000AA000055AAAAFF00FF0000AA00FFAAFF555555
AA0000FF55FFAAAAAAFF00AA0000AA0000AA00FFAAAAAAFF55FF0000AA555555FFAAFF00
AA0000FF00FFAAAA550000AA000000AA00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55000000AA000000FF00FFAA00AA00AA000000FF5555AAFFFF
AA0000AAAAAA00FFAA00AA55AA000000AA55AA00AAFF00AAAAAA0000AAFFFFAA5555FF00
0000AA00AA00AAFF00FF000000AA00000055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF00AA005555AA00AAFFAA000000AA5500FFFF00AAAA
00FF0000000000FF555555FFAA005500AAFF555555FF0000000000FF00AAAA00FFFF0055
AA000000AAFFAA00AA555500AA00FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF55FF000000FFFF00AA00FF5555555555FFAAAA00AA00FF
AAAA0000FF0000AAAAAAAAAA00FF00FF00AAAAAAAAAA0000FF0000AAAAFF00AA00AAAAFF
5555555555FF00AA00FFFF000000FF55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00550000AAAA000000AAAAAAAAAAAAAA00FFAAAA5500
FFAA005500FF00000000000000FF55FF00000000000000FF005500AAFF0055AAAAFF00AA
AAAAAAAAAAAA000000AAAA00005500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00000000FF000000000000000000FF5555FFAA
AA00FF00FF0055AA0000FF0000AAAAAA0000FF0000AA5500FF00FF00AAAAFF5555FF0000
00000000000000FF00000000AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA0000AA555500AA005555550000AAAAAAAA00
FFAAAA0055FFFFAA005555AA0000000000AA555500AAFFFF5500AAAAFF00AAAAAAAA0000
55555500AA005555AA0000AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500AAFFFF000000FFFF00FF000000000000
FF5555FFFF0055FF55FFAAFF0000AA0000FFAAFF55FF5500FFFF5555FF000000000000FF
00FFFF000000FFFFAA005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00AAAA0000AA5555AA00AA0000AA0000
AAAAAAAA00AA55FF00FF5555AA000000AA5555FF00FF55AA00AAAAAAAA0000AA0000AA00
AA5555AA0000AAAA00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500000000AA00FFFFAA000000AA55AA00
0000000000FFAA555555AAFF5555555555FFAA555555AAFF000000000000AA55AA000000
AAFFFF00AA0000000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000AAAA00FF0000FFAAFF00
005555555500FFAAFFFF00AAAAAAAAAAAAAA00FFFFAAFF00555555550000FFAAFF0000FF
00AAAA000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF0000AA00FFAAAA005555AAAA00
00FFFFAAFF55FF00AAAA000000000000000000AAAA00FF55FFAAFFFF0000AAAA555500AA
AAFF00AA0000FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055000000FF5555FFFF00FFAA00
0055FF00AAAAAA000000005555550055555500000000AAAAAA00FF550000AAFF00FFFF55
55FF0000005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA0000AAAAAAAA00AA00AAFF
AAAAAA0000000000AA0000FFFF00FF00FFFF0000AA0000000000AAAAAAFFAA00AA00AAAA
AAAA0000AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA000000000000AAFFAA00
AAFF00AA005555000000AA5555AA00AA5555AA000000555500AA00FFAA00AAFFAA000000
000000AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500AA0000AA00FF5555
55FF000000FFFF0000AA00FFFF00AA00FFFF00AA0000FFFF000000FF555555FF00AA0000
AA005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00AA000000AAAAAA
AAAA0000AA5555AA000000FF5500000055FF000000AA5555AA0000AAAAAAAAAA000000AA
00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55000000AA00000000
000000AA00FFFF00AA0000AAAAAAFFAAAAAA0000AA00FFFF00AA00000000000000AA0000
0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00AA005555
00AA000000AAAA000000AA00FFAA00AAFF00AA000000AAAA000000AA00555500AA00FF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF000000FFFF
000000AA00000000AA000000FF555555FF000000AA00000000AA000000FFFF000000FF55
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00550000AAAA
005500AAFFAAAAFFAA005500AAAAAAAAAA005500AAFFAAAAFFAA005500AAAA00005500FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA000000
00FFFF5555AAAA5555FFFF00000000000000FFFF5555AAAA5555FFFF00000000AA55FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA0000
AA5555AAFF5555FFAA5555AA0000AA0000AA5555AAFF5555FFAA5555AA0000AA00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500
AAFFFF00AAAAAAAA00FFFF00AA000000AA00FFFF00AAAAAAAA00FFFFAA005555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00AAAA000000000000AAAA000000AA000000AAAA000000000000AAAA00FF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
00000000AA0000AA00000000FF000000FF00000000AA0000AA0000000055FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FF000000AA00FF0000FF0055555500FF0000FF00AA000000FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55FF0000AA00FF00550055FFFF00FFFF55005500FF00AA0000FF55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0055000000FF55FFAAAAAA00AA00AAAAAAFF55FF0000005500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55AA0000AAAAAA00FFAA000000AAFF00AAAAAA0000AA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00AA0000000000FF5555555555FF0000000000AA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF555500AA0000AAAAAAAAAAAAAA0000AA005555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF00AA000000000000000000AA00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55000000AA0000AA0000AA00000055FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FF00AA000000AA00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55FF000000FF000000FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF005500AA00AA005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AA00FF00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AA00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.24832 0.97619 1.33563 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF55FFFFAAAAAAAAAA5555AAAA0055AAFFAAAA5500AAAAFFAA55FF0055FF0055FFAA5555
55FF0055AAFFFF550000005555AA55AA555500000055FFFFAA5500FF555555AAFF5500FF
5500FF55AAFFAAAA0055AAAAFFAA5500AAAA5555AAAAAAAAAAFFFF55FF
FFFF00000055000055005555FF55FFAA00550000AAAA55AA00FFFFFF55AA00AA00550055
5500AAAAAA5500AA00AAAAFFFF00AA00FFFFAAAA00AA0055AAAAAA005555005500AA00AA
55FFFFFF00AA55AAAA00005500AAFF55FF55550055000055000000FFFF
FFFFFF55FFFFAAAAFF550055555500AAFFAAFFAAAA55AAFF0055AA005555FF00AAAAAAFF
55AA55AAAA55FF00AAAA55AA0055FF5500AA55AAAA00FF55AAAA55AA55FFAAAAAA00FF55
5500AA5500FFAA55AAAAFFAAFFAA005555550055FFAAAAFFFF55FFFFFF
FFFFFFFF0000005500AA00AA0000AAAA5500000055005500AAAAAA55550055AA55AAAA55
005500550000AA5555FF55AAAAFFFFFFAAAA55FF5555AA00005500550055AAAA55AA5500
5555AAAAAA0055005500000055AAAA0000AA00AA0055000000FFFFFFFF
FFFFFFFFFF55FFFFAAAA5555FF00550000AAAAFFAAFFAAFFAA00FFAAFF55005500550000
AAAAAAFF55FF00AA000000AAFF000000FFAA000000AA00FF55FFAAAAAA00005500550055
FFAAFF00AAFFAAFFAAFFAAAA00005500FF5555AAAAFFFF55FFFFFFFFFF
FFFFFFFFFFFF0000005500555555AAFFAAAA55AA00FF00AA55AA55000000AAAAAAFFFF55
00005500AA0055FF5500FF555555AA555555FF0055FF5500AA0055000055FFFFAAAAAA00
000055AA55AA00FF00AA55AAAAFFAA5555550055000000FFFFFFFFFFFF
FFFFFFFFFFFFFF55FFFFAAAAAAAAAA5500005555FFFFFF55550000AAAA00AAFF00AA5500
55FFFFAAAA555500AA00AA55FFAA55AAFF55AA00AA005555AAAAFFFF550055AA00FFAA00
AAAA00005555FFFFFF5555000055AAAAAAAAAAFFFF55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000550000550055FFFF00FF000000AA00AAAA55AA55AA00AAFFFF
55AA00550000AA00AAFFAA0000FFAAFF0000AAFFAA00AA00005500AA55FFFFAA00AA55AA
55AAAA00AA000000FF00FFFF550055000055000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55FFFFAAAAFF550055AA00AA5555AA55AA55AAAAAA55FF55000000
00AAFFAA5555AAAA00FF00AAAA005500AAAA00FF00AAAA5555AAFFAA0000000055FF55AA
AAAA55AA55AA5555AA00AA550055FFAAAAFFFF55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000005500AA00AA00FF5555005500550055000055555500FF55
FF00AA55AAFF5555FFFFFF5555FF00FF5555FFFFFF5555FFAA55AA00FF55FF0055555500
005500550055005555FF00AA00AA0055000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55FFFFAAAA5555FF0000AA00AA00AA00AA00AAAAAAAAAA0055
5555AAAAAA550055555555550055AA550055555555550055AAAAAA55555500AAAAAAAAAA
00AA00AA00AA00AA0000FF5555AAAAFFFF55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000005500555555AA55AA55AA55AA55AA55AAAA55AAAAFF
55AAFF00AAFFFF55AAFFFFAAFFAA55AAFFAAFFFFAA55FFFFAA00FFAA55FFAAAA55AAAA55
AA55AA55AA55AA55AA5555550055000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF55FFFFAAAAAAAAAA55FF55AAAAAA55FF55AAAA55FF5555
550000FF555555550000000055AAAAAA550000000055555555FF0000555555FF55AAAA55
FF55AAAAAA55FF55AAAAAAAAAAFFFF55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000550000550055AAFF00AAFFFFFFAA00FFFFFFAA
FF55FFFFFFAA55FFAAAA00AAAAAA55AAAAAA00AAAAFF55AAFFFFFF55FFAAFFFFFF00AAFF
FFFFAA00FFAA550055000055000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFFAAAAFF55005500AAAA5500AA55AA5500AA55
AA0000000000555555FF550000550055000055FF5555550000000000AA55AA0055AA55AA
0055AAAA00550055FFAAAAFFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000005500AA00AA00AAFF00FF55550000AAAA55
FF55FFFF55FFFFAAFFFFFFAAAAFF55FFAAAAFFFFFFAAFFFF55FFFF55FF55AAAA00005555
FF00FFAA00AA00AA0055000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFFAAAA5555FF00AA5555550055FF00AAFF
FFFF000000AA550000FF00005500AA00550000FF000055AA000000FFFFFFAA00FF550055
5555AA00FF5555AAAAFFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000005500555555AAAAAAAAAA0000FF5555
555555AA5555FFAAAA0055FFFF005500FFFF5500AAAAFF5555AA5555555555FF0000AAAA
AAAAAA5555550055000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFFAAAAAAAAAA55AAAA55AA55555500
5555005500555555FF550055AA00AA00AA550055FF555555005500555500555555AA55AA
AA55AAAAAAAAAAFFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000005500005500550000AAFFFFAAFF
AA55FFFF0055550055AAFFAAFF005500FFAAFFAA5500555500FFFF55AAFFAAFFFFAA0000
550055000055000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFFAAAAFF550055FF00AA550000
0055555555AAFF55FFAA005500AAAAAA005500AAFF55FFAA5555555500000055AA00FF55
0055FFAAAAFFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000005500AA00AA0055FF55AA55
55AAFFFFAA55AA00000055FFAAAA55AAAAFF55000000AA55AAFFFFAA5555AA55FF5500AA
00AA0055000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFFAAAA5555FF00FF00FFAA
FF55555555FFAA00AAAA000000550055000000AAAA00AAFF55555555FFAAFF00FF00FF55
55AAAAFFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000005500555555AA00AA55
AA0000AA0000FFAAAA55AA5555AAFFAA5555AA55AAAAFF0000AA0000AA55AA00AA555555
0055000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFFAAAAAAAAAA5555FF
AA00AAAA5555AA00FFAA55AAFF555555FFAA55AAFF00AA5555AAAA00AAFF5555AAAAAAAA
AAFFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000055000055005555
55FF00AAFFFFAA00AA55AAFF0000AA0000FFAA55AA00AAFFFFAA00FF5555550055000055
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFFAAAAFF55FFAA
FFFFFF55555555FF00AA00FF0055FF5500FF00AA00FF55555555FFFFFFAAFF55FFAAAAFF
FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000005500AA0055
00AA550055550055AA55AA5500FFFFFF0055AA55AA550055550055AA005500AA00550000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFFAAAA5555
00FFAAFFAAFFFF55AAAAAA55FF000000FF55AAAAAA55FFFFAAFFAAFF005555AAAAFFFF55
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000550055
55AA00FF00AA5500550000555555AA5555550000550055AA00FF00AA55550055000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFFAAAA
AAAA555555AAAAAAFFFF55FFAA55FF55AAFF55FFFFAAAAAA555555AAAAAAAAFFFF55FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000055
000055550055000055AA000000555555000000AA55000055005555000055000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFF
AAAAFF55AA55FFFF55AAAA00AAAAAAAAAA00AAAA55FFFF55AA55FFAAAAFFFF55FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
005500AA00FFFFFFFFAA00FF5555FF5555FF00AAFFFFFFFF00AA0055000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
FFFFAAAA555555555555FFFFFF00FF00FFFFFF555555555555AAAAFFFF55FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000005500555500555500AA5500FF0055AA0055550055550055000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55FFFFAAAAAAAA0000AAAA55FFFFFF55AAAA0000AAAAAAAAFFFF55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000055000055FF00AAFFFFFFFFFFAA00FF55000055000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55FFFFAAAAFFFFFF55555555555555FFFFFFAAAAFFFF55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000005500AA550055550055550055AA0055000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55FFFFAAAA55FFFFAAFFAAFFFF55AAAAFFFF55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000550055AA00FF00AA550055000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55FFFFAAAAAA555555AAAAAAFFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000550000AA000055000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5500FFFF55FF55FFFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055AA000000AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AAAA00AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AAFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34436 0.200176 1.43167 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF550000AAAA00FFFFFF005500FFAAAAAAAAFFFF00FFFFAAAAFF5555AAAAFF55AAAAAAFF
FFFFAAAAAAAA5500FFFFAAAA00AAAAAA00AAAAFFFF0055AAAAAAAAFFFFFFAAAAAA55FFAA
AA5555FFAAAAFFFF00FFFFAAAAAAAAFF005500FFFFFF00AAAA000055FF
FFFFAAAAFF00AA00AAAA000000AAAAAAAAAAAA00AA00AAAA55FF0000FFFF0055AAAAAAAA
00AAAA55FF55555500FF55AAAAFF00FFAAAA55FF00555555FF55AAAA00AAAAAAAA5500FF
FF0000FF55AAAA00AA00AAAAAAAAAAAA000000AAAA00AA00FFAAAAFFFF
FFFFFF00FF55FFAAAAAAAAFFAAAA55AAAAAAAAAAFF55FF55AA00AA0000550055AAAA55AA
AAFF00AA55555555550000FFAA00AA00AAFF00005555555555AA00FFAAAA55AAAA550055
0000AA00AA55FF55FFAAAAAAAAAA55AAAAFFAAAAAAAAFF55FF00FFFFFF
FFFFFFFF5500AAAAAAAAAA5555FFAAFF00FFAA55AA550000FFAAAAAAFFAAFFAAFF00FF00
FFFFFF55AA0055AA00555500FFAAAAAAFF00555500AA5500AA55FFFFFF00FF00FFAAFFAA
FFAAAAAAFF000055AA55AAFF00FFAAFF5555AAAAAAAAAA0055FFFFFFFF
FFFFFFFFFFAAAAAAAAAAAA5500AAAA555500FFFFAA55005555AAAA55FF00AAAAAA000055
55AA555555FFFFAA00000000AAAAAAAAAA00000000AAFFFF555555AA55550000AAAAAA00
FF55AAAA55550055AAFFFF005555AAAA0055AAAAAAAAAAAAFFFFFFFFFF
FFFFFFFFFFFF00FFFF00FFFFAAAA55AA005555AA55AA0000FF00AAFFFFFF55AAAAAAFFAA
FFFF0000FF0055FFAAAAFFAAAAAAAAAAAAAAFFAAAAFF5500FF0000FFFFAAFFAAAAAA55FF
FFFFAA00FF0000AA55AA555500AA55AAAAFFFF00FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF550000AAAA00FFFFAA000000FFFFAA0000AAAAFF00550000FFAA55FF00
AAAA0000AAAAFFFFFF00FF55AAAAAAAAAA55FF00FFFFFFAAAA0000AAAA00FF55AAFF0000
5500FFAAAA0000AAFFFF000000AAFFFF00AAAA000055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAFF00AA00AAAAAAFFAAAA00AAFFAAAAAAAA000000AA00AAFFFFFF
55AAFFAAAA55FF0055FFFFFFAA55FF55AAFFFFFF5500FF55AAAAFFAA55FFFFFFAA00AA00
0000AAAAAAAAFFAA00AAAAFFAAAAAA00AA00FFAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF55FFAAAAAAAAAA00FFFF5555AAAAAAAAAAFFAAAAAAFF005500
00FFFFFF00AA555500AAAA00AAFFFFFFAA00AAAA005555AA00FFFFFF00005500FFAAAAAA
FFAAAAAAAAAA5555FFFF00AAAAAAAAAAFF55FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5500AAAAAAAAAA55FFFFFFFFAAFF00FFAA00FF55AAAA555500AA
0000550000AAFFFFAAAAAAAAFF005500FFAAAAAAAAFFFFAA0000550000AA005555AAAA55
FF00AAFF00FFAAFFFFFFFF55AAAAAAAAAA0055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAA55000055FF00FF55FF00AA00AA55AAFFFFAAAA
AAFFAAFFAAAAAA00AAFF55AAAA000000AAAA55FFAA00AAAAAAFFAAFFAAAAAAFFFFAA55AA
00AA00FF55FF00FF55000055AAAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFAAAAFFFFFF5500AAAAFF55FFAAFF5500FFAA
55FF00AAAAAAAAAAFF0055AAAAAAFFAAAAAA5500FFAAAAAAAAAA00FF55AAFF0055FFAAFF
55FFAAAA0055FFFFFFAAAAFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF550000AAAA00FFFFFFFFFFAAAAAAAA0055FF5500AA00AA
FFFFFF55AAAAAAAAAA0000FFAA55AA55AAFF0000AAAAAAAAAA55FFFFFFAA00AA0055FF55
00AAAAAAAAFFFFFFFFFF00AAAA000055FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00AA00AAAA00AAAAAAAAAAAAFFFFFFAAAAAAFF
005500FF00AAFF00FFFF55FF00AA55AA00FF55FFFF00FFAA00FF005500FFAAAAAAFFFFFF
AAAAAAAAAAAA00AAAA00AA00FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FFAAAAAAAAFF55AAAAAAAAAA00AAAAAAAAAA
000000AAAAFF5500550000FF55FFAAFF55FF0000550055FFAAAA000000AAAAAAAAAA00AA
AAAAAAAA55FFAAAAAAAAFF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAAAAAAAAA555555FFAA00FFAAAA55AAAAAA
AAFFAAAAAAAA00555555005500AAAAAA00550055555500AAAAAAAAFFAAAAAAAA55AAAAFF
00AAFF555555AAAAAAAAAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAA5500AA5555FFFFFF00FF00FFFF
00AAAA55AAAAAAFFFFAAFFAAFFAA55AAFFAAFFAAFFFFAAAAAA55AAAA00FFFF00FF00FFFF
FF5555AA0055AAAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFAAAA5500AAAA00AA00AA00AA
AAFF00FF00FFAA00AAAA5555FF00FF00FF5555AAAA00AAFF00FF00FFAAAA00AA00AA00AA
AA0055AAAAFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000AAAA00FFFFAAAAAAAAFF55FFAAAA
AA55550000AAAAAAFF55AA0055FFFFFF5500AA55FFAAAAAA00005555AAAAAAFF55FFAAAA
AAAAFFFF00AAAA000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00AA00AAAAAAAAAAAA0055FF55
AAFFFFAAAAFF00FFFFFFAA00000055000000AAFFFFFF00FFAAAAFFFFAA55FF5500AAAAAA
AAAAAA00AA00FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FFAAAAAAAAAAAAAAAAFFFFFF
AA00AAAAAA5555000055FFAAAAFFAAFFAAAAFF5500005555AAAAAA00AAFFFFFFAAAAAAAA
AAAAAAAAFF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAAAAAAAAAAAAAAAAAAA00AA
AAAAFF55AAFFFFAAAAFFFFFF00AAAAAA00FFFFFFAAAAFFFFAA55FFAAAAAA00AAAAAAAAAA
AAAAAAAAAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAA55AAAAAAAAAAFF
00FFFFFFAA00AAAAAAAA00AAAAFF00FFAAAA00AAAAAAAA00AAFFFFFF00FFAAAAAAAAAA55
AAAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFAA55AAAAAA55
55000055FFAAAA55AAAAAAFF00FF55FF00FFAAAAAA55AAAAFF5500005555AAAAAA55AAFF
FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000AAAA00FF00FFFF00
0000AA0055FF555555FFAA55550000005555AAFF555555FF5500AA000000FFFF00FF00AA
AA000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00AA00AA00AAAA
FFAAAAAAFFFFFFAAFFFFFF000000AA000000FFFFFFAAFFFFFFAAAAAAFFAAAA00AA00AA00
FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FFAAAAAAFF55
55AAAAAAAA00AAAAAA00AAAAFFAAAAAAFFAAAA00AAAAAA00AAAAAAAA5555FFAAAAAAFF55
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAAAAAAAAA00
55AAFF00FFAAAA55FF55FF55AA55FF55AA55FF55FF55AAAAFF00FFAA5500AAAAAAAAAA00
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAAAA
FFFF005555AAAA5500000055AAFFFFFFAA5500000055AAAA555500FFFFAAAAAAAAAAAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF
00550055AA00FFFFAAAAFFAAFF005500FFAAFFAAAAFFFF00AA55005500FFFF00FFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000AAAA
000000AA55FFFFFFFF00AAAAAA000000AAAAAA00FFFFFFFF55AA000000AAAA000055FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00
AA0000AAFFFFFFFFFFFF55AAAAAAFFAAAAAA55FFFFFFFFFFFFAA0000AA00FFAAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55
FFAAAAFF55000055FF0055AAAA55AA55AAAA5500FF55000055FFAAAAFF55FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500
AAAAAAAA00555500AAAAFFFF00FF00FF00FFFFAAAA00555500AAAAAAAA0055FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAAAAAAAAAFFFFAAAAAAAA00AA00AA00AA00AAAAAAAAFFFFAAAAAAAAAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFF00FFFFFFFF00AAFF55FFAAAAAAFF55FFAA00FFFFFFFF00FFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF550000AAAA00AAAAFF5500AAAAAAAAAA0055FFAAAA00AAAA000055FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAFF00AA00FFFFFFAAAAAAAAAAAAAAFFFFFF00AA00FFAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF55FFAAAA00AAAAAAAAAAAAAAAAAA00AAAAFF55FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF5500AAAAAAAAFF00FFAA55AAFF00FFAAAAAAAA0055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAAAAAA555500FFAAFF005555AAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF00FF0000AAAAAA0000FF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF550000AAAAFFAA55AAFFAAAA000055FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAFF00FF555555FF00FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF55FF000000FF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5500AAAAFFAAAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA55AA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.34436 0.39418 1.43167 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF555555AAFFFFAA5555AAFFFFAA5555AAFFFFAA5555AAFFFF55FFFFFFAA00AAFFFFFFFF
AA55FFFFAA0055FFFF5555AAFF55FF55FFAA5555FFFF5500AAFFFF55AAFFFFFFFFAA00AA
FFFFFF55FFFFAA5555AAFFFFAA5555AAFFFFAA5555AAFFFFAA555555FF
FFFFAAFFFF0055AAFFFFAA5555AAFFFFAA5555AAFFFFAA5555AAAA00AAAAAAFF550000AA
55FF5500FFFF55555555FF55AA00FF00AA55FF55555555FFFF0055FF55AA000055FFAAAA
AA00AAAA5555AAFFFFAA5555AAFFFFAA5555AAFFFFAA5500FFFFAAFFFF
FFFFFF0055FFFFAA5555AAFFFFAA5555AAFFFFAA5555AAFFFFAA55FFFF00FFFFFFAAAAFF
555555FFFFFFFFAAFF00AAAA55FFFFFF55AAAA00FFAAFFFFFFFF555555FFAAAAFFFFFF00
FFFF55AAFFFFAA5555AAFFFFAA5555AAFFFFAA5555AAFFFF5500FFFFFF
FFFFFFFF555555AAFFFFAA5555AAFFFFAA5555AAFFFFAA5555AAFFFFFFFF5500FF00FFFF
FFAA00FF000000FFFFFF55AAFFFFFFFFFFAA55FFFFFF000000FF00AAFFFFFF00FF0055FF
FFFFFFAA5555AAFFFFAA5555AAFFFFAA5555AAFFFFAA555555FFFFFFFF
FFFFFFFFFFAAFFFF0055AAFFFFAA5555AAFFFFAA5555AAFFFFAA5500005555FFFFFF5500
AA55FFFFFF55FFFFFFFFFFAA5500550055AAFFFFFFFFFF55FFFFFF55AA0055FFFFFF5555
000055AAFFFFAA5555AAFFFFAA5555AAFFFFAA5500FFFFAAFFFFFFFFFF
FFFFFFFFFFFF0055FFFFAA5555AAFFFFAA5555AAFFFFAA5555AAFFFF55FF55555555AAAA
FF555500FF555555AA00AA55FF55FF55FF55AA00AA555555FF005555FFAAAA55555555FF
55FFFFAA5555AAFFFFAA5555AAFFFFAA5555AAFFFF5500FFFFFFFFFFFF
FFFFFFFFFFFFFF555555AAFFFFAA5555AAFFFFAA5555AAFFFFAA5555AAAA00FFAAFFFF00
FF5555FFFFFFAA00FFFF55AAAA00FF00AAAA55FFFF00AAFFFFFF5555FF00FFFFAAFF00AA
AA5555AAFFFFAA5555AAFFFFAA5555AAFFFFAA555555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF0055AAFFFFAA5555AAFFFFAA5555AAFFFFAA55FFFFFF0055FF
FFFFAA0000AA55FFFFFFFFAA55FFFFFF55AAFFFFFFFF55AA0000AAFFFFFF5500FFFFFF55
AAFFFFAA5555AAFFFFAA5555AAFFFFAA5500FFFFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0055FFFFAA5555AAFFFFAA5555AAFFFFAA5555AAFFFFFFFFFF5555
0055FFAAAAFF5555005555AAFFFFFFFFFFAA5555005555FFAAAAFF55005555FFFFFFFFFF
AA5555AAFFFFAA5555AAFFFFAA5555AAFFFF5500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF555555AAFFFFAA5555AAFFFFAA5555AAFFFFAA55000055AA55AA
AAFFFFFF00FF00AAFFAA00FFFFFFFFFFFFFF00AAFFAA00FF00FFFFFFAAAA55AA55000055
AAFFFFAA5555AAFFFFAA5555AAFFFFAA555555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFFF0055AAFFFFAA5555AAFFFFAA5555AAFFFF55FF55AAAA
AAAA0055FFFFFF55AA55FFFFFFFFFFFFFFFFFF55AA55FFFFFF5500AAAAAAAA55FF55FFFF
AA5555AAFFFFAA5555AAFFFFAA5500FFFFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055FFFFAA5555AAFFFFAA5555AAFFFFAA5555AAAA00FFFF
00FFFF55550055FF55AAAA00550000005500AAAA55FF55005555FFFF00FFFF00AAAA5555
AAFFFFAA5555AAFFFFAA5555AAFFFF5500FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555AAFFFFAA5555AAFFFFAA5555AAFFFFAA55FFFFFF
FF5500AAFFFF5555AAAAAAAAFFFF55FFFFAAAAAAAA5555FFFFAA0055FFFFFFFF55AAFFFF
AA5555AAFFFFAA5555AAFFFFAA555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF0055AAFFFFAA5555AAFFFFAA5555AAFFFFFFFF
FFFFAAAAAA00AAFFFF00FFFF0055FF5500FFFF00FFFFAA00AAAAAAFFFFFFFFFFFFAA5555
AAFFFFAA5555AAFFFFAA5500FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFFAA5555AAFFFFAA5555AAFFFFAA55000000
0055FFAA55FFFF0055FFFFFFFF555555FFFFFFFF5500FFFF55AAFF550000000055AAFFFF
AA5555AAFFFFAA5555AAFFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555AAFFFFAA5555AAFFFFAA5555AAFFFF55FF
FF5555AAFFFFFFFF555555555555FF555555555555FFFFFFFFAA5555FFFF55FFFFAA5555
AAFFFFAA5555AAFFFFAA555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF0055AAFFFFAA5555AAFFFFAA5555AAAA
00AAFFFF00000000FFAAFFFFAAFFFFFFAAFFFFAAFF00000000FFFFAA00AAAA5555AAFFFF
AA5555AAFFFFAA5500FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFFAA5555AAFFFFAA5555AAFFFFAA55
FFFF0055FFFF55FFFFFF0000FFFFFFFFFF0000FFFFFF55FFFF5500FFFF55AAFFFFAA5555
AAFFFFAA5555AAFFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555AAFFFFAA5555AAFFFFAA5555AAFF
FFFFFF5555AA00FF0055FFFF5500000055FFFF5500FF00AA5555FFFFFFFFAA5555AAFFFF
AA5555AAFFFFAA555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF0055AAFFFFAA5555AAFFFFAA55
000055AAAA55FFFFFF555555AAAAFFAAAA555555FFFFFF55AAAA55000055AAFFFFAA5555
AAFFFFAA5500FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFFAA5555AAFFFFAA5555AAFF
FF55FF55AAFFFFFFFFFFAAFFFF00FF00FFFFAAFFFFFFFFFFAA55FF55FFFFAA5555AAFFFF
AA5555AAFFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555AAFFFFAA5555AAFFFFAA55
55AAAA00FFFFFFFFFFFFFF0055FFFFFF5500FFFFFFFFFFFFFF00AAAA5555AAFFFFAA5555
AAFFFFAA555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF0055AAFFFFAA5555AAFF
FFAA55FFFFFFFFFFFFFFFFFF5555005555FFFFFFFFFFFFFFFFFF55AAFFFFAA5555AAFFFF
AA5500FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFFAA5555AAFFFFAA55
55AAFFFFFFFFFFFFFFFFFFFFFFAAFFAAFFFFFFFFFFFFFFFFFFFFFFAA5555AAFFFFAA5555
AAFFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555AAFFFFAA5555AAFF
FFAA55555500000055FF000000FFFFFF000000FF55000000555555AAFFFFAA5555AAFFFF
AA555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF0055AAFFFFAA55
55AAFFFFAAFFAAAAFFFFFF55FFFFFFFFFF55FFFFFFAAAAFFAAFFFFAA5555AAFFFFAA5500
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFFAA5555AAFF
FFAA5500FFFFFF00FF0055FF5500FF0055FF5500FF00FFFFFF0055AAFFFFAA5555AAFFFF
5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555AAFFFFAA55
55AAFFFF550055FFFFFF555555FFFFFF555555FFFFFF550055FFFFAA5555AAFFFFAA5555
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF0055AAFF
FFAA5555AAAAFFFFFFFFFFAAFFFFFFFFFFAAFFFFFFFFFFAAAA5555AAFFFFAA5500FFFFAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFFAA55
55AAFFFFAA55FF00555500FFFFFFFFFFFFFF00555500FF55AAFFFFAA5555AAFFFF5500FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555AAFF
FFAA5555AAFFFFFF5555FFFFFFFFFFFFFFFFFF5555FFFFFFAA5555AAFFFFAA555555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00
55AAFFFFAA55555555FF5500AA000000AA0055FF55555555AAFFFFAA5500FFFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF
FFAA5555AAFFFFAAFFFFFFAAAAAAFFAAAAAAFFFFFFAAFFFFAA5555AAFFFF5500FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555
55AAFFFFAA5500FFFFFFFFFF00FFFFFF00FFFFFFFFFF0055AAFFFFAA555555FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
FFFF0055AAFFFF5500000055FFFFFFFFFF5500000055FFFFAA5500FFFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0055FFFFAA5555AAAAFFAAAA5555005555AAAAFFAAAA5555AAFFFF5500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF555555AAFFFFAA55FF00FFFFAAFFAAFFFF00FF55AAFFFFAA555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFF0055AAFFFFFF5500FFFFFF0055FFFFFFAA5500FFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0055FFFFAA55005555FFFFFFFFFF55550055AAFFFF5500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF555555AAFFFF5555FF000000FF5555FFFFAA555555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFFFF0000AAFFFFFF55FFFFFFAA0000FFFFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0055FFFF55AA0055FF5500AA55FFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF555555AAAAAAFFFFFFAAAAAA555555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF00FFFFFFFFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0055FFFFFFFFFFFFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF555555000000555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFFF55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.34436 0.588183 1.43167 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF55550000AAAA5555FFAA00FF0000AAAAAAFFAAAA555500AAFFFFAA5500FF00FF5555AA
FFAAAA0055AAFFAA00AAFFFF5500550055FFFFAA00AAFFAA5500AAAAFFAA5555FF00FF00
55AAFFFFAA005555AAAAFFAAAAAA0000FF00AAFF5555AAAA00005555FF
FFFFAAFFAAAAAAAA55AA55FFFFFF55FFAA5500FF0000550055AA555555FFFFFF55000000
FF55AAFFAA0055FFAAAAAA00AAFFAAFFAA00AAAAAAFF5500AAFFAA55FF00000055FFFFFF
555555AA5500550000FF0055AAFF55FFFFFF55AA55AAAAAAAAFFAAFFFF
FFFFFF0055AA0055AAAAAA5555AA55AA550000AAAAFFAAFFAAFF5555FF5500FF55550055
55AAAAAA005555FF00FF0000AA555555AA0000FF00FF555500AAAAAA5555005555FF0055
FF5555FFAAFFAAFFAAAA000055AA55AA5555AAAAAA5500AA5500FFFFFF
FFFFFFFF5555550000FFFF00AAFF555555FFFF55AA00AA555555AAAA5555FFFFFFAA0000
5500AA55FFFFAA00AA00AA0000FFAAFF0000AA00AA00AAFFFF55AA00550000AAFFFFFF55
55AAAA555555AA00AA55FFFF555555FFAA00FFFF0000555555FFFFFFFF
FFFFFFFFFFAAFFFF55FF00555555AAAA55AA5555FFAAAAAA55AAAAAAAA55AA5555AA0000
AAFFAA55AA55555500AA00555500FF00555500AA00555555AA55AAFFAA0000AA5555AA55
AAAAAAAA55AAAAAAFF5555AA55AAAA55555500FF55FFFFAAFFFFFFFFFF
FFFFFFFFFFFF0055FF550055000000FF00AA55AAAA0055AAFF0000FFFF00AA55AAAAAAFF
AA555555FFAAFFFFAAAAAAFF00AA00AA00FFAAAAAAFFFFAAFF555555AAFFAAAAAA55AA00
FFFF0000FFAA5500AAAA55AA00FF000000550055FF5500FFFFFFFFFFFF
FFFFFFFFFFFFFF5555AAAAFFFF55FFFFFF55AAAAAAAAFFFF00555500FF55FFAAFF55AA00
AA55AAAA555555AA55FFAA555500AA005555AAFF55AA555555AAAA55AA00AA55FFAAFF55
FF00555500FFFFAAAAAAAA55FFFFFF55FFFFAAAA5555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF55AA5555FF0055FF55AAFF55AA5555000000AAAA555555AAAAAA
FF55555555FF555555FF000000555555000000FF555555FF55555555FFAAAAAA555555AA
AA0000005555AA55FFAA55FF5500FF5555AA55FFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF005500AAFFFFFF5555AAAAAA00FFFFAA0000AA0055AAAA55AA0055
AA55AAAA55AA55AAAA5555005555FF5555005555AAAA55AA55AAAA55AA5500AA55AAAA55
00AA0000AAFFFF00AAAAAA5555FFFFFFAA005500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF555500AAAA00AAFF0000FFFF5500FFFF55FFAAAA5500AAFF55FF
55AAAAAAAA550000FFFFAAFFAAFFFFFFAAFFAAFFFF000055AAAAAAAA55FF55FFAA0055AA
AAFF55FFFF0055FFFF0000FFAA00AAAA005555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFAA55FFFF00555500FF555500FF5555AAFF555500AAAA55
55FFAA5500AAFFAAAA00AA555555AA555555AA00AAAAFFAA0055AAFF5555AAAA005555FF
AA5555FF005555FF00555500FFFF55AAFFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055AAAA00AA00FFAAAA00FFAAAA00FFAA5555FF55FFAA55
AAAA00550055AA55FFAAAAAA55AAAAAA55AAAAAAFF55AA55005500AAAA55AAFF55FF5555
AAFF00AAAAFF00AAAAFF00AA00AAAA5500FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF5555555500AA00AA55FFFFFF0000AAAAAA55AA55AA55FF
55AA000000AAFF5555AA0055AAAAAAAAAA5500AA5555FFAA000000AA55FF55AA55AA55AA
AAAA0000FFFFFF55AA00AA0055555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAAAAAAFF5555AA55550055AAFF555555FFAA00
AAFF55FFFF55AA55AAAAAAFFFF00FF00FFFFAAAAAA55AA55FFFF55FFAA00AAFF555555FF
AA55005555AA5555FFAAAAAAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFAA55FF00AAFF5555FFFFAA5555FF5555AA00
00FF5555AA55AAFF00FFFF0055FFFFFF5500FFFF00FFAA55AA5555FF0000AA5555FF5555
AAFFFF5555FFAA00FF55AAFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAFF00555555AAAA5555AAFF00AAAA55AAFF
AAAA00FFAA55AA00AA00AAAAFFFFFFFFFFAAAA00AA00AA55AAFF00AAAAFFAA55AAAA00FF
AA5555AAAA55555500FFAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF550055000055AA00FFAA555500AA55AA00
AA550055FFAA0055555500AA5555AA5555AA0055555500AAFF550055AA00AA55AA005555
AAFF00AA550000550055FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00550055005555FFAAAA00550000AA55AA00
00FFAAAA55555500000000AA55AAAAAA55AA00000000555555AAAAFF0000AA55AA000055
00AAAAFF55550055005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55550000AAFF0055AAFFAA0000AA55AA00
00AAAAAAAA55AAAAFFAAAAFF5555555555FFAAAAFFAAAA55AAAAAAAA0000AA55AA0000AA
FFAA5500FFAA00005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAAAAA000055AA5500555555FFAA
AAFF55AA005500AA55555555AAAA55AAAA55555555AA005500AA55FFAAAAFF5555550055
AA550000AAAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AA0055550000FFAAAA55AAAA00
55AA55AA000000AA55AAAA55AA005500AA55AAAA55AA000000AA55AA5500AAAA55AAAAFF
0000555500AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555550000555500FFFF00AA5500
5500AAFF55FFFF55AAAAAAAA5500550055AAAAAAAA55FFFF55FFAA00550055AA00FFFF00
55550000555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55FF555500FF55FFAA00
00555555AAAA00AAFF55AA00550055005500AA55FFAA00AAAA5555550000AAFF55FF0055
55FF55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF55000000AAAA555555
0055000000FFFF55AA55AAFFAAFFAAFFAAFFAA55AA55FFFF0000005500555555AAAA0000
0055FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAAAFFAAAAAAAA55AA
AAFFFF55FFFFFFFFAA55AA00AA555555AA00AA55AAFFFFFFFF55FFFFAAAA55AAAAAAAAFF
AAAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55AA5500AA55FF55
AA00AAAA5555AA555555FFAAAAAA55AAAAAAFF555555AA5555AAAA00AA55FF55AA0055AA
55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005500AAFFAA55AA55
AAFFAA55000055AAAA55AA55FFAA55AAFF55AA55AAAA55000055AAFFAA55AA55AAFFAA00
5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500AAAAAA55FF
55AA55FF55FFFFAA55FF55AAAA005500AAAA55FF55AAFFFF55FF55AA55FF55AAAAAA0055
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA55FFAA00
AAFF5555AAAA00AA55AA55AAFF55FF55FFAA55AA55AA00AAAA5555FFAA00AAFF55AAFFAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AAAA0055
5555AAAA55FFAAAAAA55FF55AA55AA55AA55FF55AAAAAAFF55AAAA55555500AAAA5500FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555555500
005500AA55AA55FFAA55AA55AAFF00FFAA55AA55AAFF55AA55AA0055000055555555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAA
AAFFFF55AAAAAA555555FFAAFF550055FFAAFF555555AAAAAA55FFFFAAAAFFFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF
AA5555AAAAAAAAAA55AAAA0055FF55FF5500AAAA55AAAAAAAAAA5555AAFF5500FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555
AAFF00AA5500AA55FF55AA000055FF550000AA55FF55AA0055AA00FFAA5555FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
FF550055AAAAFF5555AAAAAAFFAA00AAFFAAAAAA5555FFAAAA550055FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0055005500AA5555FF55AAFF5500AA0055FFAA55FF5555AA0055005500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55550000AA55AAAA00FFFFFFAAAAAAFFFFFF00AAAA55AA00005555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFAAAAAA55FFAAAA00AAAAAAAAAA00AAAAFF55AAAAAAFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0055AAFF5555AA005555555555555500AA5555FFAA5500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF555555AAAA5500550000000000550055AAAA555555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFFFF00005555FFFF55FFFF55550000FFFFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0055FFFF5555FF005500FF5555FFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5555AA55AAAA000000AAAA55AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF555555550055555555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0055000055005500005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF555500550055005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFAAFFAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.34436 0.782187 1.43167 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF55AAAA55AA55AA55FFFFFFFFFFAAAAAAAAFF55AAFFAAAA55AAAA55AAAA55000055AAAA
AA0000AAFF0055AAAAAAAA5555AAAAAA5555AAAAAAAA5500FFAA0000AAAAAA55000055AA
AA55AAAA55AAAAFFAA55FFAAAAAAAAFFFFFFFFFF55AA55AA55AAAA55FF
FFFFAA55FF55AAAA00FF00005500AAAAAA00AA55AA5500FFFFAA55FF55AAFFFF55FF55AA
55FFFF55000000AAAAAAAA0000AAAAAA0000AAAAAAAA00000055FFFF55AA55FF55FFFFAA
55FF55AAFFFF0055AA55AA00AAAAAA00550000FF00AAAA55FF55AAFFFF
FFFFFF00AA55AA55FFFFFF55FF55FF00FFFF55AAAA00000055AAFFFFFFAA550000AA55AA
FFFFFFFFAAAAFFAA5555AAFFAAAA00AAAAFFAA5555AAFFAAAAFFFFFFFFAA55AA000055AA
FFFFFFAA55000000AAAA55FFFF00FF55FF55FFFFFF55AA55AA00FFFFFF
FFFFFFFF55AAAAAA55000055555500000055AAAAAAAAFFAAAA5555555555AAAAFFAA55AA
55000055AA555555AAAA555555AAFFAA555555AAAA555555AA55000055AA55AAFFAAAA55
55555555AAAAFFAAAAAAAA55000000555555000055AAAAAA55FFFFFFFF
FFFFFFFFFFAA55FFAAFFAAAA55AAAAFFAAAA5555AA555555AA55AAAA55AAAAAA0055FF55
AAAAFFAAFF5555FF55AA55AAAA555555AAAA55AA55FF5555FFAAFFAAAA55FF5500AAAAAA
55AAAA55AA555555AA5555AAAAFFAAAA55AAAAFFAAFF55AAFFFFFFFFFF
FFFFFFFFFFFF00AA555555AA55AA555555AA55AAAAAA55AAAAAA5555AAAAAAAAAAFFFFFF
AA555555AA0000AA55AA55AA5555FF5555AA55AA55AA0000AA555555AAFFFFFFAAAAAAAA
AA5555AAAAAA55AAAAAA55AA555555AA55AA555555AA00FFFFFFFFFFFF
FFFFFFFFFFFFFF55AAAA55AA55AA55AAAA55FF55AA55FF5500FF555500FF55AA55555555
55AAAA55AAFFAAAAAA55FF55005555550055FF55AAAAAAFFAA55AAAA5555555555AA55FF
005555FF0055FF55AA55FF55AAAA55AA55AA55AAAA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55FF55AAAA00FFFF00AA55AA55AA0000005555FFFFFFAA55AAAA55
AAAAAAAA555555AAFF555555FFFFAAFFFF555555FFAA555555AAAAAAAA55AAAA55AAFFFF
FF5555000000AA55AA55AA00FFFF00AAAA55FF55AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00AA55AA55FFFFFFFF55AAAAAA55FFFF55FF5555555555AAAAAAAA
5555AA5555005555AA0000AA0055AA5500AA0000AA5555005555AA5555AAAAAAAA555555
5555FF55FFFF55AAAAAA55FFFFFFFF55AA55AA00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55AAAAAA55000055AAAAAAAAAA550000AA55AAAA55AAAAAAAAAA
AA55AAFFFFAAAA55AAFFAAAAAAFF00FFAAAAAAFFAA55AAAAFFFFAA55AAAAAAAAAAAA55AA
AA55AA000055AAAAAAAAAA55000055AAAAAA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55FFAAFFAAAA5555AA55FFAAFFAAAAAA5555AAAAAAAAAAAA
AAAA55555555AA55AA5500FFFF000000FFFF0055AA55AA55555555AAAAAAAAAAAAAAAA55
55AAAAAAFFAAFF55AA5555AAAAFFAAFF55AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AA555555AA55AAAA00FF0055AA5555AAAA5555AA5555AA
5555AAAA55AAAAAA5555FFFFFFFF55FFFFFFFF5555AAAAAA55AAAA5555AA5555AA5555AA
AA5555AA5500FF00AAAA55AA555555AA00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA55AA55AA55FFFFFF5555AAAA5555AAAA55FF5555
AAAA5555AAAAAAAAAA55AA005500AA005500AA55AAAAAAAAAA5555AAAA5555FF55AAAA55
55AAAA5555FFFFFF55AA55AA55AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAAA00FF00005555FFAA55AAAA00AA005555
FFAA55AAAAAAAAAAAAAA55FFFFAAAAAAFFFF55AAAAAAAAAAAAAA55AAFF555500AA00AAAA
55AAFF55550000FF00AAAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AA55FFFFFF55FF555555AAAAAAAAFF55FF55
5555AAAAAAAAAAAAAAAAAA5500AAAAAA0055AAAAAAAAAAAAAAAAAA555555FF55FFAAAAAA
AA555555FF55FFFFFF55AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAAAA550000555555005555AAFF55AA000055
55FF55AA5555AA55FF0055FF55FF00FF55FF5500FF55AA5555AA55FF55550000AA55FFAA
555500555555000055AAAAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAAFFAAAA55AAAAFFFFAA550055FFFF55
550000AAAA55AAFFFFFF555555000000555555FFFFFFAA55AAAA00005555FFFF550055AA
FFFFAAAA55AAAAFFAAFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA555555AA55AA55555555AAAAFFFFFFFF
AAFFAAAA00AA00AA550000AAFFFF55FFFFAA000055AA00AA00AAAAFFAAFFFFFFFFAAAA55
555555AA55AA555555AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA55AA55AA55AAAA55AA5555555555
55AA00AAAAFF55FFAAFFAAAA0055005500AAAAFFAAFF55FFAAAA00AA555555555555AA55
AAAA55AA55AA55AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAAA00FFFF00AAAA55AAAA55
AAAAAAFF550000AA555555AAFFAAFFAAFFAA555555AA000055FFAAAAAA55AAAA55AAAA00
FFFF00AAAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AA55FFFFFFFF55AA55AA5555
FFAA555555FFFF55AAAA55AA5500FF0055AA55AAAA55FFFF555555AAFF5555AA55AA55FF
FFFFFF55AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAAAA55000055AAAAAA555500
55AA55AAAA550000AAAAAA5555FFFFFF5555AAAAAA000055AAAA55AA55005555AAAAAA55
000055AAAAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAAFFAAAA5555AA55AAAA
FF00FFAA5555FFFF55AA55FF5555555555FF55AA55FFFF5555AAFF00FFAAAA55AA5555AA
AAFFAAFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA555555AA55AAAA00FFFF
000000FF555500AA55AA55AA0000AA0000AA55AA55AA005555FF000000FFFF00AAAA55AA
555555AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA55AA55AA55FFFFFF
FF55FFFFFFAAFFAA55AA55AAFFAAAAAAFFAA55AA55AAFFAAFFFFFF55FFFFFFFF55AA55AA
55AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAAA00FF0000
55005500AA555555AAAAAA555555AA555555AAAAAA555555AA005500550000FF00AAAA55
FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AA55FFFFFF55
FF55FF55FFAAFFFFAA5555AAAA55AA55AAAA5555AAFFFFAAFF55FF55FF55FFFFFF55AA55
AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAAAA55000055
55550000AA55555555AAAA5555AAAAAA5555AAAA55555555AA0000555555000055AAAAAA
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAAFFAAAA
55AAAAFFAA55AAAA55AA5555FF55AA55FF5555AA55AAAA55AAFFAAAA55AAAAFFAAFF55AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA555555AA
55AA555555AAAAAAAA55550055AAAAAA55005555AAAAAAAA555555AA55AA555555AA00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA55AA
55AA55AAAA5555AA5555FF55FF55AA55FF55FF5555AA5555AAAA55AA55AA55AAAA55FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55
AAAA00FF55005555AAAA550055AAAAAA550055AAAA55550055FF00AAAA55FF55AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55
AA55FFFFFFAAAA55AA55FF55FF55AA55FF55FF55AA55AAAAFFFFFF55AA55AA00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA
AAAA5500AA5555AAAAAA550055AAAAAA550055AAAAAA5555AA0055AAAAAA55FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
55FFAAFFAA55AAAAAAAA000000AAAAAA000000AAAAAAAA55AAFFAAFF55AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00AA555555AAAAAAAAAAAAFFAAAAAAAAAAFFAAAAAAAAAAAA555555AA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55AAAA55AA5555AAFF55AA00AAAAAA00AA55FFAA5555AA55AAAA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA55FF55AAAA555555FFAAAA00AAAAFF555555AAAA55FF55AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00AA55AA5555FF555555AAFFAA555555FF5555AA55AA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF55AAAA0000AA55AAAA555555AAAA55AA0000AAAA55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA55FFFF55AAAAAAAA55AAAAAAAA55FFFF55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00AA550055FF0055FF5500FF550055AA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55AAAAFFFFFF555555FFFFFFAAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5555555555005555555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00AAFFFFAAFFAAFFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5500AA555555AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAAA55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.34436 0.97619 1.43167 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF55550000000000000000005555AAAAAAAAAA555500AAAAAAAA00AAFFAAFF00AA00AAFF
FFAAAAAAAAAAAA5500AA000000000000000000AA0055AAAAAAAAAAAAFFFFAA00AA00FFAA
FFAA00AAAAAAAA005555AAAAAAAAAA55550000000000000000005555FF
FFFFAA00AAAA00AAAA00AAAAFF00AA55000055AAAA555555555555AA000000AAAAAA0055
550000FFFF0000FFAAAAAAFFAAAAFFAAAAFFAAAAAAFF0000FFFF0000555500AAAAAA0000
00AA555555555555AAAA55000055AA00FFAAAA00AAAA00AAAA00AAFFFF
FFFFFF0055AA00AA55FFFF0000AAAAAA5555AAAAAAAA55AAAA55AAAAAAFFAAAAAAAAAAFF
FFAAAA0000AAAA0000000000AA550055AA0000000000AAAA0000AAAAFFFFAAAAAAAAAAFF
AAAAAA55AAAA55AAAAAAAA5555AAAAAA0000FFFF55AA00AA5500FFFFFF
FFFFFFFF555555AAFFFFFFFF55000055AAAA55000055AAAAAAAA55000055555555555555
0055AAFFAAAAAAAAFFAAAAFFAA55AA55AAFFAAAAFFAAAAAAAAFFAA550055555555555555
000055AAAAAAAA55000055AAAA55000055FFFFFFFFAA555555FFFFFFFF
FFFFFFFFFFAA00FFFFFFFFFFFFAAAAFF0000FFAAAAFF000000FFFFAAAAFFFFAAFFFFAAFF
FF5555550000550000AA550055AAAAAA550055AA0000550000555555FFFFAAFFFFAAFFFF
AAAAFFFF000000FFAAAAFF0000FFAAAAFFFFFFFFFFFF00AAFFFFFFFFFF
FFFFFFFFFFFF00555500555500550000AAAA0000005555AA5555005500AA000055550000
AA00FFAA00AAAA5555AA00FF5555555555FF00AA5555AAAA00AAFF00AA000055550000AA
0055005555AA5555000000AAAA00005500555500555500FFFFFFFFFFFF
FFFFFFFFFFFFFF5555FFFFAA00AAFFAAAAAAAAFFAAAA55AA00FFAAAA555555AA55AAAA00
AA555500AAAAAAAA55AA00AA00FFAAFF00AA00AA55AAAAAAAA005555AA00AAAA55AA5555
55AAAAFF00AA55AAAAFFAAAAAAAAFFAA00AAFFFF5555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA0000AA555555000000550055AAFFFF0055555555FF555555FFAA55
5555FF5500000055AAAAAAFF5500550055FFAAAAAA5500000055FF555555AAFF555555FF
5555555500FFFFAA550055000000555555AA0000AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0055FFAAFF00AAAA00AAFFAA00555500FFAAFF00AA00FFAA0000FF
AAFFFFFFAAAAFFAA00550000AAFFAAFFAA00005500AAFFAAAAFFFFFFAAFF0000AAFF00AA
00FFAAFF00555500AAFFAA00AAAA00FFAAFF5500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55550000AAAAAAAA00555555AAAA555500AA00AA555500AAAA00
0000AA000055005500FFAAAA0055555500AAAAFF005500550000AA000000AAAA005555AA
00AA005555AAAA55555500AAAAAAAA00005555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00AAAAAAAAAAAAFFFFAA0055AAAA555555AAFFFFAAAAAAAA
FFAAAAAA00AAFFAA00AA005500FFAAFF005500AA00AAFFAA00AAAAAAFFAAAAAAAAFFFFAA
555555AAAA5500AAFFFFAAAAAAAAAAAA00AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055AA0055000000AA0055FF55AA00FFAA00555500000055
0055AAFF550000AA555555AAAA000000AAAA555555AA000055FFAA550055000000555500
AAFF00AA55FF5500AA0000005500AA5500FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555AAAA00AAAAAAFFFFFFAA555500AAAA55AA5555AA
AAFF0000AAFFAAAAAA55AAAAAAAAFFAAAAAAAA55AAAAAAFFAA0000FFAAAA5555AA55AAAA
005555AAFFFFFFAAAAAA00AAAA555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF0055000055550055AAAA55555555FFAAFF00
0000AAAA005555555555FFAA5500AA0055AAFF555555555500AAAA000000FFAAFF555555
55AAAA5500555500005500FFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555500FFAAAAFF00AAAA5500AAFFFFAA000000AA
AA00AA5500FFAAFFFFAA0000FFAAAAAAFF0000AAFFFFAAFF0055AA00AAAA000000AAFFFF
AA0055AAAA00FFAAAAFF00555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFFFFF0000AAAAAAAA555555005500FF5500
0055FFAA00AA00555500AAAA0000FF0000AAAA00555500AA00AAFF55000055FF00550055
5555AAAAAAAA0000FFFFFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AA00AAAAAAAAAAAA55AAAAFF005555FF
FF555500AAAAAAFFFFAAAAAAAA00AA00AAAAAAAAFFFFAAAAAA005555FFFF555500FFAAAA
55AAAAAAAAAAAA00AA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFAAAAAAAAAAAAAAAA5500AA00AAFFFF
FFFFAA00AA5500AA0000005500AAAAAA0055000000AA0055AA00AAFFFFFFFFAA00AA0055
AAAAAAAAAAAAAAAAFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500000000000000FFFFAAAAAA005555
00555555AAFF0055AA5555AAAA005500AAAA5555AA5500FFAA55555500555500AAAAAAFF
FF000000000000005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAAA00AAAA00AA00000055AA55AA
AAFFFFAA005555AAAAAA55AA0055FF5500AA55AAAAAA555500AAFFFFAAAA55AA55000000
AA00AAAA00AAAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AA00AA55FFFF0055FFFFAA55AA
00555500AAAA55AA0055AAAAAAFFFFFFAAAAAA5500AA55AAAA00555500AA55AAFFFF5500
FFFF55AA00AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555AAFFFFFFFF55550055AAAA
AAFF00AAAAAAAA5500FFAA550000AA000055AAFF0055AAAAAAAA00FFAAAAAA55005555FF
FFFFFFAA555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFFFFFFFFFFAAFFAA0055
0000AAAAAAAAAAAA555500AAFFAAAAAAFFAA005555AAAAAAAAAAAA00005500AAFFAAFFFF
FFFFFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055550055550055005500FF
AAAA005500000055AAAA555555000000555555AAAA550000005500AAAAFF005500550055
5500555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFFFAA00AAFFAA00AA
0055AA55AA5555AAAAAAAA55AAAAFFAAAA55AAAAAAAA5555AA55AA5500AA00AAFFAA00AA
FFFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AA55555500AAAA
AA00FFFFAA55AAAAAAAAAAAA5500AA0055AAAAAAAAAAAA55AAFFFF00AAAAAA00555555AA
0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFAAFF00AAAAAA
AAAA0000AA55AA0055000000FFAAAAAAFF0000005500AA55AA0000AAAAAAAAAA00FFAAFF
5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55550000AAAAAAAA
AAAAAA00AA55AAFFAA00AAAA0000FF0000AAAA00AAFFAA55AA00AAAAAAAAAAAAAA000055
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAAAAAAAAA
AAAAAAAAFF55555500AAAAAAAA00AA00AAAAAAAA00555555FFAAAAAAAAAAAAAAAAAA00AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AA005500
000000FFFFFFAAFF005500005500FF005500005500FFAAFFFFFF000000005500AA5500FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555AAAA
00AAAA0000AA005555AAAAFFAA00AA00AAFFAAAA555500AA0000AAAA00AAAA555555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF
005500AAAA0055FF5555555500AAAAAA0055555555FF5500AAAA005500FFFF00AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555
00FFAAAAAAAAFFFFFFAAFF00AAAAAAAAAA00FFAAFFFFFFAAAAAAAAFF00555500FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555
FFFFFF00FF0000AA000000AAAAAAAAAAAAAA000000AA0000FF00FFFFFF5555FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
0000AA00AA00AAAAAA00AAAAAAAAAAAAAAAAAA00AAAAAA00AA00AA0000AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0055FFAAAAAA005500AAAAAAAAAAAAAAAAAAAAAA005500AAAAAAFF5500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF555500000055FF55000000000000000000000055FF550000005555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA00AAAAFFFFFFAAAAFFAAAAFFAAAAFFAAAAFFFFFFAAAA00AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0055AA0000AA0055005500AA0055005500AA0000AA5500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF555555AA55FFFFAAAA555555AAAAFFFF55AA555555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA00FF00AA000000FFAAFF000000AA00FF00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF005555AA00AAAA000000AAAA00AA555500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5555FFAAAAAAAAFFAAAAAAAAFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA0000005500AA0055000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0055FF00AAAAAA00FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF555500FF00FF005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00AA00AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.4404 0.200176 1.52771 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF5500AAFFFF00FF00FF00000000000000000000FFAAAAAAFF0055FFFFFF0000FFFFFF00
000055555500005555555555555555555555555555550000555555000000FFFFFF0000FF
FFFF5500FFAAAAAAFF00000000000000000000FF00FF00FFFFAA0055FF
FFFFAAAAAA555500FF0055555555555555555500AAAAAAAAAA005500FF55555555FF0055
55550000005555000000000000000000000000000000555500000055555500FF55555555
FF005500AAAAAAAAAA0055555555555555555500FF005555AAAAAAFFFF
FFFFFF00FFFFAAFFAA0000000000000000000000FFFF00FFFF000000FFAAFFFFAAFF0000
00005555550000555555555555555555555555555555000055555500000000FFAAFFFFAA
FF000000FFFF00FFFF0000000000000000000000AAFFAAFFFF00FFFFFF
FFFFFFFF5500FFFFFF0000AA0055AA00555500AA00AAAAFF0055555500FFFFFFFF005555
5555000000555500000000000000000000000000000055550000005555555500FFFFFFFF
0055555500FFAAAA00AA00555500AA5500AA0000FFFFFF0055FFFFFFFF
FFFFFFFFFFAAAA00AAFFAAAAAAFFFF00000000FFFF55AAFF0000000000FF5555FF000000
0000555555000055555555555555555555555555555500005555550000000000FF5555FF
0000000000FFAA55FFFF00000000FFFFAAAAAAFFAA00AAAAFFFFFFFFFF
FFFFFFFFFFFF00FF00FF55AAFF5500FF0000AA00AAFFFF00AA00555500AAFFFFAA005555
5555000000555500000000000000000000000000000055550000005555555500AAFFFFAA
00555500AA00FFFFAA00AA0000FF0055FFAA55FF00FF00FFFFFFFFFFFF
FFFFFFFFFFFFFF5500AAFFFF005500AAFFAAAAAAFF5555FFFF00000000FFFFFFFF000000
0000555555000055555555555555555555555555555500005555550000000000FFFFFFFF
00000000FFFF5555FFAAAAAAFFAA005500FFFFAA0055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAAA55550000FFFFFF00FFFFFFAAFF00555500AA5555FF00555555
555500000055550000000000000000000000000000005555000000555555555500FF5555
AA00555500FFAAFFFFFF00FFFFFF00005555AAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFAAFFAAAA00FF55FF00AAAAAA00550000FFFFAAFF00000000
000055555500005555555555555555555555555555550000555555000000000000FFAAFF
FF00005500AAAAAA00FF55FF00AAAAFFAAFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5500FFFFFF00FF005500FF00FFFF000000FF00AAFF5555555555
55550000005555000000000055000000550000000000555500000055555555555555FFAA
00FF000000FFFF00FF005500FF00FFFFFF0055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA00AAFFAA000000FF55FF0055555555FFFF005500005500
0000555555000055555555550000AA0000555555555500005555550000005500005500FF
FF5555555500FF55FF000000AAFFAA00AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF55AA0000FFAAFF000000000055FF000055550000
FF000000005555000000550000FF00FF000055000000555500000000FF000055550000FF
550000000000FFAAFF0000AA55FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF5500AAFFFF0000FFAA55AA0000AA005500FF00000000FF
005555555500005555550000FF00AA00FF000055555500005555555500FF00000000FF00
5500AA0000AA55AAFF0000FFFFAA0055FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55550055FFAAFF55FFFF000000FF55FFFF55FF
00000000005555000000555500FF00FF00555500000055550000000000FF55FFFF55FF00
0000FFFF55FFAAFF55005555AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFAAFFAAFF00FFAAFF00555500AAFFFFFFFFAA
0055555555000000FF00000000FF55FF00000000FF0000005555555500AAFFFFFFFFAA00
555500FFAAFF00FFAAFFAAFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFFFFF005555FFAA00550000FFFFFFFFFFFF
000000000055555500FF0000FF005500FF0000FF005555550000000000FFFFFFFFFFFF00
005500AAFF555500FFFFFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAFFAAFFFFFF0000555500FF5555FF00
555555555500000000FFAAAAFF000000FFAAAAFF00000000555555555500FF5555FF0055
550000FFFFFFAAFFAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF55AAAA00AA00005500AAFFFFAA00
55000000005555555500FFFF0055555500FFFF0055555555000000005500AAFFFFAA0055
0000AA00AAAA55FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAFFFF00FF00FF000000FFFFFFFF00
00555555550000000000AAFF0000000000FFAA0000000000555555550000FFFFFFFF0000
00FF00FF00FFFFAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA555500FF0055555500FF5500FF
000000005500AA0000FF00FFAAAAFFAAAAFF00FF0000AA005500000000FF0055FF005555
5500FF005555AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFAAFFAA0000000000FFAAFFAA
0055AA000000FFFF55FF55FF00FFFFFF00FF55FF55FFFF000000AA5500AAFFAAFF000000
0000AAFFAAFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFFFFF0000AA0055AAAAAA55
FFFFAA5500AA00AAFFFFFFAA0055FF5500AAFFFFFFAA00AA0055AAFFFF55AAAAAA5500AA
0000FFFFFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAFFAAAAAAFFFF00FFFF
AA00FFFFAAAAAAFF5555AAAAAAFFFFFFAAAAAA5555FFAAAAAAFFFF00AAFFFF00FFFFAAAA
AAFFAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF55AAFF5500FF0055
FFAAAA00FFFF00FFAAFFFF00FFFFFFFFFF00FFFFAAFF00FFFF00AAAAFF5500FF0055FFAA
55FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAFFFF005500AAFFAA
FF00FFFF5555FFFFFF0055FFFFFFFFFFFFFF5500FFFFFF5555FFFF00FFAAFFAA005500FF
FFAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55550000FFFFFF
00AA00AAFFFFAA00AAAAFFFFFFFFFFFFFFFFFFAAAA00AAFFFFAA00AA00FFFFFF00005555
AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFAAFFAAAA00FF
55FFAAAAAA00FFFF55AAFF00AAAA00AAAA00FFAA55FFFF00AAAAAAFF55FF00AAAAFFAAFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFFFFF00FF00
5500FFFF00FF00AAFFFF0055AAFF55FFAA5500FFFFAA00FF00FFFF005500FF00FFFFFF00
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAFFAA00
0000FF5500AAFFAA55AAAAFFFF005500FFFFAAAA55AAFFAA0055FF000000AAFFAA00AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF55AA
0000FFAAFFAA55AAFFFF00FFAA005500AAFF00FFFFAA55AAFFAAFF0000AA55FF00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAFFFF
0000FFAA55AAFFFF0055FFFFFF000000FFFFFF5500FFFFAA55AAFF0000FFFFAA0055FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55
555500FFFFAA55AAAAFFFFFFFFFF55FFFFFFFFFFAAAA55AAFFFF00555555AAAAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
AAFFFF5555AAFFFF00FF5555FF005500FF5555FF00FFFFAA5555FFFFAAFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500
FFFFFFFFAAFF5555FFFFFFAAFF000000FFAAFFFFFF5555FFAAFFFFFFFF0055FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AA00AAFF00FFAAFFFFFFFFFF0055555500FFFFFFFFFFAAFF00FFAA00AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FF55FF55AAAA00AAAA0000550000AAAA00AAAA55FF55FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5500AAFFFFFFAA55FFFF00FF000000FF00FFFF55AAFFFFFFAA0055FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAAA5555AAFFFFFFFF5555555555FFFFFFFFAA5555AAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFAAFF5555FF00550000005500FF5555FFAAFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF5500FFFFFFAAFF000000AA000000FFAAFFFFFF0055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAA00AAAAAA0000FF00FF0000AAAAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FF00FFFF0000FF55FF0000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5500AAFF0000FFAAFF0000FFAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAAA5500AAAAAA0055AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFAAAAAAAAAAFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5500FFFF00FFFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA00AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.4404 0.39418 1.52771 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF5500AA005500FF55FFFFFFAAAAFFFFFFFFFFFF55AAAA00AAAAFFFFAAAAFF5555FF0055
550000AAAAFFFFAAFFFFFFFF55FFFFFF55FFFFFFFFAAFFFFAAAA0000555500FF5555FFAA
AAFFFFAAAA00AAAA55FFFFFFFFFFFFAAAAFFFFFF55FF005500AA0055FF
FFFFAAAAAAFFFF5555AA0000FFFF0000AA55005555AAFF55FFAA55AAAAAAAA5555AAAAFF
FFAAAAFF55AA000000FF00AAFFFFFFFFFFAA00FF000000AA55FFAAAAFFFFAAAA5555AAAA
AAAA55AAFF55FFAA55550055AA0000FFFF0000AA5555FFFFAAAAAAFFFF
FFFFFF00FFFFFFFFAAFF55FFFFFFFF55FFAAFFAAFFFF00AAAA55FF00FFFF00FF55000055
55000055AA55FFFF55FF55FFAA00FF00AAFF55FF55FFFF55AA5500005555000055FF00FF
FF00FF55AAAA00FFFFAAFFAAFF55FFFFFFFF55FFAAFFFFFFFF00FFFFFF
FFFFFFFF555555FF55AAAA00555555FF000000FFFFFFFF55AAFFFFFF5555FFFFFFAAAAFF
FFAAAAFFFF005555FF00AAAA55FFFFFF55AAAA00FF555500FFFFAAAAFFFFAAAAFFFFFF55
55FFFFFFAA55FFFFFFFF000000FF55555500AAAA55FF555555FFFFFFFF
FFFFFFFFFFAAFFFFFFAA55FFFFAAFFFFFF55FFFFFFFFFFFFAA5500AAFFFFAA0000FFFF00
00FFFF00AAFFAAFFFFFF55AAFFFFFFFFFFAA55FFFFFFAAFFAA00FFFF0000FFFF0000AAFF
FFAA0055AAFFFFFFFFFFFF55FFFFFFAAFFFF55AAFFFFFFAAFFFFFFFFFF
FFFFFFFFFFFF00AA55AAFFFFFFFF0000FF0055AAAA550055AAFFFF55AAAA55FFFF5555FF
FF5555FFFF000055555500FFFFFFFFFFFFFF005555550000FFFF5555FFFF5555FFFF55AA
AA55FFFFAA550055AAAA5500FF0000FFFFFFFFAA55AA00FFFFFFFFFFFF
FFFFFFFFFFFFFF55AA55FF5555FF55FFFFFF55000055FFFFAA5500AAAAAAAA0000AAAA00
55AA5555FF55FFFFAAFFFF555555FF555555FFFFAAFFFF55FF5555AA5500AAAA0000AAAA
AAAA0055AAFFFF55000055FFFFFF55FF5555FF55AA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA555500FF5555AA0000FF55FFFFAA00FFFFAAAAAAAAAAAAFFAA55FF
FFAA5555AA00AA0055005555AA555555AA5555005500AA00AA5555AAFFFF55AAFFAAAAAA
AAAAAAFFFF00AAFFFF55FF0000AA5555FF005555AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0055FFFFFFAAFF55FFFFFFAA00FFFF555500005500000055AAFFFF
FFFF0055FFAAAAAAFFFF5500FFFFAAFFFF0055FFFFAAAAAAFF5500FFFFFFFFAA55000000
5500005555FFFF00AAFFFFFF55FFAAFFFFFF5500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5500AA00550055FF5555FFAAAA5500FF55FFFFAAAAFFAAFF5555
55FF55FF0000000000FFAAFFAA000000AAFFAAFF0000000000FF55FF555555FFAAFFAAAA
FFFF55FF0055AAAAFF5555FF55005500AA0055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFF5500AAAA00000055FFFFFFAA000055005500AAAA
00AAFFFFFF55FFFF55FF55AAAAAAFFAAAAAA55FF55FFFF55FFFFFFAA00AAAA0055005500
00AAFFFFFF55000000AAAA0055FFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFAAAAAAAAFFAAAA0055AAAAAAFFAAFFAAFFAA55
FFFF0000AA5555FF550055FFAA55FF55AAFF550055FF5555AA0000FFFF55AAFFAAFFAAFF
AAAAAA5500AAAAFFAAAAAAAAFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FF55AAFF55AAAAAAAAFFFF00FFFFFF000055AAFF
FFFFFF55FFAAFFFFFFAAAA000055FF550000AAAAFFFFFFAAFF55FFFFFFFFAA550000FFFF
FF00FFFFAAAAAAAA55FFAA55FF555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAA5500FFFF00FFFFFFFF555555FFFF550000
AA00FF0055AAFF00AA55FFAAAAFFFFFFAAAAFF55AA00FFAA5500FF00AA000055FFFF5555
55FFFFFFFF00FFFF0055AAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AAFFFF5555FFFFFFFFFFFFAAFFFFFFFFAAAA
FF55FF55FF00FFAAAAAA000000555555000000AAAAAAFF00FF55FF55FFAAAAFFFFFFFFAA
FFFFFFFFFFFF5555FFFFAA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA55FF5555AA55AAAA55AA0000555500AAFF55
AA00AA5555FFFFFF00FFFF55FFFFAAFFFF55FFFF00FFFFFF5555AA00AA55FFAA00555500
00AA55AAAA55AA5555FF55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555500FF55AA55FFAAFF55FFFFAAFFAA5500
FFFF55AA555555FF55FF5555AA000000AA5555FF55FF555555AA55FFFF0055AAFFAAFFFF
55FFAAFF55AA55FF005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFFFFAA55550000FF55550000FFFFAA
AA5500FFFFAAFFFFFFAA00AAAAAAFFAAAAAA00AAFFFFFFAAFFFF0055AAAAFFFF00005555
FF00005555AAFFFFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA005500FF55FFFFFFAAFFAAAA5500
0055FFFFFFFF0000AA55FFFF00FFFFFF00FFFF55AA0000FFFFFFFF55000055AAAAFFAAFF
FFFF55FF005500AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFF5555AA0000FFFFFF00FF55
FFFFAA0055AAAAFFAA555555FFFFFFFFFF555555AAFFAAAA5500AAFFFF55FF00FFFFFF00
00AA5555FFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFAAFF55FFFFFFFFFF5555
AA00FFFF55000000FFFFAAFFFFFFFFFFFFFFAAFFFF00000055FFFF00AA5555FFFFFFFFFF
55FFAAFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FF55AAAA005555005555AA
55FFFFFFFFAAAAFFAA0055005555FF5555005500AAFFAAAAFFFFFFFF55AA555500555500
AAAA55FF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAA55FFFFAAFFAAFFFF
0055555555000055AAFFAAFFAAFFFFFFAAFFAAFFAA5500005555555500FFFFAAFFAAFFFF
55AAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AAFFFFFFFF00005555
FFFFAAFFFFAAAAFFFF000000FFFFFFFFFF000000FFFFAAAAFFFFAAFFFF55550000FFFFFF
FFAA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA55FF5555FF55FFFFAA
FF000000FF00FFFFFFFF55FFFFFFFFFFFFFF55FFFFFFFF00FF000000FFAAFFFF55FF5555
FF55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555500FF5555AA00FF
FFFF55FFFFFF5555555500FF0000FF0000FF0055555555FFFFFF55FFFFFF00AA5555FF00
5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFFFFAAFF55FF
5555FF00AA0055FF0055FFFFFF55FF55FFFFFF5500FF5500AA00FF5555FF55FFAAFFFFFF
5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA00550055FF
5500FFAAAAAAFFFFFF5500AA0055FF5500AA0055FFFFFFAAAAAAFF0055FF55005500AA00
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFF5500
55FFFFFF00FFFFFFFFFFAAAAAAFFFFFFAAAAAAFFFFFFFFFF00FFFFFF550055FFFFAAAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFAA
AA005555FFFFFFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFF555500AAAAFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FF55
AAFFAAFFFFFFFFFFFFFFFFFF5555005555FFFFFFFFFFFFFFFFFFAAFFAA55FF555555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF
AA550000FF0000FF0000AA5500FF55FF0055AA0000FF0000FF000055AAFFFFFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55
AAFFFF55FF55FFFFFF55FFAAFFAA00AAFFAAFF55FFFFFF55FF55FFFFAA55AA00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA
55FF5555AAAA005555FF000055AAFFAA550000FF555500AAAA5555FF55AA55FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
555500FF55AAFFAAFFFFFF55FF00FF00FF55FFFFFFAAFFAA55FF005555AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0055FFFFFFAA55AAFF00AA5555FFFFFF5555AA00FFAA55AAFFFFFF5500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5500AA005500FFFFFF55AA5555FF5555AA55FFFFFF005500AA0055FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAAAFFFF555500AAAAAA00AA00AAAAAA005555FFFFAAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFAAFFAA55FFAAAAAAFF55AAFFAAFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF555555FF55AAAAAA0000000000AAAAAA55FF555555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFFFFFFAA55FFAAAAFFAAAAFF55AAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00AA55AAFFFFFF00FF00FFFFFFAA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55AA55FF5555FFFFFF5555FF55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA555500FF555555FF005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0055FFFFFFAAFFFFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5500AA000000AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.4404 0.588183 1.52771 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF55000000AA55AAFFAA0055AAAA5555AAAAAA5555AAFFFFAAAA5500AAAAAAAA555555AA
FF00FFFFFFFF00AA0000555500AAAAAA0055550000AA00FFFFFFFF00FFAA555555AAAAAA
AA0055AAAAFFFFAA5555AAAAAA5555AAAA5500AAFFAA55AA00000055FF
FFFFAAAAFFAA555555FFAAAA0055AA55555555550055AAAA55FFAAFFAA55FFAA5555AA55
FF55FF5555FF55FFAAAAFFFFAAAAAAAAAAFFFFAAAAFF55FF5555FF55FF55AA5555AAFF55
AAFFAAFF55AAAA55005555555555AA5500AAAAFF555555AAFFAAAAFFFF
FFFFFF00FFAA5555AA55AA005500FFFFAAFFFFAAFFAAFF55AA55AAFF00FF555555AA5500
FFAAFF005555FF00AA55FF55555555555555FF55AA00FF555500FFAAFF0055AA555555FF
00FFAA55AA55FFAAFFAAFFFFAAFFFF005500AA55AA5555AAFF00FFFFFF
FFFFFFFF5555550055AA55FFFFAAAA55AAFF00AA55AAFF0055AA55FF55FF550055555500
0000FFAAAA00000055AA55AA5555AA5555AA55AA55000000AAAAFF0000005555550055FF
55FF55AA5500FFAA55AA00FFAA55AAAAFFFF55AA5500555555FFFFFFFF
FFFFFFFFFFAAFFFF5500AAAA55AAFF5500AAFFAA555555FFFFAA5555FF00AAAAFFFFAAFF
AAAAFF00FFFF55FFFFAA55555500FF00555555AAFFFF55FFFF00FFAAAAFFAAFFFFAAAA00
FF5555AAFFFF555555AAFFAA0055FFAA55AAAA0055FFFFAAFFFFFFFFFF
FFFFFFFFFFFF00AAFFFF55AAFFFF00AAAAFF555555AA5555FF55AA5555FFFF00000000FF
AA55FF55FF5555AAAA5500555500000055550055AAAA5555FF55FF55AAFF00000000FFFF
5555AA55FF5555AA555555FFAAAA00FFFFAA55FFFFAA00FFFFFFFFFFFF
FFFFFFFFFFFFFF55AAAA555555FF55FFAA55AA5555AA00AAAA555555AA55AAAAFFAAAAFF
00FF5555AAAA0000FFFFAAAA0000550000AAAAFFFF0000AAAA5555FF00FFAAAAFFAAAA55
AA555555AAAA00AA5555AA55AAFF55FF555555AAAA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55005555AAAA00FFFFAA5555AAFFAA550055FF00FF55AAFF0000FF
AAAA5555AAFF55FFFFFFFF00005500550000FFFFFFFF55FFAA5555AAAAFF0000FFAA55FF
00FF550055AAFFAA5555AAFFFF00AAAA55550055AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF005500FF55AAFFAA00FFFFAAFF5555550000AAFFAA0000FFAAAAFF
00FFFFAAFF5555AAAA55AAAAFFAAFFAAFFAAAA55AAAA5555FFAAFFFF00FFAAAAFF0000AA
FFAA0000555555FFAAFFFF00AAFFAA55FF005500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55000000AA55AAFFAA00FFFFFFAAFFFF55FFAA0055000000FFFF
FF5555FFAA0000AA5500FF00FFAA55AAFF00FF0055AA0000AAFF5555FFFFFF0000005500
AAFF55FFFFAAFFFFFF00AAFFAA55AA00000055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFFAA555555FFAAAA55AAAAAA55AA55AAFFAAFFAAAAFF00
AAFFFFAA00550000FF55FF55FF55AA55FF55FF55FF00005500AAFFFFAA00FFAAAAFFAAFF
AA55AA55AAAAAA55AAAAFF555555AAFFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFAA5555AA55AA0055FFAA55FF0000AA55AA00FF00FFAA
AAAA55AAFFAAFFAAAA5555FF00AAAAAA00FF5555AAAAFFAAFFAA55AAAAAAFF00FF00AA55
AA0000FF55AAFF5500AA55AA5555AAFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF5555550055AA55FFFFAA005555FFFF55AA55FFFFFF5555
55555500AAFF5555555500FFAAAAAAAAAAFF0055555555FFAA005555555555FFFFFF55AA
55FFFF555500AAFFFF55AA5500555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF5500AAAA55AAFFAAFFFFFFFFAA5555FF555500
55FF005500AAFFFFAAFFFF55555555555555FFFFAAFFFFAA005500FF55005555FF5555AA
FFFFFFFFAAFFAA55AAAA0055FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF55AAFFFF00AA55AAAA55AA00AAAA555500
00AAFFAAFFAA55AAAAAA55AA5555AA5555AA55AAAAAA55AAFFAAFFAA00005555AAAA00AA
55AAAA55AA00FFFFAA55FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA555555FF55FFAAFF55AA55FFFF0000AAAA
FFAA55AAFF0000AA55FFAAFF5500FF0055FFAAFF55AA0000FFAA55AAFFAAAA0000FFFF55
AA55FFAAFF55FF555555AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55005555AAAA00FFFFFFAA5555FF55FFFF00
FFAA555555FFFF55AA55AA00FF55FF55FF00AA55AA55FFFF555555AAFF00FFFF55FF5555
AAFFFFFF00AAAA55550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005500FF55AAFFAA00FFAA5555AAAA00FFAA
AA55005555AAAA555555AAFFAA000000AAFFAA555555AAAA55550055AAAAFF00AAAA5555
AAFF00AAFFAA55FF005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55000000AA55AAFFAA005555AAFF55FF55
AA00005555AA0055FF0055AAAAAAFFAAAAAA5500FF5500AA55550000AA55FF55FFAA5555
00AAFFAA55AA00000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAA555555FFAAAA00AA55AA55AA
55000055FF000055FF55FF0000FFFFFF0000FF55FF550000FF55000055AA55AA55AA00AA
AAFF555555AAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA5555AA55AA005500AA005555
55000055FF55FFFFAA00AAFFAAAA55AAAAFFAA00AAFFFF55FF55000055555500AA005500
AA55AA5555AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555550055AA55FFFFAAAAAAFFFF
AAFFAAAA00FF5555FFAAAAAA5500AA0055AAAAAAFF5555FF00AAAAFFAAFFFFAAAAAAFFFF
55AA5500555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF5500AAAA55AAFF55AAAA
55FF55AAFFAA00AA00FF00FFFFAAAAAAFFFF00FF00AA00AAFFAA55FF55AAAA55FFAA55AA
AA0055FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF55AAFFFF00AAAAAA
AA00FF55AAAAAAFF55FF55FF5555555555FF55FF55FFAAAAAA55FF00AAAAAAAA00FFFFAA
55FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA555555FF55FFAA55
FFAAAA5555555555FF00AAAA5555AA5555AAAA00FF5555555555AAAAFF55AAFF55FF5555
55AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55005555AAAA00FFFF
AA0055AA5555005555FFFF0000AAAAAA0000FFFF5555005555AA5500AAFFFF00AAAA5555
0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005500FF55AAFFAA00
FFFF5500AA000055FF00AAFFAAAAAAAAAAFFAA00FF550000AA0055FFFF00AAFFAA55FF00
5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55000000AA55AAFF
AA00FF55FFAAAAFFFFFF55AAAAAAAAAAAAAA55FFFFFFAAAAFF55FF00AAFFAA55AA000000
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAA555555
FFAAAA5555FFAA55AAAA555555555555555555AAAA55AAFF5555AAAAFF555555AAFFAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA5555AA
55AA0055FF00AA55555555AA5555AA5555AA55555555AA00FF5500AA55AA5555AAFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555550055
AA550000AAFFAA555500FF55AA555555AA55FF005555AAFFAA000055AA5500555555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55
00AAAAFFAA55AAFFFFAAAA555555AA555555AAAAFFFFAA55AAFFAAAA0055FFFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF
FF55AAFF0000AA55AAAAAAAA00AAAAAA00AAAAAAAA55AA0000FFAA55FFFFAA00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA
AA555555FFFF55AA5500AA550000FF000055AA0055AA55FFFF555555AAAA55FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
55005555AAAA5555550000FF55FFFFFF55FF0000555555AAAA55550055AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
005500FF55AAFFFFAAFFAAAA5555FF5555AAAAFFAAFFFFAA55FF005500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55000000AA55AAAAAA55FFAAFFFFFFAAFF55AAAAAA55AA00000055FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAFFAA5555555555AAAAAA55AAAAAA5555555555AAFFAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFAA5555AA5555AAFF55AA55FFAA5555AA5555AAFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF5555550055AA555555FF00FF555555AA5500555555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFFFF5500AAAA00AAFFAA00AAAA0055FFFFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00AAFFFF55AAFFAA55AAFFAA55FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55AAAA555555FFAAFF555555AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55005555AAAAAA55550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0055005555555555005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF550000AA00AA000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFF55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.4404 0.782187 1.52771 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF550000FFFFFF55FFAAAAAA0000FF000055AA55AA550055AA0000FF00AAAAAAAAAAAA55
AA55AAAAFFFFFFAAAA00FFFFAAAAAAAAAAFFFF00AAAAFFFFFFAAAA55AA55AAAAAAAAAAAA
00FF0000AA550055AA55AA550000FF0000AAAAAAFF55FFFFFF000055FF
FFFFAAAAFF00AAFFFFFF00FFFF55FF55FFFFAA555500FF005500AA55AA00005500000055
FFAAFF55AAAA55AAFF55FF55550055005555FF55FFAA55AAAA55FFAAFF55000000550000
AA55AA005500FF005555AAFFFF55FF55FFFF00FFFFFFAA00FFAAAAFFFF
FFFFFF00FFAAAAAA55AAAAFF00AAAA5555FF55AA555555FFFFAAAAAA0000FF0055AA0055
FF55AAAA0000AAAAAA5555FF0055AA5500FF5555AAAAAA0000AAAA55FF5500AA5500FF00
00AAAAAAFFFF555555AA55FF5555AAAA00FFAAAA55AAAAAAFF00FFFFFF
FFFFFFFF55550000AAAAAAAA55005500FF5555AAFFFFAAFF00AA000055AA00FF005500AA
AA55550055AA00005555AA55AA00AA00AA55AA55550000AA55005555AAAA005500FF00AA
550000AA00FFAAFFFFAA5555FF00550055AAAAAAAA00005555FFFFFFFF
FFFFFFFFFFAAFFAAAAAAAAAAAA0055FFFFFFAAFF5555FFAA0055555555AAFFAA0055FFFF
00FF5500AAAAAAFFAAFFFF005500AA005500FFFFAAFFAAAAAA0055FF00FFFF5500AAFFAA
5555555500AAFF5555FFAAFFFFFF5500AAAAAAAAAAAAFFAAFFFFFFFFFF
FFFFFFFFFFFF00AA000055005500AAAA55AAAAAA5555AAAAAAFFFFAAFFFF00AA0055FF55
5555FF00000000AAFF5555FFFFAAAAAAFFFF5555FFAA00000000FF555555FF5500AA00FF
FFAAFFFFAAAAAA5555AAAAAA55AAAA005500550000AA00FFFFFFFFFFFF
FFFFFFFFFFFFFF55AA0055FFFFAAAAAAAA000000AAAA00005555FF55AAAA550055AA55AA
5555AAAAFFAAAAFF5555AA55AAAAAAAAAA55AA5555FFAAAAFFAAAA5555AA55AA550055AA
AA55FF55550000AAAA000000AAAAAAAAFFFF5500AA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5500FFAA00000000AA5500AA0000FF0055FF55005555AA00AA00AA
00AAAAAAAA55FFAA00AAAAAA0000000000AAAAAA00AAFF55AAAAAAAA00AA00AA00AA5555
0055FF5500FF0000AA0055AA00000000AAFF0055AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0055AAAAAAFFAAAAFF5500AA0055AAAAFFFFFFAAAA00AA005500AA
00550000AA00AAFF55FFAA55FFFF55FFFF55AAFF55FFAA00AA00005500AA005500AA00AA
AAFFFFFFAAAA5500AA0055FFAAAAFFAAAAAA5500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55000000AAFF55AAAA005500AAAAAAAA55AAAAAAAAFF55FF0000
AA5555555500AA00FF555500FFAA00AAFF005555FF00AA0055555555AA0000FF55FFAAAA
AAAA55AAAAAAAA005500AAAA55FFAA00000055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFFAA55AA55FFAAAA0055000000AAAAAAAAAAAA5555FFFF
55AA5555AA550055AAAA00AA55AAFFAA55AA00AAAA550055AA5555AA55FFFF5555AAAAAA
AAAAAA0000005500AAAAFF55AA55AAFFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFAA555500FFAA55FFFFAAAAFFAA55FFAA55FFAAFFFFFF
FFAA5555AAFFFF55000000FFFFAA55AAFFFF00000055FFFFAA5555AAFFFFFFFFAAFF55AA
FF55AAFFAAAAFFFF55AAFF005555AAFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555500FF55FF55AA55AAAAAAAA55FF00AA00AAFF5555FF
555500FF55AAAA5555555555FF55AA55FF5555555555AAAA55FF005555FF5555FFAA00AA
00FF55AAAAAAAA55AA55FF55FF005555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA00AAFFFF005500005555AAAAFF55FFAA00AAAA
5555AA00FF55AAFFFFAAFFFFAA00AA00AAFFFFAAFFFFAA55FF00AA5555AAAA00AAFF55FF
AAAA555500005500FFFFAA00AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA005555FF55FF0000FF55005555FF00AA005555
00FF55AA00FF55AAAA55FF555500AA005555FF55AAAA55FF00AA55FF00555500AA00FF55
550055FF0000FF55FF555500AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00AAAA5555FFFF5555AA00AAAA550055AA55
5555FF00FF00AAAAAAAA00FF5500AA0055FF00AAAAAAAA00FF00FF555555AA550055AAAA
00AA5555FFFF5555AAAA00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55000055FF00AAFFFFAA550000AAAAFFFF00
55FF00AA55AA0000000055AAAA005500AAAA5500000000AA55AA00FF5500FFFFAAAA0000
55AAFFFFAA00FF55000055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AA00AAFFAA55AAAAAA0055AAFF5555FF
FFAA005500FFFF55FFFF55000055AA55000055FFFF55FFFF005500AAFFFF5555FFAA5500
AAAAAA55AAFFAA00AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000FFFFFF005500555555AAFF0055FF
555500AAAAFF00AAAA55AA5500AAAAAA0055AA55AAAA00FFAAAA005555FF5500FFAA5555
55005500FFFFFF000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00AAFFAAFFAAFFFFAA55AA00AA
FFFFAAAAAAAA55005500FFFFAAAAAAAAAAFFFF00550055AAAAAAAAFFFFAA00AA55AAFFFF
AAFFAAFFAA00FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAAAAA55FF55AAAA55FF00FF00
FFAA0000005555AA00AA55AAAAAAAAAAAAAA55AA00AA5555000000AAFF00FF00FF55AAAA
55FF55AAAAAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55550000AAAA55550055FF55FF55
FF55AA0055AA555500AA00AA0000000000AA00AA005555AA5500AA55FF55FF55FF550055
55AAAA00005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAAAAAAA00AA5555FF00AA
AA555500AAAAAA00AA55FFFF0000FF0000FFFF55AA00AAAAAA005555AAAA00FF5555AA00
AAAAAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00005500AA00AAAA5500
5555AA5500000055AAFFFFFFFF55FF55FFFFFFFFAA5500000055AA55550055AAAA00AA00
550000AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA0055FFFF0000AA00AA
5555AAFFFF55FFFFAA55AAAA55AA55AA55AAAA55AAFFFF55FFFFAA5555AA00AA0000FFFF
5500AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FFAA0055AAFFAA
5555AAFF00AAAA55AAFFFF00FF55AA55FF00FFFFAA55AAAA00FFAA5555AAFFAA5500AAFF
0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AAAAAAFFFF00AA
00AAAAAA55000055FFAA00FF00AAAAAA00FF00AAFF55000055AAAAAA00AA00FFFFAAAAAA
5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55000000AAFF0000
AA55FFAA55555555AAAAAAFF0000000000FFAAAAAA55555555AAFF55AA0000FFAA000000
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAA55AA00
5555AAAAAA00AAAA00005555FFFF55FFFF55550000AAAA00AAAAAA555500AA55AAFFAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA555500
AAAA0000AA00550055AA00AAAA55AA55AAAA00AA55005500AA0000AAAA005555AAFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500FF55
FFAA5500AA0055FFFFAA550000AAAAAA000055AAFFFF5500AA0055AAFF55FF005555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA00
AAFF5500AA0055FF555500FF0000550000FF005555FF5500AA0055FFAA00AAFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00
5555FF0000AA5555FF0055AAAAFFAAFFAAAA5500FF5555AA0000FF555500AA00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA
00AAAA5500AA00AAAA5500FFFF00AA00FFFF0055AAAA00AA0055AAAA00AA55FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
55000055FFFF00005555AA00FFAAAAAAFF00AA55550000FFFF55000055AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0055AA00AAFF0000FF550055AAAAAAAAAA550055FF0000FFAA00AA5500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF550000FFFFFF55FF5500AAAAAAAAAAAAAA0055FF55FFFFFF000055FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAFF00AAFFFFFFAAAAAAAAAAAAAAAAAAFFFFFFAA00FFAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFAAAAAA55AAAAAAAAAAAAAAAAAAAAAA55AAAAAAFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF55550000AAAAAAAAAAAAAAAAAAAAAAAAAA00005555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00AA00000000000055000000000000AA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55AA0055AA0055AA5500AA5500AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5500FFFF550055FFFF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0055AAAA555555AAAA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55005555AA55550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA00AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.4404 0.97619 1.52771 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF5500FFAA005555FF555555AAFF55555555555555555555555555555555000000000000
000055555500000000000000000000000000000000000000555555000000000000000055
555555555555555555555555555555FFAA555555FF555500AAFF0055FF
FFFFAAAA55FF0000AAFFFFAAFF5555555555555555555555555555555555000000000000
000055555500000000000000000000000000000000000000555555000000000000000055
55555555555555555555555555555555FFAAFFFFAA0000FF55AAAAFFFF
FFFFFF00FF00AAAAFF5555FFAA0055555555555555555555555555555555000000000000
000055555500000000000000000000000000000000000000555555000000000000000055
55555555555555555555555555555500AAFF5555FFAAAA00FF00FFFFFF
FFFFFFFF5555AAFF555500AAFF5500555555005555555555555555555555000000000000
000055555500000000000000000000000000000000000000555555000000000000000055
55555555555555555555005555550055FFAA005555FFAA5555FFFFFFFF
FFFFFFFFFFAAFF55550055FFAA000055AA00005555555555555555555555000000000000
000055555500000000000000000000000000000000000000555555000000000000000055
555555555555555555550000AA550000AAFF55005555FFAAFFFFFFFFFF
FFFFFFFFFFFF00AA00005555FFAAAAFFFF00550055555555555555555555000000000000
000055555500000000000000000000000000000000000000555555000000000000000055
555555555555555555005500FFFFAAAAFF55550000AA00FFFFFFFFFFFF
FFFFFFFFFFFFFF55AA55555555FFAA55AAAA000055555555555555555555000000000000
000055555500000000000000000000000000000000000000555555000000000000000055
5555555555555555550000AAAA55AAFF55555555AA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA550055AA00FFFFAA55FF0055555555555555005555000000000000
000055555500000000000000000000000000000000000000555555000000000000000055
55005555555555555500FF55AAFFFF00AA550055AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFF5555FFAAFF005555005555555500FF00000000000000
000055555500000000000000000000000000000000000000555555000000000000000000
FF005555555500555500FFAAFF5555FFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5500FFAA005555FFAA00AA00005555550055FF55000000000000
000055555500000000000000000000000000000000000000555555000000000000000055
FF55005555550000AA00AAFF555500AAFF0055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA55FF0000AAFF55FFAAAAFFFFAAFFAAFF00000000000000
000055555500000000000000000000000000000000000000555555000000000000000000
FFAAFFAAFFFFAAAAFF55FFAA0000FF55AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00AAAAFF555555FFAA55AAAAAA55FF55000000000000
000055555500000000000000000000000000000000000000555555000000000000000055
FF55AAAAAA55AAFF555555FFAAAA00FF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF5555AAFF555500AA55AAFFFF00FFFFAA00000000000000
000055555500000000000000000000000000000000000000555555000000000000000000
AAFFFF00FFFFAA55AA005555FFAA5555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55550055FFAAFF5555FF00AAFF55000000000000
000055555500000000000000000000000000000000000000555555000000000000000055
FFAA00FF5555FFAAFF55005555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00005555FFAA0000FFAAAAAA55000000000000
000055555500000000000000000000000000000000000000555555000000000000000055
AAAAAAFF0000AAFF55550000AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA55555555FFAAAAFF00FFFF00005500000000
000055555500000000000000000000000000000000000000555555000000000000550000
FFFF00FFAAAAFF55555555AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055AA00FFFF00AAAA55AA555500000000
0000555555000000000000000000000000000000000000005555550000000000005555AA
55AAAA00FFFF00AA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF5555FFFF00FF00FF0000000000
00005555550000000000000000000000000000000000000055555500000000000000FF00
FF00FFFF5555FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFAA005555FF55FF55FF5500000000
00005555550000000000000000000000000000000000000055555500000000000055FF55
FF55FF555500AAFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF0000AAFFFFFFAA0055000000
00005555550000000000000000000000000000000000000055555500000000005500AAFF
FFFFAA0000FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00AAAAFF5555FF55AA55000000
000055555500000000000000000000000000000000000000555555000000000055AA55FF
5555FFAAAA00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAFF555500AAFFFF00000000
000055555500000000000000000000000000000000000000555555000000000000FFFFAA
005555FFAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55550055FFAA00FF550000
0000555555000000000000000000000000000000000000005555550000000055FF00AAFF
55005555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00005555FFAAAA550000
0000555555000000000000000000000000000000000000005555550000000055AAAAFF55
550000AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA55555555FFAA550000
000000AA000000000000000000000000000000000000000000AA000000000055AAFF5555
5555AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055AA00FFFFAAAA
FFAAAAFF550000000000000000000000000000000000000055FFAAAAFFAAAAFFFF00AA55
0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF5555FFAA
55AAFF5555000000000000000000000000000000000000005555FFAA55AAFF5555FFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFAA005555FF
AAFF55555500000000000000000000000000000000000000555555FFAAFF555500AAFF00
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF0000AA
FF555555550000000000000000000000000000000000000055555555FFAA0000FF55AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00AAAAFF
5555555555000000000000000000000000000000000000005555555555FFAAAA00FF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAFF55
555555555500000000000000000000000000000000000000555555555555FFAA5555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555
00555555550000000000000000000000000000000000000055555555005555FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00
005555555500000000000000000000000000000000000000555555550000AA00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA
5555555555000000000000000000000000000000000000005555555555AA55FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
550055AA000000000000000000000000000000000000000000AA550055AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFF55000000000000000000000000000000000055FFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5500FFAA00550000000000000000000000000000005500AAFF0055FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAA55FF0000550000000000000000000000550000FF55AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FF00AAAA00000000000000000000000000AAAA00FF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF5555AAFF55000000000000000000000055FFAA5555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFF555500000000000000000000005555FFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00AA00550000000000000000005500AA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55AA5500000000000000000055AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5500000000000000000055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000550000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF550000550055000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA000000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.53644 0.200176 1.62375 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055FF55FF5500
00AAAAAA00FFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFF00AAAAAA000055FF55FF5500
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00FF55AA55
0000000000FFFFFFFFFF00FFFFFFAAFFFFFF00FFFFFFFFFF000000000055AA55FF00FF55
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055FF55
0000FF0000FFFF00FFFF0000AA000000AA0000FFFF00FFFF0000FF000055FF550055AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAFFFF00
5500AA0055AAFF55FFAA55000000FF00000055AAFF55FFAA5500AA005500FFFFAAAA00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFAA55
00FF00AA5555FFAAFF5555AA0055005500AA5555FFAAFF5555AA00FF0055AAFF5555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555
AA0000FFAAFFFF00AA00AAAA5500FF0055AAAA00AA00FFFFAAFF0000AA5555FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00AA
AA5500AA00FFFFFF555555FF5500AA0055FF555555FFFFFF00AA0055AAAA00AA00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555
FF55000000FFFFFF0055FF00FF55FF55FF00FF5500FFFFFF00000055FF555555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
FF00550000FFFFFFFF550055AAFFFFFFAA550055FFFFFFFF00005500FFFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA
0000FF55FFFF00FFFFFFAAAA00FFFFFF00AAAAFFFFFF00FFFF55FF0000AA00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
55555500FFFF0000AA00000000FFFFFF00000000AA0000FFFF0055555555FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAFFFFAAAAAAAAFFAA00550000FFFFFF00005500AAFFAAAAAAAAFFFFAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00AA000000000000AAFFAAFFAAAAAAAAAAFFAAFFAA000000000000AA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5555555555555555FFAA00000000000000AAFF5555555555555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFFAAFFFFAAFF555555555555555555FFAAFFFFAAFFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00AA000000AA00FFFFAAFFFFAAFFFFAAFFFF00AA000000AA00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000055000000FFFF00AA000000AA00FFFF00000055000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00005500FF0000FFFF000000FF000000FFFF0000FF00550000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000055FFFF0000FFFF00005500550000FFFF0000FFFF550000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFF000055FFAA5500AA00005500FF00550000AA0055AAFF550000FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00AA0055AA55FF55000000FF0055005500FF00000055FF55AA5500AA0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
55FF55FF00AAAAAA00550000AA555555AA00005500AAAAAA00FF55FF55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAA5555000000000055FFFF5555AA5555FFFF5500000000005555AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00AAAA0055AA005500FFFF0055FF5500FFFF005500AA5500AAAA00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF5555FFFFAA0055FFFFFFFF550055FFFFFFFF5500AAFFFF5555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAFF55AAAAFFFFFFFF00FF55FF00FFFFFFFFAAAA55FFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00AA00AAFF00FFFFFFFF55AA55FFFFFFFF00FFAA00AA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFAA550055550055FF550055550055AAFF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000055AAFF005500FF55FF00FF55FF005500FFAA550000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000055FF55AA00AA55FF00FF00FF55AA00AA55FF550000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF55FF00FF555555FF00FF00FF00FF555555FF00FF55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0055555500FF550055AAFFAA550055FF0055555500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF5500FF55FFAAFFAAFF00FFAAFFAAFF55FF0055FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAAAA000000AAFF55FFAA000000AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00AAFF0000FF00AA00AA00FF0000FFAA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55550000FFFF555555FFFF00005555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFAAAAAAAA00AAAAAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00AA00FFAA00FF00AAFF00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000005555FFFFFF5555000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000055AA5555005555AA550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000055FF5500FF0055FF550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FF55AA550055AA55FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55FFAAFF005500FFAAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA55AAFFAAFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00AAAA55FF55AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5555FF00FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AA00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.53644 0.39418 1.62375 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF
FFFF0055555555AAAAAAAA55AAAA00AAAA55AAAAAAAA5555555500FFFFFF00FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAAAA
AAAAAAFFFFAAFF0000FF000000FF55FF000000FF0000FFAAFFFFAAAAAAAAAAFF55FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA5555
55AA55005500FFFF55FFAAAAFFAA55AAFFAAAAFF55FFFF00550055AA555555AAFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA55AA
AA5555FFFFAAAAAAAA55FF000055FF550000FF55AAAAAAAAFFFF5555AAAA55AA55FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAA55
00FFAAFF55AA55555555FFAAAAFFFFFFAAAAFF55555555AA55FFAAFF0055AAAA00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA
FFAA55000000FFAAFFFFAA5500FFFFFF0055AAFFFFAAFF00000055AAFFAA0055FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
0000FFAAAAFFAA5500555555FFFFFFFFFF5555550055AAFFAAAAFF0000AAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055
FFFF55AA555500FFAAAA55AAAAAAAAAAAAAA55AAAAFF005555AA55FFFF5500FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
55000000FFAAFFAA555555FF0055AA5500FF555555AAFFAAFF0000005555FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
AAFFAAAAFF550000FFAAFFFFFF555555FFFFFFAAFF000055FFAAAAFFAA00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
550000FF55AAAAFFAA5555005555FF5555005555AAFFAAAA55FF000055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAFF5555555500FFAAFFAAFFFFFFAAFFAAFF0055555555FFAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0055FFAAFF00AAFFAA550000FFFFFF000055AAFFAA00FFAAFF5500FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF555500FFFF550055FF55FFFFFFFFFF55FF550055FFFF005555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAFFAA55FF55FF55AAAAAAAAAAAAAA55FF55FF55AAFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00555555FFAAFF5555AA555555AA5555FFAAFF55555500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF5555FF55AA55FF555555FF555555FF55AA55FF5555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00AAFF5555AAAAAA55AAAAAA55AAAAAA5555FFAA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF5500000000FF000000FF000000FF0000000055FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFAAAAFFAAAAAAFFAAAAAAFFAAAAAAFFAAAAFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55AA00555555555500FF00555555555500AA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00AAAAFFFFAAFFFFAAAAAAFFFFAAFFFFAAAA00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF5500FFFF00555500FF00555500FFFF0055FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAAAFFFFAAAAAAFFFFAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF0055FF00005500FF00550000FF5500FFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55AAFFAAFF55FFFFAAAAAAFFFF55FFAAFFAA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00AAAAAA0000005555AA5555000000AAAAAA00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF5500AAAAFFAAAA55AA55AAAAFFAAAA0055FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA005500FF555555FF005500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0055FFFFAAAAAA55AAAAAAFFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55550000FF000000FF00005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00AAFFAAAAAAFFAAAAAAFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF550000FF005500FF000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAFF55FF55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055AAFF00FFAA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5555AAFFAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FF55FF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFF55AAAAAA55FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55AAFF5555AA5555FFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00AAAAAA55AA55AAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5500FF555555FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFAAAAAA55AAAAAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55AA0055FF5500AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00AAAAFFFFFFAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5500FFFFFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.53644 0.588183 1.62375 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FF0055FFFF
AA00AA00AAAAAA00FF5500AAAAAAFFAAAAAA0055FF00AAAAAA00AA00AAFFFF5500FF0055
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFF00
FF00AA55AA00AA55AAFFFF5500AAAAAA0055FFFFAA55AA00AA55AA00FF00FFFFAAAAAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055FFAA55
AAFF0000AA55AA0000FFFFFFAAAA00AAAAFFFFFF0000AA55AA0000FFAA55AAFF550000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF0000
AAAAAAFF0000AAAAFF00FFFF0055FF5500FFFF00FFAAAA0000FFAAAAAA0000FFFFAA00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAAAA55
AA00AAAAAAFF0055FFAAAAAAAAFFFFFFAAAAAAAAFF5500FFAAAAAA00AA55AAAAAAAA00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FF0000
AA55AA00AAAAAAFFFF005500AAAAAAAAAA005500FFFFAAAAAA00AA55AA0000FF0055FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF
005555AAAA00AAAAAAAAFFFF5500FF0055FFFFAAAAAAAA00AAAA555500FFAAAAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000055FF
AA0000AAAA00FF0000FF00FFFFAAAAAAFFFF00FF0000FF00AAAA0000AAFF550000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF
0000000055FFFFFF55FFAAAAAAAA00AAAAAAAAFF55FFFFFF5500000000FFFFAA00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAA
AA55AAAAFFFFFFFFFFAA555555AA55AA555555AAFFFFFFFFFFAAAA55AAAAAAAA00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA
555500AAAAAAAAAAAAAA0000AA00AA00AA0000AAAAAAAAAAAAAA005555AA0055FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00
AA000000FF00005500AAAA55AA00FF00AA55AAAA00550000FF000000AA00AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFAAAAFF55FFFFAA00550055FFFFFF55005500AAFFFF55FFAAAAFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA
FFAA5555AAFFFFFF000000AAFFFFFFFFFFAA000000FFFFFFAA5555AAFFAA00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA
AAAA0000AAAAAAAAAAFF00AAAAAAAAAAAAAA00FFAAAAAAAAAA0000AAAAAA00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
00AA55AAAA005500AAAAAA555555AA555555AAAAAA005500AAAA55AA0055FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAA000055FFFFAA0055AA0000AA00AA0000AA5500AAFFFF550000AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0055AAAAFFFFFF000000AAAAFF000000FFAAAA000000FFFFFFAAAA5500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00AA00AAAAAAAAAAFFAA00AAAAAA55AAAAAA00AAFFAAAAAAAAAA00AA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00AAAA5555AA00AAAAAA00FF5500AA0055FF00AAAAAA00AA5555AAAA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00AAAA0000AA55AA0055FFFFFFAA00AAFFFFFF5500AA55AA0000AAAA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5500FFAA00AA00AAFFFFFFFF000000FFFFFFFFAA00AA00AAFF0055FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAAA00FF00AAAAAAAAAAAA55AAAAAAAAAAAA00FF00AAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000055FFFFFF550000FF5500AA0055FF000055FFFFFF550000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00AAFFFFFFFFFFAA00FFFFAA00AAFFFF00AAFFFFFFFFFFAA00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00AAAAAAAAAAAAAA00FFFF000000FFFF00AAAAAAAAAAAAAA00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5500AA55000055AAAAAAAAFFAAAAAAAA55000055AA0055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAA00000000AA5500AAAAAA0055AA00000000AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0055AAAAFFAAAA000000FF000000AAAAFFAAAA5500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00AA00AAAAAA00AAFFAAAAAAFFAA00AAAAAA00AA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00AAAA5500FF00AAAAAA00AAAAAA00FF0055AAAA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF5500AA00FFFF5500AA55AA0055FFFF00AA0055FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAA00FFFFFFAA00AA00AAFFFFFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0055AAAAAAAAAA00FF00AAAAAAAAAA5500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00AA00AAAA0055FFFFFF5500AAAA00AA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00AAAA5500AAFFFFFFFFFFAA0055AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00AAAA000000FFFFFFFFFF000000AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5500FFAA00FFFFFFFFFF00AAFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAAA00FFFFFFFFFF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000055FFFFFFFFFFFFFF550000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00AAFFFFFFFFFFFFFFFFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00AAAAAAAAAAAAAAAAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5500FF0000550000FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAAFFAAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55FFAAAAAAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.53644 0.782187 1.62375 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF5500AAFF550000000000FFAAFFFFFFFF000000FFFF00FFFFFFFFAAAAFF5555AA00FFFF
55FF00FFAAFFFFAA555555000055FF550000555555AAFFFFAAFF00FF55FFFF00AA5555FF
AAAAFFFFFFFF00FFFF000000FFFFFFFFAAFF000000000055FFAA0055FF
FFFFAAAAAA00000000000000FFFFFFFFFFFF55FFFFFFFF555555FF00FFFFFFAAFF55FF00
5555FFFFFF0055FFAAFFFFAAAAFFFFFFAAAAFFFFAAFF5500FFFFFF555500FF55FFAAFFFF
FF00FF555555FFFFFFFF55FFFFFFFFFFFF00000000000000AAAAAAFFFF
FFFFFF00FFFF55FFFF55FFFF5555555555555500AAAA00AA0000AAAAFF00AAFF550055FF
FFAAFF00AAAAFFFFFF0055AAFF555555FFAA5500FFFFFFAAAA00FFAAFFFF550055FFAA00
FFAAAA0000AA00AAAA0055555555555555FFFF55FFFF55FFFF00FFFFFF
FFFFFFFF5500AA00AAFFFFFFFFAAFFFFAAFFFFAAAAAAAAFF55FFFF00FFAAAAAA000000AA
FF00FF55FFAA555555FFFFAA5555005555AAFFFF555555AAFF55FF00FFAA000000AAAAAA
FF00FFFF55FFAAAAAAAAFFFFAAFFFFAAFFFFFFFFAA00AA0055FFFFFFFF
FFFFFFFFFFAAAAAAFF555555AAAAAA00FFFFFFFF00FFFF00AA0055FFFFFF00FFFF55FFFF
0000005555FFAAFFFFAA00FFFFAAFFAAFFFF00AAFFFFAAFF5555000000FFFF55FFFF00FF
FFFF5500AA00FFFF00FFFFFFFF00AAAAAA555555FFAAAAAAFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFAAFFFF00FFFF5555FF000000FFAAAAAAFFFFFFFFFF5500AA00FF
AAAAFFAAFFFFFF0000FFFF5500FFFFFF0055FFFF0000FFFFFFAAFFAAAAFF00AA0055FFFF
FFFFFFAAAAAAFF000000FF5555FFFF00FFFFAAFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF5500AAFF55000000FFAAFFFFFF55FFFFFF00FFFFFFFFFFFFFFAAAAAAFF
00FFFFFF0000FF55FFFFFFFFAAAA00AAAAFFFFFFFF55FF0000FFFFFF00FFAAAAAAFFFFFF
FFFFFFFF00FFFFFF55FFFFFFAAFF00000055FFAA0055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAAA0000000000FFFFFFFFFFAA0055FFFFFFFFFFFFFFFFFF00FFFF
FF5555FF55FFFFFFAA0055FF55AAFFAA55FF5500AAFFFFFF55FF5555FFFFFF00FFFFFFFF
FFFFFFFFFF5500AAFFFFFFFFFF0000000000AAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF55FFFF55FF555555AAAAAAFFFFFFFFFFFFFFFFFFFFFF5500
FFAAFFFFFFAA00AAAAAAFFFFFFAA55AAFFFFFFAAAAAA00AAFFFFFFAAFF0055FFFFFFFFFF
FFFFFFFFFFFFAAAAAA555555FF55FFFF55FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5500AA00AAFFFFFFAAFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFAA
AA55FF5555FFAAAAAAAAAA5555FFAAFF5555AAAAAAAAAAFF5555FF55AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFAAFFFFFFAA00AA0055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAAAFF555555AAFF000000FFAA00AAAA550000FF0000FF55
AAFFFFFFAAFF00FFFF00FFFFAAFF00FFAAFFFF00FFFF00FFAAFFFFFFAA55FF0000FF0000
55AAAA00AAFF000000FFAA555555FFAAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFAAFFFF0000000000FFFF55AAFFFF55FF55FFFFFF
AA55AA00FFFFFF5555FFFFFFFF000000FFFFFFFF5555FFFFFF00AA55AAFFFFFF55FF55FF
FFAA55FFFF0000000000FFFFAAFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF5500AAFF5500000000000000FFAAFF5500AA0055555555
FFAAFF55FF5555550055AA00AAAAFFAAAA00AA5500555555FF55FFAAFF5555555500AA00
55FFAAFF0000000000000055FFAA0055FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA000000000000000000FFFFFFAAAAAAFFFFAAFF
FFFF0000AAFFFFAAFFAAFF55FFAA55AAFF55FFAAFFAAFFFFAA0000FFFFFFAAFFFFAAAAAA
FFFFFF000000000000000000AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF55FFFF55FFFF55FFFFFFFFFF00FFFFFFFF00
55FF55FFFF0000FFFFFF005555FFAAFF555500FFFFFF0000FFFF55FF5500FFFFFFFF00FF
FFFFFFFF55FFFF55FFFF55FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA00AAFFFFFFFFAA005500FF55FF555555FF
FFAA000055FFFF555555FFFFAAFF00FFAAFFFF555555FFFF550000AAFFFF555555FF55FF
005500AAFFFFFFFFAA00AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF555555AAAAAAFFFF55550000AA0000
55FFAAAAFFFFFFFFAAFFFFFFFF000000FFFFFFFFAAFFFFFFFFAAAAFF550000AA00005555
FFFFAAAAAA555555FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFAAFFFF00FFFFFFFFAAFFAAAAAAFF
AAFF00FFFFFFFFFFFF0000550000000000550000FFFFFFFFFFFF00FFAAFFAAAAAAFFAAFF
FFFFFF00FFFFAAFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAFF55000000FFAA00FFFFFF00FFFF
FF00000055FF5555FF55FFFFAAAAFFAAAAFFFF55FF5555FF55000000FFFFFF00FFFFFF00
AAFF00000055FFAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA0000000000FFFF555555FFFFFF
FFFF55FFFFAA0000AAFFFFFFFF00FF00FFFFFFFFAA0000AAFFFF55FFFFFFFFFF555555FF
FF0000000000AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF55FFFF55FF5555005555FF55
0000555555FFAAAAFF55000055FFFFFF55000055FFAAAAFF555555000055FF5555005555
FF55FFFF55FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA00AAFFFFFFAAFFAAFFFFFF
AAAAFFFFAAFF00FFFFFFAAAAFFFFFFFFFFAAAAFFFFFF00FFAAFFFFAAAAFFFFFFAAFFAAFF
FFFFAA00AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF555555AAFF00FFAA00
FFFF0000FFFFFF555555AAFF5555FF5555FFAA555555FFFFFF0000FFFF00AAFF00FFAA55
5555FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFAAFFFF000000FFFF
5555FFFF5500AAFFFFAAFF55550055005555FFAAFFFFAA0055FFFF5555FFFF000000FFFF
AAFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAFF550000000000FF
AAFFFFFFFFAAAAAA00FFFFFFAAFFAAFFAAFFFFFF00AAAAAAFFFFFFFFAAFF000000000055
FFAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00000000000000
FFFFFFFFFFFF00FFFF555555AAFF00FFAA555555FFFF00FFFFFFFFFFFF00000000000000
AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF55FFFF55FFFF
5500AAAA0055FFFFFFFFAAFFFF000000FFFFAAFFFFFFFF5500AAAA0055FFFF55FFFF55FF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA00AAFFFFFF
FFAAAAAAAAFFFFFFFFFFFF00AAAAFFAAAA00FFFFFFFFFFFFAAAAAAAAFFFFFFFFAA00AA00
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF555555
AAAAAAAAAAAA00FF555555FFFF00FF00FFFF555555FF00AAAAAAAAAAAA555555FFAAAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFAAFF
FF00FFFF00FFFF555500555555FFFFFF555555005555FFFF00FFFF00FFFFAAFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAFF55
00000055FFFFFFFFAAFFAAFFFFAA00AAFFFFAAFFAAFFFFFFFF5500000055FFAA0055FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00
00000000AA55AA00FFFFFF00AAFF55FFAA00FFFFFF00AA55AA0000000000AAAAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
55FFFF55FFAAFF55FF00AAAAFF550055FFAAAA00FF55FFAAFF55FFFF55FFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500
AA00AAFFFFFF005555FFFF00FFAAFFAAFF00FFFF555500FFFFFFAA00AA0055FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAAAFF555555FFFFAAFF000000FFFFFF000000FFAAFFFF555555FFAAAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFAAFFFFFFFF0000000000FF0000000000FFFFFFFFAAFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5500AAFF555555FF55FFFF55FFFFFF55FFFF55FF555555FFAA0055FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAAA0000AA00AA00AAFFFFFFFFFFAA00AA00AA0000AAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFF55FFAAAAAAFF5555FF5555FFAAAAAAFF55FFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF5500AA00FFFF00FFAAFFFFFFAAFF00FFFF00AA0055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAAFF000000FFFFFFFFFF000000FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF55FFFFFFFFFFFFFF55FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5500AAFFFFFFFFFFFFFFFFFFAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAAA00FF555555FF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF5555005555FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5500AA000000AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.53644 0.97619 1.62375 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF550000005555AAFFFFFFAAFF00AAFFFFFFAAAA00FF55AAAAAA55FF0000005500AAFFAA
AAFFFFFF55AAFF55FFFF00FFFF555555FFFF00FFFF55FFAA55FFFFFFAAAAFFAA00550000
00FF55AAAAAA55FF00AAAAFFFFFFAA00FFAAFFFFFFAA555500000055FF
FFFFAAAAFFAAFFFF0055FF55AAAAFF5555AAAAAAAAFF0000550000FFAAAAFFAAFFAA55AA
FF5500FFAAFF555555FF55FF5555555555FF55FF555555FFAAFF0055FFAA55AAFFAAFFAA
AAFF0000550000FFAAAAAAAA5555FFAAAA55FF5500FFFFAAFFAAAAFFFF
FFFFFF00FFAA55AAAAFFFFFFAA55FF000000550000AAAAFFAAFFAAAA0000AAAAAA0000FF
FFFFAAAA55FF0000FF00AA55555555555555AA00FF0000FF55AAAAFFFFFF0000AAAAAA00
00AAAAFFAAFFAAAA000055000000FF55AAFFFFFFAAAA55AAFF00FFFFFF
FFFFFFFF550000005555AA55AAFFFFFF55FFFFAAAAFF55AA55FF55AAFFAAAAAAAAAAFFAA
00FF55AAFFFFFF55FF55FFAAFFFFAAFFFFAAFF55FF55FFFFFFAA55FF00AAFFAAAAAAAAAA
FFAA55FF55AA55FFAAAAFFFF55FFFFFFAA55AA555500000055FFFFFFFF
FFFFFFFFFFAAAAFFAAFFFF0000AAAA00AA5555AAFF55555500AAFFFF00555500005555AA
FFAA005555FF5500AAFFFFFF00AAAAAA00FFFFFFAA0055FF555500AAFFAA555500005555
00FFFFAA00555555FFAA5555AA00AAAA0000FFFFAAFFAAAAFFFFFFFFFF
FFFFFFFFFFFF00FFAA55AAAAFFAA55FFFF000000AAFFFFAAFFAA55AAAAFFFFAAAAFFFFAA
55AAFFAAFFFFFFAAAAAA00FFAAAAAAAAAAFF00AAAAAAFFFFFFAAFFAA55AAFFFFAAAAFFFF
AAAA55AAFFAAFFFFAA000000FFFF55AAFFAAAA55AAFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF550000005555AAFFFFFFFF55FFFF00AAAAAA000000AA00FFAA55FF00AA
005500FFFFFFFFFF00FFFF55550055005555FFFF00FFFFFFFFFF005500AA00FF55AAFF00
AA000000AAAAAA00FFFF55FFFFFFFFAA555500000055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAFFAAFFFF0055FF555555FF55FFAA55FFFF55FFAAAA0000FFAAAA
AAFFFF5555FF5555FFFFFFFFAAFFAAFFAAFFFFFFFF5555FF5555FFFFAAAAAAFF0000AAAA
FF55FFFF55AAFF55FF555555FF5500FFFFAAFFAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFAA55AAAAFFFFFFAAFFFFFFAA0000FF555555AAFF55FFFFFF00
FFFFFFFFAAFF0000FF5555FF55AAAAAA55FF5555FF0000FFAAFFFFFFFF00FFFFFF55FFAA
555555FF0000AAFFFFFFAAFFFFFFAAAA55AAFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF550000005555AA55AAFF0055FFAAAAFF000000FFFFFFAA00FF55
FF5555AA55FF55FFFFFFAAFF0000550000FFAAFFFFFF55FF55AA5555FF55FF00AAFFFFFF
000000FFAAAAFF5500FFAA55AA555500000055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFFAAFFFF0000AAAAFFFFFF00FF55FFFF5555AA55FFFFFF
AA0055AAFFFFFFAA00FF55AAAAFFAAFFAAAA55FF00AAFFFFFFAA5500AAFFFFFF55AA5555
FFFF55FF00FFFFFFAAAA0000FFFFAAFFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFAA55AAAAFFAA55FF5555FFFFFFAA00FF0000AA55AAAA
55FFFFAA55AAAA55FFFFFFAA55FF00FF55AAFFFFFF55AAAA55AAFFFF55AAAA55AA0000FF
00AAFFFFFF5555FF55AAFFAAAA55AAFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF550000005555AAFFFFFFAAFF00AAFF55FF55FFFF000055
00AAAA000000AA0055FF555500AAFFAA005555FF5500AA000000AAAA00550000FFFF55FF
55FFAA00FFAAFFFFFFAA555500000055FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAAFFFF0055FF55AAAAFF555555AA00FF55FFFF
AAAAAAAAFFAAAAAAFFFFFFAAFFAA55AAFFAAFFFFFFAAAAAAFFAAAAAAAAFFFF55FF00AA55
5555FFAAAA55FF5500FFFFAAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA55AAAAFFFFFFAA55FF000000FFFF555555FF
55AAFF55AAAAAAAAAA5555AAFF00FF00FFAA5555AAAAAAAAAA55FFAA55FF555555FFFF00
0000FF55AAFFFFFFAAAA55AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000005555AA55AAFFFFFF55FFFFFFFFAAFFFF
FFAA5555550000AA0000000055FFFFFF5500000000AA0000555555AAFFFFFFAAFFFFFFFF
55FFFFFFAA55AA555500000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAAFFFF0000AAAA00AA5555AAAA55FF55
55AAFFFFAAFFAAAAAAFFAAAAFFFFFFFFFFAAAAFFAAAAAAFFAAFFFFAA5555FF55AAAA5555
AA00AAAA0000FFFFAAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA55AAAAFFAA55FFFF0000005500AAFF
FFAA55AAAAAA00005555FFAA5555AA5555AAFF55550000AAAAAA55AAFFFFAA0055000000
FFFF55AAFFAAAA55AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000005555AAFFFFFFFF55FFFFAAAAAA
00FFFFAA55FFAAAAFFFFAA0000FF00FF0000AAFFFFAAAAFF55AAFFFF00AAAAAAFFFF55FF
FFFFFFAA555500000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAAFFFF0055FF555555FF55AAFF
55FF005500AAAAAAAA00FFFF55FF55FF55FFFF00AAAAAAAA005500FF55FFAA55FF555555
FF5500FFFFAAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA55AAAAFFFFFFAAFFFFFFAA55
5555FFFFAAAAAAAAAAAAFF00AA555555AA00FFAAAAAAAAAAAAFFFF555555AAFFFFFFAAFF
FFFFAAAA55AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000005555AA55AAFF0055FFAA
FFFFAA00AA000055005555FFFF000000FFFF555500550000AA00AAFFFFAAFF5500FFAA55
AA555500000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAAFFFF0000AAAAFFFFFF
0055FFAAAAAAFFAAFFAAFFFFFFFF55FFFFFFFFAAFFAAFFAAAAAAFF5500FFFFFFAAAA0000
FFFFAAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA55AAAAFFAA55FF00AA
AAFFFFFF00FFFFFF005555AAAA00FF00AAAA555500FFFFFF00FFFFFFAAAA00FF55AAFFAA
AA55AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000005555AAFFFFFF55
AAFF00AAAAFF00AAAAFFFFAA55FFFFFF55AAFFFFAAAA00FFAAAA00FFAA55FFFFFFAA5555
00000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAAFFFF0055FF00
00AAAAFF55AAAAFF55AA55AAFFFFFFFFFFAA55AA55FFAAAA55FFAAAA0000FF5500FFFFAA
FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA55AAAAFFFFFF
55FFAA55AA0000AAFFFF0000AAAA00AAAA0000FFFFAA0000AA55AAFF55FFFFFFAAAA55AA
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000005555AA55
5555FFAAFF55FFFF0055FFFF55AAFFAA55FFFF5500FFFF55FFAAFF555555AA5555000000
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAAFFFF00
0000FFAA555555AAAAFFFFFFFFAA55AAFFFFFFFFAAAA555555AAFF000000FFFFAAFFAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA55AAAA
FFAAAA00000000005500FF5555FFAAFF5555FF00550000000000AAAAFFAAAA55AAFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500000055
55AAFF55FFFF55FFFFAAAA5500AAAAAA0055AAAAFFFF55FFFF55FFAA555500000055FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAA
FFFF0055AA555555FF00FFFFAAAAAAAAAAFFFF00FF555555AA5500FFFFAAFFAAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA
55AAAAFFFF000000FF55FF00555500555500FF55FF000000FFFFAAAA55AAFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500
00005555AAAAFFAAAA0055FFFFAAFFAAFFFF5500AAAAFFAAAA555500000055FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAFFAAFFFF00FFAA55FFFFAA00AA00AA00AAFFFF55AAFF00FFFFAAFFAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFAA55AAAAFF00FF00AAAAAAFF55FFAAAAAA00FF00FFAAAA55AAFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF550000005555FFFFFF55AAFF555555FFAA55FFFFFF555500000055FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAFFAAFFFFFFFFFFAA5555555555AAFFFFFFFFFFAAFFAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFAA55AA55AA55AAFFFFAAFFFFAA55AA55AA55AAFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF5500000055AAFFFF00AAAAAA00FFFFAA5500000055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAFFAAFF5555FFFF00FFFF5555FFAAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFAA55555555FF55FF55555555AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF550000000000FFAAFF000000000055FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAFFAAAAFF00FFAAAAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFAA55FF55FF55AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF550000FFAAFF000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFF00FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.63248 0.200176 1.71979 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF5555005500000000FF000000AAFF0055AAFFAAAAFF00555555FFAA00FFAA0000AA55AA
00AAAA55000000AAAA55AAAAAAFF00FFAAAAAA55AAAA00000055AAAA00AA55AA0000AAFF
00AAFF55555500FFAAAAFFAA5500FFAA000000FF0000000055005555FF
FFFF55FFAAAAAAAAAAAA0000AA0055FFAAAA55555555AAFFFFAAAA005555AA0000AAFFAA
0000FFAAAAAAAAAA550000FF00AAAAAA00FF000055AAAAAAAAAAFF0000AAFFAA0000AA55
5500AAAAFFFFAA55555555AAAAFF5500AA0000AAAAAAAAAAAAFF55FFFF
FFFFFF5500AAFF00000000AA00FFFF5500AAFFAAFFAAFF0055FF5555000055AAFF5555AA
AAAAAA00FF0000FFAAAAAAAA0000000000AAAAAAAAFF0000FF00AAAAAAAA5555FFAA5500
005555FF5500FFAAFFAAFFAA0055FFFF00AA00000000FFAA0055FFFFFF
FFFFFFFF55AA00AA0000AA00FFFFFFFF55AA00AA555555AAFFFFFFAAAAAAAAFF00550000
00000000AAAAAAAA00FF0000FFFF00FFFF0000FF00AAAAAAAA0000000000005500FFAAAA
AAAAFFFFFFAA555555AA00AA55FFFFFFFF00AA0000AA00AA55FFFFFFFF
FFFFFFFFFF555500AA000000AAAA00AAAAFF00FFAAFFAAFF0055FF00AAFF00AAAAAAFF55
AAFF55AAFF00000000AAAAAAAA00AA00AAAAAAAA00000000FFAA55FFAA55FFAAAAAA00FF
AA00FF5500FFAAFFAAFF00FFAAAA00AAAA000000AA005555FFFFFFFFFF
FFFFFFFFFFFF55FFAA0000AA00FF00FF00AAAAAA00FF5555AAFFFFFF00AAAAAA5500AAAA
FF005500AAAAAAAAAAAA5500AA55FF55AA0055AAAAAAAAAAAA005500FFAAAA0055AAAAAA
00FFFFFFAA5555FF00AAAAAA00FF00FF00AA0000AAFF55FFFFFFFFFFFF
FFFFFFFFFFFFFF5500AA000000AAAAAA0000FF0000AAAAFFAA00AAAA0000FF0000555555
55AAFFFF000000000000005555FFFFFF555500000000000000FFFFAA555555550000FF00
00AAAA00AAFFAAAA0000FF0000AAAAAA000000AA0055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55AA0000AA0055AAAAAAAA0000AA5500FF00FFAA0000AAAAAAAAFFAA
FFAA00AAAAAAAAAAAAAAAAAAFFFFFFFFFFAAAAAAAAAAAAAAAAAA00AAFFAAFFAAAAAAAA00
00AAFF00FF0055AA0000AAAAAAAA5500AA0000AA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55550055AAFFAA0055AA0000AAFFFF005555AA0000AA55AAAA5555
55AA0000FF0000000000FF00AAAA00AAAA00FF0000000000FF0000AA555555AAAA55AA00
00AA555500FFFFAA0000AA5500AAFFAA55005555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55FFAAAA5555550000FFFF00AAAA00005500AA00000055AAAAFF
FFAA0000AAAAAAAAAAAAAA0000FF00FF0000AAAAAAAAAAAAAA0000AAFFFFAAAA55000000
AA00550000AAAA00FFFF0000555555AAAAFF55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5500AAFFFFAAAAAAAA00AA00FF00FFFF55AAAAAAAAAAFF00AA
AA00FFFF0000000000000000AA00AA00AA0000000000000000FFFF00AAAA00FFAAAAAAAA
AA55FFFF00FF00AA00AAAAAAAAFFFFAA0055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AA00AAAA55AA0055555500FFFFFFFF555555555555AAFF
00AA00AAAAAAAAAAAAAAAAAAAA55FF55AAAAAAAAAAAAAAAAAAAA00AA00FFAA5555555555
55FFFFFFFF0055555500AA55AAAA00AA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555500AAFFAA0000550000AAAA00AAAAFFAAFFAAFFAA00
AA005555555555555555555555FFFFFF555555555555555555555500AA00AAFFAAFFAAFF
AAAA00AAAA0000550000AAFFAA005555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA00AA55FFAAAAAAAA550055AA00AA555555AA00
00FFFFAAAAFFAAAAFFAAAAFFAAAA00AAAAFFAAAAFFAAAAFFAAAAFFFF0000AA555555AA00
AA550055AAAAAAAAFF55AA00AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA005500FFAA00FFAAAAAAFF00FFAAFFFFAA00
00AAAA00FF0055AA00AA5500FF00AA00FF0055AA00AA5500FF00AAAA0000AAFFFFAAFF00
FFAAAAAAFF00AAFF005500AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00005555AAAAAA00FF00AAAAAA00FF5500AA
00000000AAAAAAFF00FFAAAAAA000000AAAAAAFF00FFAAAAAA00000000AA0055FF00AAAA
AA00FF00AAAAAA55550000AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555005500000000FFFFFF000000FFFFFF55AA
AAAAAAAAAA5500AAAAAA0055AAAAAAAAAA5500AAAAAA0055AAAAAAAAAAAA55FFFFFF0000
00FFFFFF0000000055005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAAAAAAAAAAAA00AAAAAAAAAA00AAAAFF
0000000000005555555555000000000000005555555555000000000000FFAAAA00AAAAAA
AAAA00AAAAAAAAAAAAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAFF00000000AAFF00AA55AAFF00AA
AAAAAAAAAAAAAAFFAAFFAAAAAAAAAAAAAAAAAAFFAAFFAAAAAAAAAAAAAAAA00FFAA55AA00
FFAA00000000FFAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00AA0000AA00FF55AAAAFF005555
5555555555555555AAAA00FF0000000000FF00AAAA5555555555555555555500FFAAAA55
FF00AA0000AA00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500AA000000AAAAFF00AAAAAAFF
AAFFFFAAFFAAFFAAFF0000AAAAAAAAAAAAAA0000FFAAFFAAFFAAFFFFAAFFAAAAAA00FFAA
AA000000AA005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA0000AA00FF005555555555
AAAA00AA555555AAAA0000AAFF000000FFAA0000AAAA555555AA00AAAA555555555500FF
00AA0000AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA000000AAAAAAFFFFAAAA
FF0000AAFFAAFFAA00555500AAAAAAAAAA00555500AAFFAAFFAA0000FFAAAAFFFFAAAAAA
000000AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA0000AA0055AAAA00AAFF
00555500AAAA5555550000555555555555550000555555AAAA00555500FFAA00AAAA5500
AA0000AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55550055AAFFAA00555555
AAFFFFAA55AAAAFFAAAAAAAAFFAAFFAAFFAAAAAAAAFFAAAA55AAFFFFAA55555500AAFFAA
55005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAAAA555555000055
00AAAA005500AA555555555555AA00AA555555555555AA005500AAAA00550000555555AA
AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAFFFFAAAAAAAA
FF5555550000AAFFAAFFAAFFAAFF00FFAAFFAAFFAAFFAA0000555555FFAAAAAAAAFFFFAA
0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00AAAA55AA00
55FFFFAAFF55AA00AA5555FF00AAAAAA00FF5555AA00AA55FFAAFFFF5500AA55AAAA00AA
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500AAFFAA00
0055FF00AAAAFF00FFAAFFFFFF000000FFFFFFAAFF00FFAAAA00FF550000AAFFAA005555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA00AA55
FFAAAA0000FF005555AAAA00AAAAAAAAAA00AAAA555500FF0000AAAAFF55AA00AAFF55FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA0055
00FFAA0000AAAAAAFFAA005555555555555500AAFFAAAAAA0000AAFF005500AA0055FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA0000
5555AAAAAAAA55AAAA00FFFFAAAAFFAAAAFFFF00AAAA55AAAAAAAA55550000AA55FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500
5500000000FFAAFF00AA00AAAA55AA55AAAA00AA00FFAAFF0000000055005555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF
AAAAAAAAAAAA00FF55AAAAAA5500000055AAAAAA55FF00AAAAAAAAAAAAFF55FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
00AAFF000000FFFFFFAA00FFAAAAAAAAAAFF00AAFFFFFF000000FFAA0055FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
55AA00AA0000AAAA00AA55FF0000000000FF55AA00AAAA0000AA00AA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF555500AA0000FF00FFAAAA0000AA0000AAAAFF00FF0000AA005555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF55FFAA0000AAAAAA00FFAA55FF55AAFF00AAAAAA0000AAFF55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5500AA000000FFAA5555FFFFFF5555AAFF000000AA0055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF55AA0000AA00AAFFAAAA00AAAAFFAA00AA0000AA55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55550055AAFF0055AAAAAA5500FFAA55005555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF55FFAAAA555500000000005555AAAAFF55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5500AAFFAAAAAAAAAAAAAAFFAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55AA00AAFF000000FFAA00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555500AAAAAAAAAA005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55FFAA00FF00AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5500AA00AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AAAAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.63248 0.39418 1.71979 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF555555000000FFFFFF5555FFAA0000FF0000AA5500FFFF00FF00AA55AAFFAA00000000
005500555555AAAA00005555555555555555550000AAAA55555500550000000000AAFFAA
55AA00FF00FFFF0055AA0000FF0000AAFF5555FFFFFF000000555555FF
FFFF55FFFF00FFFFFFFFFF55FF00AA55FF000000555555AA5500FF00AA00FF5555555555
555500AA0000AAFF000000AA0000AA0000AA000000FFAA0000AA0055555555555555FF00
AA00FF0055AA555555000000FF55AA00FF55FFFFFFFFFF00FFFF55FFFF
FFFFFF5500FF0055FF0055FFFFFF00AA00AA55FFAAFFFFAA0000FF55AAAAAA0000AA0000
AA00000055AA00FF55AA005500AA55AA005500AA55FF00AA55000000AA0000AA0000AAAA
AA55FF0000AAFFFFAAFF55AA00AA00FFFFFF5500FF5500FF0055FFFFFF
FFFFFFFF55AA550055FFAAAA00AAAAAA550000AAAA5555AAAAAAAA0000550000FF00AA55
0000000000AAFF55005500AA0055005500AA00550055FFAA000000000055AA00FF000055
0000AAAAAAAA5555AAAA000055AAAAAA00AAAAFF550055AA55FFFFFFFF
FFFFFFFFFF555500AA00AAFF0000550000AA550000555500005500000000AA5500FF00AA
0055AA0055AAAA000000AA55AA000000AA55AA000000AAAA5500AA5500AA00FF0055AA00
0000005500005555000055AA0000550000FFAA00AA005555FFFFFFFFFF
FFFFFFFFFFFF55FFAA005500FF0000AA550000AA55FFFF55AA000000000000555555AA00
FFFFAA005555FF55AAFF555500000000005555FFAA55FF555500AAFFFF00AA5555550000
00000000AA55FFFF55AA000055AA0000FF005500AAFF55FFFFFFFFFFFF
FFFFFFFFFFFFFF55000000AA55555555FFFF00FFAAAA00AA00FFFF0000000000AA000055
AA5555FFAAFFFFFFAA00AA00000000000000AA00AAFFFFFFAAFF5555AA550000AA000000
0000FFFF00AA00AAAAFF00FFFF55555555AA00000055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55AA00550055550055FF00FF5555FFAA0055FF00000000FF00AA5500
55005555AAAA00AAAA5500000000000000000055AAAA00AAAA555500550055AA00FF0000
0000FF5500AAFF5555FF00FF55005555005500AA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55555500AA000000AAAAAA0000AAAA55FFFFFF0000FFFFFF00AA00
55555500550000FFAA0000FF0000000000FF0000AAFF0000550055555500AA00FFFFFF00
00FFFFFF55AAAA0000AAAAAA000000AA00555555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55FFFF00AA55FFAA00FFAA55FF555500FF5500AA5555AA550000
00AA000000AA5500FFAA5500FF000000FF0055AAFF0055AA000000AA00000055AA5555AA
0055FF005555FF55AAFF00AAFF55AA00FFFF55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5500FF00AA00AAFF550000AAAAFFFF00555555FFFF555500AA
5500000000FFAAFF550000AA5555555555AA000055FFAAFF0000000055AA005555FFFF55
555500FFFFAAAA000055FFAA00AA00FF0055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AA5500000055FFFF00FFAA00AAAAAAFFAAAA00AA000000
555555555555AAAA000000FFAAAAFFAAAAFF000000AAAA555555555555000000AA00AAAA
FFAAAAAA00AAFF00FFFF5500000055AA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555500AA550055FF00FF555555FF5555AAAA550000FF00
00AA0000AA00005500AA5500FFAA00AAFF0055AA00550000AA0000AA0000FF000055AAAA
5555FF555555FF00FF550055AA005555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA000000AAAAAA0000AA00AA0000550055AA00AA
550000000055AA000000555555AAAAAA555555000000AA550000000055AA00AA55005500
00AA00AA0000AAAAAA000000AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000000000550000FF00AA55AA00555555000000
5555555555550000000000AA0000550000AA000000000055555555555500000055555500
AA55AA00FF000055000000000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA0055AA000000FF55AAAAFF0000AA00000000
00AA0000AA0000FF0000000055AAFFAA5500000000FF0000AA0000AA0000000000AA0000
FFAAAA55FF000000AA5500AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555000000FFFFFF5555FF00000055AAFF55
AA00FFFF00AA5500FFFF00FFFFAA00AAFFFF00FFFF0055AA00FFFF00AA55FFAA55000000
FF5555FFFFFF000000555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFF00FFFFFFFFFF55FF0000FFFFAA00AA
00FFFFFFFF00AA0055FF00FF5500000055FF00FF5500AA00FFFFFFFF00AA00AAFFFF0000
FF55FFFFFFFFFF00FFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FF0055FF0055FFFFFF00FF55000000
55AA5555AA55000000AAAAAA0000000000AAAAAA00000055AA5555AA5500000055FF00FF
FFFF5500FF5500FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA550055FFAAAA00AAAAAA00000000
00AAFFFFAA0000FF000055000000FF000000550000FF0000AAFFFFAA0000000000AAAAAA
00AAAAFF550055AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500AA00AAFF0000550000FFFF00
FF00AAAA00FFFF0055AA000000FFFFFF000000AA5500FFFF00AAAA00FF00FFFF00005500
00FFAA00AA005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA005500FF0000AA5500FF55
AA55000055AA555555000000FFFFFFFFFF000000555555AA55000055AA55FF0055AA0000
FF005500AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55000000AA55555555FFFF0055
55FFFF0000AAFFAAFFAA5500AAAA00AAAA0055AAFFAAFFAA0000FFFF555500FFFF555555
55AA00000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00550055550055FF0000
AA00AAAAAAAA5555FF00AA00550000005500AA00FF5555AAAAAAAA00AA0000FF55005555
005500AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555500AA000000AAAAAA
AA550000550000AA00AA55AA0000000000AA55AA00AA000055000055AAAAAAAA000000AA
00555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFF00AA55FFAA00FF
AA00000000AA55FF55AAAAFF0000000000FFAAAA55FF55AA00000000AAFF00AAFF55AA00
FFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FF00AA00AAFF55
0000000000FFAAAA00005500FF000000FF00550000AAAAFF000000000055FFAA00AA00FF
0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5500000055FF
FF00FF00FF005500000000AA5555555555AA000000005500FF00FF00FFFF5500000055AA
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500AA550055
FF00FF55AA550055AA0055AAAAFFAAFFAAAA5500AA550055AA55FF00FF550055AA005555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA000000
AAAAAA0000555555000000AAFF005500FFAA0000005555550000AAAAAA000000AAFF55FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500000000
005500000000AA0000FF000055FFAAFF550000FF0000AA0000000055000000000055FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA0055
AA00000000000055AA00AA550055FF550055AA00AA55000000000000AA5500AA55FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555
000000FF00000000AAFF555500AA00AA005555FFAA00000000FF000000555555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF
FF00FFFFFF0000000055FFFF55AAAAAA55FFFF5500000000FFFFFF00FFFF55FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
00FF0055FF0000FF0000AAAA0000550000AAAA0000FF0000FF5500FF0055FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
55AA550055FFAA55555555FF55AAFFAA55FF55555555AAFF550055AA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF555500AA00AAFFAAAAFFFFFFAA00AAFFFFFFAAAAFFAA00AA005555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF55FFAA005500FFAA00AAAA00FF00AAAA00AAFF005500AAFF55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55000000AA5555FFAA00FFFFFF00AAFF5555AA00000055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF55AA0055005555AAAAAA00AAAAAA5555005500AA55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55555500AA000055000000550000AA00555555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF55FFFF00AA55FFFF00FFFF55AA00FFFF55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5500FF00AA00AAAAAA00AA00FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55AA550000005500000055AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555500AA550055AA005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55FFAA000000AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF550000FF000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AA00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.63248 0.588183 1.71979 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF555555005555005555FFAAAAAAFFFFFFFFFF0055550055AAAAAAAA55005555FF000055
AA00FFFF0000FFFFFF0000FFAA555555AAFF0000FFFFFF0000FFFF00AA550000FF555500
55AAAAAAAA5500555500FFFFFFFFFFAAAAAAFF555500555500555555FF
FFFF5555FFAA00FFFF555500005500555500555555FFFF00AAAA00AAAA55FF555500AA55
AA550055555555005555555500000000005555555500555555550055AA55AA005555FF55
AAAA00AAAA00FFFF555555005555005500005555FFFF00AAFF5555FFFF
FFFFFF555500FFFFFFFFAA0055AAAAAAFF0000000000AA0055FF000055FFFFFF555555AA
AA00FFFF5555FFFF00AAFFAAAAAAAAAAAAAAFFAA00FFFF5555FFFF00AAAA555555FFFFFF
550000FF5500AA0000000000FFAAAAAA5500AAFFFFFFFF005555FFFFFF
FFFFFFFF55555500555500FFFF55000055555555555555AAFFFFFF000000AA0000000000
5500AA00000000AA00550055000055000055005500AA00000000AA00550000000000AA00
0000FFFFFFAA55555555555555000055FFFF00555500555555FFFFFFFF
FFFFFFFFFF5555FFAA00FFFFFFFF55AAFFAAFFFF5555FF5500555500AA550000FFFF0000
FFAA555555555555AAFFAA55AAFF55FFAA55AAFFAA555555555555AAFF0000FFFF000055
AA0055550055FF5555FFFFAAFFAA55FFFFFFFF00AAFF5555FFFFFFFFFF
FFFFFFFFFFFF555500FFFFFFFFFFFF550055005555FFFFFF55AAAA55FF00AA5500555555
5500000000000000005555AAAA000000AAAA55550000000000000000555555550055AA00
FF55AAAA55FFFFFF555500550055FFFFFFFFFFFF005555FFFFFFFFFFFF
FFFFFFFFFFFFFF555555005555005555FFAAAAAAFFFFFFFFFF55000000AA5555FFAAAAFF
AAAAAAAAAAAAAAAAAAAA55AA5555555555AA55AAAAAAAAAAAAAAAAAAAAFFAAAAFF5555AA
00000055FFFFFFFFFFAAAAAAFF555500555500555555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF5555FFAA00FFFF5555000055005555005555FFAA5500000000AAAA00
0055000055FF005500FF5555AAAAFFAAAA5555FF005500FF550000550000AAAA00000000
55AAFF5555005555005500005555FFFF00AAFF5555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555500FFFFFFFFAA0055AAAAAAFF00000000AAAA5500AA55000055
AA00FF000000AA55AA0000000055005500000000AA55AA000000FF00AA55000055AA0055
AAAA00000000FFAAAAAA5500AAFFFFFFFF005555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55555500555500FFFF550000555555555555AA55AA00AAFF55AA
AA005555555555AAAA0055AAFF555555FFAA5500AAAA555555555500AAAA55FFAA00AA55
AA555555555555000055FFFF00555500555555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5555FFAA00FFFFFFFF55AAFFAAFFFF5555FF00AAAAAA000000
5500AAFFFFAAAA5555AAFF005555FF555500FFAA5555AAAAFFFFAA0055000000AAAAAA00
FF5555FFFFAAFFAA55FFFFFFFF00AAFF5555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF555500FFFFFFFFFFFF550055005555FFFFFF0055FF00FFFF
00AA5555005500000000555555FFFFFF5555550000000055005555AA00FFFF00FF5500FF
FFFF555500550055FFFFFFFFFFFF005555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555005555005555FFAAAAAAFFFFFFFFFF00AA005555
00AAAA55AAFF00FFFF0000000000AA0000000000FFFF00FFAA55AAAA00555500AA00FFFF
FFFFFFAAAAAAFF555500555500555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFAA00FFFF555500005500555500555555AAFFAA
00550000005555550055AA0055AA00AA5500AA55005555550000005500AAFFAA55555500
5555005500005555FFFF00AAFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500FFFFFFFFAA0055AAAAAAFF00000000005555
AAFFFF00FFFFAAFFFF00AAAAAA555555AAAAAA00FFFFAAFFFF00FFFFAA55550000000000
FFAAAAAA5500AAFFFFFFFF005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555500555500FFFF55000055555555555555FF
5500555555005500555555AA5555FF5555AA5555550055005555550055FF555555555555
55000055FFFF00555500555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFAA00FFFFFFFF55AAFFAAFFFF5555FFFF
FF55AAAAFFFF00AA55AAAA5555FFFFFF5555AAAA55AA00FFFFAAAA55FFFFFF5555FFFFAA
FFAA55FFFFFFFF00AAFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500FFFFFFFFFFFF550055005555FFFFFF
FFFF550000AA0055FF5500000000AA0000000055FF5500AA000055FFFFFFFFFF55550055
0055FFFFFFFFFFFF005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555005555005555FFAAAAAAFFFFFFFF
FFFFFFAA55FF000000AAFF55AA005500AA55FFAA000000FF55AAFFFFFFFFFFFFFFAAAAAA
FF555500555500555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFAA00FFFF555500005500555500
55550055FFFFFF00FF005555FF000000FF555500FF00FFFFFF5500555500555500550000
5555FFFF00AAFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500FFFFFFFFAA0055AAAAAAFF00
FFAAFF55550055555500AAFFFFFF00FFFFFFAA00555555005555FFAAFF00FFAAAAAA5500
AAFFFFFFFF005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555500555500FFFF5500005555
550000AAFF00FFAAFFAA555500555555005555AAFFAAFF00FFAA0000555555000055FFFF
00555500555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFAA00FFFFFFFF55AAFFAA
FFFF00005555550000AAAAFF0000000000FFAAAA00005555550000FFFFAAFFAA55FFFFFF
FF00AAFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500FFFFFFFFFFFF550055
0055555555FFFFAA55000055555555555555000055AAFFFF5555555500550055FFFFFFFF
FFFF005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555005555005555FFAA
AAAAFFFF55550055FFFF000000000000000000FFFF55005555FFFFAAAAAAFF5555005555
00555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFAA00FFFF555500
0055005555FFFF00AA0000FF0000FF0000FF0000AA00FFFF5555005500005555FFFF00AA
FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500FFFFFFFFAA00
55AAAAAAFFFFFFFF0055AA0000FFFFFF0000AA5500FFFFFFFFAAAAAA5500AAFFFFFFFF00
5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555500555500FF
FF550000555500555555FF00FFFFFFFFFF00FF555555005555000055FFFF005555005555
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFAA00FFFF
FFFF55AAFFAAAAAAFF00AA00555500555500AA00FFAAAAAAFFAA55FFFFFFFF00AAFF5555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500FFFFFF
FFFFFF5500550000555555AAFFAAAAAAFFAA5555550000550055FFFFFFFFFFFF005555FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555550055
55005555FFAAAAAAAA55AAAA0000550000AAAA55AAAAAAAAFF555500555500555555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFAA
00FFFF55550000550000005500AA55AA00550000005500005555FFFF00AAFF5555FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500
FFFFFFFFAA0055AAAAAAAAAA5500000055AAAAAAAAAA5500AAFFFFFFFF005555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555
5500555500FFFF55000055000000FF00000055000055FFFF00555500555555FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
55FFAA00FFFFFFFF55AAFFFF00FFFFFF00FFFFAA55FFFFFFFF00AAFF5555FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
555500FFFFFFFFFFFF5500555555005555550055FFFFFFFFFFFF005555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF555555005555005555FFAAAAFF00FFAAAAFF555500555500555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF5555FFAA00FFFF5555000055555500005555FFFF00AAFF5555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF555500FFFFFFFFAAAAAAAA55AAAAAAAAFFFFFFFF005555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF555555005555000055000000550000555500555555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF5555FFAA00FF000000FF000000FF00AAFF5555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF555500FFFFFF00FFFFFF00FFFFFF005555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF555555005555550055555500555555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF5555FFAAAAFF00FFAAAAFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555000055555500005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55555555FF55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5555FFFFFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5555005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.63248 0.782187 1.71979 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000055AAFFAA5500FFFF
FFFF550000FF00FF00FF55FF55FFFFFF55FF55FF00FF00FF000055FFFFFFFF0055AAFFAA
55000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFFAA00AAFFFF5500
FFFFFFAAAAFF55FFAAAA005500AAAAAA005500AAAAFF55FFAAAAFFFFFF0055FFFFAA00AA
FFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55FF55AAFFFF
5500005555FFAAFF5555FFFFAAAA55AAAAFFFF5555FFAAFF5555000055FFFFAA55FF55FF
55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA555555AA00FFFF
FFAAAAFFFFAA55AAFFFFAA55FF555555FF55AAFFFFAA55AAFFFFAAAAFFFFFF00AA555555
AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF5555555555FFFF00
FF5555FFAA55AA00FFFF00AA5555555555AA00FFFF00AA55AAFF5555FF00FFFF55555555
55FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000000000FF00FF55
FF0000FF555555FFFFFFFF55555555555555FFFFFFFF555555FF0000FF55FF00FF000000
000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAAAAFF55FFAA
FF55FFFF000000FFFFFFFF000000FF000000FFFFFFFF000000FFFF55FFAAFF55FFAAAAFF
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF5555FFAA00FFFFAA55
AAFFFFFFFF55FFFFFFFFFFFF55FFFFFF55FFFFFFFFFFFF55FFFFFFFFAA55AAFFFF00AAFF
5555FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA55FF55FFAA55AA
00FFFFFFFFFFAA55FF00FF5500AAAAAA0055FF00FF55AAFFFFFFFFFF00AA55AAFF55FF55
AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA550000FF555555
FFFFFFFFFFFF00AA55FFFFFFAAAA55AAAAFFFFFF55AA00FFFFFFFFFFFF555555FF000055
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF55FF000000
FFFFFFFFFFFFFF555555AA55FF555555FF55AA555555FFFFFFFFFFFFFF000000FF55FFFF
AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAFFFFFF55FF
FFFFFFFFFFFFFF00000000AA5555555555AA00000000FFFFFFFFFFFFFFFF55FFFFFFAA55
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00550000FF
FFFF00FFFFFFFFFF55FFFF55555555555555FFFF55FFFFFFFFFF00FFFFFF00005500FFAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAFFFF55FF
AA55FFFFFFFFFFFFFFAA555555555555555555AAFFFFFFFFFFFFFF55AAFF55FFFFAAAA00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF00FF00
FFAAFF5500FFFFFF00555555555555555555555500FFFFFF0055FFAAFF00FF00FF5555FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF55FFAA
AA00FFFFAAAAAAAAAAFFFFAAFFFFAAFFFFAAFFFFAAAAAAAAAAFFFF00AAAAFF55FF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAAFF55
55FFFF00555500555500FF5555AA55AA5555FF00555500555500FFFF5555FFAAFF55FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFF
FFAA55FFFFAAFFAAFFFF55AA0055555500AA55FFFFAAFFAAFFFF55AAFFFFAA55AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AA
FF555555AA55AA55AA555555FFFFAAFFFF555555AA55AA55AA555555FFAA55AA00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555
000000FF00AA55AA00FF0000FF550055FF0000FF00AA55AA00FF000000555555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
FF55FFFFFF555555FFFFFF55FFAAFFAAFF55FFFFFF555555FFFFFF55FFFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA
AA005500FFFFAAFFFFFFFFFFAA55AA55AAFFFFFFFFFFAAFFFF005500AAAA00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
55FFFFAAAAAA00FFFFFFFFFF00AA55AA00FFFFFFFFFF00AAAAAAFFFF5555FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF55005555FFFFFFFFFFFFFF555555FFFFFFFFFFFFFF55550055FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
55FFAAFFAAFFFF00FFFFFFFFFF000000FFFFFFFFFF00FFFFAAFFAAFF55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAA55AA55AA55FFFFFFFF00FFFF55FFFF00FFFFFFFF55AA55AA55AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00AA55AA0000FFFFFFFFFF5500FF0055FFFFFFFFFF0000AA55AA00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF555555FFFF5500FFFFFFFFAAAAAAFFFFFFFF0055FFFF555555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFAAFFFFFFFFAAAAAA00AAAA55AAAA00AAAAAAFFFFFFFFAAFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5500FFAA5555AAFF00AAFFAA00FF00AAFFAA00FFAA5555AAFF0055FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAA00000000AAAAFF00FFAAAAAAFF00FFAAAA00000000AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00AAFFAAAAFFAA00FF55FF00AA00FF55FF00AAFFAAAAFFAA00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5555AAAA55FF55FFAAFF55FF55FFAAFF55FF55AAAA5555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAFF00AA555555AAAA005500AAAA555555AA00FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00AAAAFF00000000AAFFAAFFAA00000000FFAAAA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF5555FFAAAAFFAAAA55FF55AAAAFFAAAAFF5555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF5555FF00AAFFFFFFAA00FF5555FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF55FFAAFFFFFF5555AA5555FFFFFFAAFF55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA55AAFF5500AA55AA0055FFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00AA55AAFFFF555555FFFFAA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55555500FFFFAAFFFF00555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAFFFF55AA55AA55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00AAAA0055555500AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5555FFFFAAFFFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF550055FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55FFAAFFAAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.63248 0.97619 1.71979 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFF55FF
FF5500FF00FFAAAA00FFFFFFFFFFFFFFFFFFFFFF00AAAAFF00FF0055FFFF55FFFF55FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF00
FFFFAAAAAAFF5555FFFF00FFFFFFFFFFFFFF00FFFF5555FFAAAAAAFFFF00FF55AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAAAA
FF55AAAA55AAFFFFAA55FFFFFFFFFFFFFFFFFF55AAFFFFAA55AAAA55FFAAAAAA00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500
55AA55AAAA00FFFF00AAAAAAAAAAAAAAAAAAAAAA00FFFF00AAAA55AA55005555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
AAFF005555FFFFFFFF5555FF5555FF5555FF5555FFFFFFFF555500FFAAFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA
55AAFFAAFFFFFFFFFFFFAAFF5500FF0055FFAAFFFFFFFFFFFFAAFFAA55AAFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA
AA00FF00AA55FFAA55FFAA0055FFFFFF5500AAFF55AAFF55AA00FF00AAAA55FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055
55FFFFFF5555AA000055AAAAFFFFFFFFFFAAAA550000AA5555FFFFFF555500FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
00FF00FF0055FF55FFFFAA0000FFFFFF0000AAFFFF55FF5500FF00FF0055FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
55FFAAAAAAFFFFFFAA55FF55FFFFFFFFFF55FF55AAFFFFFFAAAAAAFF55FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF
AAFF5555FF55AAFF5555AAFFFFFFFFFFFFFFAA5555FFAA55FF5555FFAAFF55FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
55AAFFFFAA555500AAAA00FFFFFFFFFFFFFF00AAAA005555AAFFFFAA55AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
AAFF0000FFAAFFFF5555FFFFFFFFFFFFFFFFFF5555FFFFAAFF0000FFAAFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
AAAAAAFFAA55AAFF5500FF00FFFFFFFFFF00FF0055FFAA55AAFFAAAAAA55FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
5555FF55AAAA0000FF55FFAAAAAAAAAAAAAAFF55FF0000AAAA55FF555500FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
550000FF5555FFFF55AA55FF5555FF5555FF55AA55FFFF5555FF000055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAFF5500FFFF005555AA00AAAAAA00AA555500FFFF0055FFAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFAA0055FFFFFFFF5500FFAAAA55AAAAFF0055FFFFFFFF5500AAFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55AAAAFFFF00FFFFFFAAAAAA55AA55AAAAAAFFFFFF00FFFFAAAA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA00FFFFFF55AAFF555500550055005555FFAA55FFFFFF00AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFAAAAAAAAAA00FFFFAAFFAAFFAAFFAAFFFF00AAAAAAAAAAFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55FFAA000000AAFFAA55FF55AAAAAA55FF55AAFFAA000000AAFF55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0055AAAAFFAAAA55005500AAAA55AAAA00550055AAAAFFAAAA5500FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF55005555550055FFFFAAAA55AA55AAAAFFFF55005555550055FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAA00AAAAFFFF0000AA00AA00AA0000FFFFAAAA00AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00AAFFAA00FFFFFF55FF55FF55FF55FFFFFF00AAFFAA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF555555FFFFFFFFFFAA555555AAFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFFFF0000FF00000055000000FF0000FFFFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFF55FFAAAAFFAAFFAAAAFF55FFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55FFFF00FF55AAAA55FF55AAAA55FF00FFFF55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA55FFFF00555500FF00555500FFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00AAAAAAAAFFFFAAAAAAFFFFAAAAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF555500555555550055555555005555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFAAFFFFAAFFAAFFFFAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFAA55AAFF555555FFAA55AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55AAAA00FFFFAAFFFF00AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF005555FFFF000000FFFF555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF550000FFFF55FFFF000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAFF55AA55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFAA0055FF5500AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55AAAAFFFFFFAAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00FFFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFAAAAAAAAAAFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55FFAA000000AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055AAAAFFAAAA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55005555550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AAFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.72853 0.200176 1.81584 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF55550055005500AA0000AAFFAA00FF0000000000AAFF55550000AA550000FFFF550000
00FFFF000055FFFF55555500AAAAAAAAAA00555555FFFF550000FFFF00000055FFFF0000
55AA00005555FFAA0000000000FF00AAFFAA0000AA00550055005555FF
FFFF55FF55FF55FF55AA00FFFFFF000000FF0000AAFF5500005555FFAAFF000000005555
5500FF555500000000550000FFFF00FFFF000055000000005555FF0055555500000000FF
AAFF5555000055FFAA0000FF000000FFFFFF00AA55FF55FF55FF55FFFF
FFFFFF5500000055FFFF0000000000FF000000AAFF550000FFAAFFFFFF00555500AAFFFF
55FF550000555555550000FF0055FF5500FF000055555555000055FF55FFFFAA00555500
FFFFFFAAFF000055FFAA000000FF0000000000FFFF5500000055FFFFFF
FFFFFFFF5555005500FF5555FF555500FF0000FFFFFF5555FF00FF5500FFAAAAFF00FF55
00000055550000550000AA5555FFFFFF5555AA0000550000555500000055FF00FFAAAAFF
0055FF00FF5555FFFFFF0000FF005555FF5555FF0055005555FFFFFFFF
FFFFFFFFFF55FF55FF55000055FFFF5555AA00000000005500FF005500AAAAAAAA000000
555555000055550000AAFF55FFFFFFFFFF55FFAA000055550000555555000000AAAAAAAA
005500FF00550000000000AA5555FFFF55000055FF55FF55FFFFFFFFFF
FFFFFFFFFFFF550000005555FFFFFFFF55FFAA0000FF00005555AAAAFF00FFFF00FF00AA
FFAAAAFF00005500AAFF550000000000000055FFAA00550000FFAAAAFFAA00FF00FFFF00
FFAAAA55550000FF0000AAFF55FFFFFFFF555500000055FFFFFFFFFFFF
FFFFFFFFFFFFFF5555005500000000000055FFAA000000AAFFAAAAAAAA0055FF000000FF
FFFF00FF55550000FFFFFF555555FF555555FFFFFF00005555FF00FFFFFF000000FF5500
AAAAAAAAFFAA000000AAFF5500000000000055005555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55FF55FF5555005555FFFFFF0000AA55FF00FFFF00FFAAAA00FF0000
000000AAAAFFAA000000000055000000550000000000AAFFAAAA0000000000FF00AAAAFF
00FFFF00FF55AA0000FFFFFF5555005555FF55FF55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF550000005500550000000000AAFF55FF00000000AAAAAAAA555500
AA00FF00FFFFFF00AA55AA00005555550000AA55AA00FFFFFF00FF00AA005555AAAAAAAA
00000000FF55FFAA000000000055005500000055FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55550055005500AA0000AAFF55000000FF0000FFFF00FFFF55FF
55AAAA0000000000FFFF55AA0000550000AA55FFFF0000000000AAAA55FF55FFFF00FFFF
0000FF00000055FFAA0000AA00550055005555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55FF55FF55FF55AA00FFFFFF555555FF0000AAAA0000000055
FFFF00FF0000AAFF0055FFFF00AAFFAA00FFFF5500FFAA0000FF00FFFF5500000000AAAA
0000FF555555FFFFFF00AA55FF55FF55FF55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5500000055FFFF000000000055000000AA55FFAA00FF0000
55FF000000FFAA555500000000FFFFFF000000005555AAFF000000FF550000FF00AAFF55
AA000000550000000000FFFF5500000055FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF5555005500FF5555FF55550000AA55AAFFFFFF000000FF
AAAA00FF00AAAAAAFFAA00FF0000000000FF00AAFFAAAAAA00FF00AAAAFF000000FFFFFF
AA55AA00005555FF5555FF0055005555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF55FF55000055FFFF5555FFAAFF5500FF55555500
FFFF000000FFFF00FF55AAAA0000FF0000AAAA55FF00FFFF000000FFFF00555555FF0055
FFAAFF5555FFFF55000055FF55FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000005555FFFFFFFF55FF00FF55FF5500005500
AAAA00FF00AAAA0055FFFF00FF000000FF00FFFF5500AAAA00FF00AAAA0055000055FF55
FF00FF55FFFFFFFF555500000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555005500000000000055FF5500000055550000
FFFF000000FFFF000055FF000000FF000000FF550000FFFF000000FFFF00005555000000
55FF5500000000000055005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF55FF5555005555FFFFFF55555500005555
FF00555500AAAA00FFAAAA00FF000000FF00AAAAFF00AAAA00555500FF55550000555555
FFFFFF5555005555FF55FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000005500550000000000550000AAFFAA
AA00550000FFFF00AAAAAAAA5555005555AAAAAAAA00FFFF00005500AAAAFFAA00005500
0000000055005500000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55550055005500AA0000AAFFAA00FFFFFF
00FFAAFF00AAAA00FFFF00FFFF55FF55FFFF00FFFF00AAAA00FFAAFF00FFFFFF00AAFFAA
0000AA00550055005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF55FF55FF55AA00FFFFFF00000000
00AAAAAA00FFFF00AAAA00FF5500000055FF00AAAA00FFFF00AAAAAA0000000000FFFFFF
00AA55FF55FF55FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500000055FFFF0000000000FF0000
FF00FFFF00AAAA00FFFF000000555555000000FFFF00AAAA00FFFF00FF0000FF00000000
00FFFF5500000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555005500FF5555FF555500FF00
0000AAAA00FFFF00000000FF0000550000FF00000000FFFF00AAAA000000FF005555FF55
55FF0055005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF55FF55000055FFFF5555AA
0000FFFF00AAAA0000AA000000FFAAFF000000AA0000AAAA00FFFF0000AA5555FFFF5500
0055FF55FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000005555FFFFFFFF55FF
AA00000000FFFF00AA55FF5555FF00FF5555FF55AA00FFFF00000000AAFF55FFFFFFFF55
5500000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555005500000000000055
FFAA00FF00AAAA00FFFF55000055FF55000055FFFF00AAAA00FF00AAFF55000000000000
55005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF55FF5555005555FF
FFFF000000FFFF000000005555000000555500000000FFFF000000FFFFFF5555005555FF
55FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000005500550000
000000AA5500FF55555555FFFF555555FFFF55555555FF0055AA00000000005500550000
0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55550055005500AA
0000AAFF55FF5500005500000000550000000055000055FF55FFAA0000AA005500550055
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF55FF55FF55
AA00FFFFFF550000FFAAFF0000FFAAFF0000FFAAFF000055FFFFFF00AA55FF55FF55FF55
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500000055FF
FF00000000005555FF00FF5555FF00FF5555FF00FF55550000000000FFFF5500000055FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555005500
FF5555FF5555000055FF55000055FF55000055FF5500005555FF5555FF0055005555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF55FF
55000055FFFF5555000000555500000055550000005555FFFF55000055FF55FF55FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000
005555FFFFFFFF55FF5555000055555500005555FF55FFFFFFFF555500000055FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555
005500000000000055FFFFAA0000550000AAFFFF5500000000000055005555FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
FF55FF5555005555FFFFFFFF00AAFFAA00FFFFFFFF5555005555FF55FF55FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
55000000550055000000000000FFFFFF00000000000055005500000055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55550055005500AA0000FF0000000000FF0000AA00550055005555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF55FF55FF55FF55AA00FF5555005555FF00AA55FF55FF55FF55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5500000055FFFF000000550055000000FFFF5500000055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF5555005500FF5555FF55FF55FF5555FF0055005555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55FF55FF55000055FFFFFF55000055FF55FF55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF550000005555FFFFFFFFFF555500000055FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF555500550000000000000055005555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55FF55FF5555005555FF55FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5500000055005500000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF555500550055005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55FF55FF55FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5500000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.72853 0.39418 1.81584 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF555555FFFF000000FF005555550000AAFF0000FF5555FFFFFFFFFFAA0000FF00555555
555555AA00FF5555555555000000000000005555555555FF00AA55555555555500FF0000
AAFFFFFFFFFF5555FF0000FFAA000055555500FF000000FFFF555555FF
FFFF55FFAA00FF000000AA55FFFF0000FF55555555FFFF5555FF5555FF000000AA55FFAA
FFFFAA555555FFFF55FFFF00000000000000FFFF55FFFF555555AAFFFFAAFF55AA000000
FF5555FF5555FFFF55555555FF0000FFFF55AA000000FF00AAFF55FFFF
FFFFFF5555AA00000000FF55FF55555555FFFF55FFFFFFFF55AAAAFF5555555555AAFF00
5555FF00FFFF5555FFAA0000FF000000FF0000AAFF5555FFFF00FF555500FFAA55555555
55FFAAAA55FFFFFFFF55FFFF55555555FF55FF00000000AA5555FFFFFF
FFFFFFFF55FF00000000FFAA55AAFFAAFF5555FFFFFFFFFFFF5500FFAAFF55FFAAAA0000
FFFF555555FF55AAFF0055AA0000000000AA5500FFAA55FF555555FFFF0000AAAAFF55FF
AAFF0055FFFFFFFFFFFF5555FFAAFFAA55AAFF00000000FF55FFFFFFFF
FFFFFFFFFF555555555555FF00FF5555AAAAFFFFFFFFFFFFFFFF0000AAAA55FF5500FF00
00AAFFFF55FF55FF00AA55FF0000000000FF55AA00FF55FF55FFFFAA0000FF0055FF55AA
AA0000FFFFFFFFFFFFFFFFAAAA5555FF00FF555555555555FFFFFFFFFF
FFFFFFFFFFFF55FFAAAAFF555555FFFF0055FF5555FF5555FF55555555AA55FF55AA0000
00FF5555FFFFFF555555AAFF0000000000FFAA555555FFFFFF5555FF000000AA55FF55AA
55555555FF5555FF5555FF5500FFFF555555FFAAAAFF55FFFFFFFFFFFF
FFFFFFFFFFFFFF5555AA55AAFFFFAA0000FFFFFF55FF55FFFFFFAAFF55FF00FFAA555555
5555FFFF5555FF55FFAAAA00000000000000AAAAFF55FF5555FFFF5555555555AAFF00FF
55FFAAFFFFFF55FF55FFFFFF0000AAFFFFAA55AA5555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55FF00FF555500000000AAFF00FFAAFF00AA00AAFF555555FF00FFFF
55FFFFFFFFAAAA55FF5500000000000000000055FF55AAAAFFFFFFFF55FFFF00FF555555
FFAA00AA00FFAAFF00FFAA000000005555FF00FF55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555555FFFF000000FF005555550000AA555555AAAAFFFF555555FF
55FF5555FF5500FFFFFF000000000000000000FFFFFF0055FF5555FF55FF555555FFFFAA
AA555555AA000055555500FF000000FFFF555555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55FFAA00FF000000AA55FFFF0000FF55FFFF550000AAFFFFAA55
AAFF00FFFFFF0000AA00FF00000000000000FF00AA0000FFFFFF00FFAA55AAFFFFAA0000
55FFFF55FF0000FFFF55AA000000FF00AAFF55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5555AA00000000FF55FF55555555FFFFFFFF0000FF5555FF00
FF555555FF55555555AA000000000000000000AA55555555FF555555FF00FF5555FF0000
FFFFFFFF55555555FF55FF00000000AA5555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55FF00000000FFAA55AAFFAAFF5555FF55555555FFFF5555
55FFFFAA55AAFFAA55FF000000000000000000FF55AAFFAA55AAFFFF555555FFFF555555
55FF5555FFAAFFAA55AAFF00000000FF55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555555555FF00FF5555AAAAFFFFFF55FFFF5555FFAA
FF5555FF00FF5555AAFF000000000000000000FFAA5555FF00FF5555FFAAFF5555FFFF55
FFFFFFAAAA5555FF00FF555555555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAAAAFF555555FFFF0055FF5555FFFFFFFFAAAA55
55FFFF555555FFAAAA0000000000000000000000AAAAFF555555FFFF5555AAAAFFFFFFFF
5555FF5500FFFF555555FFAAAAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA55AAFFFFAA0000FFFFFF55FF5555FF5500FF
FF5555FFFF55FF550000000000000000000000000055FF55FFFF5555FFFF0055FF5555FF
55FFFFFF0000AAFFFFAA55AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00FF555500000000AAFF00FFAAFFFFFF0000
AAFFFFAA00FFFFFF00000000000000000000000000FFFFFF00AAFFFFAA0000FFFFFFAAFF
00FFAA000000005555FF00FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFF000000FF005555550000AAFF0000
FF5555FF0000AA00FF0000000000000000000000FF00AA0000FF5555FF0000FFAA000055
555500FF000000FFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA00FF000000AA55FFFF0000FF555555
55FFFF55555555AA00000000000000000000000000AA55555555FFFF55555555FF0000FF
FF55AA000000FF00AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA00000000FF55FF55555555FFFF55
FFFFFFFF55FFAA555555555555555555555555555555AAFF55FFFFFFFF55FFFF55555555
FF55FF00000000AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00000000FFAA55AAFFAAFF5555FF
FFFFFFFFFF5555AAFFFFAAFFFFAAFFAAFFFFAAFFFFAA5555FFFFFFFFFFFF5555FFAAFFAA
55AAFF00000000FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555555555FF00FF5555AAAAFFFF
FFFFFFFFFFFF00FF5555FF00AA00AA00AA00FF5555FF00FFFFFFFFFFFFFFFFAAAA5555FF
00FF555555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAAAAFF555555FFFF0055FF55
55FF5555FF555555FFFF555555AA00AA555555FFFF555555FF5555FF5555FF5500FFFF55
5555FFAAAAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA55AAFFFFAA0000FFFFFF
55FF55FFFFFFAAFF5555FFFFAA555555AAFFFF5555FFAAFFFFFF55FF55FFFFFF0000AAFF
FFAA55AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00FF555500000000AAFF
00FFAAFF00AA00AAFFAAFF00AAAAFFAAAA00FFAAFFAA00AA00FFAAFF00FFAA0000000055
55FF00FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFF000000FF0055
55550000AA555555AAAA000000550055000000AAAA555555AA000055555500FF000000FF
FF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA00FF000000AA55
FFFF0000FF55FFFF55000000FF00FF00FF00000055FFFF55FF0000FFFF55AA000000FF00
AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA00000000FF55
FF55555555FFFFFFFF0000FF00AA55AA00FF0000FFFFFFFF55555555FF55FF00000000AA
5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00000000FFAA
55AAFFAAFF5555FF5555555500AAAAAA0055555555FF5555FFAAFFAA55AAFF00000000FF
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555555555FF
00FF5555AAAAFFFFFF00FFFF0000550000FFFF00FFFFFFAAAA5555FF00FF555555555555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAAAAFF55
5555FFFF0055FF555500AA0000FF00FF0000AA005555FF5500FFFF555555FFAAAAFF55FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA55AA
FFFFAA0000FFFFFF00FF0055AA000000AA5500FF00FFFFFF0000AAFFFFAA55AA5555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00FF
555500000000AAFF0000AA55FF000000FF55AA0000FFAA000000005555FF00FF55FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555
FFFF000000FF0055555555AAFF000000FFAA5555555500FF000000FFFF555555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF
AA00FF000000AA55FFFF00FF5555555555FF00FFFF55AA000000FF00AAFF55FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
55AA00000000FF55FF555555FFFF00FFFF555555FF55FF00000000AA5555FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
55FF00000000FFAA55AAFFFFAA000000AAFFFFAA55AAFF00000000FF55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF555555555555FF00FF555500000000005555FF00FF555555555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF55FFAAAAFF555555FFFF0000000000FFFF555555FFAAAAFF55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5555AA55AAFFFFAA00000000000000AAFFFFAA55AA5555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF55FF00FF55550000000000000000005555FF00FF55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF555555FFFF000000000000000000FFFF555555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF55FFAA00FF00000000000000FF00AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5555AA000000000000000000AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55FF000000000000000000FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555555555555555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55FFAAAAFFAAAAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5555AA55AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55FF00FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.72853 0.588183 1.81584 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF55555555FFFFFF55AAFFAAAA555555555500AAAA55FFFFFF55AA000055AA0000FF0000
5500AAAAAA55550000FFAA55FFFFFFFFFF55AAFF00005555AAAAAA00550000FF0000AA55
0000AA55FFFFFF55AAAA005555555555AAAAFFAA55FFFFFF55555555FF
FFFF55AAFFFFFFFFFF00AA55AAAAAAAAFF55FF00AAFFFFFFFFFFAA00AAAAAA5555AA00AA
AAAA0000AAFF55AA555555FFFFFFFFFFFFFF555555AA55FFAA0000AAAAAA00AA5555AAAA
AA00AAFFFFFFFFFFAA00FF55FFAAAAAAAA55AA00FFFFFFFFFFAA55FFFF
FFFFFF55555555555555AAAAFF00AA00FF00FF0055555555555555FF00AA00FFFFAA00AA
FF00AAAA00FF00FFAA55FFFFFFFFFFFFFFFFFF55AAFF00FF00AAAA00FFAA00AAFFFF00AA
00FF5555555555555500FF00FF00AA00FFAAAA55555555555555FFFFFF
FFFFFFFF55AAFFFFAA55FF555555AAAA005500AAAAAAAAAAAAFFAA5500000055AA000055
5555AAAA555555AA00FFFFFFFFFFFFFFFFFFFFFF00AA555555AAAA5555550000AA550000
0055AAFFAAAAAAAAAAAA005500AAAA555555FF55AAFFFFAA55FFFFFFFF
FFFFFFFFFF55555555FFFFFF55AAFF00AAAAAA00000000AA0000FFAAAA00AAAAAA5555AA
FFFFAA00FFFFAAAA55555555555555555555555555AAAAFFFF00AAFFFFAA5555AAAAAA00
AAAAFF0000AA00000000AAAAAA00FFAA55FFFFFF55555555FFFFFFFFFF
FFFFFFFFFFFF55AAFFFFFFFFFF00AA5555FF5555AA5555AAAA00AA55AAAA0000AAFFFF55
55555500FF0000AAFFAAAAAAAAFF55FFAAAAAAAAFFAA0000FF0055555555FFFFAA0000AA
AA55AA00AAAA5555AA5555FF5555AA00FFFFFFFFFFAA55FFFFFFFFFFFF
FFFFFFFFFFFFFF55555555555555AAAAFFFFFF00FFAA55FF5555AAAAFF00AAAA0000FF00
FFFFAA555555AA55AA0000AA00FF00FF00AA0000AA55AA555555AAFFFF00FF0000AAAA00
FFAAAA5555FF55AAFF00FFFFFFAAAA55555555555555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55AAFFFFAA55FF5555555555AA00FFFFFFAAFF00AA5555FF5500FF00
55AA00FFFF00FFAAAA5555AAAA005500AAAA5555AAAAFF00FFFF00AA5500FF0055FF5555
AA00FFAAFFFFFF00AA5555555555FF55AAFFFFAA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55555555FFFFFF55AAFFAAAA555555555500AAAA55FFFFFF5500AA
AAAA55555555AA00FFAAAAFF00AAAAAA00FFAAAAFF00AA55555555AAAAAA0055FFFFFF55
AAAA005555555555AAAAFFAA55FFFFFF55555555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55AAFFFFFFFFFF00AA55AAAAAAAAFF55FF00AAFFFFFFFFFF0055
55FF55FFAAFF5555AA0000AA5555FF5555AA0000AA5555FFAAFF55FF555500FFFFFFFFFF
AA00FF55FFAAAAAAAA55AA00FFFFFFFFFFAA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55555555555555AAAAFF00AA00FF00FF0055555555555555AA
FFFFFF000000FFFFAA00AAAA55FFFFFF55AAAA00AAFFFF000000FFFFFFAA555555555555
5500FF00FF00AA00FFAAAA55555555555555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AAFFFFAA55FF555555AAAA005500AAAAAAAAAAAAFFFF55
55555555AA55555555FF00AAFFFFFFFFFFAA00FF55555555AA5555555555FFFFAAAAAAAA
AAAA005500AAAA555555FF55AAFFFFAA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF55555555FFFFFF55AAFF00AAAAAA00000000AA0000FF00
FFFFAA55FF55AAFFFF0000555555555555550000FFFFAA55FF55AAFFFF00FF0000AA0000
0000AAAAAA00FFAA55FFFFFF55555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFFFFFFFF00AA5555FF5555AA5555AAAA00AA55
555555FFFFFF55555555AA55FFAAAAAAFF55AA55555555FFFFFF55555555AA00AAAA5555
AA5555FF5555AA00FFFFFFFFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555555555AAAAFFFFFF00FFAA55FF5555AAAA
AAAAFFFFFFFFFFAAAAAAFF00FF00AA00FF00FFAAAAAAFFFFFFFFFFAAAAAAAA5555FF55AA
FF00FFFFFFAAAA55555555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFFAA55FF5555555555AA00FFFFFFAAFF00
AA00FF0000FF0000AAFF000055AA55AA550000FFAA0000FF0000FF00AA00FFAAFFFFFF00
AA5555555555FF55AAFFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555FFFFFF55AAFFAAAA555555555500AA
AA555555AA550000555555AA55FF55FF55AA555555000055AA555555AAAA005555555555
AAAAFFAA55FFFFFF55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFFFFFFFF00AA55AAAAAAAAFF55FF00
AAFFFF00FFAA5555AAFFAAFF00FF00FF00FFAAFFAA5555AAFF00FFFFAA00FF55FFAAAAAA
AA55AA00FFFFFFFFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555555555AAAAFF00AA00FF00FF00
55555555AA00FFFFAA00555555AA00AA55555500AAFFFF00AA5555555500FF00FF00AA00
FFAAAA55555555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFFAA55FF555555AAAA005500AA
AAAAAAAAAA5555555500FFFFAA55AA55AAFFFF0055555555AAAAAAAAAAAA005500AAAA55
5555FF55AAFFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555FFFFFF55AAFF00AAAAAA00
00000000AAFFAAFF55FF0000FFAA55AAFF0000FF55FFAAFFAA0000000000AAAAAA00FFAA
55FFFFFF55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFFFFFFFF00AA5555FF5555
AA5555AA55AA00FF00FF005500AAFFAA005500FF00FF00AA55AA5555AA5555FF5555AA00
FFFFFFFFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555555555AAAAFFFFFF00
FFAA55FF55AAAA005500AAAAAA00FF00AAAAAA005500AAAA55FF55AAFF00FFFFFFAAAA55
555555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFFAA55FF5555555555
AA00FFFFFFAA00FF55AA55AAAA555555AAAA55AA55FF00AAFFFFFF00AA5555555555FF55
AAFFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555FFFFFF55AAFFAA
AA555555555500FF00FFAA55AAAAAAAAAA55AAFF00FF005555555555AAAAFFAA55FFFFFF
55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFFFFFFFF00AA55
AAAAAAAAAAAAAA005500AAFF5555FF5555FFAA005500AAAAAAAAAAAAAA55AA00FFFFFFFF
FFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555555555AAAA
FF00AA00000000AAAAAA00FF00FFFFFF00FF00AAAAAA00000000AA00FFAAAA5555555555
5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFFAA55FF55
5555AAAA00AAAA0000AA00AA5555555555AA00AA0000AAAA00AAAA555555FF55AAFFFFAA
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555FFFFFF
55AAFF00AAAA55AA555500FFAAAAAAAAAAFF005555AA55AAAA00FFAA55FFFFFF55555555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFFFFFF
FF00AA5555FF55AAAAAAAA005555FF555500AAAAAAAA55FF5555AA00FFFFFFFFFFAA55FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555555555
5555AAAAFFFFFF00AA0000AAAAFFFFFFAAAA0000AA00FFFFFFAAAA55555555555555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFF
AA55FF5555555555AAAA00AA0000FF0000AA00AAAA5555555555FF55AAFFFFAA55FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555
55FFFFFF55AAFFAAAA55AA55AA555555AA55AA55AAAAFFAA55FFFFFF55555555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA
FFFFFFFFFF00AA55AAAAFF00FFAAAAAAFF00FFAAAA55AA00FFFFFFFFFFAA55FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
555555555555AAAAFF00AA55555500555555AA00FFAAAA55555555555555FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
55AAFFFFAA55FF555555AAAAFF55AA55FFAAAA555555FF55AAFFFFAA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55555555FFFFFF55AAFF00AA55FF55AA00FFAA55FFFFFF55555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF55AAFFFFFFFFFF00AA5555FFFFFF5555AA00FFFFFFFFFFAA55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55555555555555AAAAFFFFFFFFFFAAAA55555555555555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF55AAFFFFAA55FF55555555555555FF55AAFFFFAA55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55555555FFFFFF55FFAAFF55FFFFFF55555555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF55AAFFFFFFFFFF000000FFFFFFFFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55555555555555AA55555555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55AAFFFFAA55FF55AAFFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55555555FFFFFF55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55AAFFFFFFFFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55555555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AAFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.72853 0.782187 1.81584 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF5555555555AAFFFFAA55555555FFFF55555555AAAAAA555555AAFFAAAAAAFFFFFFFFFF
FFAAAAAAFFFFAAFFAA55AAAAAAAAAAAAAAAAAA55AAFFAAFFFFAAAAAAFFFFFFFFFFFFAAAA
AAFFAA555555AAAAAA55555555FFFF55555555AAFFFFAA5555555555FF
FFFF55AAFFAA55555555AAFFAAFFFFFFFFAAFFAA555500FFFFAA55555500555555555555
5555005555555500AAAAAA00005500550000AAAAAA005555555500555555555555555500
555555AAFFFF005555AAFFAAFFFFFFFFAAFFAA55555555AAFFAA55FFFF
FFFFFF5500AAAAAAAAAAAA0055555555555500AAAAAAAA5500AAAAFFAA55AAFFAAFFFFAA
FFAA55AAFFAAAAFF005555AAAA55FF55AAAA555500FFAAAAFFAA55AAFFAAFFFFAAFFAA55
AAFFAAAA0055AAAAAAAA0055555555555500AAAAAAAAAAAA0055FFFFFF
FFFFFFFF55550000550000AAFFFFAA55FFFF55550000AAAAFF005500AAAAAA0055555555
00AAAAAA00555500AAFFFF0055FFFFFF5500FFFFAA00555500AAAAAA005555555500AAAA
AA005500FFAAAA00005555FFFF55AAFFFFAA00005500005555FFFFFFFF
FFFFFFFFFF55AAAA55FF5555AA0055FFFFFFFF55AAAA555500AAFFAA00AA00AAFFAAAAFF
AA00AA00AAFFAAAA55555555FFFFFFFFFF55555555AAAAFFAA00AA00AAFFAAAAFFAA00AA
00AAFFAA005555AAAA55FFFFFFFF5500AA5555FF55AAAA55FFFFFFFFFF
FFFFFFFFFFFF5500FFFFFFAA5555FFFFFFFFFFFF5500FFFF555500AA00FF555500AAAA00
5555FF00AA005555AAFFAAFFFFFFFFFFFFFFAAFFAA555500AA00FF555500AAAA005555FF
00AA005555FFFF0055FFFFFFFFFFFF5555AAFFFFFF0055FFFFFFFFFFFF
FFFFFFFFFFFFFF5555555555AAFFFFFFFFFFFFFFFFAA0055AAFFAA000000FFFFAA0000AA
FFFF000000AAFFAAAA0055555555555555555500AAAAFFAA000000FFFFAA0000AAFFFF00
0000AAFFAA5500AAFFFFFFFFFFFFFFFFAA5555555555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55AAFFAA55555555555555555555AAAAAA005555FF55555555AAAA55
555555FF5555AA0000AAFFAAFFAAFFAAFFAAFFAA0000AA5555FF55555555AAAA55555555
FF555500AAAAAA55555555555555555555AAFFAA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5500AAAAAAAAAAAAFFAAFFFFAA555500FFAAFFFFFFAAFFAA5555AA
FFAAFFFFFFAA5555FF5500AA0055555500AA0055FF5555AAFFFFFFAAFFAA5555AAFFAAFF
FFFFAAFF005555AAFFFFAAFFAAAAAAAAAAAA0055FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55550000550000AA55555555AAFFAA00555555555500AAAAAAAA
005555555555AAFFFFFFAA00AAFFAAFFAA00AAFFFFFFAA555555555500AAAAAAAA005555
55555500AAFFAA55555555AA00005500005555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AAAA55FF5555AAFFFFAA555555AAAAAAFFFFAAFF00555500
FFAAAAAAFFAA5555555555AAAA005500AAAA5555555555AAFFAAAAAAFF00555500FFAAFF
FFAAAAAA555555AAFFFFAA5555FF55AAAA55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5500FFFFFFAA55555555AAFFFF00555500AA555555FFAAFF
0000555500AAAAFFAAFFAA5555AAAAAA5555AAFFAAFFAAAA0055550000FFAAFF555555AA
00555500FFFFAA55555555AAFFFFFF0055FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF5555555555AAFFFFAA55555555FFFF5555AAFFAA5500FF
00AAFFAAFF0055555500AAAAAAAA00AAAAAAAA0055555500FFAAFFAA00FF0055AAFFAA55
55FFFF55555555AAFFFFAA5555555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFAA55555555AAFFAAFFFFFFFFAA555555AAFF00
0000AA555555FFAAFFAA00AAAA000000AAAA00AAFFAAFF555555AA000000FFAA555555AA
FFFFFFFFAAFFAA55555555AAFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAAAAAAAAAAA00555555555555AAFFAA555555
FF5555AAFFFF000055AA55AA5555FF5555AA55AA550000FFFFAA5555FF555555AAFFAA55
555555555500AAAAAAAAAAAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55550000550000AAFFFFAA55FFFF5500AAAAAAFF
FFFFAA55555555FF55FF00FF55FFFFFF55FF00FF55FF55555555AAFFFFFFAAAAAA0055FF
FF55AAFFFFAA00005500005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA55FF5555AA0055FFFFFFFF5555005555
555555AAFFAAFFFFFF000000FFFFFFFFFF000000FFFFFFAAFFAA5555555555005555FFFF
FFFF5500AA5555FF55AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFFFFFAA5555FFFFFFFFFFFF55AAAAFF
AAFFAAAA005555555555FF55555555555555FF555555555500AAAAFFAAFFAAAA55FFFFFF
FFFFFF5555AAFFFFFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555555555AAFFFFFFFFFFFFFFFF005555
55AA0000AAFFAAFFAAFFFFFFAAFFAAFFAAFFFFFFAAFFAAFFAA0000AA55555500FFFFFFFF
FFFFFFFFAA5555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFAA55555555555555555555FFFF
AA5555FF5500AA00555555555500AA00555555555500AA0055FF5555AAFFFF5555555555
5555555555AAFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAAAAAAAAAAAFFAAFFFFAA5500
AAAAFFFFFFAA00AAFFAAAAFFFFAA00AAFFFFAAAAFFAA00AAFFFFFFAAAA0055AAFFFFAAFF
AAAAAAAAAAAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55550000550000AA55555555AAFF
005555555555AAAA005555AA0055FF5500AA555500AAAA555555555500FFAA55555555AA
00005500005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA55FF5555AAFFFFAA5555
55FFAAAAAAAAAA00AAFFAA5555FFFFFF5555AAFFAA00AAAAAAAAAAFF555555AAFFFFAA55
55FF55AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFFFFFAA55555555AAFF
FF0000550000AAAA555555AAFFFFFFFFFFAA555555AAAA0000550000FFFFAA55555555AA
FFFFFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555555555AAFFFFAA5555
5555FF55AAAA5555AAFFAA55555555555555AAFFAA5555AAAA55FF55555555AAFFFFAA55
55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFAA55555555AAFF
AAFFFFFF0055FFFF5500AAAAAAAAAAAAAAAAAA0055FFFF5500FFFFFFAAFFAA55555555AA
FFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAAAAAAAAAAA00
5555555555FFFFFFFF5555000055005500005555FFFFFFFF555555555500AAAAAAAAAAAA
0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55550000550000AA
FFFFAA55FFFFFFFFFFFF55AAAA55FF55AAAA55FFFFFFFFFFFF55AAFFFFAA000055000055
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA55FF5555
AA0055FFFFFFFFFFFFFFFF5500FFFFFF0055FFFFFFFFFFFFFFFF5500AA5555FF55AAAA55
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFFFFFAA
5555FFFFFFFFFFFFFFFFFFFF5555555555FFFFFFFFFFFFFFFFFFFF5555AAFFFFFF0055FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555555555
AAFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFAA5555555555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFAA
5555555555555555555555555555005555555555555555555555555555AAFFAA55FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA
AAAAAAAAAAFFAAFFFFAAFFFFAA55FF55AAFFFFAAFFFFAAFFAAAAAAAAAAAA0055FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555
0000550000AA55555555AA0055FFFFFF5500AA55555555AA00005500005555FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
AAAA55FF5555AAFFFFAA5555FFFFFFFFFF5555AAFFFFAA5555FF55AAAA55FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
5500FFFFFFAA55555555AAFFFFFFFFFFFFFFAA55555555AAFFFFFF0055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5555555555AAFFFFAA555555555555555555AAFFFFAA5555555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF55AAFFAA55555555AAFFAAFFAAFFAAFFAA55555555AAFFAA55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5500AAAAAAAAAAAA005500AA005500AAAAAAAAAAAA0055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF55550000550000AAFFAA00AAFFAA00005500005555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55AAAA55FF5555AA000000AA5555FF55AAAA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF5500FFFFFFAA5555FF5555AAFFFFFF0055FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5555555555AAFFFFFFAA5555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55AAFFAA5555555555AAFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5500AAAAAAFFAAAAAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF555500555555005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AAAAFFAAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5500FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.72853 0.97619 1.81584 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF55555555AAAAFF5555000000000000AA00AAAAFFFFFF5555000055FFFFAA000000AAAA
AA5555AA5555AAAA0000AA55005500550055AA0000AAAA5555AA5555AAAAAA000000AAFF
FF5500005555FFFFFFAAAA00AA0000000000005555FFAAAA55555555FF
FFFF55FF0055AA00FF5500555500555500AA0055AAAA55AA55550055FF55555500555555
5555AA55000055AA0000AA55550000005555AA0000AA55000055AA555555555500555555
FF55005555AA55AAAA5500AA0055550055550055FF00AA5500FF55FFFF
FFFFFF55550000FFFFFFAA5555AAFFFFAA55005500AA555555AA55FFFFFFAAAA00005500
005500AAAAAAAA00555500AAAA000000AAAA00555500AAAAAAAA00550000550000AAAAFF
FFFF55AA555555AA00550055AAFFFFAA5555AAFFFFFF00005555FFFFFF
FFFFFFFF55FFAA55AAAA55000055AAAA55000000555555AA555555AAAA55AA0055550000
00005555555555550000555555550055555555000055555555555500000000555500AA55
AAAA555555AA55555500000055AAAA55000055AAAA55AAFF55FFFFFFFF
FFFFFFFFFF555555AA0055005555AA005500555500005500AAAA00AA5500FF00FF550055
5500550000550000555500005500000055000055550000550000550055550055FF00FF00
55AA00AAAA005500005555005500AA5555005500AA555555FFFFFFFFFF
FFFFFFFFFFFF55FF0000005555AA5500550055000000005555555500AAAAAA55FF550055
0000005555000000AAAA0000AAAAAAAAAA0000AAAA0000005555000000550055FF55AAAA
AA0055555555000000005500550055AA5555000000FF55FFFFFFFFFFFF
FFFFFFFFFFFFFF5555005555AA550000AAAAAA000000000055FF005555555555AAAA0000
5555005500000000AA5500555555555555550055AA00000000550055550000AAAA555555
555500FF550000000000AAAAAA000055AA5555005555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55FFAAAA00550055555555550055550055FF55AA5555AA5555555500
55000000555500555555AAFFAAAA00AAAAFFAA555555005555000000550055555555AA55
55AA55FF55005555005555555555005500AAAAFF55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555555550000AAAAFFFF5500550000AAAA555555AA550000550000
00555500550000005500FF00AA550055AA00FF00550000005500555500000055000055AA
555555AAAA0000550055FFFFAAAA000055555555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55FF00555500AA55AAAA0000555500AA5555AA55000000005555
00550000AAAAAAAAAAFF555500AAAAAA005555FFAAAAAAAAAA0000550055550000000055
AA5555AA0055550000AAAA55AA00555500FF55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55550000555555AA0055550000555555AA550000000000AAAA
FF550055555555555555FF00555555555500FF555555555555550055FFAAAA0000000000
55AA5555550000555500AA55555500005555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55FFAA5555AA550055FF00FFFFAAAA005500555500555555
55FFFF0055000055FFFF555500005500005555FFFF5500005500FFFF5555555500555500
5500AAAAFFFF00FF550055AA5555AAFF55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555AA550000AAAA55FF5555555500FFFF5500550000
55FF5555000000AAAA55AA55550055005555AA55AAAA0000005555FF550000550055FFFF
0055555555FF55AAAA000055AA555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF0000555500AA5555FFFFAAAAFF5555FFFF005555
00FFAAAA000000AA5500FF0055FFAAFF5500FF0055AA000000AAAAFF00555500FFFF5555
FFAAAAFFFF5555AA0055550000FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55550055FF00FF0055FF55555555FFFF5555FFAAAA
FF5555555500555555AAFF00FF555555FF00FFAA5555550055555555FFAAAAFF5555FFFF
55555555FF5500FF00FF55005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAAAA55FF55AA55AA5555AA55AAAAFFAA0055
AAAAFFFF55FFAAAA00AA55AAFF005500FFAA55AA00AAAAFF55FFFFAAAA5500AAFFAAAA55
AA5555AA55AA55FF55AAAAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555AAAA005500AAAA005500AA55AA0000
55AA00FFAAAA5500AA005500AAFF55FFAA005500AA0055AAAAFF00AA550000AA55AA0055
00AAAA005500AAAA55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF0055AA0000555555550000AA55555500
5500AA00FF0000555555000000FFAAFF0000005555550000FF00AA005500555555AA0000
555555550000AA5500FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55550000FFFF0055FF00555500AAAAFFAA
555500AA00FFFF0055000000AA00FF00AA0000005500FFFF00AA005555AAFFAAAA005555
00FF5500FFFF00005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA55AAAAAAFF00FF550055AA00FF
00550055AAFF00AA00AA000000FFFFFF000000AA00AA00FFAA55005500FF00AA550055FF
00FFAAAAAA55AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555AA0055AAAAAA555500FF00FF
AA555500FF00AA00555555005555FF55550055555500AA00FF005555AAFF00FF005555AA
AAAA5500AA555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00000055AA00550000AAFF55
5555AA55FF55AA00005500000055FF55000000550000AA55FF55AA555555FFAA00005500
AA55000000FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555005555AA0000555500AAFF
AAAA0055FF5500AA000055550055FF550055550000AA0055FF5500AAAAFFAA0055550000
AA5555005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAAAA00555500FF55AA00
FF0000AAAA555500AA0000550055FF5500550000AA005555AAAA0000FF00AA55FF005555
00AAAAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555555500005555FF0000
AAFF55AA0055FF00FF00FFFF55AA55AA55FFFF00FF00FF5500AA55FFAA0000FF55550000
55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00555500FF555500
55AAAA005555AAAAAA55FF5555AA00AA5555FF55AAAAAA555500AAAA55005555FF005555
00FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500005555FFFFAA
55555555000055AA0055FF55FF000000FF55FF5500AA55000055555555AAFFFF55550000
5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAA5555AAAA55
0000550000000055AAFFFFFFAA000000AAFFFFFFAA550000000055000055AAAA5555AAFF
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555AA5500AA
AAAAAA000000000055AAAA55AA000000AA55AAAA550000000000AAAAAAAA0055AA555555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00005555
55555555005555005500AA55555500555555AA0055005555005555555555550000FF55FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55550055FF
FFAAAA00AA00AAAAAA0000FF5500000055FF0000AAAAAA00AA00AAAAFFFF55005555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAAAA
55AA0055555500AA55005555FFFF00FFFF55550055AA0055555500AA55AAAAFF55FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555
55AA000055FF00FF005555AA55AAAAAA55AA555500FF00FF550000AA55555555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF
0055AAFF55FF55AAAAAA00AA5555555555AA00AAAAAA55FF55FFAA5500FF55FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
550000FFAAAA555555555500AAAA00AAAA005555555555AAAAFF00005555FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
55FFAA55AA00550000550000AA550055AA00005500005500AA55AAFF55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF555555AA000055550000AA0055005500AA000055550000AA555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF55FF000000005500555555000000555555005500000000FF55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5555005555000000550000000000550000005555005555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF55FFAAAA000000AAAAAAAAAAAAAA000000AAAAFF55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55555555005555555555555555550055555555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF55FF005555AA5555AA5555AA555500FF55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5555000055AA555555AA5500005555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55FFAA555555AA555555AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555555AA555555AA555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55FF0000550000FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55550055005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55FFAAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.82457 0.200176 1.91188 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF555555FFFF005555AA0000550055FF55555555FF555555AAFFFF55000055AA00FFFFAA
AA55AAAAFFAAAAAA55AAAAFFAAAA55AAAAFFAAAA55AAAAAAFFAAAA55AAAAFFFF00AA5500
0055FFFFAA555555FF55555555FF5500550000AA555500FFFF555555FF
FFFF5555000055AAAA5555555500AAFF55FF55FFFFFF55FF55000055555555FF00005500
FF55FF005500FF550055FF00FF550055FF00FF550055FF005500FF55FF00550000FF5555
5555000055FF55FFFFFF55FF55FFAA0055555555AAAA5500005555FFFF
FFFFFF5555555500FF5555FF555555AAFF00FFAA55FFAAFF55555555FF555500000000AA
55FF55AA000000555555000000555555000000555555000000AA55FF55AA000000005555
FF55555555FFAAFF55AAFF00FFAA555555FF5555FF0055555555FFFFFF
FFFFFFFF55550055AAFFAAFF5555FF5500000055FF55AA55FF5555FFFFFF555555555555
AAAAAA5555555555005555555555005555555555005555555555AAAAAA555555555555FF
FFFF5555FF55AA55FF5500000055FF5555FFAAFFAA55005555FFFFFFFF
FFFFFFFFFF555555FF00FF55AAAAFF55555555550000AAAAFF55FFFF00FFFF5555005555
FF0055FFFF55FF555555FFFFAA000000AAFFFF555555FF55FFFF5500FF5555005555FFFF
00FFFF55FFAAAA00005555555555FFAAAA55FF00FF555555FFFFFFFFFF
FFFFFFFFFFFF55550000005555AA55FF55550055555555AA55FFFFFF00005500555555FF
55AA0000550055005555FFAA5555555555AAFF5555005500550000AA55FF555555005500
00FFFFFF55AA55555555005555FF55AA55550000005555FFFFFFFFFFFF
FFFFFFFFFFFFFF55555555550055FFFFFF555555FF55FF550055000055AA000000AA0000
5555AA0055555500AA000055FFFF55FFFF550000AA0055555500AA55550000AA000000AA
550000550055FF55FF555555FFFFFF55005555555555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF555500555555FFAA55FFFFAAAAAAFF55555500AA55AA5500AA555555
55FF5500AA0000AA55555555FFAA55AAFF55555555AA0000AA0055FF55555555AA0055AA
55AA00555555FFAAAAAAFFFF55AAFF555555005555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555555FFFFAA5555FFAA5555AA55FFFF555555AAAA0000FF55FF55
550000AA55555555AAAAFFFF55AA55AA55FFFFAAAA55555555AA00005555FF55FF0000AA
AA555555FFFF55AA5555AAFF5555AAFFFF555555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5555000055FFFF55AA55AAAA00FFFFFFAAAA5555AA0055005500
55555555AAAAFFFF5500FFFFFF550055FFFFFF0055FFFFAAAA555555550055005500AA55
55AAAAFFFFFF00AAAA55AA55FFFF5500005555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5555555500005555AAAA00AA55FFAA5555AAAA55555500AA00
5555FF5555AA55FFAA0055000055555500005500AAFF55AA5555FF555500AA00555555AA
AA5555AAFF55AA00AAAA5555000055555555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55550055AA0000AAAA0055FF55AA55AAAA00AA0000AA5555
55FFFFFF5555AAAAAA0055555555005555555500AAAAAA5555FFFFFF555555AA0000AA00
AAAA55AA55FF5500AAAA0000AA55005555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FF0000FF5500AAFF5555AAAA00AA55555555AAAA
FFFFFFFFFF5555AA555555FFFF555555FFFF555555AA5555FFFFFFFFFFAAAA55555555AA
00AAAA5555FFAA0055FF0000FF555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF555500000000555555AAFF00AAAA0055FF5555FF5500
FFFFFF00FFFF5555AAAAFFFFFFFFAAFFFFFFFFAAAA5555FFFF00FFFFFF0055FF5555FF55
00AAAA00FFAA555555000000005555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555555555FFFF550000FF5500AAFF55550000AA
55FFAA550000555500FF55AAFF55AA55FFAA55FF005555000055AAFF55AA00005555FFAA
0055FF000055FFFF555555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555005555FFAA55AA00550055AA55FF55555555
AAAAAA00000000AA00550055FFAA00AAFF55005500AA00000000AAAAAA55555555FF55AA
55005500AA55AAFF5555005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFF005555AA000000AAAAFF55550055
55AA555555555555AA0000FFAA555555AAFF0000AA555555555555AA5555005555FFAAAA
000000AA555500FFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555000055AAAA5555555555AA55FF555555
FF55005555FF555500FF000055FF55FF550000FF005555FF55550055FF555555FF55AA55
55555555AAAA5500005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555555500FF5555FF55FF550055005555
FFAA0055550000AA005500AA55AAFFAA55AA005500AA0000555500AAFF555500550055FF
55FF5555FF0055555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55550055AAFFAAFF55FFAA00555555FF
55AA550055555555AA0000FF55FF00FF55FF0000AA555555550055AA55FF55555500AAFF
55FFAAFFAA55005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FF00FF55AAAAAA005555FF55
AAAA000000AAFFAAAA0055AAFF00FF00FFAA5500AAAAFFAA000000AAAA55FF555500AAAA
AA55FF00FF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55550000005555AA555555005500
55FF000000FF55AA555555FF00FF00FF00FF555555AA55FF000000FF55005500555555AA
55550000005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555550055FFFFAA005555
5500000000005555AAAAFFAA5500000055AAFFAAAA5555000000000055555500AAFFFF55
005555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500555555FFAA55555500
555555555555550055FF00FF5555555555FF00FF55005555555555555500555555AAFF55
5555005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFAA5555FF5555
55FFFF5555FF5555550000005555FF5555000000555555FF5555FFFF555555FF5555AAFF
FF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555000055FFFF55AAAA
FFFFFF00AAFF55FF5555555555FFFFFF5555555555FF55FFAA00FFFFFFAAAA55FFFF5500
005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555555500005555AA
55FFAA5500FFFF55AAAAFFAAFFFFFFFFFFAAFFAAAA55FFFF0055AAFF55AA555500005555
5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55550055AA0000AA
AAFF550055AAFF55FF005500FFFFFFFFFF005500FF55FFAA550055FFAAAA0000AA550055
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FF0000FF
550000AA55AA55FF55AA0000FFFF00FFFF0000AA55FF55AA55AA000055FF0000FF555555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500000000
55555555AAAA00005555AA00550000005500AA55550000AAAA55555555000000005555FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555555555
55FFFFAAAA00AA55005555AA0000000000AA55550055AA00AAAAFFFF555555555555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55550055
55FFAA5555AA00AA00555500FF000000FF00555500AA00AA5555AAFF5555005555FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555
FFFF00555500FF0055AAAA55000000000055AAAA5500FF00555500FFFF555555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555
000055AAAA55000000AAAA00FF000000FF00AAAA00000055AAAA5500005555FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
55555500FF5555555555AA55000000000055AA5555555555FF0055555555FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
55550055AAFFAAAA55AAAA00000000000000AAAA55AAAAFFAA55005555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF555555FF00FF550055FF00000000000000FF550055FF00FF555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF55550000005555550000000000000000005555550000005555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5555555555005555555555555555555555005555555555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF555500555555FFFF5555005555FFFF555555005555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF555555FFFFAA55FF555555FF55AAFFFF555555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF5555000055FFFFFF55FFFFFF5500005555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF555555550000550055000055555555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55550055AA000000AA55005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555555FF000000FF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF555500000000005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55555555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5555005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.82457 0.39418 1.91188 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF555555FFFF00AAAA55FF5500FFFFAA555555555555FF55AA5555FFFF550000FF555500
55FFFFFFAAFFAA550055FFAAFFFF55FFFFAAFF550055AAFFAAFFFFFF55005555FF000055
FFFF5555AA55FF555555555555AAFFFF0055FF55AAAA00FFFF555555FF
FFFF55FFFFFF00AAAA00555555FFAA555555555555555500000055AAFF55FF55550000FF
AAAAAAAAAA000000FFAAFF55005555550055FFAAFF000000AAAAAAAAAAFF00005555FF55
FFAA550000005555555555555555AAFF55555500AAAA00FFFFFF55FFFF
FFFFFF55AAFF5555AA55AA00550055FFFF55FFFF55FFFFAA00FFAAAA000055555555FF55
AA5555AA5555FF555500FFFF5555555555FFFF005555FF5555AA5555AA55FF5555555500
00AAAAFF00AAFFFF55FFFF55FFFF55005500AA55AA5555FFAA55FFFFFF
FFFFFFFF550055000000FF555555FFFFFFFF55AAFFFF00FF555500FF5555FFFF55FFFFFF
55000055FFFFAA5500AAFF55AA005500AA55FFAA0055AAFFFF55000055FFFFFF55FFFF55
55FF005555FF00FFFFAA55FFFFFFFF555555FF000000550055FFFFFFFF
FFFFFFFFFF555555FF5555000055005555005500FFFF00AA0055AAAAAAFFAA55FFFFFFFF
FF5555FFFFFF0055AAAA000055FF55FF550000AAAA5500FFFFFF5555FFFFFFFFFF55AAFF
AAAAAA5500AA00FFFF0055005555005500005555FF555555FFFFFFFFFF
FFFFFFFFFFFF55FFFFFF55FF555555FFFF555555FFAA55AA55AA00AAAA000000FFFFFFFF
FF0000FFFFFF00AA5555AAAA5500550055AAAA5555AA00FFFFFF0000FFFFFFFFFF000000
AAAA00AA55AA55AAFF555555FFFF555555FF55FFFFFF55FFFFFFFFFFFF
FFFFFFFFFFFFFF55AAFF55FFAAAAFFFFFFFFAAAAFF5500000055FF5500FFAA00FFFFFFFF
FF00AAFF55AAFF005500000000FFAAFF000000005500FFAA55FFAA00FFFFFFFFFF00AAFF
0055FF5500000055FFAAAAFFFFFFFFAAAAFF55FFAA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF5500550055FF00FFFFFF0055FFAAFF00AAFFFFFF555500FFAA55FFAA
55FF550055AA55FF55FF5555FF55AA55FF5555FF55FF55AA550055FF55AAFF55AAFF0055
55FFFFFFAA00FFAAFF5500FFFFFF00FF5500550055FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555555FFFF00AA0000AAFFFF005555FF00FFFFFF55FF55AA550055
FFFFFF555555AA000055555555000000555555550000AA555555FFFFFF550055AA55FF55
FFFFFF00FF555500FFFFAA0000AA00FFFF555555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55FFFFFF00AAAA55AA55FFAA0055AAFF00FFFFFFAA5500FF00AA
55FFAA55000055FF555555555555FF555555555555FF55000055AAFF55AA00FF0055AAFF
FFFF00FFAA5500AAFF55AA55AAAA00FFFFFF55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AAFF5555AA5500FF00FF555555AAFF00FFFF0055AAAAAA55
555500FF00AAFFFFFF55FFFFAAFFFFFFAAFFFF55FFFFFFAA00FF00555555AAAAAA5500FF
FF00FFAA555555FF00FF0055AA5555FFAA55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF550055000000FFAA55AAFFFF55FF00FFAA55FF55FF0055FF
FF55FF55AAAA0000AA00555500FFFFFF00555500AA0000AAAA55FF55FFFF5500FF55FF55
AAFF00FF55FFFFAA55AAFF000000550055FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FF555500FF0055550000AAFF5500AA005555FFFF
FF0000AA5555AAAA5555FFFF5555005555FFFF5555AAAA5555AA0000FFFFFF555500AA00
55FFAA0000555500FF005555FF555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFFFF55FF55AAAAFFAA00FF55AA00FF5555555500
5555FF55000055FF0000555500AA55AA0055550000FF55000055FF55550055555555FF00
AA55FF00AAFFAAAA55FF55FFFFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFF55FFAAAA00AA00AAFF55FF00AA00550000FF
AAFFFFFF5555FFFF00AAFFAAAA555555AAAAFFAA00FFFF5555FFFFFFAAFF00005500AA00
FF55FFAA00AA00AAAAFF55FFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500550055FF00AAAA555500AA00FF555555FF55
AA55FFAA550000AA00FF55AA5555555555AA55FF00AA000055AAFF55AA55FF555555FF00
AA005555AAAA00FF5500550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFF00AAAA0055AAAA00FFFF55FFFFFF
5500AA00AA55AAAA00FFFF55000055000055FFFF00AAAA55AA00AA0055FFFFFF55FFFF00
AAAA5500AAAA00FFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFFFF00AAAA00FF0055FF55AAFFFFFF00
FF00AAAA555555AA55AAFF55FF555555FF55FFAA55AA555555AAAA00FF00FFFFFFAA55FF
5500FF00AAAA00FFFFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFF5555AA55AAFF0000AA5555005555
FFAA00AAAAFFAAAA0055FFAAAAAAFFAAAAAAFF5500AAAAFFAAAA00AAFF5555005555AA00
00FFAA55AA5555FFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550055000000FF55AAAA55555555FFFF
55AA55AA555500FF55555500FF550055FF00555555FF005555AA55AA55FFFF55555555AA
AA55FF000000550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FF5555000000005500005555
00000055FFFFAA00005500AAFF55FF55FFAA00550000AAFFFF5500000055550000550000
00005555FF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFFFF55FF5555FF55FF555555
55FF5555550055FF555555FF00FF00FF00FF555555FF5500555555FF55555555FF55FF55
55FF55FFFFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFF55FFAAAAFF55FFAAAAFF
FFAA550000FFAAAAAAFFAAAAAA55FF55AAAAAAFFAAAAAAFF000055AAFFFFAAAAFF55FFAA
AAFF55FFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500550055FF00FF00FF5500
5555AA00FFAA5555AA55FF0055FFFFFF5500FF55AA5555AAFF00AA55550055FF00FF00FF
5500550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFF00AA00FFFF55
555555AAAAAA005500FF00FFAAAAAAAAAAFF00FF005500AAAAAA55555555FFFF00AA00FF
FF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFFFF00AAAA55FFAA
AAFFFF5500FF555555FFAA00000000000000AAFF555555FF0055FFFFAAAAFF55AAAA00FF
FFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFF5555AA550055
FF00FFFF55550000550055FF5555FF5555FF55005500005555FFFF00FF550055AA5555FF
AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550055000000FFAA
AAAA55FFAAAAFF00AA55AA0000FF00FF0000AA55AA00FFAAAAFF55AAAAAAFF0000005500
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FF555500
FF5500AA00AAAAAA555555AAAA55FF55AAAA555555AAAAAA00AA0055FF005555FF555555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFFFF55FF
55AA00FF5555AA5555555555AA550055AA5555555555AA5555FF00AA55FF55FFFFFF55FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFF55FF
AAAA00FFFF55FF0000550000FF55FF55FF0000550000FF55FFFF00AAAAFF55FFAA55FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55005500
55FF00AA00005555FF55FF555500AA005555FF55FF55550000AA00FF5500550055FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555
FFFF00AAAA55AA0055555500AA55AA55AA0055555500AA55AAAA00FFFF555555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF
FFFF00AAAA0055FF55FFFF5555AA00AA5555FFFF55FF5500AAAA00FFFFFF55FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
AAFF5555AA55AA00005555000055FF55000055550000AA55AA5555FFAA55FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
550055000000FF5555FFFF5555FFFFFF5555FFFF5555FF000000550055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF555555FF555500AA55FFAAFFFFFFFFFFAAFF55AA005555FF555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF55FFFFFF55FF550000AAAAAAAAAAAAAA000055FF55FFFFFF55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55AAFF55FFAAAA55AA5555AA5555AA55AAAAFF55FFAA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF5500550055FF00000055AA55000000FF5500550055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF555555FFFF00AAFF000000FFAA00FFFF555555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF55FFFFFF00AAAAAA55AAAAAA00FFFFFF55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55AAFF5555AA555555AA5555FFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55005500000055000000550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555555FF555555FF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55FFFFFF55FFFFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AAFF55FFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5500550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.82457 0.588183 1.91188 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF5500AAAA000055555555FFFFFFFFFFAA5500555500AA5555FFFF550000005555000000
AAAA5555AA00FF005500AAAAFFFFFFFFFFAAAA005500FF00AA5555AAAA00000055550000
0055FFFF5555AA0055550055AAFFFFFFFFFF555555550000AAAA0055FF
FFFF5500AA5555FFFFAAFFFFFFFFFFFF000055FFFF5500AA0000000055FF55005555FF55
5555550000FFAA555500FF00000000000000FF005555AAFF000055555555FF55550055FF
5500000000AA0055FFFF550000FFFFFFFFFFFFAAFFFF5555AA0055FFFF
FFFFFF5500AA00000000FFFFFFFFFFFF0055FFFFFFFF555555AA5555FFFFFF5555000000
AA000055FF55AA0000AAAAAA5555FF5555AAAAAA0000AA55FF550000AA0000005555FFFF
FF5555AA555555FFFFFFFF5500FFFFFFFFFFFF00000000AA0055FFFFFF
FFFFFFFF5500AAAA00AAAAAAAAAAAAAAAA000000000000555500AA00000000005555FF55
00AAAA00000055AA55555555550000005555555555AA55000000AAAA0055FF5555000000
0000AA005555000000000000AAAAAAAAAAAAAAAA00AAAA0055FFFFFFFF
FFFFFFFFFF5500AA55555555555555555555AA55AA5555FFFF555555FF5500FF55FFFFFF
55555555FF00AA00555500550055FF55005500555500AA00FF55555555FFFFFF55FF0055
FF555555FFFF5555AA55AA55555555555555555555AA0055FFFFFFFFFF
FFFFFFFFFFFF5500AA000055550055550055555500AA00000000AA00000055FFAAAAAAAA
AAFFAAAAFF555555FFFF550055FFFFFF550055FFFF555555FFAAAAFFAAAAAAAAAAFF5500
0000AA00000000AA005555550055550055550000AA0055FFFFFFFFFFFF
FFFFFFFFFFFFFF5500AAAA000055FFFF5500555500FF0055FF555555AAAA000000FF0000
FF00FF000000AA0000000055FFFFFFFFFF5500000000AA000000FF00FF0000FF000000AA
AA555555FF5500FF0055550055FFFF550000AAAA0055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF5500AA5555FFFFFFFF550000AAFF55000000AA0000FF0055FF55AAAA
55FF55AAAA555555AA5555FFFFFFFFFFFFFF5555AA555555AAAA55FF55AAAA55FF5500FF
0000AA00000055FFAA000055FFFFFFFF5555AA0055FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5500AA000000000000AAFF000000AAAA555555AAAAAA00000055AA
000000AA5500555500AA000000000000000000AA0055550055AA000000AA55000000AAAA
AA555555AAAA000000FFAA000000000000AA0055FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5500AAAA00AAAA00AA55FF5555AA0055550055AA0055FF550055
AA55AA550055FFFF5500AAAA5555FF5555AAAA0055FFFF550055AA55AA550055FF5500AA
5500555500AA5555FF55AA00AAAA00AAAA0055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5500AA55555555AA000000AA0055FFFF555500AAFFFFFF5555
00AA005555FFFFFFFF5555555500000055555555FFFFFFFF555500AA005555FFFFFFAA00
5555FFFF5500AA000000AA55555555AA0055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5500AA0000555555AAAA0055FFFFFFFF55FF0000000000AA
00AA555500000000000055550055FF550055550000000000005555AA00AA0000000000FF
55FFFFFFFF5500AAAA5555550000AA0055FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF5500AAAA000055555555FFFFFFFFFFFFAA5555AAAA5555
55AA0000AAAA5555FF55000055FFFFFF55000055FF5555AAAA0000AA555555AAAA5555AA
FFFFFFFFFFFF555555550000AAAA0055FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA5555FFFFAAFFFFFFFFFFFFFF00005555555500
0055AA55555555000000AAAA0000000000AAAA00000055555555AA550000555555550000
FFFFFFFFFFFFFFAAFFFF5555AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA00000000FFFFFFFFFFFFFF0055FFFFAAAAFF
0055555500555500FF5500AA5555FF5555AA0055FF0055550055555500FFAAAAFFFF5500
FFFFFFFFFFFFFF00000000AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAAA00AAAAAAAAAAAAAAAAAA00000000FF00
FF55FFFF55005500FFFF5500AA000000AA0055FFFF00550055FFFF55FF00FF00000000AA
AAAAAAAAAAAAAAAA00AAAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA5555555555555555555555AA55AAAAAA
55FFFFFFFF555500FFFFFF555555FF555555FFFFFF005555FFFFFFFF55AAAAAA55AA5555
555555555555555555AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA0000555500555500555500AA0055AA
0000000000005500FFFFFFFFAAFFFFFFAAFFFFFFFF0055000000000000AA5500AA005555
0055550055550000AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAAA000055FFFF55005555AA00AA00
55FF5555FF00AA00FFFFFFFF0000000000FFFFFFFF00AA00FF5555FF5500AA00AA555500
55FFFF550000AAAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA5555FFFFFFFF550000AA555555
FFFFFFAAAAAA5500FFFFFFFF0055FF5500FFFFFFFF0055AAAAAAFFFFFF555555AA000055
FFFFFFFF5555AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA000000000000AAFF0000AA00
00000000FF0000AAAAAAAAAAAA000000AAAAAAAAAAAA0000FF0000000000AA0000FFAA00
0000000000AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAAA00AAAA00AA55FF555555
FF5555AAAAAA5555555555555555FF5555555555555555AAAAAA5555FF555555FF55AA00
AAAA00AAAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA55555555AA000000AA00
000055555555550055550055550000005555005555005555555555000000AA000000AA55
555555AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA0000555555AAAA0055
FF55550000550055FFFF55005555FF55550055FFFF55005500005555FF5500AAAA555555
0000AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAAA000055555555FF
FFFF55FF005555FFFFFFFF55550000005555FFFFFFFF555500FF55FFFFFF555555550000
AAAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA5555FFFFAAFFFF
FFFFFFAA55550000000000005555FF55550000000000005555AAFFFFFFFFFFAAFFFF5555
AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA00000000FFFF
FFFFFF00005555FF5555AA55550000005555AA5555FF55550000FFFFFFFFFF00000000AA
0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAAA00AAAAAA
AAAAAAAA55550000005555550055FF55005555550000005555AAAAAAAAAAAAAA00AAAA00
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA55555555
55555555550055FF5500550055FFFFFF5500550055FF5500555555555555555555AA0055
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA000055
550055550055FFFFFF550055FFFFFFFFFF550055FFFFFF550055550055550000AA0055FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAAA00
0055FFFF55000000000055FFFFFFFFFFFFFF55000000000055FFFF550000AAAA0055FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA55
55FFFFFFFF5500FF5555FFFFFFFFFFFFFFFFFF5555FF0055FFFFFFFF5555AA0055FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA
000000000000AAFF55FFFFFFFFFFFFFFFFFFFFFF55FFAA000000000000AA0055FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500
AAAA00AAAA00AA55FFFFFFFFFFFFFFFFFFFFFFFFFF55AA00AAAA00AAAA0055FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
00AA55555555AA000000000000000000000000000000AA55555555AA0055FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
5500AA0000555555AAAA00FF5555FF5555FF00AAAA5555550000AA0055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5500AAAA000055555555FFAAFFFFFFAAFF555555550000AAAA0055FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF5500AA5555FFFFAAFFFF0000000000FFFFAAFFFF5555AA0055FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5500AA00000000FFFF0055FF5500FFFF00000000AA0055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF5500AAAA00AAAAAAAA000000AAAAAAAA00AAAA0055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF5500AA555555555555FF555555555555AA0055FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF5500AA0000555500000055550000AA0055FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5500AAAA000055FF550000AAAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF5500AA5555FFFFFF5555AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5500AA0000000000AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5500AAAA00AAAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5500AA55AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5500AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.82457 0.782187 1.91188 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF55AA000000AAAAAAAAAAAAAA00005555005500AAFF55AAAAAAAAAAAAAA00AAAA000000
AAAAAA00FF5555AA5555FF00AAAAAAAAAA00FF5555AA5555FF00AAAAAA000000AAAA00AA
AAAAAAAAAAAA55FFAA00550055550000AAAAAAAAAAAAAA000000AA55FF
FFFF55AA5555AAFF55AAAAAAAAAA00AA5500FF00550055AAAAAA55AAFF55AA55AAAA00AA
AAAAAAAA0000FF00FF0000AAAAAAAAAAAAAA0000FF00FF0000AAAAAAAAAA00AAAA55AA55
FFAA55AAAAAA55005500FF0055AA00AAAAAAAAAA55FFAA5555AA55FFFF
FFFFFF55AA00550055AAAA55AAAAAA00FF005555AA00AA55AAAA550000AA55FFFF00AAAA
AAAAAAAAAA00AA00AA00AAAAAAAAAAAAAAAAAA00AA00AA00AAAAAAAAAAAAAA00FFFF55AA
000055AAAA55AA00AA555500FF00AAAAAA55AAAA55005500AA55FFFFFF
FFFFFFFF55AA5500FF00FFFF55AAFF550055FFFF5555AAAAFF55AA00AAAA55005555AAAA
AAAAAAAAAA5555FF00AAAAAAAAAAAAAAAAAAAAAA00FF5555AAAAAAAAAAAAAA55550055AA
AA00AA55FFAAAA5555FFFF550055FFAA55FFFF00FF0055AA55FFFFFFFF
FFFFFFFFFF55AA00AA00AA0000FFFFFF5500AA0000FF00FFFFFF5555AAFF000000FF00FF
FF00FFFF00FF0000AAAAAAAAAAAAAAAAAAAAAAAAAA0000FF00FFFF00FFFF00FF000000FF
AA5555FFFFFF00FF0000AA0055FFFFFF0000AA00AA00AA55FFFFFFFFFF
FFFFFFFFFFFF55AA55FF00FF5500555500AAAAAA00AA00AA0000AA550000AAAA00AA00AA
000000AA00AA00AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA00AA00AA000000AA00AA00AAAA00
0055AA0000AA00AA00AAAAAA0055550055FF00FF55AA55FFFFFFFFFFFF
FFFFFFFFFFFFFF55AA000000AA55555555AAAAAAAA00FF5555AA55AA00AAAAAAAA00FF55
55AA5555FF00AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA00FF5555AA5555FF00AAAAAAAA
00AA55AA5555FF00AAAAAAAA55555555AA000000AA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55AA5555AAFFAAFFAAFF55AAAAAA0000FF00FF00AAAAAAAAAAAA0000
FF00FF0000AAAAAAAAAAAAAAAA55FF55AAAAAAAAAAAAAAAA0000FF00FF0000AAAAAAAAAA
AA00FF00FF0000AAAAAA55FFAAFFAAFFAA5555AA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55AA0055005500550055AAFF00AAAA000000AAAAAAAAAAAAAAAA00
AA00AA00AAAAAAAAAAAAAA55AAFFFFFFAA55AAAAAAAAAAAAAA00AA00AA00AAAAAAAAAAAA
AAAA000000AAAA00FFAA5500550055005500AA55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55AA5500FF0055AA550000AAAAAAAA00AAAAAAAAAAAAAAAAAA55
55FF00AAAAAAAAAAAAAAAA550000AA000055AAAAAAAAAAAAAAAA00FF5555AAAAAAAAAAAA
AAAAAA00AAAAAAAA000055AA5500FF0055AA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AA00AA00AA55AA00AAAAAAAAAAAA00FFAA55AAAAAAAA55AA
005555AAAAAA55AAAAAA55AA00AAAAAA00AA55AAAAAA55AAAAAA555500AA55AAAAAAAA55
AAFF00AAAAAAAAAAAA00AA55AA00AA00AA55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AA55FF00FF00AAAAAAAAAAAAAAAA000055AAAAAAAA5500
0000FF00AAFF55FFAA00FF00AAAAAAAAAA00FF00AAFF55FFAA00FF00000055AAAAAAAA55
0000AAAAAAAAAAAAAAAA00FF00FF55AA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF55AA000000AAAAAAAAAAAAAAAAAAAA00AA55AAAA55AA00
AAAA000000555555000000AAAAAAAAAAAAAA000000555555000000AAAA00AA55AAAA55AA
00AAAAAAAAAAAAAAAAAAAA000000AA55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5555AAFF55AAAAAAAAAAAAAA5555FFFF00FF00AA
AAAAAA00AAAAFFAAAA00AAAAAAAAAAAAAAAAAA00AAAAFFAAAA00AAAAAAAA00FF00FFFF55
55AAAAAAAAAAAAAA55FFAA5555AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00550055AAAA55AAAAAAAA5500AA000000AAAA
AAAAAAAA00FFFFFF00AAAAAAAAAAAAAAAAAAAAAA00FFFFFF00AAAAAAAAAAAA000000AA00
55AAAAAAAA55AAAA55005500AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5500FF00FFFF55AAFF555555AAAA00AAAAAA
AAAAAAAA5555005555AAAAAAAAAAAAAAAAAAAAAA5555005555AAAAAAAAAAAAAA00AAAA55
5555FFAA55FFFF00FF0055AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00AA00AA0000FFFFFF55FFFF00FF55AAAA
55AAAA55AA0055FFFF55AAAAAAAAAAAAAAAAAA55FFFF5500AA55AAAA55AAAA55FF00FFFF
55FFFFFF0000AA00AA00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA55FF00FF5500555500AA000000AA55AA
AAFF00AA55AA5500555555FF5555FF5555FF5555550055AA55AA00FFAAAA55AA000000AA
0055550055FF00FF55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA000000AA55555555AAAA00AAAA5500
005555AAFFFF000000FF0000AA550055AA0000FF000000FFFFAA5555000055AAAA00AAAA
55555555AA000000AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5555AAFFAAFFAAFF55AA55FFAAAA
00AA550000AA00AAAA0000000055AA5500000000AAAA00AA000055AA00AAAAFF55AA55FF
AAFFAAFFAA5555AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA0055005500550055AAFFFFFF00
FF555555AA55AA55AAAA00AAAA005500AAAA00AAAA55AA55AA555555FF00FFFFFFAA5500
550055005500AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5500FF0055AA550000AA0000
00AA5500AAFFAA00550000005500FF00550000005500AAFFAA0055AA000000AA000055AA
5500FF0055AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00AA00AA55AA00AAAAAA00
AAAA5500FFFFFF0055AA5555AA00AA00AA5555AA5500FFFFFF0055AAAA00AAAAAA00AA55
AA00AA00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA55FF00FF00AAAAAAAAAA
00FFAAAA0000AA00AA55FFFF55AA55AA55FFFF55AA00AA0000AAAAFF00AAAAAAAAAA00FF
00FF55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA000000AAAAAAAAAAAA
AA00005500FF55AA55FFFFFFFF555555FFFFFFFF55AA55FF00550000AAAAAAAAAAAAAA00
0000AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5555AAFF55AAAAAA
AAAA00AA555500AAFFFFFFFFFFFFAAFFFFFFFFFFFFAA005555AA00AAAAAAAAAA55FFAA55
55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00550055AAAA55
AAAAAA00FF00000055550055550055005555005555000000FF00AAAAAA55AAAA55005500
AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5500FF00FFFF
55AAFF550055FF0055AA00AA5500FF0055AA00AA5500FF550055FFAA55FFFF00FF0055AA
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00AA00AA00
00FFFFFF5500AA00AA55AA55AA00AA00AA55AA55AA00AA0055FFFFFF0000AA00AA00AA55
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA55FF00FF
5500555500AAAAAA00FF00FF00AAAAAA00FF00FF00AAAAAA0055550055FF00FF55AA55FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA000000
AA55555555AAAAAAAA000000AAAAAAAAAA000000AAAAAAAA55555555AA000000AA55FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5555
AAFFAAFFAAFF55AAAAAA00AAAAAAAAAAAAAA00AAAAAA55FFAAFFAAFFAA5555AA55FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00
55005500550055AAFF00AAAAAAAAAAAAAAAAAA00FFAA5500550055005500AA55FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA
5500FF0055AA550000AAAAAAAAAAAAAAAAAAAAAA000055AA5500FF0055AA55FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
AA00AA00AA55AA00AAAAAAAAAAAA55AAAAAAAAAAAA00AA55AA00AA00AA55FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
55AA55FF00FF00AAAAAAAAAA55FFAAFF55AAAAAAAAAA00FF00FF55AA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55AA000000AAAAAAAAAAAA5500550055AAAAAAAAAAAA000000AA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF55AA5555AAFF55AAAAAA5500FF0055AAAAAA55FFAA5555AA55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55AA00550055AAAA55AA00AA00AA55AAAA55005500AA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF55AA5500FF00FFFF55AA55AA55FFFF00FF0055AA55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55AA00AA00AA0000FFAAFF0000AA00AA00AA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF55AA55FF00FF5500550055FF00FF55AA55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55AA000000AA555555AA000000AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55AA5555AAFFAAFFAA5555AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55AA00550055005500AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55AA5500FF0055AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AA00AA00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AA55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.82457 0.97619 1.91188 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF55555555555555AAAA55AAAAFF0000FFAA55AAFF0055FF555555AAAA55000000AA00FF
AAFFAAFF5555AA55AA55FFAA00AAAAAA00AAFF55AA55AA5555FFAAFFAAFF00AA00000055
AAAA555555FF5500FFAA55AAFF0000FFAAAA55AAAA55555555555555FF
FFFF55FFFFAAFFFF55AAFFFF00FF5555FF0000AA5555FFFFFF55FFFF0000AAFF00AA55AA
5500FF00555500AA005555AAFF000000FFAA555500AA00555500FF0055AA55AA00FFAA00
00FFFF55FFFFFF5555AA0000FF5555FF00FFFFAA55FFFFAAFFFF55FFFF
FFFFFF5500FFFFFFFFAA5555AAAA0000AAAA55AA0000AAAA00AA00AAAA55AA00AAFF55FF
AAAA5555FFFF555555FFFFAA5555FF5555AAFFFF555555FFFF5555AAAAFF55FFAA00AA55
AAAA00AA00AAAA0000AA55AAAA0000AAAA5555AAFFFFFFFF0055FFFFFF
FFFFFFFF5555AA5555AAFFAAAAAAAA55AA00555555FF55AAFF00FFAA550055AAAAAA0000
55AA0000AAAA0000AA00AAAAAAFFFFFFAAAAAA00AA0000AAAA0000AA550000AAAAAA5500
55AAFF00FFAA55FF55555500AA55AAAAAAAAFFAA5555AA5555FFFFFFFF
FFFFFFFFFF55FFAAFFAA55555555555500AAFFFFAAAA0000FF5555AAFFAA0000FFFF00AA
FFAA55AAAAAAAA55AAFF00FF0000550000FF00FFAA55AAAAAAAA55AAFFAA00FFFF0000AA
FFAA5555FF0000AAAAFFFFAA00555555555555AAFFAAFF55FFFFFFFFFF
FFFFFFFFFFFF5500AAAAAAFFAAFFFFAAAA5500FF55AAFF00AAAAFFFF0055AAAA5555AAAA
AA0055555555555500AAAA5555FF55FF5555AAAA0055555555555500AAAAAA5555AAAA55
00FFFFAAAA00FFAA55FF0055AAAAFFFFAAFFAAAAAA0055FFFFFFFFFFFF
FFFFFFFFFFFFFF5555555555AA00AAAAAAAAFF00555555AAAAAAAA00AAFFAA5500555555
5555FFFFAAFFAAAAFF000000AA00AA00AA000000FFAAAAFFAAFFFF55555555550055AAFF
AA00AAAAAAAA55555500FFAAAAAAAA00AA5555555555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55FFFFAAFF555555555555AAAAFFAAAAAAAAAAAA55000000AAFFFFAA
FFAAAA00AA55555555AAAA55AA00FF00AA55AAAA55555555AA00AAAAFFAAFFFFAA000000
55AAAAAAAAAAAAFFAAAA555555555555FFAAFFFF55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5500FFFFFFAAFFAAFFFF55AA00AA55FFAA55FFAAFF00AAFF550000
0055AA00FFFFAAAAFFFF0000AA55AA55AA0000FFFFAAAAFFFF00AA5500000055FFAA00FF
AAFF55AAFF55AA00AA55FFFFAAFFAAFFFFFF0055FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5555AA555555AA00AAAAFF555555000000AAAAAA00FFFFFFAA00
FFAAAAAA5555AA005500FFAA0055555500AAFF005500AA5555AAAAAAFF00AAFFFFFF00AA
AAAA000000555555FFAAAA00AA555555AA5555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55FFAAFFAAAAAA5500AAAAFFAAAA55AAAAAAAAAA5555AA55FF
5500AA55FFFF55AAAAFF0055AAAAFFAAAA5500FFAAAA55FFFF55AA0055FF55AA5555AAAA
AAAAAA55AAAAFFAAAA0055AAAAAAFFAAFF55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5500AAAAAAAAAAFF0000FF55AAFFAA5500AA550055555500
00AAFF55FF0055555555AAAAFF55AA55FFAAAA5555555500FF55FFAA00005555550055AA
0055AAFFAA55FF0000FFAAAAAAAAAA0055FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF55555555555555AAAA555500AAAAAAFF0000AAFFFFAAFF
00AA555500FFAAFFAAFFFF00005555550000FFFFAAFFAAFF005555AA00FFAAFFFFAA0000
FFAAAAAA005555AAAA55555555555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFFAAFFFF55AAFFAAAA55FFAA5555FF55AA555555
AAAAAAFFAA00AA555555AA55AAAAFFAAAA55AA555555AA00AAFFAAAAAA555555AA55FF55
55AAFF55AAAAFFAA55FFFFAAFFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFFFFFFFAA5555555500FFFFAAAA000000AA00
000000FF55AAAAAAFFAAAAAAFF55AA55FFAAAAAAFFAAAAAA55FF00000000AA000000AAAA
FFFF0055555555AAFFFFFFFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA5555AAFFAAAAFFAA00AAAAAAAA55AAAAAA
55AAAA555500AA55FF00FFFF0055555500FFFF00FF55AA005555AAAA55AAAAAA55AAAAAA
AA00AAFFAAAAFFAA5555AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAAFFAA55555555AA00FF0000FFFFAA55FF
AAAAAAAAFFAA005555AAAA00AAFFAAFFAA00AAAA555500AAFFAAAAAAAAFF55AAFFFF0000
FF00AA55555555AAFFAAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAAAAAFFAAFFFF00AAAA55AA55555500
FF00FF00FF55AAAAFFFF00FFAA555555AAFF00FFFFAAAA55FF00FF00FF00555555AA55AA
AA00FFFFAAFFAAAAAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555555555AA00AAAA55FFAAAAAAFFAAAA
5555FF00AAAAFF55AA5555FF0000AA0000FF5555AA55FFAAAA00FF5555AAAAFFAAAAAAFF
55AAAA00AA5555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFFAAFF5555555500FFFF000055AA
FFAAAA00FF00005555550055FF555555FF55005555550000FF00AAAAFFAA550000FFFF00
55555555FFAAFFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFFFFFAAFFAAFF0055FF555500
AAAAAAAA5555FF55FFFF55550000AA00005555FFFF55FF5555AAAAAAAA005555FF5500FF
AAFFAAFFFFFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA555555AA00AAFFFFFFAAFF
00FF00FFFFAAAA000055FFFFAA00FF00AAFFFF550000AAAAFFFF00FF00FFAAFFFFFFAA00
AA555555AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAAFFAAAAAA5500005500AA
AA5555FF0055AA00FFAAAA00AA55AA55AA00AAAAFF00AA5500FF5555AAAA0055000055AA
AAAAFFAAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAAAAAAAAAFF00AA00FF
0000AA00AAFFAA55AA55FFAA0055555500AAFF55AA55AAFFAA00AA0000FF00AA00FFAAAA
AAAAAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555555555AAAAAA55
55FF55AAAAAA005555550000FFAAFFAAFF000055555500AAAAAA55FF5555AAAAAA555555
55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFFAAFFFF55AAFF55
FFFFFFAA5500AAFFFF55FF5555AA00AA5555FF55FFFFAA0055AAFFFFFF55FFAA55FFFFAA
FFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFFFFFFFAA5555
00FF5500AA00FF00550055FFFFAA55AAFFFF55005500FF00AA0055FF005555AAFFFFFFFF
0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA5555AAFFAA
FF005555FFAA00AAFFAA000055FFAAFF550000AAFFAA00AAFF555500FFAAFFAA5555AA55
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFAAFFAA5555
55AAAAFFFFFF00AA555555FF55FF00FF55FF555555AA00FFFFFFAAAA555555AAFFAAFF55
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AAAAAAFF
AAFF55AA5555AAAAAAFFFF550055FF550055FFFFAAAAAA5555AA55FFAAFFAAAAAA0055FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555555555
AA00AA00555500AA55FF005555FFFFFF555500FF55AA00555500AA00AA5555555555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FFFFAA
FF555555FFFF55555500FFAAFFFFFFFFFFAAFF00555555FFFF555555FFAAFFFF55FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FF
FFFFAAFFFFFFFFAAFFAA00AA5555AA5555AA00AAFFAAFFFFFFFFAAFFFFFF0055FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555
AA555555AA5555AA00AA55AAFFAAAAAAFFAA55AA00AA5555AA555555AA5555FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
FFAAFFAAAAAAFFAA55AAFFAA5555555555AAFFAA55AAFFAAAAAAFFAAFF55FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
5500AAAAAAAAAA00555555AAFFAAFFAAFFAA55555500AAAAAAAAAA0055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55555555555555FFFFAAAAAA005500AAAAAAFFFF55555555555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF55FFFFAAFFFF5500FFFF00FFAAFF00FFFF0055FFFFAAFFFF55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5500FFFFFFFFAA00AAAA555555AAAA00AAFFFFFFFF0055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF5555AA5555AAFF000000AA000000FFAA5555AA5555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55FFAAFFAA5555FF555555FF5555AAFFAAFF55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF5500AAAAAAFFFFFFAAFFFFFFAAAAAA0055FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5555555555AA555555AA5555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55FFFFAAAAAAFFAAAAAAFFFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5500FF00FFFFFF00FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5555AAAA00AAAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55FFAA55AAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5500AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.92061 0.200176 2.00792 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF5555AAAAAA55FFAAAAAAFF000000555500005555FFFFAA555555AAAAFF55AAFFFFFF55
55FF555555FFFFFFAAAAFF005555FF555500FFAAAAFFFFFF555555FF5555FFFFFFAA55FF
AAAA555555AAFFFF555500005555000000FFAAAAAAFF55AAAAAA5555FF
FFFFAAFFAAAAFF0055005555AAFF55AAAA55FFAAFFFFFFFF5555FF55FFFFFFAAAA0055FF
555555FF555555AA0000AA55FF555555FF55AA0000AA555555FF555555FF5500AAAAFFFF
FF55FF5555FFFFFFFFAAFF55AAAA55FFAA5555005500FFAAAAFFAAFFFF
FFFFFF55000055FFAAFF5555FFFFFFAAAAFF005555555555AAAA5555FF0055FFFF55AAAA
00FFAA00AAFFFFAAAAAAAAFFFFFFAAFFFFFFAAAAAAAAFFFFAA00AAFF00AAAA55FFFF5500
FF5555AAAA555555555500FFAAAAFFFFFF5555FFAAFF55000055FFFFFF
FFFFFFFFAA55FF550055FF5555AA00555500FFFFAA00FFAA0000AAFFFFFF00AA5555FFFF
55AA000000AA550055005555AA00AA00AA555500550055AA000000AA55FFFF5555AA00FF
FFFFAA0000AAFF00AAFFFF00555500AA5555FF550055FF55AAFFFFFFFF
FFFFFFFFFF5555AAAAAA5555FF55FFAA00FFFFFFFF55AA00000000AA5555AAFFAAFFFFFF
FFAAAAAAAAAAFF00FFAA55AAAAFF55FFAAAA55AAFF00FFAAAAAAAAAAFFFFFFFFAAFFAA55
55AA00000000AA55FFFFFFFF00AAFF55FF5555AAAAAA5555FFFFFFFFFF
FFFFFFFFFFFFAAFFAAAAFF00AAAA55000000FF5500FFAAAAAAAAAAAAFF00AA0055555555
55550000AA0000FFFFFF55550055FF55005555FFFFFF0000AA000055555555555500AA00
FFAAAAAAAAAAAAFF0055FF00000055AAAA00FFAAAAFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFF55000055FFAAAAFFFF00FFFFFFAA5500005500550055FFAAAAAA55AAAA
55AAAAAAAAFF55AA00AAAA55AAFFFFFFAA55AAAA00AA55FFAAAAAAAA55AAAA55AAAAAAFF
5500550055000055AAFFFFFF00FFFFAAAAFF55000055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55FF55005500AAAAAA0055FFFFAA55FF55AAAAAA5500005555FFFF
555500005500FFAAAAAAFFAA0000FF0000AAFFAAAAAAFF005500005555FFFF5555000055
AAAAAA55FF55AAFFFF5500AAAAAA00550055FF55AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555AAAAAA55FFFF55FFAA00AAAAFFFFFFAAAAFFAAFF55AAAA5555
AAAA55FFAAFF5500550055FFFF00FF00FFFF5500550055FFAAFF55AAAA5555AAAA55FFAA
FFAAAAFFFFFFAAAA00AAFF55FFFF55AAAAAA5555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFAAAAFF0055AAAA0000005500AA55550055FFFFFFAAAAFFFF
AAAAFF000055AAAAAA55FF5500FFFFFF0055FF55AAAAAA550000FFAAAAFFFFAAAAFFFFFF
55005555AA0055000000AAAA5500FFAAAAFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55000055FFAAFFAAAAAAAAAA55FFFFAAFF5555AA55550055AA
0000AA55FFAAFFAAAAFFFFFFAA555555AAFFFFFFAAAAFFAAFF55AA0000AA55005555AA55
55FFAAFFFF55AAAAAAAAAAFFAAFF55000055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55FF550055FFFF55FFFF5555555500FFAAFFAAFF00FFAA
AAAAAAFF005555550055FF005555FF555500FF550055555500FFAAAAAAAAFF00FFAAFFAA
FF0055555555FFFF55FFFF550055FF55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF5555AAAAAA5555AAAA00AAFFFFAAFF550055FFFFFF0000
55550000FFFFAAFFFF00AA55FF555555FF55AA00FFFFAAFFFF000055550000FFFFFF5500
55FFAAFFFFAA00AAAA5555AAAAAA5555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAAAFF00AA000000AA550000FFAA55AA00AA55FF
AAFF00FFFFFFFF5500FFFF555555FF555555FFFF0055FFFFFFFF00FFAAFF55AA00AA55AA
FF000055AA000000AA00FFAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55000055FFAAAAAAAAAAFFFF00FF55FF55FFAAAA55
5500FFFFFFFFFFFFAA555555FF555555FF555555AAFFFFFFFFFFFF005555AAAAFF55FF55
FF00FFFFAAAAAAAAAAFF55000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF5500550000AA00AA55FF00AAAA55005555
FF55AA5500FF0055FFFFAAFFFFFFAAFFFFFFAAFFFF5500FF0055AA55FF55550055AAAA00
FF55AA00AA0000550055FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAAAAA55FFAAAAAAFF0000005555FFAA00
FF00AA00FFFFFF00AAAA0000FF005500FF0000AAAA00FFFFFF00AA00FF00AAFF55550000
00FFAAAAAAFF55AAAAAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAAAFF0055005555AAFF55AAAA550000
00FFFF55AA0055FFAAAAFF55AA55FF55AA55FFAAAAFF5500AA55FFFF00000055AAAA55FF
AA5555005500FFAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55000055FFAAFF5555FFFFFFAAAAFFFF00
FFFFFFFFAAAAAA55005555AAAAFFFFFFAAAA55550055AAAAAAFFFFFFFF00FFFFAAAAFFFF
FF5555FFAAFF55000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF550055FF5555AA00555500FF55
AA00AA550000AA00FFFFAAFFAAAA00AAAAFFAAFFFF00AA000055AA00AA55FF00555500AA
5555FF550055FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAAAAA5555FF55FFAA00FFFFFF
AAAAAAFF00FFFF55AA005500AA000000AA005500AA55FFFF00FFAAAAAAFFFFFF00AAFF55
FF5555AAAAAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAAAFF00AAAA55000000FF55
00550000FFFFFFFFAAAAAA55FFFF00FFFF55AAAAAAFFFFFFFF0000550055FF00000055AA
AA00FFAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55000055FFAAAAFFFF00FFFFFF
AA55AAFF5500AA5555005555FF000000FF5555005555AA0055FFAA55AAFFFFFF00FFFFAA
AAFF55000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55005500AAAAAA0055
FFFFAAAA00FFFF5555FFAAFFFFFF00FFFFFFAAFF5555FFFF00AAAAFFFF5500AAAAAA0055
0055FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAAAAA55FFFF55FFAA
00AAAAFFAA5555AAAA550055FF000000FF550055AAAA5555AAFFAAAA00AAFF55FFFF55AA
AAAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAAAFF0055AAAA00
00005500AA00FFAAAAFFFF00AAAAAAAAAA00FFFFAAAAFF00AA0055000000AAAA5500FFAA
AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55000055FFAAFFAAAA
AAAAAA55FFFF0000AA00AA55FFFF55FFFF55AA00AA0000FFFF55AAAAAAAAAAFFAAFF5500
0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF550055FFFF
55FFFF5555AA55FFAAAAAAFF0055FF5500FFAAAAAAFF55AA5555FFFF55FFFF550055FF55
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAAAAA5555
AAAA00AAFFFF555555005555AAFFFFFFAA555500555555FFFFAA00AAAA5555AAAAAA5555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAAAFF00
AA000000AAAA00FFAAFF5555FFFFFFFFFF5555FFAAFF00AAAA000000AA00FFAAAAFFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55000055FF
AAAAAAAAAAFFAA550055AAAA5500FF0055AAAA550055AAFFAAAAAAAAAAFF55000055FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55
00550000AA00AA00FFFFAAAAFF00FF00FFAAAAFFFF00AA00AA0000550055FF55AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA
AAAA55FFAAAAAAFF5500AA0000FFFFFF0000AA0055FFAAAAAAFF55AAAAAA5555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
AAAAFF005500555555FFAAAAAAAA00AAAAAAAAFF555555005500FFAAAAFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
000055FFAAFF5555FF5500555500000055550055FF5555FFAAFF55000055FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55FF550055FF555555FFAAFFFF00FFFFAAFF555555FF550055FF55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5555AAAAAA5555FF55555500AAAAAA00555555FF5555AAAAAA5555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFAAAAFF00AAAA55AAAAAAFFAAAAAA55AAAA00FFAAAAFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55000055FFAAAAFFFF55FFFFFF55FFFFAAAAFF55000055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA55FF55005500AA55AA00AA55AA00550055FF55AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF5555AAAAAA55FFFFAAAAAAFFFF55AAAAAA5555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFAAAAFFFFFFFF55FFFFFFFFAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55000055AA0055FF5500AA55000055FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55FF55FFAA00AAFF55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555AAAA000000AAAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFAAAAAAAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55000055000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.92061 0.39418 2.00792 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF555555FFAA55FF0055FF550000AAFFFFAA55FF5555FF5555FFFF55FFFF5555555555AA
FFFF00FFFF550000FF5555555555555555555555FF000055FFFF00FFFFAA5555555555FF
FF55FFFF5555FF5555FF55AAFFFFAA000055FF5500FF55AAFF555555FF
FFFFAAFFFFFF5555AAFFFFFFAA55FFFFFFFF5555AA00FF555555AA55AA555555555555FF
FFFFFF005555FFAA55555555555555555555555555AAFF555500FFFFFFFF555555555555
AA55AA555555FF00AA5555FFFFFFFF55AAFFFFFFAA5555FFFFFFAAFFFF
FFFFFF5500FF5555FFFFFFFFFF55550055FF00AAFFAA555555FF55FF55FF555555555555
000055FFAAFFFFFF55555555555555555555555555FFFFFFAAFF550000555555555555FF
55FF55FF555555AAFFAA00FF55005555FFFFFFFFFF5555FF0055FFFFFF
FFFFFFFFAA555555550000550000FFAA55AA55FFFFFF555555FF00AAAA5555FF555555FF
55AAFFFFFF5500FF55555555555555555555555555FF0055FFFFFFAA55FF555555FF5555
AAAA00FF555555FFFFFF55AA55AAFF000055000055555555AAFFFFFFFF
FFFFFFFFFF555555FF55AAFFFF00FF55FF55FF550055FF555555AAFFAAAA55AA55AA0055
55FFFFFFFFFFAA555555555555555555555555555555AAFFFFFFFFFF555500AA55AA55AA
AAFFAA555555FF550055FF55FF55FF00FFFFAA55FF555555FFFFFFFFFF
FFFFFFFFFFFFAAFFFFFFAAAA000000AA555555AAAAAA55555555FFFFFF55FF55FF55FFAA
FFFFFFFFFFFFFF555555555555555555555555555555FFFFFFFFFFFFFFAAFF55FF55FF55
FFFFFF55555555AAAAAA555555AA000000AAAAFFFFFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFF5500FF55FFFF00FFFF555555FFFF55FF5555FF55005555FF00AA00FF55
FF0055005500FF555555555555555555555555555555FF0055005500FF55FF00AA00FF55
550055FF5555FF55FFFF555555FFFF00FFFF55FF0055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5555550000005555FF55550055AA55AA00AA55FF5555AAFFAA5555
55AAFF00FFAA5555555555555555555555555555555555AAFF00FFAA555555AAFFAA5555
FF55AA00AA55AA55005555FF5555000000555555AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555555FFAA55FF555500AA55FF55FF55FFAAAA555555FFFFFF5555
FF55FF00FF55FF555555555555555555555555555555FF55FF00FF55FF5555FFFFFF5555
55AAAAFF55FF55FF55AA005555FF55AAFF555555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFFFF5555AA00FFFF555500AA0055FFFF5555555500555555
55AA000000AA5555555555555555555555555555555555AA000000AA5555555500555555
55FFFF5500AA005555FFFF00AA5555FFFFFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5500FF5555FFFF005500AA55FFFF00AAAA0055AAAA55FF5555
55FFFF00FFFF5555555555555555555555555555555555FFFF00FFFF555555FF55AAAA55
00AAAA00FFFF55AA005500FFFF5555FF0055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55555555000000FFFF555500FFFF55FFAAFFAAAA555555
FF5500000055FF555555555555555555555555555555FF5500000055FF555555AAAAFFAA
FF55FFFF005555FFFF00000055555555AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FF55AAFF5500FF000000AA0055FFFFFF55FF5555
55AAAAAAAAAA5555555555555555555555555555555555AAAAAAAAAA555555FF55FFFFFF
5500AA000000FF0055FFAA55FF555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAAAA00FFFFFF00FFFF55AA00AAAA00FF5555
55FFFF55FFFF5555555555555555555555555555555555FFFF55FFFF555555FF00AAAA00
AA55FFFF00FFFFFF00AAAAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FF55FFFF005500FFFFFFFFAAAAAAFFAA555555
5555AA55AA55555555555555555555555555555555555555AA55AA5555555555AAFFAAAA
AAFFFFFFFF005500FFFF55FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555555000000FFFFFFFFFFFF55FFFFFF555555
55FF55FF55FF5555555555555555555555555555555555FF55FF55FF55555555FFFFFF55
FFFFFFFFFFFF000000555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFAA55FF0055FF0055555500FF555555
55FF00AA00FF5555555555555555555555555555555555FF00AA00FF55555555FF005555
5500FF5500FF55AAFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF5555AAFFFFFF0000FFAA55555555
5555AAFFAA55555555555555555555555555555555555555AAFFAA555555555555AAFF00
00FFFFFFAA5555FFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FF5555FFFFFFFFFF00FF55FF555555
5555FFFFFF55555555555555555555555555555555555555FFFFFF5555555555FF55FF00
FFFFFFFFFF5555FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55555555000055000000AA5555FF55
5555FF0055555555555555555555555555555555555555555500FF555555FF5555AA0000
0055000055555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FF55AAFFFF00FFFF5555FF00
AA55AA55FF55555555555555555555555555555555555555FF55AA55AA00FF5555FFFF00
FFFFAA55FF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAAAA000000AA0055AA55
FFFFAAAA555555555555555555555555555555555555555555AAAAFFFF55AA5500AA0000
00AAAAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FF55FFFF00FFFF55AAAAFF
FFFFFF55FF55555555555555555555555555555555555555FF55FFFFFFFFAAAA55FFFF00
FFFF55FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555550000005555FFFF55
0000AAAA555555555555555555555555555555555555555555AAAA000055FFFF55550000
00555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFAA55FF555500FF
00FFFF55FF5555FF55555555555555555555555555FF5555FF55FFFF00FF005555FF55AA
FF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF5555AA00FFFF
FF0055555500AA555555555555555555555555555555AA0055555500FFFFFF00AA5555FF
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FF5555FFFF0055
00FFFFAA00FFFF555555555555555555555555555555FFFF00AAFFFF005500FFFF5555FF
0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55555555000000
FFFFFFFF55AA5555555555555555555555555555555555AA55FFFFFFFF00000055555555
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FF55AAFF
55000055FF55FF555555555555555555555555555555FF55FF55000055FFAA55FF555555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAAAA
00FFFF00AA0055FF55555555555555555555555555FF5500AA00FFFF00AAAAFFFFFFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FF55FF
FF0055FFAAAAAA555555555555555555555555555555AAAAAAFF5500FFFF55FF0055FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555555
000000FF55FFFF555555555555555555555555555555FFFF55FF000000555555AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555
FFAA55FF000055FF5555FF55555555555555FF5555FF550000FF55AAFF555555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
FFFF5555AAFF5555AA00FF55555555555555FF00AA5555FFAA5555FFFFFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
00FF5555FFFFFFAAFFAA555555555555555555AAFFAAFFFFFF5555FF0055FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA555555550055FFFFFF555555555555555555FFFFFF550055555555AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF555555FF55AA000055FF55555555555555FF550000AA55FF555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFFFFAAAAAAAA555555555555555555AAAAAAAAFFFFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5500FF55FFFF55FF55555555555555FF55FFFF55FF0055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA5555550000FF55555555555555FF0000555555AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF555555FFAA555555555555555555AAFF555555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFFFFF555555555555555555FFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5500FF555555555555555555FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5555555555555555555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555555FF555555FF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFFFFAAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5500FF55FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.92061 0.588183 2.00792 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF555500000000AAAAFFFFFFAAAA5555FF00AA0000005500550055AA00555555AA55FF00
AA55AA00FF00AAAA00AA555555FF00FF555555AA00AAAA00FF00AA55AA00FF55AA555555
00AA5500550055000000AA00FF5555AAAAFFFFFFAAAA000000005555FF
FFFFAA0055AAFF55FFFFFFFFFF55000000AA5555555555FFAA005500FFFFAA00FF555500
AAAA55555500AAAAFF5500000055555500000055FFAAAA00555555AAAA005555FF00AAFF
FF005500AAFF5555555555AA00000055FFFFFFFFFF55FFAA5500AAFFFF
FFFFFF55AAAA000055550055550000FFFF00550000000000AAAAAA55005555AA00000000
FF5500000055AA55550000FF0000000000FF00005555AA5500000055FF00000000AA5555
0055AAAAAA00000000005500FFFF000055550055550000AAAA55FFFFFF
FFFFFFFFAAAAFF55AAAA55FF555555550055AAAAAAAAAAAAAA00AAAA55FF5555AA0055AA
000000FFFF00AAAA55AA005555555555555500AA55AAAA00FFFF000000AA5500AA5555FF
55AAAA00AAAAAAAAAAAAAA550055555555FF55AAAA55FFAAAAFFFFFFFF
FFFFFFFFFF55005500FF55550000000055AAAA00AAAA00AAAA0055FF00AA00FFAAAAAA55
555555550055AA5555FF000000005500000000FF5555AA55005555555555AAAAAAFF00AA
00FF5500AAAA00AAAA00AAAA55000000005555FF00550055FFFFFFFFFF
FFFFFFFFFFFFAA55AA00000000FFFF000055FFFF0055FFAAAA00550055AA550055FFFF55
55FF5555FFAA00AAFFFFFF00FF000000FF00FFFFFFAA00AAFF5555FF5555FFFF550055AA
55005500AAAAFF5500FFFF550000FFFF00000000AA55AAFFFFFFFFFFFF
FFFFFFFFFFFFFF5555AA0055AA0000AA550000AA00550055FF000055AAAAFFFF00AA0000
5500550000AAAAAA0000AA00555555555500AA0000AAAAAA00005500550000AA00FFFFAA
AA550000FF55005500AA000055AA0000AA5500AA5555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00AA55AA5500AAAA5500AAAAAA550000AA55FF55FFFFFFFF0055AA
FF000055AA00AAAAFF55AA55000000000055AA55FFAAAA00AA550000FFAA5500FFFFFFFF
55FF55AA000055AAAAAA0055AAAA0055AA55AA00AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55AA55AA55AAFFAAAA55FFFF550000FF005500550055550055AAAA
0000FF00AAAAAA00AA00FF55555555555555FF00AA00AAAAAA00FF0000AAAA5500555500
55005500FF000055FFFF55AAAAFFAA55AA55AA55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA5555FFFFFF550000AA00FF0000AA55AA00FFFFAAFF5555AA
5500AA0055FF0055AA5500550000550000550055AA5500FF5500AA0055AA5555FFAAFFFF
00AA55AA0000FF00AA000055FFFFFF5555AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5500005555005500AA55555500AA5555FF0000AA00AA00FFAA
AA55FF0000555555FF00AA55AA005500AA55AA00FF5555550000FF55AAAAFF00AA00AA00
00FF5555AA00555555AA0055005555000055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55FF555555FFAAAA55AAAAAAFF00AA0055AA5500FFFFFF
550000AA55000000555555AAAA005500AAAA55555500000055AA000055FFFFFF0055AA55
00AA00FFAAAAAA55AAAAFF555555FF55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555500000000AAAAFF0055FFFFFF0055AAAAFF0000AA00
0000FF005500AA5500000055FF000000FF5500000055AA005500FF000000AA0000FFAAAA
5500FFFFFF5500FFAAAA000000005555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AAFF55FFFFFF00AA0000AA55AA555500AA5555
55555500AAFF550000FF000055555555550000FF000055FFAA005555555555AA005555AA
55AA0000AA00FFFFFF55FFAA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA000055550055AA5500AAAA5555FF55AA55AA
AA55AAAAAA000000FFFFFF00000055000000FFFFFF000000AAAAAA55AAAA55AA55FF5555
AAAA0055AA550055550000AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55AAAA55FF550000FF5500005555FF00AA
AA00FF5500FFFF0000AA0000FF000000FF0000AA0000FFFF0055FF00AAAA00FF55550000
55FF000055FF55AAAA55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55005500FF55550000FFFFFFAA550000555555
AA55005500AA0000FF0055AA0000FF0000AA5500FF0000AA00550055AA555555000055AA
FFFFFF00005555FF00550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA00000000FFFFFFFFFF55555555FF55
55AAAAAA55FFFF0000AA55AA5500AA0055AA55AA0000FFFF55AAAAAA5555FF55555555FF
FFFFFFFF00000000AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA0055AA0000AA0000AAFFFFAA0000
5500FF550000AA0055AA55AA55AA00AA55AA55AA5500AA000055FF00550000AAFFFFAA00
00AA0000AA5500AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA55AA5500AAAAAAAA0000AAAAAA
AA55005500AA555555FF00AAAA555555AAAA00FF555555AA00550055AAAAAAAA0000AAAA
AAAA0055AA55AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA55AA55AAFFAAAA00AA5500FF55
FFFFAA55AA00AAFF00AA0055FFFFAAFFFF5500AA00FFAA00AA55AAFFFF55FF0055AA00AA
AAFFAA55AA55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555FFFFFF5500AAAA550055
005555AAAAFF550055AA550000AA00AA000055AA550055FFAAAA555500550055AAAA0055
FFFFFF5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500005555005500AAAA00FF00
AA55AAAA00AA00FF00AAAA5500AAAAAA0055AAAA00FF00AA00AAAA55AA00FF00AAAA0055
005555000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF555555FFAAAA005555
55AAAA00AA55555500AAAA00FFFF55FFFF00AAAA00555555AA00AAAA55555500AAAAFF55
5555FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500000000AAAAFF5555
FF55FF00FF5555FF55AA555555005500555555AA55FF5555FF00FF55FF5555FFAAAA0000
00005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AAFF55FFFFFFAA
000055555500005555FF00AAFF000000FFAA00FF555500005555550000AAFFFFFF55FFAA
5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA000055550055
FFAA55AAAA5500AAFFFFFF00555555555500FFFFFFAA0055AAAA55AAFF550055550000AA
AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55AAAA5500
00AAAA5555AAAAAA0000AA00550000005500AA0000AAAAAA5555AAAA000055AAAA55FFAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55005500FF5555
5555AA55AAAA00AAAAAAAAFF5555555555FFAAAAAAAA00AAAA55AA55555555FF00550055
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA000000
005500FFAAAA0055FFFF550055000000550055FFFF5500AAAAFF005500000000AA55AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA0055
AA00FFFFFF55FFAA0000AAFF5555555555FFAA0000AAFF55FFFFFF00AA5500AA5555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA55
AA550055550000AAAAAAAA00000055000000AAAAAAAA000055550055AA55AA00AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA55
AA55AAFF00AA5500FF5500FFFF000000FFFF0055FF0055AA00FFAA55AA55AA55FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
5555FFFFFF005500AA00FFFFFFFF00FFFFFFFF00AA005500FFFFFF5555AAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
000055550055AAAAAA0055550055555500555500AAAAAA55005555000055FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55FF555555FFFF5500AAFF0000000000FFAA0055FFFF555555FF55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF555500000000AA00FF005555555555555500FF00AA000000005555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA0055AAFF5500AA005500000000005500AA0055FFAA5500AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55AAAA000000FF55AAAAAAAAAAAAAA55FF000000AAAA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAFF55AA000055FFFF55FFFF550000AA55FFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55005500FFFF00AA000000AA00FFFF00550055FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA55AA0000AA5555555555AA0000AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5555AAFF55000000000055FFAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00AA00FFFF00FFFF00AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55AA55005555550055AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA5500000055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF550000FF000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.92061 0.782187 2.00792 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF5555AA00FF55555555FF00000000000055AAAAAAAAAAAAAAAA5555000000000055AAAA
AAAAAAAAAAAAFF000000000000000000000000000000FFAAAAAAAAAAAAAAAA5500000000
005555AAAAAAAAAAAAAAAA55000000000000FF55555555FF00AA5555FF
FFFFAAFFAA555555555555AAAAAAAAAAAA5500000000000000AA0055AAAAAAAAAA550000
00000000005555AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA55550000000000000055AAAAAAAA
AA5500AA0000000000000055AAAAAAAAAAAA555555555555AAFFAAFFFF
FFFFFF550000FF0000FF0000AA0000000055AAAAAAAAAAAAAAAAFF00000000000055AAAA
AAAAAAAAAA5500AA00000000000000000000000000AA0055AAAAAAAAAAAAAA5500000000
0000FFAAAAAAAAAAAAAAAA5500000000AA0000FF0000FF000055FFFFFF
FFFFFFFFAA00FF5555FF00FFAAAAAAAAAA55000000000000005555AAAAAAAAAAAA550000
000000000000FFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFF000000000000000055AAAAAAAA
AAAA55550000000000000055AAAAAAAAAAFF00FF5555FF00AAFFFFFFFF
FFFFFFFFFF5555AA0055FF550000AA000055AAAAAAAAAAAAAA5500AA000000000055AAAA
AAAAAAAAAAAA5555000000000000000000000000005555AAAAAAAAAAAAAAAA5500000000
00AA0055AAAAAAAAAAAAAA550000AA000055FF5500AA5555FFFFFFFFFF
FFFFFFFFFFFFAAFFAA5500FF00FFAAAAAA550000000000000000FFAAAAAAAAAAAA550000
0000000000AA0055AAAAAAAAAAAAAAAAAAAAAAAAAA5500AA0000000000000055AAAAAAAA
AAAAFF000000000000000055AAAAAAFF00FF0055AAFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFF550000FFFFFF00550000AA55AAAAAAAAAAAAAA5555000000000055AAAA
AAAAAAAAAAAAFF000000000000000000000000000000FFAAAAAAAAAAAAAAAA5500000000
005555AAAAAAAAAAAAAA55AA00005500FFFFFF000055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00FF5500FFAAFF555500AA0000000000AA0055AAAAAAAAAA550000
00000000005555AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA55550000000000000055AAAAAAAA
AA5500AA0000000000AA005555FFAAFF0055FF00AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555AA00FF55FF0000FFAAAAAAAAAAAAAAFF00000000000055AAAA
AAAAAAAAAA5500AA00000000000000000000000000AA0055AAAAAAAAAAAAAA5500000000
0000FFAAAAAAAAAAAAAAFF0000FF55FF00AA5555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFAA555555AAAA5555005500000000AAAAAAAAAAAAAA550000
000000000000FFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFF000000000000000055AAAAAAAA
AAAAAA0000000055005555AAAA555555AAFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF550000FF0000AA0055AAFFFF00FFAA0000000000000055AAAA
AAAAAAAAAAAA5555000000000000000000000000005555AAAAAAAAAAAAAAAA5500000000
000000AAFF00FFFFAA5500AA0000FF000055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00FF5555FFFF000055FF00FF55FF55AAAAAAAAAA550000
0000000000AA0055AAAAAAAAAAAAAAAAAAAAAAAAAA5500AA0000000000000055AAAAAAAA
AA55FF55FF00FF550000FFFF5555FF00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF5555AA0055FF00AAFFFFFF0055AA55000000000055AAAA
AAAAAAAAAAAAFF000000000000000000000000000000FFAAAAAAAAAAAAAAAA5500000000
0055AA5500FFFFFFAA00FF5500AA5555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA5500FFAAAA00AAAA550055AAAAAAAAAA550000
00000000005555AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA55550000000000000055AAAAAAAA
AA550055AAAA00AAAAFF0055AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000FFFFFF55FFAAAAFFFF00000000000055AAAA
AAAAAAAAAA5500AA00000000000000000000000000AA0055AAAAAAAAAAAAAA5500000000
0000FFFFAAAAFF55FFFFFF000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF5500FF00555500FF55AAAAAAAAAA550000
000000000000FFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFF000000000000000055AAAAAAAA
AA55FF00555500FF0055FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA00FF55555555FF00000000000055AAAA
AAAAAAAAAAAA5555000000000000000000000000005555AAAAAAAAAAAAAAAA5500000000
0000FF55555555FF00AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA555555555555AAAAAAAAAAAA550000
0000000000AA0055AAAAAAAAAAAAAAAAAAAAAAAAAA5500AA0000000000000055AAAAAAAA
AAAA555555555555AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000FF0000FF0000AA0000000055AAAA
AAAAAAAAAAAAFF000000000000000000000000000000FFAAAAAAAAAAAAAAAA5500000000
AA0000FF0000FF000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF5555FF00FFAAAAAAAAAA550000
00000000005555AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA55550000000000000055AAAAAAAA
AAFF00FF5555FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA0055FF550000AA000055AAAA
AAAAAAAAAA5500AA00000000000000000000000000AA0055AAAAAAAAAAAAAA550000AA00
0055FF5500AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA5500FF00FFAAAAAA550000
000000000000FFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFF000000000000000055AAAAAAFF
00FF0055AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000FFFFFF00550000AA55AA
AAAAAAAAAAAA5555000000000000000000000000005555AAAAAAAAAAAAAA55AA00005500
FFFFFF000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF5500FFAAFF555500AA
0000000000AA0055AAAAAAAAAAAAAAAAAAAAAAAAAA5500AA0000000000AA005555FFAAFF
0055FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA00FF55FF0000FFAA
AAAAAAAAAAAAFF000000000000000000000000000000FFAAAAAAAAAAAAAAFF0000FF55FF
00AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA555555AAAA5555
005500000000AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA0000000055005555AAAA555555
AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000FF0000AA0055
AAFFFF00FFAA0000000000000000000000000000000000AAFF00FFFFAA5500AA0000FF00
0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF5555FFFF00
0055FF00FF55FF55AAAAAAAAAAAAAAAAAAAAAAAAAA55FF55FF00FF550000FFFF5555FF00
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA0055FF00
AAFFFFFF0055AA550000000000000000000000000055AA5500FFFFFFAA00FF5500AA5555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA5500FF
AAAA00AAAA550055AAAAAAAAAAAAAAAAAAAAAAAAAA550055AAAA00AAAAFF0055AAFFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000FFFF
FF55FFAAAAFFFF000000000000000000000000000000FFFFAAAAFF55FFFFFF000055FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF55
00FF00555500FF55AAAAAAAAAAAAAAAAAAAAAAAAAA55FF00555500FF0055FF00AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA
00FF55555555FF000000000000000000000000000000FF55555555FF00AA5555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
AA555555555555AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA555555555555AAFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
0000FF0000FF0000AA0000000000000000000000AA0000FF0000FF000055FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA00FF5555FF00FFAAAAAAAAAAAAAAAAAAAAAAAAAAFF00FF5555FF00AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5555AA0055FF550000AA00000000000000AA000055FF5500AA5555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFAA5500FF00FFAAAAAAAAAAAAAAAAAAFF00FF0055AAFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF550000FFFFFF0055000000000000005500FFFFFF000055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA00FF5500FFAAFF55AAAAAA55FFAAFF0055FF00AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF5555AA00FF55FF0000000000FF55FF00AA5555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFAA555555AAAAAAAAAA555555AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF550000FF00000000000000FF000055FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00FF55AAAAAAAAAA55FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555AA0000000000AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFAA55FF55AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF550055AA550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.92061 0.97619 2.00792 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF555555FFFFFFFFAA555555AAAA55FF555555AAAAFFFFFFFFFFFFFFFF5555AA00AA5555
5555AAAA55AAAA55AA0000AA55FFFFFF55AA0000AA55AAAA55AAAA55555555AA00AA5555
FFFFFFFFFFFFFFFFAAAA555555FF55AAAA555555AAFFFFFFFF555555FF
FFFF55FF00FFFF00FFAAFFAAAA55AA55FFFF55FF55550000000055005500FF555555FFFF
55FF00AAFFAA00FF55555555FFFFFFFFFF55555555FF00AAFFAA00FF55FFFF555555FF00
550055000000005555FF55FFFF55AA55AAAAFFAAFF00FFFF00FF55FFFF
FFFFFF55AA0000AA55FF55AAAA5555FF00FFFF55AA555555555555AA00AA55FFFF55FFAA
555500AAFF55555500FF55FFFFFFFFFFFFFF55FF00555555FFAA005555AAFF55FFFF55AA
00AA555555555555AA55FFFF00FF5555AAAA55FF55AA0000AA55FFFFFF
FFFFFFFF55555555FFFFFF5555FFFFAA55000055FF55FFFF55FFFF555555FFFFFFFFAA55
AA555555FFAAAA00AA55FFFF00FFFFFF00FFFF55AA00AAAAFF555555AA55AAFFFFFFFF55
5555FFFF55FFFF55FF55000055AAFFFF5555FFFFFF55555555FFFFFFFF
FFFFFFFFFF55FF0055005555AA55FFAA00AA5500FFFF55AAFFFFFFFF55FFFFFFFF00FFAA
AA5555AA55FF555555FFFFFF0000000000FFFFFF555555FF55AA5555AAAAFF00FFFFFFFF
55FFFFFFFFAA55FFFF0055AA00AAFF55AA5555005500FF55FFFFFFFFFF
FFFFFFFFFFFF55AA00AA5555AAAAFF555555FF00005555AAAAAAAAAAAA00000000AA55FF
5555AA55AA55FFFF55000055555555555555000055FFFF55AA55AA5555FF55AA00000000
AAAAAAAAAAAA55550000FF555555FFAAAA5555AA00AA55FFFFFFFFFFFF
FFFFFFFFFFFFFF555555FFFF5555FFAAAA00AA0055AA5555FF5555FF555555555555FFFF
FF55FF55FF55005555AA0055FFFF55FFFF5500AA55550055FF55FF55FFFFFF5555555555
55FF5555FF5555AA5500AA00AAAAFF5555FFFF555555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55FF00FFFF55FFAA00FF00AA5555FFFF55AA555500FF55FFFF55FFAA
55FFFFFF55AA5500FF555555AAFF55FFAA555555FF0055AA55FFFFFF55AAFF55FFFF55FF
005555AA55FFFF5555AA00FF00AAFF55FFFF00FF55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55AA0000AAAAAA550000FFAAAAFF55AA55AA55555500FFFF005555
FFFF00FFFFAA00AA55FFFF55FF55AA55FF55FFFF55AA00AAFFFF00FFFF555500FFFF0055
5555AA55AA55FFAAAAFF000055AAAAAA0000AA55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55555555FF5555AA005555FF55AA55AA55AA5555AA000055AA55
550055AAFF555555FFFFFFFF55AA55AA55FFFFFFFF555555FFAA55005555AA550000AA55
55AA55AA55AA55FF555500AA5555FF55555555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55FF005500FF555555AA55FF00AAAA5555FFFF55555555AAAA
00AA5555FFAAFFFF55AAFF55AA55AA55AA55FFAA55FFFFAAFF5555AA00AAAA55555555FF
FF5555AAAA00FF55AA555555FF005500FF55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AA00AA55FFFF55FF550055AAAA5555AAFF55FFFF55FF55
5555FFFFAA55AAFF55FF55AA55AA55AA55AA55FF55FFAA55AAFFFF555555FF55FFFF55FF
AA5555AAAA550055FF55FFFF55AA00AA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFAA555555AAAA5555AAAAAA0000AAAAAA
00AAAAAAAA5555FFAAFF55FF55FF55FF55FF55FFAAFF5555AAAAAAAA00AAAAAA0000AAAA
AA5555AAAA555555AAFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00FFFF00FFAAFFAAAA55AA5555FF55555555FF55
5555FF5555FFFFAA55AAFFFFFF55AA55FFFFFFAA55AAFFFF5555FF555555FF55555555FF
5555AA55AAAAFFAAFF00FFFF00FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA0000AA55FF55AAAA5555FF005555AA5555AAFF
FFAAAAAAFFAA55FF55FF55AAFF55FF55FFAA55FF55FF55AAFFAAAAAAFFFFAA5555AA5555
00FF5555AAAA55FF55AA0000AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555FFFFFF5555FFFFAA5500FF5555AA55AA
FF5555FF55AAAAFF55FFAAAA55FFFFFF55AAAAFF55FFAAAA55FF5555FFAA55AA5555FF00
55AAFFFF5555FFFFFF55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF0055005555AA55FFAA00AA55FFFF5555AA
AAAAFFFFFF5555FFAAFF5555FFFFFFFFFF5555FFAAFF5555FFFFFFAAAAAA5555FFFF55AA
00AAFF55AA5555005500FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00AA5555AAAAFF555555FFFFFFFF55FF
5555FFAA55FFFF55AAAAAAFFFFFFFFFFFFFFAAAAAA55FFFF55AAFF5555FF55FFFFFFFF55
5555FFAAAA5555AA00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFF5555FFAAAAFFFF00FFFF0055
55AA55FF55FFAA5555FF555500000000005555FF5555AAFF55FF55AA555500FFFF00FFFF
AAAAFF5555FFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00FFFF55FFAA00FFFF00000055AA
5555FFFF005555FFFF55AA55555555555555AA55FFFF555500FFFF5555AA55000000FFFF
00AAFF55FFFF00FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA0000AAAAAA55005555555555AA
AAFFFF00FF0055FFAA5555FFFFAAFFAAFFFF5555AAFF5500FF00FFFFAAAA555555555500
55AAAAAA0000AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555FF5555AA00AAAAFFFF55
55FFAA550055AA55FF55FFFFFF00AA00FFFFFF55FF55AA550055AAFF5555FFFFAAAA00AA
5555FF55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF005500FF555555FF55AAFF
AAAAAA555555AAAAFF55000000AA55AA00000055FFAAAA555555AAAAAAFFAA55FF555555
FF005500FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00AA55FFFF55FFAAAA55
FF5555FFFF55FF555500FF0000FFAAFF0000FF005555FF55FFFF5555FF55AAAAFF55FFFF
55AA00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFAA55AAAA
FF55FFFFFFFF55AA55555500AA55FF55AA00555555AA55FFFFFFFF55FFAAAA55AAFFFFFF
FF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00FFFF00FFAAAA55
AAFFFFFFFFFFFF5555AA555555FFFFFF555555AA5555FFFFFFFFFFFFAA55AAAAFF00FFFF
00FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA0000AA55FF5555
AAAAAAAAAAAAAAAA00AAFFAAFFFFFFFFFFAAFFAA00AAAAAAAAAAAAAAAA5555FF55AA0000
AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555FFFFFF55
FF5555FF5555FF555555FFAA0000000000AAFF555555FF5555FF5555FF55FFFFFF555555
55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF0055005555
AAFFAAAAAAFFFFFFAAAAFF55555555555555FFAAAAFFFFFFAAAAAAFFAA5555005500FF55
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00AA5555
AAAAAA55AAAAAAAAAA55AAFFAAFFAAFFAAFFAA55AAAAAAAAAA55AAAAAA5555AA00AA55FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFF
5555FF55FF5555FF5555AAAAAA55FF55AAAAAA5555FF5555FF55FF5555FFFF555555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00FF
FF55FFAAAAAAFFFFFF55FF5555FFFFFF5555FF55FFFFFFAAAAAAFF55FFFF00FF55FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00
00AAAAAA55AAAAAAAAAAFF55FFFFFFFFFF55FFAAAAAAAAAA55AAAAAA0000AA55FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555
5555FF5555AAAA55AAAA55FFFFFFFFFFFFFF55AAAA55AAAA5555FF55555555FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
FF005500FF5555FF00AAFFFFFFFFFFFFFFFFFFAA00FF5555FF005500FF55FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
55AA00AA55FFFF55AA00FFFF00FFFFFF00FFFF00AA55FFFF55AA00AA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF555555FFFFFFFF5555550000FFFFFF0000555555FFFFFFFF555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF55FF00FFFF00FF55FF0000FFFFFF0000FF55FF00FFFF00FF55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55AA0000AA55FFFF0000FFFFFF0000FFFF55AA0000AA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF55555555FFFFFF0000FFFFFF0000FFFFFF55555555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55FF005500555555550055555555005500FF55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF55AA00AA5555AA555555AA5555AA00AA55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF555555FFFF5555AA5555FFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55FF00FFFF55FF55FFFF00FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55AA0000AAAAAA0000AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55555555FF55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55FF005500FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AA00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 2.01665 0.200176 2.10396 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF555500FFFFAAFFFF550000AA00FFFFAA55AAAAFFAAAA0000000055AA555555FF55FF00
AA55AAAAFF00FFFF00AAFFFF00FFFFFF00FFFFAA00FFFF00FFAAAA55AA00FF55FF555555
AA5500000000AAAAFFAAAA55AAFFFF00AA000055FFFFAAFFFF005555FF
FFFFAAFF5555FFFFFFFFAA55FFFF00AAAAFFFF55FF55FFFF00FFFF000000FF000055AAAA
AAFFFF55FF55AAAA55FFFFFFFF005500FFFFFFFF55AAAA55FF55FFFFAAAAAA550000FF00
0000FFFF00FFFF55FF55FFFFAAAA00FFFF55AAFFFFFFFF5555FFAAFFFF
FFFFFF555500AAFF0055FFFFAA00FFFF55FF00AA00AA00AAFF5555FFAA55FF55AAFFFF55
FFFFFFFFAA00000000FF5555FF00FF00FF5555FF00000000AAFFFFFFFF55FFFFAA55FF55
AAFF5555FFAA00AA00AA00FF55FFFF00AAFFFF5500FFAA005555FFFFFF
FFFFFFFFAAFF55FF00FF0055FFFF005500AAAAAAFF55FFAAAA0000AAAAFFFFFFAAAA5555
00FF5555FFFF00FFFF00555500FFFFFF00555500FFFF00FFFF5555FF005555AAAAFFFFFF
AAAA0000AAAAFF55FFAAAAAA005500FFFF5500FF00FF55FFAAFFFFFFFF
FFFFFFFFFF555500FFFFFF000055FFAAFF55FFFF5500AAFFAAAAAAAAFFAA00FF55FFFFAA
FF5555005500FFFFFFFF0000FFFFFFFFFF0000FFFFFFFF0055005555FFAAFFFF55FF00AA
FFAAAAAAAAFFAA0055FFFF55FFAAFF550000FFFFFF005555FFFFFFFFFF
FFFFFFFFFFFFAAFF5555FF55AAFFFFFF555500FFAAFF55FF55FFFF55FF55FFAA0055FF55
FF0000FFFFAA5555AA55AAFF5555FF5555FFAA55AA5555AAFFFF0000FF55FF5500AAFF55
FF55FFFF55FF55FFAAFF005555FFFFFFAA55FF5555FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFF555500AAFFFF5555FF0000FFFFFF55550000FF5500AAFFFFFF55AA00AA
55AAFF5555FFFFAAFFAAFFAA0055AA5500AAFFAAFFAAFFFF5555FFAA55AA00AA55FFFFFF
AA0055FF00005555FFFFFF0000FF5555FFFFAA005555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF55FF00555555AAFF5555FF0000FFFF00AA55FFFFFFFFFFAAAAAA
FFFF55555500FF55FF55FF55FFAAFFAAFF55FF55FF55FF00555555FFFFAAAAAAFFFFFFFF
FF55AA00FFFF0000FF5555FFAA55555500FF55FFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555500FFFFAAFFFF55005555FFAA55AAAAAAFFFFFFFFFFFFFF55FF
FFFFFFAAFFFF0055AA550000FF55FF55FF000055AA5500FFFFAAFFFFFFFF55FFFFFFFFFF
FFFFAAAAAA55AAFF55550055FFFFAAFFFF005555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF5555FFFFFFFFAA550055FFFFAAAAFFAA00FF5555FF555555
AA5555FFFFFFFF000000FFFF0055AA5500FFFF000000FFFFFFFF5555AA555555FF5555FF
00AAFFAAAAFFFF550055AAFFFFFFFF5555FFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF555500AAFF0055FFFFAA5500FF55FFFFFF55AA5500AAFFFFAA
FFAAFFFFFFFFFFFF00FFFFFFFF000000FFFFFFFF00FFFFFFFFFFFFAAFFAAFFFFAA0055AA
55FFFFFF55FF0055AAFFFF5500FFAA005555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF55FF00FF0055FFFFAA555555AAAA000000FFFF5555FF
FFFF5555FF005500FFFFFFFFFFFF00FFFFFFFFFFFF005500FF5555FFFFFF5555FFFF0000
00AAAA555555AAFFFF5500FF00FF55FFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555500FFFFFF000055FFFFAAFFFF55FFAA55FF00555500
FF55555500FFFFAA5555AAAA00AAAAAA00AAAA5555AAFFFF00555555FF00555500FF55AA
FF55FFFFAAFFFF550000FFFFFF005555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555FF55AAFFFFFFFF550000AAAAFFFFFF0000FF
FFFFAAFFFF0055FFFFAAFFAAAAAAFFAAAAAAFFAAFFFF5500FFFFAAFFFFFF0000FFFFFFAA
AA000055FFFFFFFFAA55FF5555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500AAFFFF5555FF0055AAFF55FFFFFFFFFF00FF
5555FFFFFFFF000055FFFFFF55FFFFFF55FFFFFF550000FFFFFFFF5555FF00FFFFFFFFFF
55FFAA5500FF5555FFFFAA005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FF00555555AAFFFF555555AA5555FF00FF
AAFFFFFFFFFFFF00FF00AAFF0000550000FFAA00FF00FFFFFFFFFFFFAAFF00FF5555AA55
5555FFFFAA55555500FF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500FFFFAAFFFF550000AA000000AA00FFFF
FF5555FF0055FF55AA55FFFFFF00FF00FFFFFF55AA55FF5500FF5555FFFFFF00AA000000
AA000055FFFFAAFFFF005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555FFFFFFFFAA55FFFF00FFFF55AAAA
55555500FFFFAA000000FF5500FFFFFF0055FF000000AAFFFF00555555AAAA55FFFF00FF
FF55AAFFFFFFFF5555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500AAFF0055FFFFAA00FFFFFFFFAAAA
FFFFAAFF5555FFFF00FFFFFFAA55AA55AAFFFFFF00FFFF5555FFAAFFFFAAAAFFFFFFFF00
AAFFFF5500FFAA005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FF00FF0055FFFF005500FF55FF
FFFFFF550055AAAA55FF00AAFFAAFFAAFFAA00FF55AAAA550055FFFFFFFF55FF005500FF
FF5500FF00FF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500FFFFFF000055FFAAFF555555
FF00AAFFFF00000000AAFF55FF55FF55FF55FFAA00000000FFFFAA00FF555555FFAAFF55
0000FFFFFF005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555FF55AAFFFFFF55555555
55FFAAAA00FFFF00FFFF5500AAFFFFFFAA0055FFFF00FFFF00AAAAFF5555555555FFFFFF
AA55FF5555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500AAFFFF5555FF0000AA00
00FF55FFFF00AAAAAA00AA55FFFFFFFFFF55AA00AAAAAA00FFFF55FF0000AA0000FF5555
FFFFAA005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FF00555555AAFF55FF
AA555555AAAAAAFFAAAAAAFFFFFFFFFFFFFFAAAAAAFFAAAAAA555555AAFF55FFAA555555
00FF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500FFFFAAFFFF550055
FFFFAAFFFF55FFFFFF55FFFFFFFFFFFFFFFFFF55FFFFFF55FFFFAAFFFF550055FFFFAAFF
FF005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555FFFFFFFFAA55
00FF55FF555555AAAA5500FF5555AA5555FF0055AAAA555555FF55FF0055AAFFFFFFFF55
55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500AAFF0055FFFF
AA55550000FF00000000FFFFFFAAFFAAFFFFFF00000000FF00005555AAFFFF5500FFAA00
5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FF00FF0055
FFFFAAFF55AAAAAAAAAAAA5555FFFFFF5555AAAAAAAAAAAA55FFAAFFFF5500FF00FF55FF
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500FFFFFF00
0055FFFFFFAAAAFFAAAAFFAAFFFFFFFFFFAAFFAAAAFFAAAAFFFFFF550000FFFFFF005555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555FF55
AAFFFFFFFFFF55FF55FFFFFF5555AA5555FFFFFF55FF55FFFFFFFFFFAA55FF5555FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500AAFF
FF5555FF005500AAFFFFFFFFFFAAFFAAFFFFFFFFFFAA005500FF5555FFFFAA005555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FF
00555555FFAAFF55FF005500FF55FF55FF005500FF55FFAAFF55555500FF55FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500
FFFFAAFFFFFF555555AAFFFF0055AA5500FFFFAA555555FFFFFFAAFFFF005555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
5555FFFFFFFFFFAAFFFF5555FFAAFFAAFF5555FFFFAAFFFFFFFFFF5555FFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
5500AAFF0055FF55FF55555555FFFFFF55555555FF55FF5500FFAA005555FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAFF55FF00FF0055AA5500555555FF5555550055AA5500FF00FF55FFAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF555500FFFFFF000000FFFFAAFFFFFFAAFFFF000000FFFFFF005555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFF5555FF00FFFF0055FFFFFFFFFF5500FFFF00FF5555FFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF555500AAFF5555FFAAFF005500FFAAFF5555FFAA005555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAFF55FF0000FF55FF00FF00FF55FF0000FF55FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF555500FFFF00AA00FFFFFF00AA00FFFF005555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFF5555FFAAAAAA00AAAAAAFF5555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF555500AAAAFFAAAAAAFFAAAA005555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF55FFFFFF55FFFFFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555500FF555555FF005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF5555555555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF555500AA005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 2.01665 0.39418 2.10396 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF5555550000AAAA55555555005555555555550055005555005500555555AAFFFF55AA00
0055000000000055AA0000AAFFFF55FFFFAA0000AA550000000000550000AA55FFFFAA55
555500550055550055005555555555550055555555AAAA0000555555FF
FFFFAAFFFF00FF5500005500000055000055000000555555550000AA5500AAAA55AA00AA
0000555500555500AAAAAAAA00FFAAFF00AAAAAAAA0055550055550000AA00AA55AAAA00
55AA0000555555550000005500005500000055000055FF00FFFFAAFFFF
FFFFFF5555FFAA005555000000000055550000000000550000555500FF00FF5500AAAAAA
00000055005500AA00AAAAFFAA55AA55AAFFAAAA00AA00550055000000AAAAAA0055FF00
FF005555000055000000000055550000000000555500AAFF5555FFFFFF
FFFFFFFFAAFF0055555555005555005500000000000000555500005555FFAA005555AA55
55005555550000AAAAAA00AAFFAAFFAAFFAA00AAAAAA0000555555005555AA555500AAFF
5555000055550000000000000055005555005555555500FFAAFFFFFFFF
FFFFFFFFFF555500AA5500000055005500555500555500550000000055AAAA0000FF0055
00000055000000AAAAFFAA5555FFFFFF5555AAFFAAAA000000550000005500FF0000AAAA
5500000000550055550055550055005500000055AA005555FFFFFFFFFF
FFFFFFFFFFFFAAFF55000000000055555500005555555500000000000055FFFF00FFAA55
005555000000AA00AAAA55555555FF55555555AAAA00AA00000055550055AAFF00FFFF55
000000000000555555550000555555000000000055FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFF55555500555500550000555500005500000000000000AA55AAAAAA5555
55000055550055FFAAAAFFFFAAFFFFFFAAFFFFAAAAFF550055550000555555AAAAAA55AA
00000000000000550000555500005500555500555555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF00005555550055000000005555005555005555AA00AAAA0055
00000000FF00FF00AAAA00FFAAAA55AAAAFF00AAAA00FF00FF000000005500AAAA00AA55
550055550055550000000055005555550000FFFFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555FFAA5500005555550055550000555555550000FF55AA555500
00000000AAFF555500FF55AAAAFFAAFFAAAA55FF005555FFAA00000000005555AA55FF00
00555555550000555500555555000055AAFF5555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF0055005555555555000055550000550000AA00FF00550000
00AA0000AAAA550000AAFFFF55FF55FF55FFFFAA000055AAAA0000AA0000005500FF00AA
0000550000555500005555555555005500FFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF555500AA0055AA005500555555550055AAFF55FFAA00005555
0055FFAA5555AA0000AAAA55AA00FF00AA55AAAA0000AA5555AAFF550055550000AAFF55
FFAA550055555555005500AA5500AA005555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF55005500FFFFAA55000055005500FFAAFF0055550000
555555FFFFAAFFAA55FF005500FFFFFF005500FF55AAFFAAFFFF5555550000555500FFAA
FF00550055000055AAFFFF00550055FFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF5555550000AAFF00550055555500AA00FF555500005555
000055AAAA5555FFFFAA00005555FF55550000AAFFFF5555AAAA550000555500005555FF
00AA00555555005500FFAA0000555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FF5555000000550000AAAAAA5500AA000055
00555555AA5500AAFF00555500AA55AA00555500FFAA0055AA55555500550000AA0055AA
AAAA0000550000005555FF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFAA0055005555000000AAAAFFAAFF55005555
550000FF0055AAFFAA000055AAFFAAFFAA550000AAFFAA5500FF00005555550055FFAAFF
AAAA0000005555005500AAFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00555555000055550055FFFFFF5555550000
55005555FFAAFFAA00AA000055FF55FF550000AA00AAFFAAFF555500550000555555FFFF
FF55005555000055555500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500AA55005555555500AAFF00AA55000000
0055555555FF00AAAAAA000000FFAAFF000000AAAAAA00FF555555550000000055AA00FF
AA00555555550055AA005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF550000005500005555AAAAAA00555500
555555555555FFAAAA00AA0000AAFFAA0000AA00AAAAFF55555555555500555500AAAAAA
555500005500000055FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555500555555005500AAAAFFAA550000
005500005500AAFFAAAAAAFF55AA55AA55FFAAAAAAFFAA005500005500000055AAFFAAAA
00550055555500555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF0000550055AAFFAAAA55555500
5555550055AAFFAA00AAAA00FF005500FF00AAAA00AAFFAA550055555500555555AAAAFF
AA5500550000FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFAA550055AA55AA5555555555
0000550055AA55AA55FF005555FFAAFF555500FF55AA55AA55005500005555555555AA55
AA550055AAFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0055005500FF005500AA5500
000000555555AA00AA55AAFFFFAA00AAFFFFAA55AA00AA5555550000000055AA005500FF
0055005500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500AA005555FFAAFF550000
0000AA0055AA00AA00AA5555FF550055FF5555AA00AA00AA5500AA0000000055FFAAFF55
5500AA005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55005500AAFFAA005555
005555AAFFFF55AA55FFFFAAFF000000FFAAFFFF55AA55FFFFAA555500555500AAFFAA00
550055FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555550000AAAA55550000
55555555AAAA5500FF00AAFFAA000000AAFFAA00FF0055AAAA5555555500005555AAAA00
00555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FF5500005555
00005500AAAA005555FFAAAA5555005555AAAAFF555500AAAA005500005555000055FF00
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFAA0055550000
55550000AAAA0000FF00AAAA0055005500AAAA00FF0000AAAA000055550000555500AAFF
5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF005555555500
55000000AAAAFF55AAAAAAFFAA550055AAFFAAAAAA55FFAAAA00000055005555555500FF
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500AA550000
0055550055FF00AA5555AA55AA550055AA55AA5555AA00FF5500555500000055AA005555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55000000
0000550055AAAAAA005500FF0055005500FF005500AAAAAA550055000000000055FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555550055
550055005500FF55FFAAFF55550000005555FFAAFF55FF0055005500555500555555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00
0055555500AA00FF00AAAA55000000000055AAAA00FF00AA005555550000FFFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF
AA5500005555AAFF00FF550000000000000055FF00FFAA5555000055AAFF5555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
00550055555555AAAAAA550055550055550055AAAAAA55555555005500FFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
5500AA0055AA0055FF0055005500000055005500FF5500AA5500AA005555FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAFF55005500FFFFAA0000555555005555550000AAFFFF00550055FFAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5555550000AAFF00555500005500550000555500FFAA0000555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFF00FF555500005555000000555500005555FF00FFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5555FFAA005500555555550055555555005500AAFF5555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAFF0055555500005500000055000055555500FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF555500AA5500555555005555550055AA005555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFF55000000550000005500000055FFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF555555005555550055555500555555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF00005500550000FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555FFAA550055AAFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF0055005500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF555500AA005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 2.01665 0.588183 2.10396 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF555555FFAAAAAAFFFFAAFF000055FFFF00FFFF55AA00555555FF5500FF00FF55550055
550055000055FF55005555FF00FF00FF00FF55550055FF55000055005555005555FF00FF
0055FF55555500AA55FFFF00FFFF550000FFAAFFFFAAAAAAFF555555FF
FFFFAAFFFFFF55FFFFFFFF55550055FF5555000055FFFF0000FF55555500000055FF00FF
005555550055AAAA0000FF55550000005555FF0000AAAA550055555500FF00FF55000000
555555FF0000FFFF5500005555FF55005555FFFFFFFF55FFFFFFAAFFFF
FFFFFF5555FF550000550000FF00FF555555550055FF5555005500FF0055550055FF55AA
AAAA0055FFAAFFAAAAAAAA55555500555555AAAAAAAAFFAAFF5500AAAAAA55FF55005555
00FF0055005555FF550055555555FF00FF000055000055FF5555FFFFFF
FFFFFFFFAAFF00555500AA00005555FF0055FF00FF5555555500FFFFFF0055AAFFFFFFAA
AAFFAA5555FFFFFF55FFFF5500FF00FF0055FFFF55FFFFFF5555AAFFAAAAFFFFFFAA5500
FFFFFF0055555555FF00FF5500FF55550000AA00555500FFAAFFFFFFFF
FFFFFFFFFF555500AA55FFFF00FF55000000FFAA55AA555555550000550055FFFFFFFFFF
55FF55FF0055000055FF555555000000555555FF5500005500FF55FF55FFFFFFFFFF5500
55000055555555AA55AAFF00000055FF00FFFF55AA005555FFFFFFFFFF
FFFFFFFFFFFFAAFF55FF00AAFF555555005555FFFFAAAA0055FF00FFFFAA550000550000
55FF55000000FFFF005500FF0000000000FF005500FFFF00000055FF55000055000055AA
FFFF00FF5500AAAAFFFF555500555555FFAA00FF55FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFF555555FFAAAA5555555500FF5555FFFF55AA00FFFFFFFF550055555500
55FF55005555000055555500000000000000555555000055550055FF55005555550055FF
FFFFFF00AA55FFFF5555FF0055555555AAAAFF555555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFFFF55FF0000FF00FFAAFFFFFFFFAAAAAA55AAAA550055FF0055
5555FF00FF55005555AA550055550055550055AA55550055FF00FF55555500FF550055AA
AA55AAAAAAFFFFFFFFAAFF00FF0000FF55FFFFFFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555FF55000000005555FFFFFFFFFFFF55FFFFAAAAFFFF00005555
5555AAAAAA555500FF55FF00FF000000FF00FF55FF005555AAAAAA555555550000FFFFAA
AAFFFF55FFFFFFFFFFFF55550000000055FF5555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF0055550055555555FF5555FF555555FF55FFFFFFFF00FF55
00FF55FFFF5500AA00FF555500000000005555FF00AA0055FFFF55FF0055FF00FFFFFFFF
55FF555555FF5555FF5555555500555500FFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF555500AA55FF0055FF00AA5555FF0055FF5500005500000055
FFAA00550000FFFF55AAAA00555500555500AAAA55FFFF00005500AAFF55000000550000
55FF5500FF5555AA00FF5500FF55AA005555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF55FF00AA00AAFF55FF00550055FF5500555555005555
55FFFF005555000055FFFF55AA550055AA55FFFF550000555500FFFF5555550055555500
55FF55005500FF55FFAA00AA00FF55FFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFAAAAAAFF00550055FFAAFF000000FF000000FF
0055000000FF00FFFFAA00FF55FF00FF55FF00AAFFFF00FF0000005500FF000000FF0000
00FFAAFF55005500FFAAAAAAFF555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF55FFFFFF00555555FFFFFF00FFFFFF00FFFF
FF00000000005555FF55FFAA0055005500AAFF55FF55550000000000FFFFFF00FFFFFF00
FFFFFF55555500FFFFFF55FFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF550000550055FF0000550000005500000055
00000000000000FF555555FFFF000000FFFF555555FF0000000000000055000000550000
00550000FF550055000055FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00555500AA00550055555500555555005555
550055550055550000FF005500000000005500FF00005555005555005555550055555500
555555005500AA00555500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500AA55FFFF00555555555500AA550055FF
000000FF00FF005555000000FFFF00FFFF000000555500FF00FF000000FF550055AA0055
5555555500FFFF55AA005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FF00AAFF5500FF0000FFFF550055AA
AAAAAAAA55FF55AA00555500550000005500555500AA55FF55AAAAAAAAAA550055FFFF00
00FF0055FFAA00FF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFAAAA5555000000005500FFFFAA
AAFFAAAAFFFFFFAAAAAA005555550055555500AAAAAAFFFFFFAAAAFFAAAAFFFF00550000
00005555AAAAFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF55FF000000000000FFFFFFFF
55FF55FFFFFFFFFF55FFFF0000FF00FF0000FFFF55FFFFFFFFFF55FF55FFFFFFFF000000
000000FF55FFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF550000000000000000550000
55FF55000055000055FF555500550055005555FF55000055000055FF5500005500000000
0000000055FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00555500555500555500FFFF
005500FFFF00000000FFAAFFFF000000FFFFAAFF00000000FFFF005500FFFF0055550055
5500555500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500AA55FF00555555550000
55555500005555005555FFFFFFFF00FFFFFFFF5555005555000055555500005555555500
FF55AA005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FF00AA00AA55555500
55FF00555500FF00FF0055000055005500005500FF00FF00555500FF5500555555AA00AA
00FF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFAAAAAAFFFFAAFF
550000AA55550000005555AAFF550055FFAA55550000005555AA000055FFAAFFFFAAAAAA
FF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF55FFFFFFFF55
55AAFF55FF0000000000FF55FF550055FF55FF0000000000FF55FFAA5555FFFFFFFF55FF
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF550000550000
FF55FF550000000000000055FF550055FF550000000000000055FF55FF000055000055FF
5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00555500AA00
0055FF550055550055550055FF550055FF550055550055550055FF550000AA00555500FF
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500AA55FFFF
00FF55555500FF00FF550055FF550055FF550055FF00FF00555555FF00FFFF55AA005555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FF00AA
FF555555555500000055FFAAFF000000FFAAFF550000005555555555FFAA00FF55FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFAA
AA55555555555500555555FFFFFF00FFFFFF55555500555555555555AAAAFF555555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF
55FF0000FF5500AA00AA550000550055000055AA00AA0055FF0000FF55FFFFFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF
550000000055FFAAAAAAFFFF00FF00FF00FFFFAAAAAAFF550000000055FF5555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
00555500555555FFFF55FF55550000005555FF55FFFF55555500555500FFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
5500AA55FF0055FF555555FF0000000000FF555555FF5500FF55AA005555FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAFF55FF00AA005500FF000055550055550000FF005500AA00FF55FFAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF555555FFAAAAAA0000555500FF00FF0055550000AAAAAAFF555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFFFF55FFFF00FF55005500550055FF00FFFF55FFFFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5555FF5500005555FF00FF00FF00FF5555000055FF5555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAFF00555500FF55550000005555FF00555500FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF555500AAAAAA55555500555555AAAAAA005555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFF55FFFF5500FF00FF0055FFFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF555555FF55005500550055FF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFFFFAA550055AAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555FF55FF00FF55FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF0055005500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF555500AA005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 2.01665 0.782187 2.10396 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF555555FF000000AAFF0000550055AA0000AA5555AA5500AAFFAAFF000055AA55555500
00FF5555005555550055FFAAFF005500FFAAFF5500555555005555FF0000555555AA5500
00FFAAFFAA0055AA5555AA0000AA5500550000FFAA000000FF555555FF
FFFFAAFFFFFF00FFFF5555AA55000000AAAA00000000AA55FFFFFF5555AA550055AA0055
FF00AA55000000000055AAAAFF00FF00FFAAAA55000000000055AA00FF5500AA550055AA
5555FFFFFF55AA00000000AAAA00000055AA5555FFFF00FFFFFFAAFFFF
FFFFFF5555FF55AAAA5500AA005500FFFF55FF00FF550055AAAA55AA00555555AA000055
AAAA0000FFFF0055000000AA00FFFFFF00AA0000005500FFFF0000AAAA550000AA555555
00AA55AAAA550055FF00FF55FFFF005500AA0055AAAA55FF5555FFFFFF
FFFFFFFFAAFF0000AA0055005500AAAA55AA00FFFFFFAA55005555550000000000AAAA00
555500FF5555FF0000550000AAAA55AAAA0000550000FF5555FF00555500AAAA00000000
005555550055AAFFFFFF00AA55AAAA0055005500AA0000FFAAFFFFFFFF
FFFFFFFFFF5555AAFFAA55000000555500AA00AAFF00AA005500AA550000550000555500
0000FF55555555FF00FF005500555555005500FF00FF55555555FF000000555500005500
0055AA005500AA00FFAA00AA00555500000055AAFFAA5555FFFFFFFFFF
FFFFFFFFFFFFAAFFAA00000055000000FF55FFAAAA5555000000555555AA55000055AA00
AAAA00FF000000FFAA55AAFFFF000000FFFFAA55AAFF000000FF00AAAA00AA55000055AA
5555550000005555AAAAFF55FF00000055000000AAFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFF555500005500AAAAAA00FF00AA00000000550000000000AA5555AA0000
555500FFAA55FFAA000000AAFF005500FFAA000000AAFF55AAFF0055550000AA5555AA00
000000005500000000AA00FF00AAAAAA005500005555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF55AA00AA0000AAAA55FFFF0055000000550000550055AA000055
00AA5555FFFFAA000055FFAAAA555555AAAAFF550000AAFFFF5555AA00550000AA550055
0000550000005500FFFF55AAAA0000AA00AA55FFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555550000AAAA0000AA55AAAA0055FFAA55000055AA5500550000
0055555555FF55FF00FF00AA0000000000AA00FF00FF55FF55555555000000550055AA55
000055AAFF5500AAAA55AA0000AAAA0000555555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFF0055550000555555005500AAFFAAFF55AA00000055AA55
55AA0055AA00FF00AAAA55FFFF005500FFFF55AAAA00FF00AA5500AA5555AA55000000AA
55FFAAFFAA0055005555550000555500FFFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5555FF0000005500AA550000005555FFFFFFAAAAAAAA005555
5555000000AAAA55550055AAAA555555AAAA55005555AAAA0000005555555500AAAAAAAA
FFFFFF555500000055AA0055000000FF5555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF0055FF0000555555AA55555555FF5555005555000000
000000550000AA0055AA550055555555550055AA5500AA00005500000000000055550055
55FF55555555AA5555550000FF5500FFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF5555AA00FFFF00000000AA5500AA55AA005500AA55FF00
55000055AA5555000000AA55555555555555AA0000005555AA5500005500FF55AA005500
AA55AA0055AA00000000FFFF00AA5555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA55AAAAAAAAAA000000555555000000555555FF
AAFF55AA000000FFFF0055555555555555555500FFFF000000AA55FFAAFF555555000000
555555000000AAAAAAAAAA55AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500AA0000AA00005500000000005500000000FF
AAAA55005500FFFFFFFF000000000000000000FFFFFFFF00550055AAAAFF000000005500
00000000550000AA0000AA005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FF005555AAFFFF0055FFAA55000055FFAA
0000AA555555AAAA55AAAA00AAAA00AAAA00AAAA55AAAA555555AA0000AAFF55000055AA
FF5500FFFFAA555500FF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FF000000AAFF00FF00AA00550000FFAA
AAAA0000FF0000AA0055550000AA00AA0000555500AA0000FF0000AAAAAAFF00005500AA
00FF00FFAA000000FF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF00FFFF5555AAAA000055AAFF5555
005555AA55AA5555000000005500550055000000005555AA55AA5555005555FFAA550000
AAAA5555FFFF00FFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF55AAAA5500AA00005500AA00FF00
0055AA000000AA5500FFFF00FF00FF00FF00FFFF0055AA000000AA550000FF00AA005500
00AA0055AAAA55FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0000AA005500550000005555AAAA
AA005555AA555500AAAA55AA55AA55AA55AA55AAAA005555AA555500AAAAAA5555000000
55005500AA0000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAFFAA550000005500000000AA
000055AA00000000555500AA0055555500AA00555500000000AA550000AA000000005500
000055AAFFAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA0000005500FF0055000055
55AA55005500FF5500AA55FFFF000000FFFF55AA0055FF00550055AA555500005500FF00
55000000AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500005500AAAA555555AA55
00AA005500AAAA550000AA55AAAA00AAAA55AA000055AAAA005500AA0055AA555555AAAA
005500005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55AA00AA0000000000AA
5555000000555500AAAA000000AA00AA000000AAAA0055550000005555AA0000000000AA
00AA55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555550000AAAA00AAAA00
000000550000000055550000550055005500005555000000005500000000AAAA00AAAA00
00555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF0055550000AA00
AAAA00AA5555AA55555555AA5500FF0055AA55555555AA5555AA00AAAA00AA0000555500
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF000000550055
FFFF550055AA000000000000AA55FF55AA000000000000AA550055FFFF550055000000FF
5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0055FF000055
AAAA55000000AAAAAAAAAAAAAAFFFFFFAAAAAAAAAAAAAA00000055AAAA550000FF5500FF
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA00FFFF00
00AA005500005555005555005555FF555500555500555500005500AA0000FFFF00AA5555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA55AAAA
AA000055AA55555555AA005500AA55AA005500AA55555555AA550000AAAAAA55AAFFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500AA00
00AAAA0055555555555500000055555500000055555555555500AAAA0000AA005555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FF
005555000000000000FF00FFFF000000FFFF00FF000000000000555500FF55FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555
FF0000FF5500FF55AA55AA55AAAAAAAAAA55AA55AA55FF0055FF0000FF555555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
FFFF00FFAAFF55555500AA00555500555500AA00555555FFAAFF00FFFFFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
55FF55AAAAFF000000005555AA005500AA555500000000FFAAAA55FF5555FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAFF0000AA00FF55AA5555555500000055555555AA55FF00AA0000FFAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5555AAFFAA55AA00000000FF005500FF00000000AA55AAFFAA5555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFAA000000AAAAAAAAAA555555AAAAAAAAAA000000AAFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5555000055005555005555555555005555005500005555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAFF55AA00AA550000000000000055AA00AA55FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF5555550000AA55FF005500FF55AA0000555555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFFF00555555FFAAFF55555500FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5555FF0000FF00AA00FF0000FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF0055FF550055FF5500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555AA00FF00FF00AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFAA55AA55AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF555500AA005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 2.01665 0.97619 2.10396 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF55AAAA0055AAFFFFFF5500000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000055FFFFFFAA5500AAAA55FF
FFFFAA00FFFFAA00AAAA0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000AAAA00AAFFFF00AAFFFF
FFFFFF55AA5555FFAA00FF00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FF00AAFF5555AA55FFFFFF
FFFFFFFFAA0000AAAAFF55000000FF000055000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000550000FF00000055FFAAAA0000AAFFFFFFFF
FFFFFFFFFF55AAFFAAAA000000FF0055AA00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000AA5500FF000000AAAAFFAA55FFFFFFFFFF
FFFFFFFFFFFFAA00AAFF00000055FFAAFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFAAFF55000000FFAA00AAFFFFFFFFFFFF
FFFFFFFFFFFFFF55AAAA0055AAFFFFFF5500000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000055FFFFFFAA5500AAAA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00FFFFAA00AAAA0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000AAAA00AAFFFF00AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55AA5555FFAA00FF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FF00AAFF5555AA55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA0000AAAAFF55000000FF000055000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000550000FF00000055FFAAAA0000AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AAFFAAAA000000FF0055AA00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000AA5500FF000000AAAAFFAA55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00AAFF00000055FFAAFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFAAFF55000000FFAA00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA0055AAFFFFFF5500000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000055FFFFFFAA5500AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFFAA00AAAA0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000AAAA00AAFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5555FFAA00FF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FF00AAFF5555AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AAAAFF55000000FF000055000000000000
000000000000000000000000000000000000000000000000000000000000000000000055
0000FF00000055FFAAAA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFAAAA000000FF0055AA00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
AA5500FF000000AAAAFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFF00000055FFAAFF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFAAFF55000000FFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA0055AAFFFFFF5500000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
55FFFFFFAA5500AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFFAA00AAAA0000000000000000
000000FFFF00FFFF00000000000000000000000000FFFF00FFFF00000000000000000000
00AAAA00AAFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5555FFAA00FF00000000000000
00000055FF00FF550000000000000000000000000055FF00FF5500000000000000000000
FF00AAFF5555AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AAAAFF55000000FF000055
00000000AAAAAA000000000000000000000000000000AAAAAA00000000550000FF000000
55FFAAAA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFAAAA000000FF0055AA00
00005500AAFFAA005500000000000000000000005500AAFFAA0055000000AA5500FF0000
00AAAAFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFF00000055FFAAFF00
000000AA55AA55AA00000000000000000000000000AA55AA55AA00000000FFAAFF550000
00FFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA0055AAFFFFFF5500
000000FFAAFFAAFF00000000000000000000000000FFAAFFAAFF0000000055FFFFFFAA55
00AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFFAA00AAAA0000
00000055FFFFFF550000000000000000000000000055FFFFFF550000000000AAAA00AAFF
FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5555FFAA00FF00
005500AA00AAAA000000000000000000000000000000AAAA00AA00550000FF00AAFF5555
AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AAAAFF5500
00555555FFAAAA550000000000000000000000000055AAAAFF555555000055FFAAAA0000
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFAAAA0000
0055550055FF5555000000000000000000000000005555FF55005555000000AAAAFFAA55
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFF0000
00555500AA00AA000000000000000000000000000000AA00AA005555000000FFAA00AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA0055
AAFFFFAA55AAFF000000000000000000000000000000FFAA55AAFFFFAA5500AAAA55FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF
AA00AAAAFFFF5500000000000000000000000000000055FFFFAAAA00AAFFFF00AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA55
55FFAA00FF55005500000000000000000000000000550055FF00AAFF5555AA55FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00
00AAAAFF550055005500000000005500000000005500550055FFAAAA0000AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
AAFFAAAA000055555500000000550055000000005555550000AAAAFFAA55FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA00AAFF000000AA00000055AA000000AA55000000AA000000FFAA00AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55AAAA0055AAFFAA55FFAAFF000000FFAAFF55AAFFAA5500AAAA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA00FFFFAA00AAFFFFFF5500000055FFFFFFAA00AAFFFF00AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55AA5555FFAA00AAAA0000000000AAAA00AAFF5555AA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA0000AAAAFF55FFFF000000FFFF55FFAAAA0000AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55AAFFAA00AA00AAAAAAAAAA00AA00AAFFAA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA00AAFF555555FF55FF555555FFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55AAAA0000AA00AA00AA0000AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00FF00FFAA55AAFF00FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55AA5500FFAAFF0055AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA000055FF550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AAFFFFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 2.11269 0.200176 2.2 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF555555AAFFFF55AA0000FFFFAAAAAA0000AAAAAA0000FFFFFFFF555555555555FF0000
AA55AA5555FF550000FFAAAA5555FF5555AAAAFF000055FF5555AA55AA0000FF55555555
5555FFFFFFFF0000AAAAAA0000AAAAAAFFFF0000AA55FFFFAA555555FF
FFFFAA55FFFFFFFFAA0000AAAA00FFAA0000AAFFAA0000AAAA00AAAAAAAAAAAAAAAA0000
FFAAFF00FFFFFF0000AAAAFF00FFFFFF00FFAAAA0000FFFFFF00FFAAFF0000AAAAAAAAAA
AAAAAA00AAAA0000AAFFAA0000AAFF00AAAA0000AAFFFFFFFF55AAFFFF
FFFFFF55AA5555AA55AA00000000FF55555555FF00AA00000000AAFFAAAA55AAAAFF0000
FF5555AA00AAAA0055AAAA555555AA555555AAAA5500AAAA00AA5555FF0000FFAAAA55AA
AAFFAA00000000AA00FF55555555FF00000000AA55AA5555AA55FFFFFF
FFFFFFFFAAAAAAAAFF5555555500AAAAAAAAAAAA000000AA0055AAAA00FFAA55AAAA0000
FF55AAFF00000000FFFF55FFAAFF55FFAAFF55FFFF00000000FFAA55FF0000AAAA55AAFF
00AAAA5500AA000000AAAAAAAAAAAA0055555555FFAAAAAAAAFFFFFFFF
FFFFFFFFFF5555FFFFFFAAFFFF0000000000000000FF000000FFFF555555AAAAAAFF0000
AAAAAA555555555555AA55FF00AAAAAA00FF55AA555555555555AAAAAA0000FFAAAAAA55
5555FFFF000000FF0000000000000000FFFFAAFFFFFF5555FFFFFFFFFF
FFFFFFFFFFFFAA5555AA55AA5555555500555555550000AA000055FFAAFF5555FF5500AA
00FFAAAAAAAAAAAAAAAA55FF0000000000FF55AAAAAAAAAAAAAAAAFF00AA0055FF5555FF
AAFF550000AA0000555555550055555555AA55AA5555AAFFFFFFFFFFFF
FFFFFFFFFFFFFF55AAFFAAFFAAFFFF00FF00FFFF00FF000000FF00FF5555AAFFFFFF0000
00AAAAFFAAAA55AAAAFFAA55555500555555AAFFAAAA55AAAAFFAAAA000000FFFFFFAA55
55FF00FF000000FF00FFFF00FF00FFFFAAFFAAFFAA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA00FF5555AA550000AAAA00005555550000AAAAAAAA5555AA5500
AA55AAAA00FFAAFF00AAAAFFFF00FF00FFFFAAAA00FFAAFF00AAAA55AA0055AA5555AAAA
AAAA00005555550000AAAA000055AA5555FF00AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555555AAFFFF55AA00000000FF00FFFF0000FFAAAA55AAFFFF55AA
00FFFF555555AAAA00000000550055005500000000AAAA555555FFFF00AA55FFFFAA55AA
AAFF0000FFFF00FF00000000AA55FFFFAA555555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA55FFFFFFFFAA0000AA000055AA55555555AAAA55FFFFFFFF00
AA00AAAAAAAAAA55AA0000FF00FF00FF00FF0000AA55AAAAAAAAAA00AA00FFFFFFFF55AA
AA55555555AA550000AA0000AAFFFFFFFF55AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AA5555AA55AA000000FF00FFAAFFFFAA55AAAAAA00AAAA00
0000FFAAAAFFAAAAAA5500550055005500550055AAAAAAFFAAAAFF000000AAAA00AAAAAA
55AAFFFFAAFF00FF000000AA55AA5555AA55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAFF555555550000AAAA5555AAAAAAFFAA00000000
AA0055FF5555AAAAFF00FF00FF00FF00FF00FF00FFAAAA5555FF5500AA00000000AAFFAA
AAAA5555AAAA000055555555FFAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF5555FFFFFFAAFFFF0000FFAAAAAAAAFFAAAA00FF0000FF
00AA55FF00FFFF55FF00005555AA00AA55550000FF55FFFF00FF55AA00FF0000FF00AAAA
FFAAAAAAAAFF0000FFFFAAFFFFFF5555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555AA55AA55555555AAAAFF00AAAAFF0000555500
00FFAA555555AA55FF0000FFFF00AA00FFFF0000FF55AA555555AAFF000055550000FFAA
AA00FFAAAA55555555AA55AA5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFAAFFAAFFFF00FFAA00AA55AAAA0000FFFF00
00AAAAFFFF00FFAA555500AAAA000000AAAA005555AAFF00FFFFAAAA0000FFFF0000AAAA
55AA00AAFF00FFFFAAFFAAFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FF5555AA55000000FFAAFF00AA00005500
5555FF550000AAAAFFFF00000000FF00000000FFFFAAAA000055FF555500550000AA00FF
AAFF00000055AA5555FF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555AAFFFF55AA0000FF55FF000000FF00FF
00FFFFFF0000FFAAAA00AA0000AA00AA0000AA00AAAAFF0000FFFFFF00FF00FF000000FF
55FF0000AA55FFFFAA555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFFFFAA0000AAAAAA00555555AA00
AA00AAAA0000AAAAFF000000FF00AA00FF000000FFAAAA0000AAAA00AA00AA55555500AA
AAAA0000AAFFFFFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5555AA55AA0000000000FFFFAAFF00
0000AAFF0000FFAAAA0000AA00AA55AA00AA0000AAAAFF0000FFAA000000FFAAFFFF0000
000000AA55AA5555AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAFF5555555500AA00AAAA5555
555555FF0000AAAA55AA000000FFAAFF000000AA55AAAA0000FF5555555555AAAA00AA00
55555555FFAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFFFFFAAFFFF000000FFAAAAAA
AAAAAAAA0000AAFFAA55AA0000FF55FF0000AA55AAFFAA0000AAAAAAAAAAAAAAFF000000
FFFFAAFFFFFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555AA55AA5555555500000000
0000000000AA55AA55AAFF0000AAAAAA0000FFAA55AA55AA000000000000000000555555
55AA55AA5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFAAFFAAFFFF00FF0000AA
0000AA0000AAFFFF55AAAA005555FF555500AAAA55FFFFAA0000AA0000AA0000FF00FFFF
AAFFAAFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FF5555AA5500FF0000
00AA55AA00000055FFAA00FF00FFFFFF00FF00AAFF55000000AA55AA000000FF0055AA55
55FF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555AAFFFF55AA00AA00
00FFAAFF0000AA55FF00AA555555AA555555AA00FF55AA0000FFAAFF0000AA00AA55FFFF
AA555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFFFFAA000000
AA5555FF0000FFAA555555FFAA55FF55AAFF555555AAFF0000FF5555AA000000AAFFFFFF
FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5555AA55AA0000
FFAA55FF0000FF55FFAAFFFFFF55AA55FFFFFFAAFF55FF0000FF55AAFF0000AA55AA5555
AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAFF555555
55AAAAAA0000FF55AA55AA5555AAFFAA5555AA55AA55FF0000AAAAAA55555555FFAAAAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFFFFFAAFF
FF00AAFF0000FF55AAAAAA55FFAA00AAFF55AAAAAA55FF0000FFAA00FFFFAAFFFFFF5555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555AA55AA
555555FF0000AAAAAA55AAAAAA00FF00AAAAAA55AAAAAA0000FF555555AA55AA5555AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFAAFF
AAFF55AA5500AAFFAAAAAAFFAA005500AAFFAAAAAAFFAA0055AA55FFAAFFAAFFAA55FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FF
5555AAFF00FF00AAAA55AAAA00FF00FF00AAAA55AAAA00FF00FFAA5555FF00AAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555
AAFF5555AA00AA00FFAAFF00AA555555AA00FFAAFF00AA00AA5555FFAA555555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55
FFFFFFAAFF000000AAAA555555FFAAFF555555AAAA000000FFAAFFFFFF55AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
AA5555AAAA0000AA00FFAAFF55AA55AA55FFAAFF00AA0000AAAA5555AA55FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAAAAAA55AA000000FF55FF00FFAAFF00FF55FF000000AA55AAAAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5555FFFF00AA0000AAAAAA0055FF5500AAAAAA0000AA00FFFF5555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA5555AA00FF0000000000FFFFFF0000000000FF00AA5555AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55AAFF0000555555555555AA5555555555550000FFAA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAA0000FFFFAAFF55AAFFAA55FFAAFFFF0000AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55555555AA55AA55FFFFFF55AA55AA55555555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA55FFAAAAAAFFFFFFFFFFAAAAAAFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55AA55AAAA5555AA5555AAAA55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAAAFFAAFF55FFAAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555FF00AAAAAA00FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA555555FF555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AAFFFFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 2.11269 0.39418 2.2 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF555555555555555555FF55FF550055AAAA5500AA00AA00AA00FF555555FFFFFF55FF55
00AAAAAA0055555555AAFFFFAAAAAAAAAAFFFFAA5555555500AAAAAA0055FF55FFFFFF55
5555FF00AA00AA00AA0055AAAA550055FF55FF555555555555555555FF
FFFFAA55AAFF55AAAA55FF00FF555555FFFF55555500AA00555555AAFF00FF5500FFFFFF
0000000000FFFF00FFFF550000000000000055FFFF00FFFF0000000000FFFFFF0055FF00
FFAA55555500AA00555555FFFF555555FF00FF55AAAA55FFAA55AAFFFF
FFFFFF555500FFAAAAFF0055AA55FF55AA5555FF55555500AAFF55550000FF555555AA55
555555555555AA5500FF555555555555555555FF0055AA55555555555555AA555555FF00
005555FFAA00555555FF5555AA55FF55AA5500FFAAAAFF005555FFFFFF
FFFFFFFFAA550000000055AAFFAA5555FFFFAA00AAFF55555500FFFF0000FF5555FF55FF
AA55AAAA55AAFFAA0055FF55AAAAAAAAAA55FF5500AAFFAA55AAAA55AAFF55FF5555FF00
00FFFF00555555FFAA00AAFFFF5555AAFFAA550000000055AAFFFFFFFF
FFFFFFFFFF555555555555FFFFFF5555FF0055555500FFFFAA0055FF0000FF5555FF00AA
AAFFFF55FFAAAA0000FFFFFFAAAAFFAAAAFFFFFF0000AAAAFF55FFFFAAAA00FF5555FF00
00FF5500AAFFFF0055555500FF5555FFFFFF555555555555FFFFFFFFFF
FFFFFFFFFFFFAA55AAFF55AA5555AAAA555555FFAA550000555555FF0000FF5555FF0000
000055FF550055555555AA55550055005555AA555555550055FF5500000000FF5555FF00
00FF555555000055AAFF555555AAAA5555AA55FFAA55AAFFFFFFFFFFFF
FFFFFFFFFFFFFF555500FFAAAAAAAAFFAA00FFFFFF55555555FFAA55555555AAAA555555
555555FF00AA55AAAA55FFFF00FF00FF00FFFF55AAAA55AA00FF555555555555AAAA5555
5555AAFF55555555FFFFFF00AAFFAAAAAAAAFF005555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55000000000000555555AA5555FFAAFFFFFF55AAFFFFAAAAFF5555
FF5555FF0000AAFFAAAAAA00AA555555AA00AAAAAAFFAA0000FF5555FF5555FFAAAAFFFF
AA55FFFFFFAAFF5555AA55555500000000000055AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555555555555555FFAAFFAAFF005555AA5555FFFFFFFF55FF00FF
FFFFAA55555555000000AA005555FF555500AA00000055555555AAFFFFFF00FF55FFFFFF
FF5555AA555500FFAAFFAAFF5555555555555555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA55AAFF55AAAA555500000055AAAAAAFF55AA5555AA55AA5500
0055FFFFAAFF555555555500AAFFFFFFAA005555555555FFAAFFFF55000055AA55AA5555
AA55FFAAAAAA550000005555AAAA55FFAA55AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF555500FFAAAAFF00FF0000FFFF55FFFFFFAAAAAAAAFFFF5555
5555FF005555AAFF00FFAA005555AA555500AAFF00FFAA555500FF55555555FFFFAAAAAA
AAFFFFFF55FFFF0000FF00FFAAAAFF005555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA550000000055AA5500AAAA00FF5500000000000055FF55
55FF5500AAFF55FF0000555555FF55FF5555550000FF55FFAA0055FF5555FF5500000000
000055FF00AAAA0055AA550000000055AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555555555FFFF00000000FF5555555555555555FF00
FFFFFF0000AAAAAA0055AAFF55AA55AA55FFAA5500AAAAAA0000FFFFFF00FF5555555555
555555FF00000000FFFF555555555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFF55AA555555555555AAAA55FF55AAAAAA5555
55AA5555555500555555FFFFFFAAAAAAFFFFFF5555550055555555AA555555AAAAAA55FF
55AAAA555555555555AA55FFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500FFAAAAAAAAAAAAAAAAFFAA00AAFFAAAAFFFF
AAFFAA55FF555555FF5555AA5555005555AA5555FF555555FF55AAFFAAFFFFAAAAFFAA00
AAFFAAAAAAAAAAAAAAAAFF005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55000000000000000000005555550000000055
FFFFFF55AA55AAAA5555FF55FF555555FF55FF5555AAAA55AA55FFFFFF55000000005555
550000000000000000000055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555555555555555555555FF555555555555
FF0055FF55FF55FFFF00FF5555AAAAAA5555FF00FFFF55FF55FF5500FF555555555555FF
555555555555555555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFF55AAAA55FFAA00FF5555FF55AAAA
555555FF00FF55AA555555AAFFFF55FFFFAA555555AA55FF00FF555555AAAA55FF5555FF
00AAFF55AAAA55FFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500FFAAAAFF00555555AAAA5555FFFF
55AAFF5500AAAAAAFFFF00AA00AAAAAA00AA00FFFFAAAAAA0055FFAA55FFFF5555AAAA55
555500FFAAAAFF005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550000000055AAFFFFAAAAFF5555AA
55FFFFFF00000000AAAA005555550055555500AAAA00000000FFFFFF55AA5555FFAAAAFF
FFAA550000000055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555555555FFFFFFFF55FF00FFFF
5555AA5555555555550055AAFF555555FFAA5500555555555555AA5555FFFF00FF55FFFF
FFFF555555555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFF55AA5555AA55AA5500FF
5555FFFFAA55AAFF555555FFFFFFAAFFFFFF555555FFAA55AAFFFF5555FF0055AA55AA55
55AA55FFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500FFAAAAAAAAFFFF555555
AAFFFFFFFF555500FFAA00FF5500000055FF00AAFF005555FFFFFFFFAA555555FFFFAAAA
AAAAFF005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500000000000055FF5555
FFFFFFFFFFFFAA55000000FF5555555555FF00000055AAFFFFFFFFFFFF5555FF55000000
00000055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555555555555555FF00FF
FFFFFFFFFFFFFF5555555555AAAAAAAAAA5555555555FFFFFFFFFFFFFFFF00FF55555555
55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFF55AAAA555555
AA5555AA5555AA55FFAA55FFAAAAFFAAAAFF55AAFF55AA5555AA5555AA555555AAAA55FF
AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500FFAAAAFF00FF
FF5555FFFFAAFFAA00AA00FF55FFFFFF55FF00AA00AAFFAAFFFF5555FFFF00FFAAAAFF00
5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550000000055AA
5555FF5500000055555500AAAAAA00AAAAAA0055555500000055FF5555AA550000000055
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555555555FF
FF00FF5555555555FF5555550055555500555555FF5555555555FF00FFFF555555555555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFF55AA
555555AAAA55FFAA00AAFF555555FF555555FFAA00AAFF55AAAA555555AA55FFAA55AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500FFAA
AAAAAAAAFFAA00AA005555AAAA55AA55AAAA555500AA00AAFFAAAAAAAAAAFF005555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550000
000000000055555500AAFFFF55FF55FF55FFFFAA005555550000000000000055AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555
555555555555FF55555500FF55AA55AA55FF00555555FF555555555555555555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55
AAFF55AAAAAA5555FF555555AAFFAAFFAA555555FF5555AAAAAA55FFAA55AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
5500FFAAAAFFAAFFFFFFAAFFFF550055FFFFAAFFFFFFAAFFAAAAFF005555FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55000000005555AA555500FF555555FF005555AA55550000000055AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF555555555555FF55FF555555AAAAAA555555FF55FF555555555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA55AAFF55AA55AA55FFAA000000AAFF55AA55AA55FFAA55AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF555500FFAAAAAAFF00555555555500FFAAAAAAFF005555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA55000000000055AAAAAAAAAA55000000000055AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55555555555555FFFF55FFFF55555555555555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA55AAFFFFAA00AAAAAA00AAFFFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF555500005555550055555500005555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5500AAFF555555FFAA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55555500FFAAFF00555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA55AA00AA00AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF555500AA005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 2.11269 0.588183 2.2 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF5555555500FF0000AAAA5555FFFF005500FFAAFFFF0000555555FFFFAAFFFFFFFFFFFF
FFFFFF00AA55FFFFAA0000AAAA555555AAAA0000AAFFFF55AA00FFFFFFFFFFFFFFFFFFAA
FFFF5555550000FFFFAAFF005500FFFF5555AAAA0000FF0055555555FF
FFFFAAFFFFAA00AAFF0000FFFF005555FFAA000000AAAA55AAFFFF005500AA0000550055
FF005555FFFF00555555FF55FFFFAAFFFF55FF55555500FFFF555500FF5500550000AA00
5500FFFFAA55AAAA000000AAFF555500FFFF0000FFAA00AAFFFFAAFFFF
FFFFFF5500FF00AA5555FF5500FFAAFFFFFF5555FF55FFFFAAAA00AAFF555555FF55AAAA
AA00FFFF0055FF55AAFFFFFF0055555500FFFFFFAA55FF5500FFFF00AAAAAA55FF555555
FFAA00AAAAFFFF55FF5555FFFFFFAAFF0055FF5555AA00FF0055FFFFFF
FFFFFFFFAA00AAFFAAFFFFFFAA0000005555AAFFFFFF0055555555FFFFFF00FFFFFFAAAA
FFAA0000AAFFFFFF00005555AAAAAAAAAA55550000FFFFFFAA0000AAFFAAAAFFFFFF00FF
FFFF5555555500FFFFFFAA5555000000AAFFFFFFAAFFAA00AAFFFFFFFF
FFFFFFFFFF555555AA00AA00AA55AAAA55FFAAAA0000AAFFFFAAFF55005555FF0055FFFF
5500AAFF000055FF00AAFFFFAAAAFFAAAAFFFFAA00FF550000FFAA0055FFFF5500FF5555
0055FFAAFFFFAA0000AAAAFF55AAAA55AA00AA00AA555555FFFFFFFFFF
FFFFFFFFFFFFAAFFFF555555FFFF0000FFFFFF55FF5555550000FF55AAAAAAAA00FFFFFF
FF00AA5555FF55AA55AA0000AA550055AA0000AA55AA55FF5555AA00FFFFFFFF00AAAAAA
AA55FF0000555555FF55FFFFFF0000FFFF555555FFFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFF5500FFFFAA5555AAAA555500FFFFFFAA55FF5555AAFFAAAAFFAA00AAAA
00AAFFAAFFFFFFAAAAAAFF00AA55FF55AA00FFAAAAAAFFFFFFAAFFAA00AAAA00AAFFAAAA
FFAA5555FF55AAFFFFFF005555AAAA5555AAFFFF0055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00AAAAFFFFAAAAFFFFAA0000AAAAFFFFFFAA5500FF000055AAAAFF
AA00555555AA5555555555AAAAFFFFFFAAAA5555555555AA55555500AAFFAAAA550000FF
0055AAFFFFFFAAAA0000AAFFFFAAAAFFFFAAAA00AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555555500FF0000AAAAFF00AA550000AAAAFF5555AAAA55FFFF55
00AAFFFFAAFFAAFFFFAAFF55FFFFFFFFFF55FFAAFFFFAAFFAAFFFFAA0055FFFF55AAAA55
55FFAAAA000055AA00FFAAAA0000FF0055555555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFFAA00AAFF000000AAFFAAFF00AA5500FFFFAAAAFFFFFFFF
AA005555AA00000055FFFFFF0055005500FFFFFF55000000AA555500AAFFFFFFFFAAAAFF
FF0055AA00FFAAFFAA000000FFAA00AAFFFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5500FF00AA5555FF555555AA00AAFFAAFF0055555555AA5555
AA00FFFFAAAA55AAAAAA00AAAA55FF55AAAA00AAAAAA55AAAAFFFF00AA5555AA55555555
00FFAAFFAA00AA555555FF5555AA00FF0055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00AAFFAAFFFFFFAAFFFF555555AA00AAFFFFAAFFFF55AA
FFAA00AAAAFFAAFFAAAAFF0000FFFFFF0000FFAAAAFFAAFFAAAA00AAFFAA55FFFFAAFFFF
AA00AA555555FFFFAAFFFFFFAAFFAA00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555AA00AA00AA5555AAFFFFAAAA5500555555AA55FF
FFFF55555555AA00000000AAFF005500FFAA00000000AA55555555FFFFFF55AA55555500
55AAAAFFFFAA5555AA00AA00AA555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF555555FFFF00FF0055FFFF55AAAAAAAAAAFFFF
FFFFFFAAFFFFAAAA55AAAA5500FFAAFF0055AAAA55AAAAFFFFAAFFFFFFFFFFAAAAAAAAAA
55FFFF5500FF00FFFF555555FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFFFAA5555AAAA00FFFFFFFF000000FF000055
0055FF0000AA0055AAFFAAAAAA555555AAAAAAFFAA5500AA0000FF5500550000FF000000
FFFFFFFF00AAAA5555AAFFFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAAAFFFFAAAAFF005555AA55AAAA5555FF55
AAAAAA00FFAAAA55FFFFFF55FFFF00FFFF55FFFFFF55AAAAFF00AAAAAA55FF5555AAAA55
AA555500FFAAAAFFFFAAAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555555500FF0000AAFFFFAAAAAAFFAAFFFFFF
AAAAFFAA000000FFFFFFFFFF0055FF5500FFFFFFFFFF000000AAFFAAAAFFFFFFAAFFAAAA
AAFFFFAA0000FF0055555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAA00AAFF0000AAAAFFAAAA00550055
555555AA00FFAA00AAAA0000AAFFFFFFAA0000AAAA00AAFF00AA55555555005500AAAAFF
AAAA0000FFAA00AAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FF00AA5555FF55FFFFFF55FF55AAAA
AAAAAAAAFF0055AAAAFFAA00FF005500FF00AAFFAAAA5500FFAAAAAAAAAAAA55FF55FFFF
FF55FF5555AA00FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFFAAFFFFFF005500FFFFFF0000
0000000000AAFF55FFFFFF5555AAAAAA5555FFFFFF55FFAA00000000000000FFFFFF0055
00FFFFFFAAFFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555AA00AA00AAFF5555AA5555FF
5555FF5555FFFFFF005500FFFF000000FFFF005500FFFFFF5555FF5555FF5555AA5555FF
AA00AA00AA555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF555555FFFFFFAAFFAA55FF
00FFFFFFAA555500FFAAFF005555FF555500FFAAFF005555AAFFFFFF00FF55AAFFAAFFFF
FF555555FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFFFAA5555000000AA55FF
00AA0000AA55FFAA000000AAFF55AA55FFAA000000AAFF55AA0000AA00FF55AA00000055
55AAFFFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAAAFFFFAA00FFAAAAAA
00FF00AAFFAA555555FF555555AAFFAA555555FF555555AAFFAA00FF00AAAAAAFF00AAFF
FFAAAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555555500FF00AAAAFFAA
AA5555FFFFFF55AAFFFFFFAA55FFFFFF55AAFFFFFFAA55FFFFFF5555AAAAFFAAAA00FF00
55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAA00AAFFAAAA00
55AAFFFFFFFFFFAAAA00AAAAFFFFFFFFFFAAAA00AAAAFFFFFFFFFFAA5500AAAAFFAA00AA
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FF00AA55555555
FFAAAA0000550000FF00AA550000AA000055AA00FF0000550000AAAAFF55555555AA00FF
0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFFAAFFFFAA
55555555FF55AAAA5555FFFF00AAFFAA00FFFF5555AAAA55FF55555555AAFFFFAAFFAA00
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555AA00AAAA
FFFFAAFFFFFF0000FFFF005555FFFFFF555500FFFF0000FFFFFFAAFFFFAAAA00AA555555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF555555
55AA55000055FF555500FFAAFF550055FFAAFF005555FF55000055AA55555555FFFFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFFFAA
55FFFFAA00FFFFFFAAFF0055AA55FF55AA5500FFAAFFFFFF00AAFFFF55AAFFFF0055FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAAA
FFFFFFFF555500555555AAAAAAFFFFFFAAAAAA555555005555FFFFFFFFAAAA00AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555
55000055FFAA55AAFFFF00000000AA00000000FFFFAA55AAFF55000055555555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
FFAA00FFFFFF55AA0000AAFF00AAFFAA00FFAA0000AA55FFFFFF00AAFFFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
00FF00AA00AAAAAAFF00AA5555FFFFFF5555AA00FFAAAAAA00AA00FF0055FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA00AAFFAA0055AA00AAFFAAFFFFFFFFFFAAFFAA00AA5500AAFFAA00AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF555555AA00FFFF555555AA0000AA0000AA555555FFFF00AA555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFF555500FFFF00FF00AAFFAA00FF00FFFF005555FFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5500FFFFAA00AAAA5555FFFFFF5555AAAA00AAFFFF0055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA00AAAAFF0000FFFF005500FFFF0000FFAAAA00AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55555555AAAA5555AAAAAA5555AAAA55555555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFFFAAAAFFFF000000FFFFAAAAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5500FF00005555FF55550000FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00AAFF00FFFFFF00FFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555555AAAA00AAAA555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFF55FF55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5500FFFFFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 2.11269 0.782187 2.2 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF55555555000055FF5500FFFFAA5555000055AA00000000AA5500FF005555AA55FF00FF
005500FF00555555AA5555AA0000000000AA5555AA55555500FF005500FF00FF55AA5555
00FF0055AA00000000AA5500005555AAFFFF0055FF55000055555555FF
FFFFAAFFFF0000FFFFFF0000AAAAFFFFAA00FFFF55555555FFFFAA0000FFFFAAAAAA0055
FF55AAAA00FFFFAAFFAAFFFF5555555555FFFFAAFFAAFFFF00AAAA55FF5500AAAAAAFFFF
0000AAFFFF55555555FFFF00AAFFFFAAAA0000FFFFFF0000FFFFAAFFFF
FFFFFF5500FFAA00005555FF55FFFFFFFF555500FFFF00FFFFFFFF5555550000000000FF
FFFFAAAAFF0055FFFFFF5500FFFF00FFFF0055FFFFFF5500FFAAAAFFFFFF000000000055
5555FFFFFFFF00FFFF005555FFFFFFFF55FF55550000AAFF0055FFFFFF
FFFFFFFFAA000000FF00FFFFFF00555500FFFF000055FF55005555AAFFFF0000FFAA0055
5500000000AAFFFFFFFFFF000055FF550000FFFFFFFFFFAA00000000555500AAFF0000FF
FFAA55550055FF550000FFFF00555500FFFFFF00FF000000AAFFFFFFFF
FFFFFFFFFF5555555500AA0000AAFFFF00005500AA55FF00FFAAFFFF5500FFAA000000FF
FF0000FF000000550055FF0000FFFFFF0000FF550055000000FF0000FFFF000000AAFF00
55FFFFAAFF00FF55AA00550000FFFFAA0000AA0055555555FFFFFFFFFF
FFFFFFFFFFFFAAFFFF000000FFAAAA0000FF00FFAAAAAA0055FFFFFFFFAA000000FF0000
555555FF0000FF00FFAA555555550055555555AAFF00FF0000FF5555550000FF000000AA
FFFFFFFF5500AAAAAAFF00FF0000AAAAFF000000FFFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFF5500FFAA0055FFFF555555AA0000000000FFFFFFFFFFFF55555555AA00
FFFFAA5555555500AAAAFFFFAA55FF55AAFFFFAAAA0055555555AAFFFF00AA55555555FF
FFFFFFFFFF0000000000AA555555FFFF5500AAFF0055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA000000FFFFFFFF00FFFF55555555FF5500550000AAAAAAAAAAAAFF
0055FFFF00FFFF00000000AAAAFFFFFFAAAA00000000FFFF00FFFF5500FFAAAAAAAAAAAA
0000550055FF55555555FFFF00FFFFFFFF000000AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55555555000055FF5500FFFFAA55FF00FF00FF0000000000000000
AAFF5500FF0055555555FF55FFFFFFFFFF55FF5555555500FF0055FFAA00000000000000
00FF00FF00FF55AAFFFF0055FF55000055555555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFF0000FFFFFF0000AAAAFF5500AA00555555555555555555
FFFFFF0000AAFFFF00FFFFFF0055005500FFFFFF00FFFFAA0000FFFFFF55555555555555
555500AA0055FFAAAA0000FFFFFF0000FFFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5500FFAA00005555FF55FFFFFF000000FFFF00FFFF00FFFFAA
555500FF000000AA00555500FF00FF00FF00555500AA000000FF005555AAFFFF00FFFF00
FFFF000000FFFFFF55FF55550000AAFF0055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA000000FF00FFFFFF00555500AAFF0055FF5500FF0055FF
FFAA550000FF000000FFFF000055AA550000FFFF000000FF000055AAFFFF5500FF0055FF
5500FFAA00555500FFFFFF00FF000000AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF5555555500AA0000AAFFFF000000AAFFFFFF00AA00FFFF
FFFF55AAAA55555555550000FFAAFFAAFF00005555555555AAAA55FFFFFFFF00AA00FFFF
FFAA000000FFFFAA0000AA0055555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF000000FFAAAA0000FF00000055FF000000FF55
0055FFAAAAFF55AAFFFFAA0055FFFFFF5500AAFFFFAA55FFAAAAFF550055FF000000FF55
000000FF0000AAAAFF000000FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFAA0055FFFF555555AA00FF00FF555555FF00
FF00FF55FFFFFFAAAA000000FFFFFFFFFF000000AAAAFFFFFF55FF00FF00FF555555FF00
FF00AA555555FFFF5500AAFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000FFFFFFFF00FFFF555500AAAAAAAAAA00
5555FF00FF5500000000FF00005500550000FF0000000055FF00FF555500AAAAAAAAAA00
5555FFFF00FFFFFFFF000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555000055FF5500FFFF00000000000000
FFFF0055AA55FF55555555AAAA55FF55AAAA55555555FF55AA5500FFFF00000000000000
FFFF0055FF55000055555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF0000FFFFFF0000AAAA5500AAFF00AA
5555AAAAAAFFFFFFAAFFFFAAAAFFFFFFAAAAFFFFAAFFFFFFAAAAAA5555AA00FFAA0055AA
AA0000FFFFFF0000FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFAA00005555FF55FFFF000000AAFF
AAFFFF55FFFFFFFFFF5500000000AA0000000055FFFFFFFFFF55FFFFAAFFAA000000FFFF
55FF55550000AAFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000FF00FFFFFF0055555555FFFF
FF5500FFFFFFFFFFFFFF0000FF000000FF0000FFFFFFFFFFFFFF0055FFFFFF5555555500
FFFFFF00FF000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555555500AA0000AAFFFFAAFFFFFF
FFFF000055FF00555500FF0000AA55AA0000FF00555500FF550000FFFFFFFFFFAAFFFFAA
0000AA0055555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF000000FFAAAA000000AAAA
000055AAAAAA00FFFF00AA00FFAAAAAAFF00AA00FFFF00AAAAAA550000AAAA000000AAAA
FF000000FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFAA0055FFFF555555FFFF
5555FFAAAAFFAA0000AAFFAA0000000000AAFFAA0000AAFFAAAAFF5555FFFF555555FFFF
5500AAFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000FFFFFFFF00FFFFFF
FF00FF55FFFFFF5555FFFFFF5555555555FFFFFF5555FFFFFF55FF00FFFFFFFF00FFFFFF
FF000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555000055FF550000
5555FF00FF5500FFFF005500FFFF00FFFF005500FFFF0055FF00FF5555000055FF550000
55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF0000FFFFFF00AA
FF55AA55AA55FF5500FFAAFF0055FF5500FFAAFF0055FF55AA55AA55FFAA00FFFFFF0000
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFAA00005555FF
FFFFAAAAAAFFFFFFAA000000AAFFFFFFAA000000AAFFFFFFAAAAAAFFFFFF55550000AAFF
0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000FF00FFFF
FFFFFF55FFFFFFFFFF555555FFFFFFFFFF555555FFFFFFFFFF55FFFFFFFFFF00FF000000
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555555500AA00
005500FFFFFFFFFFFFFFAAFFFFFFFFFFFFFFAAFFFFFFFFFFFFFF00550000AA0055555555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF000000
FFAA5500005555000055FFFFFFFFFFFFFFFFFF5500005555000055AAFF000000FFFFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FFAA00
55FFFFAA00FFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFF00AAFFFF5500AAFF0055FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000
FFFFFFFF555500FF0000AA00005500550000AA0000FF005555FFFFFFFF000000AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555
55000055FFAA5500FF000000FF00FF00FF000000FF0055AAFF55000055555555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
FF0000FFFFFF55AA0000FF000055AA550000FF0000AA55FFFFFF0000FFFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
00FFAA000055FFAAAA550000FFAAFFAAFF000055AAAAFF550000AAFF0055FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA000000FF00FF55FFFFAA0055FFFFFF5500AAFFFF55FF00FF000000AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5555555500AAAAAA000000FFFFFFFFFF000000AAAAAA0055555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFF0000000000FF00005500550000FF0000000000FFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5500FFAA0055AAAA00FF00FF00FF00AAAA5500AAFF0055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA000000FFFF55FF5500AA0055FF55FFFF000000AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF5555555500FFFFFF000000FFFFFF0055555555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFFF00AAAA0000FF0000AAAA00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5500FFAAAAFF00AA00FFAAAAFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00000000AAFFAA00000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55555555FFFFFF55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFF005500FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5500FFAAFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 2.11269 0.97619 2.2 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF555500550055AAAA00AA55555555FF005500AA00AA00AA0000AA005555AA55FF55AA00
000000FFAAAAFFAA5555AA00AAAA55AAAA00AA5555AAFFAAAAFF00000000AA55FF55AA55
5500AA0000AA00AA00AA005500FF55555555AA00AAAA550055005555FF
FFFFAA550000FFFF55FF550000550000AA55FF5500AAAA55555555AAAAAAAAFFFFFF0055
AAAA550055FFFFFF55AAFFAA00AAAAAA00AAFFAA55FFFFFF550055AAAA5500FFFFFFAAAA
AAAA55555555AAAA0055FF55AA000055000055FF55FFFF000055AAFFFF
FFFFFF55AA00555500000055AAAAAA5500FFFFFFAA00AAAAAAAAAAAA00AAAA00000000FF
FF550000FFFFFFFFFF005555AAAA00AAAA555500FFFFFFFFFF000055FFFF00000000AAAA
00AAAAAAAAAAAA00AAFFFFFF0055AAAAAA55000000555500AA55FFFFFF
FFFFFFFFAAAA55FFAA0055AAFFAAAAFF5555005555AAAA00AAAA00AAAA5555AAAA55AA00
000055AA000000000000FFFF0055FF5500FFFF000000000000AA55000000AA55AAAA5555
AAAA00AAAA00AAAA5555005555FFAAAAFFAA5500AAFF55AAAAFFFFFFFF
FFFFFFFFFF550000AAAA55FFFFFF5500550000FFFFAAAAFF0055FF5500FFFFAAAAFFFF55
5555FFAAAA55AAAA55AA000000FFFFFF000000AA55AAAA55AAAAFF555555FFFFAAAAFFFF
0055FF5500FFAAAAFFFF0000550055FFFFFF55AAAA000055FFFFFFFFFF
FFFFFFFFFFFFAA00FF550000AA000055AAFF000000AAAA0000FFFFFF000000AAAA000000
550000AAAAFF55FFFFAAAA55AA000000AA55AAAAFFFF55FFAAAA000055000000AAAA0000
00FFFFFF0000AAAA000000FFAA550000AA000055FF00AAFFFFFFFFFFFF
FFFFFFFFFFFFFF55550000FF0055AAAAAA0000FF00AAAAFF0000000000FFAA00AAAA55AA
AAAA55AA5555000000AAAAFFFF555555FFFFAAAA0000005555AA55AAAAAA55AAAA00AAFF
0000000000FFAAAA00FF0000AAAAAA5500FF00005555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5500AA005500FF55FF555500AAAA0000FF00AA550055FF55FF00FF
55FFFFAAAAAAAA55AAAA00AA0000550000AA00AAAA55AAAAAAAAFFFF55FF00FF55FF5500
55AA00FF0000AAAA005555FF55FF005500AA0055AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55AA00AAFF55550000005500AAAAFF0000AAFFAA55000000555555
000000AAAA00AAAAAA00AAFFAA005500AAFFAA00AAAAAA00AAAA00000055555500000055
AAFFAA0000FFAAAA00550000005555FFAA00AA55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA5555000055AA005500AAAA0000FF005555AAFF00AAFFFFAA
5500AA5555AAAA00AAAA555500FFAAFF005555AAAA00AAAA5555AA0055AAFFFFAA00FFAA
555500FF0000AAAA005500AA5500005555AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55000055AAAAAA005500AAAAFF0000AAFFFF005555FFFFFFFF
55AAAAFFFF0055FF5500FFFF00AA00AA00FFFF0055FF5500FFFFAAAA55FFFFFFFF555500
FFFFAA0000FFAAAA005500AAAAAA55000055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF55FF000055AA555500AA55550055AAFFFFFFFFFF
FFAAAA000000FFFFFF0000AA0055FF5500AA0000FFFFFF000000AAAAFFFFFFFFFFFFAA55
005555AA005555AA550000FF55FFFF00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555500550055AAAAAAFF55AAAAFF55AAAAAA0000AA0000
00AAAA0055AA000000AA55AA5500000055AA55AA000000AA5500AAAA000000AA0000AAAA
AA55FFAAAA55FFAAAAAA550055005555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550000FFFF55FFFFFFAAAA000055FF0055AAAA00FF
00AAAA00FFFF555555FFFFAAAAAA55AAAAAAFFFF555555FFFF00AAAA00FF00AAAA5500FF
550000AAAAFFFFFF55FFFF000055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA005555000000AA00AAAA550000AAFF55FF0000
AA5555AA00000055000000AAAAFFAAFFAAAA00000055000000AA5555AA0000FF55FFAA00
0055AAAA00AA000000555500AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FFAA0055AA5500FF55AAAA5555000000FF
AAAAAAAA0055AAAAAA55AAAA00AA00AA00AAAA55AAAAAA5500AAAAAAAAFF0000005555AA
AA55FF0055AA5500AAFF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000AAAA55FFFFAA000055FFFF00FFAA0055
55AA5555AAAAAAFFAAAAAA00AA555555AA00AAAAAAFFAAAAAA5555AA555500AAFF00FFFF
550000AAFFFF55AAAA000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF550000AA00AA550000AA005555AAAA
AAAAFFFF0055FFFFFF5500FFAAAAAAAAAAFF0055FFFFFF5500FFFFAAAAAAAA555500AA00
0055AA00AA000055FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55550000FF0055AA55FF5555AAAAAAAAFF
AAAA0000AAFFFFFFFFFF0000AAAA00AAAA0000FFFFFFFFFFAA0000AAAAFFAAAAAAAA5555
FF55AA5500FF00005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AA005500FFFFFF00FF55FF0055
55AA55AAAA000000AA0000FF0055FF5500FF0000AA000000AAAA55AA555500FF55FF00FF
FFFF005500AA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00AAFF5555005555550000AAFF
FFAAAAAA00AA55AAAAFF00AA00FFFFFF00AA00FFAAAA55AA00AAAAAAFFFFAA0000555555
005555FFAA00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555000055AAFF55AAAA5555
0055FF0055AA55FF00555555AA000000AA55555500FF55AA5500FF55005555AAAA55FFAA
5500005555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55000055AAAAAA000055FFFFAA
550000AAFF55000000FFFFAA5555555555AAFFFF00000055FFAA000055AAFFFF550000AA
AAAA55000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF55FF0000FFFFFFFF
55AAAA55550000FF000000AAAAAAAAAAAAAA000000FF00005555AAAA55FFFFFFFF0000FF
55FFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555500550055AA0000AA00
0055FFFFAA5500AA0055AA00AAAA00AAAA00AA5500AA0055AAFFFF550000AA0000AA5500
55005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550000FFFF5555FF00
AAFFFFFFFF55AAAA005500FF0055FF5500FF005500AAAA55FFFFFFFFAA00FF5555FFFF00
0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00555500005555
FFFFFFFFFFFF0055FF55AA0000FFFFFF0000AA55FF5500FFFFFFFFFFFF55550000555500
AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FFAA005500
0000000000AA00FFFFFF0055AA000000AA5500FFFFFF00AA0000000000005500AAFF55AA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000AAAA55FF
5555555555FF0000000000FFFF555555FFFF0000000000FF5555555555FF55AAAA000055
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF550000
00550000550055AAAA55AA00000055000000AA55AAAA55005500005500000055FF00AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55550000FF
000055AAAAAA55FFFF55AA55AA005500AA55AA55FFFF55AAAAAA550000FF00005555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AA
0055AAFFAAAAFFFFFFFFAAAAAA005500AAAAAAFFFFFFFFAAAAFFAA5500AA0055AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00
AAFF550055FFFFFFFFFFFF5500FFAAFF0055FFFFFFFFFFFF550055FFAA00AA55FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
55550000FFFFFFFFFFFFFFFF00AA00AA00FFFFFFFFFFFFFFFF00005555AAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
000055AA000000AA00000000AA555555AA00000000AA000000AA55000055FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA00FFFF555555FF0000FF00AAAAAAAAAA00FF0000FF555555FFFF00AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5555005500005555555500AAAA00AAAA0055555555000055005555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA550000FF00FFFFAA55AA555555AA55AAFFFF00FF000055AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55AA005555550055FFAAAAAAAAAAFF550055555500AA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAA55FFAA550000AAAA00AAAA000055AAFF55AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF550000AAAAAA55AA555555AA55AAAAAA000055FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA00FF55FFFFAAAAAAAAAAFFFF55FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5555000000AAAA00AAAA0000005555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55AA00FF55FF55FF00AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55AA55005500550055AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAA55FF55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5500FFFFFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 2.20873 0.200176 2.29604 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF5555FF00FFFF55FF00FFAAAAFFFF00FFFFFFFFFF0000AAAAAA0055FF55000055AA55FF
FFFFFFFF55AAFFFFFFFFAAFF00FFFFFF00FFAAFFFFFFFFAA55FFFFFFFFFF55AA55000055
FF5500AAAAAA0000FFFFFFFFFF00FFFFAAAAFF00FF55FFFF00FF5555FF
FFFFAAFF55550055FFAA00000000AA00FFFFFFFF00FF000000000055FFAAFF00AAAAFFFF
00FFFFFFFFAAAAAAAAAAAAFF5555005555FFAAAAAAAAAAAAFFFFFFFF00FFFFAAAA00FFAA
FF550000000000FF00FFFFFFFF00AA00000000AAFF55005555FFAAFFFF
FFFFFF55AA555555AAFFAA0055000000FFFFFFFF0000AAFF000055AA55FFFF00000000AA
00FFFFFFFFFF55FFFF55FFFF0055FF5500FFFF55FFFF55FFFFFFFFFF00AA00000000FFFF
55AA550000FFAA0000FFFFFFFF0000005500AAFFAA555555AA55FFFFFF
FFFFFFFFAAAA00AAAAFF55FF5500AAFF00FFFFFF00AAFFAA5500AAAAFFFFFF0000550000
00FFFFFFFFFF00555500FFFF00AAAAAA00FFFF00555500FFFFFFFFFF000000550000FFFF
FFAAAA0055AAFFAA00FFFFFF00FFAA0055FF55FFAAAA00AAAAFFFFFFFF
FFFFFFFFFF55FF55FFFF005555AAAAFF5555005555FFFFFF5500000000AA00005500FF00
00FFFF00FFFF00AAAA00FFFF0000000000FFFF00AAAA00FFFF00FFFF0000FF00550000AA
0000000055FFFFFF5555005555FFAAAA555500FFFF55FF55FFFFFFFFFF
FFFFFFFFFFFFAA5555005500FF55FFFF0055FF5500FFFFFFFFAA00FF000000FF00550055
0000AA00FFFF00000000FFFF0000FF0000FFFF00000000FFFF00AA000055005500FF0000
00FF00AAFFFFFFFF0055FF5500FFFF55FF0055005555AAFFFFFFFFFFFF
FFFFFFFFFFFFFF5500FF0055AAFFFFFF00AAAAAA00FFFFFFFFFF555500AAFF00FF005500
FF000000FFFF00005500AA0000FF00FF0000AA00550000FFFF000000FF005500FF00FFAA
005555FFFFFFFFFF00AAAAAA00FFFFFFAA5500FF0055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA000055FFFFFFFF0000000000FFFFFFFFFF0055FF55FFAA0000FF55
5500005500555555FF0000005500550055000000FF555555005500005555FF0000AAFF55
FF5500FFFFFFFFFF0000000000FFFFFFFF550000AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555FF00FFFFFF0000550000FFFFFFFFFF00AAAAAA000000FFAA55
55AA0055FF5500FF55AAAA5500FFAAFF0055AAAA55FF0055FF5500AA5555AAFF000000AA
AAAA00FFFFFFFFFF0000550000FFFFFF00FF5555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF5555005555FF550000FFFFFFFFFF000000000055AAAAAAFF
FFAAAA555500FF00FF55FFFFAA000000AAFFFF55FF00FF005555AAAAFFFFAAAAAA550000
000000FFFFFFFFFF000055FF5555005555FFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AA555555AA55FF0000FFFFFFFFFF00AAFF00AAFFFF55FFFF
FFFF55FF00550055AAFFFFFFFF555555FFFFFFFFAA55005500FF55FFFFFFFF55FFFFAA00
FFAA00FFFFFFFFFF0000FF55AA555555AA55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAAFFFF0000FFFF00FFFF000000AAFFAA55FF00FF
FF00FF55AAAA0055FFFFFF00FFFFAAFFFF00FFFFFF5500AAAA55FF00FFFF00FF55AAFFAA
000000FFFF00FFFF0000FFFFAAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF55FF55FFFF00FF0000AA00FFFF0000FFAAAAAAFFFF00AA
0000FFFFAAAAFF0055550055AAFF55FFAA5500555500FFAAAAFFFF0000AA00FFFFAAAAAA
FF0000FFFF00AA0000FF00FFFF55FF55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55550055005500000055550000FFFF55FFFFFF0000
0055AAFF55FFFF00AAAA00FF55FFAAFF55FF00AAAA00FFFF55FFAA55000000FFFFFF55FF
FF00005555000000550055005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FF0055AA55AA00FF550000555500FFFF00FFAA
0055FFFF005555000000005555AAFFAA555500000000555500FFFF5500AAFF00FFFF0055
55000055FF00AA55AA5500FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000055FFFFAAAA55FF00AAFFFFAA0000AAFF55
FF55005555FF00550000FF0055FFFFFF5500FF00005500FF55550055FF55FFAA0000AAFF
FFAA00FF55AAAAFFFF550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF00FFFF55FF00FFAAAAAAAAFF000000AA
AAAA0055FF00FF00550000AAFFFFFFFFFFAA00005500FF00FF5500AAAAAA000000FFAAAA
AAAAFF00FF55FFFF00FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55550055FFAA000000000000AAFF0000
000000FF55AAAAAA555555FFFFFFFFFFFFFF555555AAAAAA55FF0000000000FFAA000000
000000AAFF55005555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA555555AAFFAA00550000FFAAAAAA55
000055AAFFFF55FFFFAAFFFFFFFFFFFFFFFFFFAAFFFF55FFFFAA55000055AAAAAAFF0000
5500AAFFAA555555AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAAFF55FF5500AA55FFFF55FF
000055FFFFFFFFAA55FFFF00FFFFFFFFFF00FFFF55AAFFFFFFFF550000FF55FFFF55AA00
55FF55FFAAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF55FFFF005555AAAAFFFFFFFFAA
5500AAAAAAAAAAAAFFFF00FF00FFFFFF00FF00FFFFAAAAAAAAAAAA0055AAFFFFFFFFAAAA
555500FFFF55FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555005500FF55FFFFFFFFFFFF
550000000000000000AA005555550055555500AA000000000000000055FFFFFFFFFFFF55
FF0055005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FF0055AAFFFFFFFFFFFFFF
00550000FF000055000000FF5500FF0055FF000000550000FF00005500FFFFFFFFFFFFFF
AA5500FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000055FFFFFFFF00FFFF00
FF005500AA00FF005500005555AAAAAA555500005500FF00AA005500FF00FFFF00FFFFFF
FF550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF00FFFFFF0000AA00
555555AAAAFF00FF0055AA00AAAAFFAAAA00AA5500FF00FFAAAA55555500AA0000FFFFFF
00FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555005555FF55FF
5500FF55FFFF00AA00FF55FF55FFFFFF55FF55FF00AA00FFFF55FF0055FF55FF55550055
55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA555555AA55FF00
FF555500FFFF0000005555AAFFFFFFFFFFAA5555000000FFFF005555FF00FF55AA555555
AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAAFFFF00
00AAAA00555500AAFF0055FFFFFFFFFFFFFF5500FFAA00555500AAAA0000FFFFAAAA00AA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF55FFFF00FF
00000000FF55000000AAFFFFFFFFFFFFFFFFFFAA00000055FF00000000FF00FFFF55FF55
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555005500
550000FFAA55555555FFFFFFFFFFFFFFFFFFFFFF55555555AAFF0000550055005555AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FF0055
AA55AAAAAAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAAAAAA55AA5500FF0055FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000055
FFFFAAAAFFAA55FFFFFFFF00FFFFFFFFFF00FFFFFFFF55AAFFAAAAFFFF550000AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF
00FFFF55FFAAAA0000AA0000FFFFFFFFFF0000AA0000AAAAFF55FFFF00FF5555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
55550055FFAAAAFF000000FF00FFFFFF00FF000000FFAAAAFF55005555FFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
AA555555AAFFAAAAAA5500AA00FFFFFF00AA0055AAAAAAFFAA555555AA55FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAA00AAAAFF55FFFF55000000FFFFFF00000055FFFF55FFAAAA00AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55FF55FFFF00555500FF0000FFFFFF0000FF00555500FFFF55FF55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA5555005500FF55550000FFFFFF00005555FF0055005555AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5500FF0055AAFFFFAA00FFFFFF00AAFFFFAA5500FF0055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA000055FFFFFFFF5555005555FFFFFFFF550000AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF5555FF00FFFFFF0055FF5500FFFFFF00FF5555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFF5555005555FF00FF5555005555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55AA555555AA55FF55AA555555AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA00AAAAFFFFFFAAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55FF55FFFF00FFFF55FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA55550055005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5500FFAAFF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 2.20873 0.39418 2.29604 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF55AA55FF0000000000FFFFFF5555AA55550055AAAAFF00AAAA5500FF555555FFFFFF55
0000FFFFFFAA55AAFF550055AAFFFFFFAA550055FFAA55AAFFFFFF000055FFFFFF555555
FF0055AAAA00FFAAAA55005555AA5555FFFFFF0000000000FF55AA55FF
FFFFAAAA55555555555555AA5555FF55FF555555FFFF0055AAFF555555AAAA55AA555500
00FF005555AAFF00FF555555FFFFFFFFFF555555FF00FFAA555500FF00005555AA55AAAA
555555FFAA5500FFFF555555FF55FF5555AA55555555555555AAAAFFFF
FFFFFF55AAAA55AAAA55AAAAAA55AA55AA55AAAA5555AA00FFFFFFAAFFFF00FFAAAA55AA
00555555FF55AA5500FFAAFFFFFFFFFFFFFFAAFF0055AA55FF55555500AA55AAAAFF00FF
FFAAFFFFFF00AA5555AAAA55AA55AA55AAAAAA55AAAA55AAAA55FFFFFF
FFFFFFFFAAAAFFFF55AAAAAAAAAA55FF55AAAAAAFFFFAA550055FF00FF5500AAAAAAFF00
FF00AAFFFFFFAAAA5500FFFFFFFFFFFFFFFFFF0055AAAAFFFFFFAA00FF00FFAAAAAA0055
FF00FF550055AAFFFFAAAAAA55FF55AAAAAAAAAA55FFFFAAAAFFFFFFFF
FFFFFFFFFF55AA5555FFAAAAAAAAFFFFFFAA55FFFFFFFF555555FF00000055AAFF55AA55
00FF00FF5500FFFF555555AA5555005555AA555555FFFF0055FF00FF0055AA55FFAA5500
0000FF555555FFFFFFFF55AAFFFFFFAAAAAAAAFF5555AA55FFFFFFFFFF
FFFFFFFFFFFFAAAA55AA55FFFF55AA5555AAFF005555AA55AAAA5555555555FFFFFFAA55
AA0000FF555555AA55AAAA55FF555555FF55AAAA55AA555555FF0000AA55AAFFFFFF5555
555555AAAA55AA555500FFAA5555AA55FFFF55AA55AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFF55AAAAAA5555AAAAFFFFAA555555FF55AAAAAAAA55AAAA55AA5555AAFF
FF0000FF5555FF55AAAAAAAA5555FF5555AAAAAAAA55FF5555FF0000FFFFAA5555AA55AA
AA55AAAAAAAA55FF555555AAFFFFAAAA5555AAAAAA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAFFAAFF00FFFFFFFF00AAFFFFFFAAAAFFAA55AAFFAAFFAAFFFF00
55555555AAAA5555FFAAAAAAAA55AA55AAAAAAAAFF5555AAAA5555555500FFFFAAFFAAFF
AA55AAFFAAAAFFFFFFAA00FFFFFFFF00FFAAFFAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55AA55FF000000000000FFFFFFFFFF00FF55FF55FF00FF55FF0055
AAAA55AAAAAAAA55AA55FFFF55AAAAAA55FFFF55AA55AAAAAAAA55AAAA5500FF55FF00FF
55FF55FF00FFFFFFFFFF000000000000FF55AA55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA5555555555555555AA55550055AA55AA55AA5500550055AA
AAAAAA55FFFF55AAAAAA5555AAAAAAAAAA5555AAAAAA55FFFF55AAAAAAAA5500550055AA
55AA55AA55005555AA5555555555555555AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AAAA55AAAA55AAAA55FF555555FFFFAA55AAFF000055AAAA
AAAAAAAA5555AAAAFFAA55AAAAAAAAAAAAAA55AAFFAAAA5555AAAAAAAAAAAA550000FFAA
55AAFFFF555555FF55AAAA55AAAA55AAAA55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFF55AAAAAAAA5555FF5555AA55FF55FF0000FFAAAA
FFAAAAFFAAFFFF00FF55AAAAAAAAAAAAAAAAAA55FF00FFFFAAFFAAAAFFAAAAFF0000FF55
FF55AA5555FF5555AAAAAAAA55FFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF55AA5555FFAAAAAAAA55AA55AAAAAA5555FF0000FF55FF
FFFF00FF55AA555555AAAAAAAAAAAAAAAAAAAAAA555555AA55FF00FFFFFF55FF0000FF55
55AAAAAA55AA55AAAAAAAAFF5555AA55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AA55FFFF55AAAAAA55FFFF5555FF0000FF5555
AA555555AAAAAA55AAAAAAAAAAAAAAAAAAAAAAAAAA55AAAAAA555555AA5555FF0000FF55
55FFFF55AAAAAA55FFFF55AA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAAAA5555AAAAFFAAAA5555AAAA55555555AAAA
55FF5555FFFF55AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA55FFFF5555FF55AAAA55555555AA
AA5555AAAAFFAAAA5555AAAAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAAFF00FFFFFF00FFAAFF55AAAA55AAAAFF
5555AAAA5555AAAAAAAAAAFFAAAAFFAAAAFFAAAAAAAAAA5555AAAA5555FFAAAA55AAAA55
FFAAFF00FFFFFF00FFAAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA55FF0000000000FF55AA55AAFFAAFFAA55
55FF55AAFFFFAA55FFAA55FF00FFFFFF00FF55AAFF55AAFFFFAA55FF5555AAFFAAFFAA55
AA55FF0000000000FF55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55555555555555AAAAAA55FF00FF55AA
AA5555FFFFFFFF00AAAAAA555555AA555555AAAAAA00FFFFFFFF5555AAAA55FF00FF55AA
AAAA55555555555555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA55AAAA55AAAAAAAAAA555555AAAA
AAAA55AA55550055AAFFAAAA55AAAAAA55AAAAFFAA55005555AA55AAAAAAAA555555AAAA
AAAAAA55AAAA55AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFF55AAAAAAAAAAAAAA55AAAAAA
AAAAAA55FF555555FFFFFF55AAAAAAAAAA55FFFFFF555555FF55AAAAAAAAAAAA55AAAAAA
AAAAAAAA55FFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5555FFAAAAAAAAFFAA55AAFFAA
AAFFAAAA5555FF5555AA5555FFFF55FFFF5555AA5555FF5555AAAAFFAAAAFFAA55AAFFAA
AAAAAAFF5555AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AA55FFFF55AA55FF55AA55
FFFFFF55FF5555AAAA55FF5555AA55AA5555FF55AAAA5555FF55FFFFFF55AA55FF55AA55
FFFF55AA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAAAA5555AAAAFFFFFFAAAA
5555AA55AA55AAAAAAAA5555FF55FF55FF5555AAAAAAAA55AA55AA5555AAAAFFFFFFAAAA
5555AAAAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAAFF00FFFFFFFFFF00
FFAAFFAAFFAAFF55FFAAAA55AA55AA55AA55AAAAFF55FFAAFFAAFFAAFF00FFFFFFFFFF00
FFAAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA55FF00000000000000
FF55AA55FF00FF5555AAFFAAFFAAFFAAFFAAFFAA5555FF00FF55AA55FF00000000000000
FF55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555555555555555
55AAAAAA555555AAAA55FF00FF55AA55FF00FF55AAAA555555AAAAAA5555555555555555
55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA55AAAA55AAAA
55AAFFAAAA55AAAAAAAA555555AAAAAA555555AAAAAAAA55AAAAFFAA55AAAA55AAAA55AA
AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFF55AAAAAA
AA55FF00FFFFAAAAFFAAAA55AAAAAAAAAA55AAAAFFAAAAFFFF00FF55AAAAAAAA55FFFFAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5555FFAAAA
AAAA555555AA55FFFFFF55AAAAAAAAAAAAAA55FFFFFF55AA555555AAAAAAAAFF5555AA55
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AA55FF
FF55AAAA55AAFF005555AAAAAAAAFFAAAAAAAA555500FFAA55AAAA55FFFF55AA55AAAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAAAA55
55AAAAAAFFFF0055AAAA55FFFF55AA55FFFF55AAAA5500FFFFAAAAAA5555AAAAAA55FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAA
FF00FFFF550055AAAAAAAA5555AAAAAA5555AAAAAAAA550055FFFF00FFAAFFAAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA55
FF0000000055AAAAAAFFAA55AAAAAAAAAA55AAFFAAAAAA5500000000FF55AA55FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
555555555555FFFF00FF55AAAAAAAAAAAAAA55FF00FFFF555555555555AAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
AAAA55AAAA55AA555555AAAAAAAAAAAAAAAAAA555555AA55AAAA55AAAA55FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAAFFFF55AAAAAA55AAAAAAAAFF55FFAAAAAAAA55AAAAAA55FFFFAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55AA5555FFAAAAAA55FFFF55AA55AA55FFFF55AAAAAAFF5555AA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAA55AA55FFFF555500FFAA55AAFF005555FFFF55AA55AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55AAAAAA5555000055AA55FF55AA5500005555AAAAAA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAFFAAFF0000FFAA55AA55AAFF0000FFAAFFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55AA55FF0000FF55AAAAAA55FF0000FF55AA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAA55555555AAAAAAAAAA55555555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55AAAA55AAAAAAAAAAAAAA55AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAAA55FFFF55FFFF55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55AAFF0055FF5500FFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA0055005500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AA00FF00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 2.20873 0.588183 2.29604 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF55AAAA5555AAAA55AAAAAA0000AAAAFF00FF0055555500AA0000FF00FFAAAA55AA55FF
FF55AA000000AAAA5555AAAAAAFFFFFFAAAAAA5555AAAA000000AA55FFFF55AA55AAAAFF
00FF0000AA0055555500FF00FFAAAA0000AAAAAA55AAAA5555AAAA55FF
FFFFAAAAAA55AAFF5555555555AA5500AA00AA00AAFF00AAAAAA00AA00AA0055AAAAFFFF
FFFFAAAA00AAAAFF5555FFFF0000AA0000FFFF5555FFAAAA00AAAAFFFFFFFFAAAA5500AA
00AA00AAAAAA00FFAA00AA00AA0055AA5555555555FFAA55AAAAAAFFFF
FFFFFF55AA00FFFFFFAAFF00AAFF5555AA00AA55555500FF00FF0055AA5500FFAA550055
550055AA00AA5500550000AA00AAAAAA00AA0000550055AA00AA550055550055AAFF0055
AA5500FF00FF00555555AA00AA5555FFAA00FFAAFFFFFF00AA55FFFFFF
FFFFFFFFAAAA0000AA005555AA00005500AAAAAA55AAAA000000AAAA55000000AA55AA55
AAAA00FF0055AAAA00FF5500AAAAFFAAAA0055FF00AAAA5500FF00AAAA55AA55AA000000
55AAAA000000AAAA55AAAAAA00550000AA555500AA0000AAAAFFFFFFFF
FFFFFFFFFF55AA555555AAAA5500FF5555AA0055AAAAAAAA00AAAAFFAA00AAAA005500AA
FFAAAA00000055AA00AA00FF55FFFFFF55FF00AA00AA55000000AAAAFFAA005500AAAA00
AAFFAAAA00AAAAAAAA5500AA5555FF0055AAAA555555AA55FFFFFFFFFF
FFFFFFFFFFFFAAAA55AAAAAAAA5555000055AA55AA0055AA00AA550055AA5500AAAA5555
5500AA5555AA55AA00AA55550000AA00005555AA00AA55AA5555AA00555555AAAA0055AA
550055AA00AA5500AA55AA5500005555AAAAAAAA55AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFF55AAAAAAAAAAAA55AA5555FFAAFF550000FF55AAAA00FF00AAAAAAFFFF
AA00AA55AAAAAA5500FFFFAA00AAAAAA00AAFFFF0055AAAAAA55AA00AAFFFFAAAAAA00FF
00AAAA55FF000055FFAAFF5555AA55AAAAAAAAAAAA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAAAFFAAAAAA55000055555500000000AAFFAA555500FFFF0000AA
0055FFFFAAAAAAFF00555500AAAAFFAAAA00555500FFAAAAAAFFFF5500AA0000FFFF0055
55AAFFAA00000000555555000055AAAAAAFFAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55AA0000FFFF5555AA55AAAA5555AA55555500AAFF00555500FF55
FF00AA0000FF0000AAAA55AA55FFFFFF55AA55AAAA0000FF0000AA00FF55FF00555500FF
AA00555555AA5555AAAA55AA5555FFFF0000AA55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA00AA00005500AAFFAA55AAAAAA55AAAA005555AAAA555500
00AAAAAA00AA00AAAAAAAA550000AA000055AAAAAAAA00AA00AAAAAA00005555AAAA5555
00AAAA55AAAAAA55AAFFAA00550000AA00AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AA5500FF5555AA0000FFAAAAAAFFFF55AA55AAAAAAAA55AA
5555555555AA00AA5500AA55AA555555AA55AA0055AA00AA5555555555AA55AAAAAAAA55
AA55FFFFAAAAAAFF0000AA5555FF0055AA55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA5555000055AA555500AA55005555FFFFAAAAAAAAFF00
005500005500AAAAFF0055AAAAAA55AAAAAA5500FFAAAA00550000550000FFAAAAAAAAFF
FF55550055AA005555AA5500005555AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA5555AAAAAA55AA55000000550055555555555500
FF5555AA55AA5500AA00AAFF55FFAAFF55FFAA00AA0055AA55AA5555FF00555555555555
005500000055AA55AAAAAA5555AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55AAFF55AAAAAA5555AA55AA55AAAA55AAAA55
55000055AAAAAA555555AA00005555550000AA555555AAAAAA5500005555AAAA55AAAA55
AA55AA5555AAAAAA55FFAA55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00FFFFFFAAAAAAFFFFAA55AA00FF00FFAAAAAA
55AA5555FFFF55AAAA55AA00AAAA55AAAA00AA55AAAA55FFFF5555AA55AAAAAAFF00FF00
AA55AAFFFFAAAAAAFFFFFF00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000AA0055AA0000AA55AA00AA00AA0055AA
00FFFFAA0000AAFFAA55AA00AA55FF55AA00AA55AAFFAA0000AAFFFF00AA5500AA00AA00
AA55AA0000AA5500AA0000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA555555AAAAAA00AA55AA00AA555555AAAA
AA0000AA5555AA0000FFAAAA0055005500AAAAFF0000AA5555AA0000AAAAAA555555AA00
AA55AA00AAAAAA555555AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAAAAAAAAA005500AAAAAA55AAAAAA
AAAA00AA55AAAAAA00AA0055AA55AA55AA5500AA00AAAAAA55AA00AAAAAAAAAA55AAAAAA
005500AAAAAAAAAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAAAAAAAAAAAA00FF55FFFF00AA5500
AA5500FFFFAAAAAAAA0055FF55AAAAAA55FF5500AAAAAAAAFFFF0055AA0055AA00FFFF55
FF00AAAAAAAAAAAAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAAAAAAAA0000555500FF00AA
AAAA55550055AAFF55FF00AA00FF00FF00AA00FF55FFAA55005555AAAAAA00FF00555500
00AAAAAAAAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA0000FFFF55FF0055000000AAAA
AAAAAA55AA55AA00005555AA00AA00AA00AA55550000AA55AA55AAAAAAAAAA0000005500
FF55FFFF0000AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA00005555AAAA00AAAAAA
AAAAAAFF00FFAAAA00AAFFFF0055AA5500FFFFAA00AAAAFF00FFAAAAAAAAAAAA00AAAA55
550000AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5500FF5555FFAAAA0055AA
0055AA000000AA55FF0000AA00AAFFAA00AA0000FF55AA000000AA5500AA5500AAAAFF55
55FF0055AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555000055555555AAAA
AA00FF0055FF00005555AA5500FFFFFF0055AA55550000FF5500FF00AAAAAA5555555500
005555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA5555AAAA55AAAAFF
AAAA0000005555AA55AAAAAA5555005555AAAAAA55AA5555000000AAAAFFAAAA55AAAA55
55AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55AAFF55555555
00AA5555AA55AAAAAA55FFAAAA55AA55AAAAFF55AAAAAA55AA5555AA0055555555FFAA55
AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00FFFFFFAAFF00
AAAAAA55AA00FF00FF00AA0055AAAAAA5500AA00FF00FF00AA55AAAAAA00FFAAFFFFFF00
AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000AA005555
AA0055AAAAAA000000AAAAAA00FF00FF00AAAAAA000000AAAAAA5500AA555500AA0000AA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA555555AAAA
5500FFAAAAAAAA00AAAAAAAAAA000000AAAAAAAAAA00AAAAAAAAFF0055AAAA555555AA55
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAAAAA
AA555500AA5500AAAAAAAAAAAAAA00AAAAAAAAAAAAAA0055AA005555AAAAAAAA55AAAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAAAAAA
AAAA55AA55000000FFFF00FFFF000000FFFF00FFFF00000055AA55AAAAAAAAAAAA55FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF
AAAAAA550000000000AA00AA0000000000AA00AA000000000055AAAAAAFFAAAAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00
00FFFF5555AA5555AA55FF00000000000000FF55AA5555AA5555FFFF0000AA55FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
00AA00005500AAFFFF00AA00AAAA00AAAA00AA00FFFFAA00550000AA00AAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
AA5500FF5555AA0000AAAAAA0055AA5500AAAAAA0000AA5555FF0055AA55FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAA5555000055AA5555555555AAAAAA5555555555AA5500005555AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55AAAA5555AAAAAA55AAAA55AAFFAA55AAAA55AAAAAA5555AAAA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAAA55AAFF55AAAAAAAA550055AAAAAAAA55FFAA55AAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55AA00FFFFFFAA55FFAA55AA55AAFF55AAFFFFFF00AA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAA0000AA00550055AAAAAA55005500AA0000AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55AA555555AAAA00FF00FF00AAAA555555AA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAA55AAAAAAAA000000AAAAAAAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55AAAAAAAAAAAA00AAAAAAAAAAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAAAFF55AA00AA55FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55AA000055AA550000AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA00AAFFAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AA550055AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 2.20873 0.782187 2.29604 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF555555FFAA00FF00AA55000055555500AAAA00555500AAAAAAFF00FF000000AA00AAAA
AA0055FFFFFF000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFF5500AAAAAA00AA000000
FF00FFAAAAAA00555500AAAA00555555000055AA00FF00AAFF555555FF
FFFFAAFFFFFF0000AAFFAAFF0000000000FFFF00000000FFFF00FF555500AA55AAFF00FF
FF000000AA0000FF0000AA00AA00AA00AA00AA0000FF0000AA000000FFFF00FFAA55AA00
5555FF00FFFF00000000FFFF0000000000FFAAFFAA0000FFFFFFAAFFFF
FFFFFF5500FF5555FFFFFF0055AA00FF0000AA00FF00AA5555AA00000000FFFFAAAA0055
550000FF00FF00AAAA55AAFF00FF00FF00FFAA55AAAA00FF00FF0000555500AAAAFFFF00
000000AA5555AA00FF00AA0000FF00AA5500FFFFFF5555FF0055FFFFFF
FFFFFFFFAA00000000AA00AAFFFF555500AAFFAA0000FFFFAAFF555555555500FFFF0000
0000FF005500FF00FFFFAAAA0055555500AAAAFFFF00FF005500FF00000000FFFF005555
555555FFAAFFFF0000AAFFAA005555FFFFAA00AA00000000AAFFFFFFFF
FFFFFFFFFF555555FF55AAAAAA00000000FFFFFF55555500FFFFFFAAFFFFAAFF00555555
55555500000055555500FFFF0000000000FFFF0055555500000055555555555500FFAAFF
FFAAFFFFFF00555555FFFFFF00000000AAAAAA55FF555555FFFFFFFFFF
FFFFFFFFFFFFAAFFFFFFAAAAFFAA00FF0000AA0000000000555500FFFFFFFF5500000000
00000000FF0000000000FF55000055000055FF0000000000FF000000000000000055FFFF
FFFF0055550000000000AA0000FF00AAFFAAAAFFFFFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFF5500FF55FFFFFF555500AAFFAA00FF00AAFFFFAA0000AA000000FF0000
FF00AA5500FF0000FFAA000000FFAAFF000000AAFF0000FF0055AA00FF0000FF000000AA
0000AAFFFFAA00FF00AAFFAA005555FFFFFF55FF0055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA000000AA00000000FFFFFF00AA00FFFFFFFF00AAFFAA005500FF00
00AAFFAAFF005500AAAAFF0000FF55FF0000FFAAAA005500FFAAFFAA0000FF005500AAFF
AA00FFFFFFFF00AA00FFFFFF00000000AA000000AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555555FFAA00FF00AA0000AAFFAA0000AAAA00FFFFFF0000005555
55FFFFFF55000000FFFF0055AA000000AA5500FFFF00000055FFFFFF555555000000FFFF
FF00AAAA0000AAFFAA0000AA00FF00AAFF555555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFFFF0000AAFFAA00FFFFFF5555FFFF0000AA000055000000
0000AA00000055AAAA00AAFFFF555555FFFFAA00AAAA55000000AA0000000000550000AA
0000FFFF5555FFFFFF00AAFFAA0000FFFFFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5500FF5555FFFFFF0000AA00000000AAAA55AAFF0000005500
AA55AAFF00AAFFFF55AAAAAA0000000000AAAAAA55FFFFAA00FFAA55AA0055000000FFAA
55AAAA00000000AA0000FFFFFF5555FF0055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00000000AA00AAFF00FF0000FF00FFFFAAAA00FF000000
FFFFAAAA00FFFFFFFFAAAAFFAA005500AAFFAAAAFFFFFFFF00AAAAFFFF000000FF00AAAA
FFFF00FF0000FF00FFAA00AA00000000AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FF55AAAAAA00FF5555550000AAAAFFAA0000FF00
00AAAAAAAA555500FF55FFFFFF000000FFFFFF55FF005555AAAAAAAA0000FF0000AAFFAA
AA0000555555FF00AAAAAA55FF555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAAAAFFAA0000000000FF00FFFFFF55555500
AAFFAAAAAAFFFFAA000000AA0000550000AA000000AAFFFFAAAAAAFFAA00555555FFFFFF
00FF0000000000AAFFAAAAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FF55FFFFFF5555555555550000AA0000000000
FFFFFF55FFFFFFFF00AA55AAFF000000FFAA55AA00FFFFFFFF55FFFFFF0000000000AA00
00555555555555FFFFFF55FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000AA0000000000000000FF00FF0000FF00
00AA000000AA00AA00FFFFAAAA005500AAAAFFFF00AA00AA000000AA0000FF0000FF00FF
0000000000000000AA000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFAA00FF00AA55000055555500AA5555
55FFAA00FFAA55AAFF0055FFFF000000FFFF5500FFAA55AAFF00AAFF555555AA00555555
000055AA00FF00AAFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF0000AAFFAAFF0000000000FFFFAA
FFFFFF00AAAAFFFF55000000AA005500AA00000055FFFFAAAA00FFFFFFAAFFFF00000000
00FFAAFFAA0000FFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FF5555FFFFFF0055AA00FF0000AAAA
AA0000AA55FFFFFFFFAA00FF00FFAAFF00FF00AAFFFFFFFF55AA0000AAAAAA0000FF00AA
5500FFFFFF5555FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00000000AA00AAFFFF555500AAFFAA
AAAA55AAFFFFFFFFFFFF00AA00FF55FF00AA00FFFFFFFFFFFFAA55AAAAAAFFAA005555FF
FFAA00AA00000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FF55AAAAAA00000000FFFFFF
55FFFFAAAA00AAAA0000AAFFAA000000AAFFAA0000AAAA00AAAAFFFF55FFFFFF00000000
AAAAAA55FF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAAAAFFAA00FF0000AA00
0000AAAAAAAA55FFAA00FFFFFF555555FFFFFF00AAFF55AAAAAAAA000000AA0000FF00AA
FFAAAAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FF55FFFFFF555500AAFFAA
00FFAAAAAAAAFFFFFF00AAAA0000000000AAAA00FFFFFFAAAAAAAAFF00AAFFAA005555FF
FFFF55FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000AA00000000FFFFFF
00AAAAAAAAAAAA0000AA55FFAA00FF00AAFF55AA0000AAAAAAAAAAAA00FFFFFF00000000
AA000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFAA00FF00AA0000
AAFFAAAAAAAAAAAA55AAFFFFFF00AA00FFFFFFAA55AAAAAAAAAAAAFFAA0000AA00FF00AA
FF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF0000AAFFAA00
FFFFFF00FFFF00FFFFAAAA0000AAFFAA0000AAAAFFFF00FFFF00FFFFFF00AAFFAA0000FF
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FF5555FFFFFF00
00AA000055550000AAAAFFAA00FFFFFF00AAFFAAAA000055550000AA0000FFFFFF5555FF
0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00000000AA00AA
FF00FF00000000FF00FFFFFF0000AA0000FFFFFF00FF00000000FF00FFAA00AA00000000
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FF55AAAA
AA00FF555555555500AAAA0000FF00FF0000AAAA005555555555FF00AAAAAA55FF555555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAAAA
FFAA00000000000000FFFF00005555550000FFFF00000000000000AAFFAAAAFFFFFFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500FF55FF
FFFF555555555555555500FF0000000000FF005555555555555555FFFFFF55FF0055FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000
AA000000000000000000005555555555555500000000000000000000AA000000AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555
FFAA00FF00AA550000FF000000000000000000FF000055AA00FF00AAFF555555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
FFFF0000AAFFAAFF00AA00FF0000550000FF00AA00FFAAFFAA0000FFFFFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
00FF5555FFFFFF0055AAFF00550000005500FFAA5500FFFFFF5555FF0055FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA00000000AA00AAFFFF55000000FF00000055FFFFAA00AA00000000AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF555555FF55AAAAAA000000FF00AA00FF000000AAAAAA55FF555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFFFFAAAAFFAA005500FF00FF005500AAFFAAAAFFFFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5500FF55FFFFFF000000555555000000FFFFFF55FF0055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA000000AA0000FF0000000000FF0000AA000000AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF555555FFAA005555555555555500AAFF555555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFFFFF000000000000000000FFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5500FF555555555555555555FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA0000000000000000000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555555FF555555FF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFFFFAAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5500FF55FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 2.20873 0.97619 2.29604 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF55555555000055AA55FFFFFFAA55FFFFFFFF55AAFF5555FFFFFF5555AAFFFF0055FF55
5555AAAA55555555FFAAFFFF5500FF0055FFFFAAFF55555555AAAA555555FF5500FFFFAA
5555FFFFFF5555FFAA55FFFFFFFF55AAFFFFFF55AA55000055555555FF
FFFFAAFFFF0055FFAAAAAA55AAAAFFFFFFFFFFFFAAAA55FFAA00FFAAFFFF5555FF00FFAA
FFFFAAAAFFFFAAFF555555FF55AA55AA55FF555555FFAAFFFFAAAAFFFFAAFF00FF5555FF
FFAAFF00AAFF55AAAAFFFFFFFFFFFFAAAA55AAAAAAFF5500FFFFAAFFFF
FFFFFF5555FF00FFAAAAFFAAFFAAAA55AAAA55AAAAFFAA55AA00AAFFAA0000550055FF55
FF55555555FF55FF55AAFFFFFFAAAAAAFFFFFFAA55FF55FF55555555FF55FF5500550000
AAFFAA00AA55AAFFAAAA55AAAA55AAAAFFAAFFAAAAFF00FF5555FFFFFF
FFFFFFFFAAFF0055555555FFFFFF55FFAAAAFFFF55FF55FFAAAA00555555AA55FF00FFAA
55AAFFFFAA55AAFF00FF00AA0000FF0000AA00FF00FFAA55AAFFFFAA55AAFF00FF55AA55
555500AAAAFF55FF55FFFFAAAAFF55FFFFFF5555555500FFAAFFFFFFFF
FFFFFFFFFF5555AAFFFF00FFAA000055555555FF55AAAAAA5500AAAAAAAAAAFF5555AAAA
FFFF5555FFFF0000AAAA555555AA55AA555555AAAA0000FFFF5555FFFFAAAA5555FFAAAA
AAAAAA0055AAAAAA55FF555555550000AAFF00FFFFAA5555FFFFFFFFFF
FFFFFFFFFFFFAAFFAA00FF555555AA55FFAAFFFFFFAAAAFFAA55555555555555FFAA5500
AA00FFFF00AA00AAAAFFAAFFFFAAAAAAFFFFAAFFAAAA00AA00FFFF00AA0055AAFF555555
55555555AAFFAAAAFFFFFFAAFF55AA555555FF00AAFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFF555555AAAAAAAAAAFF555555FF55555555FFFF00FFFFAAFF55AAAAFF55
00AAAA55AA5500FF0000AA55AAAAFFAAAA55AA0000FF0055AA55AAAA0055FFAAAA55FFAA
FFFF00FFFF55555555FF555555FFAAAAAAAAAA555555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF55FFFF55FF55AAFFFFFFAAFFFFAA00FF5555FFFFFFAAAAFF00
FF55FFFFAAAAAA00000000FFFF55FF55FFFF00000000AAAAAAFFFF55FF00FFAAAAFFFFFF
5555FF00AAFFFFAAFFFFFFAA55FF55FFFF55FFFFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555FFAA00FFFFFFAAAA55AAAAFF00AA5555FFAA55AAAA5500AA00
AAFF5555FFFF55FF0055FF00AAFFFFFFAA00FF5500FF55FFFF5555FFAA00AA0055AAAA55
AAFF5555AA00FFAAAA55AAAAFFFFFF00AAFF5555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF000000AA0000FF00FF0000AAAAFFFFAA005500AA55FF0000
00FFAAFF55550000AAAAAA55555500555555AAAAAA00005555FFAAFF000000FF55AA0055
00AAFFFFAAAA0000FF00FF0000AA000000FFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5555AA555555AA55AA55AA555555550055AA55FF00005555AA
5555FFFFFFAA5555AA0055AAFF55AA55FFAA5500AA5555AAFFFFFF5555AA55550000FF55
AA550055555555AA55AA55AA555555AA5555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFFAAFFFFAAAAAAFFFF55AAFF55AA55FFFFAA00AAAAAAAA
FFFF00AA00FF00FFFF550000FFAAFFAAFF000055FFFF00FF00AA00FFFFAAAAAAAA00AAFF
FF55AA55FFAA55FFFFAAAAAAFFFFAAFFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FF55FFFF55550000FFAAFFAAFF00AA5555555555
55FF5500AAAA5555FF55AA5555FFFFFF5555AA55FF5555AAAA0055FF555555555555AA00
FFAAFFAAFF00005555FFFF55FF555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF00AAFF55AA555500AAFFAA00AA55FFAAFF55
AAFF00FF55FFFF00FFAAFFAAFFFFFFFFFFAAFFAAFF00FFFF55FF00FFAA55FFAAFF55AA00
AAFFAA005555AA55FFAA00FFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF5500AAFF55FFAA55555500AAAAFF555555FF
AAAA5555FFAA000000AA55AA0000AA0000AA55AA000000AAFF5555AAAAFF555555FFAAAA
00555555AAFF55FFAA0055FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FF55FF55AAAAFFFF00FF55FFFFFFAA55FF
55FFFFAAFF0000000000FFFF5500FF0055FFFF0000000000FFAAFFFF55FF55AAFFFFFF55
FF00FFFFAAAA55FF55FF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAAAAA55FFFF555500FFAAFF00AAFFAA55
AAFF00AA55AA5555AA5555FF55AA55AA55FF5555AA5555AA55AA00FFAA55AAFFAA00FFAA
FF005555FFFF55AAAAAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAAAFF5555000055FF55FF5500AA0055
00AA00AA55FFFF00FF00FFFFFFAAAAAAFFFFFF00FF00FFFF55AA00AA005500AA0055FF55
FF5500005555FFAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555000055FF00FFAAFF00FF55FF00
FF55FF00005555FF00AAAA55AAAAFFAAAA55AAAA00FF55550000FF55FF00FF55FF00FFAA
FF00FF55000055555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF0055FFAA00AAFFAA00AAFF5555
AAAAAA5555AAFF5555AA005500AA55AA005500AA5555FFAA5555AAAAAA5555FFAA00AAFF
AA00AAFF5500FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF00FFAAAA00555555AA00FFFF
AAAAFFAA55FFFFFF00FF005500FF00FF005500FF00FFFFFF55AAFFAAAAFFFF00AA555555
00AAAAFF00FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0055555555AAFFFF000000AA
FFAAAA550000AA000000AAAAAA000000AAAAAA000000AA000055AAAAFFAA000000FFFFAA
5555555500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAFFFFAA55005555AA5555
55FFFF55AA555555AA5555555555AA5555555555AA555555AA55FFFF555555AA55550055
AAFFFFAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA00FF00FF55AAFFAAFF
55AAAA55FFFF00FFFF55AAFFFFAAFFAAFFFFAA55FFFF00FFFF55AAAA55FFAAFFAA55FF00
FF00AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555AAAA00FFFF555555
0000FF00FFAA00AA00FFFF5555FFFFFF5555FFFF00AA00AAFF00FF0000555555FFFF00AA
AA555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55FF00AAFFFFAA
5555AAAA00FF0055AA55AAAAAAAA55AAAAAAAA55AA5500FF00AAAA5555AAFFFFAA00FF55
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFAA00AA55AAAA
FFFF0000FF5555AAFFAAFFAAAAFFAAFFAAAAFFAAFFAA5555FF0000FFFFAAAA55AA00AAFF
5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF000000FFFF55
FF5555AA55AAFFFF555555FFFF555555FFFF555555FFFFAA55AA5555FF55FFFF000000FF
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA5555FF55
AAAAAAAAFFFF5555FFAAFFFFFFFFAAFFFFFFFFAAFF5555FFFFAAAAAAAA55FF5555AA5555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAFFFFFF
AAAAFFAAAA55AAFFFFFF5555FF555555FF5555FFFFFFAA55AAAAFFAAAAFFFFFFAAFFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FF55
555555FFFF55AA0000AAFF55AAAAAAAAAA55FFAA0000AA55FFFF55555555FF555555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF
00FFFFAA000055AA555555FFAAAAFFAAAAFF555555AA550000AAFFFF00FFFFFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF
5500555555AA55FFFFAAFFFFFF55FF55FFFFFFAAFFFF55AA5555550055FF5555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
00FF55AAFF55FFAA00FF00AA00FFFFFF00AA00FF00AAFF55FFAA55FF00FFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
55AAAAAAFF00FFAAAA00FF55FF00AA00FF55FF00AAAAFF00FFAAAAAA5555FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAFFAAAAFF0055555555AAAAAA555555AAAAAA5555555500FFAAAAFFAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5555555500FFFFAAFFFF55FFFFAAFFFF55FFFFAAFFFF0055555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFF005555FFFFFFFFAA00FF00AAFFFFFFFF555500FFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5555FF00FFFFFFFFFFFF550055FFFFFFFFFFFF00FF5555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAFF005555FF5555FF55AA55FF5555FF555500FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF5555AAFFFFFFAA55AAFFAA55AAFFFFFFAA5555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFAA0000AA55FFFFFF55AA0000AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF555555AA550000AA000055AA555555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF55AA555555AA55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555FFAAAAAAAAAAFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF0000FF0000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5555AA55AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFFAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 2.30477 0.200176 2.39208 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF555555AAAA00FFAAAAFFAAAAFFFFAAFFFF55AAAA55AA00FFFFAAAA55AA5500AA555555
555555AA5555555500AAAAFFAAAA00AAAAFFAAAA0055555555AA555555555555AA0055AA
55AAAAFFFF00AA55AAAA55FFFFAAFFFFAAAAFFAAAAFF00AAAA555555FF
FFFFAAFFFF5555AAFFAAAAAAFFAA55FFFFFFFFAA00FF00AAAAAAAA55AA00FF0055555555
5555555500000055AA55AAAAAA55AA55AAAAAA55AA55000000555555555555555500FF00
AA55AAAAAAAA00FF00AAFFFFFFFF55AAFFAAAAAAFFAA5555FFFFAAFFFF
FFFFFF55AAFFFFAAAAAAFFAAAAAAFFFFFFFFFF00AAAAAA0000AA000000AAAAAA00550000
00000055AA5555AA0000FFAAAA550055AAAAFF0000AA5555AA5500000000005500AAAAAA
000000AA0000AAAAAA00FFFFFFFFFFAAAAAAFFAAAAAAFFFFAA55FFFFFF
FFFFFFFFAAAAAAAA55AAAAAA55AAAAAAAAAAAAAA0000AA00AAAA5555AA55AAAA555555AA
5555AA55005500AA00AAAAAA55AA00AA55AAAAAA00AA00550055AA5555AA555555AAAA55
AA5555AAAA00AA0000AAAAAAAAAAAAAA55AAAAAA55AAAAAAAAFFFFFFFF
FFFFFFFFFF5555FFFFAA0000AA55AAAA55AAAA55AA5555FF00AA00550055005555555555
0000555555AA00AA00AA0000AA55AA55AA0000AA00AA00AA555555000055555555550055
005500AA00FF5555AA55AAAA55AAAA55AA0000AAFFFF5555FFFFFFFFFF
FFFFFFFFFFFFAAFF55AAAA00AA00555500AAFFAAFFAAFFFF005555AA00AA555555555555
55AA5500AA55AA55AA55AA555500AA005555AA55AA55AA55AA0055AA55555555555555AA
00AA555500FFFFAAFFAAFFAA00555500AA00AAAA55FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFF55AA0000AAAA55555555AAAAAA55FFFFFF00550000AAAA5500AA550000
FF00AA55550000AA55AA000055AA55AA550000AA55AA00005555AA00FF000055AA0055AA
AA00005500FFFFFF55AAAAAA55555555AAAA0000AA55FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA00AA0000550000FFAAAAFFFFFFFF0055AA55550055AA55AA00AA
AAAA000055AA55550000AAAA0055555500AAAA00005555AA550000AAAAAA00AA55AA5500
5555AA5500FFFFFFFFAAAAFF0000550000AA00AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555AAAA00AA5555AAFFAAAAAAAAAAAA0055555555AA00005555AA
AA55AA55555500AA5555AAAA5555555555AAAA5555AA00555555AA55AAAA55550000AA55
55555500AAAAAAAAAAAAFFAA5555AA00AAAA5555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFAAAA000055AAAAAA55AAAA55AAAA005500005555AA5500AA
000000AA5500AAAAFFFFAAAAFFFFAAFFFFAAAAFFFFAAAA0055AA000000AA0055AA555500
005500AAAA55AAAA55AAAAAA550000AAAAFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AAAA5555AA0000AA00555500AAFF0055AA5555555500AAAA
5555AA55AA00AAFFAA55FFFF55AAFFAA55FFFF55AAFFAA00AA55AA5555AAAA0055555555
AA5500FFAA00555500AA0000AA5555AAAA55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA5500AA00AAAA55555555AAAAAA00555555555555AAAA
5500AA005555AAAAAAFFFFFFFFAAAAAAFFFFFFFFAAAAAA555500AA0055AAAA5555555555
5500AAAAAA55555555AAAA00AA0055AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555AAAA00FFAAFFFFAAFFAAAA555555555555555500
55AA55AA5500AAFFAAAAAAAAAAAAFFAAAAAAAAAAAAFFAA0055AA55AA5500555555555555
5555AAAAFFAAFFFFAAFF00AAAA555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF5555AAFFAA55FFFFFF55555555555555555555
AA0000555555AAAAAA55AAAA55AAAAAA55AAAA55AAAAAA5555550000AA55555555555555
555555FFFFFF55AAFFAA5555FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFFAAAAAAFFFFFFFF00000000000000005500
00AAAA005500AAFFAA0055550000AA0000555500AAFFAA005500AAAA0000550000000000
000000FFFFFFFFAAAAAAFFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA55AAAAAAAAAAAA00AAAA00AAAA00AA55
55AAAA555555AAAAAA55555555AA55AA55555555AAAAAA555555AAAA5555AA00AAAA00AA
AA00AAAAAAAAAAAA55AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFFFAA0000AA0000AAAA55AA55AAAA0000
00FFAA005500AAFFAA00550000FFAAFF00005500AAFFAA005500AAFF000000AAAA55AA55
AAAA0000AA0000AAFFFF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55AAAA00AA00AAAAFF0000AA55AAAA00
AAAAAA555555AAAAAA555555AA55FF55AA555555AAAAAA555555AAAAAA00AAAA55AA0000
FFAAAA00AA00AAAA55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA0000AAAA5555FF55AA55550000AA00
AAFFAA005500AAFFAA005500AAFFFFFFAA005500AAFFAA005500AAFFAA00AA00005555AA
55FF5555AAAA0000AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA000000FFFFAA005500FF5555
AAAAAA555555AAAAAA555555AAAAAAAAAA555555AAAAAA555555AAAAAA5555FF005500AA
FFFF000000AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAAA00AAAAAAAA555555AAFFFF
AAAAFF000055AAAA55AA0055AAAA55AAAA5500AA55AAAA550000FFAAAAFFFFAA555555AA
AAAAAA00AAAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAAA0000AAFFAAFFFFAAAAAA
AAFFAA5555AA0000AA55AA55005555550055AA55AA0000AA5555AAFFAAAAAAAAFFFFAAFF
AA0000AAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA5555AAAAAA55FFAAAA55
AAAAAA550000AAAA000000AA5555555555AA000000AAAA000055AAAAAA55AAAAFF55AAAA
AA5555AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500AA0000AA55FF5555
5500555555AA55AAAA00AAAAFFFFAAFFFFAAAA00AAAA55AA55555500555555FF55AA0000
AA0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555AAAA00AAFFFF0000
55AA5500AA55AA0000AAAAFFAA55FF55AAFFAAAA0000AA55AA0055AA550000FFFFAA00AA
AA555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF5555AAAAAAAA00
AA55AA00AA005555AA55AAAAAAFFFFFFAAAAAA55AA555500AA00AA55AA00AAAAAAAA5555
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFFAAAAFFAAAA
000000AAAA5555555500AAFFAAAAAAAAAAFFAA0055555555AAAA000000AAAAFFAAAAFFFF
AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA55AAFFAA
AA00AAAAFF00005500AAAA55FF55FF55FF55AAAA00550000FFAAAA00AAAAFFAA55AAAAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFFFAAAAAA
55AA55AAAAAA00AA55550055AAFFFFFFAA55005555AA00AAAAAA55AA55AAAAAAFFFF5555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55AAAA55
AA000000AAFF0055555555AA00FFFFFF00AA5555555500FFAA000000AA55AAAA55FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA0000AA
55AA5555AAAAAA0055000000AAAAAAAAAA0000005500AAAAAA5555AA55AA0000AA55FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA
0055555555005555AA00AAAA0000AA0000AAAA00AA5555005555555500AA00AAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AA
AA005500AA5555555500FFAAAA00AA00AAAAFF0055555555AA005500AAAA5555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
AA00AA555500AA5500AAAAAA55AA55AA55AAAAAA0055AA005555AA00AAFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
AAAA000055AA55AA00AAFFAA0055555500AAFFAA00AA55AA550000AAAA55FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAA5555AA00005555AAAAAA5555555555AAAAAA55550000AA5555AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55555555FF00550000AA00000000000000AA00005500FF55555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFFAA555555AA55AA5555AA5555AA55AA555555AAFFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55AAFF0000550055005500AA0055005500550000FFAA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAAA00AA555555AA00AA00AA555555AA00AAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF5555FF00AA5500AA00AA00AA0055AA00FF5555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFF550055AA55AA55AA55AA550055FFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55AA00AA55AA00FF00AA55AA00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA000000AAAAAA000000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555AA5555FF5555AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFAAFFFFFFAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AAAAAAAAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 2.30477 0.39418 2.39208 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF55555555000055AA550000550055AA0000AAFF55FF55AA55FF55AAAAFFFFFFFFAA55AA
AAAA555555AAAA00AAAAAA00FF000000FF00AAAAAA00AAAA555555AAAAAA55AAFFFFFFFF
AAAA55FF55AA55FF55FFAA0000AA550055000055AA55000055555555FF
FFFFAAFF00AAAA00FF00AAAA00FF5555000055AAFFFFFFAAAA55FF55FFFFFFFFFF000000
FF0000000000AA55555500AAAAAA00AAAAAA00555555AA0000000000FF000000FFFFFFFF
FF55FF55AAAAFFFFFFAA5500005555FF00AAAA00FF00AAAA00FFAAFFFF
FFFFFF55AA5500AAAAAA0000AAAAAA55AA5555FFFFFFFFFF55FF55AAAAAAAAAAAAAA00AA
AAAA00AAAA00AA00FFAA00AA0055AA5500AA00AAFF00AA00AAAA00AAAAAA00AAAAAAAAAA
AAAA55FF55FFFFFFFFFF5555AA55AAAAAA0000AAAAAA0055AA55FFFFFF
FFFFFFFFAAAA555555005500FF0000AAFFAAFFFFFFFFFFFFFFAA55AA00555500AA550000
AA000055550000FF55AA00AA00AAFFAA00AA00AA55FF000055550000AA000055AA005555
00AA55AAFFFFFFFFFFFFFFAAFFAA0000FF005500555555AAAAFFFFFFFF
FFFFFFFFFF55FF5555FF00AAAAAA00AA55FFFFFFFFFFFFFFFFFF55550000000055AAAA00
AA5555AAAA5555AAFFFF550055FFFFFF550055FFFFAA5555AAAA5555AA00AAAA55000000
005555FFFFFFFFFFFFFFFFFF55AA00AAAAAA00FF5555FF55FFFFFFFFFF
FFFFFFFFFFFFAA55AAAAAA0000AA00AA00FFFFFFFFFFFFFFFFFFFFAA00AAAA00AAFFAAAA
00000000AA55AAAAFF55AAAA00FFFFFF00AAAA55FFAAAA55AA00000000AAAAFFAA00AAAA
00AAFFFFFFFFFFFFFFFFFFFF00AA00AA0000AAAAAA55AAFFFFFFFFFFFF
FFFFFFFFFFFFFF55555555000055AA5500FFFFFFFFFFFFFFFFFFFFFF5500AA00AA55FFFF
5500005500AAFFAAAAAA5500AAAAAAAAAA0055AAAAAAFFAA0055000055FFFF55AA00AA00
55FFFFFFFFFFFFFFFFFFFFFF0055AA55000055555555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF00AAAA00FF00AAAAAAAAAAAAAAAAAAAAAAAAAA555555AA00FFFF
00AAAA00FF55FFAAAAFFAA00AA550055AA00AAFFAAAAFF55FF00AAAA00FFFF00AA555555
AAAAAAAAAAAAAAAAAAAAAAAAAA00FF00AAAA00FFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55AA5500AAAAAA0000AA5500555500AA0055AA0000000000AAAAAA
AA0000AAAAAA55FFFF55AA00AA55AA55AA00AA55FFFF55AAAAAA0000AAAAAAAA00000000
00AA5500AA0055550055AA0000AAAAAA0055AA55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA555555005500FF00AAAA55AA55000000AAAA00AAAA0000AA
0055FF0000AA00FFFF00AA00AA00FF00AA00AA00FFFF00AA0000FF5500AA0000AAAA00AA
AA00000055AA55AAAA00FF005500555555AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55FF5555FF00AAAAAA0000FFAAAA5555AA55005500AA5555AA
00AAFF550000AAAAAAAA005500AAAAAA005500AAAAAAAA000055FFAA00AA5555AA005500
55AA5555AAAAFF0000AAAAAA00FF5555FF55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55AAAAAA0000AA00AAAAAAFFAAFFFF5555AAAA00000000
AAAAFF5555AA5500555500000055555500000055550055AA5555FFAAAA00000000AAAA55
55FFFFAAFFAAAAAA00AA0000AAAAAA55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF55555555000055AA5500AA55FFFFFFFFAAFFAAAA00AAAA
0000FFFFAAFFAA00AAFF005500000000005500FFAA00AAFFAAFFFF0000AAAA00AAAAFFAA
FFFFFFFF55AA0055AA55000055555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00AAAA00FF00AAAAFFFFFFFFFFFF55AA0055FFFF
5500FFFFFF55AA00AA55FF00AAAA00AAAA00FF55AA00AA55FFFFFF0055FFFF5500AA55FF
FFFFFFFFFFAAAA00FF00AAAA00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5500AAAAAA0000FFFFFFFFFFFFFFAAAA00FFFF
00AAAAAAAAAA550000AAFF5500AA00AA0055FFAA000055AAAAAAAAAA00FFFF00AAAAFFFF
FFFFFFFFFF0000AAAAAA0055AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA555555005500FFFFFFFFFFFFFF0000AAAAAA
AA0055AA0055AAAA00AA55FF5500550055FF55AA00AAAA5500AA5500AAAAAAAA0000FFFF
FFFFFFFFFF005500555555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF5555FF00AAAAAAAAAAAAAAAAAA00AA0055
55000000FF55550055FFFFAA55AA55AA55AAFFFF55005555FF000000555500AA00AAAAAA
AAAAAAAAAAAA00FF5555FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAAAA0000AA0055AA0000FF0055AA55
AAAA00AAAAAA55AA55AAFF55FF55FF55FF55FFAA55AA55AAAAAA00AAAA55AA5500FF0000
AA5500AA0000AAAAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555000055AA55AA00AAAAAA00FF00
AA005500AA000000AAFFAA55AAFFFFFFAA55AAFFAA000000AA005500AA00FF00AAAAAA00
AA55AA55000055555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00AAAA00FF00AA55555500AAAAAA
0055FF5500AAAA00AA55FFFFAAAAAAAAAAFFFF55AA00AAAA0055FF5500AAAAAA00555555
AA00FF00AAAA00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5500AAAAAA0000000000555555
55AAAAAA55555555AA00FFFF0000AA0000FFFF00AA55555555AAAAAA5555555500000000
00AAAAAA0055AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA555555005500005500000000
0000AA000000000000AAAAAAAA00AA00AAAAAAAA000000000000AA000000000000550000
5500555555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF5555FF00AAAA00FF550000
550000AAAA00AAAA00AA0055AA00AA00AA5500AA00AAAA00AAAA000055000055FF00AAAA
00FF5555FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAAAA0000AAAAAA5555
AAAA00AA000055550000FF555500FF005555FF000055550000AA00AAAA5555AAAAAA0000
AAAAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555555000055AA000000
00AA00AA5555AAAA5555AAFF00AAAAAA00FFAA5555AAAA5555AA00AA00000000AA550000
55555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00AAAA00FF005500
FF55FF00000000AA55AAAAFF5500AA0055FFAAAA55AA00000000FF55FF005500FF00AAAA
00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA5500AAAAAA00FF
55AAAAAA00AAAA000000AA55FF550055FF55AA000000AAAA00AAAAAA55FF00AAAAAA0055
AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55555500AAAA
AA5500AA00AA55000055FFFFAA55AA55AAFFFF55000055AA00AA0055AAAAAA00555555AA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF5555FF0000
AA55AA5500FF00AAAA00FFFFFF555555FFFFFF00AAAA00FF0055AA55AA0000FF5555FF55
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAAAA00
AA00FF00AAAAAA0000AAAAAAAAAA55AAAAAAAAAA0000AAAAAA00FF00AA00AAAAAA55AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555555500
00AAAAAA0000FF005500555500AA55AA005555005500FF0000AAAAAA000055555555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00AA
AA0000AA00AAAAAA00FF5555FF000000FF5555FF00AAAAAA00AA0000AAAA00FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA55
00AAAA005500AA0055FFAAFFFF005500FFFFAAFF5500AA005500AAAA0055AA55FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
5555550000005555AAAAAAFF55AA55AA55FFAAAAAA5555000000555555AAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
FF5555FF0055FF555500AA55FF55FF55FF55AA005555FF5500FF5555FF55FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55AAAAAA00FFFFAA00AA55AAFFFFFFAA55AA00AAFFFF00AAAAAA55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5555555500FFFF00005555FFFFFFFFFF55550000FFFF0055555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFF00AAAAAAAA00AAFFFFFFFFFFFFFFAA00AAAAAAAA00FFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55AA5500AA0055FFFFFFFFFFFFFFFFFF5500AA0055AA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAA555555AAAAAAAAAAAAAAAAAAAAAA555555AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55FF5555FFFF55FFFF55FFFF55FFFF5555FF55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA55AAAAAAAA55FFAAFF55AAAAAAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55555500AA55AAFFAA55AA00555555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF005555FFFFFF555500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55AA55AAAAAAAAAA55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA5500AA0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55FF550055FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 2.30477 0.588183 2.39208 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF5555FF0000AAFFFF55FF005555FFFFFFFF55FF55FFFF555500555500FFFF5500FF00FF
005555AAFFAA55AA00555555550000005555555500AA55AAFFAA555500FF00FF0055FFFF
005555005555FFFF55FF55FFFFFFFF555500FF55FFFFAA0000FF5555FF
FFFFAAFF5555FFFF00FF00FFAAFFFFFFFFFFFFAA5500FFFFAAFF0000FFAA555555FFAA00
AAFFFFAAAAAAFFFF555555555555FF555555555555FFFFAAAAAAFFFFAA00AAFF555555AA
FF0000FFAAFFFF0055AAFFFFFFFFFFFFAAFF00FF00FFFF5555FFAAFFFF
FFFFFF5500AA55FF00AAAA55FFFFFF00FFFF00555555FF005555AAAA55FFFFAAFFFFFF55
5500FFFF55FFFFFFFFAAFFFFAAFFFFFFAAFFFFAAFFFFFFFF55FFFF005555FFFFFFAAFFFF
55AAAA555500FF55555500FFFF00FFFFFF55AAAA00FF55AA0055FFFFFF
FFFFFFFFAA0000FF55550055AAFF55AAAA00AAFFFFAAFF555555550055AAFF55FF00FFFF
AAFF00FFFFAA5555AAFFAA55FFFFFFFFFF55AAFFAA5555AAFFFF00FFAAFFFF00FF55FFAA
550055555555FFAAFFFFAA00AAAA55FFAA55005555FF0000AAFFFFFFFF
FFFFFFFFFF5555FF0000FFAAFFAA55005555FFFF005555AA005500AAFFFF5500AAAA55FF
AAAA00FF5500550000AAAAFFFFFFFFFFFFFFAAAA0000550055FF00AAAAFF55AAAA0055FF
FFAA005500AA555500FFFF55550055AAFFAAFF0000FF5555FFFFFFFFFF
FFFFFFFFFFFFAAFF5555FFAAAA0000FFAAFFFF00FFAAFFFF555555FFFFFFFFAA000000FF
FF55FF55AA00FF00AAFFAAAAAAAAAAAAAAAAAAFFAA00FF00AA55FF55FFFF000000AAFFFF
FFFF555555FFFFAAFF00FFFFAAFF0000AAAAFF5555FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFF5500AA55FFFF5555FFAAAAAAAA555500FFFFAAFFFF00FFFFFF5555FF55
AAFFFFFFAAAA5555FFFFFF55FFFF55FFFF55FFFFFF5555AAAAFFFFFFAA55FF5555FFFFFF
00FFFFAAFFFF005555AAAAAAAAFF5555FFFF55AA0055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA0000FF55AA0055FFFF55FFFFAAFF00FF55FFAA55AA55FFAAFFFFFF
AAAA00AAAAFFAAFFFFFFFFFFAA555555AAFFFFFFFFFFAAFFAAAA00AAAAFFFFFFAAFF55AA
55AAFF55FF00FFAAFFFF55FFFF5500AA55FF0000AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555FF0000AAFFFF00FF00FF55FFAA00AA555500AA0055FFFFFFFF
FF55FF55FFFFFF55AA55FF00555555555500FF55AA55FFFFFF55FF55FFFFFFFFFF5500AA
005555AA00AAFF55FF00FF00FFFFAA0000FF5555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF5555FFFF00FFAA55AAFFFFFF55550000FFAAAA5500FFFFFF
00FF00FF00FFFF000000FF55555555555555FF000000FFFF00FF00FF00FFFFFF0055AAAA
FF00005555FFFFFFAA55AAFF00FFFF5555FFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5500AA55FF00AAAAFFFF55AA55555555FF5500555555FFAA55
FF55AAAA00FFFF00AAFF00FF0000FF0000FF00FFAA00FFFF00AAAA55FF55AAFF55555500
55FF55555555AA55FFFFAAAA00FF55AA0055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA0000FF55550055FF0000AA550000FFFFAA005500AAAAFF
FFFFAAAAFF00FF555500FFAA55AAAAAA55AAFF005555FF00FFAAAAFFFFFFAAAA005500AA
FFFF000055AA0000FF55005555FF0000AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF5555FF0000FFAAFF5555FFFFAA00FFFFFF555555FFFF55
AA55FFFF55AAAA0055AAAAAAFFFF55FFFFAAAAAA5500AAAA55FFFF55AA55FFFF555555FF
FFFF00AAFFFF5555FFAAFF0000FF5555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555FFAAAA0055AAFF55FF5500FFFFAAFFFFFF00
00AA55FF000000AAFFFF55FFFF005500FFFF55FFFFAA000000FF55AA0000FFFFFFAAFFFF
0055FF55FFAA5500AAAAFF5555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA55FFFF55555500FF00FF00AAAAAAFF5500FF
AA0000FF5555FF55FF005500FF555555FF005500FF55FF5555FF0000AAFF0055FFAAAAAA
00FF00FF00555555FFFF55AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000FF55AA0055AAAA00FF5555005555AA00FF
FF5555FF0000FFFFAA55AA00FFFFAAFFFF00AA55AAFFFF0000FF5555FFFF00AA55550055
55FF00AAAA5500AA55FF0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF0000AAFFFF55FF550000FFAAFFFF5555
AAFFFFAA55AAAAAAAAFFFF5555AAFFAA5555FFFFAAAAAAAA55AAFFFFAA5555FFFFAAFF00
0055FF55FFFFAA0000FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555FFFF00FF00FF00AAFF55FF005500
00AAAAAAFFFF55FFFF55AAFFFFAAAAAAFFFFAA55FFFF55FFFFAAAAAA00005500FF55FFAA
00FF00FF00FFFF5555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA55FF00AAAA55FF55FFAAFF555555
FF55FFFF5500FF00FFFFAAAAAAAAFFAAAAAAAAFFFF00FF0055FFFF55FF555555FFAAFF55
FF55AAAA00FF55AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000FF55550055AAFFFFFF55AA0055
AAFFFF0055AAAAAA55FFAAAAFFAAAAAAFFAAAAFF55AAAAAA5500FFFFAA5500AA55FFFFFF
AA55005555FF0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF0000FFAAFFAA55FF0000AAFF
FF55AAFF0000000000FF55FFFFFF55FFFFFF55FF0000000000FFAA55FFFFAA0000FF55AA
FFAAFF0000FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555FFAAAA0000FF5555FFFF
FFFFAAAAAA55AAAA55AAFFFFFF005500FFFFFFAA55AAAA55AAAAAAFFFFFFFF5555FF0000
AAAAFF5555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA55FFFF5555FFAAFFFFFF
FFFFFF55FFFFAAAAFFFF55AAFF555555FFAA55FFFFAAAAFFFF55FFFFFFFFFFFFAAFF5555
FFFF55AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000FF55AA0055FFFFFFFF
FFFF005500FF55FFFFFFFFAAAA005500AAAAFFFFFFFF55FF005500FFFFFFFFFFFF5500AA
55FF0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF0000AAFFFF00FFFF
00FF555555FFAAFF55AA55FFFF555555FFFF55AA55FFAAFF555555FF00FFFF00FFFFAA00
00FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555FFFF00FFAA55
FF55AA0055AAFFAA550055AA5555555555AA550055AAFFAA5500AA55FF55AAFF00FFFF55
55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA55FF00AAAAFF
FFFFAAAA550055FFFFAA005555555555555500AAFFFF550055AAAAFFFFFFAAAA00FF55AA
0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000FF55550055
FF00555500AAFFFFFFFF555555555555555555FFFFFFFFAA00555500FF55005555FF0000
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF0000FFAA
FF55555555FFFFFFFFFFFFAAFFFFAAFFFFAAFFFFFFFFFFFF55555555FFAAFF0000FF5555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555FFAA
AA00550000FF5500FFFFFFFF55AAFFAA55FFFFFFFF0055FF00005500AAAAFF5555FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA55FF
FF555555FF55AA00FF5500FFFFAAAAAAFFFF0055FF00AA55FF555555FFFF55AA0055FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000FF
55AA0055AAFFFF5555AA00FFFFFF55FFFFFF00AA5555FFFFAA5500AA55FF0000AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF
0000AAFFFF55AA5500AA00FFFF005500FFFF00AA0055AA55FFFFAA0000FF5555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
5555FFFF00550055AAAAFF00FF555555FF00FFAAAA55005500FFFF5555FFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
00AA55FF00AA55AA0000AAAA5555555555AAAA0000AA55AA00FF55AA0055FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA0000FF555500AA00FFAAAAFFFFAAFFFFAAAAFF00AA005555FF0000AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5555FF0000FFAAAA55FFFF55AAFFAA55FFFF55AAAAFF0000FF5555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFF5555FFAAAAFFFFFFFFAAAAAAFFFFFFFFAAAAFF5555FFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5500AA55FFFF5500FFFFFF55FFFFFF0055FFFF55AA0055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA0000FF55AA00FFFF00FF00FFFF00AA55FF0000AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF5555FF0000AAFF55AAAAAA55FFAA0000FF5555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFF5555FFFF0000AA0000FFFF5555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55000055FF00AAFFAA00FF55000055FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00FF00FFAAAAAAFF00FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5555AAAA000000AAAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFAAAA55AAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55005555550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 2.30477 0.782187 2.39208 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF555555AAAA00AA00AAAAFFFF55AAAAAA555500AAAA00AAFFFF55FF55AAFFFFAAAAAA00
5555AAFFFFAAAA550000AAFFFFAAAAAAFFFFAA000055AAAAFFFFAA555500AAAAAAFFFFAA
55FF55FFFFAA00AAAA005555AAAAAA55FFFFAAAA00AA00AAAA555555FF
FFFFAAFFFF55FF55FF5500FFFFFFAAAA0000FF00AAAA00FF55AAFFFFFFAAAAAAAA0000AA
FFFFAAAAAAAAFFAAFF00AAAAAAAAFFAAAAAAAA00FFAAFFAAAAAAAAFFFFAA0000AAAAAAAA
FFFFFFAA55FF00AAAA00FF0000AAAAFFFFFF0055FF55FF55FFFFAAFFFF
FFFFFF55AAFFFF000055AAAAAAAAAA00AAFF00FFAAAA00FFFFAAAAAAAAAA0000AA00FFAA
AAAAAA0000AAAAAAFF55550055FFFFFF55005555FFAAAAAA0000AAAAAAAAFF00AA0000AA
AAAAAAAAFFFF00AAAAFF00FFAA00AAAAAAAAAA550000FFFFAA55FFFFFF
FFFFFFFFAAAAAAAA55AA00AAAA00AA00FF55AAAAAA000000550055550055FF5555AAAAAA
FFAAAAFF00AAAAFFAA5500AAFFFF00FFFFAA0055AAFFAAAA00FFAAAAFFAAAAAA5555FF55
0055550055000000AAAAAA55FF00AA00AAAA00AA55AAAAAAAAFFFFFFFF
FFFFFFFFFF5500555555AAAAFFAA00000055AA5555AAAA55AA00FF000000FFFFAAFFAAAA
FF55FF00FFAAAAFF5500AAFFAA55FF55AAFFAA0055FFAAAAFF00FF55FFAAAAFFAAFFFF00
0000FF00AA55AAAA5555AA55000000AAFFAAAA5555550055FFFFFFFFFF
FFFFFFFFFFFFAA0055AA00AAAAAA00FFAA0055555555AA5500FFAA55AAAA55FFAAAAAAFF
AA5500000055550000FFAAAAAAFFFFFFAAAAAAFF0000555500000055AAFFAAAAAAFF55AA
AA55AAFF0055AA5555555500AAFF00AAAAAA00AA5500AAFFFFFFFFFFFF
FFFFFFFFFFFFFF555555AAAA00AA00FFFF55555555555500AAFF5500AAAAFFFF005555AA
FFAAFF00AAFFFFAA00FFFF55FFFFFFFFFF55FFFF00AAFFFFAA00FFAAFFAA555500FFFFAA
AA0055FFAA00555555555555FFFF00AA00AAAA555555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF55FF55FF55AAFFFFAAFFFFAAFF005500AAFFAAAAAAAA5500AA
AAAAFF5555000055FF55AAFFFFFFFFFFFFFFAA55FF5500005555FFAAAAAA0055AAAAAAAA
FFAA005500FFAAFFFFAAFFFFAA55FF55FF55FFFFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55AAFFFF000055AA55FFAAAAAAAAFF555555FFFFFF5500555555FF
FF550000FF00AAFFFFFFAAAAAAAAAAAAAAAAAAFFFFFFAA00FF000055FFFF5555550055FF
FFFF555555FFAAAAAAAAFF55AA550000FFFFAA55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAAAA55AA00AA55FFFF55FFFFFFAAFFFFFFFF000000FF0000
5500AAFF00FFAAAAAAAAAAFFAAAAFFAAAAFFAAAAAAAAAAFF00FFAA00550000FF000000FF
FFFFFFAAFFFFFF55FFFF55AA00AA55AAAAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5500555555AAAAFFFFFFFFAA55FFAAAAAAAAAAAA55AAAAAA55
AA00FF55AAAAAAFFAAAA000055FFFFFF550000AAAAFFAAAAAA55FF00AA55AAAAAA55AAAA
AAAAAAAAFF55AAFFFFFFFFAAAA5555550055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA0055AA00AAAAAAAAAAAAFFFFFF55FFFF55FF0000AAAA00
55FF55AA00AAAAFF55FF00AAFFFFFFFFFFAA00FF55FFAAAA00AA55FF5500AAAA0000FF55
FFFF55FFFFFFAAAAAAAAAAAA00AA5500AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555AAAA00AA00AAAAFF55AAFFFFFFFFAA55AAAA00AA
FFFFFFAAAA5555AAFFFF00AAAAAAAAAAAAAA00FFFFAA5555AAAAFFFFFFAA00AAAA55AAFF
FFFFFFAA55FFAAAA00AA00AAAA555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55FF55FF5500FFFFAAAAAAAAAAAA0055FF00AA
AAAAAAAA0000FF0055000000AAAAFFAAAA0000005500FF0000AAAAAAAAAA00FF5500AAAA
AAAAAAAAFFFF0055FF55FF55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFF000055AAAAAAAA00AAAAFFAAAA55000000
AA00AA00AAFF00FFAAFF00AAFFAAAAAAFFAA00FFAAFF00FFAA00AA00AA00000055AAAAFF
AAAA00AAAAAAAA550000FFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA55AA00AAAA00AAFFAAAAAA00AA55AAAA
5555FF00AAAAAA55FFFF00AAAAAAFFAAAAAA00FFFF55AAAAAA00FF5555AAAA55AA00AAAA
AAFFAA00AAAA00AA55AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500555555AAAAFFAA000055FFFF5555AA0000
AA55000000AA0000FFFF00AA00AAAAAA00AA00FFFF0000AA00000055AA0000AA5555FFFF
550000AAFFAAAA5555550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AA00AAAAAA00FFAAFF55AA005555FF
5500AAFF00AAAA55AAFF5555AAAAFFAAAA5555FFAA55AAAA00FFAA0055FF555500AA55FF
AAFF00AAAAAA00AA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555AAAA00AA00FFFF55AA000000FF00
FF00AAAAAA5555AA000055AA00AAAAAA00AA550000AA5555AAAAAA00FF00FF000000AA55
FFFF00AA00AAAA555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55FF55FF55AAFFFF5555FF55AA
AAAA5555AA5500AA00FFAAFFAA00AA00AAFFAAFF00AA0055AA5555AAAAAA55FF5555FFFF
AA55FF55FF55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFF000055AA55FFAAFFFFFFAA
AA00AA550055AAAAFF00FF55AA55AA55AA55FF00FFAAAA550055AA00AAAAFFFFFFAAFF55
AA550000FFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA55AA00AA55FFFFFFFF00
5555FFFFAA005555AAFF00FF0055AA5500FF00FFAA555500AAFFFF555500FFFFFFFF55AA
00AA55AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500555555AAAAFFFFFFFF00FF
AAFFFFFFFF55555555AAFF00FFAAFFAAFF00FFAA55555555FFFFFFFFAAFF00FFFFFFFFAA
AA5555550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AA00AAAAAAAAAAAA55
FFFFFFFFFFFFAAFFFFAAAAAA55FFFFFF55AAAAAAFFFFAAFFFFFFFFFFFF55AAAAAAAAAAAA
00AA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555AAAA00AA00AAAAFF
FFFFFFFFFFFFFF55AAFFAAAAFFFF00FFFFAAAAFFAA55FFFFFFFFFFFFFFFFAAAA00AA00AA
AA555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55FF55FF5500FF
FFFFFFFFFFFFFFFFAAAAAAFFAA55FF55AAFFAAAAAAFFFFFFFFFFFFFFFFFF0055FF55FF55
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFFF000055AAAA
AAAAAAAAAAAAAAAAAA00AAAAAAFFFFFFAAAAAA00AAAAAAAAAAAAAAAAAAAAAA550000FFFF
AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA55AA00AA
00AAAA0000AAAA00AA00FF55FFFFFFFFFF55FF00AA00AAAA0000AAAA00AA00AA55AAAAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500555555AAAA
FF0055FF5555AA55AA55AAFFFFFFFFFFFFFFAA55AA55AA5555FF5500FFAAAA5555550055
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AA00AA
AAAA550000FF0055AA5500FFFFFFFFFFFFFF0055AA5500FF000055AAAAAA00AA5500AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555AAAA
0000AA55AAAAAA550055AAAAAAAAAAAAAAAAAA550055AAAAAA55AA0000AAAA555555FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55
FF555500AAAA00AA55AA0000AAAA00AAAA0000AA55AA00AAAA005555FF55FFFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFF
FF0000FFAAAAFF0055AA55AAAA000000AAAA55AA5500FFAAAAFF0000FFFFAA55FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
AAAA55AAFFAAAAAA550055AA5555FF5555AA550055AAAAAAFFAA55AAAAAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
005555550000AA00AA55AA0000FF00FF0000AA55AA00AA00005555550055FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA0055AA00FFAAAA555555AAAA55FF55AAAA555555AAAAFF00AA5500AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF555555AAAAAAFFAAFFFFAAAAFFFFFFAAAAFFFFAAFFAAAAAA555555FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFF55FFFF00550000AAAAAAAAAA00005500FFFF55FFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55AAFFFFFF00AA55AAAA00AA00AAAA55AA00FFFFFFAA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAAAAAAA555555AA55AA55AA555555AAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55005555AA0055AA550055AA5500AA55550055FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA0055AA55AA00AA55AA00AA55AA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF555555AA00AAFFAAFFAA00AA555555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF5555AAFFAA5555FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55AAFFFFAAAAAAFFFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAAAA00AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF550055FF550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 2.30477 0.97619 2.39208 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF555555FFFFFFFFFFFFFF55AAFFAA55FFFFFFFF55AA00FF00FF00AA55FFFFAAFFFF00FF
55AAAA55FF00FF5500AAFFFFFF000000FFFFFFAA0055FF00FF55AAAA55FF00FFFFAAFFFF
55AA00FF00FF00AA55FFFFFFFF55AAFFAA55FFFFFFFFFFFFFF555555FF
FFFFAAFFFF00FFFFFFFFFFFFAAAAAAFFFFFFFFFFFFAAAA55FF55AAAAFFFFFFFF55AA00FF
FFAAAAFFFF00AA55550000FF0000AA0000FF00005555AA00FFFFAAAAFFFF00AA55FFFFFF
FFAAAA55FF55AAAAFFFFFFFFFFFFAAAAAAFFFFFFFFFFFF00FFFFAAFFFF
FFFFFF55AA00FF00FFFFFFFFFF55FFFFFFFFFFFFFFFF55FF00FF55FFFFFFFFFFFFAAAA55
FFAAAAFF55AAAAFFFFAA00FF00AAFFAA00FF00AAFFFFAAAA55FFAAAAFF55AAAAFFFFFFFF
FFFF55FF00FF55FFFFFFFFFFFFFFFF55FFFFFFFFFF00FF00AA55FFFFFF
FFFFFFFFAAAA55FF55AA0055AAFFFFFFFFFFFFFFFFFFFFAA55AAFFFFFFFFFFFFFFFF55FF
00000000FF55FFFFFFFF555555FFFFFF555555FFFFFFFF55FF00000000FF55FFFFFFFFFF
FFFFFFAA55AAFFFFFFFFFFFFFFFFFFFFAA5500AA55FF55AAAAFFFFFFFF
FFFFFFFFFF55FF00FF55FF550000FFFFFFFFFFFFFFFF000055FFFFFFFFFFFFFFFFFFFFAA
55AAAA55AAFFFFFFFFFFFFAAFFFFFFFFFFAAFFFFFFFFFFFFAA55AAAA55AAFFFFFFFFFFFF
FFFFFFFF550000FFFFFFFFFFFFFFFF000055FF55FF00FF55FFFFFFFFFF
FFFFFFFFFFFFAA55AAFFFFFFAA00FFFFFFFFFFFFFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFF
55000055FFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFF55000055FFFFFFFFFFFFFF
FFFFFFFFFFAA00FFFFFFFFFFFFFFFF00AAFFFFFFAA55AAFFFFFFFFFFFF
FFFFFFFFFFFFFF550000FF000055555555555555555555FFFFFFFFFFFFFFFFFFFFFFFFFF
00555500FF0000FF0000FFAA00FF00FF00AAFF0000FF0000FF00555500FFFFFFFFFFFFFF
FFFFFFFFFFFF555555555555555555550000FF000055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00FF00AAFFFFAAFFFFAAFFFFAAFFFFFFFFFFFFFFFFFF0000FFFFFF
00AAAA00FF00AAFF5555FFAAAA55FF55AAAAFF5555FFAA00FF00AAAA00FFFFFF0000FFFF
FFFFFFFFFFFFFFAAFFFFAAFFFFAAFFFFAA00FF00AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF555555FFFFFFFF55AAFFAA55FFFFFFFFFF00FFFF00FF00AAFF55AA
000000555555FFFF0055FFAAAAFFFFFFAAAAFF5500FFFF555555000000AA55FFAA00FF00
FFFF00FFFFFFFFFF55AAFFAA55FFFFFFFF555555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFFFAAAAAAFFFFFF00FFFF00AA55FF55AAAAFF5500
00AA00FF5500FF00FFAAFF55FFFF00FFFF55FFAAFF00FF0055FF00AA000055FFAAAA55FF
55AA00FFFF00FFFFFFAAAAAAFFFFFF00FFFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55AA00FF00FFFF55FFFF00FF00AA55FF55FF00FF55FFFFFFAA
0000555555AAAAAA55FFFFFFAA550055AAFFFFFF55AAAAAA5555550000AAFFFFFF55FF00
FF55FF55AA00FF00FFFF55FFFF00FF00AA55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF55AA00AA55FF55AAAAFFFFFFAA55AAFFFFFFFFFF
555500FF5500005500FFFF000055FF550000FFFF0055000055FF005555FFFFFFFFFFAA55
AAFFFFFFAAAA55FF55AA00AA55FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF55FF00FF55FF55FF00FF55FFFFFFFFFF550000FF00FFFF
0055FF55AA55AAAA0000FF00AAFFFFFFAA00FF0000AAAA55AA55FF5500FFFF00FF000055
FFFFFFFFFF55FF00FF55FF55FF00FF55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFFFFFFAA55AAFFFFFFFFFFFFFFAA00FF00AA55
FF5500AAAAFFFF55FF555555FFFFFFFFFF555555FF55FFFFAAAA0055FF55AA00FF00AAFF
FFFFFFFFFFFFAA55AAFFFFFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000FF000055FFFFFFFFFFFFFFFFFF555555FFFF
AA5555FFFF55AAFFFFFFAAFFFFFFFFFFFFFFAAFFFFFFAA55FFFF5555AAFFFF555555FFFF
FFFFFFFFFFFFFF550000FF000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF00AAFFFFFFFFFFFFFFFFFFFFFFAAFFFF00
0055FF0000FF55FFAA55FFFFFFFFFFFFFFFFFF55AAFF55FF0000FF550000FFFFAAFFFFFF
FFFFFFFFFFFFFFFFAA00FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFF55AA00
FFAAFF5555FFAAFF55FF00FFFFFFFFFFFFFF00FF55FFAAFF5555FFAAFF00AA55FFFFFFFF
FFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFFFFFFFFFFFFFFFFFFFFFAAAA
55FFFFFFAAFF55FFAAFF555555555555555555FFAAFF55FFAAFFFFFF55AAAAFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00FF00FFFFFFFFFF00FFFFFFFFFF55
FF0000FFFF55AA55FFFFFFAAFFFFAAFFFFAAFFFFFF55AA55FFFF0000FF55FFFFFFFFFF00
FFFFFFFFFF00FF00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF55AA0055AAFF00FFFFFF00FF
55AAAA5500AAAAFFFFFFFFFF55AAFFAA55FFFFFFFFFFAAAA0055AAAA55FF00FFFFFF00FF
AA5500AA55FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00FF55FF550000FFAA5500AAFF
55000055FF55FFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFF55FF55000055FFAA0055AAFF00
0055FF55FF00FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFFFFFFAA00FFFF55005500
AAAA55AA55FF0000FF00FF00FFFF55FFFF00FF00FF0000FF55AA55AAAA00550055FFFF00
AAFFFFFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000FF000055555555AAAA00
000055FFFFAA55AAAAAA55FF55AA00AA55FF55AAAAAA55AAFFFF55000000AAAA55555555
0000FF000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF00AAFFFFAAFFFF55FF
555500FF000055FFFF55FF00FF55FF55FF00FF55FFFF550000FF005555FF55FFFFAAFFFF
AA00FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFF55AAFFFF
FFAAFF0000AAFFFFFFFFAA55AAFFFFFFAA55AAFFFFFFFFAA0000FFAAFFFFFFAA55FFFFFF
FF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFFFAAAAAA
AAAAFF5555FFFFFFFFFFFF550000FF000055FFFFFFFFFFFF5555FFAAAAAAAAAAFFFFFF00
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00FF00FFFF55FF
FF55FFAAFFFFFFFFFFFFFFFFAA00FF00AAFFFFFFFFFFFFFFFFAAFF55FFFF55FFFF00FF00
AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF55AA00AA
55FF000000FFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFF000000FF55AA00AA55FF55AA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55FF00FF55FF55
FF00FFAA0000FFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFF0000AAFF00FF55FF55FF00FF55
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFFFFFF
AA55AAFFAA00FFFFFFFFFFFFFF000000FFFFFFFFFFFFFF00AAFFAA55AAFFFFFFAA55AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000FF00
0055FFFFFF555555555555555555FF555555555555555555FFFFFF550000FF000055FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF00
AAFFFFFFFFFFAAFFFFAAFFFFAAFFFFFFAAFFFFAAFFFFAAFFFFFFFFFFAA00FF00AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555
FFFFFFFFFFFFFF55AAFFAA55FFFFFFFFFF55AAFFAA55FFFFFFFFFFFFFF555555FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
FF00FFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFF00FFFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
AA00FF00FFFFFFFFFF55FFFFFFFFFFFFFFFFFF55FFFFFFFFFF00FF00AA55FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAA55FF55AA0055AAFFFFFFFFFFFFFFFFFFFFFFAA5500AA55FF55AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55FF00FF55FF550000FFFFFFFFFFFFFFFFFF000055FF55FF00FF55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA55AAFFFFFFAA00FFFFFFFFFFFFFFFFFF00AAFFFFFFAA55AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF550000FF000055555555555555555555550000FF000055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA00FF00AAFFFFAAFFFFAAFFFFAAFFFFAA00FF00AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF555555FFFFFFFF55AAFFAA55FFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFFF00FFFFFFAAAAAAFFFFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55AA00FF00FFFF55FFFF00FF00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA55FF55AA00AA55FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55FF00FF55FF55FF00FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA55AAFFFFFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF550000FF000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 2.40082 0.200176 2.48813 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55AA0000FFAA0000AA00FFFFFFFFFFFFFF00AA0000AAFF0000AA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA55AA000000FFAA550055550055550055AAFF000000AA55AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55FFAAFF5555FF55FFAAFF0055FF5500FFAAFF55FF5555FFAAFF55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAAAFFFFAAAA000000AAFFFFFFAA000000AAAAFFFFAAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFF55FFAA5500AA55FFFFFF55AA0055AAFF55FFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55550055FFFF0055AAFFFFFFFFFFAA5500FFFF55005555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5500FF00550055AA55FFFFFFFFFF55AA55005500FF0055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA0000FF5555AAFFFFFFFFFFFFFFAA5555FF0000AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55FFAA005555AA55FFFFFFFFFFFFFF55AA555500AAFF55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAAA5555AAFFFFFFFFFFFFFFFFFFAA5555AAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFAAFF55FFFFFFFFFFFFFF55FFAAFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF555500000055FFFFFFFFFFFFFF550000005555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFF00AAFFFFFFFFFFFFFFFFFFAA00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55FFAAAA55FFFF55FFFFFF55FFFF55AAAAFF55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAAAAAA000055FFFFFF550000AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF55FFFF00FFFF00AAFFFFFFFFFFAA00FFFF00FFFF55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF550000AAFFAAAA55FFFFFFFFFF55AAAAFFAA000055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA00FFFF55AAFFFFFFFFFFFFFFAA55FFFF00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00005500FFFF55FFFFFF55FFFF00550000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF555555AA000055FFFFFF550000AA555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF5500FF55AA0055FFFFFF5500AA55FF0055FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55FF0000AAAAAA5555005555AAAAAA0000FF55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF550000FF00FFFF0055FF5500FFFF00FF000055FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF55FF00AAFFAA0000AAFFFFFFAA0000AAFFAA00FF55FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF550000FFFF55AAAA55FFFFFF55AAAA55FFFF000055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA00550055FFAA5555005555AAFF55005500AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55AAAA0055FFFF0055FF5500FFFF5500AAAA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA55FF550000AAFFFFFFAA000055FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF005555AA00FFFFFFFFFF00AA555500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5555AA55FF55FFFFFF55FF55AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF550055FFFFFF550055FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55FFAAAA0055FFFFFF5500AAAAFF55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAAAAA5555005555AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFF0055FF5500FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55550000FF55FF00005555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5500FF00AA00AA00FF0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55FF0000AA55FF55AA0000FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF550000FF00FF55FF00FF000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA005500AA00AA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF55AA00AA55FF55AA00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA55AAFFFFFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55AA55FFFFFF55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA5555005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55FF550055FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF550055FF550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 2.40082 0.39418 2.48813 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF
55AA555555AA00AAAAFF5555FFAA00AAFF5555FFAAAA00AA555555AA55FF55AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000
AA5555555555AAAA00AA00550055FF55005500AA00AAAA5555555555AA000055FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA
55555555555555AA55AA55AA00FFFFFF00AA55AA55AA55555555555555AAAA55FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA55
5555555555555555AA00AA5555FFFFFF5555AA00AA555555555555555555AA55FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055
0000FF00005500AA5555FF00FFFF55FFFF00FF5555AA00550000FF00005500FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555
55FF55FF555555FF00FFFF55550055005555FFFF00FF555555FF55FF555555FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
550055005500005555FFFF55AAFF00FFAA55FFFF555500005500550055AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
00AAFF555555FF55AA000000FF55FF55FF000000AA55FF555555FFAA0055FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
AAAA0000550000AA5555FF55550000005555FF5555AA0000550000AAAA55FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0055FF555555FF55000055555555FF55555555000055FF555555FF5500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
55555500AA55FFFF00AAFFFFAAFFFFFFAAFFFFAA00FFFF55AA00555555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAFF5555AAFFAAAA55550055FFFFFF55005555AAAAFFAA5555FFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF550055AA00AA00AAAAAAAA55FFFFFF55AAAAAAAA00AA00AA550055FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55AAAAAA00FF5555AA5555AA000000AA5555AA5555FF00AAAAAA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55AA5555AAAAFF55AA5500AAAA55AAAA0055AA55FFAAAA5555AA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55AA5500AAAA000055FFAA00AAAAAA00AAFF550000AAAA0055AA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55AA55FF5500FFAA005555AAAA00AAAA555500AAFF0055FF55AA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55AA55FFFF00AA00AAFFFF0055FF5500FFFFAA00AA00FFFF55AA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF55AA55FFFF5555AAAA0000AAFFFFFFAA0000AAAA5555FFFF55AA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00550055555555AA55AAAA000000AAAA55AA55555555005500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF555555FFAAFFFF0055AA5555FF5555AA5500FFFFAAFF555555FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA550055FFFF555555AAFFFFFFAA555555FFFF550055AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5500AAFFFFFF55AA0055FFFFFF5500AA55FFFFFFAA0055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF55AAAA00000000FF55555500555555FF00000000AAAA55FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0055FF5555FF55FFAA55FF55AAFF55FF5555FF5500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF555555000055555500FFFFFF005555550000555555FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA55FF5555555555FFFFFF5555555555FF55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF550000AA55FFAA55FFFFFF55AAFF55AA000055FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55AAAA55555500FFFFFFFFFF00555555AAAA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55AA5555555555FFFFFFFFFF5555555555AA55FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00550000FF00000000000000FF00005500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF555555FF55FF5555FF5555FF55FF555555FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA55005500550000005500550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF5500AAFF555555FF555555FFAA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF55AAAA000055000000550000AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0055FF555555FF555555FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF5555550000FFFFFF0000555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAFF5555FFFFFF5555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF550055AA000000AA550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00AA5555FF5555AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5555AAFFFFFFAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA5555005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF5500AA55AA0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AAAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5555AA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AA00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55AA55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 2.40082 0.588183 2.48813 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFF0055FF5555AAFF00AAFFAAFFAAFFFFFFAAFF555500AA0000FFFF55
AAFF55AAFFFFAAAA5555FF5555FFFFFF5555FF5555AAAAFFFFAA55FFAA55FFFF0000AA00
5555FFAAFFFFFFAAFFAAFFAA00FFAA5555FF5500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055AA5555000000AA55AA0000FF0000AA5555AAFF00FFFF55FF
00AA555500005555FF0055AA5555555555AA5500FF555500005555AA00FF55FFFF00FFAA
5555AA0000FF0000AA55AA0000005555AA5500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF005555AA55FFAA55AA55AAFF55FFAA55AA5555FFFF0000FF55
FFAA00AAAAAAAA00AA55FF00AAAA00AAAA00FF55AA00AAAAAAAA00AAFF55FF0000FFFF55
55AA55AAFF55FFAA55AA55AAFF55AA555500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055FF5500AA00AA00AAFFAAFFAA00AAFFFFAAAAFF55AA00
AA55AAFF00AAFF00FFAAFFAA55AAAAAA55AAFFAAFF00FFAA00FFAA55AA00AA55FFAAAAFF
FFAA00AAFFAAFFAA00AA00AA0055FF5500FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0055AA55FF55AAAAAA550055AAAAAA550000AA0055FF55
AAAA00FF00FFAAAAAAFF0000AAAA55AAAA0000FFAAAAAAFF00FF00AAAA55FF5500AA0000
55AAAAAA550055AAAAAA55FF55AA5500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF005555AA00AAFF00AAAAAA0000AAFFFF00FFAA555555
AAAA55FFFF0000AA0000FFFF00AA00AA00FFFF0000AA0000FFFF55AAAA555555AAFF00FF
FFAA0000AAAAAA00FFAA00AA555500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF55AAAAFF5555FF55AAFF0000FFFF5555AA55
550055FFFFFF00FFAA55FFFF55AAAAAA55FFFF55AAFF00FFFFFF55005555AA5555FFFF00
00FFAA55FF5555FFAAAA55FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AA55AAAAFFFFAAAA00FF00FFFFFFFFAAFF00
55FFAAFFAAAAFF55FF5500AA5555FF5555AA0055FF55FFAAAAFFAAFF5500FFAAFFFFFFFF
00FF00AAAAFFFFAAAA55AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555AAAA5500AAFF00FF00FF000055AAAAFF
5500AAFFAA000055FFFFAA55AA555555AA55AAFFFF550000AAFFAA0055FFAAAA550000FF
00FF00FFAA0055AAAA555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF5555AAFF000000FFFFFF00FF5555FF
FFAA55AA00FFFF0055AA00FF5555AA5555FF00AA5500FFFF00AA55AAFFFF5555FF00FFFF
FF000000FFAA5555FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AA5555000000000055000000FF5500
005555AAAAAAFFAA5555FFAAAA00AA00AAAAFF5555AAFFAAAAAA5555000055FF00000055
00000000005555AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555AA55FFAA55FFAAFF55AAFFAAFF
55AA555500555555FF0055AAAA55FF55AAAA5500FF555555005555AA55FFAAFFAA55FFAA
FF55AAFF55AA555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF5500AA00AA55AA00AAFFAA00
55FF5500FFFFAAFFFFFF00555500FF00555500FFFFFFAAFFFF0055FF5500AAFFAA00AA55
AA00AA0055FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AA55FF55AAAA000000AA55AA
FFFFFFAA5500AAFFAAAAFF5500FFFFFF0055FFAAAAFFAA0055AAFFFFFFAA55AA000000AA
AA55FF55AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555AA00AAFF00FFFF00AAAA
550000FFAAFF5555550055AA55FFFFFF55AA5500555555FFAAFF000055AAAA00FFFF00FF
AA00AA555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF55AAAAFF55FFFF00AA
FFFF00FF00AA5555AA55FF00AAAAFFAAAA00FF55AA5555AA00FF00FFFFAA00FFFF55FFAA
AA55FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AA55AAAAFFFF55FFAA
0055AAFFAA55AA5555FF000000AAFFAA000000FF5555AA55AAFFAA5500AAFF55FFFFAAAA
55AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555AAAA5500AAAAFF
00FF55555500FFAAFFFF55AAFF555555FFAA55FFFFAAFF00555555FF00FFAAAA0055AAAA
555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF5555AAFF00AA
55FFFFAAFFFF0000AA5500FFAAAA00AAAAFF0055AA0000FFFFAAFFFF55AA00FFAA5555FF
5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AA5555000000
AAAAFFAA0055AAFF5555AAFFAA000000AAFFAA5555FFAA5500AAFFAAAA0000005555AA55
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555AA55FFAA
55AAAAFF00FF555555AA55AA0000000000AA55AA555555FF00FFAAAA55AAFF55AA555500
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF5500AA
00AAFF00000055FF005555AAAAAAAAAAAAAA555500FF55000000FFAA00AA0055FF5500FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AA55FF
55AAAAFF55AAFFFFFF0055FF5555FF5555FF5500FFFFFFAA55FFAAAA55FF55AA5500FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555AA
00AA000055FF55FFFFFF0055AA555555AA5500FFFFFF55FF550000AA00AA555500FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF
55AAAAAAAA0055FFFFFFFF005555AA555500FFFFFFFF5500AAAAAAAA55FF5500FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055
AA55AAAA55AAFFFFFFFFFFFF0055FF5500FFFFFFFFFFFFAA55AAAA55AA5500FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
5555AAAA5555FFFFFF55FFFFFF005500FFFFFF55FFFFFF5555AAAA555500FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0055FF5555AA55000055FFFFFF55AA55FFFFFF55000055AA5555FF5500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0055AA555500FFFF0055000055FF5500005500FFFF005555AA5500FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF005555AA55FFFF55AA55FFAAFFAAFF55AA55FFFF55AA555500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0055FF55000055FF5500AAFFAA0055FF55000055FF5500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0055AA55FFAAFFAAFF555555FFAAFFAAFF55AA5500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF005555AA0000FFAAAA00AAAAFF0000AA555500FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0055FF55AAFFAA000000AAFFAA55FF5500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0055AA55AA0000000000AA55AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF005555AAAAAAAAAAAAAA555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0055FF5555FF5555FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055AA555555AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF005555AA555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0055FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF55FF00FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55FF000000FF55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5555FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 2.40082 0.782187 2.48813 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFF00AAAA000000FF00AA55AAFFAAFFFFAAFFFF0055FFFFFF550055005555FFFF5555
FFFFFFFFFFFF0000AAAA00FFFFFFFFFFFFFF00AAAA0000FFFFFFFFFFFF5555FFFF555500
550055FFFFFF5500FFFFAAFFFFAAFFAA55AA00FF000000AAAA00FFFFFF
FFFFFFFF0000FFFF00FF55AA00FF0055AA555555AA55FF5500FF55550000AAFFFFFF5555
FFFFFFFF5500FFFF0000FFFFFFFFFFFFFFFFFF0000FFFF0055FFFFFFFF5555FFFFFFAA00
005555FF0055FF55AA555555AA5500FF00AA55FF00FFFF0000FFFFFFFF
FFFFFFFFFF00FF55FFAAAA550055FFAA0055000055AAAA00FFFFFFAA000000FF5500FFAA
00AAAAFFAAFF55FF00FFFFFFFFFFFFFFFFFFFFFF00FF55FFAAFFAAAA00AAFF0055FF0000
00AAFFFFFF00AAAA5500005500AAFF550055AAAAFF55FF00FFFFFFFFFF
FFFFFFFFFFFF005500FF00005555FF00000055550000FF00FF55FF00000000AAAA55FF00
00AA5500FF005500FFFFFFFFFFFFFFFFFFFFFFFFFF005500FF0055AA0000FF55AAAA0000
0000FF55FF00FF00005555000000FF55550000FF005500FFFFFFFFFFFF
FFFFFFFFFFFFFF00AA00AA00005500FFFF00FFAA0000AAAAAAFF0055550055555555FFFF
00FF00AA00AA00FFFFFFFFFFFFFF55FFFFFFFFFFFFFF00AA00AA00FF00FFFF5555555500
555500FFAAAAAA0000AAFF00FFFF00550000AA00AA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFF00AA00AAAAAA00555500AA5500FFFFAAFF5555FF5555AA
55FFFF000000FFFF55FFFF55FF005500FF55FFFF55FFFF000000FFFF55AA5555FF5555FF
AAFFFF0055AA00555500AAAAAA00AA00FFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFF000000FF000000550055AAAAAA00AA5555FF55000055
AAAA00AA0000AAAA00FF55FF5500550055FF55FF00AAAA0000AA00AAAA55000055FF5555
AA00AAAAAA550055000000FF000000FFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055FFFF55AAFF5500555500000055AA00555555FF5500000000
55AA0000FFFF0000FFFFFFAAAA55FF55AAAAFFFFFF0000FFFF0000AA550000000055FF55
555500AA5500000055550055FFAA55FFFF5500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AAAA00FF005500550000AA000055AAFF00AAFFAA00000000
0055AAFF55FF00FFFFFF5500AA55AA55AA0055FFFFFF00FF55FFAA550000000000AAFFAA
00FFAA550000AA000055005500FF00AAAA00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00AA00FFFF0000AA00FF00555555AA00000000
000055AA55AA55FF0055FF55AA00FF00AA55FF5500FF55AA55AA55000000000000AA5555
5500FF00AA0000FFFF00AA00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FF00FF00FF550055555500FFFFAAFF0000AA0000
00AA00FF00AA55AA55FF550000FFFFFF000055FF55AA55AA00FF00AA000000AA0000FFAA
FFFF005555550055FF00FF00FF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF005500FFFFFF0055005500005555AA5500FFFF000000
0000FFFFFF000055AAAAFF00FFFFFFFFFF00FFAAAA550000FFFFFF0000000000FFFF0055
AA5555000055005500FFFFFF005500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00AAAAFF5555000000005500AAFF55FFFF00FF
FF00FF5500FFFF00AA5500FFFFFFFFFFFFFF0055AA00FFFF0055FF00FFFF00FFFF55FFAA
0055000000005555FFAAAA00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0055000000000000555555AAAA00AA00
AAAAAA00FFFFFF55AA00FFFFFFFFFFFFFFFFFF00AA55FFFFFF00AAAAAA00AA00AAAA5555
550000000000005500FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00AA000000000000550000FF00FF00
FF0000FFFFFF550000FFFF55FFFFFFFFFF55FFFF000055FFFFFF0000FF00FF00FF000055
000000000000AA00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFF0000000000000000555500FFFFFF
00555500FF55000000AAAAFFFFFF55FFFFFFAAAA00000055FF00555500FFFFFF00555500
00000000000000FFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAA0000000000AA000000550055FFFF
55AAAA55FF00AA0000AA5500FF55FF55FF0055AA0000AA00FF55AAAA55FFFF5500550000
00AA0000000000AAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF00000000005555FFFF
55555555FFFF0000AA00550055FF55FF55005500AA0000FFFF55555555FFFF5555000000
0000FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FFAAAA00000000AA00FFAAAA
FF00AAFFFF55005555550000AAFFAAFFAA00005555550055FFFFAA00FFAAAAFF00AA0000
0000AAAAFF55FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005500FF0000000000AA55FF0000
FF55AA00AAAA55FF5555FFAA5500FF0055AAFF5555FF55AAAA00AA55FF0000FF55AA0000
000000FF005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00AA0000AA0000FFAAAAAA
AA00FF00FF000055FF5555AA00FFFFFF00AA5555FF550000FF00FF00AAAAAAAAFF0000AA
0000AA00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000AA00AA5500
AA55FF00FF55AAFF00550000FFFFFFFFFF00005500FFAA55FF00FF55AA0055AA00AA0000
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FF00FF00AA
005500FFFF555555AAFF00FFFFFFFFFFFFFF00FFAA555555FFFF005500AA00FF00FF00FF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FFFF55AA55FFFF00
00005555AA55AAAA5500FFFFFFFFFFFFFFFFFF0055AAAA55AA5555000000FFFF55AA55FF
FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAA00FF00AAAA00
0000AAFF000055AA00FFFFFFFFFFFFFFFFFFFFFF00AA550000FFAA000000AAAA00FF00AA
AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FF
FF00FF0055550000FFFFFFFFFFFFFFFFFFFFFFFFFF0000555500FF00FFFF0000FFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF55FF00FFFF
550055FFAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAFF550055FFFF00FF55FF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005500FFFFFF
FFAA55AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AA55AAFFFFFFFF005500FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA00AAAA
00AA55AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA55AA00AAAA00AA00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
00FF00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00FF00FF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF00555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555500FFFFFF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055
FFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF5500FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
AAAA0000FF55FF0055FFFF5500FF55FF0055FFFF5500FF55FF0000AAAA00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFF005500FFFFAAAAFFFF005500FFFFAAAAFFFF005500FFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF55FFAAFF55FF0000FF55FFAAFF55FF0000FF55FFAAFF55FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF005500FF005500FFFF005500FF005500FFFF005500FF005500FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00AA00AA00FFFFFFFF00AA00AA00FFFFFFFF00AA00AA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFF000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0055FFFF5500FF550055FF0055FFFF5500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00AAAAFFFF0055005500FFFFAAAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FF55005500550055FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF55550000005555FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF005500000000005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00AA000000AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF55AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 2.40082 0.97619 2.48813 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00000055FF0055FF555500005555FFAA55FFAA55FF0000AA00FFAA0000FF5500AA55
5500FFAAFF00FFFFAA000055FF00FF00FF550000AAFFFF00FFAAFF005555AA0055FF0000
AAFF00AA0000FF55AAFF55AAFF555500005555FF5500FF55000000FFFF
FFFFFF00AAFFFF55AA0000FF00AAFFFFAAAA005555AA00005500FFFF550000555555FF00
00FFAAAA0000555500FFFF0000AAFFAA0000FFFF0055550000AAAAFF0000FF5555550000
55FFFF00550000AA555500AAAAFFFFAA00FF0000AA55FFFFAA00FFFFFF
FFFFFFFF00555500AAAAAAAAFF00555500FF55555555AAAA550000AA00550000000000AA
FF55FF0055000000FFFFFFFF00FF55FF00FFFFFFFF0000005500FF55FFAA000000000055
00AA000055AAAA55555555FF00555500FFAAAAAAAA00555500FFFFFFFF
FFFFFFFFFF00000055FF0055FFFF000000555555555555AA55000055FFAAFF00AAFF00AA
AAFFFF555555FFAA0000AA00005555550000AA0000AAFF555555FFFFAAAA00FFAA00FFAA
FF55000055AA555555555555000000FFFF5500FF55000000FFFFFFFFFF
FFFFFFFFFFFF00AAFFFF55AA0000AAFF5555555555555555AA00FFFFAAAA000055FFFF00
55FFFFFFAAFFFF55000055FF5555555555FF55000055FFFFAAFFFFFF5500FFFF550000AA
AAFFFF00AA5555555555555555FFAA0000AA55FFFFAA00FFFFFFFFFFFF
FFFFFFFFFFFFFF00555500AAAAAAAA0000FF0000FF000000FF55550055FF00AAFFFFFF55
AA0000AA00AA0000FFAA005555555555555500AAFF0000AA00AA0000AA55FFFFFFAA00FF
55005555FF000000FF0000FF0000AAAAAAAA00555500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000055FF0055FF555500005555FFAA000000FFFFAAAAAA0000AA00
55FF55AA55FF00FFFF5500000000FF0000000055FFFF00FF55AA55FF5500AA0000AAAAAA
FFFF000000AAFF555500005555FF5500FF55000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00AAFFFF55AA0000FF00AAFFFFAAAA00FFAA0000AAAA00AAFF5500
0000AA5555550000AA0055000055005500005500AA0000555555AA00000055FFAA00AAAA
0000AAFF00AAAAFFFFAA00FF0000AA55FFFFAA00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00555500AAAAAAAAFF00555500FF555500FFFF0055FF550055AA
AA55FF000000005500FFFFAA00FF00FF00AAFFFF005500000000FF55AAAA550055FF5500
FFFF005555FF00555500FFAAAAAAAA00555500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000055FF0055FFFF00000055555555FFFF55AA00000055AA
555555000055000000555500FFAAAAAAFF005555000000550000555555AA55000000AA55
FFFF55555555000000FFFF5500FF55000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF55AA0000AAFF5555555555550055AA55FFAA5500
FF0000FFFF000055000000FFAAAA00AAAAFF000000550000FFFF0000FF0055AAFF55AA55
00555555555555FFAA0000AA55FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00555500AAAAAAAA0000FF000000FF00AA55555500FF00
AA00FFFFFFFF00AA55AAFF55FF005500FF55FFAA55AA00FFFFFFFF00AA00FF00555555AA
00FF000000FF0000AAAAAAAA00555500FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000055FF0055FF5555000055005500FF0000FFFFFF
0055005555005500FF0055555500000055555500FF0055005555005500FFFFFF0000FF00
55005500005555FF5500FF55000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF55AA0000FF00AAFFFF00005555FF55FFFF
FF000055AA00FF00AA00FF00000055000000FF00AA00FF00AA550000FFFFFF55FF555500
00FFFFAA00FF0000AA55FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555500AAAAAAAAFF005555000055AA000000AA
00005500AAAAAAFF550000AAFF555555FFAA000055FFAAAAAA00550000AA000000AA5500
00555500FFAAAAAAAA00555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000055FF0055FFFF0000005500AAAAAAAAAA
00FFFFAA00AAAA0000FFFF00555555555500FFFF0000AAAA00AAFFFF00AAAAAAAAAA0055
000000FFFF5500FF55000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF55AA0000AAFF555555FF0055FF00
55005555AAAA00AAFF55FFFF0000FF0000FFFF55FFAA00AAAA5555005500FF5500FF5555
55FFAA0000AA55FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555500AAAAAAAA0000FF0000AAFFFFFF
000055AA00AAAAAA000000AA00FFFFFF00AA000000AAAAAA00AA550000FFFFFFAA0000FF
0000AAAAAAAA00555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000055FF0055FF5555000055FFFFFF
FF00FF005500FF5500005500FFFF55FFFF0055000055FF005500FF00FFFFFFFF55000055
55FF5500FF55000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF55AA0000FF00AAFFFF55FF
FF55550000FFFFFFAA00FF00AA000000AA00FF00AAFFFFFF00005555FFFF55FFFFAA00FF
0000AA55FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555500AAAAAAAAFF00555500AA
000000005500555500FFAAAA5555FF5555AAAAFF005555005500000000AA00555500FFAA
AAAAAA00555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000055FF0055FFFF00000055
FF5555FFAAFF0000FFAAAA00AA550055AA00AAAAFF0000FFAAFF5555FF55000000FFFF55
00FF55000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF55AA0000AAFF55AA
00000000AAAAFF00AA00AAAAAA005500AAAAAA00AA00FFAAAA00000000AA55FFAA0000AA
55FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555500AAAAAAAA0000FF
55AAFF00AAAA000055FF5500FF555555FF0055FF550000AAAA00FFAA55FF0000AAAAAAAA
00555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000055FF0055FF5555
00AAAAFF5500FFFF0000AA55FFFFAAFFFF55AA0000FFFF0055FFAAAA005555FF5500FF55
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF55AA0000FF
00AAAA0000FFFFFF5555FF0000AA00AA0000FF5555FFFFFF0000AAAA00FF0000AA55FFFF
AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555500AAAAAAAA
FF0055FF55550055555555000055FF55000055555555005555FF5500FFAAAAAAAA005555
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000055FF0055
FFFF0000AA5500000000FF00AAFFFFFFAA00FF0000000055AA0000FFFF5500FF55000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF55AA
0000AAFF5500AAFF00AAFFAA5555005555AAFFAA00FFAA0055FFAA0000AA55FFFFAA00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00555500AA
AAAAAA00000055FFFF005555AA005500AA555500FFFF55000000AAAAAAAA00555500FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000055
FF0055FF55AAFFFFFFFF0000FF555555FF0000FFFFFFFFAA55FF5500FF55000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFF
FF55AA0000FF55FFFF55FFAA0000FF0000AAFF55FFFF55FF0000AA55FFFFAA00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055
5500AAAAAAAAFFFFFFFFAAAA00FFFFFF00AAAAFFFFFFFFAAAAAAAA00555500FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000055FF0055FFFFFFFF5500FFFFFFFFFF0055FFFFFFFF5500FF55000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00AAFFFF55AA0000AA0000FFFFFFFFFFFFFF0000AA0000AA55FFFFAA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00555500AAAAAAAA00FFFFFFFFFFFFFFFFFF00AAAAAAAA00555500FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000055FF0055FF55FFFFFF55FFFFFF55FF5500FF55000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00AAFFFF55AA000000AA000000AA000000AA55FFFFAA00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00555500AAAAAA55AA55FF55AA55AAAAAA00555500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000055FF0055AA550055AA5500FF55000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00AAFFFF55AA00AA55AA00AA55FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00555500AAAA555555AAAA00555500FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000055FF000000FF55000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00AAFFFFFF00FFFFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF005555005500555500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFAAFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00AA00AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 2.49686 0.200176 2.58417 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAFFAA5555FF0000AA5555FFFF550055005500FFAA00AAAA00FFFF00AA55FF550055
55AA55005555FFAA00555555005555550055555500AAFF55550055AA55550055FF55AA00
FFFF00AAAA00AAFF005500550055FFFF5555AA0000FF5555AAFFAAAAFF
FFFFAAFF0055AA00FFFF0055000000005555550000AAFFFF5500FFFFFFFF550000005555
5555AA000055AAAA000055AA0000550000AA550000AAAA550000AA5555555500000055FF
FFFFFF0055FFFFAA0000555555000000005500FFFF00AA5500FFAAFFFF
FFFFFFAA0000FF55FF555500AA0000AA0055AA0000AAAA55AA0000000000005555005500
00FF00555500AAAA0000AA55550055005555AA0000AAAA00555500FF0000550055550000
00000000AA55AAAA0000AA5500AA0000AA005555FF55FF0000AAFFFFFF
FFFFFFFFAAAAFF000000550055FFAA555500AAAAFF5500FF00555500555500550000AA55
FFFFFF0000FFFFAAFF55FF00005555550000FF55FFAAFFFF0000FFFFFF55AA0000550055
5500555500FF0055FFAAAA005555AAFF550055000000FFAAAAFFFFFFFF
FFFFFFFFFFAAFF00FFFF0000AA55AA550000AAAA00FF00FFAA550000AA550055AAFF5500
00000000AA00FFAAFF000000AA005500AA000000FFAAFF00AA000000000055FFAA550055
AA000055AAFF00FF00AAAA000055AA55AA0000FFFF00FFAAFFFFFFFFFF
FFFFFFFFFFFFAA00000000AA00AA5555550055FF00FFAA55AA55005555AA0000FF555555
0055550055FFAA00AAFFAA55FF00FF00FF55AAFFAA00AAFF5500555500555555FF0000AA
55550055AA55AAFF00FF5500555555AA00AA00000000AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAFFAA555500FF0000555555FFAA00AA555555000055FFFF55555555
550000555555FF00FF5555AA00FFFFFF00AA5555FF00FF55555500005555555555FFFF55
0000555555AA00AAFF5555550000FF005555AAFFAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF0055AA000000AA005500AAFFFF00550000555500AAFF00005500
005555000055AAAAFF000055FFFFFFFFFF550000FFAAAA55000055550000550000FFAA00
555500005500FFFFAA005500AA000000AA5500FFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA0000FF55FFFF5500550055FF555500AA0000FF00FF5555005500
555555550055AA5555FFFF00000000000000FFFF5555AA5500555555550055005555FF00
FF0000AA005555FF5500550055FFFF55FF0000AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAFF0000000055555500000055AAFFFF55AAAAFF0000555555
0000FF0000AA55555555FF55AAFF55FFAA55FF55555555AA0000FF00005555550000FFAA
AA55FFFFAA5500000055555500000000FFAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFF00FFFF00FF00005555005500FFAA0055FF00AA0000FF00
00AA00FFFF55000055000000FF555555FF00000055000055FFFF00AA0000FF0000AA00FF
5500AAFF00550055550000FF00FFFF00FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00000000AAFFAA550000AA55FF550055AAAAAA0000AAFF
AAAA0000000055550000AA00000055000000AA0000555500000000AAAAFFAA0000AAAAAA
550055FF55AA000055AAFFAA00000000AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAA5555FF0000AA00AA55AA000055FF00555500FF
AAFFFF00FFFF0000FFFF005555005500555500FFFF0000FFFF00FFFFAAFF00555500FF55
0000AA55AA00AA0000FF5555AAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0055AA00FFFF005555AA00AA0000FFAA550000AA
FFFFFFFF00AAFF55FF5555000055555500005555FF55FFAA00FFFFFFFFAA000055AAFF00
00AA00AA555500FFFF00AA5500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000FF55FF5555000055FFFFAA55FF550000AA00
AAFF00AAFFAAFF000000550055555555550055000000FFAAFFAA00FFAA00AA000055FF55
AAFFFF5500005555FF55FF0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF0000005500555555FF55000000FFFF0055
55AAAAFFFFFFAA0000AA005555555555555500AA0000AAFFFFFFAAAA555500FFFF000000
55FF5555550055000000FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFFF0000AA55000000FFFF00FFAA0000
FF0055FF5555FF00FFFFAA55000055000055AAFFFF00FF5555FF5500FF0000AAFF00FFFF
00000055AA0000FFFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00000000AA00AA55FFFF00AAFF5555AAFF
555500000055AAAAAA55AA55005555550055AA55AAAAAA550000005555FFAA5555FFAA00
FFFF55AA00AA00000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAA555500FF00AAFFAAFF0000FF55
55555500555555AA555555AA0000FF0000AA555555AA5555550055555555FF0000FFAAFF
AA00FF005555AAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0055AA000000AAAA5555FFFF5555
5555555500005500FF0000FF55FFFFFF55FF0000FF00550000555555555555FFFF5555AA
AA000000AA5500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000FF55FFFF5500FF0000000055
0000FF0000AA005555FFFF555555FF555555FFFF555500AA0000FF00005500000000FF00
55FFFF55FF0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00000000FFFFFF55FFFF00
00AA00FFFF55005500000000550000005500000000550055FFFF00AA0000FFFF55FFFFFF
00000000FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFFF00FFAA00FF00AAFF
AAAA000000005555550055550000AA000055550055555500000000AAAAFFAA00FF00AAFF
00FFFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00000000AAFFFF00AA00AA
FFFFAA55FFFF0000FF00FF0000AA00AA0000FF00FF0000FFFF55AAFFFFAA00AA00FFFFAA
00000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAA5555FF55FF00FF
5555FF00000000AA00FFFFFF00FF55FF00FFFFFF00AA00000000FF5555FF00FF55FF5555
AAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0055AA00FF00AA00
FF000000AA0000AAAAFF00AAFF555555FFAA00FFAAAA0000AA000000FF00AA00FF00AA55
00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000FF55FF55FF00
FFAA55FFAAFF55AA5555FFFFAA005500AAFFFF5555AA55FFAAFF55AAFF00FF55FF55FF00
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF000000FFAA
AA555555FF00AA55555555FF5500550055FF55555555AA00FF555555AAAAFF000000FFAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFFF00AA
AA005500AAFF5500AA5500000055555500000055AA0055FFAA005500AAAA00FFFF00FFAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00000000AA
AA0000FFFFAA005555AA0000AA005500AA0000AA555500AAFFFF0000AAAA00000000AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAA55
55AAFFAA00FF55AA0055FFFF5500550055FFFF5500AA55FF00AAFFAA5555AAFFAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0055
AA00AAFFFF00AA555500000000555555000000005555AA00FFFFAA00AA5500FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000
FF55FF00AAFF5500005555005555555555005555000055FFAA00FF55FF0000AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
FF000000AAAA5500555555550000FF0000555555550055AAAA000000FFAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
FF00FFFF5500FF00FF0000FF00FFFFFF00FF0000FF00FF0055FFFF00FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA000000005555FFFFFF55AAAAAA55AAAAAA55FFFFFF555500000000AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAFFAA550000000000FF5500FF0055FF000000000055AAFFAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFF0055AAFF55FFFF00AA55FF55AA00FFFF55FFAA5500FFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA0000FF555555FF55FF000000FF55FF555555FF0000AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAFF0000FF00AA55AAFFAA55AA00FF0000FFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFF00FFFFFF0055AA55AA5500FFFFFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA0000000000AA555555AA0000000000AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAFFAAAAAA005500AAAAAAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF0055FF00FF00FF5500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA0000FFAA55AAFF0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAFF005500FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFF00FF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 2.49686 0.39418 2.58417 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAFF00FFAAAAAAFFAAFFAA00FFFF00FFAAFFFF00FFAAFF000000FFAA000055000000
0000000000FFFF000000FFFFFFFFFFFFFFFFFF000000FFFF0000000000000000550000AA
FF000000FFAAFF00FFFFAAFF00FFFF00AAFFAAFFAAAAAAFF00FFAAAAFF
FFFFAAFF000000AA000000AAFFFF00AAFFAA00000000FFAAFF00FF000000AA5500FF0000
FF0000FF00000000FF0000000000000000000000FF00000000FF0000FF0000FF0055AA00
0000FF00FFAAFF00000000AAFFAA00FFFFAA000000AA000000FFAAFFFF
FFFFFFAA0055AAFFFF00FFFFAA00FFFFAA0000550000FFAAFF000000FF0000AAAAFF00FF
FFFF000000FFFF000000FFFF0000FF0000FFFF000000FFFF000000FFFFFF00FFAAAA0000
FF000000FFAAFF0000550000AAFFFF00AAFFFF00FFFFAA5500AAFFFFFF
FFFFFFFFAAAA00000000FFAA0000FFAA00005500FF000000AAFFAAAAFF00FFFFAAFF0000
000000FF00000000FF00000000FFFFFF00000000FF00000000FF0000000000FFAAFFFF00
FFAAAAFFAA000000FF00550000AAFF0000AAFF00000000AAAAFFFFFFFF
FFFFFFFFFFAAFFAAAAFFAA0000FFFFFFAA55FF00000055AAFFFFFFAAFF00FFAA000000FF
0000FFFFFF0000FFFFFF0000FFFFFFFFFF0000FFFFFF0000FFFFFF0000FF000000AAFF00
FFAAFFFFFFAA55000000FF55AAFFFFFF0000AAFFAAAAFFAAFFFFFFFFFF
FFFFFFFFFFFFAA0000AAFFFF0000000000AAAA55FFAAAA0000000000AAFFAA0000550000
00FFFFFFFFFF0000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFF000000550000AAFF
AA0000000000AAAAFF55AAAA0000000000FFFFAA0000AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAFFFFFFFF00FF0000555500FFAAFFFF000055AA000000AA5500FFFF
00000000000000FF0000FFFFFFFFFFFFFFFFFF0000FF00000000000000FFFF0055AA0000
00AA550000FFFFAAFF0055550000FF00FFFFFFFFAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF00AAFF000000FF0055FFAA00000000FF00555555555500FFFFFF
FF0000FF0000FFFFFF0000000000000000000000FFFFFF0000FF0000FFFFFFFF00555555
555500FF00000000AAFF5500FF000000FFAA00FFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA005555FFFF000000FF555500AA55000000FF5500FF5500000000
0000FFFFFF0000000000FFFF0000FF0000FFFF0000000000FFFFFF00000000000055FF00
55FF00000055AA005555FF000000FFFF555500AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA00AAFF00FFFF00AAAA005555AAFFAAAA555555FF0000FF00
FF0000000000FF0000FFFFFFFF000000FFFFFFFF0000FF0000000000FF00FF0000FF5555
55AAAAFFAA555500AAAA00FFFF00FFAA00AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFAAFF00000000555500AAAA000000AA00AAAA00FF000000
FFAA550000FFFFFF000000000000FF000000000000FFFFFF000055AAFF000000FF00AAAA
00AA000000AAAA00555500000000FFAAFFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA0000005500AA5555AAFFFFAA5500AA005555000000FFFF
555500FF0000000000FFFF0000FFFFFF0000FFFF0000000000FF005555FFFF0000005555
00AA0055AAFFFFAA5555AA0055000000AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF550000AAAA00000000AAAAFFFF5500FF0000FFAA
00AAAAFF0000FFFF00000000FFFFFFFFFF00000000FFFF0000FFAAAA00AAFF0000FF0055
FFFFAAAA00000000AAAA000055FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF005500AA0000FF00FFFFAAFF00AAAAFF0000FFAA
FFAAFFFFFF00000000FFFF00000000000000FFFF00000000FFFFFFAAFFAAFF0000FFAAAA
00FFAAFFFF00FF0000AA005500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FFFFAAAAFF00000000AAFFAAFFFFFF000000
AAFFFFFFFFFF0000FFFFFFFF0000FF0000FFFFFFFF0000FFFFFFFFFFAA000000FFFFFFAA
FFAA00000000FFAAAAFFFF5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FFAAFFFFFF0000FFFFAA000000000055AA
FFFFFFFFFFFFFF000000000000FFFFFF000000000000FFFFFFFFFFFFFFAA550000000000
AAFFFF0000FFFFFFAAFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA0000000000FFFFFFFFAAAAAAAAAAAA00
0000000000000000FFFF0000FFFFFFFFFF0000FFFF000000000000000000AAAAAAAAAAAA
FFFFFFFF0000000000AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000FF00FF000000000000AA0000AA0000
FF0000FF0000FF00000000FFFFFFFFFFFFFF00000000FF0000FF0000FF0000AA0000AA00
0000000000FF00FF0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00FFAAAAAAFFAA550055AAFFFF00
0000FFFFFF000000FFFF000000000000000000FFFF000000FFFFFF000000FFFFAA550055
AAFFAAAAAAFF00FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF000000AA000000AAAAAA00000000
FF0000000000FF00000000FF0000FF0000FF00000000FF0000000000FF00000000AAAAAA
000000AA000000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AAFFFF00FFFFAAFFFF0000FF
FFFF0000FF000000FFFF000000FFFFFF000000FFFF000000FF0000FFFFFF0000FFFFAAFF
FF00FFFFAA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00000000FFAA00000000FFFF
FFFFFF000000FF000000005500000000005500000000FF000000FFFFFFFFFF00000000AA
FF00000000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAAAFFAA0000FFFF000000
00000000FF000000FF00FF0055AAFFAA5500FF00FF000000FF00000000000000FFFF0000
AAFFAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AAFFFF00000000FF00
00FF0000FFAAAAAAFF00FFAAAA000000AAAAFF00FFAAAAAAFF0000FF0000FF00000000FF
FFAA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFFFFFF00FF000000
FFFFFF000000AA000000FFAAFFFF00FFFFAAFF000000AA000000FFFFFF000000FF00FFFF
FFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00AAFF000000FF00
00000000FF0000AA55000000AAFF00FFAA00000055AA0000FF0000000000FF000000FFAA
00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005555FFFF000000
FF0000FFFFFF0000AAAAAAFFAAFF00FFAAFFAAAAAA0000FFFFFF0000FF000000FFFF5555
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAFF00FF00
0000FFFFFFFFFF0000AA000000AAFFAA000000AA0000FFFFFFFFFF000000FF00FFAA00AA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAFF000000
FF00000000000000FFFFAAAAAAFFFFFFAAAAAAFFFF00000000000000FF000000FFAAFFAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000005500
0000550000FFFF00000000AA0000000000AA00000000FFFF00005500000055000000AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF5500
005500FF00000000FF00FFFFAAAAAAAAAAFFFF00FF00000000FF0055000055FFAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0055
00AAAAFF00FFFF000000FFAA0000AA0000AAFF000000FFFF00FFAAAA005500FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055
FFFFAAFF00000000FF000000AA550055AA000000FF00000000FFAAFFFF5500AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
00FFAAFF00FFFF000000FF0000AAAAAA0000FF000000FFFF00FFAAFF00AAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
FFAA000000FFAA0055AA00FF0000AA0000FF00AA5500AAFF000000AAFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA0000FF000000AA55550000005500550000005555AA000000FF0000AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAFF00FF0000AAAA005500AAAAAA005500AAAA0000FF00FFAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFF000000FFFFAAFF550000AA000055FFAAFFFF000000FFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA0055AAFF00AA00FF55FFAAFF55FF00AA00FFAA5500AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAA000000555555FF00AA00FF555555000000AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFFAAAAAA00AAAA550055AAAA00AAAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA0000AA00555500FF00555500AA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAFFFF0055FFFFFF5500FFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF00AA5555FF5555AA00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA005555AA55AA555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA00AA00AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFAAFFAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 2.49686 0.588183 2.58417 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAFFFFAAAAAAAAAAAA5555AAAAFFAAAAAAAA000055AAAA55AA00AA00005555FFFFFF
FF55FFFFFF55AA55AA5500AA0055555500AA0055AA55AA55FFFFFF55FFFFFFFF55550000
AA00AA55AAAA550000AAAAAAAAFFAAAA5555AAAAAAAAAAAAFFFFAAAAFF
FFFFAA0000AAFF00AA55AA00AAAA550055AA00FFAA55FF00AA5555FFFFAAAAAA00AA0000
AA00AA0000AAAA5555FF00FFAAAA00AAAAFF00FF5555AAAA0000AA00AA0000AA00AAAAAA
FFFF5555AA00FF55AAFF00AA550055AAAA00AA55AA00FFAA0000AAFFFF
FFFFFFAAAAFFFFFF5555AAAAAA55AA55FF000000AA55550000FF550055555555FFFFAAAA
FF00FFAAAAFF00AAAA00005555FF55FF55550000AAAA00FFAAAAFF00FFAAAAFFFF555555
550055FF00005555AA000000FF55AA55AAAAAA5555FFFFFFAAAAFFFFFF
FFFFFFFFAA0000AA00AAAA55AA00AA555500000000FF55000000AAAAAA00AAAA0000AA55
00550055AA000000FFAAAAAA00AA00AA00AAAAAAFF000000AA5500550055AA0000AAAA00
AAAAAA00000055FF000000005555AA00AA55AAAA00AA0000AAFFFFFFFF
FFFFFFFFFFAAAAFFFF5555FF000000FF550000000000AAAAAAAAAA55AAAAFF00000000FF
55AA55FF0000000000AA55AAAAFF00FFAAAA55AA0000000000FF55AA55FF00000000FFAA
AA55AAAAAAAAAA000000000055FF000000FF5555FFFFAAAAFFFFFFFFFF
FFFFFFFFFFFFAA0000AAAA0000000000AAAAAAAAAAAAAA55AAAA55AA55AA000000000000
AAAA5555000000000055AA55AA000000AA55AA5500000000005555AAAA000000000000AA
55AA55AAAA55AAAAAAAAAAAAAA0000000000AAAA0000AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAFFFFAAAAAAAAAAAA55AAAA55AAAA55555555AAAA00FFFF55FFFF00
FFAA00AAAAAAAAFFAA5555FF0000000000FF5555AAFFAAAAAAAA00AAFF00FFFF55FFFF00
AAAA55555555AAAA55AAAA55AAAAAAAAAAAAFFFFAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA0000AAFF00AA55AA00AA55AA5500AAAA00AAAA550000AA00AA0000
00AAFF555555555500AAAA00000000000000AAAA005555555555FFAA000000AA00AA0000
55AAAA00AAAA0055AA55AA00AA55AA00FFAA0000AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAFFFFFF5555AAAAAA555555AAFFFFAA5500AAAAAAFFFF000000
5500AA00AAAA00AAAAAA550000000000000055AAAAAA00AAAA00AA0055000000FFFFAAAA
AA0055AAFFFFAA555555AAAAAA5555FFFFFFAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA0000AA00AAAA55AA00AAAA00555500AAAAAA5500AA00000000
55FFFFAA55AAAAAA5500AAAAFFAAAAAAFFAAAA0055AAAAAA55AAFFFF5500000000AA0055
AAAAAA00555500AAAA00AA55AAAA00AA0000AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFFFF5555FF000000FFAA5555AAFF0000FF55AAAAAAFFAA
AA0000AA5555555555AAFF0000AA55AA0000FFAA5555555555AA0000AAAAFFAAAAAA55FF
0000FFAA5555AAFF000000FF5555FFFFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA0000AAAA0000000000AA5555AA00000000AAAA55AA0000
FFAAAAAA5555AA5555AA00000055AA55000000AA5555AA5555AAAAAAFF0000AA55AAAA00
000000AA5555AA0000000000AAAA0000AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFFAAAAAAAAAAAA5555AAAAFFAAAAAA55AA550000
00AAFF00AAAA0055FF0000005500FF0055000000FF5500AAAA00FFAA00000055AA55AAAA
AAFFAAAA5555AAAAAAAAAAAAFFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AAFF00AA55AA00AAAA550055AA00FF5555AAFF
55AA000055AAAAAA0000005500FFFFFF0055000000AAAAAA550000AA55FFAA5555FF00AA
550055AAAA00AA55AA00FFAA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFFFF5555AAAAAA55AA55FF000000AAAA0055
55AAAAAAAA0055AAAAAAFF550000AA000055FFAAAAAA5500AAAAAAAA555500AAAA000000
FF55AA55AAAAAA5555FFFFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AA00AAAA55AA00AA555500000000FFAA55
55AAAA55AAAAAA00FF0000AAAAFFAAFFAAAA0000FF00AAAAAA55AAAA5555AAFF00000000
5555AA00AA55AAAA00AA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFF5555FF000000FF550000000000AA55
55AAAA55555555FFFFFF55AA0055555500AA55FFFFFF55555555AAAA5555AA0000000000
55FF000000FF5555FFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AAAA0000000000AAAAAAAAAAAAAA55
55AAAA5555AA5555005555AAAAAA00AAAAAA5555005555AA5555AAAA5555AAAAAAAAAAAA
AA0000000000AAAA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFFAAAAAAAAAAAA55AAAA55AAAA55
55AAAA5555AA00AAAAAA00AA55AAAAAA55AA00AAAAAA00AA5555AAAA5555AAAA55AAAA55
AAAAAAAAAAAAFFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AAFF00AA55AA00AA55AA5500AA
AA0055AA5555FFFFAAFFFF00AAAA55AAAA00FFFFAAFFFF5555AA5500AAAA0055AA55AA00
AA55AA00FFAA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFFFF5555AAAAAA555555AAFF
FFAA5555FF00555500AA000055AA00AA550000AA00555500FF5555AAFFFFAA555555AAAA
AA5555FFFFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AA00AAAA55AA00AAAA0055
5500AAAA000055FF00FFAA55FF000000FF55AAFF00FF550000AAAA00555500AAAA00AA55
AAAA00AA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFF5555FF000000FFAA55
55AAFFFFAAAAAA000000AA55550000005555AA000000AAAAAAFFFFAA5555AAFF000000FF
5555FFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AAAA0000000000AA55
55AA0000AAFF0000000000FF5500000055FF0000000000FFAA0000AA5555AA0000000000
AAAA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFFAAAAAAAAAAAA55
55AAAAFFAA00000000000000AAAAAAAAAA00000000000000AAFFAAAA5555AAAAAAAAAAAA
FFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AAFF00AA55AA00
AAAA550055AAFFAAAAAAFF55AAAA55AAAA55FFAAAAAAFFAA550055AAAA00AA55AA00FFAA
0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFFFF5555AAAA
AA55AA55FF0000AA5500AA00AA55AA55AA00AA0055AA0000FF55AA55AAAAAA5555FFFFFF
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AA00AAAA55
AA00AA5555000000FF55AAAAAA555555AAAAAA55FF0000005555AA00AA55AAAA00AA0000
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFF5555FF
000000FF5500000000AAAA55AAAA00AAAA55AAAA0000000055FF000000FF5555FFFFAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AAAA00
00000000AAAAAAAAAAAA55AA55AAAAAA55AA55AAAAAAAAAAAA0000000000AAAA0000AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFFAA
AAAAAAAAAA55AA0055AA00AA5555FF5555AA00AA5500AA55AAAAAAAAAAAAFFFFAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AA
FF00AA55AA00AA55FF000000FF550055FF000000FF55AA00AA55AA00FFAA0000AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF
FFFF5555AAAAAA555500000000AAAAAA000000005555AAAAAA5555FFFFFFAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00
00AA00AAAA55AA00AAAAAAAAAAAA55AAAAAAAAAAAA00AA55AAAA00AA0000AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAFFFF5555FF000000FFAA0055AA00AA5500AAFF000000FF5555FFFFAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA0000AAAA0000000000AA55FF000000FF55AA0000000000AAAA0000AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAFFFFAAAAAAAAAAAA55550000005555AAAAAAAAAAAAFFFFAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA0000AAFF00AA55AA00AAAAFFAAAA00AA55AA00FFAA0000AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAAFFFFFF5555AAAAAA550055AAAAAA5555FFFFFFAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA0000AA00AAAA5500AAAAAA0055AAAA00AA0000AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAFFFF5555FF00FFAAFF00FF5555FFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA0000AAAA00005555550000AAAA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAFFFFAAAAAA00AAAAAAFFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA0000AAFF000000FFAA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAFFFFFF55FFFFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA0000AA00AA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFF00FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 2.49686 0.782187 2.58417 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAA5500AA00AAAA5555AA55550055AAAA005500005555000000FF00AAAAAAAA00AAFFFF
5555FFAA000055AA00AAAA55AAAAAAAAAA55AAAA00AA550000AAFF5555FFFFAA00AAAAAA
AA00FF000000555500005500AAAA55005555AA5555AAAA00AA0055AAFF
FFFFAA005500AA00000000AAFF000000555555FFFF5555FFAAAAAA00550000AA005555AA
55AAAA0000FF00AA00550000005500550000005500AA00FF0000AAAA55AA555500AA0000
5500AAAAAAFF5555FFFF555555000000FFAA00000000AA005500AAFFFF
FFFFFFAA55AA0000FFFF0000AAAAAAAAAA55AAAA00AAFF0055550000FFAA550000FFAA00
0000AA0055AA550055AAAAAAAAFF00FFAAAAAAAA550055AA5500AA000000AAFF000055AA
FF0000555500FFAA00AAAA55AAAAAAAAAA0000FFFF0000AA55AAFFFFFF
FFFFFFFFAA0000FFFFFFFF0000550055000000AA005555AA00FFAAAAAA000000FF005500
AA550000FFAAFF000000550000AAAAAA000055000000FFAAFF000055AA005500FF000000
AAAAAAFF00AA555500AA0000005500550000FFFFFFFF0000AAFFFFFFFF
FFFFFFFFFFAA5500FF5500FF000000FFAAAAAAFFFF00AAFFFF5500005555555555AAFF00
00AAFFAA555500FFFF000000FFFFAAFFFF000000FFFF005555AAFFAA0000FFAA55555555
55000055FFFFAA00FFFFAAAAAAFF000000FF0055FF0055AAFFFFFFFFFF
FFFFFFFFFFFFAA0055FF55FF0000FF0055000055FF0000AAAA00FF00000000000000AAAA
AAFFFFFFAA00FF0055FFAAAAAA00AA00AAAAAAFF5500FF00AAFFFFFFAAAAAA0000000000
0000FF00AAAA0000FF5500005500FF0000FF55FF5500AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA55AA55AA5500AAAAFF00FF00AAAAAAFFFFAA55555555555555555500
5500FF550000FF55AAAA0000AA005500AA0000AAAA55FF000055FF005500555555555555
555555AAFFFFAAAAAA00FF00FFAAAA0055AA55AA55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA000000AAFFAAFFFFFF5500AA0000AAAA0000000000000000000000
FFAAAA00FF00FF55550000FFFFAA55AAFFFF00005555FF00FF00AAAAFF00000000000000
00000000AAAA0000AA0055FFFFFFAAFFAA000000AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA5500AA00AA00AAAA00FFFFAAAAFFFFAAAAAAAAAAAAAAAAAAAAAA
AA0000AA555555AAAA5500AAAA000000AAAA0055AAAA555555AA0000AAAAAAAAAAAAAAAA
AAAAAAAAFFFFAAAAFFFF00AAAA00AA00AA0055AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA005500AA00550000FF550000AAAA0000550055005555005500
00AA5500000000005555FFAAFFFF00FFFFAAFF5555000000000055AA0000550055550055
00550000AAAA000055FF00005500AA005500AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55AA0000FFAAAAAA00FF0000AA0055AAAAFF00000000FFAA
55000000FFFF0000FFAA00AA00AAAAAA00AA00AAFF0000FFFF00000055AAFF00000000FF
AAAA5500AA0000FF00AAAAAAFF0000AA55AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA0000FFFFFFAAFFFF0055AAFFFF55550055FFAAAAAAAA00
0000FFFF5500FFFF005500AA0055005500AA005500FFFF0055FFFF000000AAAAAAAAFF55
005555FFFFAA5500FFFFAAFFFFFF0000AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FF550055FF000000AAAA00FFAAAA555500550000
FFFF5500FFAA5555AAFF000055AAAAAA550000FFAA5555AAFF0055FFFF000055005555AA
AAFF00AAAA000000FF550055FF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FF55FF5500AA550000AA555500000000FFAAAA
AA00AAFF550000000055FFFF5555005555FFFF550000000055FFAA00AAAAAAFF00000000
5555AA000055AA0055FF55FF5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA55AA55AA000000FFFFAA00FF00FFFF550000
AA005500FFAAAAAAAAFF0055FF555555FF5500FFAAAAAAAAFF005500AA000055FFFF00FF
00AAFFFF000000AA55AA55AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000AAFFFF55FFFFFFFFAAAA0055FF00AA55
0000FFAAAA0000555500FF00AAAA55AAAA00FF0055550000AAAAFF000055AA00FF5500AA
AAFFFFFFFF55FFFFAA000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AA00AAAA5555AA55550055AAAA005555
FFFF55005500AA55AAAAAA00550000005500AAAAAA55AA00550055FFFF555500AAAA5500
5555AA5555AAAA00AA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005500AA00000000AAFF000000555555FF
5500FFAA55AA000000550000FFAAAAAAFF000055000000AA55AAFF0055FF555555000000
FFAA00000000AA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA0000FFFF0000AAAAAAAAAA55AAAA
00FFFFFFAA0000FF000000FF0055005500FF000000FF0000AAFFFFFF00AAAA55AAAAAAAA
AA0000FFFF0000AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000FFFFFFFF0000550055000000AA
0055FF005500AA5555555555AAFF00FFAA5555555555AA005500FF5500AA000000550055
0000FFFFFFFF0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FF5500FF000000FFAAAAAAFF
FF00AAAAAA5500000000000000AAAAAA0000000000000055AAAAAA00FFFFAAAAAAFF0000
00FF0055FF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FF55FF0000FF0055000055
FF000055000000FF0000FF00FFFFAAFFFF00FF0000FF000000550000FF5500005500FF00
00FF55FF5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA55AA5500AAAAFF00FF00
AAAAAAFF0000FFFFFF55FF00FF550055FF00FF55FFFFFF0000FFAAAAAA00FF00FFAAAA00
55AA55AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000AAFFAAFFFFFF5500
AA000055FFAAAA00AAAA555555AAAAAA555555AAAA00AAAAFF550000AA0055FFFFFFAAFF
AA000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AA00AA00AAAA00FF
FFAAAAFF00555500AA0000000000550000000000AA00555500FFAAAAFFFF00AAAA00AA00
AA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005500AA00550000FF
550000AAAAAA55AAFFFF0000FF000000FF0000FFFFAA55AAAAAA000055FF00005500AA00
5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA0000FFAAAAAA
00FF00005500000055FF00FFFFFF00FFFFFF00FF55000000550000FF00AAAAAAFF0000AA
55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000FFFFFFAAFF
FF0055AA00FF00FF00AAAAAA00AAAAAA00AAAAAA00FF00FF00AA5500FFFFAAFFFFFF0000
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FF550055
FF000000AA555555AA0000AA0055005500AA0000AA555555AA000000FF550055FF0055AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FF55FF
5500AA55000000000055AAFFFF555555FFFFAA55000000000055AA0055FF55FF5500AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA55AA
55AA000000FFFF00FF00AA00AAAA55AAAA00AA00FF00FFFF000000AA55AA55AA55AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000
AAFFFF55FFFFFFFF5500AA00550000005500AA0055FFFFFFFF55FFFFAA000000AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500
AA00AAAA5555AA5555FFAAFF5555555555FFAAFF5555AA5555AAAA00AA0055AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00
5500AA00000000AAFF005555AAAA55AAAA555500FFAA00000000AA005500AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
55AA0000FFFF0000AAAAFF00AA000000AA00FFAAAA0000FFFF0000AA55AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA0000FFFFFFFF00005555AAFFFF00FFFFAA55550000FFFFFFFF0000AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAA5500FF5500FF0000000055FF00FF5500000000FF0055FF0055AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA0055FF55FF0000FFFF00AAAAAA00FFFF0000FF55FF5500AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA55AA55AA5500AAAA0055005500AAAA0055AA55AA55AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA000000AAFFAAFFFF555555FFFFAAFFAA000000AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA5500AA00AA00AAAA55AAAA00AA00AA0055AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA005500AA00550000005500AA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA55AA0000FFAAAAAAFF0000AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA0000FFFFFFAAFFFFFF0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA5500FF550055FF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA0055FF55FF5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55AA55AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 2.49686 0.97619 2.58417 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAA00FFFF5555AA0055555500FF55FF00AA550055FFFF000055FF00000000FFFFFF0000
AAAAAAFFFFFFFFFFAAAA000000FF55FF000000AAAAFFFFFFFFFFAAAAAA0000FFFFFF0000
0000FF550000FFFF550055AA00FF55FF0055555500AA5555FFFF00AAFF
FFFFAA0055AA5555000000000055AA550000AAAA55555555FF5500AAFF00FFFFFFFFFF55
5500555555555555550055000055AA550000550055555555555555005555FFFFFFFFFF00
FFAA0055FF55555555AAAA000055AA5500000000005555AA5500AAFFFF
FFFFFFAA00AA00AAAAAAAAAAAAAA00000055005555AA5555AA00AAFFFFFF0000FF0000FF
5500000000000000000055FFFF550055FFFF5500000000000000000055FF0000FF0000FF
FFFFAA00AA5555AA55550055000000AAAAAAAAAAAAAA00AA00AAFFFFFF
FFFFFFFFAA00005555005555005555FFFF5500000000AAAA00005555555555FFFFFF5555
55AAAAAAFF00FFAAAAAAAA0055AA55AA5500AAAAAAAAFF00FFAAAAAA555555FFFFFF5555
5555550000AAAA0000000055FFFF55550055550055550000AAFFFFFFFF
FFFFFFFFFFAA00FF550000000055FF0000FF5555FF5555005500000000000000FF000000
0000AA0000FFFFFFAAFFFFAA00AA00AA00AAFFFFAAFFFFFF0000AA0000000000FF000000
0000000055005555FF5555FF0000FF550000000055FF00AAFFFFFFFFFF
FFFFFFFFFFFFAA0055FF55FFAAAA00550000FF5500AAAA00FF5555FF5555FFFF00005500
005500550000FF0000AA550055005500550055AA0000FF00005500550000550000FFFF55
55FF5555FF00AAAA0055FF00005500AAAAFF55FF5500AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA00AA555555005500FFFF00000055550000FF5500AAAA0055AAFF0055
00000055FFFF0000550055FF5500000055FF5500550000FFFF550000005500FFAA5500AA
AA0055FF00005555000000FFFF005500555555AA00AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA000000000055FFFFFFFF55AAAA00AAFF0000005555000000AA55FF
00FFFF5500AA55FF55000000FF55FF55FF00000055FF55AA0055FFFF00FF55AA00000055
55000000FFAA00AAAA55FFFFFFFF550000000000AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA00FFFF5555AA0055AA00AA0000555555FFFF5500FFFF555500FF
00FF0000005555AA00AAFFAA5500FF0055AAFFAA00AA5555000000FF00FF005555FFFF00
55FFFF5555550000AA00AA5500AA5555FFFF00AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA0055AA5555000000AAFFFF00FF5500FF00000055AA00AAAA55
0000FFFF00AAAA000055555500FFFFFF005555550000AAAA00FFFF000055AAAA00AA5500
0000FF0055FF00FFFFAA0000005555AA5500AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00AA00AAAAAAAAFFFFFFFF00000055AAAAAA55550000AA00
AAFF0000FFAAFFFF00FF5500FFFFFFFFFF0055FF00FFFFAAFF0000FFAA00AA00005555AA
AAAA55000000FFFFFFFFAAAAAAAA00AA00AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA0000555500555555555555FFFF0055550055FF00FFFFAA
0000FFFF0000AA550000FF55555555555555FF000055AA0000FFFF0000AAFFFF00FF5500
555500FFFF5555555555550055550000AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF550000000000000000FF00FF55000000FFFFFFFF
AA00FF0000550055FFFF000000000000000000FFFF5500550000FF00AAFFFFFFFF000000
55FF00FF000000000000000055FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FF55FFAAAAAAFFAA550000FF5555FFFFFFFFFF
FFAA55000055FF5500AA55FFAAAAAAAAAAFF55AA0055FF55000055AAFFFFFFFFFFFF5555
FF000055AAFFAAAAAAFF55FF5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA5555550055555500FFFF00000000FF0000FF
0000AAAA55FF0000005555AA0000AA0000AA5555000000FF55AAAA0000FF0000FF000000
00FFFF0055555500555555AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000000055FF005500AA55FFFF555555FFFF
FF00AA000000FFFF00AAAA00005500550000AAAA00FFFF000000AA00FFFFFF555555FFFF
55AA005500FF550000000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF5555AA00FF555500FF0000000000FF
00005555FFFF0000FFAAFFFF55AA55AA55FFFFAAFF0000FFFF55550000FF0000000000FF
005555FF00AA5555FFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AA55550000FF550000FFAAAAFFAA55
000055FF0000FFAA550055AA00AA00AA00AA550055AAFF0000FF55000055AAFFAAAAFF00
0055FF00005555AA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA00AAAAAA5500FFFF0000AA005555
AAFF0055AAAA550055FF550055005500550055FF550055AAAA5500FFAA555500AA0000FF
FF0055AAAAAA00AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000055550055FFFFFFFF00AA00FF55
0055AAAA0000AAAAAA0055FF5500000055FF5500AAAAAA0000AAAA550055FF00AA00FFFF
FFFF550055550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF55000000FF0000FFFFAA0055
FF55005555FFAAFFFFAA555555AAAAAA555555AAFFFFAAFF55550055FF5500AAFFFF0000
FF00000055FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FF55FFFFFF555555550000
00FF5555AA550055AA0000000000AA0000000000AA550055AA5555FF00000055555555FF
FFFF55FF5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA5555555555AA5555AAAA
FF00000000AAAAAA00005500005500550000550000AAAAAA00000000FFAAAA5555AA5555
555555AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00000000000000AAAA0000
AA55FFFF5555005555FF55000055FF55000055FF5555005555FFFF55AA0000AAAA000000
00000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF5555FFFFAAFF55
5500FF0000000055FF0000005500FF0055000000FF5500000000FF005555FFAAFFFF5555
FFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AA5555555500AA
AA00FF00AAFF55AA5500005500FFFFFF0055000055AA55FFAA00FF00AAAA0055555555AA
5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA00AAAA00AAFF
FFAA550000AA555500FFFF550000FF000055FFFF005555AA000055AAFFFFAA00AAAA00AA
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000055550000AA
550055FF555500FF55AA0055FF555555FF5500AA55FF005555FF550055AA000055550000
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF55000055
55AAAA0055FF00FF005555FF0000000000FF555500FF00FF5500AAAA5555000055FF00AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FF55AA
5555005500FF00FF00FF5500AAFF55FFAA0055FF00FF00FF0055005555AA55FF5500AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA5555
00FF55FF00FF00FF00FF00550055AA55005500FF00FF00FF00FF55FF005555AA00AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000
0055AA550000FFFFFF000055FF550055FF550000FFFFFF000055AA5500000000AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF
FF550055FF5555555555FF5500AAAAAA0055FF5555555555FF550055FFFF00AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00
55AA55FF00000000000000FF5555005555FF00000000000000FF55AA5500AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
00AA00AA55FFAA55AAAAAA5500FF55FF0055AAAAAA55AAFF55AA00AA00AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA00005555AA000000AA00000055AA55000000AA000000AA55550000AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAA00FF55005500005555FFFF550055FFFF55550000550055FF00AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA0055FF55000055FF0000FF55FF0000FF55000055FF5500AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA00AA5555FF5500AAFF000000FFAA0055FF5555AA00AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA00000000FF555500AAFFAA005555FF00000000AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA00FFFF0000000055555500000000FFFF00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA0055AAAAFF5555AA5555FFAAAA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA00AA0000FF550055FF0000AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00005500AAAAAA00550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA00FF5555005555FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA0055FF00FF5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00AA55AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 2.5929 0.200176 2.68021 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAAA55FF00FF55AAAAAAAAAAAA55FFFF00FF00FFFFFF00AAFFFFFF55000000FF55
55AA5500FF5500AAAAAAAA55000000000055AAAAAAAA0055FF0055AA5555FF00000055FF
FFFFAA00FFFFFF00FF00FFFF55AAAAAAAAAAAA55FF00FF55AAAAAAAAFF
FFFFAA00FFAA555500FF00AAFFFFAAFF0000000055FFFFFFFFFF5555AA5555550000AAAA
AAAA550055FFAAAA55AAAA55005500550055AAAA55AAAAFF550055AAAAAAAA0000555555
AA5555FFFFFFFFFF5500000000FFAAFFFFAA00FF005555AAFF00AAFFFF
FFFFFFAAAA00FF0000AAAAFF0055FF550055550055AA5555AA55555555FFAA55005555FF
5555FFAAAAAA00FFAA55AAAAAAFF55FFAAAAAA55AAFF00AAAAAAFF5555FF55550055AAFF
55555555AA5555AA550055550055FF5500FFAAAA0000FF00AAAAFFFFFF
FFFFFFFFAA0000005555FF550055AA550055AA0000FFAA55FF55AA0055AA55AA0000FFFF
FF00FF5555FF55FF00AA55AAAA555555AAAA55AA00FF55FF5555FF00FFFFFF0000AA55AA
5500AA55FF55AAFF0000AA550055AA550055FF5555000000AAFFFFFFFF
FFFFFFFFFFAAAAFFAA55FF000055AAAAAAFF55550055FF55AA55FF55FFAAFF5555000000
0000AAAAAAAA0055FFFFAA55AAAAAAAAAA55AAFFFF5500AAAAAAAA00000000005555FFAA
FF55FF55AA55FF55005555FFAAAAAA550000FF55AAFFAAAAFFFFFFFFFF
FFFFFFFFFFFFAA00AAFF5500555555FF5555AA005500AAAAAA55FF00FF5555AA00555500
005555FF5555FFFF0055FF55AAAA55AAAA55FF5500FFFF5555FF55550000555500AA5555
FF00FF55AAAAAA005500AA5555FF5555550055FFAA00AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA55555500AA55FF0000FFAAAAAAFFFFAAFF55000000FFFFAAAAAAAA
FFAA55FF00FFFFFFFF55AA55FF555555FF55AA55FFFFFFFF00FF55AAFFAAAAAAAAFFFF00
000055FFAAFFFFAAAAAAFF0000FF55AA00555555AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA0055AAFFAAFF55005555AAAA55AA5555FF0000555500FF5555FF55
55AAAAAA000000000000FFAA5555555555AAFF000000000000AAAAAA5555FF5555FF0055
550000FF5555AA55AAAA55550055FFAAFFAA5500AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAA5555FF000055AA00FFAA55AAFF550000AA55FFFFFF00FF55
AA00FFAA00005500005555AAAAAAAAAAAAAA55550000550000AAFF00AA55FF00FFFFFF55
AA000055FFAA55AAFF00AA550000FF5555AAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA00FF000000555555FFFFFFAA55AA55FFFF555555AA555500FF
00AA00AAFFAAAAAAFFAA55FF5555FF5555FF55AAFFAAAAAAFFAA00AA00FF005555AA5555
55FFFF55AA55AAFFFFFF555555000000FF00AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA00005555555555AA5555FFAA0055FF00FF00FFAA550055
FFFFAAAA5555FF5555AAAAAA0055AA5500AAAAAA5555FF5555AAAAFFFF550055AAFF00FF
00FF5500AAFF5555AA55555555550000AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA000055AAFF55AAFF00FFFFFFAAAAAA000000AAAA55FFFF
0055FF55555555AAFF5555FF55FFAAFF55FF5555FFAA55555555FF5500FFFF55AAAA0000
00AAAAAAFFFFFF00FFAA55FFAA550000AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF5555AAFF005555AA5555FF55550000AAFF000000
00AA555555555555FF0000FF55AA55AA55FF0000FF555555555555AA00000000FFAA0000
5555FF5555AA555500FFAA5555FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA55FF550055AAFF00FF0055AAFFAAAA55550000
AA00FFFF00FFFF0000005555AA00FF00AA5555000000FFFF00FFFF00AA00005555AAAAFF
AA5500FF00FFAA550055FF55AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500FFFF55AAAA000000AA55AA55AAAAAAAAFF
AA00000000AAAA000055555555FFFFFF555555550000AAAA00000000AAFFAAAAAAAA55AA
55AA000000AAAA55FFFF0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005555AA55FF55550000AAFF555555FF5555FF
00AA00005555FF55FFFF00FF0000000000FF00FFFF55FF55550000AA00FF5555FF555555
FFAA00005555FF55AA555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA55FF00FFFF55FF5500AA55FF0000FF
55FF55FFFF000000FF5500000055005500000055FF000000FFFF55FF55FF0000FF55AA00
55FF55FFFF00FF55AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFAA555500FF55AA55FFFFAA55550000
00FF55AA5555005555AAFFAAAAFF55FFAAAAFFAA5555005555AA55FF0000005555AAFFFF
55AA55FF005555AAFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FF0000AAAAAA5500FF5555555500
5555AAFFFF000055AA00FF5555FF00FF5555FF00AA550000FFFFAA55550055555555FF00
55AAAAAA0000FF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000005555FF55555500FF0000FFFF
55AA00FF5500555555FFFFFF00FF55FF00FFFFFF5555550055FF00AA55FFFF0000FF0055
5555FF5555000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAA55FF0000FFFF55000055FF
00FFAAAA005555555555AA555500FF005555AA555555555500AAAAFF00FF55000055FFFF
0000FF55AAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFF55005555AA550000AA55
5500FFAA0000FF0000FFFFAA55FFFFFF55AAFFFF0000FF0000AAFF005555AA000055AA55
550055FFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55555500AA55AAFFAAAA55
00AA00AAFFAAAA0000AAAA00FFFFFFFFFF00AAAA0000AAAAFFAA00AA0055AAAAFFAA55AA
00555555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AAFFAAFF5555AAAA55
FFFFAAAA5555FF55FFFFAA00000000000000AAFFFF55FF5555AAAAFFFF55AAAA5555FFAA
FFAA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA5555FF0000FFAAFF
5500FFAA0055AA5500FF555500005500005555FF0055AA5500AAFF0055FFAAFF0000FF55
55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF0000005555AAAA
005555AAAAFF55555500FF00005555550000FF00555555FFAAAA555500AAAA5555000000
FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA000055555555FF
55FFAA55AAAA0055AA0000005555555555000000AA5500AAAA55AAFF55FF555555550000
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000055AAFF55AA
5500FFAA55AAAAFF55550055555555555555005555FFAAAA55AAFF0055AA55FFAA550000
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF5555AAFF
0000AAAA55FF5555AA0055555555555555555500AA5555FF55AAAA0000FFAA5555FFAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA55FF55
005555FF55AA55FFAA0000FFFF00FF00FFFF0000AAFF55AA55FF55550055FF55AA00AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500FF
FF55AA00AA55AA00AAFFAAAA00AA00AA00AAAAFFAA00AA55AA00AA55FFFF0055AAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005555
AA55FF55FF55AAAAFFFFFFAAFFAAFFAAFFAAFFFFFFAAAA55FF55FF55AA555500AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA
AA55FF00FF55AAAA5555AA55AA55AA55AA55AA5555AAAA55FF00FF55AAAAAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00
FFAA555500FF00AAFF55AAAAAA55FF55AAAAAA55FFAA00FF005555AAFF00AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AA00FF0000AAAAFF0055AAAA55AA00AA55AAAA5500FFAAAA0000FF00AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA0000005555FF550055AAAA55FF55FF55AAAA550055FF5555000000AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAFFAA55FF000055AAAA55FF00FF55AAAA550000FF55AAFFAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA00AAFF55005500AAFF00FF55FF00FFAA00550055FFAA00AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAA55555500AA00FF55FF00FF55FF00AA00555555AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA0055AAFFAA000000FF55FF000000AAFFAA5500AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAA5555FFFF55FF00FF55FFFF5555AAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA00FF00000000FF55FF00000000FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA0000555500FF0055550000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA000055AA000000AA550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAFF5555005555FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA00AA550055AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA550055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 2.5929 0.39418 2.68021 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAA005500FFFFFF55AAAAAA5555005500AA55AA5555AA55FF55AA5555000000555555
55000055000000AA0055AA55550000005555AA5500AA0000005500005555555500000055
55AA55FF55AA5555AA55AA0055005555AAAAAA55FFFFFF005500AAAAFF
FFFFAA00005555555555AAAA55AA55550000AAFF5555AA55AA5500000055005555000055
0000AA00AA0000AAFFAA55AA5555005555AA55AAFFAA0000AA00AA000055000055550055
00000055AA55AA5555FFAA00005555AA55AAAA55555555550000AAFFFF
FFFFFFAAAAFF55AA5555AAAA55FF550000AA00FF0055FF55AAAAAAFFAAAA000055FFFF55
005555FFFFAAAAFFFFFFAA55AAFF55FFAA55AAFFFFFFAAAAFFFF55550055FFFF550000AA
AAFFAAAAAA55FF5500FF00AA000055FF55AAAA5555AA55FFAAAAFFFFFF
FFFFFFFFAA0055FF5500FFAA00AA55FFFF555500AA00AA5555FF555555FF55FFFF0000FF
55FFAA5500AAFFFFFFFFFFAA55AA00AA55AAFFFFFFFFFFAA0055AAFF55FF0000FFFF55FF
555555FF5555AA00AA005555FFFF55AA00AAFF0055FF5500AAFFFFFFFF
FFFFFFFFFFAAAA00550055AAAAFF0055AA00AAAAFFFF5555AA5500FF55AA00AA55005555
55AA00FFFF55555555555555FFAAFFAAFF55555555555555FFFF00AA5555550055AA00AA
55FF0055AA5555FFFFAAAA00AA5500FFAAAA55005500AAAAFFFFFFFFFF
FFFFFFFFFFFFAA00005555AAAA550055FF55FF55555555AAFF00555555AAAAFF005555AA
5555FFFFFFFF0055FFAA5555AA00FF00AA5555AAFF5500FFFFFFFF5555AA555500FFAAAA
55555500FFAA55555555FF55FF550055AAAA55550000AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAFF55AAAA55FFFF000055AAFF55AAFFFFFF55AA55FF55555500FFFF
AA5555555555550000FFAA5555FFFFFF5555AAFF0000555555555555AAFFFF00555555FF
55AA55FFFFFFAA55FFAA550000FFFF55AAAA55FFAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA0055FF5555AA005555000000FF5555555555AAAA00550000555555
55FFAA5555AAFF55FFFFFFAA5555555555AAFFFFFF55FFAA5555AAFF5555555500005500
AAAA5555555555FF000000555500AA5555FF5500AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA005500FFAAAA00AA0000AA5555AA55FFAAFFFF55005555AA55
55AA00FFFF00AA5555555555FF005500FF5555555555AA00FFFF00AA5555AA55550055FF
FFAAFF55AA5555AA0000AA00AAAAFF005500AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA0000555555FF55FF55FFFFAA5555FF000000FF005555AA55AA
5555FFFFFFFF5555AA5555AA5500550055AA5555AA5555FFFFFFFF5555AA55AA555500FF
000000FF5555AAFFFF55FF55FF5555550000AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFF55AA550000FFFFFFFFAA5555550055555500FFFFAA55
AA555555555555AA55AA5555FFAAAAAAFF5555AA55AA555555555555AA55AAFFFF005555
5500555555AAFFFFFFFF000055AA55FFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA0055FF5500555555555555FFAA5555000055FFFFFFFFAA
55AA5555AA5555AAAAAA55FF0000000000FF55AAAAAA5555AA5555AA55AAFFFFFFFF5500
005555AAFF5555555555550055FF5500AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00550055FF005500FFFFFFAA55FFFF55AA0055AA00
FF5555AA55AAFF5555FF55AA0000AA0000AA55FF5555FFAA55AA5555FF00AA5500AA55FF
FF55AAFFFFFF005500FF55005500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00005555AA00005555555555FF0000FF5555000000
AA5555AAAAAA5500FFFFFF00AA000000AA00FFFFFF0055AAAAAA5555AA0000005555FF00
00FF55555555550000AA55550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55AAAAFFAA55FFAA5555550055AAFF55FFFF
5555AA55AAAA55FFFFFFFFFF5555005555FFFFFFFFFF55AAAA55AA5555FFFF55FFAA5500
555555AAFF55AAFFAAAA55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FF555555FF00000055FFAAAAAA5500FF00
0055FF55AAAA55555555555555AAFFAA55555555555555AAAA55FF550000FF0055AAAAAA
FF55000000FF555555FF5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA005500FFFFFF55FFFF0000000000555555
005500AAAA55AA5555AA5555AAFFFFFFAA5555AA5555AA55AAAA00550055555500000000
00FFFF55FFFFFF005500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00005555555555AA00555500555500FF55
0055FFFFAAFF5555AA55AAFF5555555555FFAA55AA5555FFAAFFFF550055FF0055550055
5500AA55555555550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55AA5555AAAAFF5500550000AA55
5500FF000000FF55AAAAAA55000055000055AAAAAA55FF000000FF005555AA0000550055
FFAAAA5555AA55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FF5500FFAA00550055005555FF
0055555500555555AAAA55AAFFAAAAAAFFAA55AAAA5555550055555500FF555500550055
00AAFF0055FF5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00550055AAAAFF55FFAAAAAA00
5555AA555500FFFF00AAFF555555FF555555FFAA00FFFF005555AA555500AAAAAAFF55FF
AAAA55005500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00005555AAAA5500FF00AAFFFF
55AA55AA55FFFFFFFF555555AA555555AA555555FFFFFFFF55AA55AA55FFFFAA00FF0055
AAAA55550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55AAAA55FFFFFF555555
55AAAAAA555555555555AA55FF55AA55FF55AA555555555555AAAAAA55555555FFFFFF55
AAAA55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FF5555AA0055AA55FF
AA55AAAA5555AAFF5500000055AA55AA5500000055FFAA5555AAAA55AAFF55AA5500AA55
55FF5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA005500FFAAAAAA5555
55FFAA00FFFF00AA5555005555AAAAAA5555005555AA00FFFF00AAFF555555AAAAAAFF00
5500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000555555FF5555AA
555555FFFFFFFF5555AAFFAA5555FF5555AAFFAA5555FFFFFFFF555555AA5555FF555555
0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55AA5500FF55
55AA555555555555AAFFFFFFAA555555AAFFFFFFAA555555555555AA5555FF0055AA55FF
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FF550055AA
55FF5500005500FF5555555555FF00FF5555555555FF0055000055FF55AA550055FF5500
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00550055FF
55AA00AA0000555555AA5555AA550055AA5555AA5555550000AA00AA55FF55005500AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00005555AA
00AAFFAAFFAAAAAAAAAA55FFAAFF55FFAAFF55AAAAAAAAAAFFAAFFAA00AA55550000AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55AA
AAFF000000FFAA00FFAA00AA55AA00AA55AA00AAFF00AAFF000000FFAAAA55FFAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FF
55555500555555FFFFFFAAAA55FF55FF55AAAAFFFFFF55555500555555FF5500AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00
5500FFFF55AA5555555555FF55AA00AA55FF5555555555AA55FFFF005500AAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00
0055555555AAAAAAAAAA00AA55FF55FF55AA00AAAAAAAAAA555555550000AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAFF55AA5555FF5555FF55FF55AA00AA55FF55FF5555FF5555AA55FFAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA0055FF550000FF55AA00AA55FF55FF55AA00AA55FF000055FF5500AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAA005500555555AAAAFF00FF00FF00FFAAAA555555005500AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA00005555AA55FF55555500AA00555555FF55AA55550000AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAAFF55AAAA005500FF55FF55FF005500AAAA55FFAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA0055FF55550000AA555555AA00005555FF5500AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAA0055FFAAAAFF005500FFAAAAFF5500AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA000055AAAA5500550055AAAA550000AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAFF5555FFAAAAAAFF5555FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA0055FF0000000000FF5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA00555500555500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA00005500550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFF55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 2.5929 0.588183 2.68021 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAA55FFAAFF55FF0000FF555555555555FFAAFF55FFAAFFFFFFFFFFFFFF550055550055
FFAAAAFF55FFFFFFAA5555FFAA000000AAFF5555AAFFFFFF55FFAAAAFF550055550055FF
FFFFFFFFFFFFAAFF55FFAAFF555555555555FF0000FF55FFAAFF55AAFF
FFFFAA555500FFFFFF55FF00FFFF00FFFF0000AAAAAA0000FF0000FF0000FFFF5555FFFF
00555500FFFFFFFFFFAA55AA0000000000AA55AAFFFFFFFFFF00555500FFFF5555FFFF00
00FF0000FF0000AAAAAA0000FFFF00FFFF00FF55FFFFFF005555AAFFFF
FFFFFFAA55FFFFFFFFFF000000FF55FF000055005555000055FFFF55000055AA00FFFFFF
FF5555FFFFFFFFFFFFFFAA00000000000000AAFFFFFFFFFFFFFF5555FFFFFFFF00AA5500
0055FFFF550000555500550000FF55FF000000FFFFFFFFFF55AAFFFFFF
FFFFFFFFAA555555AA5500000000FFFFFF55FFAAAA55FFFF55AA5555FFFF55550000FF00
55FF5555AA55555555AA000055000000550000AA55555555AA5555FF5500FF00005555FF
FF5555AA55FFFF55AAAAFF55FFFFFF0000000055AA555555AAFFFFFFFF
FFFFFFFFFFAA55FFAAFF55FFFF55FF0000FFFFFFAAFF0055FFAAFF55AA5555FF55FFFFFF
555555FFAAFF5555FFAAFFAAAAAAFFAAAAAAFFAAFF5555FFAAFF555555FFFFFF55FF5555
AA55FFAAFF5500FFAAFFFFFF0000FF55FFFF55FFAAFF55AAFFFFFFFFFF
FFFFFFFFFFFFAA555500FFFFFFFF00000055FF0000AAAAFF550055FFAAFF555555FF0000
FFAA55AA0000FFFF00555555005555550055555500FFFF0000AA55AAFF0000FF555555FF
AAFF550055FFAAAA0000FF55000000FFFFFFFF005555AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA55FFFFFFFFFFFF55FFFF000055005555AAAAFF550055FFAA00FF55FF
FFFFAA00000000FF55FF5555FFFF00FFFF5555FF55FF00000000AAFFFFFF55FF00AAFF55
0055FFAAAA555500550000FFFF55FFFFFFFFFFFF55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA555555AA5500FFFFFFFF55FF55FF55550055AAAAFF55005500FFFF
FFFFFFAAAAFFAAAA00FF5555FF000000FF5555FF00AAAAFFAAAAFFFFFFFFFF00550055FF
AAAA55005555FF55FF55FFFFFFFF0055AA555555AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA55FFAAFF55FF0000FF555555FF00FFFF55550055AAAAFF55FF00
00FF5500555555005500FFFF0000000000FFFF0055005555550055FF0000FF55FFAAAA55
005555FFFF00FF555555FF0000FF55FFAAFF55AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA555500FFFFFF55FF00FFFF000055FF00FFFF55550055FF5500
0055AAAAFF55AAAAFF55FF00000000000000FF55FFAAAA55FFAAAA55000055FF55005555
FFFF00FF550000FFFF00FF55FFFFFF005555AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55FFFFFFFFFF000000FF55FFFF000000FF00FFFF55AA55FF
FF55550055FFAAFFFFFF000000000000000000FFFFFFAAFF55005555FFFF55AA55FFFF00
FF000000FFFF55FF000000FFFFFFFFFF55AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA555555AA5500000000FFFFFFFF55FFFFFF5500AAFFFF00
55AAAAAAFF550055FF0000000000000000000000FF550055FFAAAAAA5500FFFFAA0055FF
FFFF55FFFFFFFF0000000055AA555555AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAAFF55FFFF55FF0000FF55AA0055AAAAFFFFFFFF
5555005555AAAAFF55000000550000005500000055FFAAAA5555005555FFFFFFFFAAAA55
00AA55FF0000FF55FFFF55FFAAFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555500FFFFFFFF00000055FFAAFFAA0000AA555555
AAAAAAFF55550055AAAAFFAAAAAAFFAAAAAAFFAAAA55005555FFAAAAAA555555AA0000AA
FFAAFF55000000FFFFFFFF005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFFFFFFFF55FFFF0055555500005555FF55
5500555555FF55FFAAFFFFFFAAFFFFFFAAFFFFFFAAFF55FF555555005555FF5555000055
555500FFFF55FFFFFFFFFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555555AA5500FFFFFFFF55AAAAAAFFAA00FF55
55FFFF00FFFFFF005555AA00555555555500AA555500FFFFFF00FFFF5555FF00AAFFAAAA
AA55FFFFFFFF0055AA555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAAFF55FF0000FF5555005555550000FF
FF0055FFFFFFFFFF55AAFFFF5555FF5555FFFFAA55FFFFFFFFFF5500FFFF000055555500
5555FF0000FF55FFAAFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555500FFFFFF55FF00FFFF5555FF55FFFF
FFFF55AA0055AA00AAFFFFFFFF00FF00FFFFFFFFAA00AA5500AA55FFFFFFFF55FF5555FF
FF00FF55FFFFFF005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFFFFFF000000FF5555FF00AA55
5555AAFFFF55550000AAAA0055FFFFFF5500AAAA00005555FFFFAA555555AA00FF5555FF
000000FFFFFFFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555555AA5500000000FFFF000000AA
FF00AA0055AAAAAAFFAAFFFF5555AA5555FFFFAAFFAAAAAA5500AA00FFAA000000FFFF00
00000055AA555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAAFF55FFFF55FF0000000000
AAAAFFFF55550055555500AA55FFAAFF55AA00555555005555FFFFAAAA0000000000FF55
FFFF55FFAAFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555500FFFFFFFF000000000055
0055555555FF55FF5555FFFFAA550055AAFFFF5555FF55FF5555555500550000000000FF
FFFFFF005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFFFFFFFF55FFFF55FF
AAAAAAAAAAAA00FF5555FF0000AAFFAA0000FF5555FF00AAAAAAAAAAAAFF55FFFF55FFFF
FFFFFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555555AA5500FFFFFFFF00
00AA0000AA000000FFFF000000555555000000FFFF000000AA0000AA0000FFFFFFFF0055
AA555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAAFF55FF0000FF55
FFFFAAAAFFFF55FFFFFFFF55FFFF00FFFF55FFFFFFFF55FFFFAAAAFFFF55FF0000FF55FF
AAFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555500FFFFFF55FF00
FF55005555AA55FF0000FF00FF000000FF00FF0000FF55AA55550055FF00FF55FFFFFF00
5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFFFFFF0000
00FFFF55AAFFFF00000055FFFFFF55FFFFFF55000000FFFFAA55FFFF000000FFFFFFFFFF
55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555555AA550000
0000FF555500AAAAFFAAAAAA0055FF5500AAAAAAFFAAAA005555FF0000000055AA555555
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAAFF55FF
FF55FF00AAFFAAFFFFFFAAFFFF555555FFFFAAFFFFFFAAFFAA00FF55FFFF55FFAAFF55AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555500FFFF
FFFF000055555500FF0055555555FF5555555500FF005555550000FFFFFFFF005555AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFF
FFFFFF55FF5555FFFFFF5555FF555555FF5555FFFFFF5555FF55FFFFFFFFFFFF55AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555555
AA5500FFFFFF00FF0055FF555555FF555555FF5500FF00FFFFFF0055AA555555AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF
AAFF55FF0055FFFFFF555555FF555555FF555555FFFFFF5500FF55FFAAFF55AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55
5500FFFFFF5555555555FF555555FF555555FF5555555555FFFFFF005555AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
55FFFFFFFFFF00AAFF555555FF555555FF555555FFAA00FFFFFFFFFF55AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA555555AA550000AA55FF555555FF555555FF55AA000055AA555555AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAA55FFAAFF55FFFFAA5555FFAA00AAFF5555AAFFFF55FFAAFF55AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA555500FFFFFFFFAA55AA000000AA55AAFFFFFFFF005555AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA55FFFFFFFFFFFFAA0000000000AAFFFFFFFFFFFF55AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA555555AA5555550000000000555555AA555555AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA55FFAAFF5555FFFF55FFFF5555FFAAFF55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA555500FFFF0055FF5500FFFF005555AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA55FFFFFFFF555555FFFFFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55555555AAAAAA55555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA55FF5555005555FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA5555FF55FF5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55FF00FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 2.5929 0.782187 2.68021 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAA55550055FFFF55AA00005555550055550055555500AAAA0000AAAA55AA00FF0055FF
550000AAAA00FF550055AAFF0055555500FFAA550055FF00AAAA000055FF5500FF00AA55
AAAA0000AAAA00555555005555005555550000AA55FFFF55005555AAFF
FFFFAA55FFFF0000FFAAFFAAAAAAAAAA00FFAAAAAAAAAA0000AAAAFFFFAA000000FF5555
55FF00555500FF00FF555500AAAAAAAAAA005555FF00FF00555500FF555555FF000000AA
FFFFAAAA0000AAAAAAAAAAFF00AAAAAAAAAAFFAAFF0000FFFF55AAFFFF
FFFFFFAA5500AAAA00555555005555005500AA0000AA000055005555555500005500AAFF
555555AAAAAA005500AAFF00555500555500FFAA005500AAAAAA555555FFAA0055000055
55555500550000AA0000AA00550055550055555500AAAA0055AAFFFFFF
FFFFFFFFAA55550055FFAA55AA55FFAAAAAA00000000AAAA00FF55AAFF00AAAAFF550055
AAFF00AA0000AAAAAA0000FF55AAFFAA55FF0000AAAAAA0000AA00FFAA550055FFAAAA00
FFAA55FF00AAAA00000000AAAAAAFF55AA55AAFF55005555AAFFFFFFFF
FFFFFFFFFFAA55FFFF0000AAFFFF0000AA000055FF00555500FF00AA005500555555FF00
AA005500550000AA00005500AAFFFFFFAA00550000AA000055005500AA00FF5555550055
00AA00FF00555500FF550000AA0000FFFFAA0000FFFF55AAFFFFFFFFFF
FFFFFFFFFFFFAA5500AAAA0000FF0055005500FFFFFF5555FF00005555AAAA00FFAA5500
00AAAAAA00FF550055FFFF00555555555500FFFF550055FF00AAAAAA000055AAFF00AAAA
55550000FF5555FFFFFF0055005500FF0000AAAA0055AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA55550055FFFFFF55AA55FFFFFFFFFF00FF0055FF5555005500AA00FF
5500555500FF00FF55555555AAAAAAAAAA55555555FF00FF0055550055FF00AA00550055
55FF5500FF00FFFFFFFFFF55AA55FFFFFF55005555AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55FFFF0000FF00AA00FF0000FF000000FF555555FFAAAA55550000
FFFF5555FF000000FFFF00AAFFFFAAFFFFAA00FFFF000000FF5555FFFF00005555AAAAFF
555555FF000000FF0000FF00AA00FF0000FFFF55AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA5500AAAA0055005500AAAA0055000055AAAA55AA0000AAFF55FF
FFFFFF00FF005500FF000000AA550055AA000000FF005500FF00FFFFFFFF55FFAA0000AA
55AAAA5500005500AAAA0055005500AAAA0055AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA55550055FFAAAAAA0000AAAAAA00AAFFFFAA00000000AA55AA
0055AA00AA5555FF0000000000AAFFAA0000000000FF5555AA00AA5500AA55AA00000000
AAFFFFAA00AAAAAA0000AAAAAAFF55005555AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55FFFF0000AA000000555500550055AA000000000000AAFF
FF55550000AAFF000000000000555555000000000000FFAA00005555FFFFAA0000000000
00AA550055005555000000AA0000FFFF55AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA5500AAAA00000055FFAA00AAFFAA000000000000005555
5555FFAAAA0000FF55000055FFFF00FFFF55000055FF0000AAAAFF555555550000000000
0000AAFFAA00AAFF55000000AAAA0055AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAA55550055FFFF55AA0000555555000000000055FF00AA
FF55555500550000FFAAAA00FF000000FF00AAAAFF00005500555555FFAA00FF55000000
00005555550000AA55FFFF55005555AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFF0000FFAAFFAAAAAAAAAA00AAAAFFAA005500
55AAAAAAAAFF005500AA000000FF55FF000000AA005500FFAAAAAAAA55005500AAFFAAAA
00AAAAAAAAAAFFAAFF0000FFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AAAA0055555500555500550055555500FFFF
555500555500AAAAAA00005500FF00FF00550000AAAAAA005555005555FFFF0055555500
550055550055555500AAAA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55550055FFAA55AA55FFAAAAAAFF5555FFFFFF
FF00AAAAAAAA0000AA00AAAAAA005500AAAAAA00AA0000AAAAAAAA00FFFFFFFF5555FFAA
AAAAFF55AA55AAFF55005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFF0000AAFFFF0000AA0000FFFF0000FF
000000AA0000AAAA000055550055FF550055550000AAAA0000AA000000FF0000FFFF0000
AA0000FFFFAA0000FFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AAAA0000FF0055005500FF00000000
FF550000AAAA0000AAAAFF00FF555555FF00FFAAAA0000AAAA000055FF00000000FF0055
005500FF0000AAAA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55550055FFFFFF55AA55FF0000000000
00FFAAAA0000AAAA0000AA555555FF555555AA0000AAAA0000AAAAFF000000000000FF55
AA55FFFFFF55005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFF0000FF00AA00FF0055000000
5500AA0000005555000000AAFF555555FFAA0000005555000000AA00550000005500FF00
AA00FF0000FFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AAAA0055005500AAAAAAFFAA
AAAA00000055FFAA00AAAAFFFFFF00FFFFFFAAAA00AAFF55000000AAAAAAFFAAAAAA0055
005500AAAA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55550055FFAAAAAA0000AA0055
550055FFFF55AA000000AA0055AA00AA5500AA000000AA55FFFF5500555500AA0000AAAA
AAFF55005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFF0000AA0000005555AA
AAAAFF0000FFFFAAAAFFAAFFAA000000AAFFAAFFAAAAFFFF0000FFAAAAAA5555000000AA
0000FFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AAAA00000055FFAA00
00AA005500FF0000AA0055555500000055555500AA0000FF005500AA0000AAFF55000000
AAAA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55550055FFFF55AA0000
0000AAAAAA00550000AAAAAAAAAA00AAAAAAAAAA00005500AAAAAA00000000AA55FFFF55
005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFF0000FFAAFFAA
AA00AA0000AAAAAA00AA0000AA000000AA0000AA00AAAAAA0000AA00AAAAFFAAFF0000FF
FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AAAA00555555
005500550000AA000000AAAA0000000000AAAA000000AA00005500550055555500AAAA00
55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55550055FFAA55
AA55FF00FF550055FF0055550000000000555500FF550055FF00FF55AA55AAFF55005555
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFF0000AA
FFFF000000FFFF555555AAFF5500000055FFAA555555FFFF000000FFFFAA0000FFFF55AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AAAA00
00FF00550000FF00FFAA0000FFFF55FFFF0000AAFF00FF00005500FF0000AAAA0055AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55550055
FFFFFF55AA555555AA00000000FF00FF00000000AA555555AA55FFFFFF55005555AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFF
0000FF00AA00FFAA00000055FF000000FF55000000AAFF00AA00FF0000FFFF55AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500
AAAA0055005500AA00AAAAFF0000000000FFAAAA00AA0055005500AAAA0055AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55
550055FFAAAAAA000000AA00550000005500AA000000AAAAAAFF55005555AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
55FFFF0000AA0000000000AAAAAA00AAAAAA0000000000AA0000FFFF55AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA5500AAAA00000055000055550055005555000055000000AAAA0055AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAA55550055FFFF55AA5555FFAAAAAAFF5555AA55FFFF55005555AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA55FFFF0000FFAAFF55555500555555FFAAFF0000FFFF55AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA5500AAAA00555555FFAA00AAFF55555500AAAA0055AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA55550055FFAA55AA000000AA55AAFF55005555AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA55FFFF0000AAFFFF55FFFFAA0000FFFF55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA5500AAAA0000FF00FF0000AAAA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA55550055FF000000FF55005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55FFFF0000000000FFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA5500AAAA00AAAA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA55550055005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55FF00FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 2.5929 0.97619 2.68021 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAA00005555FFAAAAAA5500005555AA5555AA55000000AA00FF550055AAAA55AAFFAA55
00AA5555AA55555500AAAA55AAAAAAAAAA55AAAA00555555AA5555AA0055AAFFAA55AAAA
550055FF00AA00000055AA5555AA5555000055AAAAAAFF55550000AAFF
FFFFAA00FFFF00000055FFAAAA55FFAAFF55AA55FFFF55FF00AA55FF55AA55550000FF55
AAAA0000AAAAAAAAAAFFFFAA5555AA5555AAFFFFAAAAAAAAAA0000AAAA55FF00005555AA
55FF55AA00FF55FFFF55AA55FFAAFF55AAAAFF55000000FFFF00AAFFFF
FFFFFFAA0055AAAAFFAA550000555555AA00005555555500AAFFFF0000AAAAAAAA55AA00
0055FFFF550000000055AA00AA000000AA00AA550000000055FFFF550000AA55AAAAAAAA
0000FFFFAA00555555550000AA555555000055AAFFAAAA5500AAFFFFFF
FFFFFFFFAA00005500AAAAAA55AAFF55AA55AAAAAAAAAAAA55555555FF5500000000AAAA
FFAA5500AA00FFAAAA55FF00AAAAFFAAAA00FF55AAAAFF00AA0055AAFFAAAA0000000055
FF55555555AAAAAAAAAAAA55AA55FFAA55AAAAAA00550000AAFFFFFFFF
FFFFFFFFFFAA00FFFF5500FF55AA550055005500000000550055550055AAFFAAAA55AA55
5555AAFFAAFF00000000AA55AA555555AA55AA00000000FFAAFFAA555555AA55AAAAFFAA
550055550055000000005500550055AA55FF0055FFFF00AAFFFFFFFFFF
FFFFFFFFFFFFAA0055AAFF0000AAAAAAFF55FFAAAA55AAAAAA55FFAAAAAA00550000AAAA
AAAAAA005500AAFFAAAA55550000AA00005555AAAAFFAA005500AAAAAAAAAA00005500AA
AAAAFF55AAAAAA55AAAAFF55FFAAAAAA0000FFAA5500AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA000055AAAA5555AA550055AA555500000000AA5555AA55AAFFAA00AA
AA00AAAAFF5555AA00AAAAAAAA55AA55AAAAAAAA00AA5555FFAAAA00AAAA00AAFFAA55AA
5555AA000000005555AA550055AA5555AAAA550000AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00FFFFAAFF55AA55FF55AA55FFAAAAFFAA00AA00005555AA00AAFF
FFAAAA00AA55FFAAFF005500FF55AA55FF005500FFAAFF55AA00AAAAFFFFAA00AA555500
00AA00AAFFAAAAFF55AA55FF55AA55FFAAFFFF00AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA0055AA5500550055AAFFFF00000000FF5555AAAA55FFAAFF0055
AA00AAAAFFFF000000FFAA55AA000000AA55AAFF000000FFFFAAAA00AA5500FFAAFF55AA
AA5555FF00000000FFFFAA5500550055AA5500AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA00005555FFAAAAAA0055AAAAFFAA005555000000AA555555FF
AAFF005500AA55AAAA550000AAAAFFAAAA000055AAAA55AA005500FFAAFF555555AA0000
00555500AAFFAAAA5500AAAAAAFF55550000AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00FFFF00000055FF55AA555555AAAAAAAAFFAA00AA0000AA
555555FFAA00AA00AAAAAA55AA555555AA55AAAAAA00AA00AAFF555555AA0000AA00AAFF
AAAAAAAA555555AA55FF55000000FFFF00AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA0055AAAAFFAA5500550055550000000055AA55AA55AAAA
0000AA0055FFFFAA00AAAA000000AA000000AAAA00AAFFFF5500AA0000AAAA55AA55AA55
00000000555500550055AAFFAAAA5500AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAA00005500AAAAAA55FF55AAFF00AAFFAA55550000AAAA
00FFAAFFAA5500AAAAFFFFAAAAFFAAFFAAAAFFFFAAAA0055AAFFAAFF00AAAA00005555AA
FFAA00FFAA55FF55AAAAAA00550000AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF5500FF55AA000055AAAA0055005555FFFFAA
FF000000FF55AAAA00AA55000055AA55000055AA00AAAA55FF000000FFAAFFFF55550055
00AAAA550000AA55FF0055FFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AAFF0000AAAAFFAA5555AAAAAAFF55AA0055
00AAFFAA005555AA55AA55FFFF55AA55FFFF55AA55AA555500AAFFAA005500AA55FFAAAA
AA5555AAFFAAAA0000FFAA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000055AAAA5555AA00AA0000550000FFFFAAAA
AAFFFFFFAAAAAAAA000000AA5500550055AA000000AAAAAAAAFFFFFFAAAAAAFFFF000055
0000AA00AA5555AAAA550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFFAAFF55AA55AA55AAAAAA55AA005500
0000FF0000005500FFAA00FF55AAAAAA55FF00AAFF0055000000FF0000005500AA55AAAA
AA55AA55AA55FFAAFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AA5500550055005500005555AAAAAA
FF00AA55AAAA55FFFFFFAA005555AA555500AAFFFFFF55AAAA55AA00FFAAAAAA55550000
55005500550055AA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00005555FFAAAAAA55FF555500550000
00FFAAFF550000AA5500AAAAFF55AA55FFAAAA0055AA000055FFAAFF00000055005555FF
55AAAAAAFF55550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF000000550055AAFF55FFAAAA
55AA00AA55FF5555AAFF005500AA00AA005500FFAA5555FF55AA00AA55AAAAFF55FFAA55
0055000000FFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AAAAFFAA55AAFFFFFF000000
00AAAA555500AA000000FFAA55AA55AA55AAFF000000AA005555AAAA00000000FFFFFFAA
55AAFFAAAA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00005500AAAAAA0055AA00FFAA
AA5555AAFF5555AAAAFF000000AAAAAA000000FFAAAA5555FFAA5555AAAAFF00AA5500AA
AAAA00550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF5500FF55FFAAFF0000
0055550000FFFF005500AAFFAAAA00AAAAFFAA005500FFFF00005555000000FFAAFF55FF
0055FFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AAFF0000AA555555FF
FF55AAFFAA0055AAAAAA555555AA55AA555555AAAAAA5500AAFFAA55FFFF555555AA0000
FFAA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000055AAAA5555005555
55550000FF5555000055FFAA55FF00FF55AAFF5500005555FF000055555555005555AAAA
550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFFAAFF55AAAAAA
AAAAAA55AA0000AAFFAA550000AA55AA000055AAFFAA0000AA55AAAAAAAAAAAA55FFAAFF
FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AA5500550000
5500005555AAAA555555AAFFAA00AA00AAFFAA555555AAAA55550000550000550055AA55
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00005555FFAAAA
55FF555500550000AA000055AA55AA55AA550000AA000055005555FF55AAAAFF55550000
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF000000
00AA55FFAAAAAA55AA55AAAAAA000000AAAAAA55AA55AAAAAAFF55AA00000000FFFF00AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AAAAFF
AA00AA0055000000AAAAAA00AAAA55AAAA00AAAAAA0000005500AA00AAFFAAAA5500AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00005500
AAAA5555FFAAAA55AA5555AAAA00AA00AAAA5555AA55AAAAFF5555AAAA00550000AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF
5500FFFF0000550055005555AA55AA55AA5555005500550000FFFF0055FFFF00AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055
AAFF0000FFAAAAAAFF55550055FFAAFF55005555FFAAAAAAFF0000FFAA5500AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00
0055AAAA5500000000FFFF00AA005500AA00FFFF0000000055AAAA550000AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
00FFFFAAFF55FFFF55555555FF00AA00FF55555555FFFF55FFAAFFFF00AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA0055AA550055AA0000AA0000FFAAFF0000AA0000AA550055AA5500AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAA00005555FFAAFF00AAAAFF000000FFAAAA00FFAAFF55550000AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA00FFFF000000FFAAFFFFFF55FFFFFFAAFF000000FFFF00AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA0055AAAA55AA00AA5500AA0055AA00AA55AAAA5500AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA0000550055FFFFAA55AA55AAFFFF5500550000AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA00FFFF55AA00550055005500AA55FFFF00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA0055AAFFFF55AAAAAA55FFFFAA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA000055AA0000000000AA550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00FFFFAAAAFFAAAAFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA0055AA555555AA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA000000AA000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00FFAAFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 2.68894 0.200176 2.77625 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAAA000055FFFFFF0000FF00FFAA5555555555AA55AA555555FFFFFFFF55FFFFFF
FF55AAAA555555AAFFFFAAAAAAFFFFFFAAAAAAFFFFAA555555AAAA55FFFFFFFF55FFFFFF
FF555555AA55AA5555555555AAFF00FF0000FFFFFF550000AAAAAAAAFF
FFFFAAFFFFAAAAFF5555FF55FFFFFF5555AAFF55AAFF55005500555500AAFF000000FFAA
00FFFFAAFF55AAFFFFFFFFAAFFFFFFFFFFAAFFFFFFFFAA55FFAAFFFF00AAFF000000FFAA
00555500550055FFAA55FFAA5555FFFFFF55FF5555FFAAAAFFFFAAFFFF
FFFFFFAA005500FFAA55FF55AAAA55AAFF5500AA00AAFF55FFAAAAAAAAFFFFFF55FFFFFF
AAAA5500FF00FF5555555555AA00FF00AA5555555555FF00FF0055AAAAFFFFFF55FFFFFF
AAAAAAAAFF55FFAA00AA0055FFAA55AAAA55FF55AAFF005500AAFFFFFF
FFFFFFFFAAAAAAFF0055555500FF55AA55AAFFAAFFAAFF00FF0055FF0055AAAA55FF5555
55AA55FFFFFF55550055550055FFFFFF55005555005555FFFFFF55AA555555FF55AAAA55
00FF5500FF00FFAAFFAAFFAA55AA55FF0055555500FFAAAAAAFFFFFFFF
FFFFFFFFFFAAFFFFFF55AAFF55FF55AA55FF00AAAA5555FFFFFF55AAAAFF5500FFFFFF00
FFFFAA5500AA55FFAAAAAAAAFF555555FFAAAAAAAAFF55AA0055AAFFFF00FFFFFF0055FF
AAAA55FFFFFF5555AAAA00FF55AA55FF55FFAA55FFFFFFAAFFFFFFFFFF
FFFFFFFFFFFFAA0055AAFFFFFF0000005555FFFFAAFF55AAAA5500550000FFFF5555FF55
FF5555AAFFAAFF5555AA5555AA000000AA5555AA5555FFAAFFAA5555FF55FF5555FFFF00
00550055AAAA55FFAAFFFF5555000000FFFFFFAA5500AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA0055AAAAFFAAAAAAAA550000FFFFAAFF55FFAAAAFF00AA0000FF
FFFF00FF5555AAAAAAAA0000AAAAFFAAAA0000AAAAAAAA5555FF00FFFFFF0000AA00FFAA
AAFF55FFAAFFFF000055AAAAAAAAFFAAAA5500AAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF55AA555555AA5555AAFFAAAA55AA550055AA5555FFFFAAAAFF
00AAFFAA0000AAAA00AAAAFFAAFFFFFFAAFFAAAA00AAAA0000AAFFAA00FFAAAAFFFF5555
AA550055AA55AAAAFFAA5555AA555555AA55FFFFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA005555AAFF55AA55FFAAFF0055FFAAFF55FFAAFF55AAAA5555AA
AAFFFFFFAAAAFFFFAAAA00AAFFFFFFFFFFAA00AAAAFFFFAAAAFFFFFFAAAA5555AAAA55FF
AAFF55FFAAFF5500FFAAFF55AA55FFAA555500AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAAAA00FFFFAA5500FFAAAAAA55555500AAAA55FF00555500
FF5555FF5500FF000055FFFFAA00FF00AAFFFF550000FF0055FF5555FF00555500FF55AA
AA00555555AAAAAAFF0055AAFFFF00AAAAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFFFAAAA55AA55FFFFFFAAFFFF00FFFF5500FFFFFF55AAFF
AA0000AA55FFFFFF55FFAA00FF55FF55FF00AAFF55FFFFFF55AA0000AAFFAA55FFFFFF00
55FFFF00FFFFAAFFFFFF55AA55AAAAFFFFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA005500FFFFAA5500AAFFFFFFFF5555FFAAAA55AAAAAA00
FF55FFFFAA55AA00FFFFFFAAAA55FF55AAAAFFFFFF00AA55AAFFFF55FF00AAAAAA55AAAA
FF5555FFFFFFFFAA0055AAFFFF005500AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF00AAAAAAFFFFFFFFFFFF00FF0055FFAAFFFFAA
AA55FF5555AAFFFF5555FF5500FFFFFF0055FF5555FFFFAA5555FF55AAAAFFFFAAFF5500
FF00FFFFFFFFFFFFAAAAAA00FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF5500FF555555FF5555FFFFFF55AAAA00FFAA
FFFF0000000055AAAAAAAA55FFFFFFFFFF55AAAAAAAA5500000000FFFFAAFF00AAAA55FF
FFFF5555FF555555FF0055FFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AAFFAA00000000FFFF00AA55AAFFFFAAAA55
55FF55FFFF55FFAAFFFFAAFF5555555555FFAAFFFFAAFF55FFFF55FF5555AAAAFFFFAA55
AA00FFFF00000000AAFFAA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA0055FFFF55FFFFFFFF55005500AAFFFFAA
55FF55AA00555555AA005500AA000000AA005500AA55555500AA55FF55AAFFFFAA005500
55FFFFFFFF55FFFF5500AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55AAAA55FF555555FFAAAAAAFFFFFFFF
AA550055FFFF00FFFFAAAAAAFFFF55FFFFAAAAAAFFFF00FFFF550055AAFFFFFFFFAAAAAA
FF555555FF55AAAA55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005555AA55FF55AAFF5555AA5555555555
55AAFFAA55AAAAFF00AAAA00AA550055AA00AAAA00FFAAAA55AAFFAA555555555555AA55
55FFAA55FF55AA555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA0000FFFFAA0000AAAAAAAAAAAA
AAAA00FF55AA5555FFFFAAFFAAFF55FFAAFFAAFFFF5555AA55FF00AAAAAAAAAAAAAAAA00
00AAFFFF0000AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAAAAFF00AAAAFFAAFFFFAAFFFF
AAFFFF5555000000AA55AA55AA550055AA55AA55AA0000005555FFFFAAFFFFAAFFFFAAFF
AAAA00FFAAAAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005500FFAAAA00AA55555555AAAA
5555FF55AAFFAAAAFFFF005555AAFFAA555500FFFFAAAAFFAA55FF5555AAAA55555555AA
00AAAAFF005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF0055FFFFAA55FFAA5555
AAFF555500FFAAFFFFFFFF55AAFFFFFFAA55FFFFFFFFAAFF005555FFAA5555AAFF55AAFF
FF5500FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF55AA00FF55AAAA0000
AAAA55FFAAAA555555FF55550000FF00005555FF555555AAAAFF55AAAA0000AAAA55FF00
AA55FFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AAFFFF555500FF55FF
FFAAFF5555AA55FFAA55AAFF55FFFFFF55FFAA55AAFF55AA5555FFAAFFFF55FF005555FF
FFAA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA0055AAFF55FF55AA
0055FF55AAFFFF00AAAAAA005555FF555500AAAAAA00FFFFAA55FF5500AA55FF55FFAA55
00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55AA550055AAFF
FF55AA000055AAAAFFFFAAFFAA55FF55AAFFAAFFFFAAAA550000AA55FFFFAA550055AA55
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005555AAFFAA5555
55FFAAFFAAAAAA00AAFF0055AA55FF55AA5500FFAA00AAAAAAFFAAFF555555AAFFAA5555
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA00FF55AA
FF5555AAAA00AAAAFFFFFF55AA55FF55AA55FFFFFFAAAA00AAAA5555FFAA55FF00AAAAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAAAA55FF
0000000055FFFFAAFF0000FFFFAA55AAFFFF0000FFAAFFFF5500000000FF55AAAAFFFFAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005500FFFF
FF55FFFF55AAAA5555FFFF5555FF00FF5555FFFF5555AAAA55FFFF55FFFFFF005500AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF00
AAFF5555FFAAFFFF00FFAA0000AAFFAA0000AAFF00FFFFAAFF5555FFAA00FFAAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF
5500AA0000FF5555FFFFFFAAAAFFFFFFAAAAFFFFFF5555FF0000AA0055FFFFFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055
AAFFAAFFAAAA55FFAA00FFAAFFFFFFFFFFAAFF00AAFF55AAAAFFAAFFAA5500AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
AA0055FF550000AAFFFF5555AAAA55AAAA5555FFFFAA000055FF5500AAAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
FFFF55AAAAAAFFAAFF0000000055005500000000FFAAFFAAAAAA55FFFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA005555AA555555AAAAFFAAAAFF55FFAAAAFFAAAA555555AA555500AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAAAA000000AAAA0055FF000000FF5500AAAA000000AAAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFFAAAAFFAAFFFF55AAAAFFAAAA55FFFFAAFFAAAAFFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA00550000FF5555FFAAFFFFFFAAFF5555FF00005500AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAAAFFAA0000AA5555FF5555AA0000AAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFFFFFFAAAAFFFF00FF00FFFFAAAAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA0055AA5555FF55FF55FF5555AA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA000000FFFFFF000000AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF55FFFFFFFFFF55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA005555555555555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFFFAAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 2.68894 0.39418 2.77625 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAFFAA00FFAA55AA55FF5500FF55FFFF0055AAAA55AAAAAAAA555555FF00FF00FF
FF00AAAAAA555555FF555555AA00AA00AA555555FF555555AAAAAA00FFFF00FF00FF5555
55AAAAAAAA55AAAA5500FFFF55FF0055FF55AA55AAFF00AAFFAAAAAAFF
FFFFAAFFFFFFAAAA555555AA00FFFF555555FF55FFAAFFFF0055005555555555FFFFFF55
55FFFFAAFFFF0000FFAA55FFAAFFAAFFAAFF55AAFF0000FFFFAAFFFF5555FFFFFF555555
5555005500FFFFAAFF55FF555555FFFF00AA555555AAAAFFFFFFAAFFFF
FFFFFFAA00FFAAFFFF00FFFFAAAA55AAFF55AAAAAA5555FF55FFAAAAAAAAAAAAAA55AAAA
AAAA55AA55AAAAFFAA00AA55AA55AA55AA55AA00AAFFAAAA55AA55AAAAAAAA55AAAAAAAA
AAAAAAFF55FF5555AAAAAA55FFAA55AAAAFFFF00FFFFAAFF00AAFFFFFF
FFFFFFFFAAAA5555FF55FF55550055AA55AA0000AAAAAAAA55FF550055005555AA550055
55AA55FF0000AA00FF55FF000055AA550000FF55FF00AA0000FF55AA55550055AA555500
550055FF55AAAAAAAA0000AA55AA55005555FF55FF5555AAAAFFFFFFFF
FFFFFFFFFFAAFF55AAAAAA55FFAAAAAA0055FFFF550000555555FFAAAAAAFF55AA55FFFF
000000FFAAAAFFFF555555FFFF55AA55FFFF555555FFFFAAAAFF000000FFFF55AA55FFAA
AAAAFF555555000055FFFF5500AAAAAAFF55AAAAAA55FFAAFFFFFFFFFF
FFFFFFFFFFFFAA0055000000FFAAFFFFAAAAAA55AAFFAAAAAAAAAA555500FFAA555555FF
55FFFF5555AA55AAAAAAAAAA55AA00AA55AAAAAAAAAA55AA5555FFFF55FF555555AAFF00
5555AAAAAAAAAAFFAA55AAAAAAFFFFAAFF0000005500AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAFFAAAA5555FF5500555555AAAA0000000000FFFF555500AA55FF
55AAAA55FFAAFF550055550000FF55FF000055550055FFAAFF55AAAA55FF55AA005555FF
FF0000000000AAAA5555550055FF5555AAAAFFAAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFFFFAAFF55AAAAAAFF55AAFFFFAAAAFFAAAAFF00AA55FFFFAA55
AAFFFFAA55AA55AAFFAA55FFFF555555FFFF55AAFFAA55AA55AAFFFFAA55AAFFFF55AA00
FFAAAAFFAAAAFFFFAA55FFAAAAAA55FFAAFFFFFFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA00FFAAFF000000AAAA55FF00AAFFFFAA0000AAFFAAFF5555FF00
FF5555FF00FF55AA55AA55FF5555555555FF55AA55AA55FF00FF5555FF00FF5555FFAAFF
AA0000AAFFFFAA00FF55AAAA000000FFAAFF00AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA5555FFFF55FF0055AAAAFFFFFFFFAAAAFFFFFFAA0055AAAA
FF0000FFAAAA55FF000055AAAAAAAAAAAAAA550000FF55AAAAFF0000FFAAAA5500AAFFFF
FFAAAAFFFFFFFFAAAA5500FF55FFFF5555AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFF55AAAA55FF55FFAAFFFFFFFFFFFFAAFF00AAFFFF55AA55
55FFFF5555AA55FF55FFFF00555500555500FFFF55FF55AA5555FFFF5555AA55FFFFAA00
FFAAFFFFFFFFFFFFAAFF55FF55AAAA55FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00550000FFAA55AA55AAAA55AAAA5555FFFFAA00FFFFAA
55FF55555555AA00FFFFFFFF55AAFFAA55FFFFFFFF00AA55555555FF55AAFFFF00AAFFFF
5555AAAA55AAAA55AA55AAFF00005500AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAA0000FF55AA555555AA55FFAA00FF55FF5555
AAFF00FF0000FF55FF5555FF55AA55AA55FF5555FF55FF0000FF00FFAA5555FF55FF00AA
FF55AA555555AA55FF0000AAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAAAAFF00FF55AAFF5500AAFFFF555555FFAA
5555FFFFFF55FF55AAAAAAAA55FF00FF55AAAAAAAA55FF55FFFFFF5555AAFF555555FFFF
AA0055FFAA55FF00FFAAAAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFAAFFFFFF555555AAAAAAFFFFFFFF00FF00AA
AAAAAA55AAAAAA55FF00555500AAFFAA00555500FF55AAAAAA55AAAAAAAA00FF00FFFFFF
FFAAAAAA555555FFFFFFAAFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555FF5555555555005555FF5555FFFFFF55
005500FF00550000FFAAAAAAAAFFFFFFAAAAAAAAFF00005500FF00550055FFFFFF5555FF
5555005555555555FF5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55AAAAAAAAAAAAAAFF55AAAAAAAA55AAAA
AAFF55FF55FFAAAAFF0055005555FF5555005500FFAAAAFF55FF55FFAAAAAA55AAAAAAAA
55FFAAAAAAAAAAAAAA55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00550000005555AA55AA000055FF000000
55FF55AAAAAA5555AAAAFF55FFAA55AAFF55FFAAAA5555AAAAAA55FF55000000FF550000
AA55AA55550000005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAAAAAAAA0055FFFF55AAAAFFAA
AAAA55FF0055FFAA5555AAAAAA555555AAAAAA5555AAFF5500FF55AAAAAAFFAAAA55FFFF
5500AAAAAAAAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAAFFFFAAAAAA55AA00AAAA55
550000FFAAAAAA555555550055555555550055555555AAAAAAFF00005555AAAA00AA55AA
AAAAFFFFAAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFAAFF00AAAA0000FF55FF0055
AAFFAAAA5555AA5500AA55FFFF00FF00FFFF55AA0055AA5555AAAAFFAA5500FF55FF0000
AAAA00FFAAFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555FFFFAAFFAAAA55FF55FF
AAFF0055555555AAFFAAFF5555FFFFFF5555FFAAFFAA5555555500FFAAFF55FF55AAAAFF
AAFFFF5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55AAAA5555FF0055AAAAAA
5555FFFF00FF00FF5555AAAAAAAA55AAAAAAAA5555FF00FF00FFFF5555AAAAAA5500FF55
55AAAA55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00550000FFFFFF55AA5555
AAFF5555FFFFFF55555555005500FF00550055555555FFFFFF5555FFAA5555AA55FFFFFF
00005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAA00FFAA555555
55AAAAAAAA55AAAAAAAAAAAAFF55FF55FFAAAAAAAAAAAA55AAAAAAAA55555555AAFF00AA
FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAAAA55555555
5555AA555500AAAA000000AA00FFFFFF00AA000000AAAA005555AA555555555555AAAAFF
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFAAFFFF0000FF
0000FF55AAFFAAFFFF55FFFFAAAA55AAAAFFFF55FFFFAAFFAA55FF0000FF0000FFFFAAFF
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555FF55FFFF
FF55FF55AA55AA55AAAAAA55AA555555AA55AAAAAA55AA55AA55FF55FFFFFF55FF5555AA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55AAAAAA55
AAAAAA55FF00FF55AA555500AAAAAAAAAA005555AA55FF00FF55AAAAAA55AAAAAA55FFAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055000000
FF550000FFAAAA550000FFFF5500550055FFFF000055AAAAFF000055FF0000005500AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAA
AA55FFFF5555AA55FFFF5555FFAAAAAAFF5555FFFF55AA5555FFFF55AAAAFFAAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF
AAFF5555FFAA555555FF55AAFF005500FFAA55FF555555AAFF5555FFAAFFFFFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF
AAFF00FF00AAAAAAAAAA5500FFAAAAAAFF0055AAAAAAAAAA00FF00FFAAFF00AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
5555FFFFFF55005555AA55FFFFFFAAFFFFFF55AA55550055FFFFFF5555AAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
FF55AAAA55AAFFAA550055AAAA55AA55AAAA550055AAFFAA55AAAA55FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA00550000FF5555AAFFAA5555AA00AA5555AAFFAA5555FF00005500AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAAFFAA0055AA55AA55FFAAFFAAFF55AA55AA5500AAFFAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFFFFAAAAAA005500AAFFFFFFAA005500AAAAAAFFFFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA00FFAAFFFFAAAAAAFFFFFFFFFFAAAAAAFFFFAAFF00AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAA5555FF5500FF5555FF5555FF0055FF5555AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFF55AAAAAAFF00FFFFFF00FFAAAAAA55FFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA0055005555FFFFFFFFFF5555005500AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAFF55AAAA55AAAA55FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFFFF0055555500FFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA00FFAAAAAAAAAAFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA5555AA5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFF55AA55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 2.68894 0.588183 2.77625 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAAAAAAAAAAAAAAAAA00AAAAAA5555FF00555555FFFFFFFF00FFFFFF00FFFFFFFF
FFFFFF5555AAFF555555555555FFFFFF555555555555FFAA5555FFFFFFFFFFFFFF00FFFF
FF00FFFFFFFF55555500FF5555AAAAAA00AAAAAAAAAAAAAAAAAAAAAAFF
FFFFAAFFFFAAFFFFAAFFFFAAFFAAFFFFAA55FF55FFAA5555FF5555FFFFFFFFFF5555FF55
55FF5555AAFFFFFF00FFFF00FF555555FF00FFFF00FFFFFFAA5555FF5555FF5555FFFFFF
FFFF5555FF5555AAFF55FF55AAFFFFAAFFAAFFFFAAFFFFAAFFFFAAFFFF
FFFFFFAA005555555500AAFFFFFFAA005555AA00AAFFFF00FF00FFFFFFFFFFFFFF00FF00
FF5555AAFFFFFFFFFF5555FFFFFF00FFFFFF5555FFFFFFFFFFAA5555FF00FF00FFFFFFFF
FFFFFF00FF00FFFFAA00AA555500AAFFFFFFAA005555555500AAFFFFFF
FFFFFFFFAAAAAAAAAAAAFFFFFFFFFFAAAAAA0000555555FFFFFF555555FF555555FFFFFF
5555AAFFFFFFFFFFFFFF00FFAA005500AAFF00FFFFFFFFFFFFFFAA5555FFFFFF555555FF
555555FFFFFF5555550000AAAAAAFFFFFFFFFFAAAAAAAAAAAAFFFFFFFF
FFFFFFFFFFAAFFFFAAFFFFFFFFFFFFFFAAFFFF55FF00FF555555FF00FF5555AAFF555555
FF005555555555FF5555FFFFFFAAAAAAFFFFFF5555FF555555555500FF555555FFAA5555
FF00FF555555FF00FF55FFFFAAFFFFFFFFFFFFFFAAFFFFAAFFFFFFFFFF
FFFFFFFFFFFFAA0055555555555555555500AA55FF55FF55AA5555FFFFFF00555555AA55
55FFFF00FFFF00FFAA5555FF5555005555FF5555AAFF00FFFF00FFFF5555AA55555500FF
FFFF5555AA55FF55FF55AA0055555555555555555500AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAAAAAAAAAAAAAAAAAFFFF00AAAA555500FF555555FFFF00FFFFAA
555555FFFFFFFF555500FF5555AAFFAA5555FF005555FFFFFFFF555555AAFFFF00FFFF55
5555FF005555AAAA00FFFFAAAAAAAAAAAAAAAAAAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFFAAFFFFAAFFFFAAFF0000555500FF55FF5500FFFFFFFF555555
00FFFF000000FF00FFFF5555AAFFFFFFAA5555FFFF00FF000000FFFF00555555FFFFFFFF
0055FF55FF0055550000FFAAFFFFAAFFFFAAFFFFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA005555555500AAFFFFFF55FF005500AAAA55FFFFFFFFFFFF0055
FFFFFFFF55FFFFFF555555AAFFFFFFFFFFAA555555FFFFFF55FFFFFFFF5500FFFFFFFFFF
FF55AAAA005500FF55FFFFFFAA005555555500AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAAFFFFFFFFFF000055FFFFAAFF555555555555FFFF
00000000FFFFFFFFFF00FFFFAA00FF00AAFFFF00FFFFFFFFFF00000000FFFF5555555555
55FFAAFFFF550000FFFFFFFFFFAAAAAAAAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFFFAAFFFFFFFFFFFFFF55FF00AAFFFFFF00FFFF00FFFFFF
FF55FFFF55555555FF55FF55550000005555FF55FF55555555FFFF55FFFFFFFF00FFFF00
FFFFFFAA00FF55FFFFFFFFFFFFFFAAFFFFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00555555555555555555AAAAFFFFFFFFFF5555FFFFFFFF
FFFF0000FF5500FF5555AAAAAAAAFFAAAAAAAA5555FF0055FF0000FFFFFFFFFFFF5555FF
FFFFFFFFAAAA55555555555555555500AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAAAAAAAAAA0000AAFF000000FFFF000000FF
AA00550000FF55FF55AAFFFFAAFFFFFFAAFFFFAA55FF55FF00005500AAFF000000FFFF00
0000FFAA0000AAAAAAAAAAAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAAFFFFAAFFFFAAAAFFFFFF55FFFFFFFF55FFFF
FFAAAAAAFFAA00AA555500AAFFFFFFFFFFAA005555AA00AAFFAAAAAAFFFFFF55FFFFFFFF
55FFFFFFAAAAFFFFAAFFFFAAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005555555500AAFFFFAA0055AAFF000000FF5555
5555005555550000AAAAAAFFFFFFFFFFFFFFAAAAAA00005555550055555555FF000000FF
AA5500AAFFFFAA005555555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAAFFFFFFFFAAAA000000550000FFFF
00FFFF5500FF55FFFFAAFFFFFFFFFFFFFFFFFFAAFFFF55FF0055FFFF00FFFF0000550000
00AAAAFFFFFFFFAAAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAAFFFFFFFFFFFFAAFFAAAAFF55FFFFFF
FF5555FFAAAA55FF555500AAFF000000FFAA005555FF55AAAAFF5555FFFFFFFF55FFAAAA
FFAAFFFFFFFFFFFFAAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00555555555555555500AA0000FFFFFFFF
FFFF00FFAAFFFF00AAAAAAFFFFFF55FFFFFFAAAAAA00FFFFAAFF00FFFFFFFFFFFF0000AA
00555555555555555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAAAAAAAAAAFFFF55FF5555FF
5555FFFFFFAA005500555500AAFF00FFAA005555005500AAFFFFFF5555FF5555FF55FFFF
AAAAAAAAAAAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAAFFFFAAFFFFAA00FFFFFF00FF
00FFFFFFFFFFAAAAAAFF550000AAFFAA000055FFAAAAAAFFFFFFFFFF00FF00FFFFFF00AA
FFFFAAFFFFAAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005555555500AAFFFF555555FFFF
FF555555555555005555FFAAAAFFFFFFAAAAFF555500555555555555FFFFFF555555FFFF
AA005555555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAAFFFFFFFF00FF5555
55FFAA5555AAFF55FF00FFAAFFFFFFFFFFAAFF00FF55FFAA5555AAFF555555FF00FFFFFF
FFAAAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAAFFFFFFFFFFFF5555AA
55555500FFFFAA00AAFFAA000000FF000000AAFFAA00AAFFFF00555555AA5555FFFFFFFF
FFFFAAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005555555555555555AAFF
FF00FF55FF55550000AAFFFF55FFFFFF55FFFFAA00005555FF55FF00FFFFAA5555555555
55555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAAAAAAAA0000
000055AA5500FF55FFFFAA00FFFFFFFFFF00AAFFFF55FF0055AA5500000000AAAAAAAAAA
AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAAFFFFAAFFFF55
FFFF550055FFFFFF00AAFFFF5555FF5555FFFFAA00FFFFFF550055FFFF55FFFFAAFFFFAA
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005555555500AAFF
5555FFAAAA0055AAAAFFFFFFFF00FF00FFFFFFFFAAAA5500AAAAFF5555FFAA0055555555
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAAFFFF
FF00FFAAFFFF55005555FF5555FFFFFF5555FF55550055FFFFAAFF00FFFFFFAAAAAAAAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAAFFFFFF
FFFF555500AA55FFFF00FF00FFFFFFFFFF00FF00FFFF55AA005555FFFFFFFFFFAAFFFFAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055555555
555555AAFFAAFF5555FFFFFF5555FF5555FFFFFF5555FFAAFFAA5555555555555500AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAA
AAAAAA000000AA55FF00AAFF00FFFFFF00FFAA00FF55AA000000AAAAAAAAAAAAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAA
FFFFAAFFAAAAFFFF00005555FFFFFFFFFF55550000FFFFAAAAFFAAFFFFAAFFFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055
55555500AA000000005500FFFFFFFFFFFFFF005500000000AA005555555500AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
AAAAAAAAFFFF55FFFF5500000000FF0000000055FFFF55FFFFAAAAAAAAAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
FFFFAAFFFFFFFF0000FF55FFFF55FF55FFFF55FF0000FFFFFFFFAAFFFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA0055555555FF55FFFFFF0000FFFFFF0000FFFFFF55FF5555555500AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAAAAAAAA555555FF55FFFFFFFFFF55FF555555AAAAAAAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFFAAFFFF00FFFFFF0000000000FFFFFF00FFFFAAFFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA005555FF55FF5555FFFF55FFFF5555FF55FF555500AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAAAAA5555FF0055AA00AA5500FF5555AAAAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFFFFAA55FF55FFAAFFAAFF55FF55AAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA005555AA00AAFFFFFFAA00AA555500AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA00005555FF55550000AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF55FF00FF00FF55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA0055FF55FF55FF5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAA555555AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 2.68894 0.782187 2.77625 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAFFFFFFAA00FF00AAAAFF55FF00550000AA00FFAAFF00FF555500AAFF5555FFFF
FF55FFFF5555AAAA550055AAFFFFAAFFFFAA550055AAAA5555FFFF55FFFFFF5555FFAA00
5555FF00FFAAFF00AA00005500FF55FFAAAA00FF00AAFFFFFFAAAAAAFF
FFFFAAFFFFFFFFFFAAAA555555550000AAAAAAFFAAFFAA005555AAAAAAAAFFFFFF00FFAA
00005555000000FF00FF55AA00FFAAFF00AA55FF00FF00000055550000AAFF00FFFFFFAA
AAAAAA555500AAFFAAFFAAAAAA000055555555AAAAFFFFFFFFFFAAFFFF
FFFFFFAA0000AA00FF000055000055FFFFAAFFFFFFAA0055FFAA5500AA55005555FFFFFF
AAAAFF55AA5555AAAA000000FF555555FF000000AAAA5555AA55FFAAAAFFFFFF55550055
AA0055AAFF5500AAFFFFFFAAFFFF550000550000FF00AA0000AAFFFFFF
FFFFFFFFAAAA0055FF55FFFF0055FFAA0000FFAA00FF00550055AAFFAAFF55000000AAFF
0000FFAA55000000FF0055FFFFFF00FFFFFF5500FF00000055AAFF0000FFAA00000055FF
AAFFAA55005500FF00AAFF0000AAFF5500FFFF55FF5500AAAAFFFFFFFF
FFFFFFFFFFAAFFAA55AAFF00AAAAAA5500FF555555AAAAFF550000FFAAFF00FF55FF0000
AAAA00FF00FF55FFFFFF55AAAA55AA55AAAA55FFFFFF55FF00FF00AAAA0000FF55FF00FF
AAFF000055FFAAAA555555FF0055AAAAAA00FFAA55AAFFAAFFFFFFFFFF
FFFFFFFFFFFFAA005500AAFFAAFFFFAA555500000055AA00FFFF550055AAAA000000AAAA
FFFFAAAA55550000AA000000FF00FF00FF000000AA00005555AAAAFFFFAAAA000000AAAA
550055FFFF00AA550000005555AAFFFFAAFFAA005500AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAFFFFFFAA00FF00FFFF5500FFFFAAAA55AAFFAA5500AAAAFFAAFF
FFFFFFAAFF55AA555555AA5555FFFFFF5555AA555555AA55FFAAFFFFFFFFAAFFAAAA0055
AAFFAA55AAAAFFFF0055FFFF00FF00AAFFFFFFAAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFFFFFFFFAAAA5555005500FFAA0055AAFFFFFFAA5555555500AA
0000AAFFFFFF0000000000FFFF00AA00FFFF0000000000FFFFFFAA0000AA0055555555AA
FFFFFFAA5500AAFF0055005555AAAAFFFFFFFFFFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA0000AA00FF00005500FFFF555555AAFFFFFFFFFFAA55FFAA5555
55AA55005555FFFF55FFFF555500FF005555FFFF55FFFF55550055AA555555AAFF55AAFF
FFFFFFFFAA555555FFFF00550000FF00AA0000AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA0055FF55FFFF00555500005500AAFF00AA0000FFFFFFAA55
FFAAFF55FFAA55AAAAAA55AAFF55FF55FFAA55AAAAAA55AAFF55FFAAFF55AAFFFFFF0000
AA00FFAA00550000555500FFFF55FF5500AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFAA55AAFF00AAAAAAAAFFAA555555FFFFAAAAFF00AAFFFF
00AA55AAFF000000FF000000FFAA55AAFF000000FF000000FFAA55AA00FFFFAA00FFAAAA
FFFF555555AAFFAAAAAAAA00FFAA55AAFFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFFAAFFFFAAFF0000550000AAFFFFAA00AA55AA
AAFFFF0000AAAA00AA00AAAAFF000000FFAAAA00AA00AAAA0000FFFFAAAA55AA00AAFFFF
AA0000550000FFAAFFFFAAFFAA005500AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFAA00FF00AAAAFF55FFFFAA00FF0055AAFF
FFAA00FF5500AA555555AA005555AA555500AA555555AA0055FF00AAFFFFAA5500FF00AA
FFFF55FFAAAA00FF00AAFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFAAAA555555550000AA0055FF550000FF
AA0055FF55AA5500000055AA55FFAAFF55AA5500000055AA55FF5500AAFF000055FF5500
AA000055555555AAAAFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AA00FF000055000055FFFFAAAAAA55FFFF55
5555AAFF00FF00FF55FF00FF00FFAAFF00FF00FF55FF00FF00FFAA555555FFFF55AAAAAA
FFFF550000550000FF00AA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055FF55FFFF0055FFAA0000FF000000AAFF
55AAFFFFFF5555AAAAAA555500FFAAFF005555AAAAAA5555FFFFFFAA55FFAA000000FF00
00AAFF5500FFFF55FF5500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA55AAFF00AAAAAA5500FF5555AA555555
0000FFAA00FFFF0000FF00FFFF555555FFFF00FF0000FFFF00AAFF0000555555AA5555FF
0055AAAAAA00FFAA55AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFFAAFFFFAA5555000000FFFF00
FF550055AA55AAAA00AA00AA0000550000AA00AA00AAAA55AA550055FF00FFFF00000055
55AAFFFFAAFFAA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFAA00FF00FFFF5500FFAA00
AAFF550000FFFFAAFFAAFFAAFFAAAAAAFFAAFFAAFFAAFFFF000055FFAA00AAFF0055FFFF
00FF00AAFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFAAAA5555005500FFAAFF
AAFF00FF550055555500AAFFFFFFAAFFFFFFAA005555550055FF00FFAAFFAAFF00550055
55AAAAFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AA00FF00005500FFFF555555
00AA00AAFF55FFAA55FFFFAA00FFAAFF00AAFFFF55AAFF55FFAA00AA00555555FFFF0055
0000FF00AA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055FF55FFFF005555000055
00FF0055AAAAAA550000AAFFFF555555FFFFAA000055AAAAAA5500FF00550000555500FF
FF55FF5500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA55AAFF00AAAAAAAAFFAA
5555FFFF0000FF00FF5500AA0000550000AA0055FF00FF0000FFFF5555AAFFAAAAAAAA00
FFAA55AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFFAAFFFFAAFF00
0055005555AA55AA55AAFFAAFFAAAAAAFFAAFFAA55AA55AA555500550000FFAAFFFFAAFF
AA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFAA00FF00AA
AAFF55FFAA550000FFFFAA00555555555500AAFFFF000055AAFF55FFAAAA00FF00AAFFFF
FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFAAAA5555
55550000AA55FFFF555500AAAAAAAAAAAAAA005555FFFF55AA000055555555AAAAFFFFFF
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AA00FF000055
000055FF00005555FFAA555555555555555555AAFF55550000FF550000550000FF00AA00
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055FF55FFFF
0055FFAA00AAAAAAAA5500000000000000000055AAAAAAAA00AAFF5500FFFF55FF5500AA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA55AAFF00
AAAAAA5500FF0000FF00FF5500FF55FF0055FF00FF0000FF0055AAAAAA00FFAA55AAFFAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFF
AAFFFFAA5555FFFF5555AAAAAA000000AAAAAA5555FFFF5555AAFFFFAAFFAA005500AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFF
FFAA00FF00FFFFFFFF00FF0000FF55FF0000FF00FFFFFFFF00FF00AAFFFFFFAAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF
FFFFAAAA5555005555FFFFFF5500550055FFFFFF5555005555AAAAFFFFFFFFFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000
AA00FF00000055FFAA55AAAA55FF00FF55AAAA55AAFF55000000FF00AA0000AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
0055FF55FF00550055AAFFFFAA55AA55AAFFFFAA55005500FF55FF5500AAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
FFAA55AAFF005500FFFFAA00FF00FF00FF00AAFFFF005500FFAA55AAFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA005500AAFFAA55550055AA55AA55AA55AA55005555AAFFAA005500AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAAFFFFFFAA55FF00FF00FF00FF00FF00FF55AAFFFFFFAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFFFFFFFFAA55AA55AA55AA55AA55AA55AAFFFFFFFFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA0000AA00FF00FF00FF00FF00FF00FF00FF00AA0000AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAA0055FF55FF55FF55FF55FF55FF55FF5500AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFFAA55AAFF00FFAA55AAFF00FFAA55AAFFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA005500AAFFAA005500AAFFAA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAFFFFFFAAAAAAFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFFFFFFFFAAFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA0000AA00FF00AA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA0055FF5500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFAA55AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 2.68894 0.97619 2.77625 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAFFFFFF55FFFF0055FF5555005500AA00AAFFFFAA550055AA55000000AAFF00FF
00FF00FFAA555500555555AA5555AA5555AA555555005555AAFF00FF00FF00FFAA000000
55AA550055AAFFFFAA00AA0055005555FF5500FFFF55FFFFFFAAAAAAFF
FFFFAA00FF0000FFFFFFFF55AA55FFAAAAAAFFFF5555AA55AAFFAA55AAFFAAAAFFFFFF55
0055FFFFFFAA55FFFF00FFFFAA55FF55AAFFFF00FFFF55AAFFFFFF550055FFFFFFAAAAFF
AA55AAFFAA55AA5555FFFFAAAAAAFF55AA55FFFFFFFF0000FF00AAFFFF
FFFFFFAAAA0000AA550000FFFFAA5555FF5555AA55FFAAFF5555AAAAAA5555FF550000FF
FF55AA00AAAA55FF0000AAAA00FFFFFF00AAAA0000FF55AAAA00AA55FFFF000055FF5555
AAAAAA5555FFAAFF55AA5555FF5555AAFFFF000055AA0000AAAAFFFFFF
FFFFFFFFAA0000AAFF55FFFFFFFFAA55FF00FFFFAA5555FF00FFFFAA00FFFF000000AA00
55FFAAFFAAFF00FF55FFFFAA0000FF0000AAFFFF55FF00FFAAFFAAFF5500AA000000FFFF
00AAFFFF00FF5555AAFFFF00FF55AAFFFFFFFF55FFAA0000AAFFFFFFFF
FFFFFFFFFFAAAAFFFFFF00005500FFAA550055AA00FFFF0055555555FFFFFFFF55FFFFAA
AAAA00FF55555500000055FF55FFFFFF55FF55000000555555FF00AAAAAAFFFF55FFFFFF
FF5555555500FFFF00AA550055AAFF00550000FFFFFFAAAAFFFFFFFFFF
FFFFFFFFFFFFAA005500AA000000AAAA55FFFF00AA0055FFFF00FFFF0000FF00000055FF
5555FFFFFF00FFFF55FFFF000000FF000000FFFF55FFFF00FFFFFF5555FF55000000FF00
00FFFF00FFFF5500AA00FFFF55AAAA000000AA005500AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAFFFF55FFFFAAFF550000AAFFAA55555500FF55FFFFFF55FFFF00
000000FF55005500FFFFFFFF55FFFFFF55FFFFFFFF00550055FF00000000FFFF55FFFFFF
55FF00555555AAFFAA000055FFAAFFFF55FFFFAAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00FF000000FF00AA55FFFF555555FFAA55FFFFFF0000FF00FF0000
AA0000AAAAAAFF55FF0055000000550000005500FF55FFAAAAAA0000AA0000FF00FF0000
FFFFFF55AAFF555555FFFF55AA00FF000000FF00AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA0000AA00AA00FFFFFFFF00FFFFFFAA55000055550000AAAAFF
AA0000AAFF00AAAAAA000000AA000000AA000000AAAAAA00FFAA0000AAFFAAAA00005555
000055AAFFFFFF00FFFFFFFF00AA00AA0000AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA0000AAFFAA0000550000555555AA55AAFFAAAAAAAAFFAAFFFF
FFAAAAFFFFFF5555FF55FFFF5555005555FFFF55FF5555FFFFFFAAAAFFFFFFAAFFAAAAAA
AAFFAA55AA5555550000550000AAFFAA0000AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFFFFFFAAAAFF55FFFF00FFFFAA55AA55AAAA55AA55AA55
55AAAA550000FFFF00000055AAFF55FFAA55000000FFFF000055AAAA5555AA55AA55AAAA
55AA55AAFFFF00FFFF55FFAAAAFFFFFFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFF00000055FFFFFFFFAA55AAFFFFAA55AAFF00
FFFFAAFF55FFFFFFFF55FFFF00AAAAAA00FFFF55FFFFFFFF55FFAAFFFF00FFAA55AAFFFF
AA55AAFFFFFFFF55000000FFAA005500AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFF55FFFF0055AA00AAFF5555AA55AAFF0055
555555FF00FF0000FF00FF005555FF555500FF00FF0000FF00FF5555555500FFAA55AA55
55FFAA00AA5500FFFF55FFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF0000FFFFFFFF55AAAAFFFFFF00FFAA55AA0000
0000000055555500550055FFFF00FF00FFFF55005500555555000000000000AA55AAFF00
FFFFFFAAAA55FFFFFFFF0000FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000AA550000FFFFAA00550000AAAA55FF55FF
FF55FFFF55AAFF55FFAAAAAA0055555500AAAAAAFF55FFAA55FFFF55FFFF55FF55AAAA00
005500AAFFFF000055AA0000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AAFF55FFFFFFFFAAAAAAFFAA00FFFFFF00
00FFFFFFFF00AAAAAA00FFAA0000000000AAFF00AAAAAA00FFFFFFFF0000FFFFFF00AAFF
AAAAAAFFFFFFFF55FFAA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFFFF00005500FFAAFFFFFFAAAA0055FF
FF550000FF55FF5555FFFFFFAAAAFFAAAAFFFFFF5555FF55FF000055FFFF5500AAAAFFFF
FFAAFF00550000FFFFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005500AA000000AAAA5555AA55AAAAFF55
00FFFF55FF00FF00FFFFFFFFFFAA00AAFFFFFFFFFF00FF00FF55FFFF0055FFAAAA55AA55
55AAAA000000AA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFF55FFFFAAFF55AAAAAA55AA55
FFFFFFFF0055555500AAAA0055FF55FF5500AAAA0055555500FFFFFFFF55AA55AAAAAA55
FFAAFFFF55FFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF000000FF00AA55FF5555FFAAFF
55000055FFFF00FFFF5555FFFF000000FFFF5555FFFF00FFFF55000055FFAAFF5555FF55
AA00FF000000FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000AA00AA00FFFFFF00FF00AA
55FFFF55AA555500FF00FFFFFFFF55FFFFFFFF00FF005555AA55FFFF55AA00FF00FFFFFF
00AA00AA0000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AAFFAA0000550000AAAAFF
FF0000FFFFAA55FFFFFF5500FF000000FF0055FFFFFF55AAFFFF0000FFFFAAAA00005500
00AAFFAA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFFFFAAAAFF55FFFFAA00
5500555555AAAAAA00AA55FFFFFF55FFFFFF55AA00AAAAAA555555005500AAFFFF55FFAA
AAFFFFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFF00000055FF55
FFAAAAAAAAAA55AAAAFFFF0000FF00FF0000FFFFAAAA55AAAAAAAAAAFF55FF55000000FF
AA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFF55FFFF0000
00FFAA00FFAAFF5555FF0000AA00AA00AA0000FF5555FFAAFF00AAFF000000FFFF55FFFF
FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF0000FFFFFFFF55
FFFFFFAAAA00FF00FFFFFF55FF55FF55FF55FFFFFF00FF00AAAAFFFFFF55FFFFFFFF0000
FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000AA550000FF
FFFFFFFFAA0000555555AA55FF00FF00FF55AA5555550000AAFFFFFFFFFF000055AA0000
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AAFF55FFFF
FFFFFFFFFFAAAAFF55AAFFFF0055555500FFFFAA55FFAAAAFFFFFFFFFFFFFF55FFAA0000
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFFFF0000
5500FF5500AAFFFFFF00AAAA0000000000AAAA00FFFFFFAA0055FF00550000FFFFFFAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005500AA00
0000AAAAAAFFFFFFFFFF5555FFFF55FFFF5555FFFFFFFFFFAAAAAA000000AA005500AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFF
55FFFFAAFFFFFFFFFFFFFF00FF000000FF00FFFFFFFFFFFFFFAAFFFF55FFFFAAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF00
0000FF00AA555555555555550000AA000055555555555555AA00FF000000FF00AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00
00AA00AA00FFFF00FFFF00FFFF55FF55FFFF00FFFF00FFFF00AA00AA0000AAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00
00AAFFAA0000550055AA0000FF55AA55FF0000AA5500550000AAFFAA0000AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAFFFFFFAAAAFF55FFAA0000AA55FF55AA0000AAFF55FFAAAAFFFFFFAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA005500AAFF000000FFAAAAFF00FF00FFAAAAFF000000FFAA005500AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAAFFFFFF55FFFFFFAA0055555500AAFFFFFF55FFFFFFAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA00FF0000FFFFFFFFFFAAAAAAAAAAFFFFFFFFFF0000FF00AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAA0000AA550000FF5555FF5555FF000055AA0000AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA0000AAFF55FFFFFF00FF00FFFFFF55FFAA0000AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAFFFFFF000055FFFFFF550000FFFFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA005500AA000000FF000000AA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAFFFF55FFFFFF55FFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00FF000000FF000000FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA0000AA00AA0000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA0000AAFFAA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFFFFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 2.78498 0.200176 2.87229 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAA00FFFF000000000055555500AA555555AAFFFFFFFFFFFFAAAAAA5555FFFF5500
FFFF0055FFFFFF55555555FFFFFFFFFFFFFF55555555FFFFFF5500FFFF0055FFFF5555AA
AAAAFFFFFFFFFFFFAA555555AA005555550000000000FFFF00AAAAAAFF
FFFFAA55FFFFFFFF55FFFF55FF5555FFFFAA00FFAA555555AA0055FFAA55FF55555555FF
FFFFFF55555555550000AA00AA555555AA00AA00005555555555FFFFFFFF55555555FF55
AAFF5500AA555555AAFF00AAFFFF5555FF55FFFF55FFFFFFFF55AAFFFF
FFFFFFAA00AA5555AAAA005555550055AA55FFFFFF00AA00FFFF5555AAFF00005555FF55
00AA5555FF5555FF55FFFFAAAAAA55AAAAAAFFFF55FF5555FF5555AA0055FF55550000FF
AA5555FFFF00AA00FFFFFF55AA550055555500AAAA5555AA00AAFFFFFF
FFFFFFFFAAAAAA55AAFFFF5555FF55FF55AAAA0055FFFFAAAA00AA00FFFFFF55FF555555
FFFFAA00000055555500AA55FFAA55AAFF55AA00555555000000AAFFFF555555FF55FFFF
FF00AA00AAAAFFFF5500AAAA55FF55FF5555FFFFAA55AAAAAAFFFFFFFF
FFFFFFFFFFAA55FF55AA00AA00000055FF55AAFFAA00AAAAAAAAFFFF5500AAAA5555FF55
55AA55FFFF55FF5555FFFF00AA55FF55AA00FFFF5555FF55FFFF55AA5555FF5555AAAA00
55FFFFAAAAAAAA00AAFFAA55FF55000000AA00AA55FF55AAFFFFFFFFFF
FFFFFFFFFFFFAA00AAFF55FFAAAAFFAA00AAFFFFFFAAAAAAAAAAAA00AAFFAA55FF555555
FF55AAAA00AA00555500AAAAFF555555FFAAAA00555500AA00AAAA55FF555555FF55AAFF
AA00AAAAAAAAAAAAFFFFFFAA00AAFFAAAAFF55FFAA00AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA00FF00FFFFFFAAAAAA00AAAAAAAAAAAAAAAAFFFFFFAA00AA0000
55AAAAAAAAFFFF5555FFFFAA5500550055AAFFFF5555FFFFAAAAAAAA550000AA00AAFFFF
FFAAAAAAAAAAAAAAAA00AAAAAAFFFFFF00FF00AAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55FFFFFF5500FF00FFFFAAAAAAAAAAAAAAAAAAAA00AAAAAAFFFF55
FF55AAFFFF0055FF5555AA55FF55FF55FF55AA5555FF5500FFFFAA55FF55FFFFAAAAAA00
AAAAAAAAAAAAAAAAAAAAFFFF00FF0055FFFFFF55AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA00AA5555FFFFFF5500FFFF00FFFFAAFFFFAAFFFF55AAFF5500AA
00AAFFFFFFFF555555FF55AAAA000000AAAA55FF555555FFFFFFFFAA00AA0055FFAA55FF
FFAAFFFFAAFFFF00FFFF0055FFFFFF5555AA00AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAA55AA555555FFFFFFFF5500FFFFFFFF0000FFAA5555FFFF
AAAAAA00AA5555FF5555AAAAAAAAFFAAAAAAAA5555FF5555AA00AAAAAAFFFF5555AAFF00
00FFFFFFFF0055FFFFFFFF555555AA55AAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55FF55AAAA55AA00AA5555FFFFFFFFFFFF55FF00FFAA00AA
AAAAAAAAFF5555FF00AAFFFFAAFFFFFFAAFFFFAA00FF5555FFAAAAAAAAAA00AAFF00FF55
FFFFFFFFFFFF5555AA00AA55AAAA55FF55AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00AAFF55AAAAAAFF555500FF000000000055FFFFFFAAAA
AAAAAAAAAA0000AAAAFFFFFFFF000000FFFFFFFFAAAA0000AAAAAAAAAAAAAAFFFFFF5500
00000000FF005555FFAAAAAA55FFAA00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FFFF00FF5555FFFFFF55FFFF55FF5500AAAAAA
AAAAAAAAAAAAFFAAFFFFFFFFFFFF55FFFFFFFFFFFFAAFFAAAAAAAAAAAAAAAAAA0055FF55
FFFF55FFFFFF5555FF00FFFF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFFFF5500555555AA0000000055FF55FFAAFF
FFAAFFFF00FFFFFF000000FF0055FF5500FF000000FFFFFF00FFFFAAFFFFAAFF55FF5500
000000AA5555550055FFFFFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA5555AAAAFF00AAFF55FFFF55FF550000FFFF
FFFF0055FFFFFFFFFF55FFFFFF555555FFFFFF55FFFFFFFFFF5500FFFFFFFF000055FF55
FFFF55FFAA00FFAAAA5555AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55AAFFFFFF55AA00FF000055FF55FFFFFF
FFFFFF5555555555555500AA5555FF5555AA0055555555555555FFFFFFFFFFFF55FF5500
00FF00AA55FFFFFFAA55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AA00AAAA55FFFFFF55FF5500000000
00FF00005555FF5555FF55FFAA000000AAFF55FF5555FF55550000FF000000000055FF55
FFFFFF55AAAA00AA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFF55FFAAFF0000000055FF55FFFF55
FFFFFF55FF555555000000AAAAAAFFAAAAAA000000555555FF55FFFFFF55FFFF55FF5500
000000FFAAFF55FFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FF00FF55FFFF55FF550000FF55
5555AA00FF5555FF55FFFF55AAFFFFFFAA55FFFF55FF5555FF00AA555555FF000055FF55
FFFF55FF00FF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFF550000FF555555FFFF5500
00AAFFFF55000055FF5500AAFFFFFFFFFFAA0055FF55000055FFFFAA000055FFFF555555
FF000055FFFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA5555FFFF55000055555555FF
FF55AA5555FFFF5555AAAAFFFFFFFFFFFFFFAAAA5555FFFF5555AA55FFFF555555550000
55FFFF5555AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55AA5555FFFF5555FF5555
5555FFAA00000000AAFFFF000000FF000000FFFFAA00000000AAFF55555555FF5555FFFF
5555AA55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAAA5500AAFF000055
0000AAAAAAFFAAAAFFFFFFFF55FFFFFF55FFFFFFFFAAAAFFAAAAAA0000550000FFAA0055
AAAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFF55AAAAFFFFFF55FF
55FFFFAAFFFFFFAA5555AA00555555555500AA5555AAFFFFFFAAFFFF55FF55FFFFFFAAAA
55FFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FFFF0000000055
FF5500FFFFFFFFFFAA00FFFF5555FF5555FFFF00AAFFFFFFFFFF0055FF5500000000FFFF
00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFFFF55FFFF55
5555FFFFFFFFFFFFFFAAAA00AA000000AA00AAAAFFFFFFFFFFFFFF555555FFFF55FFFFFF
FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA5555AAAA0055
5500000000FF000000FFFFAAAAAAFFAAAAAAFFFF000000FF00000000555500AAAA5555AA
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55AAFFFF55
55FFFF55FFFFFF55FFFFFFFFAAFFFFFFAAFFFFFFFF55FFFFFF55FFFF5555FFFFAA55AAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AA00AA
0000000055AA550000000000FFFFFFFFFF000000000055AA5500000000AA00AA55FF55AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFF55FF
AAAAFFAAAA55FF55FFFF55FFFFFFFFFFFFFF55FFFF55FF55AAAAFFAAAAFF55FFAA00AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FF
00FFFFFFAAFF005555555500AAAA00AAAA005555555500FFAAFFFFFF00FF00AAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFF
FF5500FF00FF55FF5555FF55FFAAFFAAFF55FF5555FF55FF00FF0055FFFFFF55AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA
5555FFFFFF5500000055555500FFFFFF0055555500000055FFFFFF5555AA00AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
AA55AA555555FFFF55FF5555FFFFFFFFFF5555FF55FFFF555555AA55AAAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
55FF55AAAA55AA00AA0055000000000000005500AA00AA55AAAA55FF55AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA00AAFF55AAAAAAFF55FF55FFFF55FFFF55FF55FFAAAAAA55FFAA00AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAA00FFFF00FF55555500AA55AA00555555FF00FFFF00AAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA55FFFFFFFF550000AAFFAA55AAFFAA000055FFFFFFFF55AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA00AA555555FFFF55AA55FF55AA55FFFF555555AA00AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAAA55AAAA00AAFF555555FFAA00AAAA55AAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA55FF55AAFFAA5555FF5555AAFFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA00AAFFFFFF00AA00AA00FFFFFFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA00AAAAFF55FFAAAA00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55FFFFAA550055AAFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA00AA55FF55FF55AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAA550055AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55FF55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 2.78498 0.39418 2.87229 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAA00FFAAAAAAAAAAAAFFAA00FFFFAA55FF0055FF55FFFF5500AA55AA0000FF0055
AA0055FF00FFFF55AAFF55AA00FFFFFF00AA55FFAA55FFFF00FF5500AA5500FF0000AA55
AA0055FFFF55FF5500FF55AAFFFF00AAFFAAAAAAAAAAAAFF00AAAAAAFF
FFFFAA55FFFFFFAAFFFFAAFFFFFF0000AAAAAA555555FF00AAAA00FF00FFAA5500AAAAFF
00FF00AA005555AAAAAA00FFFF550055FFFF00AAAAAA555500AA00FF00FFAAAA0055AAFF
00FF00AAAA00FF555555AAAAAA0000FFFFFFAAFFFFAAFFFFFF55AAFFFF
FFFFFFAA00AA000000AAAAAA00AAAAFFAAFFFF00AAFF0055AAFFFF5500AAAAAA55000055
FFFFFF55AA00FFAA55FFAAAA00AAFFAA00AAAAFF55AAFF00AA55FFFFFF55000055AAAAAA
0055FFFFAA5500FFAA00FFFFAAFFAAAA00AAAAAA000000AA00AAFFFFFF
FFFFFFFFAAAAAAFFAAAAAAAAAAFFFF00550055FFFF0055AAAAAA00AAFFAA55FFAA0055AA
AA00AAAA55FFFFFF00AAAAAAAAFFFFFFAAAAAAAA00FFFFFF55AAAA00AAAA5500AAFF55AA
FFAA00AAAAAA5500FFFF55005500FFFFAAAAAAAAAAFFAAAAAAFFFFFFFF
FFFFFFFFFFAA55FF00FFFF00FFFFFFFF555555FF0055AAAAAAAAAAFFFFFFAA000055AAAA
AAAAFFFFAA0000AAAAFFFFAAFFFFFFFFFFAAFFFFAAAA0000AAFFFFAAAAAAAA550000AAFF
FFFFAAAAAAAAAA5500FF555555FFFFFFFF00FFFF00FF55AAFFFFFFFFFF
FFFFFFFFFFFFAA00AA5555AA00AA00AA00FFAA00AA55AAFFFF00FFFFFFFFFFAAAAFF00FF
FFAA5555AAFFAAAAAAAA000000AA00AA000000AAAAAAAAFFAA5555AAFFFF00FFAAAAFFFF
FFFFFF00FFFFAA55AA00AAFF00AA00AA00AA5555AA00AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA55AAFFAAFFAA5500FFFF55AAAAAA00AA5555005555000055FFFF
FFFF00AAFFFFFF00FFFFAAAAFFAAFFAAFFAAAAFFFF00FFFFFFAA00FFFFFFFF5500005555
005555AA00AAAAAA55FFFF0055AAFFAAFFAA55AAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55FF55AA55FF00FFAAAA00AAFFFFAAFFAAFF00AA55AAAAFFAA00AA
00AAAAFFFFFFFFFF5500FFFF0055005500FFFF0055FFFFFFFFFFAAAA00AA00AAFFAAAA55
AA00FFAAFFAAFFFFAA00AAAAFF00FF55AA55FF55AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA00AAFF555500AAAAAAAAFF5500FFFFFF0055AAFF00FFFFFF0000
00FFFF005555005555FFFFFFFF555555FFFFFFFF555500555500FFFF000000FFFFFF00FF
AA5500FFFFFF0055FFAAAAAAAA005555FFAA00AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAA00FFAAAAAAAAAAAA00FF00555500AAFF5500AA00AA0055
AA00AAAAFF00AA55AAAA0000AAAA55AAAA0000AAAA55AA00FFAAAA00AA5500AA00AA0055
FFAA00555500FF00AAAAAAAAAAAAFF00AAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55FFFFFFAAFFFFAAFFFF5500AAFF00005555FFFFAAAAAAFF
00FF00FFFFFF55AAAAAAAAFFAA55FF55AAFFAAAAAAAA55FFFFFF00FF00FFAAAAAAFFFF55
550000FFAA0055FFFFAAFFFFAAFFFFFF55AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00AA000000AAAAAA00AAFFAA55555555FF5500FFFFAA55
555500AA00AAAA55FFAAFFFFFF00AA00FFFFFFAAFF55AAAA00AA00555555AAFFFF0055FF
55555555AAFFAA00AAAAAA000000AA00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAAAAAAAAAAFFFFFF00AAFF00AA00FF0055FFAA
00FFAAAAAAFFFFAA000000AAAA005500AAAA000000AAFFFFAAAAAAFF00AAFF5500FF00AA
00FFAA00FFFFFFAAAAAAAAAAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF00FFFF00FFFFFFFFFF55AA550000FF55FF5500
00FF55AAFFFFFFFFAAAAFFAAFF55FF55FFAAFFAAAAFFFFFFFFAA55FF000055FF55FF0000
55AA55FFFFFFFFFF00FFFF00FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA5555AA00AA00AA00AAFF55555555AAAA00FF
0000AAFFFFFFFFFFFF00FF55AA55AA55AA55FF00FFFFFFFFFFFFAA0000FF00AAAA555555
55FFAA00AA00AA00AA5555AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55AAFFAAFFAA550000AAFF00AAFF55AA00
AA550000AAAA0000AA0055FF55AAAAAA55FF5500AA0000AAAA000055AA00AA55FFAA00FF
AA000055AAFFAAFFAA55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AA55FF00FFAAAAFFFFFF55AA55AAFF
AAFF0000FFFF0000FFFF5555AAAAAAAAAA5555FFFF0000FFFF0000FFAAFFAA55AA55FFFF
FFAAAAFF00FF55AA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFF555500AAAAAAAA00AAAA55FF55AA
55FF0000FF5500AA5555AAAA55FFAAFF55AAAA5555AA0055FF0000FF55AA55FF55AAAA00
AAAAAAAA005555FFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FFAAAAAAAAAAAAFFFFAA00AAFF
5555AA0055FF55FFAA00FFFFAA000000AAFFFF00AAFF55FF5500AA5555FFAA00AAFFFFAA
AAAAAAAAAAFF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFFAAFFFFAAFFFFFFFF000000
AAFF00FF00AA00FF55AA00AAAAAAFFAAAAAA00AA55FF00AA00FF00FFAA000000FFFFFFFF
AAFFFFAAFFFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA000000AAAAAA0000AAAAFFAA
AAAA0055FFFFAAAA00FFFF55AAFFFFFFAA55FFFF00AAAAFFFF5500AAAAAAFFAAAA0000AA
AAAA000000AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAAAAAAAAAAFFAAFFFFFF
AAFFFF555500FFFFAAAA00AAFFFFFFFFFFAA00AAAAFFFF005555FFFFAAFFFFFFAAFFAAAA
AAAAAAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF00FFFF00FFFFFF005555
0000AA00FFAAAA00000000FFFFFFFFFFFFFF00000000AAAAFF00AA0000555500FFFFFF00
FFFF00FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA5555AA00AA00AA55AA
AAFFAA5500FFFFAAAAFFAAAA00AA00AA00AAAAFFAAAAFFFF0055AAFFAAAA55AA00AA00AA
5555AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55AAFFAAFFAA55AA
FFFFFFAA0055FF00FFFFFF00FF00FF00FF00FFFFFF00FF5500AAFFFFFFAA55AAFFAAFFAA
55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AA55FF00FFAA
555500FFFF555500AA00AA0055FFFFFF5500AA00AA005555FFFF005555AAFF00FF55AA55
FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFF555500AAAA
AA55AA0000AAFF000055AAFFAA00AA00AAFFAA550000FFAA0000AA55AAAAAA005555FFAA
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FFAAAAAA
AAAA55FFFF55AA5500AAFFFFFFAAAAAAFFFFFFAA0055AA55FFFF55AAAAAAAAAAFF00AAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFFAAFF
55AAFF0055FF55AAAAFFFFFFFFFFAAFFFFFFFFFFAAAA55FF5500FFAA55FFAAFFFFFF55AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA000000
AAFFFFFF5555AAAAAAAA00AAAA000000AAAA00AAAAAAAA5555FFFFFFAA000000AA00AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAA
AAAA0000AAFF00FFFFAAFFAAFFFF55FFFFAAFFAAFFFF00FFAA0000AAAAAAFFAAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF00
FFFF0000FFFFFF5500FFFFFF0055FF5500FFFFFF0055FFFFFF0000FFFF00FF55AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA
5555AA00555500FFAAAA0000AA55AA55AA0000AAAAFF00555500AA5555AA00AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
AA55AAFFAA00FF00550000FF00FFAAFF00FF00005500FF00AAFFAA55AAAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
55FF55AA55FFFFFF5555555500AAAAAA0055555555FFFFFF55AA55FF55AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA00AAFF5555005555FF5555FFFFAAFFFF5555FF5555005555FFAA00AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAA00FFAAAA55AA55AAAA000000AAAA55AA55AAAAFF00AAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA55FFFFFFAAFF00FFAAFFFF55FFFFAAFF00FFAAFFFFFF55AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA00AA000055FFFFFF0055FF5500FFFFFF550000AA00AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAAAFFAA00AA00AA55AA55AA00AA00AAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA55FF00FF00FF00FFAAFF00FF00FF00FF55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA00AA555555AA000000AA555555AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA55AAAAAAFFAAAAAA55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55FF55AAFFFFFFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA00AAFF550055FFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAA00FF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55FFFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 2.78498 0.588183 2.87229 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAA00FF0055AAAAAA55000000555555FFAA55000000AA000000AA55555500000000FF
550000005500AA005555FFFFAAFF00FFAAFFFF555500AA005500000055FF000000005555
55AA000000AA00000055AAFF55555500000055AAAAAA5500FF00AAAAFF
FFFFAA550055AA55FFAA5555555555AA5555000000FF000055AA005500FF555555555555
00FF0000FFAAAAAAFF00AA00005555550000AA00FFAAAAAAFF0000FF00555555555555FF
005500AA550000FF0000005555AA5555555555AAFF55AA550055AAFFFF
FFFFFFAA0055FFAA000055FF00AAAA55FF555555555500AA55AAFFAA005555AAAA00AAAA
00555555550000550055AAFFAAAA55AAAAFFAA55005500005555555500AAAA00AAAA5555
00AAFFAA55AA005555555555FF55AAAA00FF550000AAFF5500AAFFFFFF
FFFFFFFFAAAA000055AA00AA0055000000AAFF00AAAA005500FFFFFFAAAA55AAFFFF55AA
FFAA00AAAA0055AA5500FFFFFFAA55AAFFFFFF0055AA5500AAAA00AAFFAA55FFFFAA55AA
AAFFFFFF005500AAAA00FFAA0000005500AA00AA550000AAAAFFFFFFFF
FFFFFFFFFFAA5500AAAAAAFFFF5500AA550000AA55FFAAAA0055550055000000555500FF
FFFF00005500AAAAAA5500555500000055550055AAAAAA00550000FFFFFF005555000000
5500555500AAAAFF55AA000055AA0055FFFFAAAAAA0055AAFFFFFFFFFF
FFFFFFFFFFFFAA00550000555500FF00FFAAAAFF5500550000FF555555AA0055AA555555
0055555555FFFFAAFF555555AAAAFFAAAA555555FFAAFFFF5555555500555555AA5500AA
555555FF0000550055FFAAAAFF00FF00555500005500AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA0055AAAA0055555500005555AA00AA550055FF005500AAAAAA5555
AA00AAAA00AA00005555AA55AAFFFFFFAA55AA55550000AA00AAAA00AA5555AAAAAA0055
00FF550055AA00AA5555000055555500AAAA5500AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5500FFFFAAAA5555AA0055FF00FF00FFAAAA0000FFAAAAAAAAAA55
AAFFAA55FFFFAAAAFF005500FFFFFFFFFF005500FFAAAAFFFF55AAFFAA55AAAAAAAAAAFF
0000AAAAFF00FF00FF5500AA5555AAAAFFFF0055AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA005555000055FF55AA00AA00555555000055AA00005500005500
FFFFFF0055550000555555FFFFFFFFFFFFFF5555550000555500FFFFFF00550000550000
AA55000055555500AA00AA55FF550000555500AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA00FF000000AAAAAAFFFF5555AA5500AAAAAAFFAA0055AA55
00555500AAAA0055AAAA00AA0000AA0000AA00AAAA5500AAAA0055550055AA5500AAFFAA
AAAA0055AA5555FFFFAAAAAA000000FF00AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA550055AA00550000555500FF55AA55000055005500AAFF55
5555AA55000055AA55FFAAAAAAFFAAFFAAAAAAFF55AA55000055AA555555FFAA00550055
000055AA55FF00555500005500AA550055AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA0055FFAAAA0055AAAA550055FFAA0055AAAAFF00005555
AA55AAFF0000FFAA55550000550055005500005555AAFF0000FFAA55AA55550000FFAAAA
5500AAFF550055AAAA5500AAAAFF5500AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00005500AAFFFF00AA55550000FFAAFFFFFF55FF55
0000005555555500000000FF0055AA5500FF000000005555555500000055FF55FFFFFFAA
FF00005555AA00FFFFAA00550000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AAAAFFFFFFFF55AA555555550000AA000000AA
AAFFAAAA00AAAA5500AA550055AAAAAA550055AA0055AAAA00AAAAFFAAAA000000AA0000
55555555AA55FFFFFFFFAAAA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00550000AA0000AAAAAA5555FF55FFFFAAAAFFAA
FFFFFFAA55000055FFFF0055AAAAAAAAAA5500FFFF55000055AAFFFFFFAAFFAAAAFFFF55
FF5555AAAAAA0000AA00005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055AAFFAAAAAAAAAA00AA00AA0000550055
005555000000FF00555500AAFFFF00FFFFAA00555500FF0000005555005500550000AA00
AA00AAAAAAAAAAFFAA5500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FFFFFFAAFFFF00FF00FF00FF000000FF
AAAA555555555500AAAA005500555555005500AAAA005555555555AAAAFF000000FF00FF
00FF00FFFFAAFFFFFF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00555500550055555500AA005555555555
000055FF5500FFAAAAAAAAFF0000000000FFAAAAAAAAFF0055FF550000555555555500AA
00555555005500555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FF0055AA5555FFFF000000000000
00FF005555AA0000550000555555555555550000550000AA555500FF00000000000000FF
FF5555AA5500FF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055AA55FF550055555555555555
555500AAAA55FFFF55555555AAAA55AAAA55555555FFFF55AAAA00555555555555555555
0055FF55AA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FFAA000000FF5555AA55AA55
55AAAAFFFFAA0000AAFF0055FFAA55AAFF5500FFAA0000AAFFFFAAAA5555AA55AA5555FF
000000AAFF5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA000055AA005555FF00FFAA55
55AAFFFFFFFF0000FFFFFF55550000005555FFFFFF0000FFFFFFFFAA5555AAFF00FF5555
00AA550000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AAAAAAFF005555550000
000055550055555555005555AAAAFFAAAA555500555555550055550000000055555500FF
AAAAAA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00550000555555FF555555
555555AAAAFF0055FF0000000055005500000000FF5500FFAAAA555555555555FF555555
00005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055AAAA00AA00AAAA
00AAFF00FFFFFF555500AA5500AAFFAA0055AA005555FFFFFF00FFAA00AAAA00AA00AAAA
5500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FFFFAAAAAAFFFF
0000555555005555AA55000000FFFFFF00000055AA5555005555550000FFFFAAAAAAFFFF
0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055550000550055
555555AA55AA00FFAA5555555555005555555555AAFF00AA55AA55555555005500005555
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FF000000FF
5555AAAAAA55FFFFFF00AAAA00AAFFAA00AAAA00FFFFFF55AAAAAA5555FF000000FF00AA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055AA0055
55AAAAAAAAAA0000AA00550000FFFFFF00005500AA0000AAAAAAAAAA555500AA550055AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FFAAAA
00FFFFAAFFFFAAAAFFFF555555550055555555FFFFAAAAFFFFAAFFFF00AAAAFF5500AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA000055
00AA000055550000555500FFAA00FF00AAFF005555000055550000AA00550000AAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AA
AAFFFF55FF5500AA55AA55005500AA00550055AA55AA0055FF55FFFFAAAA0055AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055
0000AA00AA00AA55FF55AA5500FF00FF0055AA55FF55AA00AA00AA00005500AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
0055AAFFAA55000000AAAAAA0055555500AAAAAA00000055AAFFAA5500AAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
5500FFFFFF0055AA0055000055AA55AA5500005500AA5500FFFFFF0055AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA0055550055AAAAAAFF0000FFAA55AAFF0000FFAAAAAA5500555500AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAA00FF00550000555555550000005555555500005500FF00AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA550055AA5500AAFF00AAAAFFAAAA00FFAA0055AA550055AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA0055FFAA00550055AAFFFFFFAA55005500AAFF5500AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAA000055AA5500FFFFFFFFFF0055AA550000AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA5500AAAAAA00555500555500AAAAAA0055AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA0055000055AA555555AA5500005500AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA0055AAAAAA55AAAAAA5500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5500FFFFAA55AAFFFF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA005555000000555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA5555555555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA5555FF5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 2.78498 0.782187 2.87229 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAA00AAFFAAFFFFAAAAAAFFAA00AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA555555
5555AAAAAAAAAAAAAAAAAAAAAA55AA55AAAAAAAAAAAAAAAAAAAAAA5555555555AAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA00AAFFAAAAAAFFFFAAFFAA00AAFF
FFFFAA00AA55555555AA555555AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA0000AA
0000AAAAAAAAAAAAAAAAAAAA00AA00AA00AAAAAAAAAAAAAAAAAAAA0000AA0000AAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA555555AA55555555AA00AAFFFF
FFFFFFAA00AA0000AA00AA0000AAAAAAAAAAAAAAAA00AAAA00AAAAAAAAAAAAAAAAAA55AA
55AAAAAAAAAAAAAAAAAAAAAA00FF55FF00AAAAAAAAAAAAAAAAAAAAAA55AA55AAAAAAAAAA
AAAAAAAA00AAAA00AAAAAAAAAAAAAAAA0000AA00AA0000AA00AAFFFFFF
FFFFFFFFAA00AAFFAAFFAAFFAAAAAAAAAAAAAAAAAAAA5555AAAAAAAAAAAAAAAAAA00AA00
AA00AAAAAAAAAAAAAAAAAAAAAA550055AAAAAAAAAAAAAAAAAAAAAA00AA00AA00AAAAAAAA
AAAAAAAAAA5555AAAAAAAAAAAAAAAAAAAAFFAAFFAAFFAA00AAFFFFFFFF
FFFFFFFFFFAA00AA555555AA00AAAA00AAAAAA00AAAA0000AAAA00AAAAAAAAAAAA00FF55
FF00AAAAAAAAAAAAAAAAAAAAAA000000AAAAAAAAAAAAAAAAAAAAAA00FF55FF00AAAAAAAA
AAAA00AAAA0000AAAA00AAAAAA00AAAA00AA555555AA00AAFFFFFFFFFF
FFFFFFFFFFFFAA00AA0000AAAAFFFFAA00AAAA00FF55AAAAFF55AAAAAAAAAAAAAAAA5500
55AAAAAAAAAAAAAAAAAAAAAA00AAFFAA00AAAAAAAAAAAAAAAAAAAAAA550055AAAAAAAAAA
AAAAAA55FFAAAA55FF00AAAA00AAFFFFAAAA0000AA00AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA00AAFFAAFFFFFFFFAA00AAAA550055FF0000AAAAAAAAAAAAAAAA0000
00AAAAAAAAAAAAAAAAAAAA00AAFFFFFFAA00AAAAAAAAAAAAAAAAAAAA000000AAAAAAAAAA
AAAAAA0000FF550055AAAA00AAFFFFFFFFAAFFAA00AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00AA555555555555AAAAAA000000AA55AAAAAAAAAAAAAAAA00AAFF
AA00AAAAAAAAAAAAAAAAAAAA5555555555AAAAAAAAAAAAAAAAAAAA00AAFFAA00AAAAAAAA
AAAAAAAA55AA000000AAAAAA555555555555AA00AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA00AA0000AA0000AAAAAAAAFFAA00AA00AAAAAAAAAAAAAAAA5555
55AAAAAA00AAAA00AAAAAAAA0000AA0000AAAAAAAA00AAAA00AAAAAA555555AAAAAAAAAA
AAAAAA00AA00AAFFAAAAAAAA0000AA0000AA00AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA00AAFFAAFFAA00AAAA00AA5555FF00AAAAAAAAAAAAAAAA0000
AA00AAAAAA55FF00AAAA00AAAAFF00FFAAAA00AAAA00FF55AAAAAA00AA0000AAAAAAAAAA
AAAAAA00FF5555AA00AAAA00AAFFAAFFAA00AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00AA555555AAAAAAAA55550055AAAAAAAAAAAAAAAAAA00FF
AA55AAFF550055AAAAAAAAFFFF000000FFFFAAAAAAAA550055FFAA55AAFF00AAAAAAAAAA
AAAAAAAA55005555AAAAAAAA555555AA00AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00AA0000AAAAAA00AA000000AAAAAAAAAAAAAAAAAA00FF
005555AA000000AAAAAA00AA5500000055AA00AAAAAA000000AA555500FF00AAAAAAAAAA
AAAAAAAA000000AA00AAAAAA0000AA00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFFAAFFFFAAAAAAFFAA00AAAAAAAAAAAAAAAAAA55
0000AA00AAFF00AAAAAAAA55550000005555AAAAAAAA00FFAA00AA000055AAAAAAAAAAAA
AAAAAA00AAFFAAAAAAFFFFAAFFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA55555555AA555555AAAAAAAAAAAAAAAAAA00AA
00FFAAFF00FF00AAAAAA00AA0000000000AA00AAAAAA00FF00FFAAFF00AA00AAAAAAAAAA
AAAAAAAA555555AA55555555AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA0000AA00AA0000AAAAAAAAAAAAAAAAAAAA55
FFFFFF000055AAAAAAAA00FF5555FF5555FF00AAAAAAAA550000FFFFFF55AAAAAAAAAAAA
AAAAAAAA0000AA00AA0000AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFFAAFFAAFFAAAAAAAAAAAAAAAAAAAAAA00
00FF00000000AAAA00AAAA55005555550055AAAA00AAAA00000000FF0000AAAAAAAAAAAA
AAAAAAAAAAFFAAFFAAFFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA555555AA00AAAA00AAAAAA00AAAA00AA
FF000000000055FF00AAAA000000AA000000AAAA00FF550000000000FFAA00AAAA00AAAA
AA00AAAA00AA555555AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA0000AAAAFFFFAA00AAAA00FF55AAAA
0055000000550055AAAA00AAFFAAAAAAFFAA00AAAA5500550000005500AAAA55FF00AAAA
00AAFFFFAAAA0000AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFFAAFFFFFFFFAA00AAAA550055FF
00AA00FFAA000000AAAAAA555555AA555555AAAAAA000000AAFF00AA00FF550055AAAA00
AAFFFFFFFFAAFFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA555555555555AAAAAA000000AA
55AA55AA00AAFFAA00AAAA0000AA00AA0000AAAA00AAFFAA00AA55AA55AA000000AAAAAA
555555555555AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA0000AA0000AAAAAAAAFFAA00
AA00AA00AAFFFFFFAA00AAAAFFAAFFAAFFAAAA00AAFFFFFFAA00AA00AA00AAFFAAAAAAAA
0000AA0000AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFFAAFFAA00AAAA00AA5555
FF00AAAA5555555555AAAA00AA555555AA00AAAA5555555555AAAA00FF5555AA00AAAA00
AAFFAAFFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA555555AAAAAAAA555500
55AAAAAA0000AA0000AAAAAA5555005555AAAAAA0000AA0000AAAAAA55005555AAAAAAAA
555555AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA0000AAAAAA00AA0000
00AAAAAAAA55AA55AAAAAA00AA000000AA00AAAAAA55AA55AAAAAAAA000000AA00AAAAAA
0000AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFFAAFFFFAAAAAAFF
AA00AAAA00AA00AA00AAAAAAFFFF55FFFFAAAAAA00AA00AA00AAAA00AAFFAAAAAAFFFFAA
FFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA55555555AA5555
55AAAAAAAA55FFFFAAAAAA00AA550055AA00AAAAAAFFFF55AAAAAAAA555555AA55555555
AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA0000AA00AA00
00AAAAAAAA0000FF00FFFFAAAA000000AAAAFFFF00FF0000AAAAAAAA0000AA00AA0000AA
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFFAAFFAAFF
AAAAAAAA00AAFF000055AA00AAAAFFAAAA00AA550000FFAA00AAAAAAAAFFAAFFAAFFAA00
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA555555AA
00AAAA00AAFFFFFF555500FFAAFFFFFFAAFF005555FFFFFFAA00AAAA00AA555555AA00AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA0000AA
AAFFFFAA00AA5500AA000000FFFFFFFFFF000000AA0055AA00AAFFFFAAAA0000AA00AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFFAA
FFFFFFFFAA00AA00FF5555FFFFFFFFFFFFFF5555FF00AA00AAFFFFFFFFAAFFAA00AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA55
5555555555AAAAAA55005555555555555555550055AAAAAA555555555555AA00AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA
0000AA0000AAAAAA000000AA0000AA0000AA000000AAAAAA0000AA0000AA00AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00
AAFFAAFFAA00AAAA00FFAAAAAAFF00FFAAAAAAFF00AAAA00AAFFAAFFAA00AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
00AA555555AAAAAAAA5500FFFF000000FFFF0055AAAAAAAA555555AA00AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA00AA0000AAAAAA00AA00FF0000000000FF00AA00AAAAAA0000AA00AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAA00AAFFAAFFFFAAAAAA55000000000055AAAAAAFFFFAAFFAA00AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA00AA55555555AA555500005500005555AA55555555AA00AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA00AA0000AA00AA00005500550000AA00AA0000AA00AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA00AAFFAAFFAAFFAA000000AAFFAAFFAAFFAA00AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA00AA555555AA00AAFFAA00AA555555AA00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA00AA0000AAAAFFFFFFAAAA0000AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA00AAFFAAFFFFFFFFFFAAFFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00AA55555555555555AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA00AA0000AA0000AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA00AAFF00FFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00AA55AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 2.78498 0.97619 2.87229 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAA000000FF55AAAA5555FFFFAAFF5555FFFF55AAAAFF55FF55FFFFFF55AAFF0000
55AA5555FF00FFAAAA55FFFFFFFFFFFFFFFFFF55AAAAFF00FF5555AA550000FFAA55FFFF
FF55FF55FFAAAA55FFFF5555FFAAFFFF5555AAAA55FF000000AAAAAAFF
FFFFAAFFFF55FFFFFF000000AA00FFAAFF00FFFFFFFF0000FF55AAAAAA5555AAFFFFFF55
FFAAFF55AAAAFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFAAAA55FFAAFF55FFFFFFAA5555
AAAAAA55FF0000FFFFFFFF00FFAAFF00AA000000FFFFFF55FFFFAAFFFF
FFFFFFAA00FFFFFFFFFF55FFFFAAAA0055FFFFFFFFFFFF55FF00FF0000FFFF0000550000
AAFFFFFF0000FF55FFFFFFFFFFFFFFFFFFFFFFFFFF55FF0000FFFFFFAA0000550000FFFF
0000FF00FF55FFFFFFFFFFFF5500AAAAFFFF55FFFFFFFFFF00AAFFFFFF
FFFFFFFFAAAA00AAAA00FFFFFFFFAAFFAA5555FF5555FF00FF55FF55FFFFFFFF55FFAAAA
FFFFFFFFFF55FF55AA5555AA5555AA5555AA5555AA55FF55FFFFFFFFFFAAAAFF55FFFFFF
FF55FF55FF00FF5555FF5555AAFFAAFFFFFFFF00AAAA00AAAAFFFFFFFF
FFFFFFFFFFAAFFAAFFFF5555AA555555AA0000AAFF55AAAAFF00FF55AA5555FF00FFAAFF
FFFFFFFFFFFF00AA00555500AA000000AA00555500AA00FFFFFFFFFFFFFFAAFF00FF5555
AA55FF00FFAAAA55FFAA0000AA555555AA5555FFFFAAFFAAFFFFFFFFFF
FFFFFFFFFFFFAA0055FF55AAFFFF00FFFFAAAAFFFFFF0000FF55FF00FF00FFFFFF5500AA
FF0055FF5555FFFFAAAAAAAAFFFF55FFFFAAAAAAAAFFFF5555FF5500FFAA0055FFFFFF00
FF00FF55FF0000FFFFFFAAAAFFFF00FFFFAA55FF5500AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA00000055FFFFFFFFAAFF0055FFFF550055FFFFFF5555AAAAAAFF
FFFF55AAAAAAAA555555555555AAAAAA555555555555AAAAAAAA55FFFFFFAAAAAA5555FF
FFFF550055FFFF5500FFAAFFFFFFFF55000000AAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF55FFFF0055FF5500AAFFAA5555AAFFAA5555FF00FFFFAAFFFF
FFFFFF0000000000AA0000AA0000FF0000AA0000AA0000000000FFFFFFFFFFAAFFFF00FF
5555AAFFAA5555AAFFAA0055FF5500FFFF55FFFFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA00FFFFFFFF55AA55FFFFAA00555500AAFFFF00FF55FF0055AAAA
5555FF55FFFF55FFFFAAAAFFFF55FF55FFFFAAAAFFFF55FFFF55FF5555AAAA5500FF55FF
00FFFFAA00555500AAFFFF55AA55FFFFFFFF00AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA00AAAA0000FFFFFFFFAAAAAAAAFFFFFFFF550055FFFF0000
FFFF005555AAAAAA55AA0055FF55AA55FF5500AA55AAAAAA555500FFFF0000FFFF550055
FFFFFFFFAAAAAAAAFFFFFFFF0000AAAA00AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFAAFFFF55FF00550000000000FF5555AAAAAAFF5555FFFF
5555FFFF00FF0000FFFFAAAAAA000000AAAAAAFFFF0000FF00FFFF5555FFFF5555FFAAAA
AA5555FF00000000005500FF55FFFFAAFFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA0055FF55AAAAFF55FFFF55FFFFFF00FF0000FFAA55FF55
005555FF55FF55FFFFFFFFAAFFFF55FFFFAAFFFFFFFF55FF55FF55550055FF55AAFF0000
FF00FFFFFF55FFFF55FFAAAA55FF5500AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA000000FF55AAAA55FF5555FFFFFF55FF0000AAAA
AAFF55AAAAAA55FF5555FF00005500550000FF5555FF55AAAAAA55FFAAAAAA0000FF55FF
FFFF5555FF55AAAA55FF000000AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55FFFFFF000000AAFF55AA55AA55FF55FFFFAA
FFFFFF000000FFFFFF00FFAAAAFF55FFAAAAFF00FFFFFF000000FFFFFFAAFFFF55FF55AA
55AA55FFAA000000FFFFFF55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFFFFFFFF55FFFFAA0000FFFFAA5555000055
AA5555FFFF55FF5555FFFFFFAAFF00FFAAFFFFFF5555FF55FFFF5555AA5500005555AAFF
FF0000AAFFFF55FFFFFFFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAA00FFFFFFFFAAAAFF0055AAFF55FFFF
0000AA00AAFF55550055FF5500AAFFAA0055FF55005555FFAA00AA0000FFFF55FFAA5500
FFAAAAFFFFFFFF00AAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAFFFF5555AA55555555FFFF00005555AA
AAFFAAFFAAFF00FFFF55AAAAAAFFFFFFAAAAAA55FFFF00FFAAFFAAFFAAAA55550000FFFF
55555555AA5555FFFFAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FF55AAFFFF00FFFF0055FFFF55AAFF
FFAA005500AAFFAA00FFFFAAFFFFFFFFFFAAFFFF00AAFFAA005500AAFFFFAA55FFFF5500
FFFF00FFFFAA55FF5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00000055FFFFFFFF55AA55AAFFFF
FFFFAAAAAAFFFFFFAAAA00AA5555FF5555AA00AAAAFFFFFFAAAAAAFFFFFFFFAA55AA55FF
FFFFFF55000000AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55FFFF0055FF550055AAFFFFFF
FFFFFFAAFFFFFFFFFFAAFFAAFF55AA55FFAAFFAAFFFFFFFFFFAAFFFFFFFFFFFFAA550055
FF5500FFFF55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFFFFFF55AA55FFFF00005500
FF5500FF0055FF550000FFAAFF00FF00FFAAFF000055FF5500FF0055FF00550000FFFF55
AA55FFFFFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAA0000FFFFFFFF55FFAA
AA55FFFFFF55AAAAAAFFAA0055FFFFFF5500AAFFAAAAAA55FFFFFF55AAAAFF55FFFFFFFF
0000AAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAFFFF55FF005500FFFFFF
AAFF5555FF00FF0000FFAAFFAA55AA55AAFFAAFF0000FF00FF5555FFAAFFFFFF005500FF
55FFFFAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FF55AAAAFF55FF00AA
FFFFFF00FF55FF55FFFFFFAA0055555500AAFFFFFF55FF55FF00FFFFFFAA00FF55FFAAAA
55FF5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA000000FF55AAAAFF
FFFFFFFF555500FFFFFFFFFFAAAAAAAAAAFFFFFFFFFF005555FFFFFFFFFFAAAA55FF0000
00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55FFFFFF0000FF
5555AA55AAFF55FF0055FF55555555555555FF5500FF55FFAA55AA5555FF0000FFFFFF55
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFFFFFFFF55FF
00FFFFAA5500FFFFFF55AAAAAAAAAAAAAAAAAA55FFFFFF0055AAFFFF00FF55FFFFFFFFFF
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAA00FFFF
FF550000FFFF5500005555555555555555555555000055FFFF000055FFFFFF00AAAA00AA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAFFFF5555
AA55FFFF5555AAFFAAAAAAAAAAAAAAAAAAAAAAAAAAFFAA5555FFFF55AA5555FFFFAAFFAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FF55AA
FFFF0055FFAA5500FF000000FF000000FF000000FF0055AAFF5500FFFFAA55FF5500AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA0000
0055FFFF00AA55FFFFFF55FFFFFF55FFFFFF55FFFFFF55AA00FFFF55000000AAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55
FFFF0055FFFFAA5555FF55AA55AAAAAA55AA55FF5555AAFFFF5500FFFF55FFFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF
FFFFFF55AAAA55005555AAFFFF000000FFFFAA55550055AAAA55FFFFFFFF00AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
00AAAA000000FFFF55AAFFFFFFFF55FFFFFFFFAA55FFFF000000AAAA00AAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
FFAAFFFF55FFFFFFFF000055FF550055FF550000FFFFFFFF55FFFFAAFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA0055FF55AAAA55AAAAFFAA55AAFFAA55AAFFAAAA55AAAA55FF5500AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAA0000FF00FF000055AAFFFFFFAA550000FF00FF0000AAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFF55FF55FF55FFFF0000550000FFFF55FF55FF55FFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA00FFFFFF00AA00AAFFAAAAAAFFAA00AA00FFFFFF00AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAA00AAFFAAFFAAFF000000FFAAFFAAFFAA00AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFFAAFF000055AAAAFFAAAA550000FFAAFFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA0055FFFF55AA005500AA55FFFF5500AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA00FFFFAAAAAAFFFF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF550000FF000055FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA00FFFF55FF55FFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA00AA00AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFAAFFAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 2.88102 0.200176 2.96833 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAA550055FFFFFF55000055AAAAFF55FF00000000FFFFFFFF5500AAAAFF55FF000000
0000000000000000000000000000AA0000000000000000000000000000000000FF55FFAA
AA0055FFFFFFFF00000000FF55FFAAAA55000055FFFFFF550055AAAAFF
FFFFAAFF00000055000000AA00FF5500000055555555000055000000FF55000000555555
55555555555555555555555500AA00AA0055555555555555555555555555555500000055
FF0000005500005555555500000055FF00AA00000055000000FFAAFFFF
FFFFFFAA5500AA00FF0000AAAAFF55550055AAAA55AAAAFFAA005555000000FF00000000
00000000000000000000000000FF55FF0000000000000000000000000000000000FF0000
00555500AAFFAAAA55AAAA55005555FFAAAA0000FF00AA0055AAFFFFFF
FFFFFFFFAA0055FFFF0000FF5500000000AAFFFFAA00AAAAAA00000000AA000055555555
5555555555555555555555555500000055555555555555555555555555555555550000AA
00000000AAAAAA00AAFFFFAA0000000055FF0000FFFF5500AAFFFFFFFF
FFFFFFFFFFAAAA55FFAAAAFF555500555555AAFF5500AAAA00AA5500AA00AA0000000000
0000000000000000000000000000AA00000000000000000000000000000000000000AA00
AA0055AA00AAAA0055FFAA555555005555FFAAAAFF55AAAAFFFFFFFFFF
FFFFFFFFFFFFAAFF00FF5500000000FFAA00FF55AAAAFFFFAAAA00FF005555AA00555555
55555555555555555555555500AA00AA0055555555555555555555555555555500AA5555
00FF00AAAAFFFFAAAA55FF00AAFF0000000055FF00FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA55000000AA55005500FF00FFAAFFFFFF0055FFFFFF5555FF00000000
00000000000000000000000000FF55FF0000000000000000000000000000000000FF5555
FFFFFF5500FFFFFFAAFF00FF00550055AA00000055AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA0055AA00AAFFAA0055005500FFFFFF000000550000000055555500
555555555555555555555555550000005555555555555555555555555500555555000000
0055000000FFFFFF0055005500AAFFAA00AA5500AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA555555AAFFFF555555FFFFFFFF0000FF00AA0000AA00FFAA00
0000000000000000000000000000AA000000000000000000000000000000AAFF00AA0000
AA00FF0000FFFFFFFF555555FFFFAA555555AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF00AAFFFF00FFAA00FFFFFF00FF000055AA550055FFFF0055
55555555555555555555555500AA00AA005555555555555555555555555500FFFF550055
AA550000FF00FFFFFF00AAFF00FFFFAA00FFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA5500FFFF000055FFFFFFFF0000555555FF00AA00FFFF0000
00000000000000000000000000FF55FF000000000000000000000000000000FFFF00AA00
FF5555550000FFFFFFFF550000FFFF0055AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00550000AA00FFFFFF00FF000000000055AA5500005555
55555555555555555555555555000000555555555555555555555555555555000055AA55
0000000000FF00FFFFFF00AA00005500AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAA550055FFFFFFFF000055AA00555555FF00AA000000
0000000000000000000000000000AA0000000000000000000000000000000000AA00FF55
555500AA550000FFFFFFFF550055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF000000550000555555FF000000000055AA550055
AA0000AA550055555555555500AA00AA005555555555550055AA0000AA550055AA550000
000000FF555555000055000000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AA00FF0000000000555500555555FF00AA00
FF55FFFFAA0000000000000000FF55FF0000000000000000AAFFFF55FF00AA00FF555555
0055550000000000FF00AA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FFFF0000FF0000FFAA000000000055AA55
0000005500FF0000AA0055555500000055555500AA0000FF005500000055AA5500000000
00AAFF0000FF0000FFFF5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FFAAAAFF55FFFF0055555500AA00FF55
55555555FFFFFF55FF0000000000AA0000000000FF55FFFFFF5555555555FF00AA005555
5500FFFF55FFAAAAFF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FF550000005500AAFF00AA55550000
00000000005500000055555500AA00AA0055555500000055000000000000005555AA00FF
AA005500000055FF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55000000AA000000FF55AA00AAFF0000
AA5500AA000000FF0000000000FF55FF0000000000FF000000AA0055AA0000FFAA00AA55
FF000000AA00000055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AA00AA0055AAFF005555AAFFAA
AA00FF0055550055005555555500000055555555005500555500FF00AAAAFFAA555500FF
AA5500AA00AA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA555555AA00FF55AA00FFAAFF55
00FF00FF00AAFFAA000000000000FF000000000000AAFFAA00FF00FF0055FFAAFF00AA55
FF00AA555555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00AAFFFF55AAAA000055FFAA
0055005500AAAAAA0000FF0000FF00FF0000FF0000AAAAAA0055005500AAFF550000AAAA
55FFFFAA00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FFFF00AAAA005555FFAA
FFAA000000AAAA00AA00550055AAFFAA55005500AA00AAAA000000AAFFAAFF555500AAAA
00FFFF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00550000AAAA0000000055
FFAAFFAAAAFFFFAAAA000000AAFFFFFFAA000000AAAAFFFFAAAAFFAAFF5500000000AAAA
00005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA550055FF0000AA0000
0055FFAAFFFF00FF5500555500FFFFFF0055550055FF00FFFFAAFF55000000AA0000FF55
0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF000000555555AA00
00AAFF55000055AAFF00000000FFFFFF00000000FFAA55000055FFAA0000AA5555550000
00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AA00FFAA00AA
0055FFAA0000AAFFFF0000AA0000550000AA0000FFFFAA0000AAFF5500AA00AAFF00AA00
55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FFFFFFAAAA
00000055FFFF550000555500FF000000FF005555000055FFFF55000000AAAAFFFFFF5500
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FFAA5555
AA005555FFAA55AA00000000FFFF55FFFF00000000AA55AAFF555500AA5555AAFF55AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FF5555
FF0000000055FF5500AA550055000000550055AA0055FF5500000000FF5555FF00FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55000000
0055550055AAAAAA5500FFAAAA550055AAAAFF0055AAAAAA550055550000000055AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AA
00000000FFAAFFFFAA005500FF555555FF005500AAFFFFAAFF00000000AA5500AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55
5500AA005500FFFFFFAAAA55000000000055AAAAFFFFFF005500AA005555AAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
00AA555555FFFFFFFFFFAAFF0000FF0000FFAAFFFFFFFFFF555555AA00FFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
5500FFAA00FFFFFFFFFFFFAA5500550055AAFFFFFFFFFFFF00AAFF0055AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA005500FF00FFFFFFFFFFFFAA000000AAFFFFFFFFFFFF00FF005500AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAA550000FFFFFFFFFFFF0055555500FFFFFFFFFFFF000055AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFF0000FFFFFFFFFFFF0000000000FFFFFFFFFFFF0000FFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA550055000055000055555555550000550000550055AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA000000AA55AA00000000000000AA55AA000000AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAFFAAFF005555550055555500FFAAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFF550000FFAA00FF00AAFF000055FFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA55AA005500FF00FF005500AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00AA00FF00FF00FF00AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA00550055005500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFAA000000AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA5555005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 2.88102 0.39418 2.96833 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAFF55AAAAAAAA00AAAA00AA000055FFFFAAAA0000AA0000AAAAAAAAAAAAAAAA55AA
AA000000AAAA00AA00AAAA0000FFFFFF0000AAAA00AA00AAAA000000AAAA55AAAAAAAAAA
AAAAAA0000AA0000AAAAFFFF550000AA00AAAA00AAAAAAAA55FFAAAAFF
FFFFAAFF55550055AA00AA550000AAAA00FFFF0000AAAA00000000AA0000AA0000AA00FF
0000005500AA00AA00AA0055FFFFFFFFFF5500AA00AA00AA0055000000FF00AA0000AA00
00AA00000000AAAA0000FFFF00AAAA000055AA00AA55005555FFAAFFFF
FFFFFFAA55AAAAFF000000FFAAAA0000AAAAAAAA00AA000000000000AAAA00000000AAAA
AA00AAAA555500FF005555AAAAAAAAAAAAAA555500FF005555AAAA00AAAAAA00000000AA
AA000000000000AA00AAAAAAAA0000AAAAFF000000FFAAAA55AAFFFFFF
FFFFFFFFAA0000FFFF55FFFF0000AAAA0000AA000000AAAA00AAAA00AA000000000000AA
000000AA00FFAAAAAAFF00AA0000FF0000AA00FFAAAAAAFF00AA000000AA000000000000
AA00AAAA00AAAA000000AA0000AAAA0000FFFF55FFFF0000AAFFFFFFFF
FFFFFFFFFFAAAAFF55AAAAAAAA00AA0000550055FF00555500FF000000FF550000550000
AAAAFFAAFFAA550055AAFFAAFFAAAAAAFFAAFFAA550055AAFFAAFFAAAA000055000055FF
000000FF00555500FF5500550000AA00AAAAAAAA55FFAAAAFFFFFFFFFF
FFFFFFFFFFFFAAFF55550055AA00AA5555AAAA00FFFF5555FFFFFF55FFFF00AAAAFF0055
0055AAFFFFFFAA00AAFFFFFFAA550055AAFFFFFFAA00AAFFFFFFAA55005500FFAAAA00FF
FF55FFFFFF5555FFFF00AAAA5555AA00AA55005555FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA55AAAAFF000000FFAA0000AAAAAAAA55AAFF55AAAAAAAA0055AAFFAA
00AAFFFFFFFF000000FFFFFFFFAA00AAFFFFFFFF000000FFFFFFFFAA00AAFFAA5500AAAA
AAAA55FFAA55AAAAAAAA0000AAFF000000FFAAAA55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA0000FFFF55FFFF00000000AA0000AAFFFF00AA0000AA00AAFFFF00
0000FFFFFFFFFF5500FFFFFFFF000000FFFFFFFF0055FFFFFFFFFF000000FFFFAA00AA00
00AA00FFFFAA0000AA00000000FFFF55FFFF0000AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAFF55AAAAAAAA00AAAA00000000FFFF0055AA55550000FFFFFF
5500FFFFFFFFFF00AAAAAAAAAAAA00AAAAAAAAAAAA00FFFFFFFFFF0055FFFFFF00005555
AA5500FFFF00000000AAAA00AAAAAAAA55FFAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF55550055AA00AA55000055FFFFFFFF555555FF5500FFFFFF
00AAAAAAAAAAAAAA0000FF0000AA00AA0000FF0000AAAAAAAAAAAAAA00FFFFFF0055FF55
5555FFFFFFFF55000055AA00AA55005555FFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55AAAAFF000000FFAAAA00FFFFFFFF00AAFF00FFAAAAAAAA
AA0000AA550055AA00AAAAAA00AA00AA00AAAAAA00AA550055AA0000AAAAAAAAAAFF00FF
AA00FFFFFFFF00AAAAFF000000FFAAAA55AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA0000FFFF55FFFF0000AAAAAAAAAAAAFFFFFF55AA0000FF
00000000AAFFAA000000AA000055AA550000AA000000AAFFAA00000000FF0000AA55FFFF
FFAAAAAAAAAAAA0000FFFF55FFFF0000AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55AAAAAAAA00AA0000AA0000FFFFFF00AA00AAAA
AA00AAAAFFFF0000000000AAAA00FF00AAAA0000000000FFFFAAAA00AAAAAA00AA00FFFF
FF0000AA0000AA00AAAAAAAA55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55550055AA00AA5555AA00AAAAAAAAAA00005555
550000AA55FFAAAAFFAAAA0000AAAAAA0000AAAAFFAAAAFF55AA00005555550000AAAAAA
AAAA00AA5555AA00AA55005555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAAFF000000FFAA000000AA0000AA00AAAA55
AAAA00AA55AAFFFFAA5500550000FF0000550055AAFFFFAA55AA00AAAA55AAAA00AA0000
AA000000AAFF000000FFAAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000FFFF55FFFF0000000000AAAA000000AA55
AA000000AAFFFFFFFFAA00AAFFAAAAAAFFAA00AAFFFFFFFFAA000000AA55AA000000AAAA
0000000000FFFF55FFFF0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55AAAAAAAA00AAAA00AA000055FFFFAA
0000000000FFFFFFFF000000FFFFAAFFFF000000FFFFFFFF0000000000AAFFFF550000AA
00AAAA00AAAAAAAA55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55550055AA00AA550000AAAA00FFFF00
00000055FFFFFFFFFFFF55FFFF00FF00FFFF55FFFFFFFFFFFF5500000000FFFF00AAAA00
0055AA00AA55005555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAAFF000000FFAAAA0000AAAAAAAA
00AAAAFF00FFFFFFFF00FFAA55FFFFFF55AAFF00FFFFFFFF00FFAAAA00AAAAAAAA0000AA
AAFF000000FFAAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000FFFF55FFFF0000AAAA0000AA00
0000AA55FF00FFFF00FF55AA00FFFFFF00AA55FF00FFFF00FF55AA000000AA0000AAAA00
00FFFF55FFFF0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55AAAAAAAA00AA0000550055
FF005555FFAAAAAAAAFF555500FFFFFF005555FFAAAAAAAAFF555500FF5500550000AA00
AAAAAAAA55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55550055AA00AA5555AAAA00
FFFF5555FFAAFFFFAAFF5555FFFFFFFFFF5555FFAAFFFFAAFF5555FFFF00AAAA5555AA00
AA55005555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAAFF000000FFAA0000AA
AAAAAA55AAFFFFFFFFAA55AAAAAAAAAAAAAA55AAFFFFFFFFAA55AAAAAAAA0000AAFF0000
00FFAAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000FFFF55FFFF00000000
AA0000AAFFFFFFFFFFFFAA00555500555500AAFFFFFFFFFFFFAA0000AA00000000FFFF55
FFFF0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55AAAAAAAA00AAAA
00000000FFFFFFFFFFFFFFAAAA55AA55AAAAFFFFFFFFFFFFFF00000000AAAA00AAAAAAAA
55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55550055AA00AA55
000055FFFFFFFFFFFFFFFF0000FFAAFF0000FFFFFFFFFFFFFFFF55000055AA00AA550055
55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAAFF000000FF
AAAA00FFFFFFFFFFFFFFFF0055FFAAFF5500FFFFFFFFFFFFFFFF00AAAAFF000000FFAAAA
55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000FFFF55FFFF
0000AAAAAAAAAAAAAAAAAAAAFF00FF00FFAAAAAAAAAAAAAAAAAAAA0000FFFF55FFFF0000
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55AAAAAA
AA00AA0000AA0000FF0000AA55FFFFFF55AA0000FF0000AA0000AA00AAAAAAAA55FFAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55550055
AA00AA5555AA00AAAAAA00AA00FFFFFF00AA00AAAAAA00AA5555AA00AA55005555FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAAFF
000000FFAA000000AA000000AAAAAAAAAA000000AA000000AAFF000000FFAAAA55AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000FF
FF55FFFF0000000000AAAA00AA550055AA00AAAA0000000000FFFF55FFFF0000AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF
55AAAAAAAA00AAAA00AA550000AAFFAA000055AA00AAAA00AAAAAAAA55FFAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
55550055AA00AA5500FF00AAAAFFFFFFAAAA00FF0055AA00AA55005555FFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
55AAAAFF000000FFAAAAAA0000FFFFFF0000AAAAAAFF000000FFAAAA55AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA0000FFFF55FFFF0000AA00AAAAAAAAAA00AA0000FFFF55FFFF0000AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAFF55AAAAAAAA00AA55555500555555AA00AAAAAAAA55FFAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFF55550055AA00AA00FFAA00AAFF00AA00AA55005555FFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA55AAAAFF000000FF55AA00AA55FF000000FFAAAA55AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA0000FFFF55FFFF00AA00AA00FFFF55FFFF0000AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAFF55AAAAAAAA000000AAAAAAAA55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFF555500AA0000000000AA005555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA55AAAA00550000005500AAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA005555AAAA00AAAA555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA55AA000000AA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF0000000000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA5555AA5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 2.88102 0.588183 2.96833 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAA005555FF00AA55FFFFFFFF00FF00FF0055AA5555AAAAAAAA00FFFF00000000FF00FF
00FF55AA55AAAAAAAAFFAA55AAAA55AAAA55AAFFAAAAAAAA55AA55FF00FF00FF00000000
FFFF00AAAAAAAA5555AA5500FF00FF00FFFFFFFF55AA00FF555500AAFF
FFFFAA00AAAAAA5500FFFFFFFFFF55AAAAAA555555AA55000055AAAAAAAA55AAAA55FFFF
FF55AA5500FF0000FF00FF0055AA00AA5500FF00FF0000FF0055AA55FFFFFF55AAAA55AA
AAAAAA55000055AA555555AAAAAA55FFFFFFFFFF0055AAAAAA00AAFFFF
FFFFFFAA00555555AAAAAAAAAAAAAA0055AA00AAAA0055FF5555AA0000AA555500AAAAAA
AAAA0055FF55AAAA55FF55AAAA000000AAAA55FF55AAAA55FF5500AAAAAAAAAA005555AA
0000AA5555FF5500AAAA00AA5500AAAAAAAAAAAAAA55555500AAFFFFFF
FFFFFFFFAA00AAAA005500AA550055AAAA0000005555FF00FF550000000055FF00AA5500
00FF00AAAAAA0000AAAAAA0000AAFFAA0000AAAAAA0000AAAAAA00FF000055AA00FF5500
00000055FF00FF5555000000AAAA550055AA005500AAAA00AAFFFFFFFF
FFFFFFFFFFAA005555FF00AA5555FF0000AAFFAA00AAAAAA55FF00AAFF00AAAAAA5500FF
AAAAAA550055AAAA550055AAAAFFFFFFAAAA550055AAAA550055AAAAAAFF0055AAAAAA00
FFAA00FF55AAAAAA00AAFFAA0000FF5555AA00FF555500AAFFFFFFFFFF
FFFFFFFFFFFFAA00AAAAAA5500FF55AAAAFFFFFFAA005500AAAAAAFFFF00AA550055FFFF
000055AA55AA550055FF550000FFFFFF000055FF550055AA55AA550000FFFF550055AA00
FFFFAAAAAA005500AAFFFFFFAAAA55FF0055AAAAAA00AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA00555555AAAAAA0000FFFFFFFFAAAA00FF0000FFFF00AA5555FF00FF
FF5555AA00AA5555FF00FF55FFFFFFFFFF55FF00FF5555AA00AA5555FFFF00FF5555AA00
FFFF0000FF00AAAAFFFFFFFF0000AAAAAA55555500AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00AAAA005500AAFF00FFFFFFFFAAFFAA55AAAAAAAA5500FF55AAAA
AAAA00AA55AA00AAAAAA55FF00FFFFFF00FF55AAAAAA00AA55AA00AAAAAAAA55FF0055AA
AAAAAA55AAFFAAFFFFFFFF00FFAA005500AAAA00AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA005555FF00AA55FFFFFFFF00FF00FF005500550055FFFF005500
00FF00AA00AA55AA0055AA55FFFFFFFFFF55AA5500AA55AA00AA00FF00005500FFFF5500
55005500FF00FF00FFFFFFFF55AA00FF555500AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA00AAAAAA5500FFFFFFFFFF55AAAAAA5555FF00AAAAAAAA5555
FFFF00AA55AA00AA55AA5500FFFFFFFFFF0055AA55AA00AA55AA00FFFF5555AAAAAAAA00
FF5555AAAAAA55FFFFFFFFFF0055AAAAAA00AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00555555AAAAAAAAAAAAAA0055AA00AAAAAA550055AA00AA
AAAAAA5500FF00AA555555AAAAAAAAAAAAAA555555AA00FF0055AAAAAAAA00AA550055AA
AAAA00AA5500AAAAAAAAAAAAAA55555500AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00AAAA005500AA550055AAAA000000555555AAAA000000
55555555AAAAAA5500FF55005500AA00550055FF0055AAAAAA55555555000000AAAA5555
55000000AAAA550055AA005500AAAA00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAA005555FF00AA5555FF0000AAFFAA00AAAA0000AAFFAA
AA00AAAA00555555AAAAAA00FF555555FF00AAAAAA55555500AAAA00AAAAFFAA0000AAAA
00AAFFAA0000FF5555AA00FF555500AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAAAAA5500FF55AAAAFFFFFFAA0055AAAAFFFF00
00AAFFFFAA00AAAA000055AAAAAA00AAAAAA550000AAAA00AAFFFFAA0000FFFFAAAA5500
AAFFFFFFAAAA55FF0055AAAAAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00555555AAAAAA0000FFFFFFFFAAAA0000FFFF00
AAFFFFFFFFAA0055AAAA555555000000555555AAAA5500AAFFFFFFFFAA00FFFF0000AAAA
FFFFFFFF0000AAAAAA55555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAAA005500AAFF00FFFFFFFFAAFFAAAAAAAA
FFFFFFFFFFFFAAAA0000AAAA00AAFFAA00AAAA0000AAAAFFFFFFFFFFFFAAAAAAAAFFAAFF
FFFFFF00FFAA005500AAAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005555FF00AA55FFFFFFFF00FF00FF0000FF
00FFFFFFFFFFFFAAFFAA0000AAFFFFFFAA0000AAFFAAFFFFFFFFFFFF00FF0000FF00FF00
FFFFFFFF55AA00FF555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAAAAA5500FFFFFFFFFF55AAAAAA55AA
FF00FFFFFFFF00FF00FF00AAFFFFFFFFFFAA00FF00FF00FFFFFFFF00FFAA55AAAAAA55FF
FFFFFFFF0055AAAAAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00555555AAAAAAAAAAAAAA0055AA00AA
55FFFFFFFFFFFF55AAAAAAFFFFFFFFFFFFFFAAAAAA55FFFFFFFFFFFF55AA00AA5500AAAA
AAAAAAAAAA55555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAAA005500AA550055AAAA000000
AAAAAAAAAAAAAAAA0000FF00FFFFFFFFFF00FF0000AAAAAAAAAAAAAAAA000000AAAA5500
55AA005500AAAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005555FF00AA5555FF0000AAFFAA
0000AA0000AA0055AAAA55FFFFFFFFFFFFFF55AAAA5500AA0000AA0000AAFFAA0000FF55
55AA00FF555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAAAAA5500FF55AAAAFFFFFF
AA00FF00AAFFFF55005500FFFFFFFFFFFFFF00550055FFFFAA00FF00AAFFFFFFAAAA55FF
0055AAAAAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00555555AAAAAA0000FFFFFF
FFAAAAAAFFFF00FF5555AAAAAAAAAAAAAAAAAA5555FF00FFFFAAAAAAFFFFFFFF0000AAAA
AA55555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAAA005500AAFF00FFFF
FFFFAAFFFFFFFF55AA5555005500550055005555AA55FFFFFFFFAAFFFFFFFF00FFAA0055
00AAAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005555FF00AA55FFFFFF
FF00FF00FFFFFF005555AA55AA55AA55AA55AA555500FFFFFF00FF00FFFFFFFF55AA00FF
555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAAAAA5500FFFFFF
FFFF55AAAAAAAAAA5555AA00AA00AA00AA00AA5555AAAAAAAAAA55FFFFFFFFFF0055AAAA
AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00555555AAAAAAAA
AAAAAA0055550000FF55000000FFAAFF00000055FF0000555500AAAAAAAAAAAAAA555555
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAAA005500AA
550055AAAA00AAFF00FF55FF55FFAAFF55FF55FF00FFAA00AAAA550055AA005500AAAA00
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005555FF00AA
5555FF0000AAFFFFFF55AA55FF00FF00FF55AA55FFFFFFAA0000FF5555AA00FF555500AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAAAAA55
00FF55AAAAFFFFFFFF0055AA55FFFFFF55AA5500FFFFFFFFAAAA55FF0055AAAAAA00AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00555555
AAAAAA0000FFFFFFFFFF5500AAAAAAAAAA0055FFFFFFFFFF0000AAAAAA55555500AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAAA
005500AAFF00FFFFFF00FF55555555555555FF00FFFFFF00FFAA005500AAAA00AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055
55FF00AA55FFFFFFFFFF55AA5555AA5555AA55FFFFFFFFFF55AA00FF555500AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00
AAAAAA5500FFFFFFFFFF0055AA555555AA5500FFFFFFFFFF0055AAAAAA00AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
00555555AAAAAAAAAAAAAA555555AA555555AAAAAAAAAAAAAA55555500AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA00AAAA005500AA55005555AA555555AA55550055AA005500AAAA00AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAA005555FF00AA5555FF005555AA555500FF5555AA00FF555500AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA00AAAAAA5500FF55AAAA00AA00AAAA55FF0055AAAAAA00AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA00555555AAAAAA0000FFAAFF0000AAAAAA55555500AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA00AAAA005500AAFF00FF00FFAA005500AAAA00AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA005555FF00AA55FFFFFF55AA00FF555500AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA00AAAAAA5500FFFFFF0055AAAAAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA00555555AAAAAAAAAA55555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00AAAA0000FF0000AAAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA005555FFFFFF555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA00AAAAAAAAAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA0000AA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 2.88102 0.782187 2.96833 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAFF55FFAAAA000000AAAA5555FFFF550000AAFF55FF00AAFF5555555555555555
FFFF55FF55FFFFAAAAAAFF55FFAAAAAAFF55FFAAAAAAFFFF55FF55FFFF55555555555555
55FFAA00FF55FFAA000055FFFF5555AAAA000000AAAAFF55FFAAAAAAFF
FFFFAAFF5555AAAAAAAAFFAAAAAAAA00AA00FF55FFFFAA00AAFFAAFF0055AA55555555AA
55AAAA00FF5555FFAAFF5555AAAAAAAAAA5555FFAAFF5555FF00AAAA55AA55555555AA55
00FFAAFFAA00AAFFFF55FF00AA00AAAAAAAAFFAAAAAAAA5555FFAAFFFF
FFFFFFAA00AA55FFAAFFFFFF00FFFFAAAAAAFF005555FFAAAAAA55FF55FF00FF0000FF00
FF00FFFF55555555FFAA00AAAAAAAAAAAAAA00AAFF55555555FFFF00FF00FF0000FF00FF
55FF55AAAAAAFF555500FFAAAAAAFFFF00FFFFFFAAFF55AA00AAFFFFFF
FFFFFFFFAAAAAA00FFFFFFFFFF5555FFAAFFFFFF5500AAFFFF00FF555555FFFFFF55FF55
FF55FF555555555555FFAAAAAAAAAAAAAAAAAAFF555555555555FF55FF55FF55FFFFFF55
5555FF00FFFFAA0055FFFFFFAAFF5555FFFFFFFFFF00AAAAAAFFFFFFFF
FFFFFFFFFFAAFF55FF5555FF55555555FFAA0000AAAAFFFFFFFF5555AA5555FF555555FF
00AAAA55555555555555FFAAFFFFAAFFFFAAFF55555555555555AAAA00FF555555FF5555
AA5555FFFFFFFFAAAA0000AAFF55555555FF5555FF55FFAAFFFFFFFFFF
FFFFFFFFFFFFAA00AA00AAAA5555555555FFAAAAFFFFAA00FFAA00AAAAAA00AA00AA5555
FFFFAA555555AA55555555FFAA000000AAFF55555555AA555555AAFFFF5555AA00AA00AA
AAAA00AAFF00AAFFFFAAAAFF5555555555AAAA00AA00AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAFF55AA00AAAA00AAFF55AAAA55FFFFFFAAAAAAAAAAFFFF55AA55
55FF55AA00AAAAAA00AAAA00FFFF55FFFF00AAAA00AAAAAA00AA55FF5555AA55FFFFAAAA
AAAAAAFFFFFF55AAAA55FFAA00AAAA00AA55FFAAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF5555AAFFAA55FFFF00AAAAAAAA0000AAFFFFAAFFFFAA00FF00FF
0000AA55FFFFAAFF55FFAAFFAA00FF00AAFFAAFF55FFAAFFFF55AA0000FF00FF00AAFFFF
AAFFFFAA0000AAAAAAAA00FFFF55AAFFAA5555FFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA00AA55FF55AA55AAAAFFFF00FFFF55FFAA000000AAFF55FF55FF
55FFFF0000AAFF5555AAAAAA55FFFFFF55AAAAAA5555FFAA0000FFFF55FF55FF55FFAA00
0000AAFF55FFFF00FFFFAAAA55AA55FF55AA00AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAA00FF00FF00FFFFFFFF555500AAFF55FFFF55AAAA00FF55
5555FF55FFFFAA00AA55FFAA5555005555AAFF55AA00AAFFFF55FF555555FF00AAAA55FF
FF55FFAA005555FFFFFFFF00FF00FF00AAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFF55FF55FF55FF55550000FF55FFAA005555FF00FFFF5555
55AA00FF5555FFAAAAAA000000FF55FF000000AAAAAAFF5555FF00AA555555FFFF00FF55
5500AAFF55FF00005555FF55FF55FF55FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00AA00AA00AA0055FFFF555555FFAAAA00AAFFAA00FF00
00FFFF55555555FFAAFF55FFFF555555FFFF55FFAAFF55555555FFFF0000FF00AAFFAA00
AAAAFF555555FFFF5500AA00AA00AA00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF55FFAAAA0000AAAA00AAFFFFAAAAAA55FFFFFF
55FF555555555555FFAA00AA0000FF0000AA00AAFF555555555555FF55FFFFFF55AAAAAA
FFFFAA00AAAA0000AAAAFF55FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555AAAAAAAAFFAA55FFFFAA0000000000FFAA00
FF55555555555555AAAAAAFFFF55FF55FFFFAAAAAA55555555555555FF00AAFF00000000
00AAFFFF55AAFFAAAAAAAA5555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA55FFAAFFFFFF0000AAFF55FFFF55FFFFFFAA
AA55555555AA00AA55FFAAFF00AA55AA00FFAAFF55AA00AA55555555AAAAFFFFFF55FFFF
55FFAA0000FFFFFFAAFF55AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FFFFFFFFFF55FFAA00AA00FF55550000
0000FF0000FFFF55AA00FFFFFF55AA55FFFFFF00AA55FFFF0000FF000000005555FF00AA
00AAFF55FFFFFFFFFF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FF5555FF555555FFAAAAAAFF0055FFFF
55FFFFFF55FF5555AAFFAA0000AAAAAA0000AAFFAA5555FF55FFFFFF55FFFF5500FFAAAA
AAFF555555FF5555FF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA00AAAA55555555FFAAFFFFFF550000
AAAA55AAAA0000FF00FFAAFFAAAAAAAAAAFFAAFF00FF0000AAAA55AAAA000055FFFFFFAA
FF55555555AAAA00AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF55AA00AAAA000000AA00FF55FF
FF00FF00FFFF55FF55FF55AAAAAAAAAAAAAA55FF55FF55FFFF00FF00FFFF55FF00AA0000
00AAAA00AA55FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555AAFFAA55FFFF55FFAAAA5555
FF55FF55FF555555FF00AAAAAAAAAAAAAAAAAA00FF555555FF55FF55FF5555AAAAFF55FF
FF55AAFFAA5555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA55FF55AA55AAAA00000000FF
555555FF00AA555555FFFF00FFFFAAFFFF00FFFF555555AA00FF555555FF00000000AAAA
55AA55FF55AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FF00FF00FFFF55FFFF55
55555555FFFF0000FF00AAFFAA000000AAFFAA00FF0000FFFF5555555555FFFF55FFFF00
FF00FF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FF55FF55FF5555AAAA55
5555AA5555FF55FFFFFF55AAAAAAFFAAAAAA55FFFFFF55FF5555AA555555AAAA5555FF55
FF55FF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA00AA00AA00AAAAAAAA
00AAAAAA00AA00AA000055FFAAFFFFFFAAFF550000AA00AA00AAAAAA00AAAAAAAA00AA00
AA00AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF55FFAAAAAAAAAA
AAFFFFAAFFAAFFAAFFAAAA00FFFFFFFFFF00AAAAFFAAFFAAFFAAFFFFAAAAAAAAAAAAFF55
FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555AAAAAAAAAAAA
AAAA55AAFF00FFAA55AAFFFF5555FF5555FFFFAA55AAFF00FFAA55AAAAAAAAAAAAAAAA55
55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA55FFAAFFFFAA
FF55AA55FF55FF55AA55FF5555AA55AA5555FF55AA55FF55FF55AA55FFAAFFFFAAFF55AA
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FFFFFFFF
00AAAAAA00FF00AAAAAA0000FF00FF00FF0000AAAAAA00FF00AAAAAA00FFFFFFFF00AAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FF5555FF
55FFAAFF55FF55FFAAFFFF55FF55FF55FF55FFFFAAFF55FF55FFAAFF55FF5555FF55FFAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA00AAAA
5555FFAA00555555FFAA00FF00AA55AA00FF00AAFF55555500AAFF5555AAAA00AA00AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF55
AA00AAFFFF5500AAAA55FFFFFF55AA55FFFFFF55AAAA0055FFFFAA00AA55FFAAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555
AAFFAAFF00AAAAFFFF00005555FF00FF55550000FFFFAAAA00FFAAFFAA5555FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA
55FF55AAAAFFFF00AAFFAAAA00AAFFAA00AAAAFFAA00FFFFAAAA55FF55AA00AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
AA00FF00FFFFFFFF55AAAAAAAAFFFFFFAAAAAAAA55FFFFFFFF00FF00AAAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
FF55FF55FF55550000FFFF00FFFFFFFFFF00FFFF00005555FF55FF55FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA00AA00AA0055FFFF5555FFFFFFFFFFFFFF5555FFFF5500AA00AA00AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAAFF55FF00AA0055FF5555FF5555FF5500AA00FF55FFAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFF5555AAAAFFFF550055AA55AA550055FFFFAAAA5555FFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA00AA55FFAA00FF55FF00FF00FF55FF00AAFF55AA00AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAAA00FFFF555555FFFFFF555555FFFF00AAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFF55FF5555AA5555FF5555AA5555FF55FFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA00AA00AAAAAA00AA00AAAAAA00AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAFF55AAFFAAFFAA55FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF5555AAFF00FFAA5555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA00AA55FF55FF55AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAA00FF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFF55FF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 2.88102 0.97619 2.96833 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAA00FF555555555555555500FF00AAAA5555AAFF550055FFFF00AA00FF55FF0000
FFAAAAFF0000AAAA55FFAAFFAA555555AAFFAAFF55AAAA0000FFAAAAFF0000FF55FF00AA
00FFFF550055FFAA5555AAAA00FF005555555555555555FF00AAAAAAFF
FFFFAAFFFF55555555555555555555AAAAFFFF000000555555AA0000AAAAAA000000AAAA
00FFFF00AAAAFF55AA00FFFFFF000000FFFFFF00AA55FFAAAA00FFFF00AAAA000000AAAA
AA0000AA555555000000FFFFAAAA55555555555555555555FFFFAAFFFF
FFFFFFAA000000000000FF00000000FFFFAA00FF55FF0000000055FFFF00FFFF5500FFFF
00555500FFFF00AA55FF00AA00FF55FF00AA00FF55AA00FFFF00555500FFFF0055FFFF00
FFFF5500000000FF55FF00AAFFFF00000000FF000000000000AAFFFFFF
FFFFFFFFAAAAFFAAAA00AAFFAAAA00AA00FFFF555555FF0055FF0000AAFFAA0000FF5555
FF0000FF5555FFFF0000AAAAAA000000AAAAAA0000FFFF5555FF0000FF5555FF0000AAFF
AA0000FF5500FF555555FFFF00AA00AAAAFFAA00AAAAFFAAAAFFFFFFFF
FFFFFFFFFFAAFF00FFFF55AAAAAAAAFF55FF5555555555FF0000AAAAFFFFFFAAAAFF0000
FFAAAA000000FFAA00AAAAAAAAAAFFAAAAAAAAAA00AAFF000000AAAAFF0000FFAAAAFFFF
FFAAAA0000FF5555555555FF55FFAAAAAAAA55FFFF00FFAAFFFFFFFFFF
FFFFFFFFFFFFAA00AA00FF00FFFFAA55AA0000FF0000FF00AAAAFFFF00AA00FFFF00AAAA
00FFFFAAAA00AAFFFF55AAFFFFAA55AAFFFFAA55FFFFAA00AAAAFFFF00AAAA00FFFF00AA
00FFFFAAAA00FF0000FF0000AA55AAFFFF00FF00AA00AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA00FF555500000055FFFFFF55FF55FFAAFF00AAAAAAFF00AAAAAA
AA00FFAA55FFFFAA00000055550000005555000000AAFFFF55AAFF00AAAAAAAA00FFAAAA
AA00FFAAFF55FF55FFFFFF550000005555FF00AAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF55555555AA555555FF55555500AAFF5555AAFFFF00AAAAAAAA
AAAAFF00FF00AAFFFF55FF0000FF55FF0000FF55FFFFAA00FF00FFAAAAAAAAAAAA00FFFF
AA5555FFAA00555555FF555555AA55555555FFFFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA00000000000055AA005555555555AAFF0000FFFFFFFF55AAFFFF
AA55FF55FF55FFAA000000AAAA000000AAAA000000AAFF55FF55FF55AAFFFFAA55FFFFFF
FF0000FFAA555555555500AA55000000000000AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAFFAAAA00AA55FF00000000FF00FFAAAA00FFAA0000005555
000000AA55AA00FFFF55FF00FFFF55FFFF00FF55FFFF00AA55AA0000005555000000AAFF
00AAAAFF00FF00000000FF55AA00AAAAFFAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFF00FFFF55AA00FF55FF005555AAAAAAAA00FFFF55FF0000
FF55FF00FF00FF555500AAFFAA000000AAFFAA005555FF00FF00FF55FF0000FF55FFFF00
AAAAAAAA555500FF55FF00AA55FFFF00FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00AA00FF00FF555555FF0000FFFFAAFF5500555555FF00
555555FFFFFF55555555AAFF00FF55FF00FFAA55555555FFFFFF55555500FF5555550055
FFAAFFFF0000FF555555FF00FF00AA00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FF5555555555FF0055550000AA5555555555FF
00000000AA00FF000000FFFFFF555555FFFFFF000000FF00AA00000000FF5555555555AA
0000555500FF5555555555FF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55555555555555FF0000FF550000FF0000FF00
AAAA00AAAAAA00FF55FF00AA0000FF0000AA00FF55FF00AAAAAA00AAAA00FF0000FF0000
55FF0000FF55555555555555FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000000000FF0000AAAA0000FF55FF55FF00AA
AAAAAAFFFF00FF555555FF00FF55FF55FF00FF555555FF00FFFFAAAAAAAA00FF55FF55FF
0000AAAA0000FF000000000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAAAA00AAFFAAAAAAAAFFAA00555555FFFF
00FFFFAA00FF5555555555FF00AA55AA00FF5555555555FF00AAFFFF00FFFF55555500AA
FFAAAAAAAAFFAA00AAAAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFFF55AAAAAAAAAAAA55FF00000000AA
00AAFF00FF55555555555555FF00FF00FF55555555555555FF00FFAA00AA00000000FF55
AAAAAAAAAAAA55FFFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA00FF00FFFFAAFFFF0000AAAA00AAAA
AAFFFFFF555555555555555555FFFFFF555555555555555555FFFFFFAAAAAA00AAAA0000
FFFFAAFFFF00FF00AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FF55550000AA00AAAAAAAAFFFF
00FFAA00FF0000FF0000FF000000AA000000FF0000FF0000FF00AAFF00FFFFAAAAAAAA00
AA00005555FF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55555555AA55FF00FFFF00FFAA
00AAFF55FF55FF00AAAAFF0055FF00FF5500FFAAAA00FF55FF55FFAA00AAFF00FFFF00FF
55AA55555555FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00000000000055AAAA0000AAAA55
FFFFAA0055555500FFFFAA00AA55AA55AA00AAFFFF0055555500AAFFFF55AAAA0000AAAA
55000000000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAAAA00AA55FFAAAAFF55AA
00FFAA5555555555AAAA55FF00FF00FF00FF55AAAA5555555555AAFF00AA55FFAAAAFF55
AA00AAAAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFFF55AA00FFFF00AA55
FFFFFF000000FF00005500AA00AA00AA00AA00550000FF000000FFFFFF55AA00FFFF00AA
55FFFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA00FF00FF5555FF00FF
00AA00FF55FFFFFF5500AAAAAAFF55FFAAAAAA0055FFFFFF55FF00AA00FF00FF5555FF00
FF00AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FF55555555FF00
AAAAAA00FF00AA0000FF55AAFF555555FFAA55FF0000AA00FF00AAAAAA00FF55555555FF
00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF555555555555FF
FFAAFF550055FFAAAA0000005555555555000000AAAAFF550055FFAAFFFF555555555555
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000000000FF00
AAFF555555AA00FFFF0055FF0000000000FF5500FFFF00AA555555FFAA00FF0000000000
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAAAA00AAFF
AAFF0000FF00FF555500FF00AAAAFFAAAA00FF005555FF00FF0000FFAAFFAA00AAAAFFAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFFF55AA
AAAA5555AAAAFF0000FF5555AAFFFFFFAA5555FF0000FFAAAA5555AAAAAA55FFFF00FFAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA00FF00
FFFF0000FFFF00AAAAFF0000FFFFFFFFFF0000FFAAAA00FFFF0000FFFF00FF00AA00AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FF
5555FF00555500FFFF00AAAA0000AA0000AAAA00FFFF00555500FF5555FF00AAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55
555555FF0000FF5555FFFFAAFFAAAAAAFFAAFFFF5555FF0000FF55555555FFFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000
00000000AAAAFF000000AAFFFFFFAAFFFFFFAA000000FFAAAA000000000000AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
FFAAAAFFAAFFFFFF55FFFFAA00FFAAFF00AAFFFF55FFFFFFAAFFAAAAFFAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
FF00FFFFFF00AA000000AAFF5500550055FFAA000000AA00FFFFFF00FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA00AA00FFAAAAAAFFAAAAAA5500FF0055AAAAAAFFAAAAAAFF00AA00AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAA00FFFF00FFAAFF55AA00AA00AA55FFAAFF00FFFF00AAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFF5555FFFFFF00AA55FF00FF55AA00FFFFFF5555FFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA00000000AAFF005500AA00AA005500FFAA00000000AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAFFAAAAAA555555AAFFAA555555AAAAAAFFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFF00FFFF000000FFFFFF000000FFFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA00AA00FF55FF00AA00FF55FF00AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA000000AAAAAA000000AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF55FFFF00FFFF55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA000000AAFFAA000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAFFAA55AAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFF00FF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 2.97706 0.200176 3.06437 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAA0000AAFFFFAA55FF00FF55AAAA5555AAFFFF0055AA55FFFFFFFF00FFFFAA0055AAFF
555555555500FFFF555555FF0055555500FF555555FFFF005555555555FFAA5500AAFFFF
00FFFFFFFF55AA5500FFFFAA5555AAAA55FF00FF55AAFFFFAA0000AAFF
FFFFAA55FF0000FF55555500AAFFFFAAAAFFFFFFFF00AAAA5500AA550000FF005555FF00
00000000000055AA00FFAA005555FF555500AAFF00AA5500000000000000FF555500FF00
0055AA0055AAAA00FFFFFFFFAAAAFFFFAA00555555FF0000FF55AAFFFF
FFFFFFAA00550055AAAAFFAA55555555AA5500AA550055FF00AA00AAFF55AA00000000FF
FF00FFFF00FFFF550055AA55FF555555FF55AA550055FFFF00FFFF00FFFF00000000AA55
FFAA00AA00FF550055AA0055AA55555555AAFFAAAA55005500AAFFFFFF
FFFFFFFFAA55AAFFAAFFFFFFAAAA55AAAA00FFFFAA000000FFFFAA555555FF00FFFF00FF
000055AA0000FF00AA00FF555555FF555555FF00AA00FF0000AA550000FF00FFFF00FF55
5555AAFFFF000000AAFFFF00AAAA55AAAAFFFFFFAAFFAA55AAFFFFFFFF
FFFFFFFFFFAA00AA5555555555AA55AA555500AA55550055555555AAAA55AA0000FF00FF
00FFFF550055555500FFFFFF55FFFFFF55FFFFFF005555550055FFFF00FF00FF0000AA55
AAAA55555555005555AA005555AA55AA5555555555AA00AAFFFFFFFFFF
FFFFFFFFFFFFAA5555FFFF55FFFFAA00AAFF00FF55FF55AAAA55AAAA00AAFFFF00FF00FF
00FF000000AAFFAA0000FF000000FF000000FF0000AAFFAA000000FF00FF00FF00FFFFAA
00AAAA55AAAA55FF55FF00FFAA00AAFFFF55FFFF5555AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA00FF000000FF005500FF00FF00AA55AA5555FF005555AA0055555500
AA0055005555AA00AA0000FFFF00FF00FFFF0000AA00AA5555005500AA0055555500AA55
5500FF5555AA55AA00FF00FF005500FF000000FF00AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5500005500AA00FFFFFF000055FFFFAA00FF00FFAAAA0000000000
AAAAAAFF55FFFFAA55550000FF00FF00FF00005555AAFFFF55FFAAAAAA0000000000AAAA
FF00FF00AAFFFF550000FFFFFF00AA0055000055AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA0000AAFF550055AA0055000000FF0055555500AAAA0000550000
AAAA00AA55AA0055FF55550000FFFFFF00005555FF5500AA55AA00AAAA0000550000AAAA
0055555500FF0000005500AA550055FFAA0000AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA55FF000000AAFFFF00AA000055AAFFAAAA55FF005500000055
00FF55AA55AA55FFFFFF55550000FF00005555FFFFFF55AA55AA55FF00550000005500FF
55AAAAFFAA550000AA00FFFFAA000000FF55AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA0055005500FF0000AAAAAAAA555555AA55AA000000550000
0055AAAA00FF5555555555FFFF00FF00FFFF5555555555FF00AAAA5500000055000000AA
55AA555555AAAAAAAA0000FF0055005500AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55AAFFAA55000055FF0055FFFF5555AAAA0000AA00FFFF
00FFAAFFFF00000000000000FF00FF00FF00000000000000FFFFAAFF00FFFF00AA0000AA
AA5555FFFF5500FF55000055AAFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA5555FFAA55AA000000FF00AAFFFFAA55FF00FF00
00AA555555550055550000AA0055555500AA000055550055555555AA0000FF00FF55AAFF
FFAA00FF000000AA55AAFF5555AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555FFFFFFAA00AA000055AAFFFFFFFFAA00555555
0055FF55FF55FFAA00FFFF005555FF555500FFFF00AAFF55FF55FF550055555500AAFFFF
FFFFAA550000AA00AAFFFFFF5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF0000FF55AA55FFAAAA0055AA0055FFAA00FF
AA55AA00FF00AA555500AA55FF555555FF55AA005555AA00FF00AA55AAFF00AAFF5500AA
5500AAAAFF55AA55FF0000FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55000055AAAA00FF0055FFAAAA000000FF55AA
00AAFFFF0000AAAAFF00FF555555FF555555FF00FFAAAA0000FFFFAA00AA55FF000000AA
AAFF5500FF00AAAA55000055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AAFFFFAA55000000FF5500555500AAFF
FF0055AA0000AAAA00555555FF555555FF55555500AAAA0000AA5500FFFFAA0055550055
FF00000055AAFFFFAA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF0000FF555500555555FFAAAA55FF00
00FFFF55005555AA55FFFF555555FF555555FFFF55AA55550055FFFF0000FF55AAAAFF55
5555005555FF0000FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00550055AAAAFF5555FFFFFFAAFF0000
55555555FFAA00FF55555555FF555555FF55555555FF00AAFF555555550000FFAAFFFFFF
5555FFAAAA55005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFFAAFFFFFF5555555555AA0000
AAFFAA00FF00555555FFFF555555FF555555FFFF55555500FF00AAFFAA0000AA55555555
55FFFFFFAAFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA5555555555FF5555FF550055
55AA00AA005555FF55555555FF555555FF55555555FF555500AA00AA55550055FF5555FF
5555555555AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555FFFF55FFFFFF555555FFAA
00FF55AA55FF555555FFFF555555FF555555FFFF555555FF55AA55FF00AAFF555555FFFF
FF55FFFF5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF000000FF0000000000FF
55AA00FF555555FF55555555FF555555FF55555555FF555555FF00AA55FF0000000000FF
000000FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500005500AA0000555500
AAFFFF0000000000FFAAAAFF0000000000FFAAAAFF0000000000FFFFAA0055550000AA00
55000055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AAFF55005555FFFF
0055AA000055000055AA555555005500555555AA550000550000AA5500FFFF55550055FF
AA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF000000AAFF0000
FFFF55005555FFAA55AA55AAAA55FF55AAAA55AA55AAFF55550055FFFF0000FFAA000000
FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055005500FF00FF
FFFFFF55AAAA5500FFAAFF0055FFFFFF5500FFAAFF0055AAAA55FFFFFFFF00FF00550055
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFFAA550000
FF0000FFAAFFFF55AA00AA55FFFFFFFFFF55AA00AA55FFFFAAFF0000FF000055AAFFAA55
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA5555FFAA
550000AA55555555FF00FF55555555555555FF00FF55555555AA000055AAFF5555AA00AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555FFFFFF
AA000055FF5555FFFFFF000000000000000000FFFFFF5555FF550000AAFFFFFF5555AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF0000
FF55AAFF00000000FF0000550000550000550000FF00000000FFAA55FF0000FF00AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550000
55AAAA005555000055AAFF55550000005555FFAA550000555500AAAA55000055AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000
AAFFFFAA55AAAAAAAA555555FFFF00FFFF555555AAAAAAAA55AAFFFFAA0000AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55
FF0000FF5555AA5555AAAA55AA005500AA55AAAA5555AA5555FF0000FF55AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
00550055AAAA5555FFFFAAFFAAFF55FFAAFFAAFFFF5555AAAA55005500AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55AAFFAAFFFF55555555AA00AA55AA00AA55555555FFFFAAFFAA55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAA00AA55555555FF5555FF00FF55FF00FF5555FF55555555AA00AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA5555FFFF555555FFFFFF000000FFFFFF555555FFFF5555AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA00FF0000000000FF0000550000FF0000000000FF00AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA55000055005555550000005555550055000055AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA0000AAFF5555FFFF00FFFF5555FFAA0000AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA55FF00000000FF00FF00000000FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA005500005500AA005500005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55AAFF55FFAAFF55FFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA00AA55AA00AA55AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA5555FF00FF5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00FF00FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 2.97706 0.39418 3.06437 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAA0000AA5555FFFF00AAAA00550000FF55000055FFAA555555FFFFFFFFFFFF55555555
FFFF005500AAFFFFFFAAAAFF00FFFFFF00FFAAAAFFFFFFAA005500FFFF55555555FFFFFF
FFFFFF555555AAFF55000055FF00005500AAAA00FFFF5555AA0000AAFF
FFFFAA00FF55FFFFFFFF0055FFAAAAAA5500000000AA5555005555555555555555000055
555555FFFF0055AA0055FF000000FF000000FF5500AA5500FFFF55555555000055555555
55555555005555AA0000000055AAAAAAFF5500FFFFFFFF55FF00AAFFFF
FFFFFFAA00555555555555FFFFFFAAFFFF5555FFAA555500000055005555005500000000
550055555555FFFFAA0000FFAA00FF00AAFF0000AAFFFF55555555005500000000550055
5500550000005555AAFF5555FFFFAAFFFFFF55555555555500AAFFFFFF
FFFFFFFFAA0000AA00005500AA5500FF00005500AAAAFFAA55FF55FFAAAAFF55FFAA00FF
FF5555000055555555AAAA5500FFFFFF0055AAAA5555555500005555FFFF00AAFF55FFAA
AAFF55FF55AAFFAAAA00550000FF0055AA00550000AA0000AAFFFFFFFF
FFFFFFFFFFAA00FF55AAFFAA00AA00FF00FFAAAA5555AA00AA00555555AA550055AA55AA
005500000000550000AAAA000000FF000000AAAA000055000000005500AA55AA550055AA
55555500AA00AA5555AAAAFF00FF00AA00AAFFAA55FF00AAFFFFFFFFFF
FFFFFFFFFFFFAA005555AA00AAFFFF000000FF55000055FFAAFF55FFFF5500000055FFFF
AA000000000000AAFF5500FFFF00FF00FFFF0055FFAA000000000000AAFFFF5500000055
FFFF55FFAAFF55000055FF000000FFFFAA00AA555500AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA0000AAAA55555555FFAA550000000055AA550055AA0000000000AA55
00FFFF00AAFF5555AA000000FF00FF00FF000000AA5555FFAA00FFFF0055AA0000000000
AA550055AA550000000055AAFF55555555AAAA0000AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00FF550000AA0000FF55FFAA00FFAAAA000000AAAA55FF55AAFFFF
55555555FF00005500FFFF00FF00FF00FF00FFFF00550000FF55555555FFFFAA55FF55AA
AA000000AAAAFF00AAFF55FF0000AA000055FF00AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA005555FFAAFF55AA0000FF555555AA55AAAAAA00AA005555AA00
5500550000FFAA000000FF00FF00FF00FF00FF000000AAFF000055005500AA555500AA00
AAAAAA55AA555555FF0000AA55FFAAFF555500AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA0000AA55555500FFAA550000AA00AA00AAAA00FF55550055FF
AAAAAAFF555555AAFF00FF00FF00FF00FF00FF00FFAA555555FFAAAAAAFF55005555FF00
AAAA00AA00AA000055AAFF00555555AA0000AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00FF55FFFF55AA00AA00FFFFAA00AAFFFFAA0055000000AA
5555AA5500555500FF00FF00FF00FF00FF00FF00FF0055550055AA5555AA0000005500AA
FFFFAA00AAFFFF00AA00AA55FFFF55FF00AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA005555555500FFFFAA5500AAAA55555555AAFFAA55FFAA
FFAAAA000000AA00FF00FF00FF00FF00FF00FF00FF00AA000000AAAAFFAAFF55AAFFAA55
555555AAAA0055AAFFFF005555555500AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AA000000FF005555FF005500005500FF00555555
AA00AAAAAAAAAA00FF00FF00FF00FF00FF00FF00FF00AAAAAAAAAA00AA55555500FF0055
00005500FF555500FF000000AA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF55AAFF000000555555FFFF00AA00FF00AA0000
55FF5500FF5500FFFFFF000000FFFFFF000000FFFFFF0055FF0055FF550000AA00FF00AA
00FFFF555555000000FFAA55FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005555AA00FFAA000055555555FF00FF00FF5555
FFFFFF55AA000000FF0000000000FF0000000000FF000000AA55FFFFFF5555FF00FF00FF
555555550000AAFF00AA555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AAAA5500FFAA0000AA0000FFFFFF000055
5555555500FFFF00FF00FFFF00FFFFFF00FFFF00FF00FFFF0055555555550000FFFFFF00
00AA0000AAFF0055AAAA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF55000000FF55AAAA00FFFFFFFFFF00AA
0000AA000000FF00FF00FF000000FF000000FF00FF00FF000000AA0000AA00FFFFFFFFFF
00AAAA55FF00000055FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005555FFAA005500FF55555555555555FF
00AAFFFF00FFFFFF000000FFFF00FF00FFFF000000FFFFFF00FFFFAA00FF555555555555
55FF005500AAFF555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AA5555FFFF000055000055000055
AAFFFFFFFF0000FF00FFFF0000FFFFFF0000FFFF00FF0000FFFFFFFFAA55000055000055
0000FFFF5555AA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF55FFFFFFFF00AA00FFFF55AAAA
FFFFFFFFFFFF00FF00FF00000000FF00000000FF00FF00FFFFFFFFFFFFAAAA55FFFF00AA
00FFFFFFFF55FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00555555555555FF00AA550055FF
0000FF0000FF00FF00FF00FFFF00FF00FFFF00FF00FF00FF0000FF0000FF550055AA00FF
55555555555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AA00005500AAFFFF555500
AAFF00000000FFFFFF000000FF00FF00FF000000FFFFFF00000000FFAA005555FFFFAA00
550000AA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF55AAFFAA00AA55005555
FF000000000000FF0000000000FFFFFF0000000000FF000000000000FF55550055AA00AA
FFAA55FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005555AA00AAFFFF555500
55AAAAAA55AAFF00000000000000FF00000000000000FFAA55AAAAAA55005555FFFFAA00
AA555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AAAA555555550000
0055FF005500FF00FFAA55AAFF555555FFAA55AAFF00FF005500FF5500000055555555AA
AA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF550000AA000000
0000AA55FFFF000000FF55FF0000AA0000FF55FF000000FFFF55AA0000000000AA000055
FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA005555FFAAFF55AA
AAAAAA0000FF00FFAA550000FFAA00AAFF000055AAFF00FF0000AAAAAAAA55FFAAFF5555
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AA55555500
FF5500FFFF000000FF55FFAA0055FF5500AAFF55FF000000FFFF0055FF00555555AA0000
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF55FFFF55
AA000000FF00FFFF000055AA55FFFFFF55AA550000FFFF00FF000000AA55FFFF55FF00AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055555555
00FFAA55AA00FF0000000055FFFFFFFFFF5500000000FF00AA55AAFF005555555500AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AA00
0000FF55FF00FF00FFAA55FFFFFFFFFFFFFF55AAFF00FF00FF55FF000000AA0000AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF55
AAFF0000AA55AA00FF0055555555555555555500FF00AA55AA0000FFAA55FF00AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055
55AA00FFAAFFAAFF000000AA0000550000AA000000FFAAFFAAFF00AA555500AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00
00AAAA5500FF0055AAAA55AA55FF55FF55AA55AAAA5500FF0055AAAA0000AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
00FF55000000FFAAAA00AA00AA005500AA00AA00AAAAFF00000055FF00AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA005555FFAA0055FF00FF5555AAFFAA5555FF00FF5500AAFF555500AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAA0000AA5555FFFFFF00005500FF00550000FFFFFF5555AA0000AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA00FF55FFFFFFFFFF00AA00FF00AA00FFFFFFFFFF55FF00AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA0055555555555555FF00FF00FF5555555555555500AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA0000AA0000550000FFFFFF0000550000AA0000AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA00FF55AAAAFF5555555555FFAAAA55FF00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA005555AA550000AA000055AA555500AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA0000AAAAFF55AA55FFAAAA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00FF5500AA00AA0055FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA005555FF00FF555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA0000AA55AA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00FF55FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 2.97706 0.588183 3.06437 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAFF00FF00FF0055000000550000AA00AA00AA55FF00AA0000FFFFFFAA0055AA00
00AA55FFAAFF0000000000FFFF000000FFFF0000000000FFAAFF55AA0000AA5500AAFFFF
FF0000AA00FF55AA00AA00AA0000550000005500FF00FF00FFAAAAAAFF
FFFFAA00FFFF55AA0000FF55FFFF5500AA55AA00FF00AAAAAAFF0000FFFFFFFFAAAA00FF
000055FFAA000000000000FFFF000000FFFF000000000000AAFF550000FF00AAAAFFFFFF
FF0000FFAAAAAA00FF00AA55AA0055FFFF55FF0000AA55FFFF00AAFFFF
FFFFFFAAAAAAAA00FF0000AAAAAAAA005500FFAAAAAAFF00AAFF55FFFFFFFFFFFFAA0055
555555AAFF000000FF0000FFFF000000FFFF0000FF000000FFAA5555555500AAFFFFFFFF
FFFF55FFAA00FFAAAAAAFF005500AAAAAAAA0000FF00AAAAAAAAFFFFFF
FFFFFFFFAA00FFAAAAAAFFAA00FFAA0055FFFF00AAFFFFFF555500FFFFFFFFFFFFFFAAAA
00AAAA00FFFF55FFFF0000FFFF000000FFFF0000FFFF55FFFF00AAAA00AAAAFFFFFFFFFF
FFFF005555FFFFFFAA00FFFF5500AAFF00AAFFAAAAAAFF00AAFFFFFFFF
FFFFFFFFFFAAAAAA55AAAAAA55005500AAAAAAAAFFFFFFFF0055FFFF00FFFF00FFFFFFAA
0055000000AA00AA000000FFFF000000FFFF000000AA00AA0000005500AAFFFFFF00FFFF
00FFFF5500FFFFFFFFAAAAAAAA00550055AAAAAA55AAAAAAFFFFFFFFFF
FFFFFFFFFFFFAA00FF5555FF5500AAAAFF00AAFF00FFFF00FF00555500AA0000FFFF00FF
AAAA0055AA00FF00AA5500AA0000000000AA0055AA00FF00AA5500AAAAFF00FFFF0000AA
00555500FF00FFFF00FFAA00FFAAAA0055FF5555FF00AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA00AA00AA55AAAAAAFF00FF00FFFF55AA00AAAAFF0000FFFF0000
AAFFFF550000FFFF5555AA00FF000000FF00AA5555FFFF000055FFFFAA0000FFFF0000FF
AAAA00AA55FFFF00FF00FFAAAAAA55AA00AA00AAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00FF00AA55AA55AAAA55FFFF0000AA00AAFFAAFFFF000000AA0055
AAAAAAAA0055AAFF5500FFAAAAAAFFAAAAAAFF0055FFAA5500AAAAAAAA5500AA000000FF
FFAAFFAA00AA0000FFFF55AAAA55AA55AA00FF00AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAAFF005500FFAA00AA0000FF00AA55AAFFFFFF000000FFAAAA
00FFAA00FF00550055FFFF00AAFFFFFFAA00FFFF55005500FF00AAFF00AAAAFF000000FF
FFFFAA55AA00FF0000AA00AAFF005500FFAAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA00FFFF5500AA00FF00AA550055AAAA00FFFFFF000000FFFFAA
005555FFFFFF5500AAAAAAAAFFFFFFFFFFAAAAAAAA0055FFFFFF555500AAFFFF000000FF
FFFF00AAAA550055AA00FF00AA0055FFFF00AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAAAAA005500AA005500FF00550000FFFFFF000000FFFFFF
AAAA00AA0000AAAAFF00AAFFFFFFFFFFFFFFAA00FFAAAA0000AA00AAAAFFFFFF000000FF
FFFF00005500FF005500AA005500AAAAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00FFAAAA005500AAAAFF55FF0000FFFFFF000000FFFFFF
FFAA005500AA55AAAAAAFFFFFFFFFFFFFFFFFFAAAAAA55AA005500AAFFFFFFFF000000FF
FFFF0000FF55FFAAAA005500AAAAFF00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55AA00AA55AAAAAA000000FFFFFF000000FFFFFF
00FFAAAA005500FFAA00FFFFFFFFFFFFFFFFFF00AAFF005500AAAAFF00FFFFFF000000FF
FFFF000000AAAAAA55AA00AA55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF555555FF00AAFF000000FFFFFF000000FFFFFF
0000AAFFFF5500AA00FF00FFFFFFFFFFFFFF00FF00AA0055FFFFAA0000FFFFFF000000FF
FFFF000000FFAA00FF555555FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00AAAAAAFF00FF000000AA0000000000AA00
000000555500FF00AA55FFFFFFFFFFFFFFFFFF55AA00FF00555500000000AA0000000000
AA000000FF00FFAAAAAA00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF00AAFF00FF00FF0000FFAAAAFFAAAAFF00
000000FF5500AA005500FFFF00FFFFFF00FFFF005500AA0055FF00000000FFAAAAFFAAAA
FF0000FF00FF00FFAA00FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF00FF00FF00FF0000AAFF00FFAA0000
FF000000AAAAFFFF5500AA0000FFFFFF0000AA0055FFFFAAAA000000FF0000AAFF00FFAA
0000FF00FF00FF00FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF55AA0000FFFF55FF55AA000055AA
00000000FFAAFF55AA55000000FFFFFF00000055AA55FFAAFF00000000AA550000AA55FF
55FFFF0000AA55FFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA00FF0000AA00AA00AAFFAAAA00
FF000000FFFFAA5555FF000000FFFFFF000000FF5555AAFFFF000000FF00AAAAFFAA00AA
00AA0000FF00AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFAAAAAAFFAA005500AAFF5555FF
FFFF55FFFFFF00AAAA00000000FFFFFF00000000AAAA00FFFFFF55FFFFFF5555FFAA0055
00AAFFAAAAAAFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55AAAAAA5500FF00AA00AAAA
AAAAAA0000AA00550000000000FFFFFF00000000005500AA0000AAAAAAAAAA00AA00FF00
55AAAAAA55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF5555FF5500AA005500AAFF
00AAFFFF55FF55FF0000000000FFFFFF0000000000FF55FF55FFFFAA00FFAA005500AA00
55FF5555FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00AA00AA55AA00AA55AA
FFAA0000AAAAAA000000000000FFFFFF000000000000AAAAAA0000AAFFAA55AA00AA55AA
00AA00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF00AA55AA55AA00FF55
55000000FFAA00FF0000000000FFFFFF0000000000FF00AAFF0000005555FF00AA55AA55
AA00FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF005500FFAAAAAA
00AA5500AA00FF00FF00000000FFFFFF00000000FF00FF00AA0055AA00AAAAAAFF005500
FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF5500AA00FFAA
005500FF00AA55FFFF00000000FFFFFF00000000FFFF55AA00FF005500AAFF00AA0055FF
FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA005500AA00
FF0055AAFFAA00AA0000000000FFFFFF0000000000AA00AAFFAA5500FF00AA005500AAAA
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFAAAA005500
AA0055FF55AAAAFF0000000000FFFFFF0000000000FFAAAA55FF5500AA005500AAAAFF00
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55AA00AA
55AA00AA00AAFFFF000000FF0000AA0000FF000000FFFFAA00AA00AA55AA00AA55AAAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF555555
FF00AA55AA00FFFF000000FFFF55FF55FFFF000000FFFF00AA55AA00FF555555FF00AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00AA
AAAAFF005500AA0000000000AA00AA00AA0000000000AA005500FFAAAAAA00AAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF00
AAFF00FF0055AAAAFFAAAAFFAAFFAAFFAAFFAAAAFFAAAA5500FF00FFAA00FF00AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA
FF00FF00FF00550000AAFFFFFFAA55AAFFFFFFAA00005500FF00FF00FFAAAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00
FFFF55AA0000FF55FFFFAA55FFAA00AAFF55AAFFFF55FF0000AA55FFFF00AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAAAAA00FF0000AAAAAAAA55550000005555AAAAAAAA0000FF00AAAAAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA00FFAAAAAAFFAA00FFAA00AAAAFFAAAA00AAFF00AAFFAAAAAAFF00AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAA55AAAAAA55005500AAFFFFFFAA00550055AAAAAA55AAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA00FF5555FF5500AAAAFFFFFFFFFFAAAA0055FF5555FF00AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAAAA00AA00AA55AAAAAAAAAAAAAA55AA00AA00AAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA00FF00AA55AA55AAAA55AAAA55AA55AA00FF00AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAAFF005500FFAA00AAFF005500FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA00FFFF5500AA00FF00AA0055FFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAAA005500AA005500AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00FFAAAA005500AAAAFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAA55AA00AA55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA00FF555555FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAAA00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 2.97706 0.782187 3.06437 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAAAFFFF550055FFFFAAAAAAAAFFFFAA00AA55FF55AA00AAFFFFAAAAAAAAFFFF55
0000AAAAFF5555FF55FFFFFFFFFFFFFFFFFFFFFF55FF5555FFAAAA000055FFFFAAAAAAAA
FFFFAA00AA55FF55AA00AAFFFFAAAAAAAAFFFF550055FFFFAAAAAAAAFF
FFFFAAFFFFAA55FF55FF55AAFFFFAAFFFFFFFFAAAA00FF00AAAAFFFFFFFFAAFFFFAA55FF
55FFFFAAFF5555FFAA0000FFFFFFFFFFFFFF0000AAFF5555FFAAFFFF55FF55AAFFFFAAFF
FFFFFFAAAA00FF00AAAAFFFFFFFFAAFFFFAA55FF55FF55AAFFFFAAFFFF
FFFFFFAA55FF00AA55AA00FF55AAFFFFFFFFFF0055FFFFFF5500FFFFFFFFFFAA55FF00AA
55AA0055FFAA00FF00550000FFFFFFFFFF00005500FF00AAFF5500AA55AA00FF55AAFFFF
FFFFFF0055FFFFFF5500FFFFFFFFFFAA55FF00AA55AA00FF55AAFFFFFF
FFFFFFFFAA000055FF550000AAFFFFFFFFFFFFFF5555005555FFFFFFFFFFFFFFAA000055
FF55000000AAAAFF55FF55FFFFFFFFFFFFFF55FF55FFAAAA00000055FF550000AAFFFFFF
FFFFFFFF5555005555FFFFFFFFFFFFFFAA000055FF550000AAFFFFFFFF
FFFFFFFFFFAAAAFF00FFAAAAFFFFFFFFFFFFFFFF00AAFFAA00FFFFFFFFFFFFFFFFAAAAFF
00FFAAAAFFAAFFFF00AA00FFFFFFFFFFFFFF00AA00FFFFAAFFAAAAFF00FFAAAAFFFFFFFF
FFFFFFFF00AAFFAA00FFFFFFFFFFFFFFFFAAAAFF00FFAAAAFFFFFFFFFF
FFFFFFFFFFFFAAFF55FFAAFFFFFFFFFFFFFFFFFFFF550055FFFFFFFFFFFFFFFFFFFFAAFF
55FFAAFFFFFFAA55FFFFAAAAAAAAAAAAAAAAAAFFFF55AAFFFFFFAAFF55FFAAFFFFFFFFFF
FFFFFFFFFF550055FFFFFFFFFFFFFFFFFFFFAAFF55FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA55AAFFFF00FFFFFFFFFFFF0000AAFFAA0000FFFFFFFFFFFF00FFFFAA
55AAFFFFFF00FF55555555AA5555AA5555AA55555555FF00FFFFFFAA55AAFFFF00FFFFFF
FFFFFF0000AAFFAA0000FFFFFFFFFFFF00FFFFAA55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00AA55FFFFFFFFFFFFFFFF55FF00FF55FFFFFFFFFFFFFFFF55AA00
AAFFFFFF000055AAAA55AAAA00FFAAFF00AAAA55AAAA550000FFFFFFAA00AA55FFFFFFFF
FFFFFFFF55FF00FF55FFFFFFFFFFFFFFFF55AA00AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA00FFFF0000FFFF0000AAFF55FFAA0000FFFF0000FFFF00AAAA
FFFFFFFFFF55FF5500FFAAFFFF55AA55FFFFAAFF0055FF55FFFFFFFFFFAAAA00FFFF0000
FFFF0000AAFF55FFAA0000FFFF0000FFFF00AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFAA55000055AAFFAAAA000000AAAAFFAA55000055AAFFAAFF
FFFFFFFF000000FFAAAAAA0000FFAAFF0000AAAAAAFF000000FFFFFFFFFFAAFFAA550000
55AAFFAAAA000000AAAAFFAA55000055AAFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA5555FFFF5555AA00AAAAFFAAAA00AA5555FFFF5555AAFFFF
FFFFFFFFFF55FFFFFFAAFFFF55FFAAFF55FFFFAAFFFFFF55FFFFFFFFFFFFFFAA5555FFFF
5555AA00AAAAFFAAAA00AA5555FFFF5555AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF00AAFFFF5500FF0055FFFFAA00FFFF00AAFFFFFF
FFFFFFFF000000FFFF00555555FFAAFF55555500FFFF000000FFFFFFFFFFFFFFAA00FFFF
00AAFFFF5500FF0055FFFFAA00FFFF00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAFFFF00FFAAAAAAFF00FFFFAAAAAAAAFFFFFFFF
FFFFFFFFFF55FFFFFFFF5555FF55AA55FF5555FFFFFFFF55FFFFFFFFFFFFFFFFFFAAAAAA
AAFFFF00FFAAAAAAFF00FFFFAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAA55FFFFFFAAFFFFFF55AAFFFFAAFFFFFFFFFF
FFFFFFFF000000FFFF00000000FFAAFF00000000FFFF000000FFFFFFFFFFFFFFFFFFAAFF
FFAA55FFFFFFAAFFFFFF55AAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF00AA55FFAAFF55AA00FF55AAFFFFFFFFFFFF
FFFFFFFFFF55FFFFFFFF55FFFF55AA55FFFF55FFFFFFFF55FFFFFFFFFFFFFFFFFFFFFFAA
55FF00AA55FFAAFF55AA00FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000055FF55AA55FF550000AAFFFFFFFFFFFFFF
FFFFFFFF000000FFFF000000AA55AA55AA000000FFFF000000FFFFFFFFFFFFFFFFFFFFFF
AA000055FF55AA55FF550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00FFAAFF00FFAAAAFFFFFFFFFFFFFFFF
FF0000FFFF55FFFFFFFF55FFFFAA00AAFFFF55FFFFFFFF55FFFF0000FFFFFFFFFFFFFFFF
FFAAAAFF00FFAAFF00FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFAAFF55FFAAFFFF00FFFFFFFFFFFF
00005500AA55AA0000AA00FFFF005500FFFF00AA0000AA55AA00550000FFFFFFFFFFFF00
FFFFAAFF55FFAAFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFFFF00AA00AA55FFFFFFFFFFFFFF
FF55FF55FF00AAAAFFAAFFAA5500000055AAFFAAFFAAAA00FF55FF55FFFFFFFFFFFFFFFF
55AA00AA00FFFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA55FFFFAAAA00FFFFFFFF0000FF
00FFAA55AAFFAAFFFF005555AAAAFFAAAA555500FFFFAAFFAA55AAFF00FF0000FFFFFFFF
00AAAAFFFF55AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FFFF0055FFFF0000FFFF55FF
AAAAAA00FF55AA55FFAAAA55AA555555AA55AAAAFF55AA55FF00AAAAAAFF55FFFF0000FF
FF5500FFFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA55000000FFFF55FFAA55AA
FFFFAAFFAA55AA55AA00AAAA5555FF5555AAAA00AA55AA55AAFFAAFFFFAA55AAFF55FFFF
00000055AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555FFFF55FFAA55AA00AAFF
FFFFFFAA5555FF00AAAAFFFFAA00FF00AAFFFFAAAA00FF5555AAFFFFFFFFAA00AA55AAFF
55FFFF5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF00AA00AAFFFF5500
AA0000AAAA55AAFFAAFFFFFFFFAAAAAAFFFFFFFFAAFFAA55AAAA0000AA0055FFFFAA00AA
00FFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAFFFF55005555FF
FFAAAAFFFFAA00AA555555555555AA555555555555AA00AAFFFFAAAAFFFF55550055FFFF
AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAA55FF55FF5555
0055FF00FFFFAAAA00FFAA00FFAA00AAFF00AAFF00AAAAFFFF00FF55005555FF55FF55AA
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF00AA55AA00FF
AAAA55FFFF00FF550000FF55FFAAFFAAFF55FF000055FF00FFFF55AAAAFF00AA55AA00FF
55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000055FF550000
AAAA00FFFFFF55AAAAFFAA55AAFFFFFFAA55AAFFAAAA55FFFFFF00AAAA000055FF550000
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00FFAAAA
FFFFAAAAAAAAAA5555AA00AAFFFFFFFFFFAA00AA5555AAAAAAAAAAFFFFAAAAFF00FFAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFAAFF
FFFFFFAAFFFFAAFF00AAAAFFFFFFFFFFFFFFAAAA00FFAAFFFFAAFFFFFFFFAAFF55FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFFFF
FF00FF0055AAFFFFFF5500FFFFFFFFFFFFFF0055FFFFFFAA5500FF00FFFFFFAA55AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA55
FFAAAAAAFF0055555555FFFF00FFFFFF00FFFF5555555500FFAAAAAAFF55AA00AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00
FFFFAAFFFFFF5555FF5555550000FF0000555555FF5555FFFFFFAAFFFF00AAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
AA5500FFFFFF00AAFF5555FF55FFFFFF55FF5555FFAA00FFFFFF0055AAFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
5555FFFFFFFFFF5500AAFF000000AA000000FFAA0055FFFFFFFFFF5555AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA00FFFFFFFF00000055FFAAAAFFAAFFAAAAFF55000000FFFFFFFF00AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAAAAAAAAFFAAAA5500FF55AA55FF0055AAAAFFAAAAAAAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFFAAFFFF0055FF55FFAA00AAFF55FF5500FFFFAAFFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA55FF00FFFF555555FFAAFFAAFF555555FFFF00FF55AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA0000555555FF555500FF005555FF5555550000AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAFF00AAFF5555FFFFFF5555FFAA00FFAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFF55FF00000000AA00000000FF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA55AAFFAAAAFFAAFFAAAAFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00AA5555AA00AA5555AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA00FFAAFFAAFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFAA555555AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA5555FF5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 2.97706 0.97619 3.06437 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAFF55AAAAAAAAAAAA5500FFFFFFFF00005555AAAAFFFFAAAAAA55AA555555AA55FF
FFFFFF55AA0055AAFFFFFFFF5500FF0055FFFFFFFFAA5500AA55FFFFFFFF55AA555555AA
55AAAAAAFFFFAAAA55550000FFFFFFFF0055AAAAAAAAAAAA55FFAAAAFF
FFFFAAFF5555555555555555FFFFFFFFFFFF55FF555555AAFF5500FF555555FF5555AAAA
AAAAAAAA55550000FFFFFF00FFAAAAAAFF00FFFFFF00005555AAAAAAAAAAAA5555FF5555
55FF0055FFAA555555FF55FFFFFFFFFFFF5555555555555555FFAAFFFF
FFFFFFAA55AAAA55AAAA55AAAAAAAAAAAAAAAA55FF5555FF00FFAAAAAA55AAAAAA55AA55
5555AA5555FF55FFFFFFFFFF55AA00AA55FFFFFFFFFF55FF5555AA555555AA55AAAAAA55
AAAAAAFF00FF5555FF55AAAAAAAAAAAAAAAA55AAAA55AAAA55AAFFFFFF
FFFFFFFFAA00AA55AA5555FF0055AA00AA5555AAAAAA55AAFFAA555555AAAA00AAAA5555
FF555555FF55AAAAAAAAAAAAAA550055AAAAAAAAAAAAAA55FF555555FF5555AAAA00AAAA
555555AAFFAA55AAAAAA5555AA00AA5500FF5555AA55AA00AAFFFFFFFF
FFFFFFFFFFAAAA00FF5555FFAAAA550055AAAA55555555FF00FF5555FF5500AA00AA55AA
AAAA55AAAAAA5555AA00AA5500AAFFAA0055AA00AA5555AAAAAA55AAAAAA55AA00AA0055
FF5555FF00FF55555555AAAA550055AAAAFF5555FF00AAAAFFFFFFFFFF
FFFFFFFFFFFFAAFFAA55AAAAAA00AAFFAA0055AAAA55AAAAAAFF5555FFAA000000AA55AA
00AAAA555555AAAA550055AAAAFFFFFFAAAA550055AAAA555555AAAA00AA55AA000000AA
FF5555FFAAAAAA55AAAA5500AAFFAA00AAAAAA55AAFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA550000000000AAAAAA000055AA55AA00AAAAAA55AAFFFF55FFFFAA00
AA00AA55AAAA5555AAAAFF0000FFFFFF0000FFAAAA5555AAAA55AA00AA00AAFFFF55FFFF
AA55AAAAAA00AA55AA550000AAAAAA000000000055AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA0000AA0000AA5500AA000055AAAA00000000FFAAFF55AAAAAAAA00
0000AAAA5555AAAA5555AAFFAAAAAAAAAAFFAA5555AAAA5555AAAA000000AAAAAAAA55FF
AAFF00000000AAAA550000AA0055AA0000AA0000AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAFFFF55FF00AA0055550000FF55FFFF55FFAAFF555555AA5500
555500FF00AAFFFFAA00FF55AA555555AA55FF00AAFFFFAA00FF0055550055AA555555FF
AAFF55FFFF55FF0000555500AA00FF55FFFFAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF55AAAAAAFFFF5555FFFF55AAAAAAAA55FF00FFAA00FF00AA
00FFAAAAAAFFFFFFFFAAAAAA5555FF5555AAAAAAFFFFFFFFAAAAAAFF00AA00FF00AAFF00
FF55AAAAAAAA55FFFF5555FFFFAAAAAA55FFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55AA00AAAAAAAA55AAFF5555AA00AAAA55FFFFFFAAAAAAFF
FF55AA00AAAAAAAAAAAA00AA55AAAAAA55AA00AAAAAAAAAAAA00AA55FFFFAAAAAAFFFFFF
55AAAA00AA5555FFAA55AAAAAAAA00AA55AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00AA0055AA5555FF00FFAA00555555AAAAAAAAAA00AAAA
AAAA550055AA5555AA550055AAAA00AAAA550055AA5555AA550055AAAAAAAA00AAAAAAAA
AA55555500AAFF00FF5555AA5500AA00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAA000055AAAA55FFFFFFAAAA55AAAA00AAAA00AA00AA
AA00AAFFAA00550000FFAAAA5500AA0055AAAAFF00005500AAFFAA00AAAA00AA00AAAA00
AAAA55AAAAFFFFFF55AAAA550000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAAA5555AAAAAAAAAA00AAFFFFAAAA00AA00AA00
AAAAFFFF0000AAFFAAAAAA00AAFFAAFFAA00AAAAAAFFAA0000FFFFAAAA00AA00AA00AAAA
FFFFAA00AAAAAAAAAA5555AAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AAFF000000FF005555AAFF5500AA00555555
00AAAAAAAAFFAAFF5500FF55FF00FF00FF55FF0055FFAAFFAAAAAAAA0055555500AA0055
FFAA555500FF000000FFAA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000FFFF55FFFFFF5555FF00FFAAAA00005500
00AA5555AA55FF00FFAAAAAA55FFFFFF55AAAAAAFF00FF55AA5555AA0000550000AAAAFF
00FF5555FFFFFF55FFFF0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55AAAAAAAAAA55AAFFAA555555005500
5555AAAA5555FFAAAAAA0055AAAAAAAAAA5500AAAAAAFF5555AAAA5555005500555555AA
FFAA55AAAAAAAAAA55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55555555555555FF00FF5555FF55FF55
FF55555555FF55AA5500AA00FF000000FF00AA0055AA55FF55555555FF55FF55FF5555FF
00FF55555555555555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAA55AAAA55AAFFAA55AAAAAA55FF
55AAAA55AAAAAA5555FFFFAAAAAAFFAAAAAAFFFF5555AAAAAA55AAAA55FF55AAAAAA55AA
FFAA55AAAA55AAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA55AA5555FF00FF5555AA5555FF
AA00AAAA5500AA55AAAAAAAA00AAAAAA00AAAAAAAA55AA0055AAAA00AAFF5555AA5555FF
00FF5555AA55AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FF5555FFAAAAAA55AA55AAAA
AA000000005555AAAA00AAAA0000000000AAAA00AAAA555500000000AAAAAA55AA55AAAA
AAFF5555FF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA55AAAAAA0055AAAA00FF00
0000AA0000AAFF000000AAAA0000AA0000AAAA000000FFAA0000AA000000FF00AAAA5500
AAAAAA55AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550000000000AAFFFFAAAAAA
FFAAAA0000AAAAAAFFAAAA00AA000000AA00AAAAFFAAAAAA0000AAAAFFAAAAAAFFFFAA00
0000000055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000AA0000AAAAAAAA00AA
AAAA00AA000000FF55AA005555550055555500AA55FF000000AA00AAAAAA00AAAAAAAA00
00AA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFF55FF0055AA0000
000000AAAAFFAAAAAA5555000055005500005555AAAAAAFFAAAA0000000000AA5500FF55
FFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55AAAAAAFF005555
00555500FF55AA5500FFAA0000AAFFAA0000AAFF0055AA55FF00555500555500FFAAAAAA
55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA00AAAAAAFF00
AA00FFAAAAAA5555FFFFFFAAAAFFFFFFAAAAFFFFFF5555AAAAAAFF00AA00FFAAAAAA00AA
55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA0055AA55FF
FFAAAAAA0055AAAA55FFAA5500FFFFFF0055AAFF55AAAA5500AAAAAAFFFF55AA5500AA00
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA000055AAAA
AAAA00AAAAFF0000FFAA5555FFFFFFFFFF5555AAFF0000FFAAAA00AAAAAAAA550000AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAAA5555
AA555500AA55FFFF55AA55AAAAAAAAAAAAAA55AA55FFFF55AA005555AA5555AAAAFFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AAFF
0000550055AAAAAAAA5500000000000000000055AAAAAAAA5500550000FFAA0055AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000FF
FF55FF55FF5500AA550000AA0000AA0000AA000055AA0055FF55FF55FFFF0000AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF
55AAAAAA55FF55FF00AA000000AA00AA000000AA00FF55FF55AAAAAA55FFAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
55555555AAAAAA55FFFFAAAAFFAAFFAAFFAAAAFFFF55AAAAAA55555555FFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
55AAAA55AA555555FFAA5555AAFFFFFFAA5555AAFF555555AA55AAAA55AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA00AA55AA55AAAA55FF00AAFFFFFFFFFFAA00FF55AAAA55AA55AA00AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAA00FF555555AAAAAAFFFFFFFFFFFFFFAAAAAA555555FF00AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFAA55AAAA5500AAAAAAAAAAAAAAAAAA0055AAAA55AAFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA55000000005555AA5555AA5555AA55550000000055AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA0000AA00005500FFAA00AAFF00550000AA0000AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAFFFF55FF55FFAAFFAAFF55FF55FFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFF55AAAAAA55FF00FF55AAAAAA55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA55AA00AA55AAFFAA55AA00AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00AA00AAFFFFFFAA00AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA0000FFFFFF0000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFAAAAAAAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA5555AA5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA00FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 3.0731 0.200176 3.16042 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAA00FF55FFFF55FFFF00005555FF550055AAFFFFAA0000FFAAAA5500AAAA000055
AA5555550000FF55FFFF55FF0055555500FF55FFFF55FF0000555555AA550000AAAA0055
AAAAFF0000AAFFFFAA550055FF55550000FFFF55FFFF55FF00AAAAAAFF
FFFFAAFFFF00AAAA55AA55AAAAAAAA00AAFFAA5555550055AAFF55555555AAFFFFAA55FF
FFAAAAFFAA55FF55005555AAAAAAFFAAAAAA55550055FF55AAFFAAAAFFFF55AAFFFFAA55
555555FFAA5500555555AAFFAA00AAAAAAAA55AA55AAAA00FFFFAAFFFF
FFFFFFAA0000005500FF0055AA0055AAFFFFFFAAAAFFAA555555FF0055FF0000AAFFFF55
550000555555AAAAFF55FF00005500550000FF55FFAAAA55555500005555FFFFAA0000FF
5500FF555555AAFFAAAAFFFFFFAA5500AA5500FF0055000000AAFFFFFF
FFFFFFFFAA55FFAAAAAA55FFFFAA555555FF5555555500AAAA00AAFF55FF55AAFFFFFFFF
55FFAA5555AA550000AAAA55FFAAAAAAFF55AAAA000055AA5555AAFF55FFFFFFFFAA55FF
55FFAA00AAAA0055555555FF555555AAFFFF55AAAAAAFF55AAFFFFFFFF
FFFFFFFFFFAAAA55000055FF555555AA5555FFFF55FF00FF0000005555AAAAFFFFFFFFFF
FF555555AA5500FFFF0000FF5555555555FF0000FFFF0055AA555555FFFFFFFFFFFFAAAA
5555000000FF00FF55FFFF5555AA555555FF55000055AAAAFFFFFFFFFF
FFFFFFFFFFFFAAFFAA55FFFFFF55FFFFAAAA00FFAAAA55FF55AAFF55FF00005555005555
FF55FF005500FFFFFFFF00FFAAAA00AAAAFF00FFFFFFFF005500FF55FF55550055550000
FF55FFAA55FF55AAAAFF00AAAAFFFF55FFFFFF55AAFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA0055FF5555FFFFFFFFAAFF55555555AAAA005555AAAAAAAAFFAA5555
AAAA00FFFF55AAAA55AAAAAA5500000055AAAAAA55AAAA55FFFF00AAAA5555AAFFAAAAAA
AA555500AAAA55555555FFAAFFFFFFFF5555FF5500AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5555FF005555FF55555500FF55FFFFAAFF55FF00005500AA0055FF
FFAAFF5555FFFFAAFFAAFFFFAAAAAAAAAAFFFFAAFFAAFFFF5555FFAAFFFF5500AA005500
00FF55FFAAFFFF55FF00555555FF555500FF5555AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA00FFFF55FF5500FF55AAAAFF00AA55AA55AAFF55FFAAFF55FF
555555FFFF555500AA0055550000FF0000555500AA005555FFFF555555FF55FFAAFF55FF
AA55AA55AA00FFAAAA55FF0055FF55FFFF00AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF555500FFAAAAAA55555555FFAAFFAAFFAAFF0055555500FF
AAAA00AA00FF55FFAAFF55FF00FFFFFF00FF55FFAAFF55FF00AA00AAAAFF0055555500FF
AAFFAAFFAAFF55555555AAAAAAFF005555FFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00AAAAAA55000055FFFF55005500550055AAAAAAFFAAAAAA
55000000FFFFFF555555FFFFFF00AA00FFFFFF555555FFFFFF00000055AAAAAAFFAAAAAA
55005500550055FFFF55000055AAAAAA00AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55000055FFAA5555FF55FFAAAAAAFF5500005500550000
55FFAA55FF5555FFFF55FF5555FFAAFF5555FF55FFFF5555FF55AAFF5500005500550000
55FFAAAAAAFF55FF5555AAFF55000055AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA0000FF55FF5500550000FFAAAAAAAAFF55FFAA
555500AAAA5555AAAA5555FFFF555555FFFF5555AAAA5555AAAA005555AAFF55FFAAAAAA
AAFF0000550055FF55FF0000AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAA55FF550055FFAAAAAAAA55000055AAAA0000
FF55FFAAFFFF550000FF55FF5555AA5555FF55FF000055FFFFAAFF55FF0000AAAA550000
55AAAAAAAAFF550055FF55AAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000055FF55FFAAAA5500AA5500FFFF0055000000
00AAAA55005555AAFF5555AAAAFFAAFFAAAA5555FFAA55550055AAAA000000005500FFFF
0055AA0055AAAAFF55FF550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFF55555555AAFFFF55AAAA55FFFF00FF
FF000055FFAAAAFFFFFF550000FFAAFF000055FFFFFFAAAAFF550000FFFF00FFFF55AAAA
55FFFFAA55555555FFFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAAAFFAAAA005555FF0000FF5555FFAA
00FFFF0055555555FF5555AAFF555555FFAA5555FF5555555500FFFF00AAFF5555FF0000
FF555500AAAAFFAAAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAFFFFFFAAFF5500FFAA55FF5500FFAA
FF5555FFAAAAFFAAAA5555AA00FF55FF00AA5555AAAAFFAAAAFF5555FFAAFF0055FF55AA
FF0055FFAAFFFFFFAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055550055AAAAFF555555AAAAFF5555
55FFFF55555555000055FFFFAA55AA55AAFFFF55000055555555FFFF555555FFAAAA5555
55FFAAAA5500555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555AAFFAAFFFFFF55FF00005555AA
5555FF55FFFF55FFAA5555005500FF0055005555AAFF55FFFF55FF5555AA55550000FF55
FFFFFFAAFFAA5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00555555FF5555AAAAAAAA00AA
5555AAAA0000AAAA5500FF55AA55FF55AA55FF0055AAAA0000AAAA5555AA00AAAAAAAA55
55FF55555500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FF005555AA55000055AAFF
FF5500AA55FFAAFFFF55AAAA0055FF5500AAAA55FFFFAAFF55AA0055FFFFAA55000055AA
555500FF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFF55FFFFAAAAAAAAFFFF
FFFF55AA00AA005555FFFFAAFF55FF55FFAAFFFF555500AA00AA55FFFFFFFFAAAAAAAAFF
FF55FFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055FF555555555555FF
5555FF000000FFFF5500555555FFFFFF5555550055FFFF000000FF5555FF555555555555
FF550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FF55FFFF55FFFF
FF55FF55AAFF555500FFFF55FFFFFFFFFF55FFFF005555FFAA55FF55FFFFFF55FFFF55FF
00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00AAAA55AA55AA
AA5555FF0000AAAAFF5555FFFFFFFFFFFFFF5555FFAAAA0000FF5555AAAA55AA55AAAA00
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000005500FF0055
AA00AAAA55FFAAFFFFFF55FF5555FF5555FF55FFFFFFAAFF55AAAA00AA5500FF00550000
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAAAAAA55FF
FFAA5500AAAA55005555FFFFFF550055FFFFFF55550055AAAA0055AAFFFF55AAAAAAFF55
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55000055FF
555555AAFFFFAAAAAAFFAA00FFAAAAAAFF00AAFFAAAAAAFFFFAA555555FF55000055AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA55FFFF
FF55FFFFAA00FF0000FFAAFF5555555555FFAAFF0000FF00AAFFFF55FFFFFF55AAFFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FF55
55FFFFFFFFAA55AAFF555555FFFF55FFFF555555FFAA55AAFFFFFFFF5555FF5500AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555FF
FF5555FF555555AA00FF55FF00AAFFAA00FF55FF00AA555555FF5555FFFF5555AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00
FFAAAAFF0055FFFFAA55AA55AAFFFFFFAA55AA55AAFFFF5500FFAAAAFF00AAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
55555555FFAAAA55AA00AA555555FF555555AA00AA55AAAAFF55555555FFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
00AAAA00AA005500FF00FF0055FFFFFF5500FF00FF005500AA00AAAA00AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55000000FFFF55AAAAAA55FFFFFFFFFF55AAAAAA55FFFF00000055AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAAAAAA55AA550000FF5555FF5555FF000055AA55AAAAAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFFAAFFAAFFAA55FF55FFFFFF55FF55AAFFAAFFAAFFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA000055555500AAAA5555FF5555AAAA005555550000AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA55FFFF55FFAAFFFF550055FFFFAAFF55FFFF55AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAA55AA55AA00FFAAAAAAFF00AA55AA55AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFAAFFAAFF5555555555FFAAFFAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA0055555500FF55FF0055555500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5555AA55FF55FF55AA5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA0055FF55FF5500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF55FF55FF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00AAFFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 3.0731 0.39418 3.16042 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAA5500FF00FF000000AAAAAA000000005500FF000000AAAAAAAA00FF55AA00AA55AA
000055FF00AAAA55AA00FF000000FF000000FF00AA55AAAA00FF550000AA55AA00AA55FF
00AAAAAAAA000000FF005500000000AAAAAA000000FF00FF0055AAAAFF
FFFFAAFFAA55AAFF00FFFF0000AA5555AAFF55FF00AAAAAA0055555555AAAAFFFF000000
AAAAAAFF00FF000000FFFFFF00FFFFFF00FFFFFF000000FF00FFAAAAAA000000FFFFAAAA
5555555500AAAAAA00FF55FFAA5555AA0000FFFF00FFAA55AAFFAAFFFF
FFFFFFAA000000FFAA55AAAAAA00000000FFAAAA55555555000000000000AA55AAAAAAAA
00555555FF00AAAAAAAA55AAAAAA55AAAAAA55AAAAAAAA00FF55555500AAAAAAAA55AA00
000000000055555555AAAAFF00000000AAAAAA55AAFF000000AAFFFFFF
FFFFFFFFAA55FFAA000000FF000055FFAA55AA00000000000055FF00FFFF000000AA0000
AAAAFFAAAA555500AA000000FF000000FF000000AA005555AAAAFFAAAA0000AA000000FF
FF00FF55000000000000AA55AAFF550000FF000000AAFF55AAFFFFFFFF
FFFFFFFFFFAAAA5500FFFF00AAAAAAFF000000AAAAAAAAAAAAAAFF00FFAA00AAAA000055
00AA55AA0000000055AA55FF00AAAAAA00FF55AA5500000000AA55AA00550000AAAA00AA
FF00FFAAAAAAAAAAAAAA000000FFAAAAAA00FFFF0055AAAAFFFFFFFFFF
FFFFFFFFFFFFAAFFAA55AAAA0000AA00FFFF00FF0000FF0000AA00FF55550000FF00FF55
FF000000FF55AA55FFFFAAAA5555555555AAAAFFFF55AA55FF000000FF55FF00FF000055
55FF00AA0000FF0000FF00FFFF00AA0000AAAA55AAFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA000000FF00FFFFAA55AAAAAA5555AAAA00AA00AAFFAAAAAA00FFFFFF
5555AA5555FFFFAAAA55AA00000000000000AA55AAAAFFFF5555AA5555FFFFFF00AAAAAA
FFAA00AA00AAAA5555AAAAAA55AAFFFF00FF000000AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55FFAA00AAFF000000AA00000000AA555555AA00FF0000AAAA55AA
AAFFAAFFAAAA55AA000000AAAAAA00AAAAAA000000AA55AAAAFFAAFFAAAA55AAAA0000FF
00AA555555AA00000000AA000000FFAA00AAFF55AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA5500FF00AAAA00AA00AAAAAA0000000000AAAA5555AA000000
FF00AA00FF000000AAAAAA0000FF00FF0000AAAAAA000000FF00AA00FF000000AA5555AA
AA0000000000AAAAAA00AA00AAAA00FF0055AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFAA55AAFFFFAA550000AA0055FFAA5555AA00000000AAAAAA
AA555555AAAAAAAA0000AA5555AAAAAA5555AA0000AAAAAAAA555555AAAAAAAA00000000
AA5555AAFF5500AA000055AAFFFFAA55AAFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA000000FFAA0000005500AAAAFF00000000AAAAAAAA0000AA
0000000000AA0000AAAA00000000AA00000000AAAA0000AA0000000000AA0000AAAAAAAA
00000000FFAAAA0055000000AAFF000000AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55FFAA000055FFAAAA0055AAAAAAAA00AA00555555AAFF
FF00FF550000AAAA0000AAAAAA00AA00AAAAAA0000AAAA000055FF00FFFFAA55555500AA
00AAAAAAAA5500AAAAFF550000AAFF55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500FFFF555555000000AA0055AA550000000000AA
FF00FFAAAAAA0000AAAA0000AA555555AA0000AAAA0000AAAAAAFF00FFAA000000000055
AA5500AA000000555555FFFF0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA55AAAAFFAAAAAA00AA55FFFFAAAAAAAAAA00AA
00FF55555500AAAA0000AAAA0000000000AAAA0000AAAA00555555FF00AA00AAAAAAAAAA
FFFF55AA00AAAAAAFFAAAA55AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000FF00AA0000FFFFAAAA55AA0000AA000055
55AAAAFFAAAA0000FF5500AA00AAAAAA00AA0055FF0000AAAAFFAAAA55550000AA0000AA
55AAAAFFFF0000AA00FF000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAA00AA00AAAA55AA000000AAAA00550000
0000AA55AA005500FFAAAA00005555550000AAAAFF005500AA55AA000000005500AAAA00
0000AA55AAAA00AA00AAFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500FF00FF000000AAAAAA0000FF55FF00
FFFF000000AAAAFF55550055000000000055005555FFAAAA000000FFFF00FF55FF0000AA
AAAA000000FF00FF0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA55AAFF00FFFF0000AA5555AAAAFF00
FFAA00AAAA0000AAFFAAAAAAFF55AA55FFAAAAAAFFAA0000AAAA00AAFF00FFAAAA5555AA
0000FFFF00FFAA55AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000FFAA55AAAAAA00000000FF00AA
AA550000AA5555AA00FF0000AAFFAAFFAA0000FF00AA5555AA000055AAAA00FF00000000
AAAAAA55AAFF000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAA000000FF000055FFAA55AAFF
FFAAAAAA00000000AAAA5555AA00FF00AA5555AAAA00000000AAAAAAFFFFAA55AAFF5500
00FF000000AAFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500FFFF00AAAAAAFF000000AA
FF0000FF00FFFF00FF00000000FFFFFF00000000FF00FFFF00FF0000FFAA000000FFAAAA
AA00FFFF0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA55AAAA0000AA00FFFF00FF
00AAAA00FF5555FF00AAAAAAAAAA55AAAAAAAAAA00FF5555FF00AAAA00FF00FFFF00AA00
00AAAA55AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000FF00FFFFAA55AAAAAA
55555555AAAAFFAA00AA0000FF000000FF0000AA00AAFFAAAA55555555AAAAAA55AAFFFF
00FF000000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAA00AAFF000000AA00
0000000000AA55AA00AA55FF00AAAAAA00FF55AA00AA55AA000000000000AA000000FFAA
00AAFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500FF00AAAA00AA00
AAAAAAAAAA000000FFFFAAAA5555555555AAAAFFFF000000AAAAAAAAAA00AA00AAAA00FF
0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA55AAFFFFAA5500
00AA0000AA00AAAAAA55AA00000000000000AA55AAAAAA00AA0000AA000055AAFFFFAA55
AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000FFAA000000
5500AAAA005500AA000000AAAAAA00AAAAAA000000AA005500AAAA0055000000AAFF0000
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAA00005500
0000555500000055AA55FF0000FF00FF0000FF55AA550000005555000000550000AAFF55
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500FFFF55
AA55FFFF55AA55FFFFAAAA5555AAAAAA5555AAAAFFFF55AA55FFFF55AA55FFFF0055AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA55AAAA
FFFF5555FFFFAAAA55AA00000000AA00000000AA55AAAAFFFF5555FFFFAAAA55AAFFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000000FF
00AAFFAAAA55AA000000AAAAAA00AA00AAAAAA000000AA55AAAAFFAA00FF000000AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAA
00AA00FF000000AAAAAA0000AA555555AA0000AAAAAA000000FF00AA00AAFF55AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55
00FF00FFAA5555AA0000AAAA0000000000AAAA0000AA5555AAFF00FF0055AAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
AA55AAFF00000000AAAA0000AAAAAAAAAA0000AAAA00000000FFAA55AAFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
000000FFAA5555AAFFFFAA55555555555555AAFFFFAA5555AAFF000000AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55FFAA00000000AAFF000000000000000000FFAA00000000AAFF55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAA5500FFFF00FF00AAAAAAAAAAAAAAAAAA00FF00FFFF0055AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFAA55AAAAAA5555555555555555555555AAAAAA55AAFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA000000FF00000000000000000000000000FF000000AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA55FF00AAAAAA00AAAAAAAAAA00AAAAAA00FF55AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAA555500AA55555555555555AA005555AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFAAAA000000000000000000AAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA0000AAAA00AAAAAA00AAAA0000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5555550000AA0000555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAFFAA555555AAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF0000000000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00AAAAAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 3.0731 0.588183 3.16042 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAA55FF005500FFAA00AA5555AA0000FFAAAAFF5555FFAAAA555500AA5500AA55AAAA
00AA00AAAA550000AAAAAA00AA00AA00AA00AAAAAA000055AAAA00AA00AAAA55AA0055AA
005555AAAAFF5555FFAAAAFF0000AA5555AA00AAFF005500FF55AAAAFF
FFFFAA0055FFAAAAAA00FFFFAAAAFF00FFFFFFAA00AA5500FFAA0055AAFFFF55AAAAFFFF
AA55AAFFFFAAAAAAAA55AAAAAA55FF55AAAAAA55AAAAAAAAFFFFAA55AAFFFFAAAA55FFFF
AA5500AAFF0055AA00AAFFFFFF00FFAAAAFFFF00AAAAAAFF5500AAFFFF
FFFFFFAA5500FFAA00FFFFFFFFAA000000AAAA00FFFFAAAAAA00FFFF5555AA5500005555
AAAAFF0055FF5555FF55FF5555FFFFFF5555FF55FF5555FF5500FFAAAA5555000055AA55
55FFFF00AAAAAAFFFF00AAAA000000AAFFFFFFFF00AAFF0055AAFFFFFF
FFFFFFFFAAAAAA00FFFFFFFFFFFFAA55FFAA00FFFFFFFFAA00FFFFFFFF55FF55FFAA5500
AAFFFFFF0000AA550055AA5500AA00AA0055AA550055AA0000FFFFFFAA0055AAFF55FF55
FFFFFFFF00AAFFFFFFFF00AAFF55AAFFFFFFFFFFFF00AAAAAAFFFFFFFF
FFFFFFFFFFAA00FFFFFFFFFFFFFFFFAAAA00FFFFFFFFFFFFAA555500555555AA000055AA
FFFFFFFFFF00FFAAAAAAFFFF55AAAAAA55FFFFAAAAAAFF00FFFFFFFFFFAA550000AA5555
55005555AAFFFFFFFFFFFF00AAAAFFFFFFFFFFFFFFFF00AAFFFFFFFFFF
FFFFFFFFFFFFAA5555005555005555AAAA55FF005555AA5555FFFF55AA0055AAAAAAAAFF
FFFFFFFFFFFF0055000055FF0000550000FF5500005500FFFFFFFFFFFFFFAAAAAAAA5500
AA55FFFF5555AA555500FF55AAAA5555005555005555AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAFF55FFFF0000FFAA0055FFAAAAFFFF55FF0055AAAAAAFFFFAAFFFF
FFFFFFFFFFFFFF00000000FF55AAFFAA55FF00000000FFFFFFFFFFFFFFFFFFAAFFFFAAAA
AA5500FF55FFFFAAAAFF5500AAFF0000FFFF55FFAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00AA5555AAFF55000000FF5555FF0055AA55FFFFAA00FF550000AA
AA00AA00AA00AAAAAAAAAAAA0055005500AAAAAAAAAAAA00AA00AA00AAAA000055FF00AA
FFFF55AA5500FF5555FF00000055FFAA5555AA00AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA55AA00550055AAFF55AA5500AAAAAAFF0000AA00FFFFFF55AAFF
FFAA55AAFFFF00AAFFFFAAFFFF000000FFFFAAFFFFAA00FFFFAA55AAFFFFAA55FFFFFF00
AA0000FFAAAAAA0055AA55FFAA55005500AA55AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA55FFFF0000555555FFFF00AAFFFFFF00FFAA55550055AAAA
00AAFFAA00AAAAAA55550000AAAAAAAAAA00005555AAAAAA00AAFFAA00AAAA55005555AA
FF00FFFFFFAA00FFFF5555550000FFFF55AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA0055FF00FFFF55FFFFFFFF00AAAA000000AAFFAAAAAAFFFF
AA55AA55AAFFFFAA0055AAFF5555FF5555FFAA5500AAFFFFAA55AA55AAFFFFAAAAAAFFAA
000000AAAA00FFFFFFFF55FFFF00FF5500AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA5500FFFFFFFF550055FF00FFAAFF55AAFFFFFFAAFF0055
55FFFFAAAA5555AAAAAAFF0055AA00AA5500FFAAAAAA5555AAAAFFFF555500FFAAFFFFFF
AA55FFAAFF00FF550055FFFFFFFF0055AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00AA00AA55FFFFFF00550055AAAA00AA00FF55AA
005555AAAA5500AAFF00AAAAAAFF00FFAAAAAA00FFAA0055AAAA555500AA55FF00AA00AA
AA55005500FFFFFF55AA00AA00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFFAA55AA00AA000000FFFF5555FFAAFF5500AA
FF55FFFFAAFFAA55AA55FF5555FF00FF5555FF55AA55AAFFAAFFFF55FFAA0055FFAAFF55
55FFFF000000AA00AA55AAFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55550000FFAA55AAFF55AA555555550000AA55FF
5500AAAA00FF555555FFFFFF55FF00FF55FFFFFF555555FF00AAAA0055FF55AA00005555
5555AA55FFAA55AAFF00005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55AA55AA00FF55FF55FFFF55FFAA55AA00
00FFFFAAFF5500AA55005555AA000000AA55550055AA0055FFAAFFFF0000AA55AAFF55FF
FF55FF55FF00AA55AA55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA55AA00FFFFFF5500AA0000FF555555FF
AA55550000AA55FF55FFAAAAFFFF00FFFFAAAAFF55FF55AA00005555AAFF555555FF0000
AA0055FFFFFF00AA55AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA00FFFFFFFFFF55AAAAAAAA0055AA00
AAFFAAAAAAAA5500FF00550000AAAAAA00005500FF0055AAAAAAAAFFAA00AA5500AAAAAA
AA55FFFFFFFFFF00AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF0055550055AAAA55AAAAAAFFFF
00AA00FFAAFFFF55AA55FFFF00FFAAFF00FFFF55AA55FFFFAAFF00AA00FFFFAAAAAA55AA
AA5500555500FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FFAAAAFF55FF555555FF5555AA
55FF55AA55AA555555FFFFFFFF005500FFFFFFFF555555AA55AA55FF55AA5555FF555555
FF55FFAAAAFF5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FFAA00AA5555555555AA0055
00AAAAFFFF5555555555AA5555AAFFAA5555AA5555555555FFFFAAAA005500AA55555555
55AA00AAFF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FFFFAAAAFFAAAAFFFF00
00005500FF55FFFF55FFFFAAAAFFFFFFAAAAFFFF55FFFF55FF0055000000FFFFAAAAFFAA
AAFFFF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFFFFFFAA00AAFFFFFFFF
00FFFF55AA550055555500550000AA000055005555550055AA55FFFF00FFFFFFFFAA00AA
FFFFFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555005555FFAA00AAAA00
0000AAAAFFFF55AA0055AAFFAA55FF55AAFFAA5500AA55FFFFAAAA000000AAAA00AAFF55
55005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55FFFFFFAA55AAAA
AAAAAA55AA555555FFAAAA5555FFFFFF5555AAAAFF555555AA55AAAAAAAAAA55AAFFFFFF
55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA5555AA55AA00FF
AAFFFFAAAA5500AA5555FF55FFFFFFFFFF55FF5555AA0055AAAAFFFFAAFF00AA55AA5555
AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA005500AAFF55
0000AA00FFAAAAAA5500AA00555500555500AA0055AAAAAAFF00AA000055FFAA005500AA
55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FFFF00AAAA
FF55AAAAAA00FFAAFFAA55AAFFAAAAAAFFAA55AAFFAAFF00AAAAAA55FFAAAA00FFFF55AA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055FF00FFAA
0000FFAAFF00FF5555AAAAFFFFFFAAFFFFFFAAAA5555FF00FFAAFF0000AAFF00FF5500AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FFFFFF
AA55FF00AAAAAA0055AAAA5555AA55AA5555AAAA5500AAAAAA00FF55AAFFFFFF0055AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00AA
AA5500FFFFAA00FFFF5555FFFF555555FFFF5555FFFF00AAFFFF0055AAAA00AAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF
AAFFAA5555000000AA0055AA5555555555AA5500AA0000005555AAFFAAFFFF00AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555
0000AAFFAAAAAAAAAA55FFFFAAAAFFAAAAFFFF55AAAAAAAAAAFFAA00005555AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
FF55AAAA00FFAA00FFAAAA00AAFFFFFFAA00AAAAFF00AAFF00AAAA55FFAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
00AA55AAAAAA00FFFFFFAAFF5555AA5555FFAAFFFFFF00AAAAAA55AA00AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55AA00FFAAFF5500FF555500AA55AA005555FF0055FFAAFF00AA55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAA55FF00AAAAFF5500AA55FF55FF55AA0055FFAAAA00FF55AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA0055FFAA00FF55FFAA0055555500AAFF55FF00AAFF5500AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA5500FFAA555555AAAAAAFFAAAAAA555555AAFF0055AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAAA00FF0000FFAAFFFFFFAAFF0000FF00AAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA00FFFFFF00FF5555AA5555FF00FFFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA555500FFFFFF55FF55FFFFFF005555AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAFF550055FFFFFF550055FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00AA55FFFFFFFFFF55AA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA55AA0000AA0000AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA55FFAAFF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA0055FF5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 3.0731 0.782187 3.16042 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAA00FF00AA55AA55AA55FFFFFFFFFFAA555500AAFFAA55FF55AAFFAAFFAA55AAAA
FF55AAAA00AA55FFFFFF55AA55FFAAFF55AA55FFFFFF55AA00AAAA55FFAAAA55AAFFAAFF
AA55FF55AAFFAA005555AAFFFFFFFFFF55AA55AA55AA00FF00AAAAAAFF
FFFFAA00FFFFFF00AAAA5555FFFFFFFFFFFFFFAAAAFF555555FFFFFF55550000AAFFAAFF
FFFF5555FFAA00AA005555AAAA005500AAAA555500AA00AAFF5555FFFFFFAAFFAA000055
55FFFFFF555555FFAAAAFFFFFFFFFFFFFF5555AAAA00FFFFFF00AAFFFF
FFFFFFAA550055AAFF00AAAA0000AA00555555000055AA5555AA005555AA55FFAA000055
AA0055FFFFFFAA55AAFFAAAA55AAFFAA55AAAAFFAA55AAFFFFFF5500AA550000AAFF55AA
555500AA5555AA55000055555500AA0000AAAA00FFAA550055AAFFFFFF
FFFFFFFFAAAAAA00FF00FFAAFF55AAAAAAFFAAAAAAAAFFFF55FF55AA5555FFFFFFAA55FF
FFAA5555555555FF00AA55AAAAFFFFFFAAAA55AA00FF5555555555AAFFFF55AAFFFFFF55
55AA55FF55FFFFAAAAAAAAFFAAAAAA55FFAAFF00FF00AAAAAAFFFFFFFF
FFFFFFFFFFAA00FFFFFF000055AA55AAAA550000550000AA555555AAAA00AA005555FFFF
FFFFAAAA00AAAA00000055FF5555555555FF55000000AAAA00AAAAFFFFFFFF555500AA00
AAAA555555AA000055000055AAAA55AA550000FFFFFF00AAFFFFFFFFFF
FFFFFFFFFFFFAA550055AAFF55FF55FF5555AAFF55FFAA55AA5555AAAA55FF55AA555555
555555FF55AAAA55FFAA555500FF55FF005555AAFF55AAAA55FF555555555555AA55FF55
AAAA5555AA55AAFF55FFAA5555FF55FF55FFAA550055AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA00FF0055AA5500FF555555AA00FF5555AA55AAAA0055FF5500FF
55FF005555AAAA555555FFFF55AA00AA55FFFF555555AAAA555500FF55FF0055FF5500AA
AA55AA5555FF00AA555555FF0055AA5500FF00AAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00FFFFFF005500FFFFFF55FFFFAA5500FF5555AAAA55FFFFFF55AA
00AA55FFFF5555FFFF55005555AAAAAA55550055FFFF5555FFFF55AA00AA55FFFFFF55AA
AA5555FF0055AAFFFF55FFFFFF005500FFFFFF00AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA550055AAFFAA5500AA5555005500FFFFFF55FF5555AA005555AA
AAAA55550055FFFFFFFF55AA5555FF5555AA55FFFFFFFF55005555AAAAAA555500AA5555
FF55FFFFFF0055005555AA0055AAFFAA550055AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAA00FF00AAAAAA5555AAFFAA5500AA555555AA55AAFFAAAA
55AAAAFFAA555555005555AAAA00AA00AAAA555500555555AAFFAAAA55AAAAFFAA55AA55
5555AA0055AAFFAA5555AAAAAA00FF00AAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00FFFFFF00AAFFFF550000AAFFAA55AA5555AAAAFFFFFFAA
00AAFFFFFFAAAAFFAA5555AAAA55FF55AAAA5555AAFFAAAAFFFFFFAA00AAFFFFFFAAAA55
55AA55AAFFAA000055FFFFAA00FFFFFF00AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFF0000FF55AAFFFFFFAAAA5555AAAA5500AA55
AAFFFFFFFFFFAA000055FFFFAA00AA00AAFFFF550000AAFFFFFFFFFFAA55AA0055AAAA55
55AAAAFFFFFFAA55FF0000FFAA550055AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FF00FFFFFF555500AA55AAAA00AAFFFF55AAAA
FFFFFFFFFFFFFFAA55FFFFFFFFAA55AAFFFFFFFF55AAFFFFFFFFFFFFFFAAAA55FFFFAA00
AAAA55AA005555FFFFFF00FF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFFFF0000AA5555AAFFFF5555FFAA0000AAAA55
AA005555550055AAAA00555500AAFFAA00555500AAAA550055555500AA55AAAA0000AAFF
5555FFFFAA5555AA0000FFFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFF5555AA55AA0055FFFFFFAA55FF5555
AAAAAAFFAAAAAAFFFFAA5555AAFFFFFFAA5555AAFFFFAAAAAAFFAAAAAA5555FF55AAFFFF
FF5500AA55AA5555FFAA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FF0055FF55FF55AA550055AAAA0055FF
FFAAFFFFFFAAFFFFFFFFAAAAFFFFFFFFFFAAAAFFFFFFFFAAFFFFFFAAFFFF5500AAAA5500
55AA55FF55FF5500FF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFFFF0055AA5500FFAAAAAAFFFFAA5555
550000AA000055555500AAFFFFFFFFFFFFFFAA005555550000AA0000555555AAFFFFAAAA
AAFF0055AA5500FFFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFFAAFFAA550000550055AAAA00
AAAAAAAA55FFAAAAFFAA55AA0000AA0000AA55AAFFAAAAFF55AAAAAAAA00AAAA55005500
0055AAFFAAFFAA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FF00AA55AA55FFAAAAAAFFFFAA
55AAAA55AA5500005555FFFFAA55FF55AAFFFF5555000055AA55AAAA55AAFFFFAAAAAAFF
55AA55AA00FF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFFFF00AAAA555555FF55555555
FFFFAA00AAFFAA55FF00555555FFFFFF55555500FF55AAFFAA00AAFFFF55555555FF5555
55AAAA00FFFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFF00AAAA00AA5555AA55
55550000005555FFFFFF0055FFFFFFFFFF5500FFFFFF5555000000555555AA5555AA00AA
AA00FFAA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FF00FFAAFF5555AA55AA
5555AAFF55AA555500AA55FFFFFFFFFFFFFF55AA005555AA55FFAA5555AA55AA5555FFAA
FF00FF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFFFF000055AA5555FFFF
AAAAFFFFFF5555AA55FF550055555555550055FF55AA5555FFFFFFAAAAFFFF5555AA5500
00FFFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFF55FF55FFFFFF
FFAA0000AA5555AAAA0055FFAAAAFFAAAAFF5500AAAA5555AA0000AAFFFFFFFF55FF55FF
AA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FF0055AA5500AA
550000000055FF00AAFF5500AAFFFFFFAA0055FFAA00FF550000000055AA0055AA5500FF
00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFFFF005500FFFF
AAAAAAAAAAAA0000005555AAFFFFFFFFFFAA5555000000AAAAAAAAAAAAFFFF005500FFFF
FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFFAA5500
AAFFFFAAFFFFAA55FFAAAAFFFFFFFFFFFFFFAAAAFF55AAFFFFAAFFFFAA0055AAFFAA5500
55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FF00AAAA
AA5500550055AAAA00005500555555555500550000AAAA5500550055AAAAAA00FF00AAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFFFF00AA
FFFF55AA55FFFFAAFF55AA55FFFF55FFFF55AA55FFAAFFFF55AA55FFFFAA00FFFFFF00AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFF
0000FF5555AA00550055FF5500AA00AA0055FF55005500AA5555FF0000FFAA550055AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FF
00FFFFFF55FF55AA55FFFFFF55AAAAAA55FFFFFF55AA55FF55FFFFFF00FF00AAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFFF
FF0000AA555555AAAA0000AA5555FF5555AA0000AAAA555555AA0000FFFFFF00AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500
55AAFF5555AA5555FF55AAFFFF550055FFFFAA55FF5555AA5555FFAA550055AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
AA00FF0055FF55FFFFFF555500AAAAAA005555FFFFFF55FF5500FF00AAAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
00FFFFFF0055AA5500AA00AAAAAA55AAAAAA00AA0055AA5500FFFFFF00AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA550055AAFFAAFFAA55AAFFFFAAFFAAFFFFAA55AAFFAAFFAA550055AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAA00FF00AA55AA55AA0055005500AA55AA55AA00FF00AAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA00FFFFFF00AAAA5555FFAAAAAAFF5555AAAA00FFFFFF00AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA550055AAFF00AAAA0000550000AAAA00FFAA550055AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAAA00FF00FFAAFF55AA55FFAAFF00FF00AAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA00FFFFFF000055AA55AA550000FFFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA550055AAFF55FF55FF55FFAA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA00FF0055AA5500FF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA00FFFFFF005500FFFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA550055AAFFAA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAA00FF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00FFFFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 3.0731 0.97619 3.16042 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAA000055FF5555AAAA5555000000FFFF55555500AA00000055005500FFFF00AAFFAA55
55FF55AAAAAA555555FF5555FF555555FF5555FF555555AAAAAA55FF5555AAFFAA00FFFF
00550055000000AA00555555FFFF0000005555AAAA5555FF550000AAFF
FFFFAA55FFFFFF55555555FFFF00FFFFFFFF5555FFAAFF55AAFF00FFAA5555AAFFFFFFAA
00FF5555555555FF5555AAAA5555FF5555AAAA5555FF5555555555FF00AAFFFFFFAA5555
AAFF00FFAA55FFAAFF5555FFFFFFFF00FFFF55555555FFFFFF55AAFFFF
FFFFFFAA000055FF5555FF55000000550055FF555500AAAAFFFFFF0055AAAAFFFFFFFFFF
AA5555FFFF55FFFFFF55555555FFFFFF55555555FFFFFF55FFFF5555AAFFFFFFFFFFAAAA
5500FFFFFFAAAA005555FF55005500000055FF5555FF550000AAFFFFFF
FFFFFFFFAA55FFFFFF5555AAAAAAAAAA55FFFFFF55FFAAFFFFFFFFFF00AA550000550055
5555FFFFFFFF55005555FFFF5555AA5555FFFF55550055FFFFFFFF5555550055000055AA
00FFFFFFFFFFAAFF55FFFFFF55AAAAAAAAAA5555FFFFFF55AAFFFFFFFF
FFFFFFFFFFAA000055FF55555555555555FF0055FF5500AA00005500FFFFAAAAAAAA55FF
55FF55005555AAAAAAFF0055FF555555FF5500FFAAAAAA55550055FF55FF55AAAAAAAAFF
FF00550000AA0055FF5500FF55555555555555FF550000AAFFFFFFFFFF
FFFFFFFFFFFFAA55FFFFFF5555FF5555FFFFFF00AA00FFFFAA55FF55AA555555555555FF
00AAAAFF55FFFFAAFFFFFF00AAAAFFAAAA00FFFFFFAAFFFF55FFAAAA00FF555555555555
AA55FF55AAFFFF00AA00FFFFFF5555FF5555FFFFFF55AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA000055FF5555AAAA5555000000FFFFFFFFAA00AAFFFF5555FF55FFFF
FF0000FF5555AA55000055FFAAFFFFFFAAFF55000055AA5555FF0000FFFFFF55FF5555FF
FFAA00AAFFFFFFFF0000005555AAAA5555FF550000AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55FFFFFF55555555FFFF00FFFFFFFFFFFFAA55005555FFFFFF5500
55FFAA5555FFFFAAAAAAAA55555500555555AAAAAAAAFFFF5555AAFF550055FFFFFF5555
0055AAFFFFFFFFFFFF00FFFF55555555FFFFFF55AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA000055FF5555FF55000000550055FF0055AAAAAA55AA5555AAAA
AA555555FF550055AA0055AAAAFF00FFAAAA5500AA550055FF555555AAAAAA5555AA55AA
AAAA5500FF55005500000055FF5555FF550000AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA55FFFFFF5555AAAAAAAAAA55FFFFFF00AA5500AAFFFF555555
5555FF5555AAAAAAFFFF00AA5500000055AA00FFFFAAAAAA5555FF5555555555FFFFAA00
55AA00FFFFFF55AAAAAAAAAA5555FFFFFF55AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA000055FF55555555555555FF0055FFAAFFAA550055FF55FF
55FFFFFF555555555500FFFFAAAAAAAAAAFFFF005555555555FFFFFF55FF55FF550055AA
FFAAFF5500FF55555555555555FF550000AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFF5555FF5555FFFFFF00AA00555555FFAAAA00FF
5555AA5555FF5555FFFF005555555555555500FFFF5555FF5555AA5555FF00AAAAFF5555
5500AA00FFFFFF5555FF5555FFFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAA000055FF5555AAAA5555000000FFFF5555FF0000FFFF
FF555555FFFFFF555500FFFF5555FF5555FFFF005555FFFFFF555555FFFFFF0000FF5555
FFFF0000005555AAAA5555FF550000AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFF55555555FFFF00FFFFFFFF5555AAFF5500
55FFFF5555005555FFFF005555FFFFFF555500FFFF5555005555FFFF550055FFAA5555FF
FFFFFF00FFFF55555555FFFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000055FF5555FF55000000550055FF555555AAAA
AA5555AAAAFF55FF5500FFFF5555AA5555FFFF0055FF55FFAAAA5555AAAAAA555555FF55
005500000055FF5555FF550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFF5555AAAAAAAAAA55FFFFFF55FFFFAA
FFFF55555555AAAA00FFFFFFFF555555FFFFFFFF00AAAA55555555FFFFAAFFFF55FFFFFF
55AAAAAAAAAA5555FFFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000055FF55555555555555FF0055FF5500FF
0055FF5555FFFFAAFF5500005555FF5555000055FFAAFFFF5555FF5500FF0055FF5500FF
55555555555555FF550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFF5555FF5555FFFFFF00AA00FFFF
FF00AAAAFF00555555AAAAAAAA55AA55AAAAAAAA55555500FFAAAA00FFFFFF00AA00FFFF
FF5555FF5555FFFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000055FF5555AAAA5555000000FFFFFF
FFFF0000FF55AAAAFFAAFFFFAAFFAAFFAAFFFFAAFFAAAA55FF0000FFFFFFFFFF00000055
55AAAA5555FF550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFF55555555FFFF00FFFFFFFF
FFFFFF00FF5555555500AAAA0055555500AAAA0055555555FF00FFFFFFFFFFFFFF00FFFF
55555555FFFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000055FF5555FF55000000550000
555500FFFFFF5555FFFF0000FFFF55FFFF0000FFFF5555FFFFFF00555500005500000055
FF5555FF550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFF5555AAAAAAAAAA55FF
AA00FFFFFFFFFF55550000000055FF55000000005555FFFFFFFFFF00AAFF55AAAAAAAAAA
5555FFFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000055FF55555555555555FF
0000005555AA5555FFFF00FFFF00AA00FFFF00FFFF5555AA5555000000FF555555555555
55FF550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFF5555FF5555FFFF
FF00FFFF555555FF5500000055FFAAFF5500000055FF555555FFFF00FFFFFF5555FF5555
FFFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000055FF5555AAAA5555
0000005555FF5555AAAAAAAAAA555555AAAAAAAAAA5555FF55550000005555AAAA5555FF
550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFF55555555FF
FF00FFFF5555AAAA5500AA5500AAFFAA0055AA0055AAAA5555FFFF00FFFF55555555FFFF
FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000055FF5555FF55
00000055FF55555555FFAAFFAA550055AAFFAAFF55555555FF5500000055FF5555FF5500
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFF5555AA
AAAAAAAA5555FF5555FF000055AAAAAA550000FF5555FF5555AAAAAAAAAA5555FFFFFF55
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000055FF5555
5555555555FFFFFF5555AAFF5555555555FFAA5555FFFFFF55555555555555FF550000AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFFF55
55FF5555FF550055FF555555AAAAFFAAAA555555FF550055FF5555FF5555FFFFFF55AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA000055FF
5555AAAA5555FFAA00AAFF00AA550055AA00FFAA00AAFF5555AAAA5555FF550000AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFF
FF55555555FFFFFFAA5500FFFFAAAAAAFFFF0055AAFFFFFF55555555FFFFFF55AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0000
55FF5555FF55000055AAAAAA0000FF0000AAAAAA55000055FF5555FF550000AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55
FFFFFF5555AAAAAAAAFFFFAAFF55AA55FFAAFFFFAAAAAAAA5555FFFFFF55AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
000055FF5555555555550000FF555555FF0000555555555555FF550000AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55FFFFFF5555FF5555FFAA5555FF5555AAFF5555FF5555FFFFFF55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAA000055FF5555AAAA555555FFFFFF555555AAAA5555FF550000AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA55FFFFFF55555555FF5555AA5555FF55555555FFFFFF55AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA000055FF5555FFFFFF555555FFFFFF5555FF550000AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA55FFFFFF5555AA5555FF5555AA5555FFFFFF55AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA000055FF555555FFFFFF555555FF550000AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA55FFFFFF55FFFFFFFFFF55FFFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA000055FFFFFFFFFFFFFF550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55FFFFFFFFFFFFFFFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA00005555AA55550000AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA55FF555555FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00AAFFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 3.16915 0.200176 3.25646 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAA55AAAA0055555500FF5555FFAAAA5555AA555555AA5500FFFFAA5555555555555500
AA55AAAAFF5555AA55AAFFAA55FF00FF55AAFFAA55AA5555FFAAAA55AA00555555555555
55AAFFFF0055AA555555AA5555AAAAFF5555FF0055555500AAAA55AAFF
FFFFAA5500AAAAFFAA5555000055555555FFFFAA55AAFFFF00555500AAFFAAAAFF5555FF
000055AA00005500AAFFFFFFAA000000AAFFFFFFAA00550000AA550000FF5555FFAAAAFF
AA00555500FFFFAA55AAFFFF5555555500005555AAFFAAAA0055AAFFFF
FFFFFFAA5555555500AAFF5500FFAA00FFFFFFFFAA00555500FFAAAA0055555555000055
55AA55AA00AAAA55555500555555AA55555500555555AAAA00AA55AA5555000055555555
00AAAAFF00555500AAFFFFFFFF00AAFF0055FFAA0055555555AAFFFFFF
FFFFFFFFAA55AAAA555555000000AA555500555500AAAAFF0055555555AAAAAAFF5500FF
FF000055AA5500AAFF5555AAFF555555FFAA5555FFAA0055AA550000FFFF0055FFAAAAAA
5555555500FFAAAA005555005555AA000000555555AAAA55AAFFFFFFFF
FFFFFFFFFFAA5500AAFFAA5555AA55000055FFAA5555555500FFFF55FFFFAAFFFFFF0055
5500FF555555FF0000AAFF0000AAFFAA0000FFAA0000FF555555FF00555500FFFFFFAAFF
FF55FFFF0055555555AAFF55000055AA5555AAFFAA0055AAFFFFFFFFFF
FFFFFFFFFFFFAA55555500AAFFAAFF0055FFFFFFAA55FFFF0055550000AA0055550055FF
AAAA0000550000AAAA005555AA550055AA555500AAAA0000550000AAAAFF5500555500AA
0000555500FFFF55AAFFFFFF5500FFAAFFAA00555555AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA55AAAA0055555500FFFFFFFFFFAA0000AAAAFF5500FF005500000055
555555AA55AA55555555AAAA5500000055AAAA55555555AA55AA555555550000005500FF
0055FFAAAA0000AAFFFFFFFFFF0055555500AAAA55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5500AAAAFFAA55550055550055AA55555555000000AAAAAA00AAAA
AAAAFF000055AAAAAAAAFFFFAAAA00AAAAFFFFAAAAAAAA550000FFAAAAAAAA00AAAAAA00
000055555555AA55005555005555AAFFAAAA0055AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA5555555500AAFF55000055FFAAFF55FFAA5555AA5500AA555555
55555500FF5555555555550055AA00AA5500555555555555FF00555555555555AA0055AA
5555AAFF55FFAAFF55000055FFAA0055555555AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA55AAAA555555000000005555550000AA55FFFFAA555555FFAA
AAAAAAAA00005500005500000055AA55000000550000550000AAAAAAAAAAFF555555AAFF
FF55AA000055555500000000555555AAAA55AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA5500AAFFAA5555AA5555FF5555AA550000AA005500005555
5555555555AA55AA5555FF0055FFAAFF5500FF5555AA55AA5555555555555500005500AA
000055AA5555FF5555AA5555AAFFAA0055AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55555500AAFFAAFF00AA00FFAAFF5500FF005500FF55FF
AAAAAAAAFFAAFFAAFFAA000000555555000000AAFFAAFFAAFFAAAAAAAAFF55FF005500FF
0055FFAAFF00AA00FFAAFFAA00555555AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAA0055555500FF00555555000000AAAAAA000055
555555555500AA00555555AA5555FF5555AA55555500AA005555555555550000AAAAAA00
000055555500FF0055555500AAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AAAAFFAA555500FFFF5555AA5555555555AA55
FFAAAAAAFF0055AA55AAFFAAFF00AA00FFAAFFAA55AA5500FFAAAAAAFF55AA5555555555
AA5555FFFF005555AAFFAAAA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555555500AAFF55005555FFFFAAAAAAAAFF0000
555555555500FFFFAA0055555500FF0055555500AAFFFF0055555555550000FFAAAAAAAA
FFFF55550055FFAA0055555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAA555555000000550055555555555500FF
55FFAAAAAAAA0000AA5555FFFF550055FFFF5555AA0000AAAAAAAAFF55FF005555555555
550055000000555555AAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AAFFAA5555AA55AA55FFAAAAAAAAAA00
00555555555555AA55000055550000005555000055AA5555555555550000AAAAAAAAAAFF
55AA55AA5555AAFFAA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55555500AAFFAAFF000055555555555555
AA55FFAAAAFFAA005500FF55AAAA00AAAA55FF005500AAFFAAAAFF55AA55555555555555
0000FFAAFFAA00555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAA0055555500FF5555FFAAAAAAFF
00005555555500AAAAAA000055AA00AA550000AAAAAA00555555550000FFAAAAAAFF5555
FF0055555500AAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AAAAFFAA555500005555555555
00FF5555FFAA5555555555AA55AA00AA55AA5555555555AAFF5555FF0055555555550000
5555AAFFAAAA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555555500AAFF5500FFAA00FFFF
005555FFFFFFAAAAAAAAFF000055AA550000FFAAAAAAAAFFFFFF555500FFFF00AAFF0055
FFAA0055555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAA555555000000AA555500
55FF55550055555555555500FF555555FF00555555555555005555FF55005555AA000000
555555AAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AAFFAA5555AA55000055
FFFFFF5555AAAAAAAAAAAAAA0000550000AAAAAAAAAAAAAA5555FFFFFF55000055AA5555
AAFFAA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55555500AAFFAAFF0055FF
FFFFFFFF555555555555555555AA55AA555555555555555555FFFFFFFFFF5500FFAAFFAA
00555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAA0055555500FFFF
FFFFFFFFFF5555FFAAAAAAAAFFAAFFAAFFAAAAAAAAFF5555FFFFFFFFFFFFFF0055555500
AAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AAAAFFAA555500
5555005555000055555555555500AA0055555555555500005555005555005555AAFFAAAA
0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555555500AAFF55
000055FFAA00AAAAFFAAAAAAAA555555AAAAAAAAFFAAAA00AAFF55000055FFAA00555555
55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAA55555500
000000555555AA00555555555555FF55555555555500AA55555500000000555555AAAA55
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AAFFAA55
55AA5555FF555555AAFFAAAAFF00AA00FFAAAAFFAA555555FF5555AA5555AAFFAA0055AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55555500AA
FFAAFF00AA00FFAA005555555500FF005555555500AAFF00AA00FFAAFFAA00555555AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAA00
55555500FF00555555AAAAAAFF550055FFAAAAAA55555500FF0055555500AAAA55AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AA
AAFFAA555500FFFF55555555550000005555555555FFFF005555AAFFAAAA0055AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555
555500AAFF55005555FF55FFAAAA00AAAAFF55FF55550055FFAA0055555555AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55
AAAA5555550000005500550055AA00AA5500550055000000555555AAAA55AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
5500AAFFAA5555AA55AA55AA55AA00AA55AA55AA55AA5555AAFFAA0055AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55555500AAFFAAFFAAFFAAFF000000FFAAFFAAFFAAFFAA00555555AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAA55AAAA0055555500AA005555AA555500AA0055555500AAAA55AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA5500AAAAFFAA555555AAFFAAFFAA555555AAFFAAAA0055AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA5555555500AAFFAA0055555500AAFFAA0055555555AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA55AAAA55555500AAAAAAAAAA00555555AAAA55AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA5500AAFFAA55555555555555AAFFAA0055AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA55555500AAFFAAAAAAFFAA00555555AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA55AAAA00555555555500AAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5500AAAAAAAAAAAAAA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA555555555555555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA55AAAAFFAAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA5500AA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 3.16915 0.39418 3.25646 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAA55FFAAFF55555500555555AAFF00AAAAAAFFFFAAFF0055AA55AA55AAAAAA55555500
AA55AA55FFFFFF55AA55AA00AA555555AA00AA55AA55FFFFFF55AA55AA00555555AAAAAA
55AA55AA5500FFAAFFFFAAAAAA00FFAA55555500555555FFAAFF55AAFF
FFFFAA550055AAFFAA55AAFFAA555555FF005555555500AAFFAAFFAAFFAAFFFFAAAAAAFF
005500FFFFFFFFFF005500FFAAFF55FFAAFF005500FFFFFFFFFF005500FFAAAAAAFFFFAA
FFAAFFAAFFAA005555555500FF555555AAFFAA55AAFFAA550055AAFFFF
FFFFFFAA55AAFFFFFFAA55555500005500AAFFAAAAAAAA55555500AA0055555555005555
55FFAA0055AA0055AAAAAA5500FF00FF0055AAAAAA5500AA5500AAFF5555550055555555
00AA00555555AAAAAAAAFFAA00550000555555AAFFFFFFAA55AAFFFFFF
FFFFFFFFAA5555555555AAFFAA55AAAAAA555555005555AAFFAAAA5555FFAAAAAAAA55FF
AA5500FFAA5555FFFFAAFFFF00AA55AA00FFFFAAFFFF5555AAFF0055AAFF55AAAAAAAAFF
5555AAAAFFAA555500555555AAAAAA55AAFFAA5555555555AAFFFFFFFF
FFFFFFFFFFAA55FFAAAAFFFFFFAAAA00AAAAFF55FF55AAFFFFFFAAFFAA5500555500FFFF
FFAAAA5500550000FF0055AA00FF55FF00AA5500FF0000550055AAAAFFFFFF0055550055
AAFFAAFFFFFFAA55FF55FFAAAA00AAAAFFFFFFAAAAFF55AAFFFFFFFFFF
FFFFFFFFFFFFAA5500555555555500FFAAFFFFFF0000555555555500AAAAAA55FFAA0055
AA00AAAAAA55FF555555FFFFAA005500AAFFFF555555FF55AAAAAA00AA5500AAFF55AAAA
AA0055555555550000FFFFFFAAFF0055555555550055AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA55AAFFAAAAFFAA005555555555FF55AAFFAAAAFF005555000000AAFF
AAFF0055550000005500000000AAFFAA0000000055000000555500FFAAFFAA0000005555
00FFAAAAFFAA55FF555555555500AAFFAAAAFFAA55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA555555AA5500FFAAAAAAFFAA550000AA555500AAFFAA55AAAA5555
5500AAFFAAAA55AAAAAA55AAAA555555AAAA55AAAAAA55AAAAFFAA00555555AAAA55AAFF
AA005555AA000055AAFFAAAAAAFF0055AA555555AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA55FFAAFF55555500555555AAFF00AAAAAAAA555555AAFFFFAA55
FFAA00AA55550000AA00005555AAFFAA55550000AA00005555AA00AAFF55AAFFFFAA5555
55AAAAAAAA00FFAA55555500555555FFAAFF55AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA550055AAFFAA55AAFFAA555555FF005555AAFFAA5555555500
0000AAFFFF55AAAA5555FF55AAFFFFFFAA55FF5555AAAA55FFFFAA00000055555555AAFF
AA555500FF555555AAFFAA55AAFFAA550055AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55AAFFFFFFAA55555500005500AAFFAA555555AAFFAAAAFF
00AAFFFFFFFF5500FFFF000055555555550000FFFF0055FFFFFFFFAA00FFAAAAFFAA5555
55AAFFAA00550000555555AAFFFFFFAA55AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA5555555555AAFFAA55AAAAAA555555AAFFAAAA00555500
AAFFFFFFFFFFFF55555555FF55AAFFAA55FF55555555FFFFFFFFFFFFAA00555500AAAAFF
AA555555AAAAAA55AAFFAA5555555555AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAAAAFFFFFFAAAA00AAAAFFAA555555AA55AAFFAA
000000000000000055000055AAFFFFFFAA550000550000000000000000AAFFAA55AA5555
55AAFFAAAA00AAAAFFFFFFAAAAFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500555555555500FFAAFFFFFFAAAAAAFFFF0055AA
55AAAA55AAAA55AAAAAA55AAFFFFFFFFFFAA55AAAAAA55AAAA55AAAA55AA5500FFFFAAAA
AAFFFFFFAAFF0055555555550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFFAAAAFFAA0055555555550055555555FFFF
AA5555AAFFFFAAAA00AAAAFFFFFFFFFFFFFFAAAA00AAAAFFFFAA5555AAFFFF5555555500
555555555500AAFFAAAAFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555555AA5500FFAAAAAAFFAA55AAFF55FFFFFF
FFAAAAFFFFFFFFAAFF0055555555555555555500FFAAFFFFFFFFAAAAFFFFFFFF55FFAA55
AAFFAAAAAAFF0055AA555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAAFF55555500555555AAFFFFFF000000
FF0055555555555500AAFFAAAAAAFFAAAAAAFFAA0055555555555500FF000000FFFFFFAA
55555500555555FFAAFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFFAA55AAFFAA5555555555FF55
5555FFAAAAAAFFAAAA5555550055555500555555AAAAFFAAAAAAFF555555FF5555555555
AAFFAA55AAFFAA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFFFFFFAA555555000055000055AA
FFAA55005555AA00AAAAFFAA55AAFFAA55AAFFAAAA00AA55550055AAFFAA550000550000
555555AAFFFFFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555555555AAFFAA55AAAAAA55AAFF
FFFFAA55AAFFAAFF00555555AAFFFFFFAA55555500FFAAFFAA55AAFFFFFFAA55AAAAAA55
AAFFAA5555555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAAAAFFFFFFAAAA00AAAAFFFF
FFFFFFAA55555500AAFFAAAAFFFFFFFFFFAAAAFFAA00555555AAFFFFFFFFFFAAAA00AAAA
FFFFFFAAAAFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500555555555500FFAAFFFFFF
FFFFFFFFAAAAAAFF0055AA55555555555555AA5500FFAAAAAAFFFFFFFFFFFFFFAAFF0055
555555550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFFAAAAFFAA0055555555
555555555500555555FFAAFF55AAFFAA55FFAAFF5555550055555555555555555500AAFF
AAAAFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555555AA5500FFAAAAAAFF
AAAAAAFFAA55AAFFAA550055AAFFFFFFAA550055AAFFAA55AAFFAAAAAAFFAAAAAAFF0055
AA555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAAFF555555005555
5500555555AAFFFFFFAA55AAFFFFFFFFFFAA55AAFFFFFFAA5555550055555500555555FF
AAFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFFAA55AAFF
AA55AAFFAA5555555555AAFFFFFFFFFFFFFFAA5555555555AAFFAA55AAFFAA55AAFFAA55
0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFFFFFFAA5555
55AAFFFFFFAAAAFF55AAFFFFFFFFFFFFFFFFFFAA55FFAAAAFFFFFFAA555555AAFFFFFFAA
55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555555555AAFF
AA55555555550055AAFFFFFFFFFFFFFFFFFFFFFFAA55005555555555AAFFAA5555555555
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAAAAFFFF
FFAAAAAAFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFFAAAAAAFFFFFFAAAAFF55AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500555555
5555AA555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555555AA55555555550055AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFFAA
AAFFAAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAAFFAAAAFFAA55AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555555
AA5500FF005555555555555555555555555555555555555500FF0055AA555555AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF
AAFF555555FFAAAAFFAAAAFF55AAFFAA55FFAAAAFFAAAAFF555555FFAAFF55AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55
0055AAFFAA55005555550055AAFFFFFFAA55005555550055AAFFAA550055AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
55AAFFFFFFAA55AAFFAA55AAFFFFFFFFFFAA55AAFFAA55AAFFFFFFAA55AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA5555555555AAFFFFFFAA55555555555555AAFFFFFFAA5555555555AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAA55FFAAAAFFFFFFFFFFAAAAAAFFAAAAAAFFFFFFFFFFAAAAFF55AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA5500555555555555550055555500555555555555550055AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA55AAFFAAAAAAFFAA55AAFFAA55AAFFAAAAAAFFAA55AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA555555AA555555AAFFFFFFAA555555AA555555AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA55FFAAFF55AAFFFFFFFFFFAA55FFAAFF55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA550055AAFFFFFFFFFFFFFFAA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA55AAFFFFFFFFFFFFFFFFFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5555555555555555555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA55FFAAAAFFAAAAFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA55005555550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA55AAFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 3.16915 0.588183 3.25646 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAFFAA5500FFAAFF55FF0000FFFFFFFFFFAAFFAAFFAAFFFFAAAAFF0000AAFFFFFF
FFFFFF0000FFFFAAFF00FFFFFFFFAAFFFFFFFF00FFAAFFFF0000FFFFFFFFFFFFAA0000FF
AAAAFFFFAAFFAAFFAAFFFFFFFFFF0000FF55FFAAFF0055AAFFAAAAAAFF
FFFFAAFFFFFFAAAAAA0055FFFFFF00FF5555FF55555500AAFFFFFFFFAAFF00FFFFAA0000
AAAA00FFFF00AAFFFFFF00AAAA555555AAAA00FFFFFFAA00FFFF00AAAA0000AAFFFF00FF
AAFFFFFFFFAA00555555FF5555FF00FFFFFF5500AAAAAAFFFFFFAAFFFF
FFFFFFAA00AAFFFFAAFF55FF5500FFFFFF55FF55FFFF55AA00AAAA555555AAFF00AA55FF
AAFFFF0055FFAAFF0055FFAAFFFF55FFFFAAFF5500FFAAFF5500FFFFAAFF55AA00FFAA55
5555AAAA00AA55FFFF55FF55FFFFFF0055FF55FFAAFFFFAA00AAFFFFFF
FFFFFFFFAA5500555555FFFFFF55AA5555FFFFFF55550000FFFFAAFFAAAAFFFFFF000055
555500FFFF5500AAFF55FF0000AAFFAA0000FF55FFAA0055FFFF005555550000FFFFFFAA
AAFFAAFFFF00005555FFFFFF5555AA55FFFFFF5555550055AAFFFFFFFF
FFFFFFFFFFAAAAAAFFAAAA5555FFFFAAAAFF00AAFFAAAAAAAA555555AA005555FF00FFFF
55FFFF0055FFFF00000055FFAA550055AAFF55000000FFFF5500FFFF55FFFF00FF555500
AA555555AAAAAAAAFFAA00FFAAAAFFFF5555AAAAFFAAAAAAFFFFFFFFFF
FFFFFFFFFFFFAAFFFFFFAAFFAAAA55555555AAFFFFFFAAFFFFAAAAFFAAFF55FFFFFF00AA
FFAA00FFFF5555FFAA55FFFFFFAAAAAAFFFFFF55AAFF5555FFFF00AAFFAA00FFFFFF55FF
AAFFAAAAFFFFAAFFFFFFAA55555555AAAAFFAAFFFFFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA00AAFFFFFFAAFFAAAAFFAAFF00AA00555500AA555555FFFFFFFFFF00
0000FFFFFFFF55FF000055FF5555555555FF550000FF55FFFFFFFF000000FFFFFFFFFF55
5555AA00555500AA00FFAAFFAAAAFFAAFFFFFFAA00AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5500555500AAFFFFAA0055FFAAFF55FFFF000055000000AA00FF55
AAFF555500FF55FF00FFFF55000055000055FFFF00FF55FF005555FFAA55FF00AA000000
550000FFFF55FFAAFF5500AAFFFFAA0055550055AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAAFFAA5500FFAAFF55FF00000055FF55AAFFAA55FFAAFF5500
00FF55FFFF005500FFFFFFFF55AAFFAA55FFFFFFFF005500FFFF55FF000055FFAAFF55AA
FFAA55FF55000000FF55FFAAFF0055AAFFAAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFFFFAAAAAA0055FFFFFF00FFFF550000FFAAFFAA0055FFFF
00FFAAAA00FFFF55AAAA55AAAAFFFFFFAAAA55AAAA55FFFF00AAAAFF00FFFF5500AAFFAA
FF000055FFFF00FFFFFF5500AAAAAAFFFFFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00AAFFFFAAFF55FF5500FFFFFFFF55AAFF000000FFFF5500
FFFFFFAAFF5555FFFFAAFFAAFFFFFFFFFFAAFFAAFFFF5555FFAAFFFFFF0055FFFF000000
FFAA55FFFFFFFF0055FF55FFAAFFFFAA00AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA5500555555FFFFFF55AA5555AAAAFFFFFF00FFFFFFFF55
AAAA555555FFFF555500AA005555FF555500AA005555FFFF555555AAAA55FFFFFFFF00FF
FFFFAAAA5555AA55FFFFFF5555550055AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAAAA5555FFFFAAAAFFFFAA00AAAAAA0000AAFF
AAFFFF55FFFFFFFF55FFAAFF55FFFFFF55FFAAFF55FFFFFFFF55FFFFAAFFAA0000AAAAAA
00AAFFFFAAAAFFFF5555AAAAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAAFFAAAA5555555500FF00FF0000FFFF0000
00FF550000AA00AAFFAA0055FFFFFFFFFF5500AAFFAA00AA000055FF000000FFFF0000FF
00FF0055555555AAAAFFAAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFFFFFFAAFFAAAAFFAA55AAFF00FFFFFFFF00
FFFFFF55AAFFFF000000FFFF5555FF5555FFFF000000FFFFAA55FFFFFF00FFFFFFFF00FF
AA55AAFFAAAAFFAAFFFFFFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500555500AAFFFFAA005500AAAAAA5555AAAA
AA55AAAAFFFFFFFF00FFFFFFFF55FF55FFFFFFFF00FFFFFFFFAAAA55AAAAAA5555AAAAAA
005500AAFFFFAA0055550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAA5500FFAAFF55FFAAFFFFAAAAFFFF
AAFFAAFFFFFFFFFFFF00AA00FF55FF55FF00AA00FFFFFFFFFFFFAAFFAAFFFFAAAAFFFFAA
FF55FFAAFF0055AAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAAAAAA0055FFFFFFAA00FF000000
AA555555AAAA00AAFF00FF00FF55FF55FF00FF00FFAA00AAAA555555AA000000FF00AAFF
FFFF5500AAAAAAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFFFFAAFF55FF5500FF00FFAA55FF
AAFFAAAAFFFFAA5500FFFFFF0055005500FFFFFF0055AAFFFFAAAAFFAAFF55AAFF00FF00
55FF55FFAAFFFFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500555555FFFFFF55AAAAAA550000
00FFAAFFFFFFFFAAAAAA5555FFAAAAAAFF5555AAAAAAFFFFFFFFAAFF00000055AAAAAA55
FFFFFF5555550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAAAA5555FFFFAAFFFF55AA
FF555555FF555500AA5500005555555555000055AA005555FF555555FFAA55FFFFAAFFFF
5555AAAAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAAFFAAAA555555AAAAFF
FFFF55FFFFFF55FFAAFFAA55FFFF55FFFF55AAFFAAFF55FFFFFF55FFFFFFAAAA555555AA
AAFFAAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFFFFFFAAFFAAAAFFFFAA
00FFAAAA5555FFFFFFAA005500FF55FF005500AAFFFFFF5555AAAAFF00AAFFFFAAAAFFAA
FFFFFFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500555500AAFFFFAA0000
FFFFFFAAFFAAAA0000AA55FFFF005500FFFF55AA0000AAAAFFAAFFFFFF0000AAFFFFAA00
55550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAA5500FFAAFF55
AAAA55AA0000FF00FFFFAAAA55AAFFAA55AAAAFFFF00FF0000AA55AAAA55FFAAFF0055AA
FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAAAAAA0055FF
FFAAFFAAFF55AAAAAA55AA005500AA005500AA55AAAAAA55FFAAFFAAFFFF5500AAAAAAFF
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFFFFAAFF55FF
55555500AAAAFFFFAAFFAAFF55FFAAFF55FFAAFFAAFFFFAAAA00555555FF55FFAAFFFFAA
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500555555FFFF
FF55FFFF0000FF5500AAFFFFFF555555FFFFFFAA0055FF0000FFFF55FFFFFF5555550055
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAAAA55
55FFFFFFFF00FF55FFAAFF00AAAAFFAAAA00FFAAFF55FF00FFFFFFFF5555AAAAFFAAAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAAFF
AAAA555500FFFFFF555555FFAAFFFFFFAAFF555555FFFFFF005555AAAAFFAAFFFFFFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AAFFFF
FFAAFFAAAAAA00FF55FFFF55555500555555FFFF55FF00AAAAAAFFAAFFFFFFAA00AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055
5500AAFFFFAAFF550000AAAAFFAAAAAAFFAAAA000055FFAAFFFFAA0055550055AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA
FFAA5500555555FFFF00FF000000FF000000FF00FFFF5555550055AAFFAAAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
FFFFAAAAAAFFAAAA00FFFFFF00FFFFFF00FFFFFF00AAAAFFAAAAAAFFFFFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
00AAFFFFAAFF0000FFFFFFFFFF00AA00FFFFFFFFFF0000FFAAFFFFAA00AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA5500555555FFAA5555FF5555FFAAFF5555FF5555AAFF5555550055AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAAFFAAAA55000055FFFF555555FFFF55000055AAAAFFAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFFFFAAFFAA55FFFFFFFF55FFFFFFFF55AAFFAAFFFFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA00AAFFFFFFAAAA0000AAFFAA0000AAAAFFFFFFAA00AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA550055FF0000FFFF000000FFFF0000FF550055AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAAFF00FFFFFFFF00FFFFFFFF00FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFFFFF005555AAAAAA555500FFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA00AAFF55FFFFAAFFFF55FFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55005500FFAAFF00550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAAFF555555FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFFFF55FFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00AAFFAA00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 3.16915 0.782187 3.25646 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAFF55AAAAFF0000AAAAFFAAAAAA00AA5555AA00FFAAFFFFFF00005555FFFF5555
55FF00AA55005555AA55AA55AA55AA55AA55AA55AA55550055AA00FF555555FFFF555500
00FFFFFFAAFF00AA5555AA00AAAAAAFFAAAA0000FFAAAA55FFAAAAAAFF
FFFFAAFFFFFF550055AAFF5500FF005500FFFFAAAAFFFF000055AAAA55FFAAAAFF000000
0000FFFFAAAAAAFFAAFFAAFFAAFFAAFFAAFFAAFFAAFFAAAAAAFFFF0000000000FFAAAAFF
55AAAA550000FFFFAAAAFFFF005500FF0055FFAA550055FFFFFFAAFFFF
FFFFFFAA00FFAAAAAAFFFFFF55AAAAAAFF555555AA55AAAAAAAAFFFFAAAA5555AAAAAAAA
AAAAAA55AA555500AA005500AA005500AA005500AA005555AA55AAAAAAAAAAAAAA5555AA
AAFFFFAAAAAAAA55AA555555FFAAAAAA55FFFFFFAAAAAAFF00AAFFFFFF
FFFFFFFFAA5500550000FF0000005500FFAAAAFFAAFFAAFFFFAAFF00AA00000000AA0000
AA00AAAAFFFF55FFAAFF55FFAAFF55FFAAFF55FFAAFF55FFFFAAAA00AA0000AA00000000
AA00FFAAFFFFAAFFAAFFAAAAFF0055000000FF0000550055AAFFFFFFFF
FFFFFFFFFFAAAAAAFF55AAAAAAAAAAFF5555AA5500FFAAFF00AAAA55FF00FFFF00FF55AA
FFFF005500AAFFAA00AAFFAA00AAFFAA00AAFFAA00AAFFAA005500FFFFAA55FF00FFFF00
FF55AAAA00FFAAFF0055AA5555FFAAAAAAAAAA55FFAAAAAAFFFFFFFFFF
FFFFFFFFFFFFAAFFFFFF5500555500FFAAAAFFFF55AA00AAFF55000000FFFFFFFF000000
AA55AAFFAA555555AAFFFFFFAA555555AAFFFFFFAA555555AAFFAA55AA000000FFFFFFFF
00000055FFAA00AA55FFFFAAAAFF0055550055FFFFFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA00FFAAAAAAFFAA5500555555FFFFAA5555FFFF00FFFFFFFFFFFF00FF
FFAAAA0055FFFF55FF00AA55000000000055AA00FF55FFFF5500AAAAFFFF00FFFFFFFFFF
FF00FFFF5555AAFFFF5555550055AAFFAAAAAAFF00AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5500550000FF55FFAAAAFFAA0055FFFF5555FFAA00FF0000FF00FF
0000AAAAAAFF000000FFFFAAAAAAAAAAAAAAFFFF000000FFAAAAAA0000FF00FF0000FF00
AAFF5555FFFF5500AAFFAAAAFF55FF0000550055AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAAFF55AAAAFF005500AAAAAAFF00000000FF55AAAAAAAA55FF
55AAFFFFAAFF00FFFF00AA55550055005555AA00FFFF00FFAAFFFFAA55FF55AAAAAAAA55
FF00000000FFAAAAAA005500FFAAAA55FFAAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFFFF550055AAFFAA55550000FFFF00FFFFFF55000055FFFF
FF5500AAFFFFFF0000FFFFAAAAFF55FFAAAAFFFF0000FFFFFFAA0055FFFFFF55000055FF
FFFF00FFFF00005555AAFFAA550055FFFFFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00FFAAAAAAFFFFFFAAAAFF55AA00FFFFFFFFFF55AAFFAA00
FFAAAAAA0055AAAAAAAA550000AAFFAA000055AAAAAAAA5500AAAAAAFF00AAFFAA55FFFF
FFFFFF00AA55FFAAAAFFFFFFAAAAAAFF00AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA5500550000FF00005555FFFFAA55AAAA55AAAAFFFFFFAA
550000AAAAAAFFFFAAFFFF55AAFFFFFFAA55FFFFAAFFFFAAAAAA000055AAFFFFFFAAAA55
AAAA55AAFFFF55550000FF0000550055AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF55AAAAAAAAFFAA0055FFFFAAFFAAFFFFFFFFFF
AAAAAAAA0000AAFF0055AAAAFFFFFFFFFFAAAA5500FFAA0000AAAAAAAAFFFFFFFFFFAAFF
AAFFFF5500AAFFAAAAAAAA55FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF5500555500AAAAAAFF00AAAA555555555555
55005500FFFF0055AAFFAAFFFFFFFFFFFFFFAAFFAA5500FFFF00550055555555555555AA
AA00FFAAAAAA0055550055FFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFAAAAAAFFAA5555AA55AAFFFFAAAAFFAAAAFF
AAAAAAFF5555FFAAAA0055555555555555555500AAAAFF5555FFAAAAAAFFAAAAFFAAAAFF
FFAA55AA5555AAFFAAAAAAFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500550000FF55FFFFAAAA0055AA555555AA55
005555AAAAFFAA00AAAAAAFFAAAAFFAAAAFFAAAAAA00AAFFAAAA55550055AA555555AA55
00AAAAFFFF55FF0000550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF55AAAAFF0000AAAAAAFFFF55FFFFAA
AAAAFFAAFFFFFFAA555500FF0055FF5500FF005555AAFFFFFFAAFFAAAAAAFFFF55FFFFAA
AAAA0000FFAAAA55FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF550055AAFF5500FF5555FFFFFFFF
AAFFFFFFAA00FFAAFFAAAAAA55FFFFFF55AAAAAAFFAAFF00AAFFFFFFAAFFFFFFFF5555FF
0055FFAA550055FFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFAAAAAAFFFFFF55AAAAFFAA0055AA
AA00FF00AAAAAA5555FF0055FFFFFFFFFF5500FF5555AAAAAA00FF00AAAA5500AAFFAAAA
55FFFFFFAAAAAAFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500550000FF0000005500AAAAAAFF
FFAA55AAFFFFAAFFAAAA55FFFFFFFFFFFFFF55AAAAFFAAFFFFAA55AAFFFFAAAAAA005500
0000FF0000550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF55AAAAAAAAAAFF55000055
AA000000AA5500FF0055FFFFFFFFFFFFFFFFFF5500FF0055AA000000AA55000055FFAAAA
AAAAAA55FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF5500555500FFAAAAAAAA
FFFF00FFFFAAAAAA55FFFFFFFFFFFFFFFFFFFFFF55AAAAAAFFFF00FFFFAAAAAAAAFF0055
550055FFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFAAAAAAFFAA5500550000
55AAAAAA55000055FFFFFFFFFFFFFFFFFFFFFFFFFF55000055AAAAAA550000550055AAFF
AAAAAAFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500550000FF55FFAAAAAA
AAFFFFAAFFAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAFFAAFFFFAAAAAAAAFF55FF00
00550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF55AAAAFF005555
00FF0000AAFFFF555555555555555555555555555555FFFFAA0000FF00555500FFAAAA55
FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF550055AAFFAA
AAAA55FFAAFF0000000000000000000000000000000000FFAAFF55AAAAAAFFAA550055FF
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFAAAAAAFFFFFF
AAFFFF5555AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA5555FFFFAAFFFFFFAAAAAAFF
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500550000FF00
0055AAAAFFAAFFFFAAFFFFAAFFFFAAFFFFAAFFFFAAFFFFAAFFAAAA550000FF0000550055
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF55AAAA
AAAAFFFFAA0000FFAAFF00AAAA550055AAAA00FFAAFF0000AAFFFFAAAAAAAA55FFAAAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF5500
555500AAFFFF00FF0055AAFFFFAAAAAAFFFFAA5500FF00FFFFAA0055550055FFFFFFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFAAAA
AAFFAA5555FF55AAAAAAFFFFFFFFAAFFFFFFFFAAAAAA55FF5555AAFFAAAAAAFF00AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055
0000FF55FFFFFF55000055AAAA55AA55AAAA55000055FFFFFF55FF0000550055AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA
FF55AAAAFF00AAFFAA55FFFFAAFFAAFFAAFFFF55AAFFAA00FFAAAA55FFAAAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
FFFF550055AAFFFFFFAAAA55AA55AA55AA55AAAAFFFFFFAA550055FFFFFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
00FFAAAAAAFFFFFFFFFFAAFFAAFFAAFFAAFFAAFFFFFFFFFFAAAAAAFF00AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA5500550000FF0000FF0055AA550055AA5500FF0000FF0000550055AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAAFF55AAAAAAAA55FFFFAAAAAAFFFF55AAAAAAAA55FFAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFFFF55000055FFFFFFFFAAFFFFFFFF55000055FFFFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA00FFAAAAAAAAFF0000FFAAFF0000FFAAAAAAAAFF00AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA550055005555FFAA550055AAFF555500550055AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAAFF55FFFFFFAAAAAAFFFFFF55FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFFFFF555555550055555555FFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA00FFAAAAFFAAAAAAFFAAAAFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5500555555005555550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAAFFAAAAAAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFFFFAAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00FFAAFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 3.16915 0.97619 3.25646 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAA55AAFFFF5555FF55FFAAAAAAFF555500AAFFFF55AAFFFFFF55FF55AA55FF55FF
55FFFFFFFF5555AAFFAAFFAAFF555555FFAAFFAAFFAA5555FFFFFFFF55FF55FF55AA55FF
55FFFFFFAA55FFFFAA005555FFAAAAAAFF55FF5555FFFFAA55AAAAAAFF
FFFFAAFFFF5500555555550000AAAA00AA0055AAFFFFFFFF55005555000000FF55FF55FF
55FF5555FF55FFFFAA00AAFFFFFF55FFFFFFAA00AAFFFF55FF5555FF55FF55FF55FF0000
0055550055FFFFFFFFAA5500AA00AAAA0000555555550055FFFFAAFFFF
FFFFFFAA00FF00FF000055AAFF5500FFFFAA5500FFAA0000AA55FFFF55AAFF555555FFFF
FF55555555FFFFFFFFAA555500555555005555AAFFFFFFFF55555555FFFFFF555555FFAA
55FFFF55AA0000AAFF0055AAFFFF0055FFAA550000FF00FF00AAFFFFFF
FFFFFFFFAA55AAFF00FFFF550055AAFF00AAAAFF5555AAFF550000AA0055FF55FFFF5555
FF55FFFF55FF5555FF550000FFFF55FFFF000055FF5555FF55FFFF55FF5555FFFF55FF55
00AA000055FFAA5555FFAAAA00FFAA550055FFFF00FFAA55AAFFFFFFFF
FFFFFFFFFFAAAA00FFFFFFFF55AA00AAFF5500FFAAAAFFFFFF55AAFFFF0000005555FFFF
5555550055005500AAFFAA55FF555555FF55AAFFAA0055005500555555FFFF5555000000
FFFFAA55FFFFFFAAAAFF0055FFAA00AA55FFFFFFFF00AAAAFFFFFFFFFF
FFFFFFFFFFFFAAFF5555FF555555AAFFFFFF55AAAA00AA000000FF5555FFAA55FFFF5555
FFFF55FFAAAAAAFF550055FFFFFF55FFFFFF550055FFAAAAAAFF55FFFF5555FFFF55AAFF
5555FF000000AA00AAAA55FFFFFFAA555555FF5555FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA0055AAAAFFAAAA000000AA5555AAFFFF00FFFFFF55FF5500AA00FF00
00AAFFAA00AAAA0000FFFF5555FF55FF5555FFFF0000AAAA00AAFFAA0000FF00AA0055FF
55FFFFFF00FFFFAA5555AA000000AAAAFFAAAA5500AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5500FF5555AA55FFAA55555555AAAA55FF5555FFFFFF55AA55FF55
AAFFFFFFAA5555AAFF5555FFFF555555FFFF5555FFAA5555AAFFFFFFAA55FF55AA55FFFF
FF5555FF55AAAA55555555AAFF55AA5555FF0055AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAA5500AAAAFF005500005500FF55FF55FFFFFFFFFF550000AA
5555FF5555AA0055FF55FFFFFFFF55FFFFFFFF55FF5500AA5555FF5555AA000055FFFFFF
FFFF55FF55FF005500005500FFAAAA0055AAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFF55AA5555FFAAAAAAAAFF555555FFFFFFFFFFFFFF55AAFF
FF55FF55FFFFAA550055005555005500555500550055AAFFFF55FF55FFFFAA55FFFFFFFF
FFFFFF555555FFAAAAAAAAFF5555AA55FFFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA00FF005500AAFFFFAAFFFFFF55FFFFFFFFFFFFFFFFFF5500
555555000000AAAAFF55FFAAAAFF55FFAAAAFF55FFAAAA0000005555550055FFFFFFFFFF
FFFFFFFF55FFFFFFAAFFFFAA005500FF00AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55AAFFAA55550055FF5555000000AA0000AA000000AA55
FFFF55FFAA55FF0055555500FF555555FF0055555500FF55AAFF55FFFF55AA000000AA00
00AA0000005555FF55005555AAFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FF55FFFF00000055AAFF55AA55FFAAFF55AAFFFF
5555FFFFFFAAAA55FFFF55FFAA005500AAFF55FFFF55AAAAFFFFFF5555FFFFAA55FFAAFF
55AA55FFAA55000000FFFF55FF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF555555FF55AAFF55FF00AA55555500FFAAAA0000
00FF00AAFF0055FFFFFFFF5555AAFFAA5555FFFFFFFF5500FFAA00FF000000AAAAFF0055
5555AA00FF55FFAA55FF555555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AA0000FF555555FFAAFFAAAAFF5555AA55FF
AA55AAFFFFFF00000000000055AA55AA55000000000000FFFFFFAA55AAFF55AA5555FFAA
AAFFAAFF555555FF0000AA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FFFF00AA5500AAFFFFFFAAFF000055FFFF
FFAAAA0000AAFF55AAFF55AAFFAAFFAAFFAA55FFAA55FFAA0000AAAAFFFFFF550000FFAA
FFFFFFAA0055AA00FFFF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55AAFFFF55AA55AAAA5555FFAA550055
5500FF55AAFFFFFF550055AA55AA55AA55AA550055FFFFFFAA55FF0055550055AAFF5555
AAAA55AA55FFFFAA55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF5500555555AA00AAAAFFAA00AA55FF
FF55AAAAFFFFFFFFFF55AA00AA555555AA00AA55FFFFFFFFFFAAAA55FFFF55AA00AAFFAA
AA00AA5555550055FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF00FF000055FFAAFFFFFFAA555555
FF55FF005555FF5555FFFFAA5555555555AAFFFF5555FF555500FF55FF555555AAFFFFFF
AAFF550000FF00FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFF00FFFF5555AAAA55AA550000
555555FFAAAAFF00005555FF0000550000FF55550000FFAAAAFF555555000055AA55AAAA
5555FFFF00FFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FFFFFFFF55FF005500FF00FF
FF55FFFFFFAAFF00FFFF55FF55AAFFAA55FF55FFFF00FFAAFFFFFF55FFFF00FF005500FF
55FFFFFFFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5555FF555555FFAAAAAA55FF
555555FF5555AAAAAA55AA000055FF550000AA55AAAAAA5555FF555555FF55AAAAAAFF55
5555FF5555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AAAAFFAAAA5555AA5500
55AA0055555555AA555555AAFF55FF55FFAA555555AA5555555500AA550055AA5555AAAA
FFAAAA5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FF5555AA5500AAAAFF
55FF00FF00005500FF000055FF55FF55FF550000FF00550000FF00FF55FFAAAA0055AA55
55FF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA5500AAAAFF5500FF
AAAA55FF55AAFFAA55AAFF55FF55FF55FF55FFAA55AAFFAA55FF55AAAAFF0055FFAAAA00
55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55AA5555FFFF00
AAAA00555555AAAA0055FF55FF55FF55FF55FF5500AAAA55555500AAAA00FFFF5555AA55
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FF00550000AAFF
5500FFFF55FFFFAAFF55FF55FF55FF55FF55FF55FFAAFFFF55FFFF0055FFAA00005500FF
00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFFAA55FF00
AA55FF5555550055FF55FF55FF55FF55FF55FF55FF5500555555FF55AA00FF55AAFFAA55
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FF55FF55
AA5500550000FFFF5555550000AA55AA0000555555FFFF0000550055AA55FF55FF00AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF555555FF
FFAAAAAAFF55AAAA5500AA55FFAAFFAAFF55AA0055AAAA55FFAAAAAAFFFF555555FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA0055AA00
00AAAA00AAFFAAFFFF55AA550055FF550055AA55FFFFAAFFAA00AAAA0000AA5500AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FF
FF0055FFAAFF00555500AAAAFF55FF55FFAAAA00555500FFAAFF5500FFFF0055AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA
55AAFFAA00AAFF55FFFF0055FF55FF55FF5500FFFF55FFAA00AAFFAA55AAAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
FF550055FFAAFF0000AAFF55FF55FF55FF55FFAA0000FFAAFF550055FFFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
00FF00FF00AAAA55FFAAFF0000AA55AA0000FFAAFF55AAAA00FF00FF00AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55AAFF00FF5500AAFFFFFF00FF55FF00FFFFFFAA0055FF00FFAA55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAA00FFFFFF55AA55AAAA55FF55FF55AAAA55AA55FFFFFF00AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFF55550055AA5500FF55FF55FF55FF0055AA55005555FFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA0055AAFFAAFFAA55AA00FF00AA55AAFFAAFFAA5500AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA5500FFAAFF005500FFFFFF005500FFAAFF0055AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAA5555FFAAAAAA55AAAAAAFF5555AAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFFF55FF5500FF55FF0055FF55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA00FF00AA55FF55FF55AA00FF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55AAFFFF555555FFFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA00000055000000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF55AAFFAA55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA0055FF5500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 3.26519 0.200176 3.3525 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAA0000FF55FFFFFFFFFF0055FF0055AA55AA00AAAAAAAAAAAAAA5500005555FF55FF
005555AAAAAAAA000000FFFFFFAAFFAAFFFFFF000000AAAAAAAA555500FF55FF55550000
55AAAAAAAAAAAAAA00AA55AA5500FF5500FFFFFFFFFF55FF0000AAAAFF
FFFFAA5555AA0000FF0000FF00555555AAAAAA55FF00FFFFAAFFFFAAFF0055FF55555500
AAAAFFAAFFFF00FF5500FF0000FFFFFF0000FF0055FF00FFFFAAFFAAAA00555555FF5500
FFAAFFFFAAFFFF00FF55AAAAAA55555500FF0000FF0000AA5555AAFFFF
FFFFFFAAAAFF550000005500AAAAFFAAAAAAAAAA55000000FFFFFFFF0000555555FF5555
AAFFFFFF00000055AAAA00550000FF00005500AAAA55000000FFFFFFAA5555FF55555500
00FFFFFFFF00000055AAAAAAAAAAFFAAAA005500000055FFAAAAFFFFFF
FFFFFFFFAA550055FF005555AAFFFFFFAAFFFFAAFF0055FF0000FF000055FFFF555555FF
FF000000FF5500FFAAFF55005500FF00550055FFAAFF0055FF000000FFFF555555FFFF55
0000FF0000FF5500FFAAFFFFAAFFFFFFAA555500FF550055AAFFFFFFFF
FFFFFFFFFFAAAA0000FF55FFFF000000FFFFFFFF0000555555AA5500FF55555555005555
5555AA55555500FF00FF00AAAA555555AAAA00FF00FF00555555AA555555550055555555
FF0055AA5555550000FFFFFFFF000000FFFF55FF0000AAAAFFFFFFFFFF
FFFFFFFFFFFFAA5555AA0000FF0055FF000000000055FF55FFFFAAAA005555FF5555AAAA
FFAAAAAAFFAAAA005500AAAAAAAA55AAAAAAAA005500AAAAFFAAAAAAFFAAAA5555FF5555
00AAAAFFFF55FF550000000000FF5500FF0000AA5555AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAFF55000000555555AA5555AA55AA000000FFFF00555500AAFFAAFF
FFFFAAFFFFFFAA5555FF00FFFFAA55AAFFFF00FF5555AAFFFFFFAAFFFFFFAAFFAA005555
00FFFF000000AA55AA5555AA55555500000055FFAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA550055FF005555FFFFAAAA55FFFF00550000FF00555500FFFFFF00
0000FFFFFFFFFF00AA005500AA55FF55AA005500AA00FFFFFFFFFF000000FFFFFF005555
00FF00005500FFFF55AAAAFFFF555500FF550055AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA0000FF55FFFFFFFFAA55AA005500550000FF55550000FF0000
550000FF000000FF55AA55AA55FFFFFF55AA55AA55FF000000FF0000550000FF00005555
FF000055005500AA55AAFFFFFFFF55FF0000AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA5555AA0000FF0000FFFF55AA55AA55AA555555005500FF0055
FF55000000550000FFAAFFAAFF000000FFAAFFAAFF00005500000055FF5500FF00550055
5555AA55AA55AA55FFFF0000FF0000AA5555AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFF550000005500AA55AAFFAAFFAA55AAAA55550000FF55
555500FF5500550000FFFFFF0000550000FFFFFF0000550055FF00555555FF00005555AA
AA55AAFFAAFFAA55AA005500000055FFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA550055FF005555AAFF00FF00FF00FFAAFF5555FF0055AA
AA55AA550055FF55000000000055FF55000000000055FF550055AA55AAAA5500FF5555FF
AAFF00FF00FF00FFAA555500FF550055AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000FF55FFFF000055AA5500FF00FF00AA0055FFFF
AAFFAAFF0055555500FF550000555555000055FF0055555500FFAAFFAAFFFF5500AA00FF
00FF0055AA550000FFFF55FF0000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555AA0000FF0055FF55AAAA005500AAAAAA000000
FFFFFF00005555FF5500AA00AAAA55AAAA00AA0055FF55550000FFFFFF000000AAAAAA00
5500AAAA55FF5500FF0000AA5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55000000555555FFAA555500FFFF00FF5500
0000FF0055FF555555FF00FF55AAFFAA55FF00FF555555FF5500FF00000055FF00FFFF00
5555AAFF55555500000055FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055FF005555FFFFFFAAAA55555555AA00FF
5500000055555500555555AA00FFFFFF00AA5555550055555500000055FF00AA55555555
AAAAFFFFFF555500FF550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000FF55FFFFFFFFFF00FFAAAAFFAA5555
55FF0055FF55550000AAFFAA5555555555AAFFAA00005555FF5500FF555555AAFFAAAAFF
00FFFFFFFFFF55FF0000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555AA0000FF0000FF0055AAFFFFFFAAAA
FF0000555555FF5500FFFFFFAAAAFFAAAAFFFFFF0055FF5555550000FFAAAAFFFFFFAA55
00FF0000FF0000AA5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF550000005500AAAAFFFFFFFFFFAA
5500FF55FF555555FF0000FF00FFFFFF00FF0000FF555555FF55FF0055AAFFFFFFFFFFAA
AA005500000055FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055FF005555AAFFFFFFFFFFFFFF
AAAA00555555FF555555AA550000FF000055AA555555FF55555500AAAAFFFFFFFFFFFFFF
AA555500FF550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000FF55FFFF000000FF000000
FFFF0055550055AAAAFFAA55AA555555AA55AAFFAAAA5500555500FFFF000000FF000000
FFFF55FF0000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555AA0000FF0055FF00005500
FF0000555500FFAAFFFFFFAAAAAAFFAAAAAAFFFFFFAAFF0055550000FF00550000FF5500
FF0000AA5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55000000555555AA55AA
5500FF55550000FFFFFFFFFFAAFFFFFFAAFFFFFFFFFF00005555FF0055AA55AA55555500
000055FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055FF005555FFFFAAAA
AA555555FF550000FF000000FFFFFFFFFF000000FF000055FF555555AAAAAAFFFF555500
FF550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000FF55FFFFFFFFAA
FF5555FFFFFF5500000055000000000000005500000055FFFFFF5555FFAAFFFFFFFF55FF
0000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555AA0000FF0000FF
FFFF5555555555FF00550055000055000055005500FF5555555555FFFFFF0000FF0000AA
5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF550000005500
AA5500555500555555AAAA000055FF550000AAAA5555550055550055AA005500000055FF
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055FF005555
AAFF00555500FFAAAAFFFF0055FFFFFF5500FFFFAAAAFF00555500FFAA555500FF550055
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000FF55FF
FF000055550000FFFF0000005555555555000000FFFF000055550000FFFF55FF0000AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555AA0000
FF0055FFFF5500FF0000550000AAFFAA0000550000FF0055FFFF5500FF0000AA5555AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF5500
0000555555550000FF550055FF00FF00FF550055FF00005555555500000055FFAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055
FF005555FFFF5500FF00AAAA5500FF0055AAAA00FF0055FFFF555500FF550055AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00
00FF55FFFFFFFF5500AAAAAAAA555555AAAAAAAA0055FFFFFFFF55FF0000AAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55
55AA0000FF000000AAAAAAAAAAAA55AAAAAAAAAAAA000000FF0000AA5555AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAFF550000005500FFFF00FFFFAA55AAFFFF00FFFF005500000055FFAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA550055FF005555AA005500AA55FF55AA005500AA555500FF550055AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAA0000FF55FF55AA55AA55FFFFFF55AA55AA55FF55FF0000AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA5555AA0000FFAAFFAAFF000000FFAAFFAAFF0000AA5555AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAAFF550000FFFFFF0000550000FFFFFF000055FFAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA550055000000000055FF550000000000550055AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAA00FF55000055FFFFFF55000055FF00AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA555555FF00555555555500FF555555AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAFF00005555FF55550000FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5500FF55FFFFFF55FF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA00555555555500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA5555FF55FF5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA550055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 3.26519 0.39418 3.3525 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAFFFFAAFF00FFAAAA55FFFFFF55AAAAAAAAAAFFAA5555AAFF00FF5500AA000000
FF55AAAA00000055005555AA00AAAAAA00AA55550055000000AAAA55FF000000AA0055FF
00FFAA5555AAFFAAAAAAAAAA55FFFFFF55AAAAFF00FFAAFFFFAAAAAAFF
FFFFAA55FF005555AAAA0000AA5555AA55000055005555AAFFAAAAAA00FF55FF55AAAA55
AA55005555FF555555FFFF55AAAAAAAAAA55FFFF555555FF55550055AA55AAAA55FF55FF
00AAAAAAFFAA55550055000055AA5555AA0000AAAA555500FF55AAFFFF
FFFFFFAAAA00FF0000AA00FFAAFFAAAAAAFF00AA55AA005555AAFFFFAA00AA5555550055
AAFFAA0055AA5500AA5555AA0000AA0000AA5555AA0055AA5500AAFFAA5500555555AA00
AAFFFFAA555500AA55AA00FFAAAAAAFFAAFF00AA0000FF00AAAAFFFFFF
FFFFFFFFAA55AA55AAAAAA555500FFFF00FF555500AA00FF000055FF00FFAAFFAAAAFF00
00AAAAAA550055AAAAAAFFAAFF00AA00FFAAFFAAAAAA550055AAAAAA0000FFAAAAFFAAFF
00FF550000FF00AA005555FF00FFFF005555AAAAAA55AA55AAFFFFFFFF
FFFFFFFFFFAAAAAAFFFFAAFFAAAA5555AAAA0055AAAAAA5555FF55FF00AAAAAA0000AAAA
55AAFF55AA00FF00FFFF005500FFAAFF005500FFFF00FF00AA55FFAA55AAAA0000AAAAAA
00FF55FF5555AAAAAA5500AAAA5555AAAAFFAAFFFFAAAAAAFFFFFFFFFF
FFFFFFFFFFFFAA55FF005555AAFFFF55FFAA55AA00000000FF0055AA55AAFFFF00AAFFFF
AAAAAA005555FF00AAAA00FF00AAAAAA00FF00AAAA00FF555500AAAAAAFFFFAA00FFFFAA
55AA5500FF00000000AA55AAFF55FFFFAA555500FF55AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA00FF0000AAAA0055FFAAAAAA55AAAA5555FFFFAAAAAA00AAFFFFFF
FFAAFF55555555AAAAAAAA5555FFAAFF5555AAAAAAAA55555555FFAAFFFFFFFFAA00AAAA
AAFFFF5555AAAA55AAAAAAFF5500AAAA0000FF00AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55AA55AAAAAAAA5500FFFFAAFFAAFF55FFFFFFFFAA55FF55AA5555
AA55FF0000FF000000550055AA00AA00AA550055000000FF0000FF55AA5555AA55FF55AA
FFFFFFFF55FFAAFFAAFFFF0055AAAAAAAA55AA55AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAAFFFFAAFF55FF5500FFFFFF0055AA5555AA55FFFFFF55AA00
555555AAAA5555FF555555FFFF00AA00FFFF555555FF5555AAAA55555500AA55FFFFFF55
AA5555AA5500FFFFFF0055FF55FFAAFFFFAAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA55FF005555AA00AA55AA5555AAAAFF55FFFFAAAA00AAAAFF55
555555550000FF0055AA0055FF00AA00FF5500AA5500FF00005555555555FFAAAA00AAAA
FFFF55FFAAAA5555AA55AA00AA555500FF55AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA00FF0000AAFFFF55AA00550055FFFFFFFFAAFF00FFFFFF
55FFFF55FF5555AAAAFF555555AAAAAA555555FFAAAA5555FF55FFFF55FFFFFF00FFAAFF
FFFFFF55005500AA55FFFFAA0000FF00AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55AA55AAAAAA00AA55FF55FF55FF0055FF00FF5555AA55
5555AA5500FF000000AAAAFFAAAAAAAAAAFFAAAA000000FF0055AA555555AA5555FF00FF
5500FF55FF55FF55AA00AAAAAA55AA55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFAAFF00FF0055AA5500FFAAAA00FF55FFFF00
00FF00FF00AAAA55AAAAAAAA0000AA0000AAAAAAAA55AAAA00FF00FF0000FFFF55FF00AA
AAFF0055AA5500FF00FFAAFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF005555AAAA00FF00FF00AAAAAAAA555555AA55
AAAA00FF55550055AAFFFFAA55AAAAAA55AAFFFFAA55005555FF00AAAA55AA555555AAAA
AAAA00FF00FF00AAAA555500FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FF0000AA00FF5555AAAAAAAAAAAAFFAAAAAA
FF55AAAA0055AAAAFFFFFFFFAAAAAAAAAAFFFFFFFFAAAA5500AAAA55FFAAAAAAFFAAAAAA
AAAAAA5555FF00AA0000FF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA55AAAAAA55555555000000555500FFFF00
FF55FFAAFF00005500FF5500FFFFAAFFFF0055FF00550000FFAAFF55FF00FFFF00555500
000055555555AAAAAA55AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFAAFFAAAAFFAA00FFAAAAFF0055FF
5500AAAAAA00FFAAAA555555FF005500FF555555AAAAFF00AAAAAA0055FF5500FFAAAAFF
00AAFFAAAAFFAAFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF005555AAFFFFFF00AAAAAAAA00FF00
55AAAAAAAAAA55550055AA0055FF55FF5500AA55005555AAAAAAAAAA5500FF00AAAAAAAA
00FFFFFFAA555500FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FF0000AAAA00AAFF55AAFF5555AA
AAFFFFAAFFFF0000FFAAAAAA5500FF0055AAAAAAFF0000FFFFAAFFFFAAAA5555FFAA55FF
AA00AAAA0000FF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA55AAAAAAAA55FF0000AAAAFFAA
55FF005555AA55AAAA000000AA55AA55AA000000AAAA55AA555500FF55AAFFAAAA0000FF
55AAAAAAAA55AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFAAFF55FF00AAFFFF0055
5555AAAAFFAAFFAA55FF5555FFAAAAAAFF5555FF55AAFFAAFFAAAA55555500FFFFAA00FF
55FFAAFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF005555AA00AAFF5500FFAA
AAFFAAFFFFFF00555555AA0055FFAAFF5500AA55555500FFFFFFAAFFAAAAFF0055FFAA00
AA555500FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FF0000AAFFFFFF5555AA
FFFFFF0055FF00AA5500AA00FF005500FF00AA0055AA00FF5500FFFFFFAA5555FFFFFFAA
0000FF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA55AAAAAA00AAAAFFAA
5555AA55AA00AAFF55FF55AAAA00FF00AAAA55FF55FFAA00AA55AA5555AAFFAAAA00AAAA
AA55AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFAAFF00FFFFFF
0000FFFF55AAAAAA0055FFFFAA55AA55AAFFFF5500AAAAAA55FFFF0000FFFFFF00FFAAFF
FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF005555AAAA00AA
AA55AA555555005555FFFFFFFFAAAAAAFFFFFFFF555500555555AA55AAAA00AAAA555500
FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FF0000AA00FF
FFAAAAAAFFAAAA5500AAAA00AAAAAAAAAA00AAAA0055AAAAFFAAAAAAFFFF00AA0000FF00
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA55AAAAAA55
55AAFFFF00555500AAFF55AAAAAAAAAAAAAA55FFAA00555500FFFFAA5555AAAAAA55AA55
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFAAFF
AAAAAA00AAFFAAAA55FF000055005500550000FF55AAAAFFAA00AAAAAAFFAAFFFFAAAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF005555
AAFF55AAAAAA0000AA5555FF55FF55FF55FF5555AA0000AAAAAA55FFAA555500FF55AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FF00
00AAAAFF55AAFF00AA0055AA5500FF0055AA5500AA00FFAA55FFAAAA0000FF00AAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AA55
AAAAAAAA005500FFAAFF0000AA55AA55AA0000FFAAFF005500AAAAAAAA55AA55AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA
FFFFAAFF555555FF00FF5555FFAAAAAAFF5555FF00FF555555FFAAFFFFAAAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55
FF005555AA0055AA55AA5500AAAAAAAAAA0055AA55AA5500AA555500FF55AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AA00FF0000AAFFAA550055AAAAAAAAAAAAAA550055AAFFAA0000FF00AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55AA55AAAAAA0000FFAAAAAAAAAAAAAAAAAAFF0000AAAAAA55AA55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAAFFFFAAFF00AAAAAAAAAAAAAAAAAAAAAA00FFAAFFFFAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA55FF005555AAAAAAAAAAAAAAAAAAAAAAAAAA555500FF55AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAA00FF0000AA000055005500550000AA0000FF00AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA55AA55AAAAAA55AA00FF00AA55AAAAAA55AA55AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAAFFFFAAFFAA55AA55AAFFAAFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA55FF005555AAFFAAFFAA555500FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA00FF0000AAAAAA0000FF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55AA55AAAAAAAAAA55AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAAFFFFAAFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA55FF005500FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA00FF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 3.26519 0.588183 3.3525 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAA555500AAAA550000AA0000FF555555FFAA55AA55AA005555FF55AA55555555AAAA
0000AA00550055AA55FF55AAFF005500FFAA55FF55AA55005500AA0000AAAA55555555AA
55FF555500AA55AA55AAFF555555FF0000AA000055AAAA005555AAAAFF
FFFFAA5555AAAAAAAA00FFAAFF00AA5555AA550055FFAAAAAA5555AA00AA00AAAA00AA00
000000AAFFAA00AA00AA555500AAFFAA005555AA00AA00AAFFAA00000000AA00AAAA00AA
00AA5555AAAAAAFF550055AA5555AA00FFAAFF00AAAAAAAA5555AAFFFF
FFFFFFAAAAFFFFAAFF55555500AAFFFF550055FF5500AA0000AAAA000000AAFFFFAA0000
00000000AA55FF55AAAAAA00AAFFFFFFAA00AAAAAA55FF55AA000000000000AAFFFFAA00
0000AAAA0000AA0055FF550055FFFFAA00555555FFAAFFFFAAAAFFFFFF
FFFFFFFFAA5500AA0055FFFF555500AA5555FFFFFF5555000055550000550055AA000000
000000005555AA00AA0000AAFFFFFFFFFFAA0000AA00AA555500000000000000AA550055
0000555500005555FFFFFF5555AA005555FFFF5500AA0055AAFFFFFFFF
FFFFFFFFFFAAAA55FF5500AA5555AAAAAA00AA5500AAAAFF00AAAAFF00AAAA5555000000
0000000055FFFFAA00000055555555555555000000AAFFFF55000000000000005555AAAA
00FFAAAA00FFAAAA0055AA00AAAAAA5555AA0055FF55AAAAFFFFFFFFFF
FFFFFFFFFFFFAA555555AAAAAA00AA0000AAFF550000AA005500555555FFAA5555AAAA55
AAAA55AAAA0055AAFF00AAFFAAAAFFAAAAFFAA00FFAA5500AAAA55AAAA55AAAA5555AAFF
555555005500AA000055FFAA0000AA00AAAAAA555555AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAFFAAFFFFAA00000000AA5555FF55AAAA00FF55FFFFFFAAAAFFFF00
555500FFFFAA00AA00550055AAFFFFFFAA55005500AA00AAFFFF00555500FFFFAAAAFFFF
FF55FF00AAAA55FF5555AA00000000AAFFFFAAFFAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA550055AA000055000000AAAA0055FFAA55AA00AA5500AA0000FF00
AAAA00FF0000AAFF5555AAAAFFFFFFFFFFAAAA5555FFAA0000FF00AAAA00FF0000AA0055
AA00AA55AAFF5500AAAA000000550000AA550055AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA5555000055FF5555FFAAFF0055AAFFAA55AAFFAA00000055AA
AAAAAA55000000AA5555AAFFFFFFFFFFFFFFAA5555AA00000055AAAAAAAA55000000AAFF
AA55AAFFAA5500FFAAFF5555FF5500005555AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA5555AAAA555555AA550055AAAAFFFFFF0055555500005500FF
FFAAFF5500000000AAAAFFFFFFFFFFFFFFFFFFAAAA0000000055FFAAFFFF005500005555
5500FFFFFFAAAA550055AA555555AAAA5555AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFFFFAAAAFFAAFFAA00AA0000FF000055FFFF5555FF00AA
550055AA55AAAA55AAFFFFFFFFFFFFFFFFFFFFFFAA55AAAA55AA550055AA00FF5555FFFF
550000FF0000AA00AAFFAAFFAAAAFFFFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA5500AA0000FFFFFFAA00000055AAAA55555555AA550000
AAAA555500FFFF005555555555555555555555555500FFFF005555AAAA000055AA555555
55AAAA55000000AAFFFFFF0000AA0055AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF555555555500005500FFFFAAAAFFAAAAAA00FF
AA55FF005500AA55AA5555AA5555AA5555AA5555AA55AA005500FF55AAFF00AAAAAAFFAA
AAFFFF005500005555555555FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555555AA5555AA55AAAA00FF0000AA005555005500
AA00AA55AA55AAFFAAFFAAAAAA00AA00AAAAAAFFAAFFAA55AA55AA00AA005500555500AA
0000FF00AAAA55AA5555AA555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAAFFAAAAAAFFFF00AA55AAAAAA5555AAAAFF
00FFAAFFAA555500AA0055550055005500555500AA005555AAFFAAFF00FFAAAA5555AAAA
AA55AA00FFFFAAAAAAFFAAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055AAFF55AA00550055FFAAFF55FFFFAA55
0000FFFFFFAAAAFF00FFAAAAFF005500FFAAAAFF00FFAAAAFFFFFF000055AAFFFF55FFAA
FF55005500AA55FFAA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA555500AAAAAA5555FF0000AA5555555500
FFAA0055AA0000AA55AA0000AA55AA55AA0000AA55AA0000AA5500AAFF0055555555AA00
00FF5555AAAAAA005555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555AAAAAAAAAA00AA55AAAAAA00AAAAFF
0000AAFFAA55AAAAAA00000000AAAAAA00000000AAAAAA55AAFFAA0000FFAAAA00AAAAAA
55AA00AAAAAAAAAA5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFFAAFF55AAAAAA0000AA00FFFF00
00550055AAFFAAFF55AAAA55AAAAAAAAAA55AAAA55FFAAFFAA5500550000FFFF00AA0000
AAAAAA55FFAAFFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AA0055FFAAFF5555FFAA0055AA
AA5555FF00FF00FF00555500FFFF00FFFF00555500FF00FF00FF5555AAAA5500AAFF5555
FFAAFF5500AA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF5500AA0055FFFFFF00AAAA
AAAA00AA55AA00FF00AAAA00FF000000FF00AAAA00FF00AA55AA00AAAAAAAA00FFFFFF55
00AA0055FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555555AAAAAA5555555555FFAA
FF55AAAAAA000000FFAAFF555555FF555555FFAAFF000000AAAAAA55FFAAFF5555555555
AAAAAA555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAAFFFFAAAA00AAAA0055
5555AAFF55AAAA55AA0000FF55FFFFFF55FF0000AA55AAAA55FFAA55555500AAAA00AAAA
FFFFAAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055AA0000AAFFFFAA00
AAAAFFFFFF55AAFFAAFF00AA5555555555AA00FFAAFFAA55FFFFFFAAAA00AAFFFFAA0000
AA550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA555500005555555500
00AA0055AA00AA00555555FFAAAA00AAAAFF55555500AA00AA5500AA0000555555550000
5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555AAAA5555AA5555
FF55AAAA00005555FFFF5500AA000000AA0055FFFF55550000AAAA55FF5555AA5555AAAA
5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFFAAAAFF5500
FF005555000055FFFFFFFF55550000005555FFFFFFFF550000555500FF0055FFAAAAFFFF
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AA0000FF55
5555FFFF5555FFFFFFFFFFFF5500000055FFFFFFFFFFFF5555FFFF555555FF0000AA0055
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF555555
AA55555555AA5500AA5500AA5555FF5555AA0055AA0055AA55555555AA555555FF55AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555555AA55
5500FF55FFFF00550055FF55AA555555AA55FF55005500FFFF55FF005555AA555555AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAAFF
AAAA5500FF000055FF5500AAAAAAFFAAAAAA0055FF550000FF0055AAAAFFAAFFAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550055
AAFF550000FFAA00AA5555FFAAFFFFFFAAFF5555AA00AAFF000055FFAA550055AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55
5500AAAA55AA000000AAAA00555555555500AAAA000000AA55AAAA005555AAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55
55AAAAAAAA00000055005555FFFF55FFFF55550055000000AAAAAAAA5555AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAFFFFAA55FF5555FF00AAAA0055AA5500AAAA00FF5555FF55AAFFFFAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA5500AA00AA5555AA00FFFFAA00AA00AAFFFF00AA5555AA00AA0055AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAA55FF55AA55550000FF00FFAAFF00FF00005555AA55FF55AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA555555AAFFAAAA55AA00FF00FF00AA55AAAAFFAA555555AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAAFFAA55005555AAFF000000FFAA55550055AAFFAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA550055FF55FFFF0000000000FFFF55FF550055AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAA555555AA00550000005500AA555555AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA5555AA55FF5500000055FF55AA5555AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAFF5500AAAA55AAAA0055FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5500FFAAFF55FFAAFF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA550055AA550055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA5555FF00FF5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA005500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 3.26519 0.782187 3.3525 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAA55FFFF00AAFFAAFFAAFFAA00555555FF0055FFFFFF55AA55FFFF555555FF555555FF
FFFFFFFF55AA55FF55555500AAFFAAFFAA00555555FF55AA55FFFFFFFFFF555555FF5555
55FFFF55AA55FFFFFF5500FF55555500AAFFAAFFAAFFAA00FFFF55AAFF
FFFFAA55AAAA0055555500AA0055FFAAAAFF0055005555FFAAFF5555FFFF55FF55FFFF55
55FF5555FFFFAAAA55FFAAAA0055555500AAAAFF55AAAAFFFF5555FF5555FFFF55FF55FF
FF5555FFAAFF5555005500FFAAAAFF5500AA0055555500AAAA55AAFFFF
FFFFFFAA5500AAAAFF55AA5500FFFFFFAAFF005500FFFF555555FFFF5555FFFFFF5555FF
AAAA55FFFFFFFFAAFF55555555AAFFAA55555555FFAAFFFFFFFF55AAAAFF5555FFFFFF55
55FFFF555555FFFF005500FFAAFFFFFF0055AA55FFAAAA0055AAFFFFFF
FFFFFFFFAA55555555FFFFAA5555FF555555FF00FF5555FFFF55AAAA55FFFFFFFFFF00FF
AAFFFF5555FF555555FFAAAAAAFFFFFFAAAAAAFF555555FF5555FFFFAAFF00FFFFFFFFFF
55AAAA55FFFF5555FF00FF555555FF5555AAFFFF55555555AAFFFFFFFF
FFFFFFFFFFAA55FFFF00AAFFFF55AAAAFF55AAAA00FFFF5555FFAAFFFF00AAFF00AA00AA
FFFFFFFF55AAAAAAFF5555555555FF5555555555FFAAAAAA55FFFFFFFFAA00AA00FFAA00
FFFFAAFF5555FFFF00AAAA55FFAAAA55FFFFAA00FFFF55AAFFFFFFFFFF
FFFFFFFFFFFFAA55AAAA005555FFAAFFFFFF0000FF5555FFFF555555FF5500AA00AA5555
55005555FFFFAAFFFFFF55FFFF55FF55FFFF55FFFFFFAAFFFF555500555555AA00AA0055
FF555555FFFF5555FF0000FFFFFFAAFF555500AAAA55AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA5500AAAAFF555555005555AA55AAFF5555FFAA55FF55FF000000FFFF
55AA55FFAA00FF00AA00005555FFFFFF55550000AA00FF00AAFF55AA55FFFF000000FF55
FF55AAFF5555FFAA55AA555500555555FFAAAA0055AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55555555FFFF55AA55FFAAFFAAFF00FFFFFFAAAA55FF5500FF5555
FFAAFF555555AAAA0055FF00FFFFFFFFFF00FF5500AAAA555555FFAAFF5555FF0055FF55
AAAAFFFFFF00FFAAFFAAFF55AA55FFFF55555555AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA55FFFF00AAFFAAFFAA00555555FF00AAFF0000FFFFFF55005500
00AA55AAFFAA5500AAAAFF005555FF555500FFAAAA0055AAFFAA55AA0000550055FFFFFF
0000FFAA00FF55555500AAFFAAFFAA00FFFF55AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA55AAAA0055555500AAAAFFAAAA55555500FF5555FF55AA55FF
0055AAFFFFFFAA55555555FF00FFFFFF00FF55555555AAFFFFFFAA5500FF55AA55FF5555
FF00555555AAAAFFAAAA0055555500AAAA55AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA5500AAAAFF55AA5500AA0055AAFFAA5555FFAA55AAFFFF55
55AAFFFFFFFFFFAAAAFFAAAA5555FF5555AAAAFFAAAAFFFFFFFFFFAA5555FFFFAA55AAFF
5555AAFFAA5500AA0055AA55FFAAAA0055AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55555555FFFFAA555555AAFFFFFFAAAAFF000055AAAA55
FFAAFF00AA00FFAAFFFFFFAAFF55FF55FFAAFFFFFFAAFF00AA00FFAAFF55AAAA550000FF
AAAAFFFFFFAA555555AAFFFF55555555AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFF00AAFFFF55AAFFFFFFFFFFAAFF0055FFFFAAFF
55555500FF00555555FF555555FFFFFF555555FF55555500FF00555555FFAAFFFF5500FF
AAFFFFFFFFFFAA55FFFFAA00FFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAA005555FFAAFF00AA00FFAAFF005500555555
FFAAAAAA00FF55FFAAAA55FFAAAA55AAAAFF55AAAAFF55FF00AAAAAAFF555555005500FF
AAFF00AA00FFAAFF555500AAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AAAAFF55555500FF00555555FF00FF55AAFF
5555555555AAAAFF0000FFFFFFAAFFAAFFFFFF0000FFAAAA5555555555FFAA55FF00FF55
555500FF00555555FFAAAA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55555555FFFF55AA55AA55FFAAAA55550000FF
AA55FFFF00FF0000AAAA0000AAFFFFFFAA0000AAAA0000FF00FFFF55AAFF00005555AAAA
FF55AA55AA55FFFF55555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFF00AAFFAAFFAAFFAA0055AAFF5500FF
AAFF5555FF00AAAA0055AA555555FF555555AA5500AAAA00FF5555FFAAFF0055FFAA5500
AAFFAAFFAAFFAA00FFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAA0055555500AA0055FFAAFF00FF55
5555FFFF5555AA0055FFAAFF55FFFFFF55FFAAFF5500AA5555FFFF555555FF00FFAAFF55
00AA0055555500AAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AAAAFF55AA5500FFFFFFAA00AAFF
55FFAA00FFFF000000555555FFFFFFFFFF555555000000FFFF00AAFF55FFAA00AAFFFFFF
0055AA55FFAAAA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55555555FFFFAA5555FF555555AA00
00555555AAAA5555AA55FFFF5555005555FFFF55AA5555AAAA5555550000AA555555FF55
55AAFFFF55555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFF00AAFFFF55AAAAFF55AA00
AAAAAAAAFFFFAAAAFFFF00AAFF55AA55FFAA00FFFFAAAAFFFFAAAAAAAA00AA55FFAAAA55
FFFFAA00FFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAA005555FFAAFFFFFF0000
00FF0000FFAA0055AAAA555555FFAAFF555555AAAA5500AAFF0000FF000000FFFFFFAAFF
555500AAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AAAAFF555555005555AA
555500FF555555AAFFFFAAAAFF555555FFAAAAFFFFAA555555FF005555AA555500555555
FFAAAA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55555555FFFF55AA55FFAA
FFAAAA0000550000FFAA0055AAAAAAAAAA5500AAFF0000550000AAAAFFAAFF55AA55FFFF
55555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFF00AAFFAAFFAA00
55555555AA55FF00555555AAFFFFAAFFFFAA55555500FF55AA5555555500AAFFAAFFAA00
FFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAA0055555500AA
AAFFAAAAFFFF5555AAFF55AA00FFAAFF00AA55FFAA5555FFFFAAAAFFAAAA0055555500AA
AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AAAAFF55AA55
00AA0055AAAA55FFAAFF00FF0055555500FF00FFAAFF55AAAA5500AA0055AA55FFAAAA00
55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55555555FFFFAA
555555AAFFFFAA55AA00FF5555AAFFAA5555FF00AA55AAFFFFAA555555AAFFFF55555555
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFF00AAFF
FF55AAFFFFFFFFAA5500FFAAAAFFFFFFAAAAFF0055AAFFFFFFFFAA55FFFFAA00FFFF55AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAAA0055
55FFAAFF00AA00FF00FF55555555FF55555555FF00FF00AA00FFAAFF555500AAAA55AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500AAAA
FF55555500FF005555AAAAAAFFAA55AAFFAAAAAA555500FF00555555FFAAAA0055AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555555
55FFFF55AA55AA55FFAAFFFFAA005500AAFFFFAAFF55AA55AA55FFFF55555555AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF
FF00AAFFAAFFAAFFAA00555500AAAAAA00555500AAFFAAFFAAFFAA00FFFF55AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55
AAAA0055555500AA0055FFAA5555555555AAFF5500AA0055555500AAAA55AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
5500AAAAFF55AA5500FFFFFFAAAAAAAAAAFFFFFF0055AA55FFAAAA0055AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55555555FFFFAA5555FF55555555555555FF5555AAFFFF55555555AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAA55FFFF00AAFFFF55AAAAFFAAAAAAFFAAAA55FFFFAA00FFFF55AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA55AAAA005555FFAAFFFFFFAAFFFFFFAAFF555500AAAA55AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA5500AAAAFF555555FF555555FF555555FFAAAA0055AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA55555555FFFF55AAAAFFAAAA55FFFF55555555AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA55FFFF00AAFFAAFFFFFFAAFFAA00FFFF55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA55AAAA005555550055555500AAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA5500AAAAFF55AA55FFAAAA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA55555555FFAAFF55555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA55FFFF555555FFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA55AAAAFFAAAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA5500AA0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 3.26519 0.97619 3.3525 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAA55FF0055FFFFFFFF55AAAAAA00AAAA00AA5555AA55FF5500AAFF00FF00FFFFFFFF00
FF00005555AA5555FFFF555555555555555555FFFF5555AA55550000FF00FFFFFFFF00FF
00FFAA0055FF55AA5555AA00AAAA00AAAAAA55FFFFFFFF5500FF55AAFF
FFFFAA5500FFFFFFFFFFFF5555FF55000055FF55AAFF00FF00FF555555AA00AA5500AA55
5500FF55AAFF00FFFFFFFF55FFAAAAAAFF55FFFFFFFF00FFAA55FF005555AA0055AA00AA
555555FF00FF00FFAA55FF55000055FF5555FFFFFFFFFFFF0055AAFFFF
FFFFFFAA555500AA0000AA55FFFFFF5500FFFFFF00AA555500FF00FFFF5555AAAAAA00FF
FF0055AAFF000000FF0000FFFFFFAAFFFFFF0000FF000000FFAA5500FFFF00AAAAAA5555
FFFF00FF005555AA00FFFFFF0055FFFFFF55AA0000AA005555AAFFFFFF
FFFFFFFFAA55FF00AAAA00FFFFFFFFFF0055555500FFAAAAAA000000FF00FFFFAAFF0055
5555AAFF0000000000AAAA0000AA55AA0000AAAA0000000000FFAA55555500FFAAFFFF00
FF000000AAAAAAFF0055555500FFFFFFFFFF00AAAA00FF55AAFFFFFFFF
FFFFFFFFFFAA5500FFAA00AA0055555555AAFFAA555555FF5555AA555555AA000055AA55
FFFF555555AA5555AA55AAAA00AAFFAA00AAAA55AA5555AA555555FFFF55AA550000AA55
5555AA5555FF555555AAFFAA5555555500AA00AAFF0055AAFFFFFFFFFF
FFFFFFFFFFFFAA555500000055FFFF55AAFFFFFFAA55FFFFFF55AAAAAAAAAA5555AAFFFF
0000FFFF55AAAAAAFFFF5555FF00AA00FF5555FFFFAAAAAA55FFFF0000FFFFAA5555AAAA
AAAAAA55FFFFFF55AAFFFFFFAA55FFFF550000005555AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAA55FF0055FFFFFFFF5555005555FFFFFFFFFF5555FF5555FFFF555500
AAAA0000FFFFAAFFFFFFFF00FF005500FF00FFFFFFFFAAFFFF0000AAAA005555FFFF5555
FF5555FFFFFFFFFF5555005555FFFFFFFF5500FF55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5500FFFFFFFFFFFF55AA55FFFFFFFFFFFFFF00FF00FFFFFFFF55AA
55AAAA00AA00550055AA000000AAAAAA000000AA55005500AA00AAAA55AA55FFFFFFFF00
FF00FFFFFFFFFFFFFF55AA55FFFFFFFFFFFF0055AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA555500AA0000AA55FF55AA0055555500AA555500FF0000AA55FF
55AAAA5555FF00FF55AAAA00AAAA55AAAA00AAAA55FF00FF5555AAAA55FF55AA0000FF00
5555AA0055555500AA55FF55AA0000AA005555AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA55FF00AAAA00FFFFFF00AAAAAAAAAA00FFFF0055AA5555FFFF
FF5555FFFF000000FFFFAA00AAFF00FFAA00AAFFFF000000FFFF5555FFFFFF5555AA5500
FFFF00AAAAAAAAAA00FFFFFF00AAAA00FF55AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA5500FFAA00AA005555AAAA55AAAA55555555AAFF00FFFFFF
FFFF00FF0000000000AA55AA55AA00AA55AA55AA0000000000FF00FFFFFFFFFF00FFAA55
555555AAAA55AAAA555500AA00AAFF0055AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA555500000055FFFF5555FFFFAAFFAAAAAAFF000000FF00
00FF0055AA5555AA5555FFFFAA55AA55AAFFFF5555AA5555AA5500FF0000FF000000FFAA
AAAAFFAAFFFF5555FFFF550000005555AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF0055FFFFFFFF55AA00005555FF555555AA555555
AA5500FFFFAAAAFF00FFFFFFFFAA55AAFFFFFFFF00FFAAAAFFFF0055AA555555AA555555
FF55550000AA55FFFFFFFF5500FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FFFFFFFFFFFF5555AA55FFFFFF00FFFFAA55FF
FFAA555500AAFF000000FF0000AAFFAA0000FF000000FFAA005555AAFFFF55AAFFFF00FF
FFFF55AA5555FFFFFFFFFFFF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555500AA0000AA55FFFFAA5500AA55555555FFFF
FFFFAA55FF00AA5555AA5500FF555555FF0055AA5555AA00FF55AAFFFFFFFF55555555AA
0055AAFFFF55AA0000AA005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF00AAAA00FFFFFFFFAA5555FFFF55FFFFFF
FFFFFFAA5500FFAAAAFFFF0055AAFFAA5500FFFFAAAAFF0055AAFFFFFFFFFFFF55FFFF55
55AAFFFFFFFF00AAAA00FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FFAA00AA00555555FFFF0000FFFFFFFF
FFFFFFFFAA55550000555555AAFFFFFFAA55555500005555AAFFFFFFFFFFFFFFFF0000FF
FF55555500AA00AAFF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555500000055FFFF55AA00000000AA0000
FF0000AA00FFFF0055FFAAAAFFFFFFFFFFAAAAFF5500FFFF00AA0000FF0000AA00000000
AA55FFFF550000005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF0055FFFFFFFF5555AA5555AAAA00
AA00AAAA55555500FFFFFFAA0000FF0000AAFFFFFF00555555AAAA00AA00AAAA5555AA55
55FFFFFFFF5500FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FFFFFFFFFFFF55AAAAAAAA55AA
55AA55AAAAAAAAAA0000AA55AA555555AA55AA0000AAAAAAAAAA55AA55AA55AAAAAAAA55
FFFFFFFFFFFF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555500AA0000AA55FF5555FF55FF
55AAAAFF00AAFF00AAAA00FFFFAAAAAAFFFF00AAAA00FFAA00FFAAAA55FF55FF5555FF55
AA0000AA005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF00AAAA00FFFFFF00FF00FF
00FFAA0000005555AAAA55555555FF55555555AAAA5555000000AAFF00FF00FF00FFFFFF
00AAAA00FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FFAA00AA005555AA00AA
00AA55AA5555AAFF5555FFFF00FFFFFF00FFFF5555FFAA5555AA55AA00AA00AA555500AA
00AAFF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555500000055FFFF5555AA
AA00FFFFAAAAFFFFFF55AA000000FF000000AA55FFFFFFAAAAFFFF00AAAA5555FFFF5500
00005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF0055FFFFFFFF55AA
AA555500AAFFFFFFFFFF5555AA555555AA5555FFFFFFFFFFAA005555AAAA55FFFFFFFF55
00FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FFFFFFFFFFFF55
55FFFF550000AA5500AA55FFFFAAAAAAFFFF55AA0055AA000055FFFF5555FFFFFFFFFFFF
0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA555500AA0000AA55
FFFFFFFF5500FFAAAA00FFFFFFFFAAFFFFFFFF00AAAAFF0055FFFFFFFF55AA0000AA0055
55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF00AAAA00FF
FFFFFFFFFF0055AAAA5555555500550055555555AAAA5500FFFFFFFFFFFF00AAAA00FF55
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FFAA00AA
005555555555AAFFFFAAAAFF55FF00FF55FFAAAAFFFFAA555555555500AA00AAFF0055AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555000000
55FFFF55AAFFAA0000AAFFFFFF000000FFFFFFAA0000AAFFAA55FFFF550000005555AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF0055
FFFFFFFF55550000000055555555AA55555555000000005555FFFFFFFF5500FF55AAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FF
FFFFFFFFFF55AA5555AA55FFFF55FF55FFFF55AA5555AA55FFFFFFFFFFFF0055AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555
00AA0000AA55FF55AAFFFF0000FFFFFF0000FFFFAA55FF55AA0000AA005555AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55
FF00AAAA00FFFFFF00AA00000000AA00000000AA00FFFFFF00AAAA00FF55AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
5500FFAA00AA0055AA55AA5555AA55AA5555AA55AA5500AA00AAFF0055AAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA555500000055FFFFAA55AAFFAAFFAAFFAA55AAFFFF550000005555AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAA55FF0055FFFFFFFFAA55AA00FF00AA55AAFFFFFFFF5500FF55AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA5500FFFFFFFFFFFFAAAA555555AAAAFFFFFFFFFFFF0055AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA555500AA0055AA00FFAAAAAAFF00AA5500AA005555AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA55FF00AAAAAA555555FF555555AAAAAA00FF55AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAA5500FFAAFFFF00FFFFFF00FFFFAAFF0055AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA55550000FF0055555500FF00005555AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAA55FF005555AAFFAA555500FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5500FFFF00AA00FFFF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA55550055FF55005555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA55FF00FF00FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAA5500FF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA555555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 3.36123 0.200176 3.44854 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAFFFFFFAAAA5500FFAAAA55FF5555FFFFFFFFFF55555555AA00FF5555FF5555FF
FF00000000FFFF550000FFAAAAFFFFFFAAAAFF000055FFFF00000000FFFF5555FF5555FF
00AA55555555FFFFFFFFFF5555FF55AAAAFF0055AAAAFFFFFFAAAAAAFF
FFFFAAFFFF00FFFFAAFFAA00AA0000FF55FFFFFFFFFFFF0000FF0000AAFF55FFFFFF55FF
005500005500FFFF5555FFAAFFFF00FFFFAAFF5555FFFF005500005500FF55FFFFFF55FF
AA0000FF0000FFFFFFFFFFFF55FF0000AA00AAFFAAFFFF00FFFFAAFFFF
FFFFFFAA55FF55AAFFFFFFAA00005500FF00FFFFFFFF0055000000550055FFFFFFFFFF55
0000FFAA005500FF55FFFFFFAA55FF55AAFFFFFF55FF005500AAFF000055FFFFFFFFFF55
00550000005500FFFFFFFF00FF00550000AAFFFFFFAA55FF55AAFFFFFF
FFFFFFFFAAAAAAFFFFFFFFFFAA00FF00AAAA5555AAFF555555FF555555FFFFFFFFFFFFFF
5555FFAAFF000055FFFFFFFFFFAAAAAAFFFFFFFFFF550000FFAAFF5555FFFFFFFFFFFFFF
555555FF555555FFAA5555AAAA00FF00AAFFFFFFFFFFAAAAAAFFFFFFFF
FFFFFFFFFFAAFFFF00FFFFFFFFAA00AAFFFFAAAAFFFFFF55FFFFFF55FFFFFFFFFFFFFFFF
FF55FFAAFF5555FFFFFFFFFFFFFFAAFFFFFFFFFFFFFF5555FFAAFF55FFFFFFFFFFFFFFFF
FF55FFFFFF55FFFFFFAAAAFFFFAA00AAFFFFFFFF00FFFFAAFFFFFFFFFF
FFFFFFFFFFFFAA55FF55AAFF5500550055FFAAFFFF0055FFFFFFFFFF5500FFFFFF00FFFF
FFFF550055FFFF5500FF5500FF550055FF0055FF0055FFFF550055FFFFFFFF00FFFFFF00
55FFFFFFFFFF5500FFFFAAFF5500550055FFAA55FF55AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAFFFFFF555555FFFFFFAA5555FFFFFFFFFFFFFF5555AA55FF55AA
5555AA00FF00FF55FF5500AAFF55FF55FFAA0055FF55FF00FF00AA5555AA55FF55AA5555
FFFFFFFFFFFFFF5555AAFFFFFF555555FFFFFFAAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF00FFFF55FFFFFFFFFFAAAAFF55AA55FF00FF55FFFFAAAA0055
55555500000055FFFFFF555500FF00FF005555FFFFFF550000005555555500AAAAFFFF55
FF00FF55AA55FFAAAAFFFFFFFFFF55FFFF00FFFFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA55FF55AAFFAA5555AA55550055FFFFAAAAAA55FFFFFFFFAAFF00
00FF0000550000FF5500FF000055FF550000FF0055FF0000550000FF0000FFAAFFFFFFFF
55AAAAAAFFFF55005555AA5555AAFFAA55FF55AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFAAAAFFFF55FF55FF0055550055AA55FF005555AA
AA55FF555555FF55AA00FF5555FFFFFF5555FF00AA55FF555555FF55AAAA555500FF55AA
5500555500FF55FF55FFFFAAAAFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFAAFF5500AAAAFF55555555FFFFAAAAAA5500AA
0000FF55FFFF5500AA00FF55FFFFFFFFFF55FF00AA0055FFFF55FF0000AA0055AAAAAAFF
FF55555555FFAAAA0055FFAAFFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFFFFFF55550055FFFF55FFFFFFFFAAFFFF5555
000055FFFFFFFF5555000000FFFF00FFFF0000005555FFFFFFFF5500005555FFFFAAFFFF
FFFF55FFFF55005555FFFFFFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFF55FF55FF00FF00FFFFFFFFAA55FFFF
5555FFFFFFFFFFFF55FF5555FF005500FF5555FF55FFFFFFFFFFFF5555FFFF55AAFFFFFF
FF00FF00FF55FF55FFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFFFFF5500AAAA55FF55AAFF550055AAFF
55FFFFFFFFFFFFFFFF55AA0055FF55FF5500AA55FFFFFFFFFFFFFFFF55FFAA550055FFAA
55FF55AAAA0055FFFFFFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFF5500AAFFFFAAAAAAFFFFFF55555500
FF00FF55AA55FFAA5555550000FF55FF0000555555AAFF55AA55FF00FF00555555FFFFFF
AAAAAAFFFFAA0055FFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFF555500FFFFAAFFFFFFFF0000FF00
AAAA55FFFFAAAA0000FF00005500FF00550000FF0000AAAAFFFF55AAAA00FF0000FFFFFF
FFAAFFFF005555FFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFF55FF55AAFFFFFF00FF5555FF00
AA0000FF55005555FF55AAAA5500000055AAAA55FF55550055FF0000AA00FF5555FF00FF
FFFFAA55FF55FFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFFAA550055FF005500FF000000
5555FF5500AAFFAAAAAAFFFFAAAA55AAAAFFFFAAAAAAFFAA0055FF5555000000FF005500
FF550055AAFFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFAAAA5500FFAAAA55FF5555
FFFF5500AAFFFFFFAAFFFFFFFFAAFFAAFFFFFFFFAAFFFFFFAA0055FFFF5555FF55AAAAFF
0055AAAAFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFAAFFAA00AA0000FF55FF
FFFFFF555500FFFFFFAA5555AAFFFFFFAA5555AAFFFFFF005555FFFFFFFF55FF0000AA00
AAFFAAFFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFFFFFFAA00005500FF00
FFFFFFFF55FF5500FFFFAAAAFFFFFFFFFFAAAAFFFF0055FF55FFFFFFFF00FF00550000AA
FFFFFFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFAA00FF00AAAA
5555AAFF55FF000055FFAAFFFFFF00FFFFFFAAFF550000FF55FFAA5555AAAA00FF00AAFF
FFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFFFFFAA00AAFFFF
AAAAFFFFFF55000055AAFFFF0055FF5500FFFFAA55000055FFFFFFAAAAFFFFAA00AAFFFF
FFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFF5500550055FF
AAFFFFFFFFFF5555FFFFAA5555FFFFFF5555AAFFFF5555FFFFFFFFFFAAFF5500550055FF
AA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFF555555FFFF
FFAA55FFAA55FFFF55AAFFFF55FF00FF55FFFFAA55FFFF55AAFF55AAFFFFFF555555FFFF
FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFF55FFFFFF
FFFFAAAA0000FFFF0000AAAA0055FF5500AAAA0000FFFF0000AAAAFFFFFFFFFF55FFFF00
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFFAA5555
AA555500550000000055005555FFFFFF555500550000000055005555AA5555AAFFAA55FF
55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFAAAA
FFFF55FF55FF5555FF55FF55FFFFFFFFFF55FF55FF5555FF55FF55FFFFAAAAFFFFFFAAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFAA
FF5500AAAAFF55FFFFFF5500AAAA00AAAA0055FFFFFF55FFAAAA0055FFAAFFFF00FFFFAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFF
FFFF55550055FFFF00FFFF55550055005555FFFF00FFFF55005555FFFFFFAA55FF55AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFF
FFFFFF55FF55FF005500FFFF55FF55FF55FFFF005500FF55FF55FFFFFFFFFFAAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00
FFFFFFFF5500AAAA5500000000FF55FF0000000055AAAA0055FFFFFFFF00FFFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF
55AAFF5500AAFFFFAAAA55AAAA555555AAAA55AAAAFFFFAA0055FFAA55FF55AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
AAFFFFFF555500FFFFAAFFAAFFFF55FFFFAAFFAAFFFF005555FFFFFFAAAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
FFFF00FFFF55FF55AAFFFFFFAA555555AAFFFFFFAA55FF55FFFF00FFFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55FF55AAFFAA550055FF00555555555500FF550055AAFFAA55FF55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAAFFFFFFAAAA5500FFAAAAFFAAAAFF0055AAAAFFFFFFAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFF00FFFFAAFFAA00AA000000AA00AAFFAAFFFF00FFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA55FF55AAFFFFFFAA0000550000AAFFFFFFAA55FF55AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAAAFFFFFFFFFFAA00FF00AAFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFFFF00FFFFFFFFAA00AAFFFFFFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA55FF55AAFF5500550055FFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAFFFFFF555555FFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF00FFFF55FFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA55FF55AAFFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 3.36123 0.39418 3.44854 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAFFFFFFAA55550000005555FF00AAAA5555FFAA00FFFF0055FFAAFFAA555500AA
00FF00FF55FFAA55AA555555AA005500AA555555AA55AAFF55FF00FF00AA005555AAFFAA
FF5500FFFF00AAFF5555AAAA00FF55550000005555AAFFFFFFAAAAAAFF
FFFFAAFFFF00FFFFAAAAFF00AAFFAAAAAA5555AA005555AAAAAAAA550055FFAAFFAAAA55
55FFAA0000FFFFAAAA0055AA00AAFFAA00AA5500AAAAFFFF0000AAFF5555AAAAFFAAFF55
0055AAAAAAAA555500AA5555AAAAAAFFAA00FFAAAAFFFF00FFFFAAFFFF
FFFFFFAA55FF55AAFFFFAA55AA55FF0055FFFF550000FF0055FF0055AAAAFF550055FF00
00FFFFAA00FFFF0055FF55FF00AAAAAA00FF55FF5500FFFF00AAFFFF0000FF550055FFAA
AA5500FF5500FF000055FFFF5500FF55AA55AAFFFFAA55FF55AAFFFFFF
FFFFFFFFAAAAAAFFFFFFFFAAAA005555FFFFFFFF5555FFAA005555FFFFAAFF55FF55FFAA
00FFFF0055005555FFFFFF55AAAA00AAAA55FFFFFF5555005500FFFF00AAFF55FF55FFAA
FFFF555500AAFF5555FFFFFFFF555500AAAAFFFFFFFFAAAAAAFFFFFFFF
FFFFFFFFFFAAFFFF00FFFFFFAAFF0000FFFF00FFFF55FFAAFF0000FFFF0055555500AA00
AAFF55AAAAFF0000FFFF00FF0055FF5500FF00FFFF0000FFAAAA55FFAA00AA0055555500
FFFF0000FFAAFF55FFFF00FFFF0000FFAAFFFFFF00FFFFAAFFFFFFFFFF
FFFFFFFFFFFFAA55FF55AAFF55005500000000555500AA00AA00FFAA55FF55FFFF5555AA
AA0000FF550055000000005555FFFFFF555500000000550055FF0000AAAA5555FFFF55FF
55AAFF00AA00AA00555500000000550055FFAA55FF55AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAFFFFFF555555FF5555FFFF5555AAAA00FFFFAAAAAAFF55AA0055
FF00AAFF55FF55FF5555FF55FFFFFFFFFF55FF5555FF55FF55FFAA00FF5500AA55FFAAAA
AAFFFF00AAAA5555FFFF5555FF555555FFFFFFAAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF00FFFF55FFFF0000FFFFFF55FF0055005555AA555500AAAA55
005500FFFF55AA0000FF00FF00FFFFFF00FF00FF0000AA55FFFF00550055AAAA005555AA
5555005500FF55FFFFFF0000FFFF55FFFF00FFFFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA55FF55AAFFAA55FF5555005555550000FFAAAAFFFF55FF5500FF
00AA55AAFF55FF00AAFF55550000AA00005555FFAA00FF55FFAA55AA00FF0055FF55FFFF
AAAAFF0000555555005555FF55AAFFAA55FF55AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFAAAAAAFFAA0055AA00FFAA5555AAFF55FFAAAA55
FF5500AAAAAAFF5555AAFFAAAA55AA55AAAAFFAA5555FFAAAAAA0055FF55AAAAFF55FFAA
5555AAFF00AA5500AAFFAAAAAAFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFAAFFFFFFAA0055FF55AA5500AAAAAAFF5500FF
00FF00AAAA00AA0055AA55FF0055AA5500FF55AA5500AA00AAAA00FF00FF0055FFAAAAAA
0055AA55FF5500AAFFFFFFAAFFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFFFFFFFFFFAA00555555AA00FF5500FFFF5555
0000AAFFFFAA00AAFFAAFFAA55AA00AA55AAFFAAFFAA00AAFFFFAA00005555FFFF0055FF
00AA55555500AAFFFFFFFFFFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFF005500AA5500FFAA5500000000FF
00AAFFFF00FF5555AAFFFF0055AA55AA5500FFFFAA5555FF00FFFFAA00FF0000000055AA
FF0055AA005500FFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFFF00FFAAAA555555FFAAFFAA00FFAA00
0055FFAA55AAFFAAAA0000AAFFAAFFAAFFAA0000AAAAFFAA55AAFF550000AAFF00AAFFAA
FF555555AAAAFF00FFFFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFF555500FF55FFFF55AA55FF00AA00AA
FF0000AAAAFFFF0055FF5555AAFFFFFFAA5555FF5500FFFFAAAA0000FFAA00AA00FF55AA
55FFFF55FF005555FFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFF55FF55AA000000FF55FFAA00AAFF
FF00AAFFFFAA55FF55FFAAAAFFFFFFFFFFAAAAFF55FF55AAFFFFAA00FFFFAA00AAFF55FF
000000AA55FF55FFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFF55AA00AAFF00AA005555AAAA00
00AAFFFFFFFFAAAAAAFF5500FFFF00FFFF0055FFAAAAAAFFFFFFFFAA0000AAAA555500AA
00FFAA00AA55FFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFFAAFF005555FF00AA5500FF55
55FF00FFFF00FF5500FFFF55550055005555FFFF0055FF00FFFF00FF5555FF0055AA00FF
555500FFAAFFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFAA55AA005555FF00005555
555500000000555555FFAA5500AAFFAA0055AAFF55555500000000555555550000FF5555
00AA55AAFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFAAAA00FF0000005500AA
5500AAFF00AAFFAAAAFF5500AAFFFFFFAA0055FFAAAAFFAA00FFAA0055AA0055000000FF
00AAAAFFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFFFFAA0000550000FFAA
FFAA00AA00FF55AA555500AAFFFFFFFFFFAA005555AA55FF00AA00AAFFAAFF0000550000
AAFFFFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFAA00FF00AAFF55
0055FF550000AA55555555FF00FFFFFF00FF55555555AA000055FF550055FFAA00FF00AA
FFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFFFAA000055FFAA
AA550055AAAA5555555555550000000000555555555555AAAA550055AAAAFF550000AAFF
FFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFF55000055AAFF
FFAAAA5500FF55FFFF55FFFF5555FF5555FFFF55FFFF55FF0055AAAAFFFFAA55000055FF
AA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFF5555FFFFAA
55FF0055AAAAAAFF55AA000000FF00FF000000AA55FFAAAAAA5500FF55AAFFFF5555FFFF
FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFF55FFAA55
55550000FF5500FFFF5500005500550055000055FFFF0055FF0000555555AAFF55FFFF00
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFFAA5555
555555FF55AA00FFFF00005500AAFFAA00550000FFFF00AA55FF5555555555AAFFAA55FF
55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFAAAA
FFAAAAFF55FF00AA00005500AAFFFFFFAA00550000AA00FF55FFAAAAFFAAAAFFFFFFAAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFAA
FF5500FFFF55AAAA00FFAAAA5555005555AAAAFF00AAAA55FFFF0055FFAAFFFF00FFFFAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFF
FFFF55550055AA5555FFAAFFFF55FF55FFFFAAFF5555AA55005555FFFFFFAA55FF55AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFF
FFFFFF55FF55FF0000FFFFAA55FFFFFF55AAFFFF0000FF55FF55FFFFFFFFFFAAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00
FFFFFF0000AA55FF55550055FFFFFFFFFF55005555FF55AA0000FFFFFF00FFFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF
55AAFF5555FF0000AA550000FFFF00FFFF000055AA0000FF5555FFAA55FF55AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
AAFFFFFF55FFAA00FF55FF55550055005555FF55FF00AAFF55FFFFFFAAAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
FFFF00FFFF55AA55AAFFAA5500AAFFAA0055AAFFAA55AA55FFFF00FFFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55FF55AAFFAAFFAAFF5500AAFFFFFFAA0055FFAAFFAAFFAA55FF55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAAFFFFFFAA555500AAFFFFFFFFFFAA005555AAFFFFFFAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFF00FFFFAAAAFF00555500555500FFAAAAFFFF00FFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA55FF55AAFFFFAA55AA005500AA55AAFFFFAA55FF55AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAAAFFFFFFFFAAAA00FF00AAAAFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFFFF00FFFFFFAAFF00FFAAFFFFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA55FF55AAFF5500550055FFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAFFFFFF555555FFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF00FFFF55FFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA55FF55AAFFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 3.36123 0.588183 3.44854 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAFFFFFFAAFFAAAAAA0055550055AA55FFFF55005555AAAAAAAAAAAA0000AA00FF
55FF5555FFFFFF5555AA55FF0055AA5500FF55AA5555FFFFFF5555FF55FF00AA0000AAAA
AAAAAAAA55550055FFFF55AA5500555500AAAAAAFFAAFFFFFFAAAAAAFF
FFFFAAFFFF00FFFFAA5500AA00FF55FF550055FFAA5555FF0055AA0000AA55000055AAAA
AAFF55FFFFFFFFFF5500AAAAAA555555AAAAAA0055FFFFFFFFFF55FFAAAAAA55000055AA
0000AA5500FF5555AAFF550055FF55FF00AA0055AAFFFF00FFFFAAFFFF
FFFFFFAA55FF55AAFFFF555555FFAAAAAA00FF55AA00AAAAAA5555000055AA55AAAA0000
AA55FF00FFFFFFFFFF5555555555AA5555555555FFFFFFFFFF00FF55AA0000AAAA55AA55
00005555AAAAAA00AA55FF00AAAAAAFF555555FFFFAA55FF55AAFFFFFF
FFFFFFFFAAAAAAFFFFFFFF55FF00FF0000FFAA5555000000AA5555AAAA555555AA005500
00FF55AAAAAAAAAAAAAA00AAAAFFAAFFAAAA00AAAAAAAAAAAAAA55FF00005500AA555555
AAAA5555AA0000005555AAFF0000FF00FF55FFFFFFFFAAAAAAFFFFFFFF
FFFFFFFFFFAAFFFF00FFFFFF55AAAAAA55AAFFFF5500005500AAAA0000AAAA00AA55AA55
AAAAAA0055555500AA550000FF00FF00FF000055AA0055555500AAAAAA55AA55AA00AAAA
0000AAAA0055000055FFFFAA55AAAAAA55FFFFFF00FFFFAAFFFFFFFFFF
FFFFFFFFFFFFAA55FF55AAFF5500AA5500FF00FFFF5555FF00AA00550000FF00AA00AA55
55005555FFFF550000AAAA55AAFF00FFAA55AAAA000055FFFF5555005555AA00AA00FF00
005500AA00FF5555FFFF00FF0055AA0055FFAA55FF55AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAFFFFFF555500FFAA55AAFF55FFFF00AA55AA55AAAAAA550000FF
55FF55FFFFFF00550000AA00AA55FF55AA00AA00005500FFFFFF55FF55FF000055AAAAAA
55AA55AA00FFFF55FFAA55AAFF005555FFFFFFAAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF00FFFF55FF55AA00AA55FFFFFF00AA00AA5555005555AAAA55
FF00FF55AAFF5555AAAA550000AAAAAA000055AAAA5555FFAA55FF00FF55AAAA55550055
55AA00AA00FFFFFF55AA00AA55FF55FFFF00FFFFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA55FF55AAFFAA55550000AAAAAAAAAA550000FF55FF55FF0000FF
55AAAAAAFFFFFF55005555AAAA550055AAAA55550055FFFFFFAAAAAA55FF0000FF55FF55
FF000055AAAAAAAAAA00005555AAFFAA55FF55AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFAAAAFF00AA0055555555AAAA55FF00FF55AAAA55
FF000000FFFFFFFF5555AA550055FF550055AA5555FFFFFFFF000000FF55AAAA55FF00FF
55AAAA5555555500AA00FFAAAAFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFAAFF555555FFFF55FF0000FF55AAAAAA0000AA
AAAA55AAAAAAAAAAAA00AA5555FFFFFF5555AA00AAAAAAAAAAAA55AAAAAA0000AAAAAA55
FF0000FF55FFFF555555FFAAFFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFFFFFF55FF00FFFF55AAAA55FF000000005500
555555AA0000AA5500550055FFFFFFFFFF5500550055AA0000AA555555005500000000FF
55AAAA55FFFF00FF55FFFFFFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFF55AAAAAAAA0000AAAAAA55AAAA5555
FFFF5500550000AAAA5555FFFFFFFFFFFFFF5555AAAA0000550055FFFF5555AAAA55AAAA
AA0000AAAAAAAA55FFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFFF0055555555000055555555AA0055FF
FFFFFF5555AAAA550055FFFFFFFFFFFFFFFFFF550055AAAA5555FFFFFFFF5500AA555555
5500005555555500FFFFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFF5555AA5555AAAA5555AA555555FFFF
FFFFFFFF5500AA5555FFFFFFFFFFFFFFFFFFFFFF5555AA0055FFFFFFFFFFFF555555AA55
55AAAA5555AA5555FFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFF5500AAAA0000AAAAFFFF55FF00FF
FFFFFFFF00550055FFFFFFFFFFFFFFFFFFFFFFFFFF55005500FFFFFFFFFF00FF55FFFFAA
AA0000AAAA0055FFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFF555500550000FF00FFFF55AAAA
AAAAAAAAAA5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555AAAAAAAAAAAAAA55FFFF00FF
000055005555FFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFFAAAA5555FF55AAAAAAAA0000
00AA0055AA00AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA00AA5500AA000000AAAAAAAA55
FF5555AAAAFFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFAAFFAAAAAA005555005500
005555FFFFAA000000AA550055550055550055AA000000AAFFFF555500005500555500AA
AAAAFFAAFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFAA5500AA00FF55FF5500
0055FFFFFF0000550000FF5555AA55AA5555FF0000550000FFFFFF55000055FF55FF00AA
0055AAFFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFFFF555555FFAAAAAA00
FFAAAAAAAAAA55AA55AAAAAA00AA00AA00AAAAAA55AA55AAAAAAAAAAFF00AAAAAAFF5555
55FFFFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFF55FF00FF0000FF
AA550055555500FF0055AA00550055005500AA5500FF005555550055AAFF0000FF00FF55
FFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFFF55AAAAAA55AA
FFFF5555AA5555FFAA00AA55AA55AA55AA55AA00AAFF5555AA5555FFFFAA55AAAAAA55FF
FFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFF5500AA5500FF
00FFFF550055FFFF00005555AA00AA00AA55550000FFFF550055FFFF00FF0055AA0055FF
AA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFF555500FFAA
55AAFF55FF55FFAA55AAAA00AA00FF00AA00AAAA55AAFF55FF55FFAA55AAFF005555FFFF
FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFF55FF55AA
00AA55FFFFFF55AA00AA000055AAAAAA550000AA00AA55FFFFFF55AA00AA55FF55FFFF00
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFFAA5555
0000AAAAAAAAAA00005555FF5500AA0055FF55550000AAAAAAAAAA00005555AAFFAA55FF
55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFAAAA
FF00AA0055555555FF55FF00FF555555FF00FF55FF5555555500AA00FFAAAAFFFFFFAAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFAA
FF555555FFFF55FF00FF55AAAAAAFFAAAAAA55FF00FF55FFFF555555FFAAFFFF00FFFFAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFF
FFFF55FF00FFFF55AAAAAA0000FF00FF0000AAAAAA55FFFF00FF55FFFFFFAA55FF55AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFF
FFFFFF55AAAAAAAA0000AA00FFAA55AAFF00AA0000AAAAAAAA55FFFFFFFFFFAAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00
FFFFFF005555555500005555FFAAFFAAFF555500005555555500FFFFFF00FFFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF
55AAFF5555AA5555AAAA5555AAFFFFFFAA5555AAAA5555AA5555FFAA55FF55AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
AAFFFFFF5500AAAA0000AAAAFFFFFFFFFFAAAA0000AAAA0055FFFFFFAAAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
FFFF00FFFF555500550000FF00FFFFFF00FF000055005555FFFF00FFFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55FF55AAFFAAAA5555FF55AAAAAAAAAA55FF5555AAAAFFAA55FF55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAAFFFFFFAAFFAAAAAA0000AA0000AAAAAAFFAAFFFFFFAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFF00FFFFAA5500AA00FFAAFF00AA0055AAFFFF00FFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA55FF55AAFFFF555555FFAAFF555555FFFFAA55FF55AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAAAFFFFFFFF55FF00FF00FF55FFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFFFF00FFFFFF55AAAAAA55FFFFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA55FF55AAFF5500AA0055FFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAFFFFFF555555FFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF00FFFF55FFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA55FF55AAFFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFFF00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 3.36123 0.782187 3.44854 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAA00FF55FFAAAAAAFF55FFFF5555FFFFAAFFAAFFFF5500AAFFFFFF0055FF0055AA55
FF00FF00FFAAFFFFFF55FFFFFFFFFFFFFFFFFF55FFFFFFAAFF00FF00FF55AA5500FF5500
FFFFFFAA0055FFFFAAFFAAFFFF5555FFFF55FFAAAAAAFF55FF00AAAAFF
FFFFAA5555FFFFFF00FFFFFF5555550000FFAA55AAFF0000AAAAAA55AAAA0000FF55FFAA
AA555555AAAAAA55AA0000FF00AA55AA00FF0000AA55AAAAAA555555AAAAFF55FF0000AA
AA55AAAAAA0000FFAA55AAFF0000555555FFFFFF00FFFFFF5555AAFFFF
FFFFFFAAAAFF00AA555555FF55FFFF5500FFAAFFAAFF0055FFAA55FFFFAA5555AAAAFF00
FFFF55FFFFAAFFFF55AA555555AAFFAA555555AA55FFFFAAFFFF55FFFF00FFAAAA5555AA
FFFF55AAFF5500FFAAFFAAFF0055FFFF55FF555555AA00FFAAAAFFFFFF
FFFFFFFFAA5500FFFF55FFFFFF55555500FFAA55AAFF005555FFAAAA55AAFFAAAAAAAA55
5555FFFFFFFF00AAFFAAFFAAAAFFFFFFAAAAFFAAFFAA00FFFFFFFF555555AAAAAAAAFFAA
55AAAAFF555500FFAA55AAFF00555555FFFFFF55FFFF0055AAFFFFFFFF
FFFFFFFFFFAAAA00FFAAAA55AAAAFFAAAA00FFFF55AAAA000000FFFFAAAAAA55FFAAFF55
FFFF55555555FF00FFAA55AAFFFFFFFFFFAA55AAFF00FF55555555FFFF55FFAAFF55AAAA
AAFFFF000000AAAA55FFFF00AAAAFFAAAA55AAAAFF00AAAAFFFFFFFFFF
FFFFFFFFFFFFAA5555FFAAFFAAFFFFFFAA555555FFFFAA5555AA55AAAAAAAAAAFF00FFAA
AA55005500555555AAAAAAFFFFFFFFFFFFFFAAAAAA55555500550055AAAAFF00FFAAAAAA
AAAA55AA5555AAFFFF555555AAFFFFFFAAFFAAFF5555AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAFF00FF00FF0000FFFF55FFFFFFFFAAAAFFFF55AAFFFFAA55AA55AA
FFFF550055FFFF55FFAA55FF5555FF5555FF55AAFF55FFFF550055FFFFAA55AA55AAFFFF
AA55FFFFAAAAFFFFFFFF55FFFF0000FF00FF00FFAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5500FF0055AA555555FFFFFFFFFFFFAA55AAAAFFFFFFFFAAAAAAFF
FFFFFF550000FFAAAA55FFFFFF55FF55FFFFFF55AAAAFF000055FFFFFFFFAAAAAAFFFFFF
FFAAAA55AAFFFFFFFFFFFF555555AA5500FF0055AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA00FF55FFAAAAFFAA00FF0000FFAAFFAAFFFFFFFFFFFF00FFFF
FFFFFFFF5500FFAAFFFF555555FFFFFF555555FFFFAAFF0055FFFFFFFFFFFF00FFFFFFFF
FFFFAAFFAAFF0000FF00AAFFAAAAFF55FF00AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA5555FFFFFF00FF00FF5555AA55AAFF00FF00AA55AAAA555555
555555555500FFAA55AA000000AA55AA000000AA55AAFF005555555555555555AAAA55AA
00FF00FFAA55AA5555FF00FF00FFFFFF5555AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFF00AA555555AAAAFFAAFFAA55AA55AA55FFFFAAFFAAAA
FFAAAAFFAAAA00FFFF55AA5555AAFFAA5555AA55FFFF00AAAAFFAAAAFFAAAAFFAAFFFF55
AA55AA55AAFFAAFFAAAA555555AA00FFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA5500FFFF55FFFF00FF00FFAAFFAAFFAAFFAA00FFFFFF00
FFAAFFFFFFAA555555FFFFAAAAFFFFFFAAAAFFFF555555AAFFFFFFAAFF00FFFFFF00AAFF
AAFFAAFFAAFF00FF00FFFF55FFFF0055AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FFAAAA55AA55AA55AAFF00FF00FFAA5555555555
AAAAAA55AAAAAAFFAAAA55AAFF555555FFAA55AAAAFFAAAAAA55AAAAAA5555555555AAFF
00FF00FFAA55AA55AA55AAAAFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555FFAAFFAAFFAAFFAA55AA55AA55AAFFAAAAFFAA
AAAAAAAAFFFFAAFF00FFFF55AAAAFFAAAA55FFFF00FFAAFFFFAAAAAAAAAAFFAAAAFFAA55
AA55AA55AAFFAAFFAAFFAAFF5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00FF00FF00FFAAFFAAFFAAFFAAFF00FFFFFF
AAFFFFAA55AAAAAA555555FFFF00FF00FFFF555555AAAAAA55AAFFFFAAFFFFFF00FFAAFF
AAFFAAFFAAFF00FF00FF00FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FF0055AA55AAFF00FF00FFAA55AA5500AA
FFFFFFFFAAAAAAAAAAFFAAAA55AA55AA55AAAAFFAAAAAAAAAAFFFFFFFFAA0055AA55AAFF
00FF00FFAA55AA5500FF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FF55FFAAAAAA555555AAAAAAFF55FF00
FFAA00FFAAFFFFAAFFFFFFAAFFAAFFAAFFAAFFFFFFAAFFFFAAFF00AAFF00FF55FFAAAAAA
555555AAAAAAFF55FF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555FFFFFF00FFFF55FFFFAAFFFFFF5555
AAAAAA00FFFFFFFFAA00FF00FFAA55AAFF00FF00AAFFFFFFFF00AAAAAA5555FFFFFFAAFF
FF55FFFF00FFFFFF5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00AA555555FFFFFFFFAA00FFAAAA
FFFF00FF555555FF55AA55AA55AAFFAA55AA55AA55FF555555FF00FFFFAAAAFF00AAFFFF
FFFF555555AA00FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FFFF55FFFFFFFFFFFF0055AAFF
5555FF0000005555FFFFAAAAAAFFFFFFAAAAAAFFFF5555000000FF5555FFAA5500FFFFFF
FFFFFF55FFFF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FFAAAA55AAAA5500AAAAFFFF
FF55FF5500FF55FFFFFFFFAAFFFFFFFFFFAAFFFFFFFF55FF0055FF55FFFFFFAAAA0055AA
AA55AAAAFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555FFAAFFAAFF55FF00FFFFFF
FFFF555500FFAAAA55AA00FFFFFFFFFFFFFF00AA55AAAAFF005555FFFFFFFFFF00FF55FF
AAFFAAFF5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00FF00FFAAAA55555555
FF55550055FF55AAFFAA555555555555555555AAFFAA55FF55005555FF55555555AAAAFF
00FF00FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FF0055AAFFFF55FFFF
55550055FFFFFF55AAAAAAFFAAAAFFAAAAFFAAAAAA55FFFFFF55005555FFFF55FFFFAA55
00FF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FF55FFAA00555555
550055FFFFFFFFFF55AAFFFFFFAA55AAFFFFFFAA55FFFFFFFFFF55005555555500AAFF55
FF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555FFFFFF00550000
0055FFFFFFFFFFFFFF55AAAA55AAFFAA55AAAA55FFFFFFFFFFFFFF550000005500FFFFFF
5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00AA555500FF
550055AAAA55AA00FFAAAAAAAAFFFFFFAAAAAAAAFF00AA55AAAA550055FF005555AA00FF
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FFFF55FF00
00AAAAFFFFAAAAAA00FFFFAAFFFFFFFFFFAAFFFF00AAAAAAFFFFAAAA0000FF55FFFF0055
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FFAAAA55
55AAFFFFFFFFAA55FF0000FFFFFFFFFFFFFF0000FF55AAFFFFFFFFAA5555AAAAFF00AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5555FFAAFF
AAAAAA55AA00FFFF5555AA55AAAA55AAAA55AA5555FFFF00AA55AAAAAAFFAAFF5555AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00FF
00FFFFAAAAAA00FFAAAAFF55FFAAFFAAFF55FFAAAAFF00AAAAAAFFFF00FF00FFAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500FF
0055AAAAAAAAAA00FFFF00AA00FFFFFF00AA00FFFF00AAAAAAAAAA5500FF0055AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00
FF55FFAAFFFF00FF5555FF00FF555555FF00FF5555FF00FFFFAAFF55FF00AAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55
55FFFFFFAA00FF55550055AA5500000055AA55005555FF00AAFFFFFF5555AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAFF00AA55FF00000055FFFFAAAA00AAAAFFFF55000000FF55AA00FFAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA5500FFFF5555AA555500AAFF55AA55FFAA005555AA5555FFFF0055AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAA00FFAAAAFFFF55FF00FFAAAAAAFF00FF55FFFFAAAAFF00AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA5555FFAAFF0000AA5555FFAAFF5555AA0000FFAAFF5555AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAAFF00FF0055FFAAAAFF00FFAAAAFF5500FF00FFAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA5500FF005555FFAA55AA55AAFF555500FF0055AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAA00FF55FFFFFFAAAAAAFFFFFF55FF00AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA5555FFFFFFFFFF00FFFFFFFFFF5555AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAFF00AA55AA00AA55AA00FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5500FFFF55AA55FFFF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA00FFAAAAAAFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA5555FFAAFF5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFF00FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 3.36123 0.97619 3.44854 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAA00550000FF55FF55FF0000000000550000AAFF5500AAFFFFAAAAFFFF5555FF55FF
55FFFFFF0000FF0000000055AAFF00FFAA5500000000FF0000FFFFFF55FF55FF5555FFFF
AAAAFFFFAA0055FFAA0000550000000000FF55FF55FF00005500AAAAFF
FFFFAA55005500AAFFAA000000FF0055AA000055FFAA0000FFFFFFFF00FFAA0000AAFFAA
0000000000FF00AAAA0055FFFFAA00AAFFFF5500AAAA00FF0000000000AAFFAA0000AAFF
00FFFFFFFF0000AAFF550000AA5500FF000000AAFFAA00550055AAFFFF
FFFFFFAAAA0000FFFFFF0000FF00AAAAFF550000AAFF55000000000000FFAA5555AAFF00
FF5500FF000000FFFF0000AAFF00FF00FFAA0000FFFF000000FF0055FF00FFAA5555AAFF
00000000000055FFAA000055FFAAAA00FF0000FFFFFF0000AAAAFFFFFF
FFFFFFFFAA550000000000FF5555AAFF555500AA55FF55FF0000FF0055AAAAAAFFAAFF00
0000AAAA555555AAAA5555AAFF000000FFAA5555AAAA555555AAAA000000FFAAFFAAAAAA
5500FF0000FF55FF55AA005555FFAA5555FF000000000055AAFFFFFFFF
FFFFFFFFFFAAAA00550000FFAAAAFF55550055AAFFAA000000FF00AAAAFFFFAA55AAFF00
00FF55AAFFAAAAFFFFAAAAFF5555555555FFAAAAFFFFAAAAFFAA55FF0000FFAA55AAFFFF
AAAA00FF000000AAFFAA55005555FFAAAAFF00005500AAAAFFFFFFFFFF
FFFFFFFFFFFFAA55005500AAFFFFAA0000AAAAFFFFFF0000FF5555AAFFFFFFFFAAAAAA55
00AAFFAAFF00FFFFFFFF00FFAAAAFFAAAAFF00FFFFFFFF00FFAAFFAA0055AAAAAAFFFFFF
FFAA5555FF0000FFFFFFAAAA0000AAFFFFAA00550055AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA0000FFFFFFFF0000FFFF00AAFF0000FFAAAAFFFFFFFFFFFFAAFF55
FF00FFAAFF000000000000FFAAFFFFFFAAFF000000000000FFAAFF00FF55FFAAFFFFFFFF
FFFFAAAAFF0000FFAA00FFFF0000FFFFFFFF0000AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5500000000000055FF5555AAFF0000FFAAFFFFFFFFFFFFFFFFAA00
0000FFAAFF005500005500AAFFFFFFFFFFAA005500005500FFAAFF000000AAFFFFFFFFFF
FFFFFFAAFF0000FFAA5555FF5500000000000055AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA00550000FF55FF55FFFF00AAAA00FFFFFFFFFFFFFFFFFFFF00
5500FFAAFF0000AAAA0000FFFFFFFFFFFFFF0000AAAA0000FFAAFF005500FFFFFFFFFFFF
FFFFFFFF00AAAA00FFFF55FF55FF00005500AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA55005500AAFFAA00000000FFFF000000000000000000000000
5555AAAAAA5555AAFF5500000000000000000055FFAA5555AAAAAA555500000000000000
0000000000FFFF00000000AAFFAA00550055AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA0000FFFFFF0000FF00000000FF550000FF0000FF0000FF
55FFFFAAFFFF55FFAA0000FF0000550000FF0000AAFF55FFFFAAFFFF55FF0000FF0000FF
000055FF00000000FF0000FFFFFF0000AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA550000000000FF5555AA55000000AAAA00FF000000FF00
AA00FFAA55AAAAFF00FF000000550055000000FF00FFAAAA55AAFF00AA00FF000000FF00
AAAA00000055AA5555FF000000000055AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00550000FFAAAAFF55FF0000FFFF00000055FF00AA
AAAA00FFFF55AAFF000000FF0055555500FF000000FFAA55FFFF00AAAAAA00FF55000000
FFFF0000FF55FFAAAAFF00005500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55005500AAFFFFAA00000055AAAA5555AA000000FF
FF00FF00AAFFAAFF0000FF00AAAAFFAAAA00FF0000FFAAFFAA00FF00FFFF000000AA5555
AAAA55000000AAFFFFAA00550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000FFFFFFFF0000FF55FFAAFFAAAAAA0055FF
555555FF00FFAA55AA5555FF00FFFFFF00FF5555AA55AAFF00FF555555FF5500AAAAAAFF
AAFF55FF0000FFFFFFFF0000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500000000000055FF55FF55AAAAAAAAAA0000
00AA000000FFAAFFAAFFAAAA5555FF5555AAAAFFAAFFAAFF000000AA000000AAAAAAAAAA
55FF55FF5500000000000055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00550000FF55FF55FF55FFAAFFFFAA5555
AA55FF0000FFAAFF00FFAAFF55FFFFFF55FFAAFF00FFAAFF0000FF55AA5555AAFFFFAAFF
55FF55FF55FF00005500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55005500AAFFAA000000AAFF5555FFAAAA
FFFF555555AAAAAA5555FFAA0000000000AAFF5555AAAAAA555555FFFFAAAAFF5555FFAA
000000AAFFAA00550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000FFFFFF0000FF00FFAAAAFF00FF
FFFFFF55FFFFAAFF55FFFFFF0000550000FFFFFF55FFAAFFFF55FFFFFFFF00FFAAAAFF00
FF0000FFFFFF0000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550000000000FF5555AAAAAAAA5555
FF5555FFFFFFFFAA00000000005500550000000000AAFFFFFFFF5555FF5555AAAAAAAA55
55FF000000000055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00550000FFAAAAFFFF00FFFF55
FF55FFFFFFFFFFFF0000FF00550055005500FF0000FFFFFFFFFFFF55FF55FFFF00FFFFAA
AAFF00005500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55005500AAFFFFAA00FF00AAFF
AA0000000000000000FF55555500AA00555555FF0000000000000000AAFFAA00FF00AAFF
FFAA00550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000FFFFFFFF000000FFFF
FF000055AA5555AA5555FFFF55FF00FF55FFFF5555AA5555AA550000FFFFFF000000FFFF
FFFF0000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5500000000000055000000
0000FF55FFAAAAFF55FFFFFFFF555555FFFFFFFF55FFAAAAFF55FF000000000055000000
00000055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00550000FF55FF0055
FF000000AAFFFFAA000000000000AA000000000000AAFFFFAA000000FF5500FF55FF0000
5500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55005500AAFFAA0055
55FF0000FFFFFFFF0000FF0000FF00FF0000FF0000FFFFFFFF0000FF555500AAFFAA0055
0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000FFFFFF0000
AA00FF000000000000FF00AAAA00FF00AAAA00FF000000000000FF00AA0000FFFFFF0000
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550000000000FF
55AA55AA550000FF000000FFFF000000FFFF000000FF000055AA55AA55FF000000000055
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00550000FF
AAAAAAFFFF550000005500000000FF000000005500000055FFFFAAAAAAFF00005500AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55005500AA
FFFFAAFF00AA00550000AA5555AA55AA5555AA00005500AA00FFAAFFFFAA00550055AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000FF
FFFFFF00AAAAAA000055FFAAAAFF55FFAAAAFF550000AAAAAA00FFFFFFFF0000AAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA550000
00000000FFFFAA5500AA00FFFF00AA00FFFF00AA0055AAFFFF00000000000055AAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00
550000FF00AAFF55FF00FF5555FF00FF5555FF00FF55FFAA00FF00005500AAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55
0055000000FFFFFF555555FFFF555555FFFF555555FFFFFF000000550055AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AA0000FF0000000000AA00000000AA00000000AA0000000000FF0000AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55000000550000FF00FF0000FF00FF0000FF00FF00005500000055AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAA00550055AA00FF00AAAA00FF00AAAA00FF00AA55005500AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAA550055FFFF000000FFFF000000FFFF000000FFFF550055AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAA000000005500000000FF000000005500000000AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAA55000055005500FF000000FF00550055000055AAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAA00555555000000FF00000055555500AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA5500555500FF000000FF0055550055AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA0000AA55AA00AA55AA0000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAA5500FFFF55AA55FFFF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA00FFAAAAAAFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAA5555FFAAFF5555AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFF00FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 3.45727 0.200176 3.54458 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAA005555FF00AAFF55FFAA55AA55555555FFAA00AA00AA55FF00FFAA55AAAAAA55
5555AAAA555555555555FF0000AA55AA0000FF555555555555AAAA555555AAAAAA55AAFF
00FF55AA00AA00AAFF55555555AA55AAFF55FFAA00FF555500AAAAAAFF
FFFFAAAAFF555500FFFF55005500AAFFAA0000AA00AA55FFFF0000AAAAAA005555555555
FF55555555FF5555005555AAFF55FF55FFAA5555005555FF55555555FF555555555500AA
AAAA0000FFFF55AA00AA0000AAFFAA00550055FFFF005555FFAAAAFFFF
FFFFFFAAAA00FFAA5555AAAAAA55FFFFFF55AAFFAA550055FF00FFFFAAFFFF00AA0000AA
00AA00FFAA00AA000000AA00550055005500AA000000AA00AAFF00AA00AA0000AA00FFFF
AAFFFF00FF550055AAFFAA55FFFFFF55AAAAAA5555AAFF00AAAAFFFFFF
FFFFFFFFAAAAAA005555FFFF55FF5500FF555555AA000000AAAAAA00AA5555AAFFAA55FF
FF00000055AAFFAA55FFAAAAAA55FF55AAAAAAFF55AAFFAA55000000FFFF55AAFFAA5555
AA00AAAAAA000000AA555555FF0055FF55FFFF555500AAAAAAFFFFFFFF
FFFFFFFFFFAAAAFF555500FF5555AAAAAA0000AAFFAA55FFAAFFAAAAAAFF00AA55555500
FF55AAFF555555AA00FF55FFFFAA00AAFFFF55FF00AA555555FFAA55FF00555555AA00FF
AAAAAAFFAAFF55AAFFAA0000AAAAAA5555FF005555FFAAAAFFFFFFFFFF
FFFFFFFFFFFFAAAA00FFAA5555FF55FFFF55AAFFFFFFAA00AA5555555555AAFFAA00FFAA
555500AAAA55AAAAFF55005500FF00FF00550055FFAAAA55AAAA005555AAFF00AAFFAA55
55555555AA00AAFFFFFFAA55FFFF55FF5555AAFF00AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA005555FF00AAAA0000FF550000FFFF5555005555FFFFFFAA5555
55FF55AA0055555555AAAAAA55FF00FF55AAAAAA5555555500AA55FF555555AAFFFFFF55
55005555FFFF000055FF0000AAAA00FF555500AAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAFF555500FFFF55FFAA5555FFAA5555AAAA55FF5555AA555555FF
5555AAAAFF55550055555555550000005555555555005555FFAAAA5555FF555555AA5555
FF55AAAA5555AAFF5555AAFF55FFFF005555FFAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA00FFAA5555AAAA00555500FF00AAFFAAAA5555FF55FF555500
00AAFFAAAA00FFAA55AAAA55AAAAAAAAAA55AAAA55AAFF00AAAAFFAA00005555FF55FF55
55AAAAFFAA00FF00555500AAAA5555AAFF00AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAA005555FFFF55AAAA55FF00FF0055AA0000AAAA5555FF55
AAFFFFFFAAAAAA0055555555FFFFAAFFFF5555555500AAAAAAFFFFFFAA55FF5555AAAA00
00AA5500FF00FF55AAAA55FFFF555500AAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFF555500FF55555555FF00FF55AAAAFF55AA0055550000
AA5555AA5500AA55FF5555FF5500FF0055FF5555FF55AA0055AA5555AA0000555500AA55
FFAAAA55FF00FF55555555FF005555FFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA00FFAA5555FF555500000055555555AAAAFF5555FFAA
5500555555FFAAAA55550055FF55AA55FF55005555AAAAFF5555550055AAFF5555FFAAAA
555555550000005555FF5555AAFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA005555FF00AAFF55AAFF00AAFF0000FF55550000
FFAA55AAAA55555555FF55AAAA00FF00AAAA55FF55555555AAAA55AAFF00005555FF0000
FFAA00FFAA55FFAA00FF555500AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF555500FFFF550055AA55FFFFFF00FF5555FFAA
555555FFFFAA00FFAA00AAFFFF55AA55FFFFAA00AAFF00AAFFFF555555AAFF5555FF00FF
FFFF55AA550055FFFF005555FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FFAA5555AAAAAA55005500FF55AA55AAAA00
5555FF550000FFFFFFAA5500FF555555FF0055AAFFFFFF000055FF555500AAAA55AA55FF
00550055AAAAAA5555AAFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA005555FFFF55FF55AAAAAA0000FFAAFFAA
55AAAA00000000550000FFAA5555005555AAFF00005500000000AAAA55AAFFAAFF0000AA
AAAA55FF55FFFF555500AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF555500FF5555AAAAFFAAAAAAAA005500
AAFFFFAA55FFAA55AAFF5500AAFF00FFAA0055FFAA55AAFF55AAFFFFAA005500AAAAAAAA
FFAAAA5555FF005555FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FFAA5555FF55FFFFFFAAFFAAAAAA55
FFFFFFFFAA00AA55AA00AAFF55FF00FF55FFAA00AA55AA00AAFFFFFFFF55AAAAAAFFAAFF
FFFF55FF5555AAFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA005555FF00AAAA00AA5555555555
000055FF000000FFAAFF55FF00AAAAAA00FF55FFAAFF000000FF5500005555555555AA00
AAAA00FF555500AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF555500FFFF55FFAAAA55AAAA55
AAFF5555AAFF55AA550000AAAAAAFFAAAAAA000055AA55FFAA5555FFAA55AAAA55AAAAFF
55FFFF005555FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FFAA5555AAAA0055AAAAFFAA
005500555555AAAAFF00FFFFAAFFFFFFAAFFFF00FFAAAA555555005500AAFFAAAA5500AA
AA5555AAFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA005555FFFF55AAAAFFFFFF
55AAAAAA55AAAAFFFFFF0055FFFFFFFFFF5500FFFFFFAAAA55AAAAAA55FFFFFFAAAA55FF
FF555500AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF555500FF55555555AA55
55FFFF55FF55FFFFFFFFFF00AAAA00AAAA00FFFFFFFFFF55FF55FFFF5555AA55555555FF
005555FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FFAA5555FF555500AA
0000550055005500FF55000000FF00FF00000055FF0055005500550000AA005555FF5555
AAFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA005555FF00AAFF55
FFAA55AAFF00FFAA5555FFAA55FF00FF55AAFF5555AAFF00FFAA55AAFF55FFAA00FF5555
00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF555500FFFF5500
5500AAFFFFFF0055AAAA555555FF00FF555555AAAA5500FFFFFFAA00550055FFFF005555
FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FFAA5555AAAA
AA55FFFFFFFFFF00AA5500555500000055550055AA00FFFFFFFFFF55AAAAAA5555AAFF00
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA005555FFFF
55FF5500FF55000000FFAA55AAAAAAAAAA55AAFF00000055FF0055FF55FFFF555500AAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF555500FF
5555AAAAAA000000000055AAAAFFAAFFAAAA550000000000AAAAAA5555FF005555FFAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FFAA55
55FF55FFFF55AAFF55AAFF0000FF55FF0000FFAA55FFAA55FFFF55FF5555AAFF00AAAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA0055
55FF00AAAA0000FF555555AAFF550055FFAA555555FF0000AAAA00FF555500AAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55
5500FFFF55FFAA5555FF555555AAAAAA555555FF5555AAFF55FFFF005555FFAAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00
FFAA5555AAAA0055550000AA0000FF0000AA0000555500AAAA5555AAFF00AAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
AA005555FFFF55AAAA55FFAAFF55AA55FFAAFF55AAAA55FFFF555500AAAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAFF555500FF55555555FF00005555550000FF55555555FF005555FFAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAA00FFAA5555FF555500000000AA000000005555FF5555AAFF00AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAA005555FF00AAFF55AAFF55FFAA55FFAA00FF555500AAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAFF555500FFFF550055AA55AA550055FFFF005555FFAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAA00FFAA5555AAAAAA550055AAAAAA5555AAFF00AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAAA005555FFFFAAFF00FFAAFFFF555500AAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAFF555500FF55FF00FF55FF005555FFAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAA00FFAA5555FF00FF5555AAFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA005555FF00FF555500AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAFF5555FF00FF5555FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA0000AAAAAA0000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAAAAFFAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFFFFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 3.45727 0.39418 3.54458 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAFFAA5555FF55FF55FF00FFAA55AAAA55AAAAAA555555005555AA555500555555
AAAAAA5555AA5555AA55AAAA0000000000AAAA55AA5555AA5555AAAAAA555555005555AA
555500555555AAAAAA55AAAA55AAFF00FF55FF55FF5555AAFFAAAAAAFF
FFFFAAAA0055FF55555500AA005500AAAA5555AAAA00AAAA55AAAAAA55AA55AAAAAA55AA
AA00AAAA55AA55AAAA00FF55000055000055FF00AAAA55AA55AAAA00AAAA55AAAAAA55AA
55AAAAAA55AAAA00AAAA5555AAAA005500AA00555555FF5500AAAAFFFF
FFFFFFAAAAAA55005555FFAAAAAA55FFFF5555FFFFAA5555AAAAFFFF5555AAAAFFFFAA00
AAAAAA00AA00AAFFFF55AA00005500550000AA55FFFFAA00AA00AAAAAA00AAFFFFAAAA55
55FFFFAAAA5555AAFFFF5555FFFF55AAAAAAFF55550055AAAAAAFFFFFF
FFFFFFFFAAAA0000555500AAAA00AA0055AAAA5500AAAA55AA55555555FF55FFFFFFFFAA
5555AA55FFFF0055AA0000005500550055000000AA5500FFFF55AA5555AAFFFFFFFF55FF
55555555AA55AAAA0055AAAA5500AA00AAAA0055550000AAAAFFFFFFFF
FFFFFFFFFFAAAAAAAA55AAFFAAFF55FFAA00AAAA55FFFFAA00AA0000AA00555555555555
AAAA555500AA55FF55000055005500550055000055FF55AA005555AAAA55555555555500
AA0000AA00AAFFFF55AAAA00AAFF55FFAAFFAA55AAAAAAAAFFFFFFFFFF
FFFFFFFFFFFFAAAA00AA00AA55555500AAAAAAFFAA0055AA55FFFF00FF55AAAA55AAAA55
AA5555FF55AA55AA00005500550055005500550000AA55AA55FF5555AA55AAAA55AAAA55
FF00FFFF55AA5500AAFFAAAAAA00555555AA00AA00AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAFF55FF5555FFAAAAFFFFFFAA55AA55AA005500AAFFFFAA00AAAA
55550055AAAA0000005500550055005500550055000000AAAA55005555AAAA00AAFFFFAA
005500AA55AA55AAFFFFFFAAAAFF5555FF55FFAAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA005555550055AA5555555555AAAA00FF55AAAAAA0055AA55FFFF
5555FFAA00AAAAAAAAAA55FF55AAAAAA55FF55AAAAAAAAAA00AAFF5555FFFF55AA5500AA
AAAA55FF00AAAA5555555555AA550055555500AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAA55AAAAAA5555FF55550055FFFF0000AAAAFFAA55AA55AA00
555500AAAAAAFFAAAA00AA005555AA555500AA00AAAAFFAAAAAA00555500AA55AA55AAFF
AAAA0000FFFF55005555FF5555AAAAAA55AAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA0000000000AA005555FFAA0055AAFF55FFFFFF5555AAAAFF
5555FFAAAAFFFFFFAAFF55FFAA000000AAFF55FFAAFFFFFFAAAAFF5555FFAAAA5555FFFF
FF55FFAA5500AAFF555500AA0000000000AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAAAAFF555500AAAAAA55555500AA55005555AA55
00555555AA5500AA55555500AAAAAAAAAA00555555AA0055AA5555550055AA55550055AA
00555555AAAAAA005555FFAAAAAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAA00AA55AAAAAA00AAAA55AAAAAAFF00FFAA00AA
FF5555FF55FF55AA55AAAA55FFFFAAFFFF55AAAA55AA55FF55FF5555FFAA00AAFF00FFAA
AAAA55AAAA00AAAAAA55AA00AAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAA5555FFFFAAAAAAFFAA00AAAA005500AAAAAA
00555500AA005555AAAA00AA0055AA5500AA00AAAA555500AA00555500AAAAAA005500AA
AA00AAFFAAAAAAFFFF5555AAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055FF55555555AA555555AAFFFFAA55AAFFAAAA
FF5555FFAAFF555500FF55AA55FF55FF55AA55FF005555FFAAFF5555FFAAAAFFAA55AAFF
FFAA555555AA55555555FF5500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55005555FF55FF5555FFFFFFFFAA00AA5555
AA0000AA555555FF55AA000000AA55AA000000AA55FF555555AA0000AA5555AA00AAFFFF
FFFF5555FF55FF55550055AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000555500AA00555500AA5500AAAAAA0000
AAAAAAAA0000AA005555AAFF55AA55AA55FFAA555500AA0000AAAAAAAA0000AAAAAA0055
AA00555500AA0055550000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA55AAFFAA55AAAAAA000055FFFF55AA
FFAAAAFFAA55FF00FFAA00AA55AA55AA55AA00AAFF00FF55AAFFAAAAFFAA55FFFF550000
AAAAAA55AAFFAA55AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA00AA5555FFFF55000055555555FF
FFFF5500AAAA550000FF55AA55AA55AA55AA55FF000055AAAA0055FFFFFF555555550000
55FFFF5555AA00AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF55FF5555555500005555005555
555555FFAAAA00005500AAFFAA00AA00AAFFAA00550000AAAAFF55555555550055550000
55555555FF55FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00555555005555FFAA55AAAAAA55
AAAA55AA00AAAAAAAA55FFFFFF55AA55FFFFFF55AAAAAAAA00AA55AAAA55AAAAAA55AAFF
55550055555500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55AAAAAA55AA00AAFFFFAAFF
0055FF55FFAAAA00AAAA5500AA55AA55AA0055AAAA00AAAAFF55FF5500FFAAFFFFAA00AA
55AAAAAA55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000000000AAAAAA0055AA55
0000AA55AA00AAAAAA00AAFF55FF55FF55FFAA00AAAAAA00AA55AA000055AA5500AAAAAA
0000000000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAAAAFFAAAAAA5555
000055FF55FFAAAAFFAA55555500AA00555555AAFFAAAAFF55FF5500005555AAAAAAFFAA
AAAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAA00AA5555AA55AA
AAAAAA550055AA555555AAAA55AAFFAA55AAAA555555AA550055AAAAAAAA55AA5555AA00
AAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAA5555FF55FF55
FF0055FF55AAAA0000AAFFAAAA555555AAAAFFAA0000AAAA55FF5500FF55FF55FF5555AA
FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055FF55555500AA
00550055AAAAFFAA55FFFFFFAAAA55AAAAFFFFFF55AAFFAAAA55005500AA00555555FF55
00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55005555FFAA
AAAA55FF55FFFFFF5555555555AA55AA5555555555FFFFFF55FF55AAAAAAFF55550055AA
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000555500AA
AA00AA005555555555005555FF55FF55FF555500555555555500AA00AAAA0055550000AA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA55AAFF
AAFF55FFAA0000AAFF00FFAA0055555500AAFF00FFAA0000AAFF55FFAAFFAA55AAAAAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA00AA
55555500AAAAAAAA005500AAAAAA55AAAAAA005500AAAAAAAA00555555AA00AA00AAAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF55
FF5555FFAAAAFFFFAA55AAFFFF550055FFFFAA55AAFFFFAAAAFF5555FF55FFAAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055
55550055AA55555555AAAA0055AAAAAA5500AAAA55555555AA550055555500AAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA
55AAAAAA5555FF5555FFFF55AAAAFFAAAA55FFFF5555FF5555AAAAAA55AAAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
0000000000AA00555500AA55AA555555AA55AA00555500AA0000000000AAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAAAAAAAAAAAFF5555000000AAAA55AAAA0000005555FFAAAAAAAAAAAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAA00AAAA00AA55AAAAAAAAAA00AA00AAAAAAAAAA55AA00AAAA00AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAAFFAA5555FFFF55FFFF55AA55FFFF55FFFF5555AAFFAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAA0055FF5555555500AA55AA55AA0055555555FF5500AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAAAA55005555FF55AA55AA55AA55FF55550055AAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAA0000555500AA00AAFFAA00AA0055550000AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAAAA55AAFFAA555555AAFFAA55AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAA00AA00AA5555FF5555AA00AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAFF55FF555555FF55FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA005555550055555500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAA55AAAAAA55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA0000000000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 3.45727 0.588183 3.54458 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAA55FF00AAAAFFFF00AA0000555500000000FF5555FF0000550000AAAA00AAAA00AA
00AA5555FF55FF55FF55AA00AAAAAAAAAA00AA55FF55FF55FF5555AA00AA00AAAA00AAAA
0000550000FF5555FF0000000055550000AA00FFFFAAAA00FF55AAAAFF
FFFFAAAA000055AA0000AAFFFF00FF550000550000AAAA00005500FFFF0000FFFF55FF55
FFAAAA00AA00AA00AA00AA55FFFFAAFFFF55AA00AA00AA00AA00AAAAFF55FF55FFFF0000
FFFF00550000AAAA000055000055FF00FFFFAA0000AA550000AAAAFFFF
FFFFFFAAAA55FF00005500AA000000AAAAAA5555FF55FFFF00FF555500550000AA00AA00
AA0055AAFFAA550000FFFF55005555550055FFFF000055AAFFAA5500AA00AA00AA000055
005555FF00FFFF55FF5555AAAAAA000000AA00550000FF55AAAAFFFFFF
FFFFFFFFAAAA00005500FFAAFF00AAFFFFAAAA00AA00AA00005555AA55AA55FFAAFF55FF
55FF5500AA0055FFAA0000AAAAAA00AAAAAA0000AAFF5500AA0055FF55FF55FFAAFF55AA
55AA55550000AA00AA00AAAAFFFFAA00FFAAFF00550000AAAAFFFFFFFF
FFFFFFFFFFAAAA55FF00AA005555FFFFFFFF55FF55FF55FFAA5555AA00AA555500AA00AA
00AA00AAFFAA00AA00550000FF000000FF00005500AA00AAFFAA00AA00AA00AA005555AA
00AA5555AAFF55FF55FF55FFFFFFFF555500AA00FF55AAAAFFFFFFFFFF
FFFFFFFFFFFFAAAA000055AAAA00AA0000AA00AA00AA00AA0055FF000000FF550000FFFF
555555FFFFFFAA005500FFAA0000000000AAFF005500AAFFFFFF555555FFFF000055FF00
0000FF5500AA00AA00AA00AA0000AA00AAAA550000AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA55FF0000FFAAAA55FFFF000000FFAAAAAA000000550055FFAA0000
AAAA00AA0000AA55FF00AA00550000005500AA00FF55AA0000AA00AAAA0000AAFF550055
000000AAAAAAFF000000FFFF55AAAAFF0000FF55AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA0000550055AA00AA0000000000AA5500AAFF00AAAAAA0000FFFF
0000FFFFAA55AA00AA00FF00AAAA55AAAA00FF00AA00AA55AAFFFF0000FFFF0000AAAAAA
00FFAA0055AA0000000000AA00AA5500550000AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA55FF00AAAAFF00000000000000FF55AA000000FF00000000AA
00FFFFFFFF5500AAFFAA000055AA00AA550000AAFFAA0055FFFFFFFF00AA00000000FF00
0000AA55FF00000000000000FFAAAA00FF55AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA000055AA000000000000000000AAAAFF00FFFFFF00FFFF00
005555005555AAFFFFFF5555FF000000FF5555FFFFFFAA55550055550000FFFF00FFFFFF
00FFAAAA000000000000000000AA550000AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA55FF0000550000000000000055AA000000AA0000555500
0055FF00FF5500AA0000AAAA0000000000AAAA0000AA0055FF00FF55000055550000AA00
0000AA5500000000000000550000FF55AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA00005500FFAA55AAAAAA55FF0000000000FFAA00AAAA
AAAA00005555AAFFAA55AA00550000005500AA55AAFFAA55550000AAAAAAAA00AAFF0000
000000FF55AAAAAA55AAFF00550000AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF00AA0055FFFFAAAA0000000000550055AAFFAA
FFAAAA55AA55555500AAAAFF5500000055FFAAAA00555555AA55AAAAFFAAFFAA55005500
00000000AAAAFFFF5500AA00FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA000055AAAA0000AA55000000000055FF5500AA00
55555555AA00AAAA00FF0000AAAA55AAAA0000FF00AAAA00AA5555555500AA0055FF5500
0000000055AA0000AAAA550000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF0000FFAA0055FFAA00FFAA00AA00AAFFFF
0055FF0055AAFFFF5555000055AA00AA5500005555FFFFAA5500FF5500FFFFAA00AA00AA
FF00AAFF5500AAFF0000FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000550055AAAA0000FFFFFF555555FFFFFF
FF005555FF0000AA00AAAA55FF000000FF55AAAA00AA0000FF555500FFFFFFFF555555FF
FFFF0000AAAA5500550000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF00AAAAFFFF00AA0000AAAA00AA0000
AA00FF5500550000FFFFAAAA0000550000AAAAFFFF0000550055FF00AA0000AA00AAAA00
00AA00FFFFAAAA00FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA000055AA0000AAFFFF00FF000000FFFF
000000AAAAAA00FFFFFFFFAAAA55AA55AAAAFFFFFFFF00AAAAAA000000FFFF000000FF00
FFFFAA0000AA550000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF00005500AA000000AAFF00AA00
00000000FF000000AA0000AA5500FF0055AA0000AA000000FF0000000000AA00FFAA0000
00AA00550000FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00005500FFAAFF00AAFFFFFF0000
550000550055000055AAAA5500FFFFFF0055AAAA5500005500550000550000FFFFFFAA00
FFAAFF00550000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF00AA005555FFFFFFFFFF00
FF5555FF00FF5555FF0000FF5555005555FF0000FF5555FF00FF5555FF00FFFFFFFFFF55
5500AA00FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA000055AAAA00AA0000AA0000
00AAAA000000AAAA0000550055FF00FF5500550000AAAA000000AAAA000000AA0000AA00
AAAA550000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF0000FFAAAA55FFFF00
FFAAAAFF00FFAAAAFF00AAAAAA000000AAAAAA00FFAAAAFF00FFAAAAFF00FFFF55AAAAFF
0000FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000550055AA00AA0000
00AA5500550055AA000000FF0000000000FF000000AA5500550055AA000000AA00AA5500
550000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF00AAAAFF000000
0000FF55AA55AA5500000000AAFF00FFAA0000000055AA55AA55FF0000000000FFAAAA00
FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA000055AA00000000
00005555AA00AA5555FFAA55AA000000AA55AAFF5555AA00AA5555000000000000AA5500
00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF0000550000
000055FF000000FF550055AA5500000055AA550055FF000000FF5500000000550000FF55
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00005500FFAA
55AAAA0000550000AAAA555555AAAAAA555555AAAA0000550000AAAA55AAFF00550000AA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF00AA00
55FFFFAA55FF00FFFFAAAA00AAAAFFAAAA00AAAAFFFF00FF55AAFFFF5500AA00FF55AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA000055AA
AA0000AA55550000AA0055AAAAFFFFFFAAAA5500AA00005555AA0000AAAA550000AAAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF00
00FFAA0055FF00FFFFAA555555550055555555AAFFFF00FF5500AAFF0000FF55AAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000
550055AAAA0000555500AAAA00AAAAAA00AAAA0055550000AAAA5500550000AAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55
FF00AAAAFFFF00AAAA00FF000000FF000000FF00AAAA00FFFFAAAA00FF55AAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
000055AA0000AAFFFFAA000000550055000000AAFFFFAA0000AA550000AAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AA55FF00005500AA0000FFFF00AAAAAA00FFFF0000AA00550000FF55AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAA00005500FFAAFF00AA000000FF000000AA00FFAAFF00550000AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAA55FF00AA005555FFFF00FFFFFF00FFFF555500AA00FF55AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAA000055AAAA00AA000000AA000000AA00AAAA550000AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAA55FF0000FFAAAA55FF55FF55AAAAFF0000FF55AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAA0000550055AA00AA00AA00AA5500550000AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAA55FF00AAAAFF000000FFAAAA00FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAA000055AA0000000000AA550000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA55FF00000000000000FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA000000000000000000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA55AAAA55AAAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA0055AA5500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA555555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 3.45727 0.782187 3.54458 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAAA55FFAAFFFF5555FFAA55FFFF000055AAAAAAFF0055FFFF00550000FF55AA55
55AA0055AA00FFAAFFFF5555AAFFFFFFAA5555FFFFAAFF00AA5500AA5555AA55FF000055
00FFFF5500FFAAAAAA550000FFFF55AAFF5555FFFFAAFF55AAAAAAAAFF
FFFFAAFFFFAAAAAA55FFAAAAFF55555500550000FFAAFF00FF55FFAA555555AA55FFFFAA
AAFF0055AAAA000000AA0055AAAAAAAAAA5500AA000000AAAA5500FFAAAAFFFF55AA5555
55AAFF55FF00FFAAFF00005500555555FFAAAAFF55AAAAAAFFFFAAFFFF
FFFFFFAA55FF5555FFFFFFAAFF55FFFF5500AAAA000000AAAAAAFF5555555555FFFFFF00
AAFF5500AAFF005500000055AAAA55AAAA550000005500FFAA0055FFAA00FFFFFF555555
5555FFAAAAAA000000AAAA0055FFFF55FFAAFFFFFF5555FF55AAFFFFFF
FFFFFFFFAAAAAAFFAA55FFAAFF55FFAA5500000000550000000000AA5500AA5500555500
FFAA5500FFAA555555AA555555FF55FF555555AA555555AAFF0055AAFF0055550055AA00
55AA0000000000550000000055AAFF55FFAAFF55AAFFAAAAAAFFFFFFFF
FFFFFFFFFFAAFFFFFFAAAAAA55FFFFFFAAAA00AAAA005500FF55000000FF555555AA0055
FFAA0055FFAAFFAAAAFF0000FF00FF00FF0000FFAAAAFFAAFF5500AAFF5500AA555555FF
00000055FF005500AAAA00AAAAFFFFFF55AAAAAAFFFFFFAAFFFFFFFFFF
FFFFFFFFFFFFAA55FFAAFFFFAAAAAAAAAA55AA55AAAA00550055AA5555AAFFAAAAFF0055
AAFF0055AAFFFFFFAAFF550000AAAAAA000055FFAAFFFFFFAA5500FFAA5500FFAAAAFFAA
5555AA55005500AAAA55AA55AAAAAAAAAAFFFFAAFF55AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA55FFAAFFFFAAFFFF555555FF5500AAAAFFFF55FF55AAAA55FF00
0000AAAAFFFFFFFF00AA005500000000005500AA00FFFFFFFFAAAA000000FF55AAAA55FF
55FFFFAAAA0055FF555555FFFFAAFFFFAAFF55AAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF55AAAAAAAA55FFAAAAFFAA5500FFAAFF55AA0000FFAAFFAA55
55AA55AAAAAAAAAAAA00FF55FF005500FF55FF00AAAAAAAAAAAA55AA5555AAFFAAFF0000
AA55FFAAFF0055AAFFAAAAFF55AAAAAAAA55FFFFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA55FFFFAAFFFFAAAAAA55AAFF00005555FFAAAA5555AAFFFFFFAA
AAFF000000000000000055555500FF005555550000000000000000FFAAAAFFFFFFAA5555
AAAAFF55550000FFAA55AAAAAAFFFFAAFFFF55AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAAAA55FFAAFFFFAAAA55FF0055AA00000000FF00AA0000AA
FFFF005500FF55000055FFFF55FF00FF55FFFF55000055FF005500FFFFAA0000AA00FF00
000000AA5500FF55AAAAFFFFAAFF55AAAAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFFFAAAAAA55FFAAFF0000AAAAFF005500005555AAAA00AA
FF55AA5500FFFF5500FF00FFFF55AA55FFFF00FF0055FFFF0055AA55FFAA00AAAA555500
005500FFAAAA0000FFAAFF55AAAAAAFFFFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55FF5555FFFFFFAA5555AAAA55FF00005500AA55AAAA00
FFFF555555AAFF55FF00FF55AAFFAAFFAA55FF00FF55FFAA555555FFFF00AAAA55AA0055
0000FF55AAAA5555AAFFFFFF5555FF55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAA55FFAA0055AAAA5500550000FF555555FF55
005555555555FFAAAAAA0000FFAA55AAFF0000AAAAAAFF55555555550055FF555555FF00
00550055AAAA5500AAFF55AAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAAAAAA555555FF55FF000055FFAAAAFFAA55
0000FF0000FF00FFAAFF0055FFAAFFAAFF5500FFAAFF00FF0000FF000055AAFFAAAAFF55
0000FF55FF555555AAAAAAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAAFFFFAAAAFFAA5500550000FFFFAAFF5555
55AA55FF005555AAFFFF0055AAFFFFFFAA5500FFFFAA555500FF55AA555555FFAAFFFF00
00550055AAFFAAAAFFFFAAFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55FFAAFFFFFFAAAA005500FFFFFFAA5500
AA55AA000055AA00FFFF0055AAAAAAAAAA5500FFFF00AA550000AA55AA0055AAFFFFFF00
5500AAAAFFFFFFAAFF55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55AAAAAAAAAA55AA550000AA000000FF
555555FF0055AAAA0000AAAAFFFFAAFFFFAAAA0000AAAA5500FF555555FF000000AA0000
55AA55AAAAAAAAAA55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFAAFFFFAAFFAA00550000005500FF
FF55FFFF0055AAAA5555AAAA55FFAAFF55AAAA5555AAAA5500FFFF55FFFF005500000055
00AAFFAAFFFFAAFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA55FFAAFF5555AA00AAAA005500
555555005500AAFF0000FFAAFFAA55AAFFAAFF0000FFAA005500555555005500AAAA00AA
5555FFAAFF55AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAAAAAA55FFFF5555AAAA555555
AA0055AA55000000AAAA000000AAFFAA000000AAAA00000055AA5500AA555555AAAA5555
FFFF55AAAAAAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF5555FFFFFFFF55FF55555555
55FF000000FF550000000055FF00AA00FF550000000055FF000000FF5555555555FF55FF
FFFFFF5555FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAA55FFAA550055AA0055
AA0000550000AA5555AA555555000000555555AA5555AA0000550000AA5500AA550055AA
FF55AAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAAAAAA5500FF00AAAA
FF005500AAAA00FF000000FF0000550000FF000000FF00AAAA005500FFAAAA00FF0055AA
AAAAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFAAFF00AA555500FFAA
FF5500AAAA55AA55FF0055005500FF0055005500FF55AA55AAAA0055FFAAFF005555AA00
FFAAFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55FF00AA5500FFFF
AA5500000000FFAAAAAA005500AAAAAA005500AAAAAAFF0000000055AAFFFF0055AA00FF
55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55AA55AA00AA00
0000FF5500FF55AAAA55AA5500FFAAFF0055AA55AAAA55FF0055FF000000AA00AA55AA55
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FFFFAAAA5555FF
00550055AA55FFFFAAFFAA0055FFAAFF5500AAFFAAFFFF55AA55005500FF5555AAAAFFFF
55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA55AA0055
55AA00AA55AA0000AAFF5555AA000000AA5555FFAA0000AA55AA00AA555500AA55AAAAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAAAA5555
5555FF00AA55AA5555FFAAAAFF005500FFAAAAFF5555AA55AA00FF55555555AAAAFFFFAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF555555
55555500FFAAAA5500AA00FFAA555555AAFF00AA0055AAAAFF00555555555555FF55AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAA
AAFFAAAA00000000FF5555AAFFFF55FFFFAA5555FF00000000AAAAFFAAAAFFAAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFF
AAFF5555FF005500FFFF55FF55AAFFAA55FF55FFFF005500FF5555FFAAFFFFFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF
AAFF55FFFF0055AA55FFAAAAAAFF00FFAAAAAAFF55AA5500FFFF55FFAAFF55AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
AA55FFFFFF0055AAAAFF5555FF55AA55FF5555FFAAAA5500FFFFFF55AAAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
FFFF55AAFF5500AAFF00FF0000AA55AA0000FF00FFAA0055FFAA55FFFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55FFFFAA55000000AAAAAA00AAFFAA00AAAAAA00000055AAFFFF55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAAAA55000055FF5555FF00AA00FF5555FF55000055AAAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFFAAAA00AA55FFFF55AA55AA55FFFF55AA00AAAAFFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA55FF5555AAAAFF55AA00FF00AA55FFAAAA5555FF55AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAAAFFAAFF00FF00AAAAAA00FF00FFAAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFFFFFFAA555500FFAAFF005555AAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA55FFAA0055AA55FF55AA5500AAFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA555555FFFFFF555555AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF55FFFFFFFFFF55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA55FFFFFFFFFFFFFF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFFFAAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 3.45727 0.97619 3.54458 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAA5500AAFFAAFFFFFF00555500FF00FFFF55555555FF00FF5555FF55FF555555FF
FF0055AAAAAAAA5555FFFF005555AA555500FFFF5555AAAAAAAA5500FFFF555555FF55FF
5555FF00FF55555555FFFF00FF00555500FFFFFFAAFFAA0055AAAAAAFF
FFFFAAFFFF5500AA0055005555AAAA555500FFFFFF55FF555500FFFF55FFAAAAAAFFAA00
00AAAAFFFFAAFFFF55550055FF555555FF55005555FFFFAAFFFFAAAA0000AAFFAAAAAAFF
55FFFF005555FF55FFFFFF005555AAAA5555005500AA0055FFFFAAFFFF
FFFFFFAA55FF5500AAAA5555FFFFAAFF00AAAAAAAAAA55FF5555AAFF555500AA550055AA
555555550000FFFFFF5555AAAAAAFFAAAAAA5555FFFFFF000055555555AA550055AA0055
55FFAA5555FF55AAAAAAAAAA00FFAAFFFF5555AAAA0055FF55AAFFFFFF
FFFFFFFFAAAAAA55555555FFFFFFFFAA55555555555555FFAAAAFFFFFF5555AA00FF5555
55FFFF55FF0055005555FFFFAAFFFFFFAAFFFF5555005500FF55FFFF555555FF00AA5555
FFFFFFAAAAFF55555555555555AAFFFFFFFF55555555AAAAAAFFFFFFFF
FFFFFFFFFFAAFFFF55FF55550000555555FFFF55FFFF55FFAAFFFFFFFFFF555555AAFFAA
AAFF55AAAAAA00FF55FFFFFF0000550000FFFFFF55FF00AAAAAA55FFAAAAFFAA555555FF
FFFFFFFFAAFF55FFFF55FFFF55555500005555FF55FFFFAAFFFFFFFFFF
FFFFFFFFFFFFAA55FF55AAAA5555AAAAFFAA55FF55AAFF00FF00FFFFFF00FFAAAAFFFFFF
AAFF5555555555AAFF00FFFF0055FF5500FFFF00FFAA5555555555FFAAFFFFFFAAAAFF00
FFFFFF00FF00FFAA55FF55AAFFAAAA5555AAAA55FF55AAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA5500AAFFAAFFFFFFAAAAAAFFFF005500FFFFFF00555555550000
AA55FF55FF55FFFFAA55550055FFFFFF55005555AAFFFF55FF55FF55AA00005555555500
FFFFFF005500FFFFAAAAAAFFFFFFAAFFAA0055AAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF5500AA00550055555555550055FF5500550055FF55FF55FF00
55AAAAAA55FF55AAFFFF5555AAAAAAAAAA5555FFFFAA55FF55AAAAAA5500FF55FF55FF55
00550055FF55005555555555005500AA0055FFFFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA55FF5500AAAA5555FFFF5555FF00AA00FF5555AAAAAAFF555500
FFAAFFFFAAAAAAFFFFFFFF55555555555555FFFFFFFFAAAAAAFFFFAAFF005555FFAAAAAA
5555FF00AA00FF5555FFFF5555AAAA0055FF55AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAA55555555FFFFFFFF555500FF005555FFFFAAFFFFFF5555
AAFFFFFFFFAAFFFFFFFFFFFF5555FF5555FFFFFFFFFFFFAAFFFFFFFFAA5555FFFFFFAAFF
FF555500FF005555FFFFFFFF55555555AAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFFF55FF555500005555FF550055FFFF55AAFFFFFF00FFAA
00555500555555005555005555FFFFFF55550055550055555500555500AAFF00FFFFFFAA
55FFFF550055FF555500005555FF55FFFFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAAA5555AAAAFF5555AAAAAAAAFFFFFFFF005555
55AAAA5555FF5555AAAA5555FFFFFFFFFF5555AAAA5555FF5555AAAA55555500FFFFFFFF
AAAAAAAA5555FFAAAA5555AAAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA5500AAFFAAFFFFFF55555555555500000055FFFF
55555555FFFFFF55555555FFFFFFFFFFFFFF55555555FFFFFF55555555FFFF5500000055
5555555555FFFFFFAAFFAA0055AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF5500AA0055005555FFFF55FF5555AA5555FFAA
55AAAAFF00FFFFFF5555FFFFFFFFFFFFFFFFFF5555FFFFFF00FFAAAA55AAFF5555AA5555
FF55FFFF5555005500AA0055FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF5500AAAA5555FFFFFFFF55AAAAFFFF555500
AAFFFFAA5555005555FFFF00FFFFFFFFFF00FFFF5555005555AAFFFFAA005555FFFFAAAA
55FFFFFFFF5555AAAA0055FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55555555FFFFFFFF00FFAAFFFFFFFF5555
AA000000FFAAAA00FFAA55FF00FFFFFF00FF55AAFF00AAAAFF000000AA5555FFFFFFFFAA
FF00FFFFFFFF55555555AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55FF555500005555AAFFFFFFFFFFFF55
5555AA555500AA555500AAFF5500550055FFAA005555AA005555AA555555FFFFFFFFFFFF
AA555500005555FF55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAAA5555AAAAFFFF00FFFF00FFFF
55FFFFAAAA555555FF5500AA00FF55FF00AA0055FF555555AAAAFFFF55FFFF00FFFF00FF
FFAAAA5555AAAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA5500AAFFAAFFFFFF00555500FFFF
FF55AAFFFFAAAA55AAFF0055AA55FF55AA5500FFAA55AAAAFFFFAA55FFFFFF00555500FF
FFFFAAFFAA0055AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF5500AA0055005555AAAA555500
00AAFFFFFFFFAAFF000055FFFFAAAAAAFFFF550000FFAAFFFFFFFFAA00005555AAAA5555
005500AA0055FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF5500AAAA5555FFFFAAFF00AA
AA0055550055555500FF55550000FF00005555FF0055555500555500AAAA00FFAAFFFF55
55AAAA0055FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55555555FFFFFFFFAA5555
5555AAAA5555FF5555AAFFAAAA00AA00AAAAFFAA5555FF5555AAAA55555555AAFFFFFFFF
55555555AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55FF55550000555555FF
FF55555555FFFFFF55555500AA555555AA00555555FFFFFF55555555FFFF555555000055
55FF55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAAA5555AAAAFFAA
55FF55FF5555005555FFFF5500AAFFAA0055FFFF5555005555FF55FF55AAFFAAAA5555AA
AA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA5500AAFFAAFFFFFF
AAAAAA55FF5555AAAAFF55AAAA005500AAAA55FFAAAA5555FF55AAAAAAFFFFFFAAFFAA00
55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF5500AA00550055
55555555FFAAAAFFFFAA55AA0055FF5500AA55AAFFFFAAAAFF5555555555005500AA0055
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF5500AAAA5555
FFFF5555FFAAFFFFFFFFAA0055FFFFFF5500AAFFFFFFFFAAFF5555FFFF5555AAAA0055FF
55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55555555FF
FFFFFF555500AA0000AA0055FFFFFFFFFF5500AA0000AA005555FFFFFFFF55555555AAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55FF5555
00005555FF5500AAAA0055FFFFFFFFFFFFFF5500AAAA0055FF555500005555FF55FFFFAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAAA
5555AAAAFF5555AA0055FFFFFFFFFFFFFFFFFF5500AA5555FFAAAA5555AAAA55FF55AAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA5500
AAFFAAFFFFFF555555AAAAAAAAAAAAAAAAAAAAAA555555FFFFFFAAFFAA0055AAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55
00AA0055005555FF55555555555555555555555555FF5555005500AA0055FFFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF
5500AAAA5555FFFFFF55FFFF5555FF5555FFFF55FFFFFF5555AAAA0055FF55AAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
AA55555555FFFFFFFFFF55AAFFAAAAAAFFAA55FFFFFFFFFF55555555AAAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
FFFF55FF555500000000AAFFFFFFAAFFFFFFAA000000005555FF55FFFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA55FF55AAAA5555AA5555550055555500555555AA5555AAAA55FF55AAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAA5500AAFFAAFFAAAA5555FF5555AAAAFFAAFFAA0055AAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFF5500AA0055555555FFFFFF5555555500AA0055FFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA55FF5500AAAAFFAA00FFFFFF00AAFFAAAA0055FF55AAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAAA5555555500AAAAAAAAAA0055555555AAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAFFFF55FF55FF0000FF0000FF55FF55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAA55FF55AAAAAA00AA00AAAAAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA5500AA555555AA0055AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF5500AAFFAA0055FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA55FF5500AA0055FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAA555555AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAFFFF55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 3.55331 0.200176 3.64062 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAA00AAFF00AA0055AAFFFFFFAA550000FFFF00AA5555000000AA00555500AA5555
5500AAFFAAFF00AAAA55550055AAFFAA55005555AAAA00FFAAFFAA00555555AA00555500
AA0000005555AA00FFFF000055AAFFFFFFAA5500AA00FFAA00AAAAAAFF
FFFFAAAA000055AAAA00000055AA0055FFAA00FF0000AAAAAAAA55AAAA00000000AAAAAA
AAAA555555AA00FF55FFAA55AAFFFFFFAA55AAFF55FF00AA555555AAAAAAAAAA00000000
AAAA55AAAAAAAA0000FF00AAFF5500AA55000000AAAA550000AAAAFFFF
FFFFFFAAAA55AAFFAAAA55AAAAAA000000FF555555FF55FFFFAAAAAAFFAA0000AA00AAAA
FFAAAAAAAAAA0000FFFFFFAA5555555555AAFFFFFF0000AAAAAAAAAAFFAAAA00AA0000AA
FFAAAAAAFFFF55FF555555FF000000AAAAAA55AAAAFFAA55AAAAFFFFFF
FFFFFFFFAAAAAA0055000000550000AA0000FFFF00FF00FF00005500FF005555FF00AAAA
0055FFFFAAAAFF00AA5500AAAAAAAAAAAAAA0055AA00FFAAAAFFFF5500AAAA00FF555500
FF00550000FF00FF00FFFF0000AA0000550000005500AAAAAAFFFFFFFF
FFFFFFFFFFAAAA000000AA000000AA00AA00FF0000AA55AA00FFAA55AA00000000FFAAAA
FF00FF00005500AAFFFF00AAAAFFAAFFAAAA00FFFFAA00550000FF00FFAAAAFF00000000
AA55AAFF00AA55AA0000FF00AA00AA000000AA000000AAAAFFFFFFFFFF
FFFFFFFFFFFFAAAA55AAAA0000AA00AA00AA005555000000555555AAFFAA00FFAA005500
FF00AA55AAAAAA55555555000055AA55000055555555AAAAAA55AA00FF005500AAFF00AA
FFAA555555000000555500AA00AA00AA0000AAAA55AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA00AAFF005555AAAA00000000AA000000000055AA55AA00AAFF55
5555FF00FF55000000000000AAFF55FFAA00000000000055FF00FF555555FFAA00AA55AA
550000000000AA00000000AAAA555500FFAA00AAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA000055AAAAAAAAFFAA0000AAFFAA0000AA00FFFFAA555500FF00
FFFF0000AA55FF5555FF555500FF00FF005555FF5555FF55AA0000FFFF00FF005555AAFF
FF00AA0000AAFFAA0000AAFFAAAAAAAA550000AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA55AAFFAAAAFFFFFF555500FF0055550000AA5500000000AA55
AA005555000000FFFF00000000AA55AA00000000FFFF000000555500AA55AA0000000055
AA0000555500FF005555FFFFFFAAAAFFAA55AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAA00550000FF00000000AA55AAFF5555FF00FFAA00FFAAAA
AA00000000AA0000FF00AA00FFAAAAAAFF00AA00FF0000AA00000000AAAAAAFF00AAFF00
FF5555FFAA55AA00000000FF00005500AAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA000000AA005555FF5555AAFFFFFF00FF00AA555500AAAA
00AA0000AA00AA0000FFAAFF0000550000FFAAFF0000AA00AA0000AA00AAAA005555AA00
FF00FFFFFFAA5555FF555500AA000000AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAAA00000000FFFF0055AA0055555500000000AAAA
00FF55550000AAAA55AA00AA55AAAAAA55AA00AA55AAAA00005555FF00AAAA0000000055
555500AA5500FFFF00000000AAAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00AAFF00AA0055AAAAAA0000000000AA0000AAAA
FF00000000AAFFFFAA5555000000550000005555AAFFFFAA00000000FFAAAA0000AA0000
000000AAAAAA5500AA00FFAA00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA000055AAAA0000005500FFAA0000AA00AA000055
00AA00FFAA00AA5500FFFF00AAFF00FFAA00FFFF0055AA00AAFF00AA00550000AA00AA00
00AAFF0055000000AAAA550000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAFFAAAA55AAAAAA550000AA00AA00AA0000
00AAAA550000AAAAAA5500AA00AA55AA00AA0055AAAAAA000055AAAA000000AA00AA00AA
000055AAAAAA55AAAAFFAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA005500000055000000AA00AAFFAA00AA00
FFAAFFAA55AAAA00AAAAAA55550000005555AAAAAA00AAAA55AAFFAAFF00AA00AAFFAA00
AA000000550000005500AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA000000AA000000AA00005555AA00AA00AA
005500AAAAAA00AAFFFFAAAAAAAA55AAAAAAAAFFFFAA00AAAAAA005500AA00AA00AA5555
0000AA000000AA000000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAAA0000AA00AA000000005555AAAA
000000AAAA00AA00AA5500FF5500000055FF0055AA00AA00AAAA000000AAAA5555000000
00AA00AA0000AAAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00AAFF005555AAAA55AAAAAAAA00
AA00FFAAAAFF005555AAFF000000AA000000FFAA555500FFAAAAFF00AA00AAAAAAAA55AA
AA555500FFAA00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA000055AAAAAAAAFFAA5555AA5555
FF00AA5555AA0000000055AAAA55AA55AAAA5500000000AA5555AA00FF5555AA5555AAFF
AAAAAAAA550000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAFFAAAAFFFFFF55AAFFFF00
FF00AAAAAAAA00FFAA00FFFFAAFF55FFAAFFFF00AAFF00AAAAAAAA00FF00FFFFAA55FFFF
FFAAAAFFAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00550000FF00000055AA00
FF00AAAA00AAAA550000AA5500FF00FF0055AA000055AAAA00AAAA00FF00AA55000000FF
00005500AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA000000AA005555FF55AA55
AA0000550055000000AAFFFF00AA55AA00FFFFAA0000005500550000AA55AA55FF555500
AA000000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAAA00000000FFFF55
AA55AAAAAA55FF555500FF0000AAAAAA0000FF005555FF55AAAAAA55AA55FFFF00000000
AAAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00AAFF00AA0055AA
FFFF0055000000FFFF00AA55AAAAFFAAAA55AA00FFFF0000005500FFFFAA5500AA00FFAA
00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA000055AAAA000000
55AA000000AA0000FF00AAAAAAFFFFFFAAAAAA00FF0000AA000000AA55000000AAAA5500
00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAFFAAAA55AA
AAAA0000AA00AAFF0000AAAAFFFFFFFFFFAAAA0000FFAA00AA0000AAAAAA55AAAAFFAA55
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA0055000000
5500FFAA00AA00AA55AAAAFFFFFFFFFFFFFFAAAA55AA00AA00AAFF00550000005500AAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA000000AA00
0000AA5555FF00AAAAAAFFFFFFFFFFFFFFFFFFAAAAAA00FF5555AA000000AA000000AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAAA00
00AAFFFF00FF00AAAAFFFFFFFFFFFFFFFFFFFFFFAAAA00FF00FFFFAA0000AAAA55AAAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00AA
FF0055AA0000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0000AA5500FFAA00AAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000
55AAAAAA0000AA555555555555555555555555555555AA0000AAAAAA550000AAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55
AAFFAAAAFF00AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA00FFAAAAFFAA55AAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
AA00550000FFAAFFFFAAAA00AAAA00AAAA00AAAAFFFFAAFF00005500AAAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AA000000AA005500AA5555AAAA00AA00AAAA5555AA005500AA000000AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAA55AAAA000000AAAAAAAA00AAFFAA00AAAAAAAA000000AAAA55AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAA00AAFF00AAAA00AAAA555555AAAA00AAAA00FFAA00AAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAA000055AAAA00AA00AAAAAAAAAA00AA00AAAA550000AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAA55AAFFAAAA5555FFFF55FFFF5555AAAAFFAA55AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAAA005500000000FF00FF000000005500AAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAA000000AA0000AA55AA0000AA000000AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAA55AAAA0000AAAAAA0000AAAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA00AAFF005500FFAA00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA000055AAAAAA550000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA55AAFFAAFFAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAA005500AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA000000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 3.55331 0.39418 3.64062 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAA0055FFAA00AA005555AA555500AAFFAAFF55550055005500AAAAFF5555005555
55005555FFFFAA550000555555555555555555000055AAFFFF555500555555005555FFAA
AA00550055005555FFAAFFAA005555AA555500AA00AAFF5500AAAAAAFF
FFFFAAAA0000FFAAAAAA0000FF005500AA00AAFFAA005500550055AAFFFF555555550000
55005500AAFF0055005555555555555555555555005500FFAA00550055000055555555FF
FFAA550055005500AAFFAA00AA005500FF0000AAAAAAFF0000AAAAFFFF
FFFFFFAAAAAAAA5555AA55FFAA000000AAAAAAFF0055555500AA0055FF55555555555500
550055AAFFAA0000555555555555555555555555550000AAFFAA55005500555555555555
FF5500AA0055555500FFAAAAAA000000AAFF55AA5555AAAAAAAAFFFFFF
FFFFFFFFAAAA00AA5500FF00AAAAAAAAAAFFFFAA00000000FFFF55AA00FF0000FF000055
555500AAAA55550055000000000055000000000055005555AAAA005555550000FF0000FF
00AA55FFFF00000000AAFFFFAAAAAAAAAA00FF0055AA00AAAAFFFFFFFF
FFFFFFFFFFAAAAAA005555FFAAAAFFAAAA00FFAAAAAAAAAAAA55AA00AA00FFFF00AA0000
000000AAAA00550055005555005555550055550055005500AAAA0000000000AA00FFFF00
AA00AA55AAAAAAAAAAAAFF00AAAAFFAAAAFF555500AAAAAAFFFFFFFFFF
FFFFFFFFFFFFAAAA0000FF00AAAAFF0055FFAA00AAAAFFAAAA0055FFAAFF5555FFAAAAAA
AAAAAAAA00AA0055555500005555555555000055555500AA00AAAAAAAAAAAAAAFF5555FF
AAFF5500AAAAFFAAAA00AAFF5500FFAAAA00FF0000AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAAA55FFFFAA0000FFAAFF5500FFAAAA0000FFAAAA5500AAFFFFAA
AA00AAAAFF55005500005555000000000055550000550055FFAAAA00AAAAFFFFAA0055AA
AAFF0000AAAAFF0055FFAAFF0000AAFFFF55AAAAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA00AA55AAAAFF55AAAA00FF00FFAAFFFF00FFAAAA005555AAAA55
55AAFFFF55555500AA000000FFFF00FFFF000000AA00555555FFFFAA5555AAAA555500AA
AAFF00FFFFAAFF00FF00AAAA55FFAAAA55AA00AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAA0055FF00AA5555AAFF00FFAAFF00AA00FF55005500AAAA00
5500FFAA005500AA00AA0000AAFF00FFAA0000AA00AA005500AAFF005500AAAA00550055
FF00AA00FFAAFF00FFAA5555AA00FF5500AAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA0000FFAA55555555AAAAAA5555FFAAFF5555550000AAAA00
0000AAFFAA550055FFAAAAAAAAFF00FFAAAAAAAAFF550055AAFFAA000000AAAA00005555
55FFAAFF5555AAAAAA55555555AAFF0000AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAAAAA555555555555AA55555555FF00AA550000AA00AAAA
AAAAAAFF00550055AAAA00AAAAFF00FFAAAA00AAAA55005500FFAAAAAAAAAA00AA000055
AA00FF55555555AA555555555555AAAAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA5500000055AA550000FF00AA00AA55FFAAAAAA00
AAAAFFAA000000AA5555AAFFAAFF00FFAAFFAA5555AA000000AAFFAAAA00AAAAAAFF55AA
00AA00FF000055AA5500000055AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA0055550055AA55005555FFAAFF5500AAFFFF5500
55FF00AAAAAAAAAA005500FFAAFF00FFAAFF005500AAAAAAAAAA00FF550055FFFFAA0055
FFAAFF55550055AA5500555500AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000FF00FF0055005500AAFFAA005555AAAA5500
55AAAAAAFFFFAAAA00005555FF00AA00FF55550000AAAAFFFFAAAAAA550055AAAA555500
AAFFAA0055005500FF00FF0000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA55FF55AA000000AAAA5555000055FF0000
AA5555AA55AAAA00AA0000FF00AA00AA00FF0000AA00AAAA55AA5555AA0000FF55000055
55AAAA000000AA55FF55AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA55AA00AA0000AAAA005500555555FFAA
55555555AA00AAAAAA0000AAFF550055FFAA0000AAAAAA00AA55555555AAFF5555550055
00AAAA0000AA00AA55AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA0055FFAAAAAAAA00AA005555555555FF
00005500AAAAAAFFAAAAAAAA00FF00FF00AAAAAAAAFFAAAAAA00550000FF555555555500
AA00AAAAAAAAFF5500AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000FFAAAA00AAAAAA0000000000FF00
AA000000AAAAFFFFFFAAAAFFFF00AA00FFFFAAAAFFFFFFAAAA000000AA00FF0000000000
AAAAAA00AAAAFF0000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA5555AAFFFF55005555005555FF
AAAAAAAAAAFFFFFFFFFFAAFF00AA00AA00FFAAFFFFFFFFFFAAAAAAAAAAFF555500555500
55FFFFAA5555AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA5500FFAA00555555550000FF
AAAA00AAAAFF00AAFF00AAAA55FF00FF55AAAA00FFAA00FFAAAA00AAAAFF000055555555
00AAFF0055AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA005555FF00FF0000FF00FFFF
FF550055FF00AA00AAFF5500FF00AA00FF0055FFAA00AA00FF550055FFFFFF00FF0000FF
00FF555500AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000FF00AA00FFFF00AA00FF
AA00555555FFAAAAAAFF0000AAFF55FFAA0000FFAAAAAAFF55555500AAFF00AA00FFFF00
AA00FF0000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA55FFFF00AAFF55FFAA
00AA005500AAFFAAFFFFFF00FF555555FF00FFFFFFAAFFAA005500AA00AAFF55FFAA00FF
FF55AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA55AAAAAA00FF00AA
AAAA00005555AAAAFF00AAFF5555555555FFAA00FFAAAA55550000AAAAAA00FF00AAAAAA
55AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA0055FF005555FFAA
AA00AA000055AA5555FFAAFF0000550000FFAAFF5555AA550000AA00AAAAFF555500FF55
00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000FFAA5500AAFF
AAAAAA0000AA55555555FF00AA000000AA00FF55555555AA0000AAAAAAFFAA0055AAFF00
00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA55555500FF
AAFFAAAAAAAA005500AA55AAFFFF00FFFFAA55AA005500AAAAAAAAFFAAFF00555555AAAA
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA550000AA
FFAA00AAAA00AA005555AA00AAFF00FFAA00AA555500AA00AAAA00AAFFAA000055AA00AA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00555500
FFAAAAAAFFAA5555000055FFAAFF00FFAAFF5500005555AAFFAAAAAAFF00555500AAAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000FF00
FFAAAAFFAA00AA5500555555FF00AA00FF5555550055AA00AAFFAAAAFF00FF0000AAAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA55
FF55FF00AAAAAA005555555555FFAAFF555555555500AAAAAA00FF55FF55AAAAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA
55AA00FFFFAAAA000000005500AAFFAA005500000000AAAAFFFF00AA55AA00AAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA
0055FFAA00FF5500555500550055FF5500550055550055FF00AAFF5500AAAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
0000FFAAAAAA550055AA000000AA55AA000000AA550055AAAAAAFF0000AAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAAAAA5555AA550055AA55FFAA555555AAFF55AA550055AA5555AAAAAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAA00AA5500FF00FF0055AAAA005500AAAA5500FF00FF0055AA00AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAA005555FFAA0000FF5500550055FF0000AAFF555500AAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAA0000FF00AAAAAAAA5500550055AAAAAAAA00FF0000AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAAAAAA55FFFFAAAA0055555500AAAAFFFF55AAAAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAA00AA55AAAA00AA005500AA00AAAA55AA00AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAA0055FFFF0055555500FFFF5500AAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAA0000FFAA0000550000AAFF0000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAAA55550055005555AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA00AA5500550055AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAA0055555500AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA0000000000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 3.55331 0.588183 3.64062 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAAAAAFFFFAAAAFF555555FFAAAAAAFF00FF55FF00AAAAAAAAAAAAAA5555005555
55FF00AA0055AA55555500FFFFAAFFAAFFFF00555555AA5500AA00FF555555005555AAAA
AAAAAAAAAA00FF55FF00FFAAAAAAFF555555FFAAAAFFFFAAAAAAAAAAFF
FFFFAAAAFFFF5555FFFFAA00AAAA00FF0000FFAA55AA55AAFFAAAAFFAAFFAAAA00005555
AA55AAFFFF0055AA5555AAFF00AA55AA00FFAA5555AA5500FFFFAA55AA55550000AAAAFF
AAFFAAAAFFAA55AA55AAFF0000FF00AAAA00AAFFFF5555FFFFAAAAFFFF
FFFFFFAAAA55AA5555FF55FFAAFFAA55AAFF555555AA0000FFAAFFFFFFAA0055AAFF5500
FF0055AAAA55FF00000000FFAA550055AAFF00000000FF55AAAA5500FF0055FFAA5500AA
FFFFFFAAFF0000AA555555FFAA55AAFFAAFF55FF5555AA55AAAAFFFFFF
FFFFFFFFAAAA005555AAAA00FF00AA555555FF0055FFFF00FFAAFF00AAFFAA555555FF00
FFAA55555555AAAAAAAAAAAA5500550055AAAAAAAAAAAA55555555AAFF00FF555555AAFF
AA00FFAAFF00FFFF5500FF555555AA00FF00AAAA555500AAAAFFFFFFFF
FFFFFFFFFFAAAAAA0000FF00FFAA55005555AAAAAA00FFAA55AA00FFFF555555005555FF
AA005555005555555555555555000000555555555555555500555500AAFF555500555555
FFFF00AA55AAFF00AAAAAA55550055AAFF00FF0000AAAAAAFFFFFFFFFF
FFFFFFFFFFFFAAAAFF55AAAAAA5500550055FFFFAAAAAA5500FF00FFAA0000AAAAAA00AA
FFAA55550000000000000000AAAAAAAAAA00000000000000005555AAFFAA00AAAAAA0000
AAFF00FF0055AAAAAAFFFF5500550055AAAAAA55FFAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA555555555500000055FF5555555555AAFF00FFAAAAAAAAFFAAAAAA
FF0000AAAAAAAAAAAAAAAAAAAAFFAAFFAAAAAAAAAAAAAAAAAAAA0000FFAAAAAAFFAAAAAA
AAFF00FFAA5555555555FF550000005555555555AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA000000AAAAAAAAAA00FF5500555500AAFF555555555555FFFFAA
FF00FFFFAAFFFFAAFFFFAAFFFF555555FFFFAAFFFFAAFFFFAAFFFF00FFAAFFFF55555555
5555FFAA0055550055FF00AAAAAAAAAA000000AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAAAAAAFFFFAAAAFF55550000000055AAAA00AAAA00AA00FFAA
AA55FF555555FF55FF555555FF550055FF555555FF55FF555555FF55AAAAFF00AA00AAAA
00AAAA55000000005555FFAAAAFFFFAAAAAAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAFFFF5555FFFFAA00AAAAAAAAAAAA0055AAFFAAAAAAFF5555
5555AAAA00AA00FF5555AA5555FF00FF5555AA5555FF00AA00AAAA55555555FFAAAAAAFF
AA5500AAAAAAAAAAAA00AAFFFF5555FFFFAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA55AA5555FF55FFAAFFAAFFAAFFFF0055AAAAFFFFAA0000
00AA0055AAFFFF00AAAA005555AAAAAA555500AAAA00FFFFAA5500AA000000AAFFFFAAAA
5500FFFFAAFFAAFFAAFF55FF5555AA55AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA005555AAAA00FF00AA55AA00FFAA55555555FF55FFAA
55FFFF0055AAAA55FFFF55AA5555555555AA55FFFF55AAAA5500FFFF55AAFF55FF555555
55AAFF00AA55AA00FF00AAAA555500AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA0000FF00FFAA550055AAFF00000000AA00FF5555
55AAAA55FF0000FF5555FF00000000000000FF5555FF0000FF55AAAA555555FF00AA0000
0000FFAA550055AAFF00FF0000AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55AAAAAA5500550055AAAAAAAAAAAAFF5555AA
55555555AAAAAAAA5555AAAAAAAAAAAAAAAAAA5555AAAAAAAA55555555AA5555FFAAAAAA
AAAAAA5500550055AAAAAA55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA555555555500000055FFFFAAFFFF55FF550055
AA55550055AA0055AA5555555555555555555555AA5500AA55005555AA550055FF55FFFF
AAFFFF550000005555555555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA000000AAAAAAAAAA00FFAAFF00AA00FF55AA
5500FF55AA550000AA5555AA5555005555AA5555AA000055AA55FF0055AA55FF00AA00FF
AAFF00AAAAAAAAAA000000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAFFFFAAAAFF555555FFAAFF555500
AAAAAA555555000055AA555555005500555555AA550000555555AAAAAA005555FFAAFF55
5555FFAAAAFFFFAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFF5555FFFFAA00AA00AAFFAA00AAAA
AAFFAAAA00AAAAAAAA0055550055005500555500AAAAAAAA00AAAAFFAAAAAA00AAFFAA00
AA00AAFFFF5555FFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AA5555FF55FFAAFF55FF55FFAAAA
FFFFFFAAAAAAFFAAAAFF550055005500550055FFAAAAFFAAAAAAFFFFFFAAAAFF55FF55FF
AAFF55FF5555AA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA005555AAAA00FF00AAAA5555FFFF
AA00FFAAFFFF55555555FF00FF55AA55FF00FF55555555FFFFAAFF00AAFFFF5555AAAA00
FF00AAAA555500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA0000FF00FFAA5500AAAA00FF
AAFF555555FF55005555AAAAAA555555AAAAAA55550055FF555555FFAAFF00AAAA0055AA
FF00FF0000AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55AAAAAA55005500AA55FF
55FF550055FF5500000000FF0000AA0000FF0000000055FF550055FF55FF55AA00550055
AAAAAA55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA555555555500000055AA55
AA55AA55FF00AAAAAAAAAAAA55FFAAFF55AAAAAAAAAAAA00FF55AA55AA55AA5500000055
55555555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA000000AAAAAAAAAA0055
555500AA00FFFFAAAAFFFFAAAA00FF00AAAAFFFFAAAAFFFF00AA0055555500AAAAAAAAAA
000000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAFFFFAAAAFF55
0055FFAAFF5555FFFF5555FFFFAA55AAFFFF5555FFFF5555FFAAFF550055FFAAAAFFFFAA
AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFF5555FFFFAA00
0055FF55FF5500FFAA0000AAFF000000FFAA0000AAFF0055FF55FF550000AAFFFF5555FF
FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AA5555FF55FF
AA5555FF00AAAAAA55000055AAAAAAAAAA55000055AAAAAA00FF5555AAFF55FF5555AA55
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA005555AAAA00
FF005555FFAAFFFF55000055555555555555000055FFFFAAFF555500FF00AAAA555500AA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA0000FF00
FFAA5555AAAAFF00AAAAAAAA0000000000AAAAAAAA00FFAAAA5555AAFF00FF0000AAAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55AAAA
AA550055555555FFAAAAFFAAAAAAAAAAAAAAFFAAAAFF555555550055AAAAAA55FFAAAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA555555
55550000000000AAFFFF555555555555555555FFFFAA00000000005555555555AAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0000
00AAAAAAAAAAAAAAFF00AA00000000000000AA00FFAAAAAAAAAAAAAA000000AAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA
AAAAFFFFAAFFAAAAFF00FF00FFFF00FFFF00FF00FFAAAAFFAAFFFFAAAAAAAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
FFFF5555FFFFFFAAFF00FFAA55AAAAAA55AAFF00FFAAFFFFFF5555FFFFAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AA55AA5555FF555555FFAA00555555555500AAFF555555FF5555AA55AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAA005555AAAA0000AAFFAA5555005555AAFFAA0000AAAA555500AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAA0000FF00FFFF555555005500555555FFFF00FF0000AAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAFF55AAAAAA55AA55550000005555AA55AAAAAA55FFAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAA555555555500AA0000550000AA005555555555AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAA000000AAAAAAFF55AA55FFAAAAAA000000AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAAAAAAFFAAAA555555AAAAFFAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAAFFFF555555550055555555FFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA55AA55550055005555AA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA005555000000555500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAA0000550000AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAFF55AA55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA555555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 3.55331 0.782187 3.64062 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAFF55555500AA0000FFFF555555FF55FFFF55FF5555FFAA55000000AAAA005555
AAAAAAAA55FF00AAFF5555FF00FFAAFF00FF5555FFAA00FF55AAAAAAAA555500AAAA0000
0055AAFF5555FF55FFFF55FF555555FFFF0000AA00555555FFAAAAAAFF
FFFFAAAAFF005555AAFFFF0000550055550000AAFF00550055FF55FF0000FFFFAAAAAA00
0000000000AAFF55FF55005500AAFFAA00550055FF55FFAA000000000000AAAAAAFFFF00
00FF55FF55005500FFAA0000555500550000FFFFAA555500FFAAAAFFFF
FFFFFFAAAA5500FF55FF5555555500AA0000FFFFAA00555555AAAA00FFFF00AAFFFFAAFF
55AAFF55AAFFAA0000555555AAFFFFFFAA5555550000AAFFAA55FFAA55FFAAFFFFAA00FF
FF00AAAA55555500AAFFFF0000AA0055555555FF55FF0055AAAAFFFFFF
FFFFFFFFAAAA0055005500FF5500FFFF55AA00FFAAFF550055FFFF55AAAA55FFFFFFFFAA
00000055FFFFFF55AA00AA00000055000000AA00AA55FFFFFF55000000AAFFFFFFFF55AA
AA55FFFF550055FFAAFF00AA55FFFF0055FF0055005500AAAAFFFFFFFF
FFFFFFFFFFAAAAAA00555555FF00FFAA000000FFAAAA555555000055FFFF550000550000
00FF0000AAFF00AAAAFF55FFAA550055AAFF55FFAAAA00FFAA0000FF00000055000055FF
FF550000555555AAAAFF000000AAFF00FF55555500AAAAAAFFFFFFFFFF
FFFFFFFFFFFFAAAAFF5500FF555555FFFF00FFFFFF55FF0055555555AAAA55555555AAFF
55AAAAAAAAFF0000000055FF55FF00FF55FF5500000000FFAAAAAAAA55FFAA55555555AA
AA5555555500FF55FFFFFF00FFFF555555FF0055FFAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA555555FF0055FF555555FF5555AAAAAA00AA00000000AAAA000000
55FFFFAAAAFF0000FF00FF5555AAAAAA5555FF00FF0000FFAAAAFFFF55000000AAAA0000
0000AA00AAAAAA5555FF555555FF5500FF555555AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA00AA00FF00550055550000AAAAFFAAFF55FFAA55FFAAFFFF0000
FF5555FFFF55555555FFAA00AAAAFFAAAA00AAFF55555555FFFF5555FF0000FFFFAAFF55
AAFF55FFAAFFAAAA00005555005500FF00AA00AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAAFF55555500AA0000FFFF55FF55FF55000000AAFFFFFFFF00
005555000055550055FF55FFAAFFFFFFAAFF55FF55005555000055550000FFFFFFFFAA00
000055FF55FF55FFFF0000AA00555555FFAAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAFF005555AAFFFF0000550055005500FF00FFFF5555FF5555
555500FFFF005555550000AAFFFFFFFFFFAA000055555500FFFF0055555555FF5555FFFF
00FF0055005500550000FFFFAA555500FFAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA5500FF55FF5555555500AA00555555FFAA00FF550000AA
AA0000FFAA0055550055AAFFFFFFFFFFFFFFAA5500555500AAFF0000AAAA000055FF00AA
FF55555500AA0055555555FF55FF0055AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA0055005500FF5500FFFF55AA5555AAAAFF5555AAFF55
FFFF00FFAAAAAA0000FF55FF5555FF5555FF55FF0000AAAAAAFF00FFFF55FFAA5555FFAA
AA5555AA55FFFF0055FF0055005500AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00555555FF00FFAA000000AAAAFFAA00AAAAFF00
550000FFAAFFAAAAAAAA5555FF005500FF5555AAAAAAAAFFAAFF00005500FFAAAA00AAFF
AAAA000000AAFF00FF55555500AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF5500FF555555FFFF00FFFF55FF55FFAAFFAA00
55555555FFFFFF55FFFF55005500AA00550055FFFF55FFFFFF5555555500AAFFAAFF55FF
55FFFF00FFFF555555FF0055FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA555555FF0055FF555555FF550000AAFFFFFFAA
555500FF5555FF550000555555AAFFAA555555000055FF5555FF005555AAFFFFFFAA0000
55FF555555FF5500FF555555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA00FF00550055550000AA55FFFFFFFFFF
5500FF00AA0000555555550055FFFFFF5500555555550000AA00FF0055FFFFFFFFFF55AA
00005555005500FF00AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF55555500AA0000FFFF550000550000
555555FFAAAAAAAA0000AA005555FF555500AA0000AAAAAAAAFF555555000055000055FF
FF0000AA00555555FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF005555AAFFFF0000550055AA00AA55
005555AAAAFFFFAAAAAAAAFF5500550055FFAAAAAAAAFFFFAAAA55550055AA00AA550055
0000FFFFAA555500FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500FF55FF5555555500AAAAFF55FF
0000AAAAFFFFFFFF55FFFF555500AA005555FFFF55FFFFFFFFAAAA0000FF55FFAAAA0055
555555FF55FF0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055005500FF5500FFFF55FF5500
00FFFF55FF5555FF55000055FF000000FF55000055FF5555FF55FFFF000055FF55FFFF00
55FF0055005500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00555555FF00FFAA00005555
5555FF550000AAAA55555555AAAAAAAAAA55555555AAAA000055FF555555550000AAFF00
FF55555500AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF5500FF555555FFFF00FF55
005555FF00FFFFAAAA00AA00000000000000AA00AAAAFFFF00FF55550055FF00FFFF5555
55FF0055FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA555555FF0055FF555555FF
0000AA00FFFFFFFF55FFAAAAAAAAAAAAAAAAAAFF55FFFFFFFF00AA0000FF555555FF5500
FF555555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA00FF0055005555AA
AAAAAAFF5555FF555500000000000000000000005555FF5555FFAAAAAAAA5555005500FF
00AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF55555500AA0000
000000005555AAAA0000FF0000FF00FF0000FF0000AAAA5555000000000000AA00555555
FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF005555AAFFFF00
00FF00FF0055FFFFAA55FF55AAFF00FFAA55FF55AAFFFF5500FF00FF0000FFFFAA555500
FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500FF55FF5555
5555FFAA005555FF55FF00AAAAFF00FFAAAA00FF55FF555500AAFF55555555FF55FF0055
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055005500FF
5500FFAAAAAA00005555FFAAAAFF00FFAAAAFF55550000AAAAAAFF0055FF0055005500AA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00555555
FF00FFAAFFAAAAAAAA00AAFFFF555555FFFFAA00AAAAAAAAFFAAFF00FF55555500AAAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF5500FF
555555FFFFFFAAFFAAFF55FF5555005555FF55FFAAFFAAFFFFFF555555FF0055FFAAAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA555555
FF0055FF5555FFFFFF55550000AAAAAA00005555FFFFFF5555FF5500FF555555AAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA
00FF0055005555FF55550055AAFFAAFFAA55005555FF5555005500FF00AA00AAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA
FF55555500AA000055FF00FF55FF55FF55FF00FF550000AA00555555FFAAAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
FF005555AAFFFF00FF555555FF00AA00FF555555FF00FFFFAA555500FFAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AA5500FF55FF555555FF005555FFAAFF555500FF555555FF55FF0055AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAA0055005500FF550000FF5500000055FF000055FF0055005500AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAA00555555FF00FF00AAAAAAAAAA00FF00FF55555500AAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAFF5500FF555555FFAAFFAAFFAAFF555555FF0055FFAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAA555555FF0055FF55FF55FF55FF5500FF555555AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAA00AA00FF005500550055005500FF00AA00AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAAFF55555500AAAAAA00555555FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAAFF005555AAFFAAFFAA555500FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA5500FF55FF55FF55FF0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA005500550055005500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAA0055555500AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAFF550055FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA555555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 3.55331 0.97619 3.64062 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAA55AA555555AA0000FFFF55FF5500005555FF5500005500AA5555550055AA0000
000000005555FF005500000055000000550000005500FF5555000000000000AA55005555
55AA0055000055FF5555000055FF55FFFF0000AA555555AA55AAAAAAFF
FFFFAAAA5555FF0055FFFF0000AA00AA00AA55FF005555AA0055FFAA00AAAA0055FFFF00
FF00FF0000550055AA5500AA5555555555AA0055AA5500550000FF00FF00FFFF5500AAAA
00AAFF5500AA555500FF55AA00AA00AA0000FFFF5500FF5555AAAAFFFF
FFFFFFAAAA00AA00550055555555FFAAAAAA555500AAAA00FF005555FFAAAAFF55005555
5500AA0055AA55FF00AAAAAA5555AA5555AAAAAA00FF55AA5500AA005555550055FFAAAA
FF555500FF00AAAA005555AAAAAAFF55555555005500AA00AAAAFFFFFF
FFFFFFFFAAAAAA550000FF5500005555FF5555AA55FF55555500AAAA00000000AAAAAA00
AAAAAA55000000555555FFFF5500000055FFFF55555500000055AAAAAA00AAAAAA000000
00AAAA00555555FF55AA5555FF5555000055FF000055AAAAAAFFFFFFFF
FFFFFFFFFFAAAA5555555500FF00FF5500550000005555AA555555FF55AA0055AAAAFF00
0000000055AAFF55000055550000FF00005555000055FFAA550000000000FFAAAA5500AA
55FF555555AA5555000000550055FF00FF0055555555AAAAFFFFFFFFFF
FFFFFFFFFFFFAAAA00AAAA0055555500FF0055AA0055000000550000AAAA5500000000AA
55FFAA55000000AAAAAAAA00AA550055AA00AAAAAAAA00000055AAFF55AA0000000055AA
AA0000550000005500AA5500FF0055555500AAAA00AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA55AA00AAAA00555555AAAAAA0055AA00AA55FF55FF0000FF0000
005555FF0000FFFF55FF555555FF00FF555555FF55FFFF0000FF5555000000FF0000FF55
FF55AA00AA5500AAAAAA55555500AAAA00AA55AAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA5555FFAA00FF00550000000000FF55FFAAAA00005555555500AA
5500005555555500550055FF0055555500FF5500550055555555000055AA005555555500
00AAAAFF55FF00000000005500FF00AAFF5555AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA00AA00FFFFFF0055AA0055AA00005555FFFF000055000055AA
AA0055AA5555AA5500FF00555555AA55555500FF0055AA5555AA5500AAAA550000550000
FFFF55550000AA5500AA5500FFFFFF00AA00AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAA5500555500AAAA55FF00AA550000555500AA55555555AA
AA5500000055FF5500AA005500FF55FF005500AA0055FF5500000055AAAA55555555AA00
5555000055AA00FF55AAAA0055550055AAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA555555AA55FFFF550055AAAA0055AA555555FF00550000
000055AAFF550055FFAA005500AA00AA005500AAFF550055FFAA55000000005500FF5555
55AA5500AAAA550055FFFF55AA555555AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAA5555005500AAAAFFAA5555FF00550055AA5500
AA55000000AAAAAA000000FF55AAAAAA55FF000000AAAAAA00000055AA0055AA55005500
FF5555AAFFAAAA0055005555AAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55AA555555AAFFAA000000550055AA5500000055
AAAA0055AAFFFF555555555500000000005555555555FFFFAA5500AAAA5500000055AA55
0055000000AAFFAA555555AA55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555FF0055FFFFFF55AA005500AAAA5555555555
AAAA55000000AA00AAAA00AAAAAAAAAAAAAA00AAAA00AA00000055AAAA5555555555AAAA
005500AA55FFFFFF5500FF5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA0055005555000000FF55AAAA5555AA5555
AAAA5555555555FFAAAA55FF55FF55FF55FF55AAAAFF5555555555AAAA5555AA5555AAAA
55FF0000005555005500AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA550000FF5500AA550055FFFF5500000055
FF55FF005500005555FF550055005500550055FF555500005500FF55FF5500000055FFFF
550055AA0055FF000055AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555555500FF00AAAAAA0000AAAAAAAAAA
0000555555AA00550000AAAAAA005500AAAAAA00005500AA5555550000AAAAAAAAAA0000
AAAAAA00FF0055555555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAA00555555FF55555555FFFF55FF
FF00FF5500FFAA55555555FFFF55AA55FFFF55555555AAFF0055FF00FFFF55FFFF555555
55FF55555500AAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55AA00AAAA000055000055550000
AA005555AA00000055000055550000005555000055000000AA555500AA00005555000055
0000AAAA00AA55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555FFAA00FF000055AA00AAAAAA
AAFF55000000FF000055AA00AAAAAAAAAA00AA550000FF00000055FFAAAAAAAA00AA5500
00FF00AAFF5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA00FFFFFF00FF555555FFFF
555500FF00FFFFFF00FF55FFAAAAFFAAAAFF55FF00FFFFFF00FF005555FFFF555555FF00
FFFFFF00AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA5500555500AA00AAAA0000
AAAA00555555005555550000AAFFFFFFAA00005555550055555500AAAA0000AAAA00AA00
55550055AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA555555AA55FF55AAAAFF55
AAAA55FF005500AAAA00AA55FFFFFFFFFF55AA00AAAA005500FF55AAAA55FFAAAA55FF55
AA555555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAA555500000000AA
AAFF00555555AAFFFF55AAAA0000AA0000AAAA55FFFFAA55555500FFAAAA000000005555
AAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55AA555555555555
FFFFFF0055000000AA00AAFFAA55FF55AAFFAA00AA0000005500FFFFFF555555555555AA
55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555FF0055FF0055
00555500AAAAAAAAAA55FFFFFF550055FFFFFF55AAAAAAAAAA005555005500FF5500FF55
55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA00550055AA
5500FF55AAAAFFFFAA00AA0000AAAAAA0000AA00AAFFFFAAAA55FF0055AA55005500AA00
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA550000FF55
FF0000AAAAFFFFFFFF55AAAAAAAAFFAAAAAAAA55FFFFFFFFAAAA0000FF55FF000055AAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555555500
00AA55FF555500555500FFAAAAFFFFFFAAAAFF005555005555FF55AA000055555555AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAA00
55AAAA00005500AAAA005555FFFFFFFFFF555500AAAA00550000AAAA5500AAAA00AAAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55AA
00AAFFFF000055AAAA5500005555005555000055AAAA550000FFFFAA00AA55AAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555
FFAA0000AA550000000055AA00AAAAAA00AA550000000055AA0000AAFF5555AAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00
AA00FFFF00AAAAAAAAAAAA00FFFF55FFFF00AAAAAAAAAAAA00FFFF00AA00AAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
AA5500555555FFFF55FF555555005500555555FF55FFFF5555550055AAAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AA555555AA55550055005500FF55AA55FF00550055005555AA555555AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAA00AAAA5555AA00AA555555000000555555AA00AA5555AAAA00AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAA55AA5555FFAAAA00AAAAAAAAAA00AAAAFF5555AA55AAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAA5555FF005555FF55AAAAFFAAAA55FF555500FF5555AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAA00AA00550000AAAAFFFFFFAAAA00005500AA00AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAAA550000FFFF5555005555FFFF000055AAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAA55555555005500FF00550055555555AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAA00AAAA005500AA005500AAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA55AA00AA55AA00AA55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA5555FFAA00AAFF5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA00AA00FF00AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAA550055AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA555555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 3.64935 0.200176 3.73666 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAFFFFFF5555FF00AAAAAA555555AAAAAAFF00FF00FFFF0000FF55FF55FFFFFFFF
FFFF0000FF0055FFFFFFAAFFFFFFAAFFFFFFAAFFFFFF5500FF0000FFFFFFFFFFFF55FF55
FF0000FFFF00FF00FFAAAAAA555555AAAAAA00FF5555FFFFFFAAAAAAFF
FFFFAAAAFF0000FFFF00AAAAFFAAFF55AAFFFFAAAA555555AAAA5555AAAAAA55FF555555
555555AA5500FFFFFFFFFF5555FF55FF5555FFFFFFFFFF0055AA555555555555FF55AAAA
AA5555AAAA555555AAAAFFFFAA55FFAAFFAAAA00FFFF0000FFAAAAFFFF
FFFFFFAAAA5555AAAA555500000055AAFFFFFFFFAAFF55AAFFAAAAAAAAFFFF55AAAAAAAA
AAAAAAAAFF5500AAFF00AAFF55AAAAAA55FFAA00FFAA0055FFAAAAAAAAAAAAAAAA55FFFF
AAAAAAAAFFAA55FFAAFFFFFFFFAA550000005555AAAA5555AAAAFFFFFF
FFFFFFFFAAAAAAAAFFAA55FF0055FFAAFF0000000055AAFFFFFFAAFFFF5555FFAAFFAAAA
FFAAFFAAFF00FF55FF550000FFFF55FFFF000055FF55FF00FFAAFFAAFFAAAAFFAAFF5555
FFFFAAFFFFFFAA5500000000FFAAFF5500FF55AAFFAAAAAAAAFFFFFFFF
FFFFFFFFFFAAAAFFFFFFAA5500FFFFFF5555AA5555AAFFFFFFFFFF5555FFAA5500000055
55FFFFFF5555AAAAAA55FF0055AAAAAA5500FF55AAAAAA5555FFFFFF555500000055AAFF
5555FFFFFFFFFFAA5555AA5555FFFFFF0055AAFFFFFFAAAAFFFFFFFFFF
FFFFFFFFFFFFAAAA55AAAAFF5500AAFF00FFFF55AAFFFFFFFFFFFFFF00FFAAAAAA00AAAA
AAAA55AAAAAAAAFFFFAA5500FFFF55FFFF0055AAFFFFAAAAAAAA55AAAAAAAA00AAAAAAFF
00FFFFFFFFFFFFFFAA55FFFF00FFAA0055FFAAAA55AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAFFFFFF00555555AA00FFFF555555FF5555FF5500AA0000AAAAFF
FFAAAAAAFFAAFFFFFFFF55AA55AAAAAA55AA55FFFFFFFFAAFFAAAAAAFFFFAAAA0000AA00
55FF5555FF555555FFFF00AA55555500FFFFFFAAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAFF0000FF55AAFF55FF0000FFFF00FF00FFFFFF005500FF55FFFF
FFFFAAFFFFFF55555555FFAAAAAAFFAAAAAAFF55555555FFFFFFAAFFFFFFFF55FF005500
FFFFFF00FF00FFFF0000FF55FFAA55FF0000FFAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA5555AAAAAAFF00FF0055FF5555AAAA00FF00AAAAAA00FFFFFF
FFFFFFAA00FF00FFFF00FFAAAAFFFFFFAAAAFF00FFFF00FF00AAFFFFFFFFFFFF00AAAAAA
00FF00AAAA5555FF5500FF00FFAAAAAA5555AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAAAAFFAAAA5555FF00FF00FFFFAAAA0055FFFFAAAA00FF00
0000FFAAAA00FF555555AAAAFFFFFFFFFFAAAA555555FF00AAAAFF000000FF00AAAAFFFF
5500AAAAFFFF00FF00FF5555AAAAFFAAAAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFFFFFFAAAAAAAA5555FF0000005555AAFF00005500FF00
55FF00005555AAAAAAAAAAFFFFFFFFFFFFFFAAAAAAAAAA55550000FF5500FF00550000FF
AA5555000000FF5555AAAAAAAAFFFFFFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAAAFFAAFFFF00FF0055FF00FFFF5555AA55FF00AA
AAAA5555AAFF55FFFF55FFFFFFFFFFFFFFFFFF55FFFF55FFAA5555AAAAAA00FF55AA5555
FFFF00FF5500FF00FFFFAAFFAAAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFF5555FF00AAAAAA5555FF55AAFFFF00AAAA
FFFFAA55FFFFFF0000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF55AAFFFFAAAA00FFFFAA55
FF5555AAAAAA00FF5555FFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF0000FFFF00AAAAFFAAFF55AAAAAAFF00AAAAFF
FFFFFF55AAAA55AA55555555555555555555555555AA55AAAA55FFFFFFFFAAAA00FFAAAA
AA55FFAAFFAAAA00FFFF0000FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555AAAA555500000055AAFFFFAAFF00550000
FF0000FFFF55FFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFF55FFFF0000FF00005500FFAAFF
FFAA550000005555AAAA5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAFFAA55FF0055FFAAFF000055AA55FF00
55AA5555FF55AAAAFFFF55FFFFAAFFAAFFFF55FFFFAAAA55FF5555AA5500FF55AA550000
FFAAFF5500FF55AAFFAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFFFFAA5500FFFFFF5555AA55FFFF00AA
AAAAFF55AAAAAAFFFFFFFF00AAFFFFFFAA00FFFFFFFFAAAAAA55FFAAAAAA00FFFF55AA55
55FFFFFF0055AAFFFFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAAAFF5500AAFF00FFFF55AAAA5555
000055AAFFAAAAFF00AAFF00555555555500FFAA00FFAAAAFFAA5500005555AAAA55FFFF
00FFAA0055FFAAAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFF00555555AA00FFFF55FFAA
5555AAFFFFFFAAAA555500AAAAAAAAAAAAAA005555AAAAFFFFFFAA5555AAFF55FFFF00AA
55555500FFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF0000FF55AAFF55FF0000FFFFFF
55AAFFFFFFFFFFAAAAAAAA00005500550000AAAAAAAAFFFFFFFFFFAA55FFFFFF0000FF55
FFAA55FF0000FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555AAAAAAFF00FF0055FF5555
FFAAAA55AAAA550000555500FF55AA55FF005555000055AAAA55AAAAFF5555FF5500FF00
FFAAAAAA5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAFFAAAA5555FF00FF00FF
FFFF55FFAAAAFF5500FFFF0055AAFFAA5500FFFF0055FFAAAAFF55FFFFFF00FF00FF5555
AAAAFFAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFFFFAAAAAAAA5555FF00
AAFF00FFAAAAFF00FF555555AAFFFFFFAA555555FF00FFAAAAFF00FFAA00FF5555AAAAAA
AAFFFFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAAAFFAAFFFF00FF00
555555AAAAFFAA00AAFF55AAFFFFFFFFFFAA55FFAA00AAFFAAAA55555500FF00FFFFAAFF
AAAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFF5555FF00AA
AAAAAAAAFFFFFF550055AAFFFFFFFFFFFFFFAA550055FFFFFFAAAAAAAAAA00FF5555FFFF
FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF0000FFFF00AAAA
FFAAFFFF5555FF55AA55FFFFFFFFFFFFFFFFFF55AA55FF5555FFFFAAFFAAAA00FFFF0000
FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555AAAA555500
000055AAAAAAAA55FFFF0000FF000000FF0000FFFF55AAAAAAAA550000005555AAAA5555
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAFFAA55FF
0055FFAAFFFFAAAAAA55AA555555AA555555AA55AAAAAAFFFFAAFF5500FF55AAFFAAAAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFFFFAA55
00FFFFFF5555FFFF55FFAAFF55AAFFAA55FFAAFF55FFFF5555FFFFFF0055AAFFFFFFAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAAAFF
5500AAFF00FFFFFFFF0000AA55FFFFFF55AA0000FFFFFFFF00FFAA0055FFAAAA55AAAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFF
FF00555555AA00FFAA00AAAAFF555555FFAAAA00AAFF00AA55555500FFFFFFAAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00
00FF55AAFF55FF0000AAAAFFFFFF00FFFFFFAAAA0000FF55FFAA55FF0000FFAAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55
55AAAAAAFF00FF0055FFFFAA0055AA5500AAFFFF5500FF00FFAAAAAA5555AAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
AAAAFFAAAA5555FF00FF000055FFAAFF550000FF00FF5555AAAAFFAAAAAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAFFFFFFAAAAAAAA555555AA55FF55FF55AA555555AAAAAAAAFFFFFFAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAA55AAAAFFAAFFFF00FFFF55AAAAAA55FFFF00FFFFAAFFAAAA55AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAAFFFFFF5555FF0000FFFFAAFFFF0000FF5555FFFFFFAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAFF0000FFFF00AAAA00FFAAFF00AAAA00FFFF0000FFAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAA5555AAAA55550055FF55FF55005555AAAA5555AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAAAAAFFAA55FF00FF00FF00FF55AAFFAAAAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAFFFFFFAA55AA55AA55AA55AAFFFFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAA55AAAAFF55FFAAFF55FFAAAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAFFFFFF00AA00FFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAFF0000FF55FF0000FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA5555AAAAAA5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAAAAFFAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFFFFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 3.64935 0.39418 3.73666 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAFF00AAAA000000FFFFFF55555500AAAAFFFFFFAAFF0055555555555500FFFFAA
55FF5555AAAAAAAA00AAAA00FFFF00FFFF00AAAA00AAAAAAAA5555FF55AAFFFF00555555
55555500FFAAFFFFFFAAAA00555555FFFFFF000000AAAA00FFAAAAAAFF
FFFFAAAAFF00000000FF0000AAFF00FFFF00000000AA000000AAAAAAAAAAAAAAAA00FFAA
AAAA55FFAAAAFFFF55000055FF555555FF55000055FFFFAAAAFF55AAAAAAFF00AAAAAAAA
AAAAAAAA000000AA00000000FFFF00FFAA0000FF00000000FFAAAAFFFF
FFFFFFAAAA5555555555FF0000555555FF5500FF000000FF00550000000000005500FFAA
FFFF55AAAAFFFFFFFF0000FFFFFF00FFFFFF0000FFFFFFFFAAAA55FFFFAAFF0055000000
0000005500FF000000FF0055FF5555550000FF5555555555AAAAFFFFFF
FFFFFFFFAAAAAAAAAAAAAA5500FFFF00FFAA555500FF0000AAAAAA0055AA00AAAAAA0000
5555FFAAAAFF00AAFF0000FFAA00FF00AAFF0000FFAA00FFAAAAFF55550000AAAAAA00AA
5500AAAAAA0000FF005555AAFF00FFFF0055AAAAAAAAAAAAAAFFFFFFFF
FFFFFFFFFFAAAAFFFF55FFFF00555500FFAAAAAAAA00FF5500000000FFFF5500000000FF
00FFFFFFAAFF000000AAAA000055FF550000AAAA000000FFAAFFFFFF00FF0000000055FF
FF0000000055FF00AAAAAAAAFF00555500FFFF55FFFFAAAAFFFFFFFFFF
FFFFFFFFFFFFAAAA55AAFF00AAAAAAAA000055000000FFAA5500AAAA00FFAA5555555555
FF00AA00005555AA55000055AA55FF55AA55000055AA55550000AA00FF5555555555AAFF
00AAAA0055AAFF000000550000AAAAAAAA00FFAA55AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAFF000000550000FF00FF0055AAAAFF55000000FFAAAAAAAAAAAA
AA550000FF55AAFFFF0000FFFFAA55AAFFFF0000FFFFAA55FF000055AAAAAAAAAAAAAAFF
00000055FFAAAA5500FF00FF000055000000FFAAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAFF0000FF00FF0055555500FFFFAAAA55FF0055AAAAFFAAFFFFAA
FFAA5555AAAAAAFF00AAAA00FFAAAAAAFF00AAAA00FFAAAAAA5555AAFFAAFFFFAAFFAAAA
5500FF55AAAAFFFF0055555500FF00FF0000FFAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA555555FF00AAAAAAAAAA00FFAAFFFF00AAAAAAFFFFFF5555FF
FFFFAA55FFFFAAFF00550000FFAAFFAAFF00005500FFAAFFFF55AAFFFFFF5555FFFFFFAA
AAAA00FFFFAAFF00AAAAAAAAAA00FF555555AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAAAAAA55000000005500FFAAFF00AAAAFFAAAA55AAAAAAAA
55AAAAFF55550000AAAAAA00AAFFFFFFAA00AAAAAA00005555FFAAAA55AAAAAAAA55AAAA
FFAAAA00FFAAFF00550000000055AAAAAAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFFFF55AA5500AAAAAA000000AAAAFFFFFFAAAAAAFFFFAA
AAAAFFFFFF00FF0000000055FFFFFFFFFF5500000000FF00FFFFFFAAAAAAFFFFAAAAAAFF
FFFFAAAA000000AAAAAA0055AA55FFFFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAFFFF0000000055FF00000000AA00000000555500
000000AAFF005555555555AAFF00AA00FFAA555555555500FFAA00000000555500000000
AA00000000FF5500000000FFFFAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF00AAAA0055AAFF0055AA550000FF0000FFFF00
00FF000000AAAAAAAAAAAAAAFF000000FFAAAAAAAAAAAAAA000000FF0000FFFF0000FF00
0055AA5500FFAA5500AAAA00FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00000000FFFF5555AAFFAA5500AA0055AAAA55
555500FF000000000000000055555555550000000000000000FF00555555AAAA5500AA00
55AAFFAA5555FFFF00000000FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555555555FF55AAFFFFFFAA550000FFFFAAAA
AAAAAA0000FF0055AA5500AAAAAAAAAAAAAA0055AA5500FF0000AAAAAAAAAAFFFF000055
AAFFFFFFAA55FF5555555555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAAAA55FFFFFFFFFFAA5500AA000000
00000000FF5555AAFFFF000000000000000000FFFFAA5555FF00000000000000AA0055AA
FFFFFFFFFF55AAAAAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFF55FFFF00AAFF00AAFFFF000055AA55
55555555AAAAAAAAFF00AAAA0055AA5500AAAA00FFAAAAAAAA5555555555AA550000FFFF
AA00FFAA00FFFF55FFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAFF00AAAAFF000000AA0055FFAAAA
AAAAAAAAAAFFAAAAFF00000055FFAAFF55000000FFAAAAFFAAAAAAAAAAAAAAFF5500AA00
0000FFAAAA00FFAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF0000005555AA550000FFFFFFAA
AAFFFFAAFFFFFFAAFF0000FF00FFAAFF00FF0000FFAAFFFFFFAAFFFFAAAAFFFFFF000055
AA5555000000FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF0000FF00FFFFAA5500AA00FFAA
FFFFFFFFAA00FFAAAA5500AA00AAFFAA00AA0055AAAAFF00AAFFFFFFFFAAFF00AA0055AA
FFFF00FF0000FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA555555FF00AAFFFF000055AAAA
FF00AA000000FFAAFFFF000055FFFFFF550000FFFFAAFF000000AA00FFAAAA550000FFFF
AA00FF555555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAA550000AA0055FFAAAA
FF000055AA55550000AA00AAAAAA55AAAAAA00AA00005555AA550000FFAAAAFF5500AA00
0055AAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFF55AA550000FFFFFFAA
FF0055AAFFFF00FF000055FFFFAAAAAAFFFF550000FF00FFFFAA5500FFAAFFFFFF000055
AA55FFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAFFFF0000FFAA0000
00AAAAAAFF00AAAA5500FFFFFFFFAAFFFFFFFF0055AAAA00FFAAAAAA000000AAFF0000FF
FFAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF00AAAA000000FF
0000000000AAAAFFFF0000AA00FFAAFF00AA0000FFFFAAAA0000000000FF000000AAAA00
FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00000000FF0000
AAAA00AA5500005555FF005500FFAAFF005500FF5555000055AA00AAAA0000FF00000000
FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555555555FF00
000055FFFF0000FFFF00AAAAAA000000AAAAAA00FFFF0000FFFF55000000FF5555555555
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAAAA55
00FF00FFAA0055AAAA5500000000FF0000000055AAAA5500AAFF00FF0055AAAAAAAAAAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFF55FFFF
005555550000FFFFAAAAAA0055AA55AA5500AAAAAAFFFF000055555500FFFF55FFFFAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAFF00
AAAAAAAAAA00555500000055FFAAAAAAFF55000000555500AAAAAAAAAA00FFAA55AAAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF00
000055000000FFFF0000FF55AAAAFFAAAA55FF0000FFFF00000055000000FFAAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00
00FF00FF0000FFAA0055AAAAAAFFFFFFAAAAAA5500AAFF0000FF00FF0000FFAAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55
5555FF00AAAA000000FFFFAAFFFFFFFFFFAAFFFF000000AAAA00FF555555AAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
AAAAAA55000000FF0000AAFFFFFFFFFFFFFFAA0000FF00000055AAAAAAAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAFFFF55AA5500AA0055FFFFFFFFFFFFFFFFFF5500AA0055AA55FFFFAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAA55AAFFFF005500FFFFFFFFFFFFFFFFFFFFFF005500FFFFAA55AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAAFF00AAAAAA0000AA0000AA0000AA0000AAAAAA00FFAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAFF0000000000FF55FF000000FF55FF0000000000FFAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAA5555555555AAAAAA555555AAAAAA5555555555AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAAAAAAAAAAAAFFAAAAAAAAAAFFAAAAAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAFFFF55FFFFFFAAFFAAFFFFFF55FFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAA55AAFF00AAFFFFFFAA00FFAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAFF000000AA000000FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAAFF0000FF55FF0000FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA5555AAAAAA5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAAAAAFFAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFFFFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 3.64935 0.588183 3.73666 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAA55555555AAAAAAAA555555AA5500FFFFFFFF00005555AAAAAAAA55AAAAFFAAAA
AAAA00FF55AA5555AA55FF550055FF550055FF55AA5555AA55FF00AAAAAAAAFFAAAA55AA
AAAAAA55550000FFFFFFFF0055AA555555AAAAAAAA55555555AAAAAAFF
FFFFAAAA5500AA55FFFFAAAA5500AA55AA00AA00005555AA55FFAAAA55AAAAAAFFFFFF55
55FF550055AAAAAAAA550055AA550055AA550055AAAAAAAA550055FF5555FFFFFFAAAAAA
55AAAAFF55AA55550000AA00AA55AA0055AAAAFFFF55AA0055AAAAFFFF
FFFFFFAAAAAA00FFFFFFFF555555AAAAAA5555FF0055AA00FFFFFF555555FF5555005555
555500AAAAAAFFAAAA5500FFFF55AA55FFFF0055AAAAFFAAAAAA0055555555005555FF55
5555FFFFFF00AA5500FF5555AAAAAA555555FFFFFFFF00AAAAAAFFFFFF
FFFFFFFFAAAA555500555500AA55FF55FFFF0000AAAAAA5555000055AA005500AA555555
555555AAAAFFFFFFAAAAAA0000AA55AA0000AAAAAAFFFFFFAAAA555555555555AA005500
AA5500005555AAAAAA0000FFFF55FF55AA005555005555AAAAFFFFFFFF
FFFFFFFFFFAAAAAAAA0055AA55AA0000005500FF5555FF55AA00AAAAAA555555AAAAAAAA
AAAAAAAAFFFFFFFFFFAAAA5555AAAAAA5555AAAAFFFFFFFFFFAAAAAAAAAAAAAAAA555555
AAAAAA00AA55FF5555FF0055000000AA55AA5500AAAAAAAAFFFFFFFFFF
FFFFFFFFFFFFAAAA55AA55FF55AAAA00AAAAAA0000FFFFFF00AAAA55AAAAAAAAAAFFFF55
FFFF55FFFFFFFFFFFFFF55555555FF55555555FFFFFFFFFFFFFF55FFFF55FFFFAAAAAAAA
AA55AAAA00FFFFFF0000AAAAAA00AAAA55FF55AA55AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA550055AAAA5555FF55FF0055005555AAAAFF5555FFFF55550000
00AA005500005500005500AA5500AA0055AA005500005500005500AA0000005555FFFF55
55FFAAAA5555005500FF55FF5555AAAA550055AAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA5500FFFF5555555500AA00AA55555555FFFFFF000055555555AA
5555FF00FF5500AAAA0055FF55AA55AA55FF5500AAAA0055FF00FF5555AA555555550000
FFFFFF55555555AA00AA0055555555FFFF0055AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAA000055AA0055AA55AA55AAFF55AA0000AA00AAAAAAAAAAAA
5500AA00AA0055FF55FF000055AAAAAA550000FF55FF5500AA00AA0055AAAAAAAAAAAA00
AA0000AA55FFAA55AA55AA5500AA550000AAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA5555AA00FF55AAAAAA55FFFFFF00AAAA00FF5555FFFFAAAA
55FF00AAAA55555500AA00AAAAAAFFAAAAAA00AA00555555AAAA00FF55AAAAFFFF5555FF
00AAAA00FFFFFF55AAAAAA55FF00AA5555AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAAAAA555500AAFFAA0055000055FFFF550000FFFFFFFF55
555500FFAAAAAAAAAA00FF5555FFFFFF5555FF00AAAAAAAAAAFF00555555FFFFFFFF0000
55FFFF5500005500AAFFAA005555AAAAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA55AA0055FFFFFF5500AAAA00550055AA555500550000
00FF005555FF5555FF5500000000550000000055FF5555FF555500FF00000055005555AA
55005500AAAA0055FFFFFF5500AA55AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA555555000055AA55AAAA0055FFAAAAAAAA0055FF
005555AA005555555500AAAA00AAAAAA00AAAA005555555500AA555500FF5500AAAAAAAA
FF5500AAAA55AA550000555555AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500AA5555AAFFAA55AAAA005555FFFF55FF0000
AAAAAAAA555555555555AAAA5555FF5555AAAA555555555555AAAAAAAA0000FF55FFFF55
5500AAAA55AAFFAA5555AA0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FFFF00AA00FFFF55FF0000005500AA00AA
AAFFFFAAAAAAAAAAAAAAAAFFAA550055AAFFAAAAAAAAAAAAAAAAFFFFAAAA00AA00550000
00FF55FFFF00AA00FFFF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55550055FF550055555500FF5500AAAA5555
FFFFFFFF5555FFFFAAAAFFFFFF55AA55FFFFFFAAAAFFFF5555FFFFFFFF5555AAAA0055FF
005555550055FF55005555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA005500AAAAAAAAAA0000FF55FF55AA
0000AA0000FFFFFFFF55550000AA55AA00005555FFFFFFFF0000AA0000AA55FF55FF0000
AAAAAAAAAA005500AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AA55FF00AAFFAA00FF55000000AA55
AA5555FF005500555500AA5555AAAAAA5555AA005555005500FF5555AA55AA00000055FF
00AAFFAA00FF55AA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA550055FFFFFF550055AA5555AAAA
AA5500AA00AA55555555AAAAAAAA55AAAAAAAA55555555AA00AA0055AAAAAA5555AA5500
55FFFFFF550055AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500FFFFFFFFFF0055AAAAAAAA55
AAAAAA00FF555555555555FFFF555555FFFF555555555555FF00AAAAAA55AAAAAAAA5500
FFFFFFFFFF0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA0000550000AAAAAA55AAAA55
FF55FF5500000000000000005555555555000000000000000055FF55FF55AAAA55AAAAAA
0000550000AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555AA00AAAAFFFF55AAAA55
00000055AA5555AA5555AA55555555555555AA5555AA5555AA5500000055AAAA55FFFFAA
AA00AA5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA5555FFFFFFFF00AAFF
5500FF55AAAAAAAA55FFAAAAAAAAAAAAAAAAAAFF55AAAAAAAA55FF0055FFAA00FFFFFFFF
5555AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AA005555000055FFFF
FF00555555FFFFAA005555FFFF55FF55FFFF555500AAFFFF55555500FFFFFF5500005555
00AA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55555555AA550055
0055FFAA55005555FF0000005500AA0055000000FF55550055AAFF5500550055AA555555
55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500AA55FF55AA55
00FFFFFF55AA5500AA00AAAA0055FF5500AAAA00AA0055AA55FFFFFF0055AA55FF55AA00
55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FFFFFF00AA
5555000055AAAAAA00FF55FF5500AA0055FF55FF00AAAAAA5500005555AA00FFFFFF00AA
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555005555AA
AAAAAA00AA55AAAA555500AA0055FF5500AA005555AAAA55AA00AAAAAAAA5555005555AA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA0055AA
AA55AAAA00FFFF55555555AAAA005500AAAA55555555FFFF00AAAA55AAAA5500AAAAAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55AA55FF
555555FF55005500AA55FFAAAA555555AAAAFF55AA00550055FF555555FF55AA55AAAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA5500
55AA005500AAAAAA00FFFFFF5555555555FFFFFF00AAAAAA005500AA550055AAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500
FFFF5500AAAA55AAAA0000555555555555550000AAAA55AAAA0055FFFF0055AAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA
000055AA55AAAAAA55AA555555555555555555AA55AAAAAA55AA550000AAAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
5555AA00FFFF5555FFAAAAAAAAAAAAAAAAAAAAAAFF5555FFFF00AA5555AAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAAAAA555500000000AAFFFFAAAA55AAAAFFFFAA000000005555AAAAAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAA55AA0055FF0055FFFFFFFFAAAAAAFFFFFFFF5500FF5500AA55AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAA55555500FFFFFFFFFFFF55FFFFFFFFFFFF00555555AAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAA5500AA555500550000555555000055005555AA0055AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAAAA00FFFF0055AA5555555555AA5500FFFF00AAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAA55550055FFAAAAAAAAAAAAAAFF55005555AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAAAA005555FF55FF55FF555500AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAA55AA5500AA005500AA0055AA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA55FF00AAAAAA00FF55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA550055FF55FF550055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAA0055555500AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAA5555555555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 3.64935 0.782187 3.73666 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAA00FF550000FFFF00AAFFAAAAFF0000AA55AA555500AA00FF550000FFFFFFFF55
AAFF0000FF00000000AAAAAAFFFF55FFFFAAAAAA00000000FF0000FFAA55FFFFFFFF0000
55FF00AA005555AA55AA0000FFAAAAFFAA00FFFF000055FF00AAAAAAFF
FFFFAAAAFF005555FF5500AAFFFFFFAAAA00FFAAAAAAFF55AAAAFF005555FF5500AAAA00
0055AAAA5555FF5555FFFFAAAA00AA00AAAAFFFF5555FF5555AAAA550000AAAA0055FF55
5500FFAAAA55FFAAAAAAFF00AAAAFFFFFFAA0055FF555500FFAAAAFFFF
FFFFFFAAAA00FFFF005555FFFFFFFFFF55FF5500005500FFFFAAAA00FFFF005555FFFF55
55FFAAFFFF00FF00FFFFFFFF55FF55FF55FFFFFFFF00FF00FFFFAAFF5555FFFF555500FF
FF00AAAAFFFF0055000055FF55FFFFFFFFFF555500FFFF00AAAAFFFFFF
FFFFFFFFAAAA5555AAAAAAAA0055FF0000AAAAAA55AAFF0055FFFF5555AA00FFFF0000FF
FF005500FF00AAAA555555555500AA005555555555AAAA00FF005500FFFF0000FFFF00AA
5555FFFF5500FFAA55AAAAAA0000FF5500AAAAAAAA5555AAAAFFFFFFFF
FFFFFFFFFFAAAAAAAAFFAAAAFF00FF5555FFFFAAFF55FF00AA00AAAAAAAAFF0055FF5555
55AAAAAA5555FFFFAA55FFAA55FF55FF55AAFF55AAFFFF5555AAAAAA555555FF5500FFAA
AAAAAA00AA00FF55FFAAFFFF5555FF00FFAAAAFFAAAAAAAAFFFFFFFFFF
FFFFFFFFFFFFAAAAFFFFFFAAAA00FF00FFFFFFFF550055FF55FF55FFFFAAAA00FFFFFF00
FFFF55FFFF00FF00550055FFFF000000FFFF55005500FF00FFFF55FFFF00FFFFFF00AAAA
FFFF55FF55FF550055FFFFFFFF00FF00AAAAFFFFFFAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA0055FFFF555555FF0000FF55AAAAAA0000FFFFFFFFAAAA5500FF55
55555500FF00AAAA55FF55AA5555FF5555AA55FF55AAAA00FF0055555555FF0055AAAAFF
FFFFFF0000AAAAAA55FF0000FF555555FFFF5500AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA55FF0055550055FF5555AAFFAAFFAA00FF5500FF55FFFF00AAAA
AAAAAAAA5555FFFF55AA55FFFF00FF00FFFF55AA55FFFF5555AAAAAAAAAAAA00FFFF55FF
0055FF00AAFFAAFFAA5555FF5500555500FF55AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAA00FFFF00AA00AA000055FFFFFF5555AAFF00555555AAAAFF
AAFFFF55FFAA5555550000AAAA00FF00AAAA0000555555AAFF55FFFFAAFFAAAA55555500
FFAA5555FFFFFF550000AA00AA00FFFF00AAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAFF0055FF55FF55FF555500FF0000000055AAAAAAAAAAFFFF
FF5500FFFFFF55AAFF5555FFFF555555FFFF5555FFAA55FFFFFF0055FFFFFFAAAAAAAAAA
5500000000FF005555FF55FF55FF5500FFAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA00FFFFFF0000AAAAAAAA5555FF5555FFAAAAFFFFAAAA00
AAAAAA5555AA55FFFFFF00FF0000AA0000FF00FFFFFF55AA5555AAAAAA00AAAAFFFFAAAA
FF5555FF5555AAAAAAAA0000FFFFFF00AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA5555AA55AAAAFFFFAAAAAAAA0000AAAAFFFFFFFF55FF
55FFFFAA55FFFF0055AA55AA00FFAAFF00AA55AA5500FFFF55AAFFFF55FF55FFFFFFFFAA
AA0000AAAAAAAAFFFFAAAA55AA5555AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAFF55FFFFFFFF55FFFF5555FFFF5500FF000000
FFFFFFFFAA5500AAFF55FFAAFF005500FFAAFF55FFAA0055AAFFFFFFFF000000FF0055FF
FF5555FFFF55FFFFFFFF55FFAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFFFF0000FF000000FF00FFFFFFFF00AA55AAAA
5500FF00005555FFFFFF000055AAAAAA550000FFFFFF55550000FF0055AAAA55AA00FFFF
FFFF00FF000000FF0000FFFFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055FF5555AAAA55AA55AA555555AAAAFF55FF
FF00AA55AAAAAAAA00AA55AAAAAAFFAAAAAA55AA00AAAAAAAA55AA00FFFF55FFAAAA5555
55AA55AA55AAAA5555FF5500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF00FFFFAAFF55FFAAAAAAAAAAFFFFFF00
55AAAAFF55FFFF55FF55FFAAAAFFFFFFAAAAFF55FF55FFFF55FFAAAA5500FFFFFFAAAAAA
AAAAFF55FFAAFFFF00FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FF550000FFFFFF55FFFF55FF0055AA
AAAAFFFFFF0000FFFFFF00550000FF00005500FFFFFF0000FFFFFFAAAAAA5500FF55FFFF
55FFFFFF000055FF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF005555FF5500AAAAAA005555AAAAAA
FFAAAA0055AAAA5500AAAA55FF555555FF55AAAA0055AAAA5500AAAAFFAAAAAA555500AA
AAAA0055FF555500FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FFFF005555FFFF55FF55AAFFAAFF
FFFFAAAA55FFFF55AAAAFFFF0000AA0000FFFFAAAA55FFFF55AAAAFFFFFFAAFFAA55FF55
FFFF555500FFFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555AAAAAAAA005555AAFFFFFF55
00AAAAFFAA555555000055AA00FFAAFF00AA550000555555AAFFAAAA0055FFFFFFAA5555
00AAAAAAAA5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAFFAAAAFF00FFFF5500AA55
FF55FFFFFF55AAFF5555FFAAFF005500FFAAFF5555FFAA55FFFFFF55FF55AA0055FFFF00
FFAAAAFFAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFFFFAAAA00FF005555FFFF
0000AA5555550000FFFF000055AAAAAA550000FFFF0000555555AA0000FFFF555500FF00
AAAAFFFFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055FFFF555555FFAA5555
55FF55FFAA55FF5555AA55AAAAAAFFAAAAAA55AA5555FF55AAFF55FF555555AAFF555555
FFFF5500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF0055550055FFFF00
FFFFFF00550055AAFF55FFAAAAFFFFFFAAAAFF55FFAA55005500FFFFFF00FFFF55005555
00FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00FFFF00AA00AA55
AA5555AAAAAA55FFFFFF00550000FF00005500FFFFFF55AAAAAA5555AA55AA00AA00FFFF
00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF0055FF55FF55FF
AAAAAAAAFFFFAA5500AAAA55FF555555FF55AAAA0055AAFFFFAAAAAAAAFF55FF55FF5500
FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FFFFFF0000AA
AAFFAAFFFFFFFF55AAAAFFFF0000AA0000FFFFAAAA55FFFFFFFFAAFFAAAA0000FFFFFF00
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555AA55AAAA
FFFFFF5500FF5500550000FF00AAFFAA00FF0000550055FF0055FFFFFFAAAA55AA5555AA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAFF55FF
FFFFFFFF00AAAAAA55FF555555FFFFFF555555FF55AAAAAA00FFFFFFFFFF55FFAAAAAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFFFF00
00FF0055AAAAFFFFAA5555005555AA5555005555AAFFFFAAAA5500FF0000FFFFFFAAAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055FF
5555AAAAAAFFFFFFFFAA55FF55AAFFAA55FF55AAFFFFFFFFAAAAAA5555FF5500AAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF
00FFFF55FFFFFFFFFFFF55AA55FFFFFF55AA55FFFFFFFFFFFF55FFFF00FF55AAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA
00FF550055AA5500FF0000005555AA5555000000FF0055AA550055FF00AAAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
FF005555FFAAFF555555FF55550055005555FF555555FFAAFF555500FFAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AA00FFFF005500FFFF00FF55AAFF00FFAA55FF00FFFF005500FFFF00AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAA5555AAAAAA5555AAAA000055FF550000AAAA5555AAAAAA5555AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAAAAFFAAAAAAAAFFAA00FFFFFF00AAFFAAAAAAAAFFAAAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAFFFFFFAAAAFFFFFF5555AA5555FFFFFFAAAAFFFFFFAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAA0055FFFF5500AA55FFAAFF55AA0055FFFF5500AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAA55FF005555FFFF005500FFFF555500FF55AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAA00FFFF0055AAAAAA5500FFFF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAAFF0055AAAAAAFFAAAAAA5500FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA00FFFF55FFFFFF55FFFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA5500FFFFFFFFFF0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAA5500FF0055AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAFF555555FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA000000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 3.64935 0.97619 3.73666 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAA5500AAAAAA55AAAA550055AA550000AAAAAAAA0055FFFFAAAA55FF00FF0055FF
FF5500FFFFFFFFFF00FFFF00AA55AA55AA00FFFF00FFFFFFFFFF0055FFFF5500FF00FF55
AAAAFFFF5500AAAAAAAA000055AA550055AAAA55AAAAAA0055AAAAAAFF
FFFFAAAAFF5555005555550055AAAAAAFF5555FFFFAAAAFF00FF5500555555AAAA00FF00
55FFAA00AAAA00AAAA5555AAAAFF55FFAAAA5555AAAA00AAAA00AAFF5500FF00AAAA5555
550055FF00FFAAAAFFFF5555FFAAAAAA5500555555005555FFAAAAFFFF
FFFFFFAAAA0055AAAAAAAAAA55FFFF55FF0000FF550000AAAA555555FFAA55FFFF5555AA
AAAA0000005555FFFF55AA0000AAAAAA0000AA55FFFF5555000000AAAAAA5555FFFF55AA
FF555555AAAA000055FF0000FF55FFFF55AAAAAAAAAA5500AAAAFFFFFF
FFFFFFFFAAAA55005555000055AA555555AAAA555555FF55FFFF00FFFFFF55AA55555555
005555FF55555555AA5500000000550000000055AA55555555FF55550055555555AA55FF
FFFF00FFFF55FF555555AAAA555555AA55000055550055AAAAFFFFFFFF
FFFFFFFFFFAAAAAA5500AAFF000055AAFF55FFFF00FF0055AA5555FF0055FFAAAAAAAAAA
AA5500AAAAAAAAAAAAFF5555FF555555FF5555FFAAAAAAAAAAAA0055AAAAAAAAAAAAFF55
00FF5555AA5500FF00FFFF55FFAA550000FFAA0055AAAAAAFFFFFFFFFF
FFFFFFFFFFFFAAAAFF555500FFAA005555AA00AAAA5555FFAAAAAAAA00FFFFFFAAAAFFAA
AAFF5555005500550055FFAA5555555555AAFF5500550055005555FFAAAAFFAAAAFFFFFF
00AAAAAAAAFF5555AAAA00AA555500AAFF005555FFAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA0055AAAA000000FFFF55550055AA00AA00005555FF0055FFFF5500
5555AAFF555555FFAA0055FFFF00FF00FFFF5500AAFF555555FFAA55550055FFFF5500FF
55550000AA00AA55005555FFFF000000AAAA5500AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA55005555FF5555AA5500AAFF55FF55FF55555555AAAAAA00AA55
AAFF55FF0000FFFFFF555555AA55AA55AA555555FFFFFF0000FF55FFAA55AA00AAAAAA55
555555FF55FF55FFAA0055AA5555FF55550055AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAA5500AAAAAAAAFF555500FF0055AA55FFAA55FFFF55FF55FF
AAAA0055FF5555AA555555555500AA005555555555AA5555FF5500AAAAFF55FF55FFFF55
AAFF55AA5500FF005555FFAAAAAAAA0055AAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAFF555500555500FFFF00AAAA55FFFF00555555AA5500FFFF
FFAAAA5500FF0000AA5500AA55FF55FF55AA0055AA0000FF0055AAAAFFFFFF0055AA5555
5500FFFF55AAAA00FFFF005555005555FFAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA0055AAAAAAAA5555AAAAFFAA5555AAAAAAAAAAFF5555AA
55550055AAAA00FFAAFF555500AAAAAA005555FFAAFF00AAAA55005555AA5555FFAAAAAA
AAAA5555AAFFAAAA5555AAAAAAAA5500AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA550055550000FFFFAAAA0000FFFFAAFFFF55FF00FFFF
55AA00FFFFAAFF005500FF00000055000000FF005500FFAAFFFF00AA55FFFF00FF55FFFF
AAFFFF0000AAAAFFFF000055550055AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA5500AAFF0055FFFF5555FF005555AA55FF00AAAA
005555FF005555AAAAAA5555FF555555FF5555AAAAAA555500FF555500AAAA00FF55AA55
5500FF5555FFFF5500FFAA0055AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF555500FFAA5555AA0055FF55AAFFAA5555FFFF
AA0055AA55AA00550000AA55FF00FF00FF55AA00005500AA55AA5500AAFFFF5555AAFFAA
55FF5500AA5555AAFF005555FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055AAAA0000FFFF555555AAFFFFFFAA55FF00
5555FFAAAAAAFF0000000055AA55AA55AA5500000000FFAAAAAAFF555500FF55AAFFFFFF
AA555555FFFF0000AAAA5500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55005555FF5500FFFF000055FF00555555AA
AAAAAA00005555AAAA55AAAAAAFF55FFAAAAAA55AAAA55550000AAAAAAAA55555500FF55
0000FFFF0055FF55550055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA5500AAAAAA5555AAAA5500FFAA55FFAA
FFFFAAFF00AA55005555550000AAAAAA00005555550055AA00FFAAFFFFAAFF55AAFF0055
AAAA5555AAAAAA0055AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF555500555555550055AAAA0000FF55
FF005500FFAAAAAA5500AA55AAAAFFAAAA55AA0055AAAAAAFF005500FF55FF0000AAAA55
0055555555005555FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055AAAAAAAAAAAA55005555FF5500
AAAA55FF5500550000FFAAAAAAFFFFFFAAAAAAFF0000550055FF55AAAA0055FF55550055
AAAAAAAAAAAA5500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA550055550000555555FFAA555555
FFFF55AA55FF55AAAA5555005555AA5555005555AAAA55FF55AA55FFFF555555AAFF5555
55000055550055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA5500AAFF0000FFFFFFAA5500
AAAA00555555AAFFAAAAAAAA5500AA0055AAAAAAAAFFAA55555500AAAA0055AAFFFFFF00
00FFAA0055AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF555500FFAA00AAAA0000FF
AAAAFF0000FFFF550000555500AAFFAA005555000055FFFF0000FFAAAAFF0000AAAA00AA
FF005555FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055AAAA0000005555FF55
000055FF5555AA55FF55555555FFFFFF55555555FF55AA5555FF55000055FF5555000000
AAAA5500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55005555FF55555555AA
00FFAA5555555500AAAAAAAAAAAA00AAAAAAAAAAAA0055555555AAFF00AA55555555FF55
550055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA5500AAAAAAAAAAAA
FF00555555555555FFFF55FFFF55FF55FFFF55FFFF55555555555500FFAAAAAAAAAAAA00
55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55550055550055
55AAAAAAAAAAAAAAAA00AA5555AA00AA5555AA00AAAAAAAAAAAAAAAA5555005555005555
FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055AAAAAAAA55
00AA0000AA00005500000055AA000000AA55000000550000AA0000AA0055AAAAAAAA5500
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA550055550000
FFAAFF00AA00FFAA55AAAA55000000000055AAAA55AAFF00AA00FFAAFF000055550055AA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA5500AAFF
005555AAAAFF005555550055AAAA55AAAA550055555500FFAAAA555500FFAA0055AAAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF555500
FFAA55005555AAAAAAAAAA55005555550055AAAAAAAAAA55550055AAFF005555FFAAAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055AA
AA0000FFAA55005555000055AAAAAAAAAA55000055550055AAFF0000AAAA5500AAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500
5555FF550055AAAAAAAA55AA0000AA0000AA55AAAAAAAA550055FF55550055AAAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA
5500AAAAAA550055005500AA00FFAAFF00AA005500550055AAAAAA0055AAAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA
FF5555000055AAAAAA55FF55FF550055FF55FF55AAAAAA5500005555FFAAAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AA0055AAAA5500550000FF55AA55FF55AA55FF0000550055AAAA5500AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAAA55000055AAAAAA55AA550055AA550055AA55AAAAAA55000055AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAA55AAFFFFAAFF55FFAA005500AAFF55FFAAFFFFAA55AAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAAAFF55FF005500FFFFFF555555FFFFFF005500FF55FFAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAA0055FF55AAAA00AAAAAAAAAA00AAAA55FF5500AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAAA55FF00005555FFFFAAFFFF55550000FF55AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAA00FFAA55FF005500FF55AAFF00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAAAFF00555555AAAAAA55555500FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA00FF00FFFFAAFFFF00FF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAAA5555FF005500FF5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAAAA00FF00AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAAAFFAA00AAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA000000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 3.74539 0.200176 3.8327 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAFFFF00AAAA00FFAA005500FFFFFFAAAAAA00FFFFFFAA55FFFFFFFFFF55FFFFAA
FF5500FFFF00FF0000FF00AAFF55FF55FFAA00FF0000FF00FFFF0055FFAAFFFF55FFFFFF
FFFF55AAFFFFFF00AAAAAAFFFFFF005500AAFF00AAAA00FFFFAAAAAAFF
FFFFAAFF0000FFFFAAFF55FF55AA55FFFFFFFFAA00FFFFFF55FF55005555550055FFFF55
5500FFFF55FFAAAAAAAAFF555500FF005555FFAAAAAAAAFF55FFFF005555FFFF55005555
550055FF55FFFFFF00AAFFFFFFFF55AA55FF55FFAAFFFF0000FFAAFFFF
FFFFFFAAAAAAAAFFAA000000AAAA55550055AA00FFFFFFFF5500AAAAAA00AAAAAA000055
FF00FF000000FFAAFF00AA5555AAFFAA5555AA00FFAAFF000000FF00FF550000AAAAAA00
AAAAAA0055FFFFFFFF00AA55005555AAAA000000AAFFAAAAAAAAFFFFFF
FFFFFFFFAAFF00AA00FFFF00FFAA00AAAAAA00FFFFFFFF55FF00FFAAFF00FFAAFFFF00FF
55FFAAAAAAAAAAFFFFFF00AAAA00FF00AAAA00FFFFFFAAAAAAAAAAFF55FF00FFFFAAFF00
FFAAFF00FF55FFFFFFFF00AAAAAA00AAFF00FFFF00AA00FFAAFFFFFFFF
FFFFFFFFFFAAAAAA55FFFF55AA00FFFFAAFFFF0000FF000000FFFFFFAAAAAAFFFFFFFF00
0000AAFFFFAAFFFFFFFFFF00AAFF55FFAA00FFFFFFFFFFAAFFFFAA000000FFFFFFFFAAAA
AAFFFFFF000000FF0000FFFFAAFFFF00AA55FFFF55AAAAAAFFFFFFFFFF
FFFFFFFFFFFFAAFF00555555AAAAAAFFAA0055AAFF55FFAA55FFFFFFFFAAFFFFFFFFFFFF
00FFFFAAAAFFFFFFFFFFFFFF00AA00AA00FFFFFFFFFFFFFFAAAAFFFF00FFFFFFFFFFFFAA
FFFFFFFF55AAFF55FFAA5500AAFFAAAAAA55555500FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAA00AAAA55AAAAFF00FF555500FF00AAAAFFAAAAFFFFFFFF55FFFF
FF0000AAFFFFFF55FFFFFFFF55AAAAAA55FFFFFFFF55FFFFFFAA0000FFFFFF55FFFFFFFF
AAAAFFAAAA00FF005555FF00FFAAAA55AAAA00AAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF00FFAA00AAFFFF55AA00AAAAAAFF5555FFFFAA0000AA0055FFFF
FF55AAFF0000AA55555500AA5555FF5555AA00555555AA0000FFAA55FFFFFF5500AA0000
AAFFFF5555FFAAAAAA00AA55FFFFAA00AAFF00FFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAAFFFF00AA0055FF55AAAA55AA00AAAAFFAAFF55AAAAAA0055
5500FFAAAAAAAA5555AA55FF5500FF0055FF55AA5555AAAAAAAAFF00555500AAAAAA55FF
AAFFAAAA00AA55AAAA55FF5500AA00FFFFAAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF0000FFFFAA555500FFAA00AAFF5555FFFFAAAA00FFAAFF55
00FFFFFFAAFF00AAAA00FF55FF00FF00FF55FF00AAAA00FFAAFFFFFF0055FFAAFF00AAAA
FFFF5555FFAA00AAFF005555AAFFFF0000FFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAAAAAFFAA00AAAAAAFFFF00AA00AAAAFFAA00FFFF555500
FFFFFF55FF55FFAAFFFF000000FFFFFF000000FFFFAAFF55FF55FFFFFF005555FFFF00AA
FFAAAA00AA00FFFFAAAAAA00AAFFAAAAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF00AA00FFFFAAFFFFFF55AAAAAA55AA00FFFFFF5500FF
FFFFFF5500AAAAFFFFFFFF00FFFF55FFFF00FFFFFFFFAAAA0055FFFFFFFF0055FFFFFF00
AA55AAAAAA55FFFFFFAAFFFF00AA00FFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55FFFF555500AA00AAFF00AAAA55FFFF55FF00FF
00005555AAFF00AA0000FF00FF000000FF00FF0000AA00FFAA55550000FF00FF55FFFF55
AAAA00FFAA00AA005555FFFF55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00555555AA55FF55AAAAFF5555FF0000FF55FFAA
AAAAAA00AAFFAA55AAFF55FFAAAAAAAAAAFF55FFAA55AAFFAA00AAAAAAAAFF55FF0000FF
5555FFAAAA55FF55AA55555500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00AAAA555500FFAA00000000FFFF000000AA
FFFFAAFF555555FF00AA00AA00FFAAFF00AA00AA00FF555555FFAAFFFFAA000000FFFF00
000000AAFF005555AAAA00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFAA00AAAAAAFFFF00FFFF0000FFFF00FF
AAAAFF0000000000FFFFAA55AAFFAAFFAA55AAFFFF0000000000FFAAAAFF00FFFF0000FF
FF00FFFFAAAAAA00AAFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFF00AAFF0000FFFFFF55AAFFAAAAAA
FFFFAAAAAAAAAAAAAAFFAA00AAFFAAFFAA00AAFFAAAAAAAAAAAAAAFFFFAAAAAAFFAA55FF
FFFF0000FFAA00FFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0000FFFFAAAAAAAAFFAAAA00FF00AAFF
FFFFFFAA00FFAAFFFFAAAA55FF55FF55FF55AAAAFFFFAAFF00AAFFFFFFFFAA00FF00AAAA
FFAAAAAAAAFFFF0000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAFFAA00FFAAFFAA00FFFFFF00AA
5500AA55AAFFAA0055AAAA555500FF005555AAAA5500AAFFAA55AA0055AA00FFFFFF00AA
FFAAFF00AAFFAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00AA00FFFFFFAAAA55FFFFFFFF00
AAAAAA5555FFFFAA5555FF5500FFFFFF0055FF5555AAFFFF5555AAAAAA00FFFFFFFF55AA
AAFFFFFF00AA00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55FFFF55FF5555AA0000FF00
FFAAFF0055FFFF5555AA5500FFFFFFFFFF0055AA5555FFFF5500FFAAFF00FF0000AA5555
FF55FFFF55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00555555AA00AAAA55FFAAAA
AAFFFFFF00555555AA55AA55FFFFFFFFFF55AA55AA55555500FFFFFFAAAAAAFF55AAAA00
AA55555500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00AAAA55FF5555AA00FF
AAFFAAAAFF5500FF5555AAAA0000FF0000AAAA5555FF0055FFAAAAFFAAFF00AA5555FF55
AAAA00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFAA00AA5555AAAAAA
FFFFFFAA0055FFAAAA00AAFF00FFFFFF00FFAA00AAAAFF5500AAFFFFFFAAAAAA5555AA00
AAFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFF00AAAA00FFAA
005500AAFF5500AAFF00FFAAAAAAFFAAAAAAFF00FFAA0055FFAA005500AAFF00AAAA00FF
FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0000FFFFAAFF55FF
55AA55FF55FF00FFAAAAAAFFFFAAFFAAFFFFAAAAAAFF00FF55FF55AA55FF55FFAAFFFF00
00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAFFAA000000
AAAA555500FF00FF00AAFF0000AAFFAA0000FFAA00FF00FF005555AAAA000000AAFFAAAA
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00AA00FFFF00
FFAA00AAAAAAFF55FFAAFFAA55FF55FF55AAFFAAFF55FFAAAAAA00AAFF00FFFF00AA00FF
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55FFFF55
AA00FFFFAAFFFF5500AAFFAA00AA00AA00AAFFAA0055FFFFAAFFFF00AA55FFFF55AAAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00555555
AAAAAAFFAA0055AA55FF55FF55AAAAAA55FF55FF55AA5500AAFFAAAAAA55555500FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA00AA
AA55AAAAFF00FF5555AA00AA5555FF5555AA00AA5555FF00FFAAAA55AAAA00AAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FF
AA00AAFFFF55AA00AAAA55FF5500FF0055FF55AAAA00AA55FFFFAA00AAFF00FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA
FFFF00AA0055FF55AAAA555500FFFFFF005555AAAA55FF5500AA00FFFFAAAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
0000FFFFAA555500FFAA00AAAAAAFFAAAAAA00AAFF005555AAFFFF0000FFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAAAAAFFAA00AAAAAAFFFF00AAFFFFFFAA00FFFFAAAAAA00AAFFAAAAAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAFF00AA00FFFFAAFFFFFF55AAAAFFAAAA55FFFFFFAAFFFF00AA00FFAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAA55FFFF555500AA00AAFFFFFFAA00AA005555FFFF55AAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFF00555555AA55FF55AAAAFFAAAA55FF55AA55555500FFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAAAA00AAAA555500FFAAFFAAFF005555AAAA00AAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAFF00FFAA00AAAAAAFFFFFFAAAAAA00AAFF00FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAAFFFF00AAFFFFFFFFFFAA00FFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFF0000FFFFAAAAFFAAAAFFFF0000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAAAFFAA00FF00AAFFAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF00AA00FFFFFF00AA00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAA55FFFFFF55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF0055555500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAAA00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 3.74539 0.39418 3.8327 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAA55AA55AAFF00AA00FFAAAAFFFFAA00FF5555555500AAAAAAAAAA00AA55555555
AAAAAAAAFFFFFFAAAAFF000000FFAAFF000000FFAAAAFFFFFFAAAAAAAA55555555AA00AA
AAAAAAAA0055555555FF00AAFFFFAAAAFF00AA00FFAA55AA55AAAAAAFF
FFFFAAFF000000FFAAAAAA55FFFFAAFFAAAA555500AA5500AAAA55AAAA55AAFF0000FF00
0000000000AA00000000AAAAAA000000AAAAAA00000000AA000000000000FF0000FFAA55
AAAA55AAAA0055AA005555AAAAFFAAFFFF55AAAAAAFF000000FFAAFFFF
FFFFFFAAAAAAAA0000005500AA000000AAFF0000FF555555AAAA55000000FFAAAA00AA00
AAAA00AAAA00FFFF00FFFFAAFFFF00FFFFAAFFFF00FFFF00AAAA00AAAA00AA00AAAAFF00
000055AAAA555555FF0000FFAA000000AA0055000000AAAAAAAAFFFFFF
FFFFFFFFAAFF00AAAA00AA55FF5500FFFFAAAAAA0000FF00005500AAAAAAAAFFFFAA55AA
55AAAAAA55AAFFAAAA0000AAFFAAAAAAFFAA0000AAAAFFAA55AAAAAA55AA55AAFFFFAAAA
AAAA00550000FF0000AAAAAAFFFF0055FF55AA00AAAA00FFAAFFFFFFFF
FFFFFFFFFFAAAAAA55AA55AA0000FF55FFFFAAFFFF005555AA5500FFAAFFFFAAAAFF0000
00FFAAFF000000AAFF00FFFFAAAA55AAAAFFFF00FFAA000000FFAAFF000000FFAAAAFFFF
AAFF0055AA555500FFFFAAFFFF55FF0000AA55AA55AAAAAAFFFFFFFFFF
FFFFFFFFFFFFAAFF000000FFAA555500AA000000AA00AA550000FFFFFFAAAAFFFFAAAA00
AAAAFFFFFF00FFFFAAAAAAFFAA00FF00AAFFAAAAAAFFFF00FFFFFFAAAA00AAAAFFFFAAAA
FFFFFF000055AA00AA000000AA005555AAFF000000FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAAA000000FF005500FF55AAAA00FF0055FFFFFFFFAAFFAAAA55AA
55AAAAFFAAAA0000AAFF00AA00FFFFFF00AA00FFAA0000AAAAFFAAAA55AA55AAAAFFAAFF
FFFFFF5500FF00AAAA55FF005500FF000000AAAAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF00AAAA00AA00AA555500AAFF005555AA0000AA000000AAFF0000
00FFAAFFAAFF00FFFFAAAA00FFFFFFFFFF00AAAAFFFF00FFAAFFAAFF000000FFAA000000
AA0000AA555500FFAA005555AA00AA00AAAA00FFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAA55AA55AAFF0000FFFFAAAA0055AAAAAA00FFFF00FFAAAAAA
AAAAFFFFFFAAAA0000AAFF00555500555500FFAA0000AAAAFFFFFFAAAAAAAAAAFF00FFFF
00AAAAAA5500AAAAFFFF0000FFAA55AA55AAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF000000FFAAAAAAAAFFAAFF0055AAAA55AAFFAAAA00000000
000000AA00005500FFFFAAAA0055AA5500AAAAFFFF00550000AA00000000000000AAAAFF
AA55AAAA5500FFAAFFAAAAAAAAFF000000FFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAAAAA000000550000AAFFAA55000055AAAAFF00AAAAAA00
AAAAAA00FF5500AAAAFFAAFFFF000000FFFFAAFFAAAA0055FF00AAAAAA00AAAAAA00FFAA
AA55000055AAFFAA000055000000AAAAAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF00AAAA00AA55FFAAFFAA0055FF00000000AAAA55AAAA
AA55AAAA0000FFFFAAFFAA0000AAAAAA0000AAFFAAFFFF0000AAAA55AAAAAA55AAAA0000
0000FF5500AAFFAAFF55AA00AAAA00FFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55AA55AA00005555FF0000AAAAAA00AAFF000000
0000FFAA00AAAAFFAAFFAA00AAAA55AAAA00AAFFAAFFAAAA00AAFF0000000000FFAA00AA
AAAA0000FF55550000AA55AA55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF000000FFAA5555555500FFFFAAFF00FFAAAAAAAA
AAAAAAFFFF00AAFFAA000055FF555555FF550000AAFFAA00FFFFAAAAAAAAAAAAAAFF00FF
AAFFFF0055555555AAFF000000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA000000FF0000FFFFFFFFAAAA0000000000
550000555500FFAAAA5555AA0000FF0000AA5555AAAAFF0055550000550000000000AAAA
FFFFFFFF0000FF000000AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00AAAA00AA00AAAAFFAAAAFF00AAAA00AAAA
0055FF0000FFFFFFAA0055AAAA00AA00AAAA5500AAFFFFFF0000FF5500AAAA00AAAA00FF
AAAAFFAAAA00AA00AAAA00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55AA55AAFF00AA00FFAAAAAA55AA55AA
AA005555AAFFAAAAFF0055AAAA55FF55AAAA5500FFAAAAFFAA555500AAAA55AA55AAAAAA
FF00AA00FFAA55AA55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF000000FFAAAAAA55FFFFAAFF000000FF
AA00AA550000AAFFFFFF00005500AA00550000FFFFFFAA000055AA00AAFF000000FFAAFF
FF55AAAAAAFF000000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA0000005500AA000000AAAAAAAA
FFFF00AA55FF00AA0000AAAA0055FF5500AAAA0000AA00FF55AA00FFFFAAAAAAAA000000
AA0055000000AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00AAAA00AA55FF5500FFFFAAFFFF
AAAAFF55555500FFAA5555FF5500AA0055FF5555AAFF00555555FFAAAAFFFFAAFFFF0055
FF55AA00AAAA00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55AA55AA0000FF55FFFFAAAA
FF00AA0055AA00AA00FF0000AA55FF55AA0000FF00AA00AA5500AA00FFAAAAFFFF55FF00
00AA55AA55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF000000FFAA555500AA000000
00AAAA555555FFAA00AA00AAAA550055AAAA00AA00AAFF555555AAAA00000000AA005555
AAFF000000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA000000FF005500FF55
00FFAA0055AA000055FF55000055AA55000055FF550000AA5500AAFF0055FF005500FF00
0000AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00AAAA00AA00AA555500
AAAAFFFF000055FF0000AA55FF000000FF55AA0000FF550000FFFFAAAA005555AA00AA00
AAAA00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55AA55AAFF0000FF
FFAAFFAAAAAA005555AAFF0000AAAAAA0000FFAA555500AAAAAAFFAAFFFF0000FFAA55AA
55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF000000FFAAAAAAAA
FFAAFFAAFFFFAA5500AAFFAA5555FF5555AAFFAA0055AAFFFFAAFFAAFFAAAAAAAAFF0000
00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA0000005500
00AAFFAAFFAAAA5500FFAAAA5500AA0055AAAAFF0055AAAAFFAAFFAA000055000000AAAA
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00AAAA00AA55
FFAAFFAA00005500AAAAFF00AA55FF55AA00FFAAAA00550000AAFFAAFF55AA00AAAA00FF
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA55AA55AA
00005555FF0055AAFFFFAAAAAA550055AAAAAAFFFFAA5500FF55550000AA55AA55AAAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF000000FF
AA5555555500FF00AA0000000055AA5500000000AA00FF0055555555AAFF000000FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA00
0000FF0000FFFFFF00AAAAAAAA005500AAAAAAAA00FFFFFF0000FF000000AAAAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00AA
AA00AA00AAAAFFAAAAAA55AAAA555555AAAA55AAAAAAFFAAAA00AA00AAAA00FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA
55AA55AAFF00AA00FFAA00550000FF00005500AAFF00AA00FFAA55AA55AAAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
000000FFAAAAAA55FFFFAA5500FFFFFF0055AAFFFF55AAAAAAFF000000FFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAAAAA0000005500AA000000FFFFFFFFFF000000AA0055000000AAAAAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAFF00AAAA00AA55FF5500FFFFFFFFFFFFFF0055FF55AA00AAAA00FFAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAA55AA55AA0000FFFFFFFFFFFFFFFFFF0000AA55AA55AAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFF000000FFAA5555005555005555005555AAFF000000FFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAAAAAA000000FF0055AA00AA5500FF000000AAAAAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAFF00AAAA00AA00AA55AA55AA00AA00AAAA00FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAA55AA55AAFF000000FFAA55AA55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFF000000FFAAAAAAAAAAFF000000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAAA00000000000000AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF00AAAAAA00AAAAAA00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAA55AAAAAA55AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF0000000000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAAA00AAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 3.74539 0.588183 3.8327 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAFF00AAAAFFFF5555FFFFFFFF00FFFF5500FF550055550055FF5500AA00AA55FF
00FFFF00FF5500FFFF0000AAFFFFFFFFFFAA0000FFFF0055FF00FFFF00FF55AA00AA0055
FF550055550055FF0055FFFF00FFFFFFFF5555FFFFAAAA00FFAAAAAAFF
FFFFAAFFFF55AA55555555FF55FFFFFFFF0000AAFF55FF55AAAA55FF55FF55AA55FF00AA
55FFFF55AA00FFFFFF55AAFFFFFFFFFFFFFFAA55FFFFFF00AA55FFFF55AA00FF55AA55FF
55FF55AAAA55FF55FFAA0000FFFFFFFF55FF55555555AA55FFFFAAFFFF
FFFFFFAAAAFF005500000000FFAAAAFFAAAAAAAA005500AAFFFFAA000055AAAA00FF00FF
55555555FF00FF0000AAFFFFFFFF55FFFFFFFFAA0000FF00FF55555555FF00FF00AAAA55
0000AAFFFFAA005500AAAAAAAAFFAAAAFF000000005500FFAAAAFFFFFF
FFFFFFFFAAFFAA55AAFF55AAFFAAFFFFFFAAFFFFAA55AAFFFFFFFFAA55FF5500FFFFFF00
0055000000FFFF55AAFFFFFFFF55FF55FFFFFFFFAA55FFFF000000550000FFFFFF0055FF
55AAFFFFFFFFAA55AAFFFFAAFFFFFFAAFFAA55FFAA55AAFFAAFFFFFFFF
FFFFFFFFFFAAAA00FF55FF550055FFFFFF5500AA00AAFFFFFFFFFF550000AAFF55FFFF55
AAFF00FFFF0000AAFFFFFFFFFF555555FFFFFFFFFFAA0000FFFF00FFAA55FFFF55FFAA00
0055FFFFFFFFFFAA00AA0055FFFFFF550055FF55FF00AAAAFFFFFFFFFF
FFFFFFFFFFFFAAFF55FF55FF55AAAAFFAAAA55FF00FF55FFFFFF55FF55AAFFFF555500AA
FFFFFF0000FFFF00555500555555FF55555500555500FFFF0000FFFFFFAA005555FFFFAA
55FF55FFFFFF55FF00FF55AAAAFFAAAA55FF55FF55FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA550000AAFFFFAAAA00AAFFAA550000FF000000FFAAFFAAAA55AAFF
FFFFFF55AAFFAAAAAA55AAFF00AAFFAA00FFAA55AAAAAAFFAA55FFFFFFFFAA55AAAAFFAA
FF000000FF000055AAFFAA00AAAAFFFFAA000055AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF00FFFFAAAAFFFFAA555500FFAA55FFFF00FFFFFFAAAA00AAFFFF
55FFFF5555AA00AAAA00FF55FFAAFFAAFF55FF00AAAA00AA5555FFFF55FFFFAA00AAAAFF
FFFF00FFFF55AAFF005555AAFFFFAAAAFFFF00FFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAAFFAAFFFFFFFFAA00FFFFFFAA0055AAFFAAAAFFFFAA555555
0000AA00FFAAFF5500FFFF555500FF005555FFFF0055FFAAFF00AA0000555555AAFFFFAA
AAFFAA5500AAFFFFFF00AAFFFFFFFFAAFFAAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFF550055555500FFFFFF55FF00FFAAFFAAFFFFFFFFAA00FF
AA55FF00FF0055AAAAAAFFAA00FFFFFF00AAFFAAAAAA5500FF00FF55AAFF00AAFFFFFFFF
AAFFAAFF00FF55FFFFFF005555550055FFFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFF00FFAA00FFFFFF55FF55FFAAAA0055FFFF55FFFFAA55
00FFAAAAAAFF5555AA555500FFFFFFFFFF005555AA5555FFAAAAAAFF0055AAFFFF55FFFF
5500AAAAFF55FF55FFFFFF00AAFF00FFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFFAA5500FFFFFFFF555555FFFFAAFF555500AAFFAAAA00
FFFFFFAAFFFF5555FF00AAFF55FFFFFF55FFAA00FF5555FFFFAAFFFFFF00AAAAFFAA0055
55FFAAFFFF555555FFFFFFFF0055AAFFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FFFFFFFFFF5555FF55FFFFAAAA55AAFFFF5500FF
FFFFFFFFAAAAFF00AA55FF000000FF000000FF55AA00FFAAAAFFFFFFFFFF0055FFFFAA55
AAAAFFFF55FF5555FFFFFFFFFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFFFFF55FF555555FFFFFFAAFF0055AA00FFFF
FF55FFFFFFAAFFAA5555FFFF00FFFFFF00FFFF5555AAFFAAFFFFFF55FFFFFF00AA5500FF
AAFFFFFF555555FF55FFFFFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500AA55AA00FFAA00555500FF00FFAAFF55FF
FF55550055AA5500FFAA0000FFFFFFFFFF0000AAFF0055AA55005555FFFF55FFAAFF00FF
00555500AAFF00AA55AA0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FF5555AAFFAAFF5555FFAAAAAAFFFF5555
5555FF55AAAA00FFFFFFAA55FFFFFFFFFF55AAFFFFFF00AAAA55FF55555555FFFFAAAAAA
FF5555FFAAFFAA5555FF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF00AAAAFFFF5555FFFFAAFFFF55FF55
55FF55FF5500FFFFFFFFFFAA0000FF0000AAFFFFFFFFFF0055FF55FF5555FF55FFFFAAFF
FF5555FFFFAAAA00FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55AA55555555FF55FFFFAAAAFF0000
0000FFAAAA55FFFFFFFF55FF00FFFFFF00FF55FFFFFFFF55AAAAFF00000000FFAAAAFFFF
55FF55555555AA55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF005500000000FFAAAAFFFFAAAAAA
AAAAAAFFFFAA0000FF000000FFFFFFFFFF000000FF0000AAFFFFAAAAAAAAAAAAFFFFAAAA
FF000000005500FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA55AAFF55AAFFAAFFFFFFFFAAFF
FFAAFFFFFFFFAA55FFFF00FFFFFFFFFFFFFF00FFFF55AAFFFFFFFFAAFFFFAAFFFFFFFFAA
FFAA55FFAA55AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FF55FF550055FFFFFFFFFFAA
AAFFFFFFFFFFFFAA0000FFFFFFFFFFFFFFFFFF0000AAFFFFFFFFFFFFAAAAFFFFFFFFFF55
0055FF55FF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FF55FF55AAAAFFAAAAFFAA
FFFFFFFFFFFF55FF00FFFF55FFFFFFFFFF55FFFF00FF55FFFFFFFFFFFFAAFFAAAAFFAAAA
55FF55FF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA550000AAFFFFAAAA00AA55
5500AA00555555FFFF0000FFAAAAFFAAAAFF0000FFFF55555500AA005555AA00AAAAFFFF
AA000055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFFFAAAAFFFFAA5555
FF55AA55FF5555FFFF55AAFFAAFFFFFFAAFFAA55FFFF5555FF55AA55FF5555AAFFFFAAAA
FFFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAAFFFFFFFFAA00
FF00AAAA55000000FF00AAAAFFFFFFFFFFAAAA00FF00000055AAAA00FF00AAFFFFFFFFAA
FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF550055555500FF
FFFF0055FF55AAFF55FFAAFFFFFFFFFFFFFFAAFF55FFAA55FF5500FFFFFF005555550055
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00FFAA00FFFF
FFFF55AAAAFF0055AAAAFFFFFFFFFFFFFFFFFFAAAA5500FFAAAA55FFFFFFFF00AAFF00FF
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA5500FFFFFF
FF55FF5500FF00FFAAFFFFFFFFFFFFFFFFFFFFFFAAFF00FF0055FF55FFFFFFFF0055AAFF
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FFFFFFFF
FF555555FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF555555FFFFFFFFFF00AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFFFFF
55FF5555FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF5555FF55FFFFFF55FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500AA
55AA00FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF00AA55AA0055AAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FF
5555AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA5555FF00FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA
FF00AAAAFFFFFFFF55FFFFFFFFFFFFFFFFFFFFFF55FFFFFFFFAAAA00FFAAAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
FF55AA555555555555FFFFFF55FFFFFF55FFFFFF555555555555AA55FFFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAFF005500000000005555550000FF000055555500000000005500FFAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAFFAA55AAFF55AAFF5555FF55AAFFAA55FF5555FFAA55FFAA55AAFFAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAA00FF55FF5500550000FFAAFFAAFF0000550055FF55FF00AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFF55FF55FF55AAAAAAAAFFFFFFAAAAAAAA55FF55FF55FFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAA550000AAFFFFAAFFFF55FFFFAAFFFFAA000055AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAFF00FFFFAAAAFFFF55FF55FFFFAAAAFFFF00FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAAFFAAFFFFFF555555FFFFFFAAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFFF5500555555FF5555550055FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAFF00FFAA00FF00AAFF00FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFAA5500FFFFFF0055AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA00FFFFFFFFFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF55FFFFFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA550055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 3.74539 0.782187 3.8327 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAAA55FFFF005500550000AAAAAAAAAAAAFFFFFFAAAA55AA005500AA0055AA5500
00000000FFFFFFFF0055FFFFFFAAFFAAFFFFFF5500FFFFFFFF000000000055AA5500AA00
5500AA55AAAAFFFFFFAAAAAAAAAAAA000055005500FFFF55AAAAAAAAFF
FFFFAAFFFFAA000000FFAA55AAFF55000055000055550055FF00AAAAAA55FF00FFAAFF00
00FFFF0000AA000000FFAAAAFFAAFFAAFFAAAAFF000000AA0000FFFF0000FFAAFF00FF55
AAAAAA00FF55005555000055000055FFAA55AAFF000000AAFFFFAAFFFF
FFFFFFAAAAFFFF00FFFFFFAA00AA00FF00FFAA55FF555555FFFF005500FFAAAAAAFFFFFF
00000000FFFFAA5500AA00AAAAFFFFFFAAAA00AA0055AAFFFF00000000FFFFFFAAAAAAFF
005500FFFF555555FF55AAFF00FF00AA00AAFFFFFF00FFFFAAAAFFFFFF
FFFFFFFFAAFFAAAAAAFFAAAA005500AA005555AAAAFF00AAFFAAAAAA55FFFFAAFFFFFFFF
FF0000FFFFFFFFAA0055FFAAFFFFFFFFFFAAFF5500AAFFFFFFFF0000FFFFFFFFFFAAFFFF
55AAAAAAFFAA00FFAAAA555500AA005500AAAAFFAAAAAAFFAAFFFFFFFF
FFFFFFFFFFAAAA00AAAAFFFFAA55AAFFFF00AAFFFFAAAAAA00005500FFAAAAFFFF55FFFF
FFFF00000000000055AAAAFFFFFFFFFFFFFFAAAA55000000000000FFFFFFFF55FFFFAAAA
FF00550000AAAAAAFFFFAA00FFFFAA55AAFFFFAAAA00AAAAFFFFFFFFFF
FFFFFFFFFFFFAAFF550000AA00AAFFFFFFFF00555500005500AA55AA000055005555FFFF
FFFFFF0000FF0000FFAAFFFFFFFFFFFFFFFFFFAAFF0000FF0000FFFFFFFFFF5555005500
00AA55AA00550000555500FFFFFFFFAA00AA000055FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA5500AAAAAA0000000000FFAA0055AAAAAA00FF55AAFF00FFAA0000
AA000000FFFFFF0000AAAAFFAAAAFFAAAAFFAAAA0000FFFFFF000000AA0000AAFF00FFAA
55FF00AAAAAA5500AAFF0000000000AAAAAA0055AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF00005500FF0000FF00000055AAAA00AAAAAAFF005555550000FF
FFAA5500AA000000FFFFAAFFAAFFFFFFAAFFAAFFFF000000AA0055AAFFFF000055555500
FFAAAAAA00AAAA55000000FF0000FF00550000FFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAAAA55FFFF000000FFFF00AAAA005500FF55FFAA00FFAA55FF
FFFFAA005500AA55FFFFFFAAAA000000AAAAFFFFFF55AA005500AAFFFFFF55AAFF00AAFF
55FF005500AAAA00FFFF000000FFFF55AAAAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFFAA000000FF000000AA5555AA00FFFF555500FFFFFFAA00
0000AAAAAA5500FFAAAAFFAAFFFF00FFFFAAFFAAAAFF0055AAAAAA000000AAFFFFFF0055
55FFFF00AA5555AA000000FF000000AAFFFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFFFF00FFFFFF0000FF5555FF000000AAFF00000000AAAA
AAAAAA00AAAA55FFFFAAFFAAFFAAAAAAFFAAFFAAFFFF55AAAA00AAAAAAAAAA00000000FF
AA000000FF5555FF0000FFFFFF00FFFFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFFAAAAAAFFAAAAAAAAFF00AA0055AAFFFFFF0000FFFFAA
FFFFAAFF5500FFAAAAFFFFFFAAAA00AAAAFFFFFFAAAAFF0055FFAAFFFFAAFFFF0000FFFF
FFAA5500AA00FFAAAAAAAAFFAAAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAAFFFFAAFFFFFF0055AAAA00000000FFFFFFFF
AAAAFFFF55555500005555005500FF00550055550000555555FFFFAAAAFFFFFFFF000000
00AAAA5500FFFFFFAAFFFFAAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF550000AA00AA000000FFAAFFFF0000FFFF55FFFF
FFAAFFAAAA55AAAAAAAA55AAFF000000FFAA55AAAAAAAA55AAAAFFAAFFFFFF55FFFF0000
FFFFAAFF000000AA00AA000055FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500AAAAAA0055AAFFAAFFAAAAAAAAFFAA0000
00AAAAFFFFAA00AAAA00AAFFFFFF00FFFFFFAA00AAAA00AAFFFFAAAA000000AAFFAAAAAA
AAFFAAFFAA5500AAAAAA0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00005500FF00AAAAFFFFFFAAFFFFAAAA0055
AAFFFFAAAAFFFF005500AAAAFFAAAAAAFFAAAA005500FFFFAAAAFFFFAA5500AAAAFFFFAA
FFFFFFAAAA00FF00550000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA55FFFF0055005555000000005500AA
FFFFFF55000000AA55AAFFFFAAAA00AAAAFFFFAA55AA00000055FFFFFFAA005500000000
5555005500FFFF55AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAA000000FFAA55AAAAAAAAAAAA5500
000000AAFF55AA00AAFFFFFF5500FF0055FFFFFFAA00AA55FFAA0000000055AAAAAAAAAA
AA55AAFF000000AAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFF00FFFFFFAA00AAAA00AAAA00FF
FF0000FF55FF5500AAAAFFAAAA550055AAAAFFAAAA0055FF55FF0000FFFF00AAAA00AAAA
00AAFFFFFF00FFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAAAAAFFAAAA005500FFFFAAFF55
FFFF0000AAFFAA00550000AAAA00FF00AAAA00005500AAFFAA0000FFFF55FFAAFFFF0055
00AAAAFFAAAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAAFFFFAA55AA0000005555
FFFF55AAFFFFFFAA55AAFF5500FFFFFF0055FFAA55AAFFFFFFAA55FFFF5555000000AA55
AAFFFFAAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF550000AA00AAFFFF0000FFAA
0000AAFFFFFFFFFFAA00AA00FFFFFFFFFF00AA00AAFFFFFFFFFFAA0000AAFF0000FFFFAA
00AA000055FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500AAAAAA000000FFFFFF
AA550000AA0000000055AA55FFFFFFFFFF55AA5500000000AA000055AAFFFFFF000000AA
AAAA0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00005500FFFF00000000
AAAA5500AAAAAAAAAAAA5555FFFFFFFFFF5555AAAAAAAAAAAA0055AAAA00000000FFFF00
550000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAA55FFFFFF0000FF
FFAAFF00FF5500FF5500FFAA0000000000AAFF0055FF0055FF00FFAAFFFF0000FFFFFF55
AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAA000000AA55FF
FFFFAAAAAAFF0000AAFF55FF0000FF0000FF55FFAA0000FFAAAAAAFFFFFF55AA000000AA
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFF00FFFFAA00
00AA00AAAA0000FF005555FFFF000000FFFF555500FF0000AAAA00AA0000AAFFFF00FFFF
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAAAAAFFAAFF
55AA55000055AA0000FFAA000000FF000000AAFF0000AA55000055AA55FFAAFFAAAAAAFF
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAAFFFF
5555AAAAAAAA5555555500FFFF000000FFFF0055555555AAAAAAAA5555FFFFAAAA00AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF550000AA
00FFAAFFFFAAFF00AAFF00000000FF00000000FFAA00FFAAFFFFAAFF00AA000055FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500AA
AAAAFFFFFFFFAAAAAA0000FFFF000000FFFF0000AAAAAAFFFFFFFFAAAAAA0055AAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0000
550000AA0000005500FF00000000FF00000000FF0055000000AA0000550000FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA
AA55FFAAFF55AA00FFFFFF0000FFFFFF0000FFFFFF00AA55FFAAFF55AAAAAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
FFAA00005555FF0000000000FFFFFFFFFF0000000000FF55550000AAFFFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAFFFF00FFAA0000FF0000FFFFFFFFFFFFFF0000FF0000AAFF00FFFFAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAFFAAAAAAFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFAAAAAAFFAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAA00AAAAFFAA5500AA00000000000000AA0055AAFFAAAA00AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFF550000AAAA5500FF0000FF0000FF0055AAAA000055FFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAA5500AAAA00FFFFFF000000FFFFFF00AAAA0055AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAFF00005500AA000000FF000000AA00550000FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAAAA55FF0000FFFFFF0000FF55AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFFFAA0000FFFFFFFFFF0000AAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAFFFF00000000000000FFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFAAAAAAAAAAAAAAAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA00AAAA00AAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF5500FF0055FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA550055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 3.74539 0.97619 3.8327 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAFFFFFF00FFFF550000FFAAAAFF00FFFFFF00555500FF00550000FF00FFFF0000
5500FFFFFFAAFFFF5555FFFF00FF00FF00FFFF5555FFFFAAFFFFFF00550000FFFF00FF00
005500FF00555500FFFFFF00FFAAAAFF000055FFFF00FFFFFFAAAAAAFF
FFFFAAFFFF55FF00FF5500AAFF00555500FFFFFFFFFF0000FFFF55AA00FFFFFF0055FF55
5555FFFF5500000000FF0055FFAAAAAAFF5500FF0000000055FFFF555555FF5500FFFFFF
00AA55FFFF0000FFFFFFFFFF00555500FFAA0055FF00FF55FFFFAAFFFF
FFFFFFAAAA0055FF5500AAFFFFFF0000FFFFFFFFFFFFFF00AAAA005555FFFFFFFF000000
FF00000000FFFF00FFFFFF000000AA000000FFFFFF00FFFF00000000FF000000FFFFFFFF
555500AAAA00FFFFFFFFFFFFFF0000FFFFFFAA0055FF5500AAAAFFFFFF
FFFFFFFFAAFF000000FFAAFFAAAA00FFFF55FFFFFF5500FFFFAAFF0000FF55FFFF55AAAA
AAFF5555FF5500FFFFFFFFFF00FFAAFF00FFFFFFFFFF0055FF5555FFAAAAAA55FFFF55FF
0000FFAAFFFF0055FFFFFF55FFFF00AAAAFFAAFF000000FFAAFFFFFFFF
FFFFFFFFFFAAAAAAAAAAFFFFFFAAFF55FF0000000000FFFFFFFFAAAAAAAA0055FF000055
5500FF000000FFFFFFFFFFFFFF005500FFFFFFFFFFFFFF000000FF0055550000FF5500AA
AAAAAAFFFFFFFF0000000000FF55FFAAFFFFFFAAAAAAAAAAFFFFFFFFFF
FFFFFFFFFFFFAAFFFFAAFFAAAA000000FF55AAFF00FFFFFFFFFFFFAAFFFFAA5500FFAA00
55AAAAFF5555FFFFFFFFFFFFFF555555FFFFFFFFFFFFFF5555FFAAAA5500AAFF0055AAFF
FFAAFFFFFFFFFFFF00FFAA55FF000000AAAAFFAAFFFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA000000AA00FFAA55555500FFFFFFFFFFFFFFFFAAAA0000FFFFFFAA
00555500FF000000000000000000FF000000000000000000FF00555500AAFFFFFF0000AA
AAFFFFFFFFFFFFFFFF00555555AAFF00AA000000AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF00FFAAFF005555555555FFFFFFFFFFFFFFFFFFAAFF00FF55FFFF
AA0055AAAAFF00FFFF00AAFF00FFFFFF00FFAA00FFFF00FFAAAA5500AAFFFF55FF00FFAA
FFFFFFFFFFFFFFFFFF555555555500FFAAFF00FFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAAFFFFFF0000FF0000FF55FFFFFFFF55FFFFFFAAAAAA0055FF
FFAA55000055FF5500FFFFAAAAAAFFAAAAAAFFFF0055FF55000055AAFFFF5500AAAAAAFF
FFFF55FFFFFFFF55FF0000FF0000FFFFFFAAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFF55FF00FFAAAA55FF000000000000FF55FFFFAAFFFF0000
000055AAFF000000FFFFFFFFAAFFFFFFAAFFFFFFFF000000FFAA5500000000FFFFAAFFFF
55FF000000000000FF55AAAAFF00FF55FFFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA0055FF55000055AA55AAAAAAAA55FF00000000AAAAFF00
AAFF000055FF5555FFFFFF55000000000055FFFFFF5555FF550000FFAA00FFAAAA000000
00FF55AAAAAAAA55AA55000055FF5500AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF000000FFAA005555550000AA0055FF5555FFAAFFFF55
5500FFAA5500FF0000000000FFFF00FFFF0000000000FF0055AAFF005555FFFFAAFF5555
FF5500AA000055555500AAFF000000FFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAFFFF0000FF00FFFFAA5500FF000000AAAA00
55AAAA0000FFAAAA55FF55AAFFAAAAAAFFAA55FF55AAAAFF0000AAAA5500AAAA000000FF
0055AAFFFF00FF0000FFFFAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAAFFAAAA55FF00FF550000FFFFFF00FFFFAAFF
00005555FF55000055AA550000005500000055AA55000055FF55550000FFAAFFFF00FFFF
FF000055FF00FF55AAAAFFAAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA000000AA0055FF5500AAFF0055FF00AAAAFFFF
FF00FF000000FFFF000055AAFF00FF00FFAA550000FFFF000000FF00FFFFFFAAAA00FF55
00FFAA0055FF5500AA000000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFAAFF000000FFFFAAAA5500FFAAFFFF55
00FFFFFF00FFAAAAFF55555500FFFFFF00555555FFAAAAFF00FFFFFF0055FFFFAAFF0055
AAAAFFFF000000FFAAFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFF00FFFF55000055AAAA00000000
FFFFFFFFFF00555500FF0000FFFFFFFFFF0000FF00555500FFFFFFFFFF00000000AAAA55
000055FFFF00FFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55FF00FF5500AAFF00005555FF5555
FFFFFFFFFFFF0000FFAAAA55FFFFFFFFFF55AAAAFF0000FFFFFFFFFFFF5555FF55550000
FFAA0055FF00FF55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055FF5500AAFFFFFF00FF000000FF
0055FFFF5500FFFF00555500AAAAFFAAAA00555500FFFF0055FFFF5500FF000000FF00FF
FFFFAA0055FF5500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF000000FFAAFFAAAA00FF55AAAAAA
FF00000000FFAAAAFF0000FFAAFFFFFFAAFF0000FFAAAAFF00000000FFAAAAAA55FF00AA
AAFFAAFF000000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAFFFFFFAAFF5500AA0000
AAAAAAAAAAAAFFFFAAAAAAAAFFFFFFFFFFAAAAAAAAFFFFAAAAAAAAAAAA0000AA0055FFAA
FFFFFFAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAAFFAAAA000000FFAAFF00
AA0000550000AAAA00005500000000000000550000AAAA0000550000AA00FFAAFF000000
AAAAFFAAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA000000AA00FFAA555500FF
FFAA00FF00AAFFFFAA00FF00FFFF00FFFF00FF00AAFFFFAA00FF00AAFFFF005555AAFF00
AA000000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFAAFF0055555555FF
FFFFAA00AAFFFFFFFFAA00AAFFAAAAAAFFAA00AAFFFFFFFFAA00AAFFFFFF5555555500FF
AAFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFF0000FF0000
000000AAFFFFFF55FFFFAA000000AA000000AAFFFF55FFFFFFAA0000000000FF0000FFFF
FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55FF00FFAAAA55
FF55AAFFFFFF5500AAAAFFFF00FFAAFF00FFFFAAAA0055FFFFFFAA55FF55AAAAFF00FF55
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055FF55000055
AA550000000000FFAAFFFFFFFF005500FFFFFFFFAAFF000000000055AA55000055FF5500
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF000000FFAA00
555555FFAA55AAAAFFFFFFFFFF555555FFFFFFFFFFAAAA55AAFF55555500AAFF000000FF
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAFFFF
0000FF0055555500000000000000FF0000000000000055555500FF0000FFFFAAAAAAAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAAFFAA
AA55FF00FF0000FFFF00AAFF00FFFFFF00FFAA00FFFF0000FF00FF55AAAAFFAAFFFFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA000000
AA0055FFAAAA55FFFF555500FFFFFFFFFF005555FFFF55AAAAFF5500AA000000AAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FF
AAFF000000AA0055FF0000FFFFFFFFFFFFFF0000FF5500AA000000FFAAFF00FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA
FFFFFF00FFFFAA5500FFFF0055FFFFFF5500FFFF0055AAFFFF00FFFFFFAAAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
FF55FF00FF550000FFAAAAFF0000000000FFAAAAFF000055FF00FF55FFFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AA0055FF5500AAFF00555500FFFF00FFFF00555500FFAA0055FF5500AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAFF000000FFAAFFAA0055AAFFAAAAAAFFAA5500AAFFAAFF000000FFAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAAAAAAFFFFFFAA550000005500000055AAFFFFFFAAAAAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFFAAFFAAAA0000FFFF00FF00FFFF0000AAAAFFAAFFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAA000000AA00FFAAAAFF55FFAAAAFF00AA000000AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAFF00FFAAFF00555500FF00555500FFAAFF00FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAAFFFFFF0000FFFFFF0000FFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFFF55FF00FFFF55FFFF00FF55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA0055FF5500FF0055FF5500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF000000FFFFFF000000FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAAAAAAFFAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFFAAFFAAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA000000AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 3.84144 0.200176 3.92875 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAFF55AAFFFFAAAAAA5500AAFFFFFFFFFFAAAAFFFFFFAAFF55FFAAFF5555AAFFFF
00AA0055FFAA00FF55FFAA0055FFAAFF5500AAFF55FF00AAFF5500AA00FFFFAA5555FFAA
FF55FFAAFFFFFFAAAAFFFFFFFFFFAA0055AAAAAAFFFFAA55FFAAAAAAFF
FFFFAAFFFF55AAAAFFAAFFFFAA5555FFFFFFFFFF5555FFFFFFFFAAAAAAFFFF55AAFF0000
FF5555AAFFAA0000FFFF5555AAFFAAFFAA5555FFFF0000AAFFAA5555FF0000FFAA55FFFF
AAAAAAFFFFFFFF5555FFFFFFFFFF5555AAFFFFAAFFAAAA55FFFFAAFFFF
FFFFFFAAAAFF5555FFFFAAAAFF00FFFFFFFFFFFF55AAFFAAAAFFAAFFFFAAAAFF55555500
FF00FFFFAAAA555500AA55FFAAFFAAFFAAFF55AA005555AAAAFFFF00FF00555555FFAAAA
FFFFAAFFAAAAFFAA55FFFFFFFFFFFF00FFAAAAFFFF5555FFAAAAFFFFFF
FFFFFFFFAAFFAA55FFFFFFAA0055FFFFFFFFFF55FFAAFFAAFFFFFFAAAAFFFFAAAAAAAAAA
0055FFFFFFAAFF55AA55AAFFAAFFAAFFAAFFAA55AA55FFAAFFFFFF5500AAAAAAAAAAFFFF
AAAAFFFFFFAAFFAAFF55FFFFFFFFFF5500AAFFFFFF55AAFFAAFFFFFFFF
FFFFFFFFFFAAAA55FFFFFF5555000000FF0000FFFF555555FFFFFFFFAAFFAAAA55AAAA55
AA55FFFFFFFFAAAAAA55FF55FF55FF55FF55FF55AAAAAAFFFFFFFF55AA55AAAA55AAAAFF
AAFFFFFFFF555555FFFF0000FF0000005555FFFFFF55AAAAFFFFFFFFFF
FFFFFFFFFFFFAAFF55FFFFFF00FF5500FF0055FFFF55AAFF55FFFFFFFFAAAA55AAFFFFAA
55AAFFAAAAFFAAFFFFAA550000FFFFFF000055AAFFFFAAFFAAAAFFAA55AAFFFFAA55AAAA
FFFFFFFF55FFAA55FFFF5500FF0055FF00FFFFFF55FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAFFAAAA00550055AA55FFFFFF00AA55FFFFFFFFFFAAFF55555555
FFAAFFAAFFFFFFAAAAFFFF0055FFFFFF5500FFFFAAAAFFFFFFAAFFAAFF55555555FFAAFF
FFFFFFFF55AA00FFFFFF55AA55005500AAAAFFAAAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF5555FF00FF55AAAAAAFFAAAA00FFFF55FFFFFFFFAAAAAAAAAA
AAFFFFFFAAAAFFAAFFFFFF55000000000055FFFFFFAAFFAAAAFFFFFFAAAAAAAAAAAAFFFF
FFFF55FFFF00AAAAFFAAAAAA55FF00FF5555FFFFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAFF55AA00AA55FF5555FFFFAA000000FFFFFFFFFFFFAAFFFFAA
FFFFFFFF5555FFFFAAAAFFAA5555AA5555AAFFAAAAFFFF5555FFFFFFFFAAFFFFAAFFFFFF
FFFFFF000000AAFFFF5555FF55AA00AA55FFAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFAA55AA55AAFFAA55FFFF55550055FFFFFFFFFF55FF55FFFF
AAAAFFAAAAAAAAFFAAFFFFFFAA55FF55AAFFFFFFAAFFAAAAAAAAFFAAAAFFFF55FF55FFFF
FFFFFF55005555FFFF55AAFFAA55AA55AAFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA55FF55AAAAFFFF0000005500FFFFFFFFFF55FFAAAAAAFF
AAFFFFFFAAFFFFAAAA5500AA55AAFFAA55AA0055AAAAFFFFAAFFFFFFAAFFAAAAAAFF55FF
FFFFFFFF0055000000FFFFAAAA55FF55AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFAAFF0000FF55005500FF000000000055AAAA55AA
00FF0000FFAAAAFFFFAA5555FFAAFFAAFF5555AAFFFFAAAAFF0000FF00AA55AAAA550000
000000FF00550055FF0000FFAAFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF0000AAAAFF550000AA5555AA5555AAFFFFAA55
AA550055FFFFAA0055AAAAAAAAFFFFFFAAAAAAAA5500AAFFFF550055AA55AAFFFFAA5555
AA5555AA000055FFAAAA0000FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF5500FFAAFFAA5555AAAAAAAA55FFAAFFAAAA55
FF55AA55FFFF5555AAFFFFAAFFFFFFFFFFAAFFFFAA5555FFFF55AA55FF55AAAAFFAAFF55
AAAAAAAA5555AAFFAAFF0055FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF5500AAFFAAFF55AAAA55AAAAAAFFFF5555FF
AAAAAA55FFFFFF00FFAAAAFFFFFFFFFFFFFFAAAAFF00FFFFFF55AAAAAAFF5555FFFFAAAA
AA55AAAA55FFAAFFAA0055FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA5555FFFFAAAAAA55AAFF00AAFFAAAAAAAA
FFFFAAFF55FFFF5500AAFFFFFFFFFFFFFFFFFFAA0055FFFF55FFAAFFFFAAAAAAAAFFAA00
FFAA55AAAAAAFFFF5555AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FFAAAAFF00AAFF555555AAAAFFFFAAFF
FFFFFFAAAAAAFFAA5555FFFFFFFFFFFFFFFFFF5555AAFFAAAAAAFFFFFFFFAAFFFFAAAA55
5555FFAA00FFAAAAFF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FF555555AAAAFF55AAFFFFAAAAFFFF
FFFF55FF5555FFFFAA55FFFFFFFFFFFFFFFFFF55AAFFFF5555FF55FFFFFFFFAAAAFFFFAA
55FFAAAA555555FF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF55AAFFFFAAAAAA5500AAFFFFFF
FF55FFAAAAAAAAFFAAFF55FFFFFF55FFFFFF55FFAAFFAAAAAAAAFF55FFFFFFFFAA0055AA
AAAAFFFFAA55FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55AAAAFFAAFFFFAA5555FFFFFF
FF55AA00FFAAFFFFFFAAAAAAFFAAAAAAFFAAAAAAFFFFFFAAFF00AA55FFFFFFFF5555AAFF
FFAAFFAAAA55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF5555FFFFAAAAFF00FFFFFF55
FFFF00AAAAFFFFFFFFFFAAFFFFFFAAFFFFFFAAFFFFFFFFFFAAAA00FFFF55FFFFFF00FFAA
AAFFFF5555FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA55FFFFFFAA0055FFFFFFFF
000000AAFF0000FF0000FFAAAAFFAAFFAAAAFF0000FF0000FFAA000000FFFFFFFF5500AA
FFFFFF55AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FFFFFF5555000000FF00
00AAAA00FF0055555500FF00AAFFAAFFAA00FF0055555500FF00AAAA0000FF0000005555
FFFFFF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFFFFF00FF5500FF00
5555FF5500AAAAAAAAAA0055FF55FF55FF5500AAAAAAAAAA0055FF555500FF0055FF00FF
FFFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAAAA00550055AA
55FFAAAAAA00FFAAFF00AAAAAAFF55FFAAAAAA00FFAAFF00AAAAAAFF55AA55005500AAAA
FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF5555FF00FF55AA
AAAAFFFFAA00AA55AA00AAFFFFAAAAAAFFFFAA00AA55AA00AAFFFFAAAAAA55FF00FF5555
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF55AA00AA55FF
5555FFFF5555AAAAAA5555FFFFFFAAFFFFFF5555AAAAAA5555FFFF5555FF55AA00AA55FF
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA55AA55AAFF
AA55FFFFFF00FFAAFF00FFFFFF55FF55FFFFFF00FFAAFF00FFFFFF55AAFFAA55AA55AAFF
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF55AAAA
FFFF00000000AA55AA00000000FFFFFF00000000AA55AA00000000FFFFAAAA55FF55AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFAAFF
0000FF550055FF55AAAA0000AAAAFFAAAA0000AAAA55FF550055FF0000FFAAFF55FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF00
00AAAAFF550000FFFFAA0000AAFFFFFFAA0000AAFFFF000055FFAAAA0000FFAAAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55
00FFAAFFAA555500AA55AA5555FFFFFF5555AA55AA005555AAFFAAFF0055FFFFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF
5500AAFFAAFF55AA55AAFF00FFFFFFFFFF00FFAA55AA55FFAAFFAA0055FFAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
AA5555FFFFAAAAAA55FF55FF0000FF0000FF55FF55AAAAAAFFFF5555AAFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AA55FFAAAAFF00AAFF55FFAAAA000000AAAAFF55FFAA00FFAAAAFF55AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAFF55FF555555AAAAFF55FF5555005555FF55FFAAAA555555FF55FFAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAAFF55AAFFFFAAAAAAFF55AA55FFAAAAAAFFFFAA55FFAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFF55AAAAFFAAFF00AA55FF55AA00FFAAFFAAAA55FFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAAFF5555FFFFAAAA00FFFFFF00AAAAFFFF5555FFAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAFFAA55FFFFFFAA0000FF0000AAFFFFFF55AAFFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAA55FFFFFF555500FF005555FFFFFF55AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFF55FFFFFF00FF55FF00FFFFFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAAAFFAAAA005500AAAAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFFF5555FF00FF5555FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAFF55AA00AA55FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFAA55AA55AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA55FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 3.84144 0.39418 3.92875 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAA5555AAAA0055AA55AA00000055005555555500555555005555FF55005555AAAA55
55555555000000AAFFFF555555005500555555FFFFAA0000005555555555AAAA55550055
FF55550055555500555555550055000000AA55AA5500AAAA5555AAAAFF
FFFFAAFF55AA0055FFAAFF0000000000AAAA55FF5555AAAAAA5555FF55FF550055555555
FF55AAAA5555AA55000055550055FF55005555000055AA5555AAAA55FF555555550055FF
55FF5555AAAAAA5555FF55AAAA0000000000FFAAFF5500AA55FFAAFFFF
FFFFFFAAAA5500FFFFFFAAAA00AAAA00AA550055005555555555005500550055FF555500
550055AA0000AA55AA5555FF5500550055FF5555AA55AA0000AA550055005555FF550055
005500555555555500550055AA00AAAA00AAAAFFFFFF0055AAAAFFFFFF
FFFFFFFFAAFF5500005500AA55555555AA000000AAAAAAAAAA55AA55AA55AA55FFFF00AA
AA555500AAAA0055555500550055FF5500550055555500AAAA005555AAAA00FFFF55AA55
AA55AA55AAAAAAAAAA000000AA55555555AA0055000055FFAAFFFFFFFF
FFFFFFFFFFAAAA5555AAAA00555500555555AA5555555555555500AA00555555FFFF5500
AA55AAAA0055AA55AAAA555500FFFFFF005555AAAA55AA5500AAAA55AA0055FFFF555555
00AA0055555555555555AA55555500555500AAAA5555AAAAFFFFFFFFFF
FFFFFFFFFFFFAAFF55AA0055FFAA555500555555FF55AAAAAAAA555555AAAA55FFFF55AA
550055AA00AA00555555550055FFFFFF55005555555500AA00AA550055AA55FFFF55AAAA
555555AAAAAAAA55FF555555005555AAFF5500AA55FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA5500FFFFFFAA000000AA00005555555555550055555555FFFF55AA
000000AA555555AAAAAAAAAA0000550000AAAAAAAAAA555555AA000000AA55FFFF555555
55005555555555550000AA000000AAFFFFFF0055AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF5500005500AAAA00AA5555AAAAAAAAAAAA555500555500005555
55AA5555550055555555555555AA55AA5555555555555500555555AA5555550000555500
5555AAAAAAAAAAAA5555AA00AAAA0055000055FFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA5555AAAA0055AA550055555555555555550055FF55AA5555FF
555555FF5555AAAAAAAA55AAAA550055AAAA55AAAAAAAA5555FF555555FF5555AA55FF55
0055555555555555550055AA5500AAAA5555AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF55AA0055FFAAFF00555500555500555500FFFF555555FFAA
AA55AAAAFF55555555555500AA55AA55AA00555555555555FFAAAA55AAAAFF555555FFFF
00555500555500555500FFAAFF5500AA55FFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA5500FFFFFFAAAA0000AAAA55AA55FF5500005555005500
AA55AA0055005555FF55AAAA0055555500AAAA55FF5555005500AA55AA00550055550000
55FF55AA55AAAA0000AAAAFFFFFF0055AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF5500005500AA5555AA00555555FFFF0055FF5555AAAA
00555555AAAA00FFFF55555555AAAAAA55555555FFFF00AAAA55555500AAAA5555FF5500
FFFF55555500AA5555AA0055000055FFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555AAAA00555500AAAAAA55FFFF55005500555555
55AAAA55AA0055FFFF5555005555555555005555FFFF5500AA55AAAA5555555500550055
FFFF55AAAAAA00555500AAAA5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55AA0055FFAA5555555555FFFFFF005555AAAAAA
55AA00555555AAAAFFAA55AA55AAAAAA55AA55AAFFAAAA55555500AA55AAAAAA555500FF
FFFF5555555555AAFF5500AA55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500FFFFFFAA0000AAFF55FFFF550055555555
5500AAAAAA55AA005500AA00555555555500AA005500AA55AAAAAA0055555555550055FF
FF55FFAA0000AAFFFFFF0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5500005500AAAA005500550000AAAAAA55AA
AA555555555500AAAA555555AAAAAAAAAA555555AAAA005555555555AAAA55AAAAAA0000
55005500AAAA0055000055FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555AAAA0055AA55AA55AA555555555500
AA55AAAAAAAA5555555500555555555555550055555555AAAAAAAA55AA005555555555AA
55AA55AA5500AAAA5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55AA0055FFAAFF0000AA55FFAA55AAAA
00555555555555FFAA55AA55AAAAAAAAAA55AA55AAFF55555555555500AAAA55AAFF55AA
0000FFAAFF5500AA55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500FFFFFFAAAA00AA55FFFFAA5500
AAAAAAAAAAAA55FFFFAA005555555555555500AAFFFF55AAAAAAAAAAAA0055AAFFFF55AA
00AAAAFFFFFF0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5500005500AA555555FFFFFFAA55
55555555555555000055AA55AAAAAAAAAA55AA5500005555555555555555AAFFFFFF5555
55AA0055000055FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555AAAA0055550055000055AA
AAAAAAAAAA55AAAA00AA005555555555555500AA00AAAA55AAAAAAAAAAAA550000550055
5500AAAA5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55AA0055FFAA555500FF5555
55555555555500AA555555AAAAAAAAAAAAAA555555AA005555555555555555FF005555AA
FF5500AA55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500FFFFFFAA0000005555
FF55AAAAAAAA5555550055555555555555555500555555AAAAAAAA55FF5555000000AAFF
FFFF0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5500005500AAAA00AA00
00555555555555FF5555AAAAAAAAAAAAAAAAAA5555FF5555555555550000AA00AAAA0055
000055FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555AAAA0055AA5500
FF555500555500550055555555555555555555550055005555005555FF0055AA5500AAAA
5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55AA0055FFAAFF00
55005555AAFF005555AAAA55AAAA55AAAA55AAAA555500FFAA5555005500FFAAFF5500AA
55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500FFFFFFAAAA
000000AAFFFF55005555555500AA55AA00555555550055FFFFAA000000AAAAFFFFFF0055
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5500005500AA
5555AA5500005555AAAAAA55AA550055AA55AAAAAA5555000055AA5555AA0055000055FF
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5555AAAA00
555500AA00AAAAAA5500AA55AA000000AA55AA0055AAAAAA00AA00555500AAAA5555AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55AA0055
FFAA555555AA0055AAAA00555555AA55555500AAAA5500AA555555AAFF5500AA55FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500FF
FFFFAA0000AA555500AA5555FF555555FF5555AA005555AA0000AAFFFFFF0055AAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF5500
005500AAAA00555500FF00FFFFFF00FFFFFF00FF00555500AAAA0055000055FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55
55AAAA0055AA55FF55000000550000005500000055FF55AA5500AAAA5555AAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
55AA0055FFAAFF55FF5500FF5555AA5555FF0055FF55FFAAFF5500AA55FFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AA5500FFFFFFAAAAAAFF005500555555005500FFAAAAAAFFFFFF0055AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAFF5500005500AA55000000AAAAAAAAAA00000055AA0055000055FFAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAA5555AAAA005555AA55555555555555AA555500AAAA5555AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFF55AA0055FFAA55005555FF55550055AAFF5500AA55FFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAA5500FFFFFFAA5555FF55FF5555AAFFFFFF0055AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAFF5500005500AAFF55FF55FFAA0055000055FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAA5555AAAA00550055005500AAAA5555AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFF55AA0055FF550055FF5500AA55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA5500FFFF55AA55FFFF0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF550000555555000055FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA5555AAAAAA5555AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF5555555555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA55FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 3.84144 0.588183 3.92875 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAFFAAFF55AAAAAAAAAAAA0000AAAAAAFF55FFAAAA55AA005500AAAAAAAAAA55FF
00AAAA55AAAAFFAAFF55FFFFFFFFFFFFFFFFFF55FFAAFFAAAA55AAAA00FF55AAAAAAAAAA
005500AA55AAAAFF55FFAAAAAA0000AAAAAAAAAAAA55FFAAFFAAAAAAFF
FFFFAAFFFFFFAAAAAA0000AA00AA00FFAAFFFFAAAAAAFFFFAA5555FFAA00AAAA00AAAAAA
FF0055FFAAFFFFFFAAAAAAFFAAAAFFAAAAFFAAAAAAFFFFFFAAFF5500FFAAAAAA00AAAA00
AAFF5555AAFFFFAAAAAAFFFFAAFF00AA00AA0000AAAAAAFFFFFFAAFFFF
FFFFFFAAAAFFAAFFFFAA00FF5555AAAAFFFFFFFFAAFFFFFFFFAA55FFFFAA00AAAA555500
55AAAAAAFFFFFFFFFFAAFFFF5500FF0055FFFFAAFFFFFFFFFFAAAAAA55005555AAAA00AA
FFFF55AAFFFFFFFFAAFFFFFFFFAAAA5555FF00AAFFFFAAFFAAAAFFFFFF
FFFFFFFFAAFFAAFFAAAA00FF00FFFFAAFFAAAAFFAAFFAAAAFFAAFF55FFFFAA00AAAAAAAA
55FF0055FFFFFF55FFFFAAAAFF555555FFAAAAFFFF55FFFFFF5500FF55AAAAAAAA00AAFF
FF55FFAAFFAAAAFFAAFFAAAAFFAAFFFF00FF00AAAAFFAAFFAAFFFFFFFF
FFFFFFFFFFAAAA0055000000FFAAAAFFFFFFAAFFAAFFAAFFFFFFAAAAAAFFAAFF005500FF
55AA00FFFFFF55FFAAAAFFFFAAAAAAAAAAFFFFAAAAFF55FFFFFF00AA55FF005500FFAAFF
AAAAAAFFFFFFAAFFAAFFAAFFFFFFAAAAFF0000005500AAAAFFFFFFFFFF
FFFFFFFFFFFFAAFF00FFAA00FF0055FFFFFFFFAAAA005500AA5500005500AAAAFF00FFAA
AAAA00FF0000FFFFFFAAFFAAAA00AA00AAAAFFAAFFFFFF0000FF00AAAAAAFF00FFAAAA00
55000055AA005500AAAAFFFFFFFF5500FF00AAFF00FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA5500FFAAAA55FFFFFFFFFFAAFF00FFAAFF5555FFAA00AAAAFF0000
5555AAAAFF00AA5500AA005500FFAAFF005500AA0055AA00FFAAAA55550000FFAAAA00AA
FF5555FFAAFF00FFAAFFFFFFFFFF55AAAAFF0055AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF55555500FFFFFF55FFFF5500AAFFAAFFAA55FFFFAA0000AA55AA
AAAAAA0000FFAAFF5555AAAAAA550055AAAAAA5555FFAAFF0000AAAAAAAA55AA0000AAFF
FF55AAFFAAFFAA0055FFFF55FFFFFF00555555FFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAAAAAA5500AA55FFFF55AAAA005500AAAAAAFFAAFF00AAAAAA
00AA00AAFF0000AA55FFAAFFFFAA55AAFFFFAAFF55AA0000FFAA00AA00AAAAAA00FFAAFF
AAAAAA005500AAAA55FFFF55AA0055AAAAAAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFFAAFF5555AAFFAAAAAA00AAFF55550000AA555555FF0055
55FF00AAAAFF00AAAAAAFFFF55FF00FF55FFFFAAAAAA00FFAAAA00FF555500FF555555AA
00005555FFAA00AAAAAAFFAA5555FFAAFFFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFFFF55AAFFFF550000AAFFFF55AAFF00AAAAAAAAAAFF00
FFFF55550000FFAAFFFFAAAAFF55FF55FFAAAAFFFFAAFF00005555FFFF00FFAAAAAAAAAA
00FFAA55FFFFAA000055FFFFAA55FFFFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFFAAAAAA0055AAFF00AAAAFFAA555555FF005500555555
FFFFFF00FFAA0055FFFF550000FFFFFF000055FFFF5500AAFF00FFFFFF555555005500FF
555555AAFFAAAA00FFAA5500AAAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAA55FF0000005500AAAAAAAAAAFF00FFAA55FF
AAAAFFAA005555FFAAAAFF5555FFFFFF5555FFAAAAFF555500AAFFAAAAFF55AAFF00FFAA
AAAAAAAA0055000000FF55AAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0055FFAAAA55AAAAAA555500550055AAAAFFFF00
00555555AAAAAAAAFFFFAAAAAAAAFFAAAAAAAAFFFFAAAAAAAA5555550000FFFFAAAA5500
55005555AAAAAA55AAAAFF5500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FFFFAAFF550055FFAA55AAFF00FF5500AA55
AAAAAAAAAA0000AAAAFFAAFFFFAAFFAAFFFFAAFFAAAA0000AAAAAAAAAA55AA0055FF00FF
AA55AAFF550055FFAAFFFF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFFFAAAAAA55FFFFAA555555FFFF00AAAA
AA00AA0000AAFF0055FFFFAAAAFFFFFFAAAAFFFF5500FFAA0000AA00AAAAAA00FFFF5555
55AAFFFF55AAAAAAFFFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAAFFFFAA5500AAAAAAAAAAFFAA00AA
000000AAFF0055AAAAAAFFAAFFFFFFFFFFAAFFAAAAAA5500FFAA000000AA00AAFFAAAAAA
AAAA0055AAFFFFAAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAAAAFFFF00AAAA00AA00AA5555FF
00AAFF0055AAAAAA00AAAAFFFFFF55FFFFFFAAAA00AAAAAA5500FFAA00FF5555AA00AA00
AAAA00FFFFAAAAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAAFFFFFF5555AA55AA55AA55FFAA
AA555555FFAAFFFFAA00AAAAFFAAAAAAFFAAAA00AAFFFFAAFF555555AAAAFF55AA55AA55
AA5555FFFFFFAAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAFFAAAAFF55AA55FF00FF55AA00
AAAAAAAAAAFFFFFFFFAA00AA0055005500AA00AAFFFFFFFFAAAAAAAAAA00AA55FF00FF55
AA55FFAAAAFFAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00550055AAFFFF000000FFFFAA
00005500FF55FFFF55FF00AAAA55FF55AAAA00FF55FFFF55FF00550000AAFFFF000000FF
FFAA55005500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFAA55555555FF55555555
AAAA55FF55FFAAAAFF55FF5500FFFFFF0055FF55FFAAAAFF55FF55AAAA55555555FF5555
5555AAFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA5500FFFF00FFFFFF00FFFF
0055FFAAAAAAFFFFAAAAAAFF5555555555FFAAAAAAFFFFAAAAAAFF5500FFFF00FFFFFF00
FFFF0055AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55555555FFFFFF555555
55FFAAAA00AAAAFFAAFFFFAAAAAAAAAAAAAAFFFFAAFFAAAA00AAAAFF55555555FFFFFF55
555555FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAAFFAAAAAAAA
AAAAFFFFAA00AAAAFFFFFF55005500550055FFFFFFAAAA00AAFFFFAAAAAAAAAAAAFFAAAA
AAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFAAFFFFFFAAFFFF
AAFFFFFFFFAA00AAAAFFAAAAAA55FF55AAAAAAFFAAAA00AAFFFFFFFFAAFFFFAAFFFFFFAA
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFFFF55FFFFAAAA
FFFF55FFFFFFAA00AAAAFFFFAAFF55FFAAFFFFAAAA00AAFFFFFF55FFFFAAAAFFFF55FFFF
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAAAAAFFAAFF
FF55FFAAAAFFAAFF0055FFFFFFAAAAAAFFFFFF5500FFAAFFAAAAFF55FFFFAAFFAAAAAAFF
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00AAAAFFFF
FFFF000055FFFFAAAA55FFFFFFFFAAFFFFFFFF55AAAAFFFF550000FFFFFFFFAAAA00AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0055FFFF
FFFF5555FFAAAAFFFFAA5500AA550055AA0055AAFFFFAAAAFF5555FFFFFFFF5500FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FFFF
FFFFFF00FF0055FFFFFFAA55AA55FF55AA55AAFFFFFF5500FF00FFFFFFFFFF55AAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FF
FFFF55FF55FF55AA0055AA55FF00FF00FF55AA5500AA55FF55FF55FFFFFF55FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA
FFAAAAAAFF55FFAAFF00FF55AA00FF00AA55FF00FFAAFF55FFAAAAAAFFAAAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
FFFFAAFFFF55AA0000FFAAAAAA00FF00AAAAAAFF0000AA55FFFFAAFFFFFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAFFAAFFAAAAAA00FFAAAA0000AAFFAA0000AAAAFF00AAAAAAFFAAFFAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAFFAAFFAAFFFFAA0055FF00AAFFFFFFAA00FF5500AAFFFFAAFFAAFFAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAA005500AA5555FFAAAA5555555555AAAAFF5555AA005500AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFF00FFAAFF55AA00AAAAAAAAAAAAAA00AA55FFAAFF00FFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAA5500FF00FF55550000AA00005555FF00FF0055AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAFF555555FFFF00FFAA00AAFF00FFFF555555FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAAAAAAFFAA0055FF5500AAFFAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFFFAAFFAAFF00FF00FFAAFFAAFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAFFFF5500AAFFAA0055FFFFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFFAAAAAA555555AAAAAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA00AAAAAAAAAA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF0055005500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA55FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 3.84144 0.782187 3.92875 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAA005555FFFFFF000055AA5555AAFF5500AAAAFF005555FFAAFF005555AAAA555555
5555FFAAFF55FFFFAAFF555555FFFFFF555555FFAAFFFF55FFAAFF5555555555AAAA5555
00FFAAFF555500FFAAAA0055FFAA5555AA550000FFFFFF555500AAAAFF
FFFFAAFF0055FFFFFF5555FFAAFF550000FF55550055AAAAAA005500AAFF55000055FFAA
5555AA0000FF55FFFFAAAAAAAAAAFFAAAAAAAAAAFFFF55FF0000AA5555AAFF55000055FF
AA005500AAAAAA55005555FF000055FFAAFF5555FFFFFF5500FFAAFFFF
FFFFFFAAAA55FFFF55FFAA550055AAFF00AA5555AAAA00005555FFAA0000FF5555FF0000
AAAA00000000FFFFFFFFAAFFFFAAFFAAFFFFAAFFFFFFFF00000000AAAA0000FF5555FF00
00AAFF55550000AAAA5555AA00FFAA550055AAFF55FFFF55AAAAFFFFFF
FFFFFFFFAAFF55FFFF000055FF550000FFAAFF55005555FF55AA5500000000FFFF000000
005555FF5555FFFFFFFFFFAAAAFFFFFFAAAAFFFFFFFFFF5555FF555500000000FFFF0000
000055AA55FF55550055FFAAFF000055FF550000FFFF55FFAAFFFFFFFF
FFFFFFFFFFAAAA0055AAAA555555AAAA550055AAFF00FF55FFAAFF5555FF55555555FF55
55FF0055AA555555555555550000FF000055555555555555AA5500FF5555FF55555555FF
5555FFAAFF55FF00FFAA550055AAAA555555AAAA5500AAAAFFFFFFFFFF
FFFFFFFFFFFFAAFF00550055FF00550055FF550000FFAAAAAAFFFFFF00FF00FFFF0055AA
555555FFAAFF5500FFFF0055FF555555FF5500FFFF0055FFAAFF555555AA5500FFFF00FF
00FFFFFFAAAAAAFF000055FF55005500FF55005500FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA55FF5500AAFF5555AA00AAFF0000550000FF000000FFAAAAFF0055
00FF55AA0000FF55555555FFAAAA00AAAAFF55555555FF0000AA55FF005500FFAAAAFF00
0000FF0000550000FFAA00AA5555FFAA0055FF55AAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF55FFAA0000FF5500000055AAAA55FF555555FF5555550055AAAA
00FF005555FF55FF00FF5500AA000000AA0055FF00FF55FF555500FF00AAAA5500555555
FF555555FF55AAAA5500000055FF0000AAFF55FFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA005555FF55FF00AAFF00550055FFFF00FFFF55AA55FF550000
AAFFAA00AAAAFF55FF55FFAA0000000000AAFF55FF55FFAAAA00AAFFAA000055FF55AA55
FFFF00FFFF55005500FFAA00FF55FF555500AAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF0055FFFF00000055AAAAAA55555555FFFF550055FFFF00AA
FFFFFFAA0000AA555555AA00000000000000AA555555AA0000AAFFFFFFAA00FFFF550055
FFFF55555555AAAAAA55000000FFFF5500FFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA55FFFF5555FF5500555500FF55AA5500AAAA55FFFF5555
00AA5500000000AAAAAA000000000000000000AAAAAA0000000055AA005555FFFF55AAAA
0055AA55FF0055550055FF5555FFFF55AAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFFF00FF00FFAA55FF55FFAAFF55550055FFFFFF00
FFAAFF5555FF5555005555FF5555FF5555FF5555005555FF5555FFAAFF00FFFFFF550055
55FFAAFF55FF55AAFF00FF00FFFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055AAAAFF000055FFFF000055AA55FF55AA0055AA
AAFFFF55AAFFAA5555FF00FF00FFFFFF00FF00FF5555AAFFAA55FFFFAAAA5500AA55FF55
AA550000FFFF550000FFAAAA5500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00550055AAAA55FFFF5555FFAAFF55FFAAFF0055
0000FF0055555500FFFF555555FFFFFF555555FFFF0055555500FF00005500FFAAFF55FF
AAFF5555FFFF55AAAA55005500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF55000055FFFF55AA550000FFFFFFAAAA55
FF555555FF00FF55555555AA55FFFFFF55AA55555555FF00FF555555FF55AAAAFFFFFF00
0055AA55FFFF55000055FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFAA00FFFF55FFAAFF5555FFFFFFFFAAFF
55FFAA555555FFFF00FF550055FFFFFF550055FF00FFFF555555AAFF55FFAAFFFFFFFF55
55FFAAFF55FFFF00AAFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA005555FFFFFF000055AA55FFFFFFFFFFAA
AAAAFFFF00FFFFFF555555AAAAAAFFAAAAAA555555FFFFFF00FFFFAAAAAAFFFFFFFFFF55
AA550000FFFFFF555500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0055FFFFFF5555FFAAFF55FFFFFFFFFF
AAFFFF55FF55FFFF55AA555500555555005555AA55FFFF55FF55FFFFAAFFFFFFFFFF55FF
AAFF5555FFFFFF5500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FFFF55FFAA550000FFFFFFFFFFFF
FFAAAAFF55FF0000FFFFAA5555FF00FF5555AAFFFF0000FF55FFAAAAFFFFFFFFFFFFFF00
0055AAFF55FFFF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFFF000055FF55555555555555
55550000FF55FF5555555500FF55FF55FF0055555555FF55FF0000555555555555555555
FF550000FFFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055AAAA555555AA5555AA55FF
AA5555FF55FFAAAAAAAAAAAA5500FF0055AAAAAAAAAAAAFF55FF5555AAFF55AA5555AA55
5555AAAA5500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00550055FF005500FFFFAA55
0055FFAAAA0055550055550055FF55FF5500555500555500AAAAFF550055AAFFFF005500
FF55005500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF5500AAFF5555555500
FFAA55005555FF00FFAA5555FFAAAAAAFF5555AAFF00FF55550055AAFF0055555555FFAA
0055FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFAA0000FF5500FF55
555500FFAA555555FFFFAA55555500555555AAFFFF555555AAFF00555555FF0055FF0000
AAFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA005555FF55FF00AA55
55AAFF000055FF00FF000055FFAA55AAFF550000FF00FF550000FFAA5555AA00FF55FF55
5500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF0055FFFF00000055
FFAAFFAA00FFFF555555FF5500AA00AA0055FF555555FFFF00AAFFAAFF55000000FFFF55
00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FFFF5555FF55
00AA005555FFFFFF00FF55FFAA000000AAFF55FF00FFFFFF555500AA0055FF5555FFFF55
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFFF00FF00
FFAAFF0055FFFFFF555555AA0000000000AA555555FFFFFF5500FFAAFF00FF00FFFF55FF
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA0055AAAAFF
000055AAAAAAFFAAAAAAAA00000000000000AAAAAAAAFFAAAAAA550000FFAAAA5500AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00550055
AAAA55550055555500550000000000000000005500555555005555AAAA55005500FFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA55FF55
000055FF00AAAAAAAA5555FF5555FF5555FF5555AAAAAAAA00FF55000055FF55AAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF55FF
AA00FFFF555500555500FFFFFF00FF00FFFFFF005555005555FFFF00AAFF55FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00
5555FFFFFF00FFAA5555FFFFFF555555FFFFFF5555AAFF00FFFFFF555500AAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
0055FFFFFF55555500FFFFFFFFFF00FFFFFFFFFF00555555FFFFFF5500FFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AA55FFFF55FFAA55FF55FFFFFF55FF55FFFFFF55FF55AAFF55FFFF55AAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAFF55FFFF000055FFFF0000FF00FF00FF0000FFFF550000FFFF55FFAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAA0055AAAA55555555FF55FF55FF55FF55555555AAAA5500AAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFF00550055FFAA555555AA00AA555555AAFF55005500FFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAA55FF5500AA00AAAA000000AAAA00AA0055FF55AAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAFF55FFAA0000005555FF5555000000AAFF55FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAA005555FF5555AAFFAA5555FF555500AAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFF0055FFFF0055555500FFFF5500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAA55FFFF5555AA5555FFFF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF55FFFF005500FFFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAA0055AAAAAA5500AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFF0055005500FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAA55FF55AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF55FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 3.84144 0.97619 3.92875 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00952018 0.00952018 0.00952018 [
[ 0 0 0 0 ]
[ 1 .49505 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49505 L
0 .49505 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00952 translate
.96154 .47601 scale
101 string
101 50 8 [101 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFAAAAAAFFAA000000AAAAFFFFFFFF555500FFAAFF55FF55FF55AAAAAA00FFFFAAAAFFAA
AAAA555500FFFFAAAAAAFF0055FFFFFF5500FFAAAAAAFFFF005555AAAAAAFFAAAAFFFF00
AAAAAA55FF55FF55FFAAFF005555FFFFFFFFAAAA000000AAFFAAAAAAFF
FFFFAAFFFFFFAA55FFAAFFFFFFFF555500FFFFFFAAAA00FF55FF000000FFFFFFFFAAFF00
000000AAAAAAFF000000FFAA5555FF5555AAFF000000FFAAAAAA00000000FFAAFFFFFFFF
000000FF55FF00AAAAFFFFFF005555FFFFFFFFAAFF55AAFFFFFFAAFFFF
FFFFFFAAAAFF0000AAFFFF55FF555500FFFFFFFFFFAAFF5555AAAAAAAAAAFFAAAAFFFFFF
00FFFF000055AAAAAAAAAA5500FF55FF0055AAAAAAAAAA550000FFFF00FFFFFFAAAAFFAA
AAAAAAAA5555FFAAFFFFFFFFFF005555FF55FFFFAA0000FFAAAAFFFFFF
FFFFFFFFAAFF00FFFFAA00FF555500FFFFFFFFFFFFFFAAAA0000FF000000FFAAFFFF5555
FFAAAAFF55AA550000000055FFAA00AAFF550000000055AA55FFAAAAFF5555FFFFAAFF00
0000FF0000AAAAFFFFFFFFFFFFFF005555FF00AAFFFF00FFAAFFFFFFFF
FFFFFFFFFFAAAAAAFFAAFF5555AA55FFFFFFFFFFFFFFFFAAFF55AAAAAAAAAAFFFF555500
FFAAFFFF5500AAAAAAAAAAAA00FF00FF00AAAAAAAAAAAA0055FFFFAAFF005555FFFFAAAA
AAAAAA55FFAAFFFFFFFFFFFFFFFF55AA5555FFAAFFAAAAAAFFFFFFFFFF
FFFFFFFFFFFFAAFFFFFFAAAA00005555FF55FF55FFFF555555FF0000000000FFAA00AAAA
AAFFFF55FF00FF0000000055AAFF00FFAA5500000000FF00FF55FFFFAAAAAA00AAFF0000
000000FF555555FFFF55FF55FF55550000AAAAFFFFFFAAFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAFF0000FFFF005555FF00AAAAFF005555AAAAAAAAAAAAAAFFFF0000
00FFAAAA00FFFFFF00FFFF0055AAAAAA5500FFFF00FFFFFF00AAAAFF000000FFFFAAAAAA
AAAAAAAA555500FFAAAA00FF555500FFFF0000FFAAAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF00FFFFFF55AA5555FFAAFFFFFF00555555555555555555FFFF00
FFFFFFAAFF55FF55FFAAAA55FF000000FF55AAAAFF55FF55FFAAFFFFFF00FFFF55555555
555555555500FFFFFFAAFF5555AA55FFFFFF00FFAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAAFFAA000000AAAAFFFFFFFF55AA5555005555AA5555AAAA55
FFFFFFFFAAAA00FF55555555AAAAAAAAAA55555555FF00AAAAFFFFFFFF55AAAA5555AA55
55005555AA55FFFFFFFFAAAA000000AAFFAAAAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFFFFAA55FFAAFFFFFFFF55550000AAAAAA0000FF550000FF
55FFFFFFFFAAFF5555AA555500000000005555AA5555FFAAFFFFFFFF55FF000055FF0000
AAAAAA00005555FFFFFFFFAAFF55AAFFFFFFAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFF0000AAFFFF55FF555500FFFF000000FFFF00AAAAAAAA
5555FF55FFFFAAAA000000AAAAAAAAAAAAAA000000AAAAFFFF55FF5555AAAAAAAA00FFFF
000000FFFF005555FF55FFFFAA0000FFAAAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFFFAA00FF555500FFFFFFFF00FFFFFFFF00000000
55FF00AAAAFF0000FFFF00FF0000000000FF00FFFF0000FFAAAA00FF5500000000FFFFFF
FF00FFFFFFFF005555FF00AAFFFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAAFF5555AA55FFFFFFFFFF00AAFFAAAAAAAAAA
AA00FFFFAAFF00FFFFFF55AAAAAAAAAAAAAA55FFFFFF00FFAAFFFF00AAAAAAAAAAAAFFAA
00FFFFFFFFFF55AA5555FFAAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAAAA00005555FF55FF55FFAAFF0000000000
00FFFFFFFFAAAAAAFFAA0000FF000000FF0000AAFFAAAAAAFFFFFFFF000000000000FFAA
FF55FF55FF55550000AAAAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF0000FFFF005555FF00AAAAFFFFFF00FFFF00
FFFFFFFFFFFFAAFFFFFFAA55FFFF00FFFF55AAFFFFFFAAFFFFFFFFFFFF00FFFF00FFFFFF
AAAA00FF555500FFFF0000FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFFFFF55AA5555FFAAFFFFFFFF55AAAA55
FFFFFFFFFFFFFFAAAAFF0000AAFF00FFAA0000FFAAAAFFFFFFFFFFFFFF55AAAA55FFFFFF
FFAAFF5555AA55FFFFFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAA000000AAAAFFFFFFFF5555000055
55FFFFFFFFFFFFFFAAFF00FFFFAAAAAAFFFF00FFAAFFFFFFFFFFFFFF555500005555FFFF
FFFFAAAA000000AAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAA55FFAAFFFFFFFF555500FFFF00
5555FFFFFFFFFFFFFFAAAAAAFF000000FFAAAAAAFFFFFFFFFFFFFF555500FFFF005555FF
FFFFFFAAFF55AAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF0000AAFFFF55FF555500FFFFFFFF
005555FFFFFFFFFFFFFFAAFFFFFF00FFFFFFAAFFFFFFFFFFFFFF555500FFFFFFFF005555
FF55FFFFAA0000FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFFFAA00FF555500FFFFFFFFFF
FF005555FFFFFFFFFFFFFFAAAAFF00FFAAAAFFFFFFFFFFFFFF555500FFFFFFFFFFFF0055
55FF00AAFFFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAAFF5555AA55FFFFFFFFFF
FFFF005555FFFFFFFFFFFFFFAAFF00FFAAFFFFFFFFFFFFFF555500FFFFFFFFFFFFFF55AA
5555FFAAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAAAA00005555FF55FF55
55FFFF0055FFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFF5500FFFF5555FF55FF555500
00AAAAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF0000FFFF005555FF00AA
AA00FFAA5555FFFF5555FFFF5555555555FFFF5555FFFF5555AAFF00AAAA00FF555500FF
FF0000FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFFFFF55AA5555FFAA
FFFF00AA5555AAAA5555AAAA5555AA5555AAAA5555AAAA5555AA00FFFFAAFF5555AA55FF
FFFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAA000000AAAAFF
FFFFFF0000AA0055005555555500FF0055555555005500AA0000FFFFFFFFAAAA000000AA
FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAA55FFAAFFFF
FFFFFFFF00FF00FF55AA555500FFFFFF005555AA55FF00FF00FFFFFFFFFFFFAAFF55AAFF
FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF0000AAFFFF55
FFFF55FF55AAAAAA555555AA55FFFFFF55AA555555AAAAAA55FF55FFFF55FFFFAA0000FF
AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFFFAA00FF
5555FF00AA0055AA00AAAA0055FFFFFF5500AAAA00AA5500AA00FF5555FF00AAFFFF00FF
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFAAFF55
55AA55AAFFFF0055AAFFFFAA5555FF5555AAFFFFAA5500FFFFAA55AA5555FFAAFFAAAAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFAAAA
0000555555FFFF0055AAAA5500FF55FF0055AAAA5500FFFF5555550000AAAAFFFFFFAAFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAFF0000
FFFF005555AAAA55FF000055FFAA00AAFF550000FF55AAAA555500FFFF0000FFAAAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00FF
FFFF55AA55555555AAAAAAAA00FF00FF00AAAAAAAA55555555AA55FFFFFF00FFAAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAA
FFAA000000AAAA0000000055AAFF00FFAA5500000000AAAA000000AAFFAAAAAAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF
FFFFAA55FFAAFFFF00FFFF0055AAAAAA5500FFFF00FFFFAAFF55AAFFFFFFAAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA
AAFF0000AAFFFF55FFAAAA55FF000000FF55AAAAFF55FFFFAA0000FFAAAAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AAFF00FFFFAA00FF55555555AAAAAAAAAA55555555FF00AAFFFF00FFAAFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAAAAAAFFAAFF5555AA555500000000005555AA5555FFAAFFAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFAAFFFFFFAAAA000000AAAAAAAAAAAAAA000000AAAAFFFFFFAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAAFF0000FFFF00FF0000000000FF00FFFF0000FFAAAAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAAFF00FFFFFF55AAAAAAAAAAAAAA55FFFFFF00FFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFAAAAAAFFAA0000FF000000FF0000AAFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFFFFFAA55FFFF00FFFF55AAFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAAFF0000AAFF00FFAA0000FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF00FFFFAAAAAAFFFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAAAAAAFF000000FFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFAAFFFFFF00FFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFAAAAFF00FFAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAFF00FFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433.813, 1745.75},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006a0006dB000`400?l00000o`00003oo`3AcJVb
0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb
0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb
0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb
0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb
0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb
0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb
0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb
0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb
0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@002`3AcJT0203oool000000000
00000000oooo0:ZZZP000000EEEE103oool01@2ZZZX0oooo05EEE@1EEED0oooo008000001P3oool0
3P2ZZZX000000?ooo`2ZZZX0EEEE0000001EEED000000:ZZZP1EEED0oooo0000002ZZZX0oooo0P2Z
ZZX020000000oooo0000001EEED0ZZZZ0?ooo`000000ZZZZ103oool01`2ZZZX0oooo0000002ZZZX0
oooo0:ZZZP1EEED0103oool00`2ZZZX0oooo05EEE@030:ZZZP<0000000<0oooo0=7=Z@3AcJT0203A
cJT01P3oool0000005EEE@1EEED0ZZZZ00000080oooo0P1EEED20:ZZZP0305EEE@2ZZZX0ZZZZ0080
000000D0EEEE0?ooo`3oool0oooo000000020?ooo`030000003oool0EEEE008000000`1EEED20000
00040:ZZZP1EEED0EEEE0:ZZZP80EEEE0P000000102ZZZX0EEEE05EEE@1EEED2000000040?ooo`00
000000000?ooo`8000000`3oool200000080ZZZZ00P0oooo0:ZZZP2ZZZX0000005EEE@3oool0EEEE
000000<0EEEE00<000000?ooo`3AcJT02@3AcJT0203oool0ZZZZ0:ZZZP2ZZZX000000:ZZZP3oool0
EEEE0P2ZZZX02@000000EEEE000000000000EEEE0000003oool000000?ooo`020:ZZZP070000003o
ool0oooo0?ooo`000000EEEE000000020:ZZZP060000003oool000000?ooo`2ZZZX0EEEE0P3oool0
1`1EEED0ZZZZ0?ooo`000000oooo0000002ZZZX00P0000001P3oool000000?ooo`2ZZZX0oooo0000
0080ZZZZ00D0oooo0000003oool0000005EEE@020000000505EEE@000000ZZZZ0:ZZZP1EEED01@2Z
ZZX00`000000oooo0=7=Z@090=7=Z@040?ooo`000000EEEE0:ZZZP80oooo00@000000:ZZZP1EEED0
oooo0`1EEED00`2ZZZX0oooo0?ooo`0=05EEE@80oooo00<0ZZZZ05EEE@0000001@3oool200000004
05EEE@3oool0oooo0?ooo`d0EEEE0P3oool00`2ZZZX0EEEE05EEE@0305EEE@80ZZZZ0P3oool0102Z
ZZX0EEEE0000003oool:0=7=Z@030?ooo`1EEED0oooo0080ZZZZ00@0oooo0000003oool0oooo0P00
00001P2ZZZX0oooo0:ZZZP3oool000000?ooo`<0EEEE0P2ZZZX01`000000oooo05EEE@2ZZZX0EEEE
0000002ZZZX00P3oool2000000030:ZZZP1EEED0EEEE0080000000<0EEEE0000002ZZZX00P000002
0?ooo`0505EEE@000000EEEE0:ZZZP1EEED00P0000003@2ZZZX0EEEE05EEE@1EEED000000?ooo`1E
EED0oooo0:ZZZP000000ZZZZ0000001EEED01@3oool0102ZZZX0oooo0000003oool<0=7=Z@002`3A
cJT01P3oool000000?ooo`3oool0EEEE00000080ZZZZ00<0oooo0000000000000P000000203oool0
ZZZZ000000000000oooo0:ZZZP3oool0EEEE0P000000101EEED000000000003oool30:ZZZP80oooo
00<0EEEE0:ZZZP2ZZZX00P0000001@3oool000000000002ZZZX0EEEE0080oooo00@0ZZZZ0000002Z
ZZX0oooo1P000000103oool0ZZZZ05EEE@0000020:ZZZP030?ooo`00000000000080000000<0oooo
0:ZZZP2ZZZX00P0000040?ooo`X0dLfY00H0oooo0000003oool0EEEE0000003oool205EEE@050?oo
o`000000EEEE05EEE@3oool00P000000103oool0ZZZZ0:ZZZP1EEED20:ZZZP0305EEE@3oool0ZZZZ
0080ZZZZ00@0oooo0000001EEED0ZZZZ0P1EEED00`2ZZZX0oooo0000000205EEE@050000001EEED0
EEEE0?ooo`2ZZZX00P1EEED0102ZZZX0oooo0000001EEED20:ZZZP0305EEE@3oool0EEEE0080ZZZZ
0P1EEED0102ZZZX0oooo00000000000305EEE@80oooo00D0EEEE0?ooo`3oool0000005EEE@030?oo
o`X0dLfY00/0oooo0000002ZZZX0oooo0000002ZZZX0000005EEE@000000EEEE0:ZZZP030?ooo`<0
ZZZZ00<000000:ZZZP2ZZZX00`2ZZZX00`3oool0EEEE000000030?ooo`030000002ZZZX0ZZZZ0080
ZZZZ00<0oooo0:ZZZP0000000P2ZZZX01@000000ZZZZ0:ZZZP000000ZZZZ0080000000D0oooo05EE
E@000000EEEE000000020:ZZZP0405EEE@2ZZZX0ZZZZ000000<0ZZZZ00<0oooo0:ZZZP3oool00P2Z
ZZX01`000000EEEE0?ooo`2ZZZX000000?ooo`2ZZZX00P3oool:0=7=Z@030?ooo`000000oooo00<0
EEEE00@0oooo0:ZZZP00000000000P1EEED00`3oool0EEEE05EEE@0205EEE@<0000000<0EEEE0000
000000000`0000000`1EEED0000005EEE@0305EEE@030?ooo`000000oooo00D0oooo00<000000?oo
o`1EEED00P1EEED20000000305EEE@000000000000L00000101EEED01P000000EEEE05EEE@2ZZZX0
00000:ZZZP@0EEEE0`3oool:0=7=Z@060?ooo`000000EEEE05EEE@000000ZZZZ0P000000102ZZZX0
oooo0?ooo`00000305EEE@80oooo00H0000005EEE@3oool0ZZZZ05EEE@00000205EEE@030:ZZZP3o
ool0ZZZZ0080EEEE0`0000000`1EEED0oooo0:ZZZP040:ZZZP0405EEE@000000EEEE00000080EEEE
00@0ZZZZ0000002ZZZX0EEEE0P000000101EEED000000?ooo`1EEED20?ooo`030000001EEED0EEEE
0080000000<0oooo0000002ZZZX00P000000102ZZZX0EEEE05EEE@1EEED20?ooo``0dLfY000;0=7=
Z@<0oooo0`0000001@1EEED0oooo0000001EEED0oooo0080000000@0ZZZZ0?ooo`2ZZZX0ZZZZ0P1E
EED2000000040?ooo`1EEED0ZZZZ0:ZZZP80EEEE00@0oooo0:ZZZP2ZZZX0ZZZZ0P3oool00`000000
ZZZZ0?ooo`0205EEE@040?ooo`00000000000?ooo`<0ZZZZ00X0EEEE0?ooo`2ZZZX0EEEE0:ZZZP00
0000EEEE0?ooo`1EEED000000P1EEED00`2ZZZX0EEEE0?ooo`020:ZZZP060000003oool0EEEE0000
003oool0ZZZZ0`0000030?ooo`X0dLfY0`3oool010000000oooo0000000000020:ZZZP070000001E
EED0ZZZZ05EEE@000000EEEE000000020?ooo`030000001EEED0oooo0080000000@0EEEE00000000
000000000P1EEED00`2ZZZX0EEEE0:ZZZP0205EEE@80ZZZZ0P1EEED20:ZZZP80EEEE00<0oooo05EE
E@2ZZZX00`1EEED2000000050?ooo`00000000000?ooo`1EEED00P000000203oool0EEEE05EEE@00
0000EEEE0:ZZZP1EEED0oooo0P2ZZZX4000000<0oooo2P3AcJT30?ooo`030000003oool000000080
000000L0ZZZZ05EEE@3oool0EEEE0:ZZZP3oool0ZZZZ0080000000H0oooo000000000000EEEE0000
003oool2000000060?ooo`00000000000:ZZZP000000ZZZZ0`3oool0102ZZZX000000000001EEED2
00000080oooo00P000000:ZZZP000000ZZZZ0000001EEED0oooo00000080oooo00D0000005EEE@00
000000000?ooo`02000000070:ZZZP3oool0ZZZZ05EEE@3oool000000:ZZZP03000000030:ZZZP00
0000oooo0080oooo2P3AcJT30?ooo`030000001EEED0oooo0080EEEE00L0oooo05EEE@2ZZZX00000
05EEE@3oool0ZZZZ0080oooo0P0000030?ooo`<0EEEE00<0oooo0000003oool00P1EEED00`3oool0
ZZZZ0?ooo`090?ooo`0705EEE@3oool0EEEE05EEE@3oool000000?ooo`0305EEE@<0oooo00d00000
0?ooo`3oool0EEEE0:ZZZP3oool0EEEE0000002ZZZX0EEEE0?ooo`1EEED0ZZZZ0080oooo00@00000
0?ooo`3oool0oooo2P3AcJT30?ooo`040000001EEED0000005EEE@80000000<0ZZZZ000000000000
0`1EEED01@000000EEEE0000001EEED0ZZZZ00D0EEEE0P00000505EEE@050000001EEED0oooo0:ZZ
ZP1EEED00`2ZZZX00`1EEED0000005EEE@0205EEE@040:ZZZP1EEED00000000000@0EEEE00<0oooo
0:ZZZP1EEED01@1EEED00`2ZZZX00000000000050000000305EEE@000000oooo0080oooo303AcJT0
00/0dLfY1P3oool205EEE@030?ooo`2ZZZX0oooo0080000000D0oooo000000000000ZZZZ0?ooo`02
0:ZZZP<0oooo00H0ZZZZ0000001EEED0EEEE0000002ZZZX205EEE@060000003oool0ZZZZ05EEE@00
0000ZZZZ0P000000103oool0ZZZZ0?ooo`2ZZZX205EEE@8000000P1EEED010000000EEEE0?ooo`3o
ool60:ZZZP0;0000003oool0oooo0000003oool0ZZZZ0?ooo`1EEED000000?ooo`000000103oool:
0=7=Z@D0oooo00D0ZZZZ0?ooo`00000000000:ZZZP0205EEE@040:ZZZP1EEED0oooo05EEE@80ZZZZ
00D0EEEE0?ooo`3oool0oooo000000030:ZZZP80oooo0P0000001`3oool0EEEE05EEE@2ZZZX00000
05EEE@2ZZZX00`1EEED01`2ZZZX0EEEE05EEE@3oool0000005EEE@3oool00`2ZZZX00`3oool00000
0?ooo`020?ooo`0305EEE@2ZZZX0ZZZZ0080oooo101EEED01P3oool000000000003oool0ZZZZ0000
00@0oooo2P3AcJT40?ooo`D0ZZZZ0`3oool205EEE@<0ZZZZ00<000000:ZZZP0000000P000000102Z
ZZX000000000002ZZZX20?ooo`050000001EEED0EEEE0000003oool00P1EEED20:ZZZP050?ooo`2Z
ZZX0000005EEE@3oool00`1EEED01@2ZZZX0oooo0:ZZZP2ZZZX000000080ZZZZ0`0000050:ZZZP80
EEEE0P3oool00`1EEED0ZZZZ0:ZZZP020:ZZZP030000003oool0oooo0080oooo2P3AcJT40?ooo`03
0000001EEED0ZZZZ0080000000<0EEEE0?ooo`1EEED00`1EEED30?ooo`080:ZZZP1EEED0ZZZZ05EE
E@000000EEEE0000001EEED20?ooo`0305EEE@000000000000/0EEEE00<0oooo0000000000000P3o
ool00`2ZZZX0EEEE000000020000000405EEE@000000EEEE0:ZZZP<0oooo0P1EEED0102ZZZX0EEEE
0?ooo`3oool2000000030:ZZZP1EEED0000000@0oooo2P3AcJT40?ooo`0505EEE@3oool0oooo0:ZZ
ZP3oool00`000000203oool0ZZZZ0:ZZZP2ZZZX0EEEE0:ZZZP3oool000000P2ZZZX305EEE@030:ZZ
ZP3oool000000080ZZZZ00P000000:ZZZP2ZZZX0ZZZZ0000001EEED000000:ZZZP80EEEE0P2ZZZX0
2`3oool000000:ZZZP1EEED000000?ooo`2ZZZX0EEEE0:ZZZP1EEED0ZZZZ0080000000@0oooo05EE
E@1EEED0oooo0P2ZZZX300000080oooo0P2ZZZX00`3oool000000?ooo`030?ooo``0dLfY000;0=7=
Z@@0oooo00L000000:ZZZP3oool0EEEE0?ooo`000000oooo0080ZZZZ00@0oooo000000000000oooo
0P000000103oool0000005EEE@0000060:ZZZP8000000P2ZZZX01P1EEED0oooo0?ooo`3oool00000
0?ooo`80EEEE0P2ZZZX200000080ZZZZ00<0oooo0:ZZZP2ZZZX00P0000000`1EEED000000?ooo`02
00000080oooo00X000000?ooo`1EEED0ZZZZ0?ooo`1EEED0oooo05EEE@3oool0ZZZZ1@3oool:0=7=
Z@@0oooo00<000000:ZZZP2ZZZX00P2ZZZX00`1EEED000000000000205EEE@030:ZZZP1EEED0EEEE
0080EEEE00H0ZZZZ05EEE@2ZZZX0ZZZZ05EEE@00000205EEE@80oooo00<0ZZZZ0?ooo`1EEED00P00
00001P1EEED0ZZZZ05EEE@1EEED0ZZZZ0?ooo`<0000000@0oooo0:ZZZP1EEED0oooo0P1EEED00`00
0000ZZZZ0:ZZZP030:ZZZP<0EEEE0P2ZZZX0101EEED000000000000000030:ZZZP0305EEE@2ZZZX0
oooo00@0oooo2P3AcJT40?ooo`090000002ZZZX000000000003oool0ZZZZ0000002ZZZX0oooo0080
ZZZZ00P000000:ZZZP000000EEEE0:ZZZP3oool000000?ooo`80000000@0ZZZZ0000003oool0EEEE
0`000000101EEED0oooo0:ZZZP2ZZZX205EEE@030:ZZZP3oool0oooo0080EEEE0P0000002P1EEED0
oooo05EEE@2ZZZX000000:ZZZP3oool000000?ooo`2ZZZX205EEE@030:ZZZP1EEED0ZZZZ00<0ZZZZ
00H000000:ZZZP3oool000000?ooo`2ZZZX50?ooo`X0dLfY103oool01@000000oooo05EEE@3oool0
ZZZZ0080000000<0oooo05EEE@2ZZZX01@1EEED00`3oool000000:ZZZP020:ZZZP80oooo0`1EEED0
2@2ZZZX0oooo0?ooo`1EEED0000005EEE@000000EEEE0?ooo`030000000405EEE@3oool0oooo0:ZZ
ZP<0EEEE0P3oool30:ZZZP80oooo1@1EEED0202ZZZX0EEEE0?ooo`000000EEEE0:ZZZP3oool0EEEE
1P3oool:0=7=Z@@0oooo00D0000005EEE@1EEED000000:ZZZP040000000;0:ZZZP1EEED0EEEE0:ZZ
ZP1EEED0000005EEE@000000oooo0000002ZZZX00P1EEED00`000000EEEE0?ooo`02000000<0EEEE
00D0ZZZZ0?ooo`00000000000?ooo`0405EEE@<000001@1EEED01@000000oooo0000001EEED00000
0080ZZZZ00<0000005EEE@2ZZZX010000000102ZZZX0000005EEE@1EEED50?ooo``0dLfY000;0=7=
Z@P0oooo0P0000000`2ZZZX0oooo0000000205EEE@80ZZZZ0P0000001@2ZZZX0EEEE0:ZZZP000000
ZZZZ0080oooo00D0EEEE0?ooo`3oool0EEEE000000020:ZZZP800000103oool01`1EEED000000:ZZ
ZP2ZZZX0000005EEE@0000001@3oool01P000000ZZZZ05EEE@2ZZZX0000005EEE@80ZZZZ0P1EEED2
0?ooo`050:ZZZP1EEED000000?ooo`0000001P3oool:0=7=Z@L0oooo00L0EEEE000000000000EEEE
0:ZZZP1EEED0oooo008000000P1EEED01@000000oooo0?ooo`3oool0EEEE00<0oooo0`1EEED20?oo
o`@0EEEE00@0ZZZZ05EEE@1EEED0ZZZZ101EEED30?ooo`0905EEE@3oool0oooo0?ooo`000000EEEE
0?ooo`000000oooo0080000000@0EEEE0?ooo`000000oooo0P2ZZZX01@1EEED000000000001EEED0
000000H0oooo2P3AcJT60?ooo`030:ZZZP3oool0000000<0ZZZZ00<000000?ooo`2ZZZX00P2ZZZX0
1@1EEED0oooo000000000000oooo00800000102ZZZX01@000000oooo0:ZZZP000000ZZZZ0080oooo
102ZZZX00`000000oooo0:ZZZP020:ZZZP030?ooo`1EEED0ZZZZ00@0ZZZZ00H000000?ooo`2ZZZX0
00000?ooo`1EEED30:ZZZP040?ooo`000000ZZZZ0:ZZZP80000000<0oooo0000003oool01@3oool:
0=7=Z@L0oooo00<0EEEE0?ooo`0000000P3oool01@000000EEEE0:ZZZP3oool0ZZZZ00D0oooo00D0
000005EEE@3oool0EEEE0:ZZZP0305EEE@80000000@0oooo05EEE@1EEED0EEEE0P2ZZZX305EEE@03
0?ooo`1EEED0000000<0EEEE00D0oooo05EEE@3oool0ZZZZ000000040?ooo`0505EEE@2ZZZX0EEEE
0:ZZZP1EEED00`3oool010000000oooo05EEE@0000060?ooo`X0dLfY1P3oool205EEE@030000001E
EED0000000<000000P1EEED01P000000EEEE05EEE@1EEED000000:ZZZP80000000D0oooo05EEE@1E
EED0EEEE0000000205EEE@040:ZZZP000000ZZZZ05EEE@@0ZZZZ00<0EEEE0:ZZZP0000001`1EEED0
1@3oool000000000002ZZZX000000080EEEE0P00000205EEE@H0000000<0EEEE0000003oool01@3o
ool<0=7=Z@002`3AcJT60?ooo`0?0000002ZZZX0oooo05EEE@2ZZZX000000:ZZZP3oool0ZZZZ0000
002ZZZX0oooo05EEE@2ZZZX000000080ZZZZ00D0EEEE00000000000000000:ZZZP020?ooo`0405EE
E@000000ZZZZ0:ZZZPD0oooo102ZZZX0101EEED0oooo0?ooo`2ZZZX3000000<0ZZZZ00<000000:ZZ
ZP1EEED0102ZZZX20?ooo`050000002ZZZX0oooo0?ooo`2ZZZX01`3oool:0=7=Z@H0oooo00<00000
0:ZZZP2ZZZX00P2ZZZX00`000000ZZZZ0:ZZZP0205EEE@050:ZZZP3oool000000?ooo`1EEED00P2Z
ZZX40?ooo`80EEEE00<0oooo05EEE@2ZZZX0101EEED0102ZZZX0EEEE05EEE@2ZZZX405EEE@80oooo
00<0EEEE0?ooo`3oool00P3oool30:ZZZP070?ooo`000000EEEE0:ZZZP3oool0EEEE0:ZZZP020000
00@0ZZZZ1`3oool:0=7=Z@H0oooo00D000000:ZZZP2ZZZX0ZZZZ05EEE@030:ZZZP8000000`2ZZZX0
2@000000oooo0?ooo`3oool0ZZZZ0000003oool000000?ooo`020:ZZZP0;0000002ZZZX0oooo0000
001EEED0ZZZZ0?ooo`000000ZZZZ05EEE@0000000P3oool01P000000ZZZZ0:ZZZP3oool000000?oo
o`8000000P3oool2000000050:ZZZP3oool0ZZZZ0?ooo`0000000`2ZZZX0101EEED0ZZZZ0:ZZZP2Z
ZZX70?ooo`X0dLfY1P3oool20000000305EEE@3oool0oooo0080oooo0P2ZZZX205EEE@H0oooo00D0
00000:ZZZP1EEED0EEEE0?ooo`0205EEE@80ZZZZ00D0EEEE000000000000EEEE0?ooo`0205EEE@80
000000H0EEEE0?ooo`2ZZZX0EEEE0000003oool205EEE@80ZZZZ1P3oool205EEE@80ZZZZ0`3oool0
0`2ZZZX0EEEE000000070?ooo`X0dLfY1P3oool01`000000EEEE0?ooo`3oool0ZZZZ0?ooo`000000
0P3oool01`000000oooo0000001EEED0oooo0:ZZZP1EEED00P00000405EEE@040?ooo`000000ZZZZ
05EEE@8000001@1EEED00`3oool00000000000020:ZZZP040000003oool0EEEE0?ooo`80EEEE0P00
0000101EEED0oooo0?ooo`1EEED20?ooo`0305EEE@3oool0oooo0080oooo0P2ZZZX00`3oool0EEEE
0?ooo`060?ooo``0dLfY000;0=7=Z@L0oooo0`0000000`2ZZZX0EEEE05EEE@03000000030?ooo`00
0000000000<0ZZZZ00<000000:ZZZP3oool00P3oool0101EEED000000000000000020:ZZZP040000
003oool0EEEE0?ooo`<0EEEE00<000000:ZZZP2ZZZX00`0000001P1EEED0ZZZZ0?ooo`3oool0ZZZZ
000000<0ZZZZ0P0000020?ooo`80000000<0oooo05EEE@2ZZZX00`0000070?ooo`X0dLfY1`3oool4
000000040?ooo`00000000000:ZZZP80EEEE0`2ZZZX2000000<0ZZZZ00<0EEEE0:ZZZP1EEED00`3o
ool02P000000EEEE000000000000EEEE0?ooo`000000EEEE0?ooo`00000205EEE@80oooo0P1EEED0
1`2ZZZX0EEEE0:ZZZP1EEED0ZZZZ0000001EEED00P2ZZZX205EEE@80ZZZZ00D000000?ooo`3oool0
00000?ooo`02000000L0oooo2P3AcJT70?ooo`030000002ZZZX000000080000000P0ZZZZ0000003o
ool0oooo0000002ZZZX0EEEE0:ZZZP<0oooo0P0000030:ZZZP040?ooo`000000ZZZZ0:ZZZP80EEEE
0P0000020?ooo`8000000P1EEED010000000ZZZZ0000000000030:ZZZP030000003oool0oooo0080
oooo00@0ZZZZ05EEE@2ZZZX000000P3oool01`000000oooo000000000000oooo0:ZZZP0000001`3o
ool:0=7=Z@L0oooo00<000000?ooo`1EEED0101EEED00`3oool0000005EEE@0605EEE@050?ooo`2Z
ZZX000000000002ZZZX00P3oool205EEE@<0oooo00D0EEEE0?ooo`3oool0EEEE0:ZZZP020?ooo`80
EEEE00H0oooo05EEE@2ZZZX0ZZZZ0000002ZZZX905EEE@030?ooo`1EEED0EEEE00<0EEEE00<0oooo
0000003oool01P3oool:0=7=Z@L0oooo00D0000005EEE@1EEED000000:ZZZP02000000090:ZZZP3o
ool0oooo0?ooo`000000ZZZZ0000003oool0EEEE0080oooo0P1EEED30?ooo`030000003oool0ZZZZ
0080oooo00@0EEEE0?ooo`1EEED0EEEE0P3oool00`2ZZZX00000000000030?ooo`090000001EEED0
oooo0:ZZZP1EEED0oooo0000002ZZZX000000080oooo00H000000:ZZZP00000000000:ZZZP000002
05EEE@030000003oool0oooo00D0oooo303AcJT000/0dLfY2@3oool0102ZZZX0oooo0?ooo`3oool2
05EEE@80ZZZZ0P0000020:ZZZP030?ooo`000000ZZZZ00<0oooo00@000000?ooo`1EEED000000P2Z
ZZX200000080EEEE00@0000005EEE@00000000000P2ZZZX01@000000EEEE000000000000ZZZZ00<0
oooo00H000000?ooo`2ZZZX0ZZZZ0000001EEED20:ZZZP<0EEEE0P3oool00`000000oooo0?ooo`07
0?ooo`X0dLfY2@3oool01@2ZZZX0EEEE0:ZZZP1EEED0ZZZZ00@0oooo00<0EEEE0000003oool00P3o
ool205EEE@040:ZZZP3oool0oooo0:ZZZP80EEEE0P2ZZZX305EEE@030?ooo`1EEED0EEEE0080EEEE
0P2ZZZX205EEE@060:ZZZP3oool0oooo0:ZZZP1EEED0ZZZZ0`3oool01P000000EEEE0000003oool0
00000?ooo`<0ZZZZ00<0EEEE0000003oool0203oool:0=7=Z@T0oooo00<0ZZZZ0?ooo`0000001@3o
ool0102ZZZX000000:ZZZP3oool205EEE@040:ZZZP3oool00000000000D0oooo00@0000005EEE@2Z
ZZX0EEEE0P2ZZZX01@1EEED0ZZZZ05EEE@000000ZZZZ00@0oooo0P0000000`3oool0000005EEE@02
05EEE@030:ZZZP000000oooo00@0oooo0P0000000`3oool000000?ooo`080?ooo`X0dLfY2P3oool0
0`1EEED0oooo05EEE@0305EEE@080:ZZZP3oool0ZZZZ05EEE@3oool0EEEE0:ZZZP3oool305EEE@05
0000002ZZZX0ZZZZ05EEE@2ZZZX00P3oool00`2ZZZX000000:ZZZP02000000<0oooo0P1EEED20:ZZ
ZP090000003oool0EEEE05EEE@3oool0ZZZZ05EEE@3oool0EEEE00<0ZZZZ0`1EEED0102ZZZX0oooo
05EEE@0000090?ooo`X0dLfY2@3oool205EEE@070000001EEED000000000002ZZZX000000:ZZZP03
0000000305EEE@3oool0000000D000000`3oool20:ZZZP030?ooo`1EEED000000080EEEE00@0oooo
0:ZZZP2ZZZX000000P3oool2000000060?ooo`00000000000000003oool0EEEE2P0000000`1EEED0
00000?ooo`080?ooo``0dLfY000;0=7=Z@T0oooo0`0000001`2ZZZX0oooo0:ZZZP000000EEEE0?oo
o`2ZZZX00P1EEED20:ZZZP0505EEE@00000000000?ooo`2ZZZX00P3oool00`1EEED000000:ZZZP03
0:ZZZP0305EEE@3oool0ZZZZ00@0ZZZZ00@0EEEE0?ooo`3oool0ZZZZ0`0000030:ZZZP80EEEE00<0
ZZZZ0?ooo`1EEED00P2ZZZX0103oool0000000000000000:0?ooo`X0dLfY2@3oool200000080EEEE
00D0ZZZZ0000003oool0oooo000000020:ZZZP0305EEE@2ZZZX0ZZZZ0080000000D0EEEE0:ZZZP1E
EED0000005EEE@03000000@0oooo00h0EEEE0?ooo`1EEED0oooo0000003oool0000005EEE@2ZZZX0
EEEE0:ZZZP1EEED0000005EEE@D0ZZZZ0`3oool01@000000ZZZZ05EEE@1EEED0000000X0oooo2P3A
cJT90?ooo`090000002ZZZX0ZZZZ0:ZZZP000000ZZZZ0000002ZZZX000000080EEEE0P3oool01`1E
EED0ZZZZ0000002ZZZX000000:ZZZP0000000P2ZZZX01P1EEED0oooo0:ZZZP1EEED000000?ooo`80
00000P2ZZZX00`3oool000000:ZZZP030:ZZZP050000002ZZZX000000?ooo`1EEED00P3oool205EE
E@@0ZZZZ00@000000:ZZZP2ZZZX0ZZZZ2P3oool:0=7=Z@T0oooo0P0000001P1EEED0ZZZZ00000000
0000EEEE0?ooo`80EEEE0`3oool305EEE@030000002ZZZX0EEEE0080EEEE00<0oooo05EEE@1EEED0
0P1EEED0103oool0EEEE0:ZZZP3oool305EEE@80oooo00D0EEEE0?ooo`1EEED0EEEE0000000305EE
E@<0oooo0P1EEED01`3oool00000000000000000ZZZZ05EEE@0000002P3oool:0=7=Z@T0oooo00H0
000005EEE@3oool0oooo0:ZZZP3oool3000000<0oooo0P1EEED200000080EEEE0P00000205EEE@03
0000002ZZZX0EEEE0080EEEE0P2ZZZX01@1EEED0000005EEE@2ZZZX000000080EEEE0`0000000`1E
EED000000000000205EEE@030:ZZZP3oool0oooo008000000P3oool20:ZZZP030?ooo`1EEED0oooo
00T0oooo303AcJT000/0dLfY2`3oool020000000oooo0?ooo`1EEED000000:ZZZP1EEED0oooo0P00
00003@3oool00000000000000000EEEE0?ooo`2ZZZX0oooo0:ZZZP3oool000000:ZZZP1EEED00P3o
ool20:ZZZP80oooo0100EEEE0:ZZZP1EEED0oooo0:ZZZP3oool0ZZZZ0000001EEED000000?ooo`00
0000oooo05EEE@000000oooo0`2ZZZX0101EEED0oooo0:ZZZP00000;0?ooo`X0dLfY2`3oool00`00
0000ZZZZ0:ZZZP060:ZZZP0305EEE@3oool0oooo0080ZZZZ00<0EEEE0?ooo`1EEED00P2ZZZX405EE
E@040:ZZZP1EEED0EEEE0:ZZZPH0EEEE0P2ZZZX01@1EEED0oooo05EEE@2ZZZX0EEEE0080oooo0`2Z
ZZX00`1EEED0ZZZZ05EEE@030:ZZZP030000003oool0oooo00T0oooo2P3AcJT;0?ooo`070000002Z
ZZX0ZZZZ0:ZZZP1EEED000000:ZZZP020?ooo`030:ZZZP000000000000<0ZZZZ00@0EEEE0?ooo`1E
EED0oooo0`2ZZZX0103oool0EEEE0:ZZZP0000020:ZZZP0505EEE@3oool0ZZZZ0000002ZZZX00`3o
ool00`000000ZZZZ0:ZZZP03000000060:ZZZP3oool0oooo0?ooo`000000EEEE0`2ZZZX00`000000
oooo0?ooo`090?ooo`X0dLfY2`3oool010000000EEEE05EEE@1EEED30?ooo`050:ZZZP3oool0oooo
0:ZZZP1EEED00`3oool01P1EEED0ZZZZ0?ooo`1EEED0oooo000000<0ZZZZ00@0oooo05EEE@1EEED0
oooo102ZZZX01@3oool0EEEE0:ZZZP2ZZZX0EEEE0080oooo00<0000005EEE@2ZZZX00P3oool20:ZZ
ZP80oooo0P1EEED2000000/0oooo2P3AcJT;0?ooo`030000003oool0oooo00H0000000@0oooo05EE
E@00000000001@1EEED00`000000EEEE0:ZZZP0505EEE@030:ZZZP1EEED0EEEE0080EEEE00@0oooo
05EEE@00000000001@1EEED00`000000EEEE0?ooo`06000000030?ooo`1EEED0000000/0oooo303A
cJT000/0dLfY303oool30000000505EEE@3oool0EEEE05EEE@3oool00P2ZZZX205EEE@030:ZZZP3o
ool0oooo00<0000000<0oooo0:ZZZP2ZZZX00`0000000`3oool000000000000200000080ZZZZ00T0
oooo0000001EEED000000:ZZZP3oool0ZZZZ0?ooo`1EEED00P2ZZZX01@3oool0EEEE0000003oool0
ZZZZ00<00000303oool:0=7=Z@`0oooo00D000000?ooo`00000000000:ZZZP0405EEE@80ZZZZ0`1E
EED01@2ZZZX0EEEE05EEE@000000EEEE00@000000P1EEED00`000000EEEE05EEE@030000000505EE
E@000000EEEE05EEE@2ZZZX00`1EEED20:ZZZP@0EEEE00D0ZZZZ000000000000oooo0000000<0?oo
o`X0dLfY303oool00`2ZZZX0oooo00000002000000040:ZZZP1EEED0EEEE000000<0oooo00<00000
0:ZZZP3oool00P3oool0101EEED000000000003oool4000000080?ooo`000000EEEE0000003oool0
ZZZZ0000001EEED20?ooo`0405EEE@2ZZZX0000000000080oooo00@0ZZZZ05EEE@1EEED0ZZZZ0`00
00000`3oool000000?ooo`0;0?ooo`X0dLfY3@3oool0201EEED0oooo0000003oool0ZZZZ05EEE@2Z
ZZX0EEEE0P2ZZZX30?ooo`0605EEE@3oool0EEEE05EEE@000000oooo101EEED0102ZZZX0EEEE05EE
E@3oool205EEE@040:ZZZP000000EEEE05EEE@D0oooo0P2ZZZX02@000000ZZZZ05EEE@000000oooo
0000003oool0EEEE0000000<0?ooo`X0dLfY303oool205EEE@030000001EEED0000000<0000000@0
EEEE0000003oool0EEEE102ZZZX20?ooo`040000001EEED0EEEE0:ZZZP80EEEE00<000000:ZZZP1E
EED00P2ZZZX205EEE@050000003oool0EEEE0:ZZZP3oool00P2ZZZX20?ooo`030000001EEED00000
00D0000000<0EEEE0000003oool02`3oool<0=7=Z@002`3AcJT<0?ooo`030000003oool0oooo0080
EEEE0P2ZZZX00`3oool000000?ooo`0205EEE@0<0?ooo`000000ZZZZ05EEE@3oool0ZZZZ0?ooo`00
0000oooo0000003oool000000P3oool02`000000oooo0000003oool000000?ooo`2ZZZX0oooo05EE
E@2ZZZX000000080oooo00P0EEEE0?ooo`000000oooo0:ZZZP3oool0EEEE000000l0oooo2P3AcJT<
0?ooo`040000003oool0ZZZZ0?ooo`H0000000P0oooo05EEE@000000000005EEE@000000EEEE0?oo
o`@0ZZZZ0P3oool00`2ZZZX0EEEE0?ooo`050:ZZZP040?ooo`000000000005EEE@<0000000<0oooo
000000000000100000000`3oool0ZZZZ0?ooo`0=0?ooo`X0dLfY303oool00`000000ZZZZ0:ZZZP02
0:ZZZP0305EEE@000000000000<0oooo00<0000005EEE@1EEED0103oool00`1EEED0ZZZZ0:ZZZP02
00000080ZZZZ00@000000:ZZZP00000000000P2ZZZX00`1EEED0oooo0?ooo`020?ooo`80EEEE0`3o
ool3000000D0ZZZZ3@3oool:0=7=Z@`0oooo0P000000201EEED0oooo0?ooo`2ZZZX000000:ZZZP1E
EED0oooo1@1EEED30:ZZZP040?ooo`1EEED0EEEE0:ZZZP80000000D0oooo05EEE@000000EEEE0:ZZ
ZP0205EEE@040?ooo`2ZZZX000000:ZZZPD0EEEE0P3oool01`2ZZZX000000?ooo`3oool0ZZZZ05EE
E@0000003@3oool:0=7=Z@`0oooo00T0000005EEE@3oool0oooo0:ZZZP3oool000000?ooo`1EEED0
0`0000000`2ZZZX0EEEE05EEE@020:ZZZP80000000D0oooo05EEE@1EEED0EEEE0?ooo`0200000003
0?ooo`1EEED0EEEE0080EEEE0`0000000`2ZZZX0000005EEE@020:ZZZP8000000P3oool01P000000
oooo0:ZZZP2ZZZX0oooo05EEE@d0oooo303AcJT000/0dLfY3P3oool3000000060?ooo`2ZZZX0oooo
0000002ZZZX0oooo0`0000001@2ZZZX0oooo05EEE@2ZZZX0oooo00<000001@3oool4000000050?oo
o`2ZZZX0oooo0?ooo`2ZZZX00P0000001@2ZZZX0oooo0:ZZZP000000oooo0080ZZZZ0`00000>0?oo
o`X0dLfY3P3oool00`000000EEEE05EEE@0505EEE@080000003oool0EEEE05EEE@000000EEEE0?oo
o`1EEED5000000050?ooo`2ZZZX0ZZZZ0?ooo`1EEED01000000305EEE@050000001EEED0EEEE05EE
E@0000001P1EEED2000000h0oooo2P3AcJT>0?ooo`0:0000002ZZZX0ZZZZ0000003oool000000?oo
o`2ZZZX0EEEE0:ZZZP8000000P2ZZZX01`1EEED00000000000000000ZZZZ05EEE@2ZZZX010000000
103oool0EEEE0:ZZZP2ZZZX2000000030?ooo`2ZZZX0000000<0000000D0EEEE0:ZZZP0000000000
0?ooo`030:ZZZP030000003oool0oooo00`0oooo2P3AcJT>0?ooo`050000001EEED0EEEE0000001E
EED00P2ZZZX01@3oool0ZZZZ0:ZZZP3oool0ZZZZ008000000P1EEED02@3oool0ZZZZ05EEE@1EEED0
ZZZZ0000001EEED0oooo0000000305EEE@80oooo00H0EEEE0?ooo`000000EEEE0:ZZZP3oool20:ZZ
ZP060?ooo`2ZZZX0ZZZZ05EEE@000000EEEE0P00000>0?ooo`X0dLfY3P3oool00`000000oooo0?oo
o`03000000<0oooo00<0ZZZZ05EEE@1EEED00P1EEED30?ooo`<0000000<0EEEE0000000000000P00
00000`2ZZZX00000000000030?ooo`030:ZZZP1EEED0EEEE0080EEEE0`3oool4000000030?ooo`1E
EED0000000h0oooo303AcJT000/0dLfY4@3oool0101EEED000000:ZZZP3oool200000080oooo1000
00001@2ZZZX0EEEE0?ooo`3oool0ZZZZ00H0oooo00D0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP0200000003
0?ooo`000000oooo00<0000000H0oooo0:ZZZP00000000000?ooo`00000?0?ooo`X0dLfY403oool0
201EEED000000000001EEED0000005EEE@3oool0ZZZZ0P1EEED00`3oool0EEEE0?ooo`050:ZZZP03
0?ooo`1EEED0EEEE0080EEEE1P2ZZZX00`000000EEEE0:ZZZP0205EEE@050:ZZZP3oool0EEEE0?oo
o`1EEED00P0000000`1EEED000000?ooo`0>0?ooo`X0dLfY3`3oool00`2ZZZX0oooo000000030:ZZ
ZP070000001EEED0EEEE0:ZZZP3oool0ZZZZ000000020?ooo`070:ZZZP000000oooo0:ZZZP000000
EEEE0000000205EEE@80ZZZZ0P3oool0102ZZZX0oooo05EEE@0000020?ooo`040:ZZZP000000EEEE
000000<0ZZZZ00<000000?ooo`0000003`3oool:0=7=ZA00oooo00<0EEEE0:ZZZP1EEED01`1EEED0
0`3oool000000000000305EEE@<0oooo00<0EEEE0000002ZZZX00P1EEED20?ooo`<0EEEE00<0oooo
0000003oool00P1EEED0103oool0EEEE05EEE@3oool205EEE@030?ooo`1EEED0000000l0oooo2P3A
cJT?0?ooo`80EEEE00L0000005EEE@00000000000:ZZZP000000ZZZZ00@0EEEE0P000000102ZZZX0
00000000000000050:ZZZP0905EEE@00000000000000002ZZZX000000:ZZZP1EEED0oooo0080EEEE
0P0000001`2ZZZX000000000001EEED0000005EEE@0000003`3oool<0=7=Z@002`3AcJT?0?ooo`0:
0000002ZZZX0oooo05EEE@2ZZZX0oooo0:ZZZP3oool0ZZZZ00000080oooo00<000000?ooo`000000
0P1EEED00`3oool0EEEE000000050000000705EEE@3oool0EEEE05EEE@000000oooo000000020?oo
o`090000003oool0oooo0:ZZZP000000ZZZZ05EEE@3oool0ZZZZ0100oooo2P3AcJT?0?ooo`030000
002ZZZX0ZZZZ0080ZZZZ0P3oool205EEE@8000000P2ZZZX305EEE@0;0000002ZZZX0000005EEE@3o
ool0EEEE0000003oool0EEEE0000002ZZZX00`1EEED00`3oool0ZZZZ05EEE@0200000080EEEE00<0
oooo0000002ZZZX00`2ZZZX@0?ooo`X0dLfY3`3oool020000000ZZZZ0:ZZZP2ZZZX0EEEE0:ZZZP1E
EED0oooo0P2ZZZX01P1EEED0ZZZZ0000001EEED0oooo00000080ZZZZ00<000000:ZZZP3oool00P2Z
ZZX20?ooo`050000002ZZZX0ZZZZ0000003oool00P00000205EEE@060:ZZZP3oool0oooo05EEE@2Z
ZZX0EEEE0`2ZZZX@0?ooo`X0dLfY3`3oool200000080ZZZZ00<000000?ooo`1EEED00P3oool00`1E
EED0oooo000000020?ooo`050000001EEED0EEEE0000002ZZZX00P1EEED20:ZZZP80EEEE00D0ZZZZ
000000000000EEEE000000020?ooo`030000003oool0EEEE0080oooo00H0EEEE000000000000ZZZZ
05EEE@00000@0?ooo`X0dLfY3`3oool01P000000EEEE0:ZZZP3oool0ZZZZ0?ooo`<0000000@0oooo
05EEE@1EEED0oooo0`0000000`3oool0ZZZZ0?ooo`0605EEE@030?ooo`2ZZZX0oooo00<0000000@0
oooo0000001EEED0oooo0`0000001@3oool0ZZZZ0?ooo`3oool0EEEE0100oooo303AcJT000/0dLfY
4`3oool00`000000EEEE0?ooo`060?ooo`8000000P1EEED2000000<0ZZZZ00<0EEEE0:ZZZP000000
0`0000000`1EEED000000?ooo`040?ooo`070:ZZZP3oool0oooo05EEE@000000oooo0000000A0?oo
o`X0dLfY4P3oool00`2ZZZX0oooo0?ooo`020?ooo`0305EEE@2ZZZX0ZZZZ00<0oooo00D0EEEE0:ZZ
ZP2ZZZX0oooo000000020:ZZZP80EEEE00H0ZZZZ0?ooo`000000oooo05EEE@2ZZZX205EEE@040?oo
o`1EEED0ZZZZ0:ZZZPD0oooo00<0ZZZZ0000003oool0403oool:0=7=ZA40oooo102ZZZX00`000000
oooo0?ooo`050:ZZZP0405EEE@2ZZZX0oooo0?ooo`H0000000L0oooo0000003oool0oooo0:ZZZP1E
EED0000000@0ZZZZ00<000000?ooo`0000000`2ZZZX00`000000oooo0?ooo`0?0?ooo`X0dLfY4@3o
ool00`000000EEEE05EEE@020?ooo`8000000P3oool905EEE@030:ZZZP1EEED0EEEE0080ZZZZ0P1E
EED00`3oool0EEEE05EEE@0305EEE@<0oooo00<000000?ooo`1EEED00P1EEED00`000000oooo0?oo
o`0?0?ooo`X0dLfY4@3oool00`1EEED0oooo0?ooo`0<00000080oooo0P1EEED20?ooo`80EEEE0P3o
ool5000000030?ooo`000000000000@000000P3oool00`000000oooo0?ooo`0?0?ooo``0dLfY000;
0=7=ZA40oooo00H000000:ZZZP3oool0EEEE0?ooo`1EEED20:ZZZP0305EEE@2ZZZX0EEEE00<0ZZZZ
00D0EEEE0?ooo`2ZZZX0oooo0000000205EEE@030000001EEED0ZZZZ0080oooo0`2ZZZX0101EEED0
ZZZZ05EEE@2ZZZX205EEE@<0oooo00<0ZZZZ0?ooo`3oool0403oool:0=7=ZA40oooo00H000000:ZZ
ZP1EEED0ZZZZ05EEE@2ZZZX305EEE@80ZZZZ00D0EEEE0?ooo`00000000000?ooo`020:ZZZP@00000
00<0EEEE0:ZZZP3oool00P0000000`3oool0EEEE0:ZZZP0305EEE@80ZZZZ00@0EEEE0:ZZZP1EEED0
ZZZZ4P3oool:0=7=ZA40oooo00@000000:ZZZP3oool000000P3oool010000000EEEE0:ZZZP1EEED2
0000000405EEE@000000ZZZZ00000080ZZZZ00<000000:ZZZP0000000P0000001`2ZZZX000000:ZZ
ZP000000EEEE0:ZZZP0000000P2ZZZX01`1EEED0oooo0?ooo`3oool000000?ooo`2ZZZX04P3oool:
0=7=ZA40oooo00<000000?ooo`1EEED00P0000020?ooo`80000000<0EEEE0000000000000P000000
1`3oool0EEEE0?ooo`2ZZZX0000005EEE@3oool00P0000000`3oool0EEEE000000020000000305EE
E@000000oooo008000000P3oool00`000000oooo05EEE@0C0?ooo`X0dLfY4@3oool01@000000EEEE
05EEE@000000EEEE00<000000P1EEED40000000605EEE@000000EEEE0:ZZZP1EEED00000101EEED7
0000000605EEE@00000000000000001EEED000000P1EEEDB0?ooo``0dLfY000;0=7=ZA80oooo0`00
0000102ZZZX0oooo0:ZZZP00000305EEE@090:ZZZP1EEED0EEEE0:ZZZP3oool000000:ZZZP3oool0
EEEE0080oooo0P0000001@3oool0ZZZZ05EEE@1EEED0000000<0EEEE00@000000:ZZZP3oool0ZZZZ
0`00000B0?ooo`X0dLfY4P3oool200000080EEEE00L0ZZZZ05EEE@3oool0oooo0000002ZZZX0EEEE
00@0ZZZZ00@0EEEE0000003oool000000P3oool00`000000EEEE0:ZZZP030:ZZZP0305EEE@2ZZZX0
EEEE0080oooo00@000000:ZZZP1EEED0EEEE0P00000B0?ooo`X0dLfY4P3oool01@000000ZZZZ0:ZZ
ZP2ZZZX000000080ZZZZ00@0oooo0000001EEED0EEEE0P0000001@3oool000000?ooo`1EEED00000
0080EEEE00D000000:ZZZP3oool000000:ZZZP0200000080EEEE00D000000?ooo`2ZZZX0ZZZZ0000
00030:ZZZP030000003oool0oooo0100oooo2P3AcJTB0?ooo`80000000<0ZZZZ0?ooo`3oool00P3o
ool03@2ZZZX000000?ooo`1EEED0ZZZZ0?ooo`2ZZZX000000:ZZZP3oool0EEEE0000002ZZZX00P1E
EED01@2ZZZX0000005EEE@3oool0ZZZZ0080oooo00<0EEEE0:ZZZP3oool00`3oool00`1EEED00000
0000000B0?ooo`X0dLfY4P3oool03@000000EEEE0:ZZZP3oool0ZZZZ0?ooo`000000oooo05EEE@2Z
ZZX0oooo0000003oool00`2ZZZX205EEE@80ZZZZ0P1EEED20:ZZZP80oooo00P000000?ooo`2ZZZX0
ZZZZ0?ooo`000000oooo0:ZZZP80oooo00<0EEEE0000003oool04@3oool<0=7=Z@002`3AcJTD0?oo
o`060:ZZZP3oool0oooo0:ZZZP000000ZZZZ0P1EEED00`2ZZZX0oooo0?ooo`020?ooo`80EEEE0P00
00001P1EEED0000005EEE@1EEED0oooo05EEE@80oooo00H0ZZZZ05EEE@2ZZZX0ZZZZ0000001EEED2
0?ooo`030000003oool0oooo0180oooo2P3AcJTD0?ooo`<0ZZZZ00h0EEEE0:ZZZP1EEED0oooo05EE
E@3oool0EEEE0000001EEED0oooo0:ZZZP1EEED000000?ooo`8000000P2ZZZX01@3oool000000000
001EEED0ZZZZ00<0EEEE102ZZZX00`000000oooo0?ooo`0B0?ooo`X0dLfY503oool30:ZZZP80EEEE
00L0000005EEE@000000ZZZZ05EEE@000000oooo0080ZZZZ00D000000?ooo`000000ZZZZ0?ooo`04
0:ZZZP070000001EEED0ZZZZ0000002ZZZX0000005EEE@030:ZZZP030000003oool0oooo0180oooo
2P3AcJTD0?ooo`050000001EEED0EEEE0000001EEED00`3oool02@1EEED000000000001EEED0oooo
05EEE@000000EEEE0?ooo`0405EEE@050?ooo`1EEED000000000002ZZZX00`3oool01@1EEED00000
05EEE@1EEED0000001@0oooo2P3AcJTD0?ooo`0305EEE@3oool0oooo00<0000000D0oooo05EEE@2Z
ZZX0oooo000000020:ZZZP040?ooo`2ZZZX0EEEE0:ZZZP80EEEE00H000000?ooo`2ZZZX0oooo0000
003oool205EEE@@000000P3oool00`000000oooo0?ooo`0B0?ooo``0dLfY000;0=7=ZA@0oooo0`00
00000`2ZZZX0EEEE0?ooo`0205EEE@030?ooo`1EEED0EEEE00D0oooo0P2ZZZX00`3oool0EEEE0?oo
o`020?ooo`80EEEE00D0000005EEE@000000oooo05EEE@03000001D0oooo2P3AcJTD0?ooo`800000
00L0oooo000000000000ZZZZ0?ooo`000000EEEE00<0oooo0`1EEED0102ZZZX0oooo0?ooo`2ZZZX3
05EEE@050000003oool0oooo05EEE@0000000P2ZZZX2000000030?ooo`000000oooo01@0oooo2P3A
cJTD0?ooo`030000002ZZZX0oooo00<0000000<0oooo0:ZZZP0000000P00000405EEE@80000000<0
oooo0000001EEED00P1EEED0102ZZZX000000000003oool20:ZZZP<0000000<0oooo0:ZZZP3oool0
503oool:0=7=ZA@0oooo00@000000?ooo`1EEED0ZZZZ101EEED0203oool000000?ooo`1EEED00000
0:ZZZP3oool0EEEE0P3oool0101EEED0ZZZZ0:ZZZP0000020?ooo`030000001EEED0EEEE00<0EEEE
00<0oooo05EEE@3oool05@3oool:0=7=ZA@0oooo00D0000005EEE@1EEED0000005EEE@0200000003
0:ZZZP1EEED000000080EEEE00@0ZZZZ000000000000oooo0P1EEED01`3oool000000000002ZZZX0
000005EEE@0000000P2ZZZX20000000405EEE@000000EEEE05EEEAD0oooo303AcJT000/0dLfY5@3o
ool00`000000oooo0000000205EEE@80ZZZZ0P1EEED300000080EEEE00<000000?ooo`0000000P00
0000201EEED0000005EEE@000000EEEE0?ooo`2ZZZX0oooo0P1EEED20?ooo`030000003oool0oooo
01<0oooo2P3AcJTE0?ooo`080000003oool0oooo0?ooo`000000oooo0:ZZZP1EEED20:ZZZP060?oo
o`1EEED000000000001EEED0oooo0P1EEED200000080EEEE0P2ZZZX0201EEED0ZZZZ000000000000
oooo0:ZZZP3oool000005@3oool:0=7=ZAD0oooo00<000000:ZZZP2ZZZX00P2ZZZX205EEE@030:ZZ
ZP3oool0oooo00D000000P2ZZZX500000080oooo0P1EEED50:ZZZP030000003oool0oooo01<0oooo
2P3AcJTE0?ooo`8000000P2ZZZX010000000EEEE05EEE@0000030?ooo`0505EEE@2ZZZX0EEEE0000
003oool00P0000020:ZZZP0605EEE@3oool0oooo0?ooo`000000EEEE0P000000102ZZZX0EEEE0000
0000000E0?ooo`X0dLfY5@3oool02`000000EEEE0:ZZZP3oool0ZZZZ0?ooo`000000oooo0:ZZZP1E
EED0oooo00<0000000@0EEEE0?ooo`1EEED0EEEE0`0000000`2ZZZX0EEEE0:ZZZP02000000060?oo
o`2ZZZX0oooo0?ooo`1EEED000005@3oool<0=7=Z@002`3AcJTG0?ooo`<0000000H0oooo0:ZZZP00
0000EEEE0:ZZZP3oool2000000040?ooo`1EEED0000000000080EEEE0P0000020:ZZZP0405EEE@3o
ool0ZZZZ0:ZZZP<000005`3oool:0=7=ZAL0oooo00<0000005EEE@1EEED00P1EEED20?ooo`060000
001EEED0oooo05EEE@2ZZZX0EEEE0P3oool0101EEED0ZZZZ05EEE@3oool2000000030?ooo`2ZZZX0
EEEE00<0EEEE00<000000?ooo`3oool05@3oool:0=7=ZAL0oooo0`2ZZZX030000000oooo05EEE@2Z
ZZX0oooo0:ZZZP3oool000000?ooo`000000oooo0:ZZZP<0000000H0oooo0000003oool0ZZZZ0000
003oool30:ZZZP030000003oool0oooo01D0oooo2P3AcJTG0?ooo`030000001EEED0EEEE0080oooo
1P1EEED00`000000oooo0?ooo`020?ooo`030000001EEED0EEEE00@0EEEE00D0oooo05EEE@1EEED0
EEEE0000000G0?ooo`X0dLfY5`3oool00`1EEED0oooo0?ooo`04000000070?ooo`1EEED0ZZZZ0?oo
o`2ZZZX0EEEE0000000205EEE@80oooo00<0ZZZZ05EEE@3oool0100000020?ooo`030000003oool0
oooo01D0oooo303AcJT000/0dLfY5`3oool01@000000oooo0?ooo`1EEED000000080oooo00<0EEEE
0?ooo`2ZZZX00P3oool00`1EEED0ZZZZ0?ooo`0205EEE@060?ooo`2ZZZX0000005EEE@3oool0ZZZZ
0P00000J0?ooo`X0dLfY5`3oool00`000000oooo05EEE@0200000080ZZZZ00L0EEEE0:ZZZP2ZZZX0
EEEE0000002ZZZX0EEEE0080ZZZZ0P1EEED01@2ZZZX0oooo05EEE@2ZZZX0EEEE0080000000<0EEEE
0?ooo`3oool05`3oool:0=7=ZAL0oooo00@000000:ZZZP3oool000000P2ZZZX01@3oool0000005EE
E@1EEED0ZZZZ0080oooo00D000000:ZZZP3oool0oooo0:ZZZP0205EEE@070000003oool0ZZZZ0:ZZ
ZP000000oooo0:ZZZP0H0?ooo`X0dLfY5`3oool00`000000oooo05EEE@020000000405EEE@000000
EEEE0:ZZZP80EEEE1@3oool00`2ZZZX0EEEE05EEE@0205EEE@050000003oool000000?ooo`1EEED0
6@3oool:0=7=ZAL0oooo00D0000005EEE@1EEED0000005EEE@020000000405EEE@2ZZZX0EEEE0000
0080EEEE00D000000?ooo`1EEED0EEEE0000000305EEE@80000000@0EEEE0000001EEED0EEEE603o
ool<0=7=Z@002`3AcJTH0?ooo`060000002ZZZX0oooo05EEE@000000oooo0P2ZZZX205EEE@80oooo
0P1EEED20?ooo`80EEEE0P2ZZZX01P3oool0ZZZZ05EEE@3oool0ZZZZ000001P0oooo2P3AcJTH0?oo
o`040000002ZZZX0ZZZZ0:ZZZP80000000H0oooo05EEE@000000EEEE0000003oool200000080oooo
00D0EEEE0000001EEED0oooo000000040:ZZZP030000003oool0oooo01H0oooo2P3AcJTH0?ooo`03
0000002ZZZX0ZZZZ00<0ZZZZ100000001P1EEED000000000003oool000000?ooo`@0000000<0ZZZZ
05EEE@2ZZZX00P2ZZZX00`000000oooo0?ooo`0F0?ooo`X0dLfY603oool2000000060:ZZZP3oool0
oooo05EEE@2ZZZX0EEEE0P3oool605EEE@80oooo00<0EEEE0:ZZZP1EEED00P3oool00`1EEED00000
0000000H0?ooo`X0dLfY603oool00`000000EEEE0:ZZZP020?ooo`0405EEE@2ZZZX0EEEE05EEE@<0
ZZZZ0P0000000`2ZZZX0oooo0:ZZZP0205EEE@030:ZZZP1EEED0ZZZZ0080oooo00<0EEEE0000003o
ool05`3oool<0=7=Z@002`3AcJTL0?ooo`80EEEE00<0oooo0:ZZZP000000100000000`1EEED00000
05EEE@0200000080oooo00@0EEEE0000003oool000006P3oool:0=7=ZA/0oooo00L0ZZZZ0?ooo`3o
ool0oooo0000003oool0ZZZZ00D0EEEE0P2ZZZX00`3oool000000?ooo`020?ooo`030:ZZZP000000
oooo01T0oooo2P3AcJTJ0?ooo`@0ZZZZ00/0000005EEE@3oool0EEEE0000002ZZZX0oooo0000002Z
ZZX0000005EEE@020?ooo`050000002ZZZX0ZZZZ0:ZZZP0000006P3oool:0=7=ZAX0oooo00<00000
05EEE@0000000`1EEED20:ZZZP060?ooo`1EEED000000:ZZZP1EEED0oooo0P2ZZZX00`3oool0EEEE
05EEE@0205EEE@030000003oool0oooo01P0oooo2P3AcJTJ0?ooo`0305EEE@3oool0000000800000
0P1EEED00`000000EEEE0:ZZZP030:ZZZP80000000@0EEEE0?ooo`00000000000P3oool00`000000
oooo0?ooo`0H0?ooo``0dLfY000;0=7=ZAX0oooo00T000000:ZZZP3oool0EEEE0?ooo`1EEED0ZZZZ
0?ooo`1EEED00P2ZZZX02P3oool0ZZZZ0?ooo`3oool0ZZZZ05EEE@3oool0EEEE0?ooo`2ZZZXK0?oo
o`X0dLfY6P3oool01P000000ZZZZ0:ZZZP2ZZZX0EEEE0?ooo`<0EEEE00D0oooo05EEE@3oool0oooo
0000000205EEE@050:ZZZP1EEED0ZZZZ05EEE@2ZZZX06`3oool:0=7=ZAX0oooo00@000000:ZZZP00
000000000P3oool0101EEED000000:ZZZP0000020?ooo`<0000000H0EEEE0?ooo`3oool000000?oo
o`2ZZZXK0?ooo`X0dLfY6P3oool00`000000oooo0?ooo`020:ZZZP0305EEE@3oool0EEEE0080EEEE
0P2ZZZX305EEE@050?ooo`000000ZZZZ0:ZZZP1EEED0703oool:0=7=ZAX0oooo00@0000005EEE@00
000000000P1EEED20?ooo`D0EEEE00H0ZZZZ0?ooo`3oool0000005EEE@00000205EEEA/0oooo303A
cJT000/0dLfY6`3oool3000000<0ZZZZ00/000000:ZZZP2ZZZX0oooo0000002ZZZX0oooo0000002Z
ZZX0oooo0:ZZZP03000001/0oooo2P3AcJTK0?ooo`070000001EEED0EEEE05EEE@000000oooo05EE
E@030:ZZZP0605EEE@2ZZZX0oooo05EEE@3oool0ZZZZ0P1EEED2000001/0oooo2P3AcJTK0?ooo`03
0000002ZZZX0ZZZZ00<0ZZZZ00@0oooo0:ZZZP2ZZZX000000P2ZZZX0101EEED0oooo0:ZZZP000003
0:ZZZP030000003oool0oooo01T0oooo2P3AcJTK0?ooo`040000001EEED0ZZZZ0:ZZZP<0oooo00<0
000005EEE@3oool00`1EEED20?ooo`0305EEE@2ZZZX0ZZZZ008000006`3oool:0=7=ZA/0oooo00@0
00000?ooo`2ZZZX0oooo0P1EEED01@000000ZZZZ05EEE@1EEED0ZZZZ0080EEEE00L0000005EEE@2Z
ZZX0oooo0:ZZZP1EEED0000001/0oooo303AcJT000/0dLfY703oool01`000000ZZZZ0?ooo`1EEED0
ZZZZ0000002ZZZX0103oool00`2ZZZX000000:ZZZP020?ooo`030:ZZZP3oool0oooo01/0oooo2P3A
cJTL0?ooo`070000002ZZZX0ZZZZ0:ZZZP1EEED0ZZZZ0?ooo`020:ZZZP050?ooo`2ZZZX0ZZZZ0:ZZ
ZP1EEED00`2ZZZXM0?ooo`X0dLfY703oool010000000ZZZZ0:ZZZP2ZZZX205EEE@060000002ZZZX0
ZZZZ0?ooo`2ZZZX000000P1EEED30:ZZZQd0oooo2P3AcJTL0?ooo`8000001@1EEED0102ZZZX0oooo
0:ZZZP2ZZZX505EEE@030000003oool0oooo01/0oooo2P3AcJTL0?ooo`030000001EEED0oooo0080
000000<0ZZZZ05EEE@3oool00P000000103oool0EEEE0:ZZZP0000020?ooo`0305EEE@3oool0oooo
01/0oooo303AcJT000/0dLfY7@3oool3000000040:ZZZP1EEED0000005EEE@80000000@0EEEE0?oo
o`1EEED0ZZZZ0`00000M0?ooo`X0dLfY7@3oool50000000405EEE@2ZZZX0oooo00000080ZZZZ0P00
00000`3oool000000000000M0?ooo`X0dLfY7@3oool00`000000ZZZZ00000002000000040:ZZZP00
0000oooo05EEE@@0000000<0oooo0:ZZZP0000007@3oool:0=7=ZAd0oooo00@000000?ooo`3oool0
00000P1EEED02P3oool0EEEE05EEE@3oool0000005EEE@000000EEEE0?ooo`00000M0?ooo`X0dLfY
7@3oool010000000EEEE00000000000305EEE@80000000@0EEEE0:ZZZP1EEED000000P1EEED00`00
0000oooo0?ooo`0K0?ooo``0dLfY000;0=7=ZAl0oooo00L0ZZZZ0?ooo`3oool0oooo05EEE@3oool0
00000080EEEE0P3oool00`000000oooo0?ooo`0M0?ooo`X0dLfY7`3oool00`2ZZZX0EEEE0:ZZZP02
0:ZZZP0305EEE@2ZZZX0ZZZZ0080ZZZZ00<0EEEE0000003oool07P3oool:0=7=ZAl0oooo00H0ZZZZ
0?ooo`000000oooo0:ZZZP0000020:ZZZP80000000<0oooo0000003oool07P3oool:0=7=ZB00oooo
0P1EEED30?ooo`0305EEE@3oool0EEEE0080EEEE00<000000?ooo`3oool07@3oool:0=7=ZAl0oooo
0`1EEED01P000000ZZZZ000000000000ZZZZ0?ooo`80EEEE00<000000?ooo`3oool07@3oool<0=7=
Z@002`3AcJTO0?ooo`<0000000D0ZZZZ0?ooo`1EEED0ZZZZ0?ooo`0300000200oooo2P3AcJTO0?oo
o`800000101EEED01@000000EEEE05EEE@1EEED000000200oooo2P3AcJTO0?ooo`040000002ZZZX0
ZZZZ0:ZZZP80000000<0oooo0000002ZZZX00P2ZZZXP0?ooo`X0dLfY7`3oool20000000305EEE@00
0000ZZZZ0080EEEE00@0ZZZZ05EEE@1EEED00000803oool:0=7=ZAl0oooo00@0000005EEE@3oool0
oooo100000020?ooo`0305EEE@3oool0oooo01h0oooo303AcJT000/0dLfY803oool01`000000oooo
0000001EEED0ZZZZ0000001EEED00P3oool00`000000oooo0?ooo`0N0?ooo`X0dLfY803oool02P00
0000oooo0000003oool0ZZZZ05EEE@3oool0EEEE0?ooo`00000P0?ooo`X0dLfY803oool010000000
ZZZZ0000000000020:ZZZP040000003oool0ZZZZ00000200oooo2P3AcJTP0?ooo`040000003oool0
oooo0:ZZZP80000000@0ZZZZ05EEE@3oool00000803oool:0=7=ZB00oooo00@0000005EEE@000000
EEEE0P00000305EEE@030000003oool0oooo01h0oooo303AcJT000/0dLfY8P3oool200000080EEEE
0P00000R0?ooo`X0dLfY8P3oool01P000000oooo05EEE@000000oooo00000280oooo2P3AcJTR0?oo
o`060:ZZZP3oool000000000003oool000008P3oool:0=7=ZB<0oooo00D0EEEE0?ooo`1EEED0EEEE
0000000R0?ooo`X0dLfY8P3oool505EEE@030000003oool0oooo0200oooo303AcJT000/0dLfY8P3o
ool00`000000oooo05EEE@0U0?ooo`X0dLfY8P3oool010000000oooo0?ooo`2ZZZXT0?ooo`X0dLfY
8P3oool00`000000ZZZZ0:ZZZP020:ZZZR<0oooo2P3AcJTR0?ooo`8000000P1EEED00`000000oooo
0?ooo`0Q0?ooo`X0dLfY8P3oool01@000000EEEE05EEE@3oool0EEEE02<0oooo303AcJT000/0dLfY
8`3oool010000000oooo0:ZZZP00000S0?ooo`X0dLfY8`3oool010000000EEEE0:ZZZP00000S0?oo
o`X0dLfY8`3oool010000000EEEE0:ZZZP00000S0?ooo`X0dLfY8`3oool010000000EEEE0?ooo`00
000S0?ooo`X0dLfY8`3oool2000000030:ZZZP000000oooo0280oooo303AcJT000/0dLfY903oool0
0`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool0
0`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool0
0`2ZZZX0oooo0?ooo`0S0?ooo``0dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY
003o0=7=ZK80dLfY003o0=7=ZK80dLfY000;0=7=Z@050?ooo`000000000005EEE@0000000P1EEED2
000000@0EEEE00@000000?ooo`2ZZZX0ZZZZ0P0000001@2ZZZX00000000000000000ZZZZ00H0EEEE
00L000000?ooo`1EEED0ZZZZ05EEE@000000EEEE0080000000T0EEEE0:ZZZP1EEED0oooo0000001E
EED0000005EEE@0000000`1EEED2000000050?ooo`2ZZZX000000000002ZZZX00P3oool2000000<0
EEEE0`00000305EEE@80000000<0oooo0=7=Z@3AcJT0203AcJT0103oool000000000003oool20:ZZ
ZP050000002ZZZX0oooo0000001EEED00P00000205EEE@030000001EEED0EEEE0080000000X0oooo
0:ZZZP1EEED000000?ooo`2ZZZX0EEEE0000003oool000000P3oool20:ZZZP050?ooo`000000oooo
0?ooo`000000102ZZZX02P3oool00000000000000000EEEE0:ZZZP3oool0ZZZZ05EEE@2ZZZX40000
000;05EEE@000000EEEE05EEE@2ZZZX0000005EEE@000000oooo0:ZZZP3oool00P2ZZZX0103oool0
00000000003oool:0=7=Z@060?ooo`1EEED0ZZZZ05EEE@2ZZZX0oooo0P1EEED01`2ZZZX0oooo0:ZZ
ZP2ZZZX0000005EEE@2ZZZX00P0000001@1EEED000000000003oool0ZZZZ00<0oooo00<0EEEE0000
001EEED00P3oool01P000000oooo0?ooo`3oool0ZZZZ05EEE@80ZZZZ00@0EEEE0:ZZZP3oool0oooo
0P0000000`3oool0EEEE05EEE@0205EEE@<0oooo00P0ZZZZ05EEE@000000000005EEE@000000EEEE
0:ZZZP80EEEE102ZZZX0201EEED0oooo0?ooo`2ZZZX0EEEE0:ZZZP1EEED0oooo2P3AcJT01@3oool0
EEEE05EEE@1EEED0oooo0080ZZZZ0P1EEED01@2ZZZX0oooo0000002ZZZX0oooo0080ZZZZ0P1EEED0
102ZZZX000000000003oool30000000305EEE@2ZZZX0oooo0080ZZZZ00L0EEEE0000002ZZZX0ZZZZ
0000001EEED000000080EEEE0`2ZZZX205EEE@0<0:ZZZP000000oooo0?ooo`1EEED000000:ZZZP00
0000oooo0:ZZZP000000ZZZZ0P1EEED01P3oool0ZZZZ0?ooo`1EEED000000?ooo`<0EEEE00<00000
0:ZZZP2ZZZX00`1EEED00`3oool0dLfY0=7=Z@080=7=Z@040?ooo`000000ZZZZ00000080oooo00X0
EEEE00000000000000000?ooo`1EEED0oooo0000002ZZZX0oooo100000000`3oool0EEEE0?ooo`02
000000030?ooo`000000000000<0000000@0oooo05EEE@3oool0ZZZZ0P0000001P2ZZZX000000000
003oool0EEEE0?ooo`80000000T0ZZZZ0000002ZZZX0oooo0000001EEED0oooo05EEE@3oool00P00
0000102ZZZX000000?ooo`2ZZZX20000000305EEE@3oool0oooo0080000000L0EEEE0?ooo`3oool0
00000:ZZZP1EEED0oooo00`0dLfY000;0=7=Z@030?ooo`2ZZZX00000008000000P1EEED20:ZZZP80
00000P1EEED01P000000EEEE0000003oool0ZZZZ00000080oooo00@0ZZZZ0?ooo`00000000000P1E
EED20000000305EEE@000000oooo0080000000@0EEEE0000001EEED0EEEE10000000101EEED00000
05EEE@2ZZZX20000000505EEE@00000000000?ooo`2ZZZX00P3oool01@000000oooo0?ooo`3oool0
EEEE0080000000<0EEEE0000001EEED00P2ZZZX00`000000EEEE05EEE@0200000080oooo2P3AcJT0
203oool0ZZZZ0?ooo`000000EEEE0000003oool0EEEE0`2ZZZX00`3oool000000:ZZZP0300000008
0?ooo`2ZZZX0oooo0:ZZZP1EEED0oooo0000001EEED40:ZZZP050000003oool0oooo0000003oool0
0P0000000`3oool00000000000020?ooo`80000000L0oooo0000001EEED0ZZZZ0?ooo`2ZZZX0EEEE
0080oooo00<0EEEE0000003oool00P2ZZZX3000000070:ZZZP3oool0oooo0:ZZZP000000ZZZZ05EE
E@04000000<0oooo2P3AcJT0103oool0EEEE0:ZZZP2ZZZX2000000040:ZZZP3oool0ZZZZ0?ooo`80
EEEE00<0oooo0:ZZZP1EEED00P3oool00`2ZZZX0oooo0?ooo`0505EEE@80ZZZZ00@0oooo05EEE@1E
EED000000P1EEED30:ZZZP0605EEE@2ZZZX0ZZZZ05EEE@2ZZZX0EEEE0P0000001`1EEED0ZZZZ0?oo
o`3oool0ZZZZ05EEE@0000000P1EEED02@2ZZZX0oooo0?ooo`2ZZZX0oooo0:ZZZP1EEED0ZZZZ0?oo
o`0205EEE@060000002ZZZX0oooo0:ZZZP000000oooo0P2ZZZX20?ooo`X0dLfY00H0oooo05EEE@2Z
ZZX0oooo0000001EEED30:ZZZP<0EEEE00@0oooo000000000000oooo0P2ZZZX01@3oool0000005EE
E@2ZZZX000000080oooo00<0ZZZZ0000000000000P1EEED01@3oool0ZZZZ000000000000EEEE0080
ZZZZ00<0oooo0:ZZZP1EEED00P0000003P2ZZZX0oooo05EEE@3oool0000005EEE@2ZZZX0oooo0:ZZ
ZP000000ZZZZ05EEE@000000oooo0P2ZZZX3000000040:ZZZP1EEED0EEEE0?ooo`80ZZZZ0P1EEED0
0`2ZZZX0oooo0:ZZZP020?ooo`X0dLfY00L0oooo05EEE@1EEED0EEEE0000001EEED0oooo0080EEEE
00<000000:ZZZP2ZZZX00P1EEED01`000000ZZZZ000000000000ZZZZ0?ooo`1EEED00P3oool205EE
E@030?ooo`000000ZZZZ0080EEEE00@000000?ooo`000000oooo0P1EEED03P2ZZZX0000005EEE@1E
EED0oooo0000001EEED0000005EEE@000000ZZZZ0000003oool0EEEE0`3oool020000000oooo0:ZZ
ZP3oool000000:ZZZP000000EEEE0`2ZZZX01P3oool0EEEE05EEE@3oool0EEEE00000080EEEE0P3o
ool<0=7=Z@002`3AcJT30?ooo`80ZZZZ0P0000000`3oool0EEEE0:ZZZP020:ZZZP80000000L0oooo
05EEE@3oool0EEEE0:ZZZP1EEED0ZZZZ0080EEEE00<0000005EEE@1EEED01000000205EEE@050?oo
o`000000EEEE0000001EEED00P0000000`3oool000000?ooo`0205EEE@<000000`1EEED00`000000
EEEE05EEE@0205EEE@070:ZZZP3oool0oooo0:ZZZP3oool0000005EEE@020:ZZZP80EEEE00D0oooo
05EEE@000000EEEE0:ZZZP030?ooo`X0dLfY0`3oool02`2ZZZX0000005EEE@000000ZZZZ0?ooo`00
0000EEEE0:ZZZP000000EEEE00<0000000<0oooo0000000000000P0000001@2ZZZX000000:ZZZP1E
EED0oooo0080EEEE00<0oooo000000000000101EEED010000000EEEE05EEE@00000205EEE@800000
0P3oool01P1EEED0000005EEE@2ZZZX000000:ZZZPH0000000<0EEEE0000001EEED00P2ZZZX0201E
EED0ZZZZ0?ooo`2ZZZX0000005EEE@3oool0ZZZZ0`3oool:0=7=Z@<0oooo00D0EEEE0?ooo`3oool0
ZZZZ05EEE@0200000080EEEE0P3oool00`1EEED0000000000003000000<0EEEE0P0000000`3oool0
ZZZZ0?ooo`0205EEE@H0ZZZZ00@0EEEE0:ZZZP2ZZZX0EEEE0P2ZZZX02@000000ZZZZ05EEE@1EEED0
oooo0:ZZZP3oool000000:ZZZP0305EEE@@000000P1EEED0103oool0ZZZZ05EEE@1EEED200000005
05EEE@2ZZZX0oooo0:ZZZP1EEED00`3oool:0=7=Z@<0oooo00H0EEEE0?ooo`3oool0oooo0:ZZZP00
000305EEE@<0ZZZZ00@0EEEE0?ooo`1EEED000000`3oool0102ZZZX0oooo0?ooo`2ZZZX405EEE@80
ZZZZ00<000000:ZZZP0000000P2ZZZX0103oool0ZZZZ0000002ZZZX2000000090:ZZZP1EEED0EEEE
05EEE@000000ZZZZ0?ooo`000000ZZZZ00<0oooo0P000000103oool0ZZZZ0:ZZZP2ZZZX305EEE@03
0:ZZZP000000ZZZZ0080oooo00<0ZZZZ05EEE@3oool00P3oool:0=7=Z@<0oooo00@0EEEE0:ZZZP00
0000ZZZZ0`1EEED3000000@0ZZZZ0P0000000`3oool0EEEE00000003000000040:ZZZP3oool0ZZZZ
05EEE@80oooo0`0000020?ooo`0405EEE@3oool0oooo0?ooo`8000000`3oool01P000000ZZZZ0:ZZ
ZP2ZZZX0000005EEE@8000000P3oool00`000000ZZZZ0:ZZZP040:ZZZP8000000`1EEED0103oool0
00000000001EEED30?ooo``0dLfY000;0=7=Z@@0oooo0P0000000`1EEED0ZZZZ05EEE@0300000080
EEEE00H000000?ooo`1EEED0oooo0000003oool20000000405EEE@2ZZZX0EEEE000000@0EEEE00<0
000005EEE@2ZZZX00P1EEED01`000000EEEE05EEE@000000ZZZZ05EEE@2ZZZX00P0000000`1EEED0
oooo05EEE@020000000305EEE@2ZZZX0EEEE0080000000L0oooo000000000000EEEE0?ooo`000000
EEEE00@0000000<0EEEE0:ZZZP2ZZZX00P0000040?ooo`X0dLfY103oool2000000040?ooo`000000
oooo0?ooo`<0ZZZZ0P0000030:ZZZP090000002ZZZX0oooo0:ZZZP3oool0EEEE0?ooo`2ZZZX00000
0080EEEE00@000000:ZZZP000000ZZZZ0P000000102ZZZX000000000002ZZZX2000000040:ZZZP3o
ool0ZZZZ00000080EEEE0P2ZZZX02@3oool0EEEE0?ooo`2ZZZX0oooo0:ZZZP000000EEEE0:ZZZP03
000000<0ZZZZ00@000000?ooo`000000ZZZZ0P0000040?ooo`X0dLfY103oool0201EEED0ZZZZ0:ZZ
ZP2ZZZX0oooo0:ZZZP3oool0ZZZZ0P1EEED20:ZZZP070?ooo`2ZZZX0oooo0?ooo`2ZZZX0oooo0:ZZ
ZP02000000<0EEEE00D0oooo0:ZZZP1EEED000000?ooo`02000000040?ooo`00000000000?ooo`80
000000<0oooo0000001EEED00P2ZZZX305EEE@050000001EEED0ZZZZ0?ooo`2ZZZX01@3oool0102Z
ZZX0EEEE0:ZZZP2ZZZX30?ooo`040:ZZZP1EEED0ZZZZ05EEE@@0oooo2P3AcJT40?ooo`@0EEEE00L0
00000:ZZZP2ZZZX0ZZZZ0?ooo`000000ZZZZ0080oooo00<0ZZZZ05EEE@1EEED00`1EEED00`3oool0
0000000000030:ZZZP0<0?ooo`2ZZZX0ZZZZ0000002ZZZX0oooo0:ZZZP1EEED000000:ZZZP3oool0
ZZZZ0P0000000`2ZZZX0oooo0:ZZZP020:ZZZP<000001@1EEED20?ooo`030000002ZZZX0000000<0
ZZZZ00<0oooo0000001EEED00`1EEED40?ooo`X0dLfY103oool205EEE@030000003oool0oooo0080
oooo00<0ZZZZ05EEE@1EEED0101EEED01@3oool0EEEE0?ooo`3oool0ZZZZ0080EEEE00<0000005EE
E@1EEED0103oool01P2ZZZX0000005EEE@000000EEEE0?ooo`<0000000@0ZZZZ0?ooo`3oool0oooo
0P1EEED02@2ZZZX0000005EEE@3oool0ZZZZ0?ooo`000000EEEE0?ooo`0505EEE@040000002ZZZX0
oooo00000080oooo00<0000005EEE@1EEED0103oool<0=7=Z@002`3AcJT50?ooo`80000000<0oooo
05EEE@0000000`1EEED010000000EEEE00000000000205EEE@0B0:ZZZP000000EEEE0000001EEED0
000005EEE@000000ZZZZ05EEE@3oool000000?ooo`2ZZZX0000005EEE@000000EEEE0P0000000`3o
ool000000:ZZZP020000000;0?ooo`000000ZZZZ0000001EEED0000005EEE@000000EEEE0000002Z
ZZX00P1EEED20000000305EEE@000000EEEE0080EEEE00D0000005EEE@3oool0ZZZZ000000050?oo
o`X0dLfY1@3oool2000000040?ooo`2ZZZX0ZZZZ0?ooo`80000000@0oooo0:ZZZP3oool0ZZZZ1@00
00020?ooo`0305EEE@000000oooo0080000000@0oooo0:ZZZP000000EEEE0P000000101EEED00000
0000001EEED20000000=05EEE@000000ZZZZ0?ooo`1EEED0000005EEE@000000EEEE0:ZZZP3oool0
00000?ooo`0200000080ZZZZ00H0oooo0:ZZZP3oool0ZZZZ0000003oool20:ZZZP030?ooo`000000
000000D0oooo2P3AcJT50?ooo`80EEEE0P0000020:ZZZP040?ooo`1EEED0EEEE05EEE@80ZZZZ0P3o
ool40:ZZZP030000001EEED0EEEE0080EEEE00D0oooo0:ZZZP1EEED0EEEE0:ZZZP0205EEE@040000
001EEED0EEEE00000080EEEE00@0ZZZZ05EEE@1EEED0ZZZZ1P1EEED40:ZZZP80oooo00P0ZZZZ0?oo
o`1EEED0EEEE0:ZZZP3oool0ZZZZ05EEE@8000000P1EEED50?ooo`X0dLfY1@3oool205EEE@040000
001EEED0oooo0?ooo`80ZZZZ00<000000?ooo`2ZZZX0103oool20000000605EEE@000000oooo0?oo
o`2ZZZX000000`2ZZZX01@000000EEEE0000002ZZZX000000080EEEE00@000000:ZZZP000000EEEE
102ZZZX010000000oooo0?ooo`3oool205EEE@090000003oool0oooo0?ooo`1EEED0oooo0:ZZZP3o
ool000000080ZZZZ00@0oooo0000001EEED000000P1EEED50?ooo`X0dLfY1@3oool00`1EEED0ZZZZ
000000020?ooo`80EEEE00D000000?ooo`3oool0oooo05EEE@0200000080oooo0P1EEED200000004
0?ooo`1EEED0oooo05EEE@80oooo0P2ZZZX00`1EEED0oooo05EEE@0305EEE@030000001EEED0ZZZZ
00<0oooo00@0EEEE0?ooo`1EEED0oooo0P00000205EEE@80oooo0P0000001@1EEED0oooo0?ooo`3o
ool000000080EEEE0P3oool20000000305EEE@3oool0oooo00<0oooo303AcJT000/0dLfY1P3oool0
0`1EEED0ZZZZ05EEE@0505EEE@040000002ZZZX0oooo05EEE@80oooo00<0ZZZZ0000001EEED00P1E
EED2000000040?ooo`2ZZZX0ZZZZ000000<0ZZZZ0`1EEED00`3oool0EEEE05EEE@020:ZZZP800000
00D0ZZZZ0?ooo`3oool0ZZZZ0000000305EEE@800000103oool2000000@0EEEE00@0000005EEE@2Z
ZZX0ZZZZ1P3oool:0=7=Z@L0oooo100000002@3oool0ZZZZ05EEE@000000oooo0000003oool0ZZZZ
0?ooo`0300000080oooo00<0EEEE0000002ZZZX00`3oool20:ZZZP030?ooo`2ZZZX0000000<00000
0P3oool0102ZZZX000000?ooo`3oool20:ZZZP80EEEE0P3oool3000000030?ooo`2ZZZX0oooo00<0
00000P1EEED00`3oool0000005EEE@02000000030:ZZZP3oool0oooo00@0oooo2P3AcJT60?ooo`09
0:ZZZP3oool0oooo0:ZZZP1EEED000000:ZZZP3oool0ZZZZ0080EEEE00<0000005EEE@1EEED00`1E
EED01@3oool0ZZZZ0:ZZZP2ZZZX0oooo0080EEEE00<0oooo0000003oool00P2ZZZX0103oool00000
0?ooo`3oool20:ZZZP<0oooo00<0EEEE0:ZZZP3oool00`2ZZZX0103oool0EEEE05EEE@3oool505EE
E@060:ZZZP3oool0EEEE0000001EEED0ZZZZ0P3oool00`1EEED0oooo0?ooo`040?ooo`X0dLfY1P3o
ool01P2ZZZX0oooo0?ooo`1EEED0ZZZZ00000080EEEE00<0ZZZZ000000000000103oool00`2ZZZX0
oooo05EEE@0305EEE@040?ooo`2ZZZX0000000000080oooo00@0EEEE0000002ZZZX0oooo0P2ZZZX0
10000000EEEE0?ooo`2ZZZX3000000070?ooo`1EEED0EEEE05EEE@2ZZZX0oooo0:ZZZP040?ooo`80
000000H0ZZZZ05EEE@00000000000:ZZZP0000020?ooo`0305EEE@3oool0oooo00@0oooo2P3AcJT6
0?ooo`80EEEE00H0000005EEE@3oool0oooo05EEE@3oool2000000090?ooo`2ZZZX0oooo0000003o
ool000000?ooo`2ZZZX0000000<0oooo00@000000?ooo`1EEED0oooo0P0000020:ZZZP0305EEE@3o
ool0ZZZZ00@0000000L0EEEE0?ooo`3oool0oooo05EEE@3oool000000080oooo00<0000005EEE@00
00000`3oool0101EEED000000?ooo`1EEED20?ooo`8000000P1EEED60?ooo``0dLfY000;0=7=Z@H0
oooo0`00000705EEE@030:ZZZP1EEED0EEEE0080ZZZZ00D0oooo0000001EEED000000:ZZZP0305EE
E@040?ooo`2ZZZX0oooo0?ooo`<0000000d0EEEE0?ooo`000000oooo0000003oool000000:ZZZP3o
ool0ZZZZ05EEE@3oool0ZZZZ00<0000000<0oooo05EEE@2ZZZX00P1EEED00`2ZZZX0oooo05EEE@05
05EEE@8000001`3oool:0=7=Z@H0oooo0`0000020:ZZZP80EEEE00L0000005EEE@00000000000?oo
o`000000oooo0080ZZZZ00@0000005EEE@000000ZZZZ0`0000001@2ZZZX0EEEE0?ooo`3oool00000
0080oooo00<000000:ZZZP3oool00P0000001@3oool0000005EEE@2ZZZX0EEEE0080000000L0ZZZZ
0000002ZZZX000000:ZZZP000000oooo00<0000000H0oooo05EEE@000000000005EEE@2ZZZX30000
00L0oooo2P3AcJT60?ooo`80EEEE0`2ZZZX01P3oool0EEEE05EEE@2ZZZX0oooo0:ZZZP80oooo00@0
000005EEE@3oool0oooo1@1EEED30:ZZZP080000001EEED0EEEE05EEE@3oool0EEEE0000003oool3
05EEE@040000002ZZZX0ZZZZ0:ZZZP@0EEEE00H000000?ooo`3oool0oooo0000003oool40:ZZZP07
05EEE@3oool0oooo0:ZZZP1EEED0ZZZZ05EEE@070?ooo`X0dLfY1P3oool305EEE@030:ZZZP3oool0
00000080oooo00<0EEEE0:ZZZP1EEED01@1EEED01@000000oooo05EEE@3oool0EEEE0080ZZZZ0P3o
ool030000000EEEE0:ZZZP3oool0ZZZZ0?ooo`000000ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP80oooo00L0
00000:ZZZP3oool0oooo05EEE@2ZZZX0000000P0EEEE00@0oooo05EEE@000000oooo0`1EEED70?oo
o`X0dLfY1P3oool00`1EEED0oooo0:ZZZP020000000305EEE@2ZZZX0ZZZZ0080000000L0ZZZZ0000
001EEED0oooo0:ZZZP1EEED0ZZZZ0080EEEE0P000000101EEED000000:ZZZP2ZZZX20?ooo`080:ZZ
ZP000000000005EEE@3oool000000?ooo`2ZZZX20?ooo`80ZZZZ00@0000005EEE@00000000000P1E
EED01@2ZZZX0EEEE05EEE@3oool0EEEE0080ZZZZ0P0000000`2ZZZX0oooo05EEE@02000000030:ZZ
ZP3oool0oooo00H0oooo303AcJT000/0dLfY203oool200000080EEEE00@0oooo0:ZZZP3oool00000
0P2ZZZX00`000000oooo00000002000000070?ooo`000000EEEE05EEE@3oool0EEEE000000030?oo
o`80ZZZZ00/0oooo05EEE@000000oooo05EEE@2ZZZX0oooo0000003oool0000005EEE@020?ooo`03
05EEE@000000oooo0080000000@0EEEE0?ooo`00000000000P2ZZZX00`3oool0ZZZZ0?ooo`0205EE
E@030:ZZZP000000oooo00L0oooo2P3AcJT80?ooo`80000000L0ZZZZ0?ooo`3oool000000?ooo`00
0000EEEE00<000000P2ZZZX01@1EEED0oooo0?ooo`1EEED000000080oooo0P00000205EEE@030:ZZ
ZP00000000000080EEEE0P0000000`2ZZZX0EEEE0:ZZZP0200000080oooo00<0ZZZZ05EEE@3oool0
0P1EEED0102ZZZX0oooo00000000000205EEE@060:ZZZP3oool000000000003oool0ZZZZ0P000008
0?ooo`X0dLfY203oool205EEE@8000000P2ZZZX2000000040?ooo`1EEED0000000000080EEEE00<0
ZZZZ05EEE@1EEED00`1EEED200000080EEEE00D0000005EEE@1EEED0oooo0:ZZZP020?ooo`030000
001EEED000000080EEEE00<0000005EEE@1EEED0101EEED00`2ZZZX0EEEE0000000200000080oooo
00@0EEEE0000002ZZZX0EEEE0P00000205EEE@P0oooo2P3AcJT80?ooo`80EEEE00<000000?ooo`3o
ool00P3oool01`000000ZZZZ0?ooo`000000oooo0:ZZZP0000001P3oool01@000000oooo0?ooo`00
0000EEEE00<0ZZZZ0P3oool01@2ZZZX0oooo0:ZZZP1EEED0ZZZZ0080oooo00<0ZZZZ0?ooo`3oool0
0P3oool01@2ZZZX0oooo000000000000oooo0080000000<0ZZZZ0?ooo`3oool00`3oool00`000000
EEEE05EEE@080?ooo`X0dLfY203oool205EEE@80000000`0oooo0000003oool0ZZZZ05EEE@3oool0
000005EEE@000000ZZZZ0000001EEED20?ooo`0605EEE@3oool000000:ZZZP000000oooo0P1EEED2
000000040:ZZZP000000000000000080EEEE00@0ZZZZ0000002ZZZX00000103oool2000000060:ZZ
ZP3oool0EEEE0000003oool0EEEE0P3oool010000000oooo00000000000205EEE@P0oooo303AcJT0
00/0dLfY2@3oool01P1EEED0ZZZZ0000003oool000000?ooo`80ZZZZ00@0EEEE0?ooo`1EEED0ZZZZ
0P0000001`2ZZZX000000?ooo`1EEED0ZZZZ0000002ZZZX00P0000020:ZZZP050?ooo`1EEED0EEEE
0000001EEED0102ZZZX020000000ZZZZ05EEE@2ZZZX000000?ooo`000000ZZZZ0`0000002@1EEED0
oooo0:ZZZP2ZZZX0EEEE0?ooo`000000EEEE000000020:ZZZPT0oooo2P3AcJT:0?ooo`050000003o
ool0EEEE0:ZZZP1EEED00`0000001@2ZZZX0oooo0000001EEED0000000<0EEEE1@00000205EEE@<0
000000<0ZZZZ0000000000000P0000001@1EEED00000000000000000oooo008000000`1EEED01000
0000EEEE0000003oool20:ZZZP80000000H0EEEE0:ZZZP000000oooo0000002ZZZX90?ooo`X0dLfY
2@3oool01@2ZZZX0oooo0?ooo`2ZZZX0EEEE0080000000<0EEEE0:ZZZP3oool00P3oool20:ZZZP03
0?ooo`2ZZZX0ZZZZ00<0ZZZZ0`3oool02`2ZZZX0oooo0?ooo`1EEED0oooo0000001EEED0ZZZZ0?oo
o`2ZZZX0EEEE00<0oooo102ZZZX0101EEED0ZZZZ0:ZZZP2ZZZX20?ooo`80EEEE0P0000001@1EEED0
ZZZZ0?ooo`3oool0EEEE00T0oooo2P3AcJT90?ooo`030:ZZZP3oool0oooo00@0oooo0P2ZZZX205EE
E@80ZZZZ00<0000005EEE@1EEED00`1EEED00`000000oooo000000030:ZZZP030000001EEED0EEEE
00<0EEEE0P2ZZZX2000000030?ooo`1EEED0EEEE00@0EEEE00<000000:ZZZP1EEED00P1EEED00`00
0000ZZZZ0?ooo`050?ooo`0305EEE@3oool0oooo00L0oooo2P3AcJT:0?ooo`060:ZZZP000000EEEE
0?ooo`1EEED000000`3oool0102ZZZX0EEEE0000002ZZZX40?ooo`@0EEEE0P2ZZZX00`3oool0EEEE
0?ooo`0205EEE@050?ooo`1EEED0oooo0:ZZZP0000000P1EEED00`000000EEEE0?ooo`020?ooo`05
0000002ZZZX0000005EEE@2ZZZX00`3oool00`000000EEEE0?ooo`02000000030:ZZZP1EEED0oooo
00P0oooo303AcJT000/0dLfY2P3oool0202ZZZX000000000003oool0000005EEE@000000EEEE0`3o
ool60000000>05EEE@000000oooo0?ooo`2ZZZX0EEEE0:ZZZP1EEED000000?ooo`2ZZZX0000005EE
E@2ZZZX205EEE@80oooo0`1EEED5000000<0oooo00D0EEEE0000001EEED000000?ooo`0200000003
0:ZZZP3oool0oooo00P0oooo2P3AcJT:0?ooo`070:ZZZP3oool0000005EEE@000000oooo05EEE@03
000000<0oooo0`2ZZZX0103oool0ZZZZ0?ooo`3oool3000000<0oooo0P0000030?ooo`030000001E
EED000000080oooo00D0ZZZZ0000002ZZZX0ZZZZ000000020?ooo`<0000000P0ZZZZ05EEE@000000
000005EEE@000000oooo0:ZZZPX0oooo2P3AcJT:0?ooo`0305EEE@2ZZZX0oooo0080000000D0ZZZZ
05EEE@1EEED0oooo0:ZZZP020000000305EEE@3oool0ZZZZ0080ZZZZ00X0oooo000000000000EEEE
0000001EEED000000?ooo`1EEED000000P1EEED0203oool0000005EEE@2ZZZX0EEEE0000001EEED0
oooo0`2ZZZX205EEE@040000001EEED0ZZZZ0?ooo`80EEEE00<0ZZZZ0000000000000P2ZZZX00`1E
EED0oooo0?ooo`080?ooo`X0dLfY2P3oool00`1EEED0ZZZZ0:ZZZP040:ZZZP0=0000001EEED0EEEE
05EEE@2ZZZX0EEEE0:ZZZP1EEED0ZZZZ05EEE@000000EEEE000000020?ooo`050:ZZZP000000EEEE
0000002ZZZX00P0000000`2ZZZX000000:ZZZP020?ooo`<000000P2ZZZX01@1EEED0ZZZZ05EEE@2Z
ZZX000000080EEEE0P2ZZZX01P3oool0ZZZZ0:ZZZP3oool0ZZZZ05EEE@X0oooo2P3AcJT:0?ooo`80
EEEE0P0000001`1EEED0oooo05EEE@3oool0ZZZZ0000001EEED00P3oool00`2ZZZX0EEEE0:ZZZP02
0?ooo`030000003oool000000080EEEE0P000000101EEED000000000001EEED20000000505EEE@00
000000000?ooo`0000000P3oool00`2ZZZX0EEEE05EEE@020?ooo`80000000H0ZZZZ05EEE@1EEED0
oooo05EEE@00000305EEE@X0oooo303AcJT000/0dLfY2`3oool2000000080?ooo`1EEED0EEEE05EE
E@000000oooo05EEE@3oool405EEE@80000000@0EEEE0000003oool0EEEE0P0000001@3oool0EEEE
0?ooo`2ZZZX0EEEE00<0oooo0P0000000`1EEED0oooo0:ZZZP0205EEE@030000001EEED000000080
EEEE00@0000005EEE@3oool000000`1EEED00`3oool0ZZZZ0000000;0?ooo`X0dLfY2`3oool30000
00050:ZZZP1EEED000000000003oool00P2ZZZX00`1EEED000000:ZZZP020:ZZZP0305EEE@000000
oooo0080000000@0ZZZZ0?ooo`000000oooo1P0000000`3oool0000000000003000000@0ZZZZ00L0
000005EEE@000000ZZZZ0?ooo`1EEED000000080ZZZZ0`00000;0?ooo`X0dLfY2`3oool205EEE@80
00000`2ZZZX205EEE@030?ooo`2ZZZX0oooo00D0EEEE0P3oool01@2ZZZX00000000000000000EEEE
0080ZZZZ00<0oooo0:ZZZP1EEED00P000000101EEED0ZZZZ0?ooo`2ZZZX405EEE@040:ZZZP3oool0
ZZZZ0?ooo`80EEEE00<0oooo0:ZZZP1EEED00P00000205EEE@/0oooo2P3AcJT;0?ooo`80EEEE00T0
000005EEE@2ZZZX000000:ZZZP3oool0EEEE0000003oool01@2ZZZX00`3oool0ZZZZ05EEE@0305EE
E@080000002ZZZX0ZZZZ0:ZZZP000000ZZZZ0?ooo`00000405EEE@80oooo00D0EEEE0:ZZZP2ZZZX0
EEEE0:ZZZP020?ooo`0305EEE@3oool0oooo0080000000@0EEEE0000001EEED0EEEE2`3oool:0=7=
Z@/0oooo00T0EEEE0:ZZZP000000000005EEE@3oool0ZZZZ0000001EEED00`3oool30000000505EE
E@000000ZZZZ0000002ZZZX00P3oool3000000080:ZZZP00000000000:ZZZP000000oooo0000002Z
ZZX3000000030?ooo`000000000000<0oooo0P1EEED00`000000ZZZZ0?ooo`03000000030?ooo`1E
EED0oooo00X0oooo303AcJT000/0dLfY303oool01P1EEED0ZZZZ05EEE@000000EEEE0:ZZZP80EEEE
00D000000?ooo`000000ZZZZ05EEE@020000000305EEE@3oool0000000<0EEEE00D0oooo05EEE@00
000000000?ooo`02000000060?ooo`1EEED0000005EEE@000000ZZZZ0P1EEED01@000000EEEE0000
00000000oooo00<0EEEE00@0ZZZZ05EEE@000000EEEE0P2ZZZX<0?ooo`X0dLfY3@3oool00`000000
EEEE000000020:ZZZP080000001EEED0oooo0?ooo`1EEED0000005EEE@00000205EEE@@0000000<0
EEEE0:ZZZP1EEED00P1EEED01@2ZZZX0EEEE05EEE@2ZZZX0EEEE00<000000140oooo05EEE@000000
000005EEE@000000EEEE0?ooo`000000EEEE0000003oool0ZZZZ0000001EEED000000:ZZZP0<0?oo
o`X0dLfY303oool0102ZZZX0oooo0?ooo`2ZZZX205EEE@070:ZZZP3oool000000?ooo`000000ZZZZ
0?ooo`030:ZZZP80EEEE00<0ZZZZ0?ooo`3oool00P2ZZZX01`1EEED0oooo0000001EEED0oooo0:ZZ
ZP3oool00P2ZZZX00`1EEED0ZZZZ0:ZZZP020:ZZZP0:0?ooo`1EEED000000?ooo`1EEED0oooo0:ZZ
ZP000000EEEE0:ZZZP80oooo00<0EEEE0?ooo`3oool02P3oool:0=7=Z@`0oooo00<0ZZZZ0?ooo`3o
ool00P1EEED020000000oooo000000000000EEEE0:ZZZP3oool000000P2ZZZX020000000ZZZZ0:ZZ
ZP2ZZZX0oooo05EEE@3oool000000P2ZZZX01@000000ZZZZ0000003oool0EEEE00<0ZZZZ00D0EEEE
0000003oool0ZZZZ000000020:ZZZP0705EEE@3oool000000?ooo`2ZZZX0EEEE000000020?ooo`03
05EEE@3oool0oooo00X0oooo2P3AcJT<0?ooo`040000002ZZZX000000:ZZZP<0EEEE00<0oooo05EE
E@0000000P00000205EEE@80oooo00<0000005EEE@1EEED00P00000205EEE@040000001EEED0EEEE
00000080EEEE00L0000005EEE@1EEED0EEEE0:ZZZP3oool0000000<0EEEE0P0000020?ooo`<0EEEE
00@0oooo0000002ZZZX0EEEE303oool<0=7=Z@002`3AcJT=0?ooo`070:ZZZP000000EEEE0000001E
EED0000005EEE@020:ZZZP<0EEEE00<0oooo05EEE@3oool0101EEED01P2ZZZX0EEEE05EEE@000000
ZZZZ05EEE@80000000<0EEEE0:ZZZP1EEED00P1EEED01`000000oooo0?ooo`3oool0EEEE0?ooo`1E
EED00P2ZZZX00`1EEED0000005EEE@03000000030:ZZZP3oool0oooo00/0oooo2P3AcJT=0?ooo`07
0:ZZZP3oool0oooo0000002ZZZX0EEEE0000000205EEE@040:ZZZP3oool000000?ooo`80EEEE0P3o
ool4000000040:ZZZP00000000000:ZZZP@0000000/0EEEE0000003oool0000005EEE@000000oooo
0000003oool0ZZZZ05EEE@0200000080EEEE0P0000000`3oool0ZZZZ0?ooo`0<0?ooo`X0dLfY3@3o
ool0101EEED0ZZZZ0?ooo`0000020:ZZZP070?ooo`00000000000:ZZZP1EEED0ZZZZ0?ooo`020:ZZ
ZP0405EEE@000000oooo05EEE@80ZZZZ00<0oooo05EEE@0000000P1EEED00`3oool0ZZZZ0:ZZZP02
0?ooo`050000003oool0ZZZZ0:ZZZP3oool00`2ZZZX010000000ZZZZ0?ooo`2ZZZX200000080ZZZZ
00<0EEEE0?ooo`3oool02`3oool:0=7=Z@d0oooo00D0EEEE0:ZZZP2ZZZX0000005EEE@020:ZZZP03
0?ooo`1EEED0EEEE00<0ZZZZ0`00000605EEE@040000002ZZZX0ZZZZ000000<0EEEE00D0ZZZZ05EE
E@1EEED0oooo000000030:ZZZP<0EEEE0`2ZZZX01@1EEED000000?ooo`2ZZZX0EEEE00d0oooo2P3A
cJT=0?ooo`0805EEE@3oool000000000003oool0EEEE0000001EEED20?ooo`8000000P3oool00`1E
EED0oooo000000040000000605EEE@2ZZZX0EEEE0000002ZZZX0oooo0P0000000`3oool000000000
000205EEE@80oooo00@0000005EEE@3oool0oooo0P00000205EEE@040000002ZZZX0oooo05EEE@d0
oooo303AcJT000/0dLfY3P3oool2000000<0EEEE10000000101EEED0oooo0?ooo`3oool205EEE@D0
00000P1EEED200000080EEEE0P0000001@1EEED00000000000000000EEEE00@0oooo1000000305EE
E@030:ZZZP000000oooo00d0oooo2P3AcJT>0?ooo`80000000D0oooo0:ZZZP2ZZZX0oooo0:ZZZP02
000000030:ZZZP000000oooo0080EEEE00<0oooo0000000000000P2ZZZX01@1EEED0ZZZZ0:ZZZP3o
ool0EEEE0080ZZZZ00<0EEEE0:ZZZP0000000`0000001@1EEED000000?ooo`000000EEEE00<00000
00@0oooo0:ZZZP2ZZZX0oooo0P00000>0?ooo`X0dLfY3P3oool205EEE@050000001EEED0ZZZZ0:ZZ
ZP1EEED00P0000020:ZZZP<0EEEE00@0ZZZZ0?ooo`3oool0oooo0P1EEED0102ZZZX0EEEE0:ZZZP3o
ool405EEE@<0oooo101EEED00`2ZZZX0oooo0000000200000080ZZZZ0P00000205EEE@h0oooo2P3A
cJT>0?ooo`80EEEE00/000000?ooo`000000ZZZZ0?ooo`000000oooo0000002ZZZX000000:ZZZP02
0?ooo`050:ZZZP1EEED0EEEE0:ZZZP3oool00P2ZZZX200000080ZZZZ00D0oooo0:ZZZP3oool0EEEE
0:ZZZP030?ooo`040000002ZZZX0oooo0?ooo`80000000@0ZZZZ0000003oool000000P1EEED>0?oo
o`X0dLfY3P3oool00`1EEED0ZZZZ000000020?ooo`0405EEE@3oool0oooo0?ooo`80EEEE00@00000
05EEE@3oool000000P1EEED01@3oool0ZZZZ0000001EEED0ZZZZ0080000000D0ZZZZ0?ooo`000000
ZZZZ0000000205EEE@80oooo0P000000101EEED0oooo0?ooo`3oool205EEE@80oooo0P0000000`1E
EED0oooo0?ooo`0<0?ooo``0dLfY000;0=7=Z@l0oooo00`0EEEE0:ZZZP1EEED000000:ZZZP000000
ZZZZ0?ooo`1EEED0ZZZZ05EEE@2ZZZX205EEE@040000001EEED0EEEE000000<0EEEE00<0000005EE
E@1EEED00P1EEED00`000000EEEE05EEE@02000000<0EEEE00H0ZZZZ0000003oool0ZZZZ0000002Z
ZZX200000080ZZZZ3`3oool:0=7=ZA00oooo00L0000005EEE@000000000005EEE@2ZZZX0EEEE00<0
00000P2ZZZX40000000405EEE@000000000000000080EEEE00@0000005EEE@000000EEEE0`000000
0`3oool0ZZZZ0?ooo`0200000080EEEE00<0ZZZZ0?ooo`0000000`0000000`2ZZZX0oooo0?ooo`0=
0?ooo`X0dLfY3`3oool01@2ZZZX0oooo0:ZZZP2ZZZX0EEEE008000000P1EEED40:ZZZP80EEEE00<0
000005EEE@2ZZZX00P3oool205EEE@090:ZZZP1EEED0EEEE0?ooo`2ZZZX0EEEE0000001EEED0oooo
00@0ZZZZ00H0000005EEE@000000000005EEE@2ZZZX20?ooo`0305EEE@3oool0oooo00d0oooo2P3A
cJT?0?ooo`040:ZZZP3oool0oooo0?ooo`80ZZZZ0`1EEED20:ZZZP@0EEEE0P3oool205EEE@030000
001EEED0ZZZZ00D0EEEE0P3oool305EEE@030000002ZZZX0ZZZZ00<0EEEE00<000000:ZZZP3oool0
0P3oool00`1EEED0oooo0?ooo`0=0?ooo`X0dLfY3`3oool205EEE@040000001EEED0oooo05EEE@80
00000P3oool0101EEED0oooo0?ooo`3oool20:ZZZP<0EEEE00@000000?ooo`2ZZZX000000P3oool2
05EEE@<0ZZZZ0P3oool205EEE@040?ooo`1EEED0000000000080oooo00@0EEEE0000001EEED0EEEE
3`3oool<0=7=Z@002`3AcJT@0?ooo`030:ZZZP000000000000<0oooo00X000000?ooo`2ZZZX0oooo
05EEE@2ZZZX0oooo05EEE@3oool0EEEE0`3oool00`2ZZZX0EEEE0?ooo`020:ZZZP@0oooo0P1EEED0
102ZZZX0oooo0?ooo`2ZZZX2000000<0oooo0P0000000`2ZZZX0oooo0?ooo`0>0?ooo`X0dLfY403o
ool01P2ZZZX0000005EEE@000000ZZZZ0?ooo`@0ZZZZ0`0000030?ooo`80000000H0oooo0000002Z
ZZX0ZZZZ0000001EEED2000000<0oooo0P0000030:ZZZP030?ooo`2ZZZX0oooo0080000000<0EEEE
0?ooo`2ZZZX0403oool:0=7=ZA00oooo00@0EEEE0:ZZZP3oool000000P2ZZZX205EEE@030:ZZZP3o
ool0ZZZZ0080ZZZZ0P1EEED20:ZZZP<0oooo00<0ZZZZ0?ooo`3oool00P3oool0102ZZZX0EEEE05EE
E@1EEED30:ZZZP050?ooo`2ZZZX0EEEE05EEE@2ZZZX00P0000000`3oool0ZZZZ05EEE@0@0?ooo`X0
dLfY403oool0301EEED0oooo0:ZZZP2ZZZX0000005EEE@000000EEEE0000002ZZZX0EEEE0:ZZZPH0
oooo0P0000020?ooo`8000001@3oool020000000ZZZZ0:ZZZP2ZZZX0000005EEE@000000EEEE102Z
ZZX00`1EEED0oooo0?ooo`0>0?ooo`X0dLfY403oool0101EEED0ZZZZ0000003oool305EEE@050000
001EEED000000000003oool00`000000201EEED0oooo0000003oool0ZZZZ05EEE@3oool0ZZZZ0P00
0000103oool0ZZZZ0000000000020?ooo`80000000H0EEEE0000001EEED0EEEE0:ZZZP3oool20000
000305EEE@3oool0oooo00h0oooo303AcJT000/0dLfY4@3oool02@2ZZZX000000?ooo`000000oooo
05EEE@3oool000000?ooo`020000000605EEE@3oool0oooo0?ooo`1EEED000000P3oool01P1EEED0
00000?ooo`3oool0000005EEE@<0oooo0P0000000`1EEED0oooo0000000205EEE@030?ooo`1EEED0
oooo008000004@3oool:0=7=ZA40oooo0P0000000`2ZZZX000000?ooo`02000000<0oooo00P0ZZZZ
0000001EEED0ZZZZ05EEE@2ZZZX0EEEE000000@0ZZZZ0P1EEED01`2ZZZX000000:ZZZP1EEED0oooo
0:ZZZP0000000`3oool010000000oooo0?ooo`2ZZZX200000140oooo2P3AcJTA0?ooo`80EEEE00<0
000005EEE@2ZZZX00`2ZZZX405EEE@<0oooo101EEED0103oool0000005EEE@2ZZZX305EEE@80oooo
101EEED0102ZZZX0oooo0:ZZZP2ZZZX200000080EEEE4@3oool:0=7=ZA40oooo0P1EEED200000080
oooo0P2ZZZX00`000000ZZZZ0:ZZZP0605EEE@030:ZZZP1EEED0EEEE00T0EEEE00<0ZZZZ0?ooo`00
00000P2ZZZX20?ooo`0405EEE@000000EEEE05EEEA40oooo2P3AcJTA0?ooo`80EEEE00/000000?oo
o`3oool000000:ZZZP3oool0EEEE0000001EEED000000:ZZZP02000000070?ooo`1EEED000000000
001EEED0oooo0000000205EEE@80oooo00<000000:ZZZP3oool00`1EEED20?ooo`040000003oool0
000000000080EEEE4@3oool<0=7=Z@002`3AcJTB0?ooo`800000101EEED01@000000EEEE0?ooo`1E
EED0ZZZZ0080EEEE00<000000?ooo`0000000P2ZZZX01P1EEED000000:ZZZP1EEED000000?ooo`<0
EEEE00H0ZZZZ05EEE@000000EEEE0000002ZZZX205EEE@<000004P3oool:0=7=ZA80oooo0P000000
103oool0ZZZZ0:ZZZP3oool60000000305EEE@00000000000080000000D0oooo000000000000oooo
0:ZZZP030000000305EEE@000000oooo00@000000`2ZZZX300000180oooo2P3AcJTB0?ooo`<0EEEE
0P2ZZZX00`3oool0EEEE05EEE@0305EEE@030:ZZZP3oool0oooo0080oooo0P1EEED0102ZZZX0EEEE
05EEE@1EEED40?ooo`030:ZZZP1EEED0EEEE00<0EEEE00@0oooo0:ZZZP2ZZZX0ZZZZ0P1EEEDB0?oo
o`X0dLfY4P3oool305EEE@030:ZZZP3oool0EEEE0080oooo00<0EEEE0:ZZZP0000000P0000002P2Z
ZZX000000?ooo`3oool0ZZZZ0?ooo`000000ZZZZ0000003oool5000000070:ZZZP1EEED0oooo0?oo
o`000000oooo0:ZZZP0305EEEA80oooo2P3AcJTB0?ooo`0305EEE@00000000000080oooo101EEED2
0:ZZZP030?ooo`1EEED0EEEE0080EEEE00D0ZZZZ0000001EEED0oooo0000000305EEE@050?ooo`1E
EED0oooo05EEE@2ZZZX00`1EEED30?ooo`030:ZZZP000000EEEE0180oooo303AcJT000/0dLfY4`3o
ool00`2ZZZX0000005EEE@0200000080EEEE00L0oooo000000000000000005EEE@2ZZZX000000080
ZZZZ0P1EEED0103oool0EEEE0?ooo`2ZZZX20000000405EEE@0000000000000000<0EEEE0P000000
0`1EEED000000:ZZZP0C0?ooo`X0dLfY4`3oool01P2ZZZX000000000001EEED000000?ooo`80ZZZZ
00H0oooo00000000000000000:ZZZP0000020:ZZZP040000003oool0EEEE00000080ZZZZ00<00000
0:ZZZP0000000P0000002@3oool000000:ZZZP3oool0000005EEE@000000oooo0:ZZZP0C0?ooo`X0
dLfY4`3oool0101EEED0ZZZZ0?ooo`0000070:ZZZP0805EEE@000000EEEE05EEE@3oool0ZZZZ0?oo
o`1EEED20:ZZZP@0EEEE0`2ZZZX00`3oool0ZZZZ0:ZZZP02000000030?ooo`2ZZZX0EEEE01<0oooo
2P3AcJTC0?ooo`0405EEE@3oool0ZZZZ000000<0oooo00<0EEEE0:ZZZP0000000`2ZZZX01P000000
ZZZZ05EEE@1EEED0oooo00000080EEEE00<0ZZZZ000000000000102ZZZX30?ooo`0505EEE@000000
ZZZZ0:ZZZP1EEED04`3oool:0=7=ZA<0oooo0P1EEED200000080oooo00L0EEEE0?ooo`0000000000
0?ooo`1EEED0000000<0oooo00<000000:ZZZP2ZZZX00P0000030?ooo`0805EEE@3oool000000000
003oool0EEEE0?ooo`1EEED200000080EEEE4`3oool<0=7=Z@002`3AcJTD0?ooo`0;0:ZZZP000000
EEEE0?ooo`1EEED0oooo05EEE@000000EEEE0000001EEED00P2ZZZX01@1EEED000000?ooo`1EEED0
00000080oooo00L0EEEE0:ZZZP2ZZZX0EEEE0000001EEED000000080oooo0`1EEED2000001@0oooo
2P3AcJTD0?ooo`<0000000d0ZZZZ05EEE@000000000005EEE@2ZZZX000000?ooo`1EEED0oooo0000
003oool000000080EEEE00T000000?ooo`000000oooo0:ZZZP3oool000000:ZZZP1EEED00P000000
0`1EEED0ZZZZ00000002000001@0oooo2P3AcJTD0?ooo`80EEEE00@0000005EEE@2ZZZX0ZZZZ0`1E
EED00`3oool0EEEE0?ooo`020:ZZZP80EEEE0P3oool01`1EEED0ZZZZ0:ZZZP2ZZZX0oooo05EEE@3o
ool00`1EEED20:ZZZP8000000P1EEEDD0?ooo`X0dLfY503oool205EEE@030000003oool0oooo0080
oooo0P0000001`2ZZZX0000005EEE@1EEED0ZZZZ0?ooo`2ZZZX00P1EEED30:ZZZP0305EEE@3oool0
00000080ZZZZ00<000000?ooo`3oool00P3oool00`000000EEEE05EEE@0D0?ooo`X0dLfY5@3oool0
102ZZZX000000000001EEED30?ooo`040000003oool0EEEE00000080ZZZZ00<0oooo05EEE@1EEED0
0P1EEED01`000000ZZZZ0:ZZZP3oool0EEEE0?ooo`2ZZZX00`3oool01@1EEED000000000002ZZZX0
EEEE01@0oooo303AcJT000/0dLfY5@3oool2000000030:ZZZP1EEED0EEEE00L0EEEE00D000000:ZZ
ZP1EEED0EEEE0000000205EEE@030000001EEED0000000@0EEEE00<0ZZZZ05EEE@1EEED00`00000E
0?ooo`X0dLfY5@3oool2000000030:ZZZP3oool0000000@0000000@0EEEE0?ooo`2ZZZX0ZZZZ0`3o
ool00`000000oooo0:ZZZP020:ZZZP080?ooo`1EEED0000005EEE@000000oooo0000003oool30000
01D0oooo2P3AcJTE0?ooo`<0EEEE00X0ZZZZ0?ooo`000000ZZZZ0?ooo`000000EEEE0:ZZZP3oool0
EEEE1@3oool205EEE@80oooo00H0EEEE0000001EEED0ZZZZ0000003oool20:ZZZP80EEEE5@3oool:
0=7=ZAD0oooo1`1EEED01`000000oooo0:ZZZP000000oooo0000002ZZZX00P000000101EEED00000
0:ZZZP0000020?ooo`030:ZZZP3oool0EEEE00L0EEEE5@3oool:0=7=ZAD0oooo0P1EEED200000003
0?ooo`00000000000080000000L0ZZZZ0?ooo`1EEED0oooo05EEE@2ZZZX0EEEE00<0ZZZZ00@0oooo
05EEE@3oool0ZZZZ0`0000020?ooo`040000001EEED0EEEE05EEEAD0oooo303AcJT000/0dLfY5P3o
ool00`2ZZZX00000000000020?ooo`040000001EEED00000000000<0EEEE0P00000205EEE@800000
0`1EEED5000000040?ooo`00000000000:ZZZQH0oooo2P3AcJTF0?ooo`040:ZZZP000000oooo0000
0080ZZZZ0`0000001@1EEED00000000000000000ZZZZ0080EEEE00D0ZZZZ05EEE@00000000000:ZZ
ZP03000000030:ZZZP1EEED000000080oooo00<0ZZZZ0?ooo`3oool0503oool:0=7=ZAH0oooo00<0
EEEE0:ZZZP3oool00`0000020?ooo`040:ZZZP000000oooo05EEE@H0oooo00@0EEEE0?ooo`2ZZZX0
ZZZZ0P3oool01P000000EEEE0000003oool0ZZZZ05EEEAH0oooo2P3AcJTF0?ooo`0505EEE@3oool0
ZZZZ0:ZZZP3oool00P2ZZZX010000000EEEE05EEE@2ZZZX2000000070?ooo`2ZZZX0EEEE0?ooo`2Z
ZZX000000:ZZZP0205EEE@030000002ZZZX0ZZZZ00@0ZZZZ00<0EEEE0?ooo`3oool0503oool:0=7=
ZAH0oooo00L0EEEE0:ZZZP00000000000?ooo`1EEED000000080EEEE00<0ZZZZ05EEE@3oool00`00
0000103oool000000000003oool705EEE@80000000<0oooo05EEE@3oool05@3oool<0=7=Z@002`3A
cJTG0?ooo`030:ZZZP1EEED0ZZZZ00<000001P1EEED010000000EEEE00000000000605EEE@800000
00<0EEEE0:ZZZP1EEED0603oool:0=7=ZAL0oooo00D0ZZZZ0?ooo`000000EEEE0000000205EEE@03
0000001EEED000000080ZZZZ00@0EEEE0:ZZZP000000EEEE0P2ZZZX30000000305EEE@0000000000
008000006@3oool:0=7=ZAL0oooo00@0EEEE0:ZZZP3oool0ZZZZ0P3oool0202ZZZX0EEEE00000000
0000EEEE0:ZZZP1EEED00000101EEED20000000305EEE@2ZZZX0ZZZZ00<0oooo00<0ZZZZ0?ooo`3o
ool05P3oool:0=7=ZAL0oooo00L0EEEE0:ZZZP3oool0000005EEE@2ZZZX000000080oooo00@00000
0:ZZZP1EEED0EEEE0P3oool00`1EEED0ZZZZ0:ZZZP02000000040?ooo`000000EEEE05EEE@80oooo
00<0ZZZZ0?ooo`3oool05P3oool:0=7=ZAL0oooo0`1EEED01`000000EEEE0?ooo`3oool0EEEE0000
002ZZZX00`3oool0201EEED0ZZZZ0?ooo`000000oooo0:ZZZP000000EEEE0P3oool0101EEED00000
05EEE@1EEEDH0?ooo``0dLfY000;0=7=ZAP0oooo0P00000;05EEE@030000001EEED0EEEE00D0EEEE
00<0000005EEE@0000000P00000H0?ooo`X0dLfY603oool3000000040:ZZZP00000000000:ZZZPD0
00000P2ZZZX010000000EEEE0000000000020:ZZZP030000002ZZZX0ZZZZ00<00000603oool:0=7=
ZAP0oooo0`1EEED20:ZZZP0605EEE@2ZZZX0oooo0:ZZZP3oool0EEEE0P2ZZZX01`3oool0ZZZZ0:ZZ
ZP3oool0ZZZZ0?ooo`2ZZZX00P1EEED20:ZZZP80EEEE603oool:0=7=ZAP0oooo0`1EEED20:ZZZP06
0000002ZZZX0EEEE05EEE@2ZZZX0EEEE103oool20:ZZZP80EEEE00@0ZZZZ0000003oool0ZZZZ0`1E
EEDH0?ooo`X0dLfY603oool02@1EEED0oooo000000000000EEEE0?ooo`000000ZZZZ0000000205EE
E@0:0?ooo`00000000000?ooo`000000EEEE0000003oool000000?ooo`80000000<0ZZZZ0?ooo`1E
EED0603oool<0=7=Z@002`3AcJTI0?ooo`040:ZZZP000000EEEE05EEE@@0000000X0EEEE0000001E
EED0EEEE0000001EEED0000005EEE@000000oooo0`0000000`1EEED000000:ZZZP0I0?ooo`X0dLfY
6@3oool00`2ZZZX0000005EEE@04000000050?ooo`2ZZZX000000000001EEED00`0000000`2ZZZX0
oooo05EEE@030000000305EEE@3oool0ZZZZ01T0oooo2P3AcJTI0?ooo`0505EEE@2ZZZX0oooo0?oo
o`2ZZZX0101EEED20:ZZZP80EEEE0P2ZZZX205EEE@070000001EEED0ZZZZ0000003oool0ZZZZ05EE
E@0I0?ooo`X0dLfY6@3oool00`1EEED0oooo0:ZZZP0205EEE@80ZZZZ00<0oooo05EEE@3oool0103o
ool205EEE@050?ooo`2ZZZX0ZZZZ05EEE@0000000P2ZZZX00`1EEED0oooo0?ooo`0G0?ooo`X0dLfY
6@3oool0101EEED0ZZZZ0000002ZZZX205EEE@080000003oool0ZZZZ05EEE@3oool0ZZZZ0000003o
ool20:ZZZP050?ooo`000000EEEE05EEE@3oool00P0000000`1EEED0oooo0?ooo`0G0?ooo``0dLfY
000;0=7=ZAX0oooo00@0ZZZZ05EEE@000000EEEE0P000000102ZZZX0EEEE0:ZZZP00000205EEE@80
000000L0EEEE0:ZZZP3oool0000005EEE@2ZZZX0EEEE01/0oooo2P3AcJTJ0?ooo`070:ZZZP3oool0
oooo0000001EEED000000?ooo`020000000405EEE@2ZZZX0ZZZZ05EEE@80000000<0oooo0000001E
EED00P00000L0?ooo`X0dLfY6P3oool02@1EEED0ZZZZ0?ooo`2ZZZX000000?ooo`1EEED0oooo0000
000405EEE@030000003oool0EEEE0080000000<0ZZZZ0?ooo`2ZZZX06`3oool:0=7=ZAX0oooo00<0
EEEE0:ZZZP3oool00P3oool00`000000ZZZZ05EEE@0705EEE@80ZZZZ0`3oool00`2ZZZX0oooo0?oo
o`0I0?ooo`X0dLfY6P3oool01P1EEED0oooo000000000000EEEE0?ooo`80EEEE00<000000:ZZZP2Z
ZZX00P2ZZZX01`3oool0EEEE05EEE@3oool0EEEE0000002ZZZX0703oool<0=7=Z@002`3AcJTK0?oo
o`80000000@0ZZZZ05EEE@1EEED0ZZZZ0P3oool405EEE@060:ZZZP3oool0ZZZZ0:ZZZP1EEED0ZZZZ
0P00000K0?ooo`X0dLfY6`3oool2000000080?ooo`2ZZZX0EEEE0:ZZZP000000ZZZZ0000001EEED2
000000030?ooo`000000ZZZZ0080ZZZZ00<0oooo0000000000006`3oool:0=7=ZA/0oooo00D0EEEE
0:ZZZP1EEED0000005EEE@020?ooo`040:ZZZP3oool0ZZZZ0:ZZZP@0oooo0P00000305EEEA/0oooo
2P3AcJTK0?ooo`@0EEEE00<000000?ooo`2ZZZX01`2ZZZX00`3oool0EEEE05EEE@0305EEEA/0oooo
2P3AcJTK0?ooo`0305EEE@2ZZZX0000000<0oooo00<0000005EEE@1EEED00`1EEED00`3oool00000
0?ooo`020?ooo`80000000<0EEEE0?ooo`3oool06@3oool<0=7=Z@002`3AcJTL0?ooo`040000002Z
ZZX0000005EEE@80000000D0EEEE0?ooo`1EEED0EEEE0?ooo`03000000030?ooo`000000ZZZZ01d0
oooo2P3AcJTL0?ooo`<000000P2ZZZX00`3oool00000000000020?ooo`80000000<0oooo0:ZZZP00
00000P00000M0?ooo`X0dLfY703oool305EEE@030?ooo`000000000000D0ZZZZ00@0EEEE00000000
000000000P1EEEDM0?ooo`X0dLfY703oool405EEE@030000003oool0ZZZZ0080ZZZZ00@000000:ZZ
ZP3oool0oooo0P00000205EEEAd0oooo2P3AcJTL0?ooo`0305EEE@3oool0ZZZZ00800000201EEED2
000000030:ZZZP3oool0oooo01`0oooo303AcJT000/0dLfY7@3oool01@2ZZZX0EEEE05EEE@000000
EEEE0080oooo00<0EEEE0?ooo`3oool00P1EEED010000000ZZZZ05EEE@2ZZZXM0?ooo`X0dLfY7@3o
ool00`2ZZZX0oooo05EEE@02000000030:ZZZP3oool0oooo00<0oooo0`0000000`3oool0ZZZZ0?oo
o`0L0?ooo`X0dLfY7@3oool01@1EEED0ZZZZ0?ooo`3oool0ZZZZ00D0EEEE00H0oooo0:ZZZP3oool0
oooo0:ZZZP1EEEDM0?ooo`X0dLfY7@3oool01@1EEED0ZZZZ0?ooo`000000EEEE0080000000T0oooo
05EEE@000000ZZZZ05EEE@000000oooo0:ZZZP1EEED07@3oool:0=7=ZAd0oooo00@0EEEE00000000
0000oooo0`2ZZZX00`1EEED0oooo0:ZZZP020:ZZZP040?ooo`2ZZZX0000005EEEAd0oooo303AcJT0
00/0dLfY7P3oool2000000<0EEEE00@0ZZZZ05EEE@1EEED0ZZZZ0`1EEED2000001h0oooo2P3AcJTN
0?ooo`80000000D0ZZZZ0?ooo`3oool000000?ooo`0200000080oooo00<0ZZZZ0000000000007P3o
ool:0=7=ZAh0oooo00H0EEEE0:ZZZP1EEED0EEEE0:ZZZP3oool20:ZZZP030?ooo`1EEED0EEEE00<0
EEEE7P3oool:0=7=ZAh0oooo0`1EEED00`2ZZZX0000005EEE@020?ooo`0305EEE@3oool0ZZZZ00<0
EEEE7P3oool:0=7=ZAh0oooo0P1EEED40000000405EEE@3oool000000?ooo`8000000P1EEEDN0?oo
o``0dLfY000;0=7=ZAl0oooo00/000000:ZZZP000000EEEE0?ooo`1EEED000000?ooo`1EEED00000
0:ZZZP0P0?ooo`X0dLfY7`3oool300000080EEEE00@0000005EEE@1EEED0oooo0P00000P0?ooo`X0
dLfY7`3oool405EEE@040?ooo`2ZZZX0ZZZZ0?ooo`<0EEEE803oool:0=7=ZAl0oooo0`1EEED50?oo
o`030000001EEED0EEEE0200oooo2P3AcJTO0?ooo`0305EEE@000000ZZZZ0080oooo00H0ZZZZ0000
003oool000000:ZZZP00000P0?ooo``0dLfY000;0=7=ZB00oooo00<0ZZZZ05EEE@0000000P1EEED0
1@3oool0EEEE0:ZZZP1EEED0ZZZZ0200oooo2P3AcJTP0?ooo`040:ZZZP3oool000000:ZZZP800000
00@0ZZZZ0000003oool0ZZZZ803oool:0=7=ZB00oooo00<0EEEE0:ZZZP2ZZZX0101EEED00`3oool0
ZZZZ05EEE@0P0?ooo`X0dLfY803oool00`1EEED0ZZZZ0?ooo`050?ooo`030:ZZZP1EEED0oooo01l0
oooo2P3AcJTP0?ooo`80EEEE0P00000205EEE@040000001EEED0EEEE05EEEB00oooo303AcJT000/0
dLfY8@3oool2000000040:ZZZP1EEED0EEEE0:ZZZP8000008@3oool:0=7=ZB40oooo0`0000000`3o
ool0EEEE0000000200000240oooo2P3AcJTQ0?ooo`0405EEE@2ZZZX0ZZZZ0?ooo`80ZZZZ0P1EEEDQ
0?ooo`X0dLfY8@3oool805EEEB40oooo2P3AcJTQ0?ooo`0805EEE@3oool0ZZZZ05EEE@3oool0ZZZZ
0?ooo`1EEEDQ0?ooo``0dLfY000;0=7=ZB80oooo00D000000:ZZZP3oool000000:ZZZP0S0?ooo`X0
dLfY8P3oool2000000030:ZZZP000000000002<0oooo2P3AcJTR0?ooo`80EEEE00<0ZZZZ0?ooo`1E
EED08`3oool:0=7=ZB80oooo0P1EEED00`000000EEEE05EEE@0S0?ooo`X0dLfY8P3oool205EEE@03
0000003oool0EEEE02<0oooo303AcJT000/0dLfY8`3oool20:ZZZP0305EEE@2ZZZX0oooo0280oooo
2P3AcJTS0?ooo`040:ZZZP000000oooo0:ZZZR<0oooo2P3AcJTS0?ooo`80EEEE00<0ZZZZ05EEE@3o
ool08P3oool:0=7=ZB<0oooo00@0EEEE0:ZZZP3oool0EEEE8`3oool:0=7=ZB<0oooo0P1EEED00`2Z
ZZX0EEEE0?ooo`0R0?ooo``0dLfY000;0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool:0=7=ZB@0
oooo00<0ZZZZ0?ooo`3oool08`3oool:0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool:0=7=ZB@0
oooo00<0ZZZZ0?ooo`3oool08`3oool:0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool<0=7=Z@00
o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00
2`3AcJT0103oool000000000000000020?ooo`0305EEE@2ZZZX0EEEE0080ZZZZ00D000000?ooo`3o
ool0oooo000000020:ZZZP0305EEE@3oool0oooo0080EEEE00@0oooo05EEE@1EEED0EEEE0`2ZZZX2
05EEE@0@0?ooo`2ZZZX0ZZZZ05EEE@000000oooo05EEE@3oool0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP00
0000ZZZZ000000H0EEEE00D0oooo05EEE@3oool0ZZZZ05EEE@020?ooo`050:ZZZP000000ZZZZ0:ZZ
ZP1EEED00P2ZZZX00`3oool0EEEE00000002000000030?ooo`3AcJT0dLfY00P0dLfY0P3oool01@2Z
ZZX0EEEE0000003oool0EEEE0080000000<0oooo0:ZZZP2ZZZX00P1EEED20?ooo`0305EEE@000000
00000080ZZZZ00@0EEEE0?ooo`000000EEEE0`3oool00`000000ZZZZ000000020:ZZZP030000003o
ool0oooo00<0oooo00H0EEEE0000002ZZZX0EEEE0000002ZZZX20?ooo`0305EEE@3oool0EEEE0080
oooo00<0EEEE0?ooo`2ZZZX00P0000001@1EEED0ZZZZ0?ooo`1EEED0oooo0080ZZZZ00X0oooo0000
00000000EEEE0?ooo`2ZZZX0EEEE0:ZZZP000000oooo2P3AcJT0103oool000000000001EEED20?oo
o`L0ZZZZ00<0EEEE0000001EEED0102ZZZX00`000000oooo0000000L0:ZZZP030000003oool0ZZZZ
00@0ZZZZ0P0000000`1EEED0ZZZZ0:ZZZP040:ZZZP80oooo0P1EEED2000000030?ooo`3AcJT0dLfY
00P0dLfY00d0oooo000000000000oooo0000002ZZZX0000005EEE@000000EEEE0000001EEED0ZZZZ
0080EEEE00D0ZZZZ0?ooo`2ZZZX0ZZZZ0000000205EEE@050000002ZZZX0oooo05EEE@0000000P1E
EED30?ooo`0505EEE@3oool0oooo05EEE@3oool00P1EEED00`000000oooo05EEE@030?ooo`@0EEEE
00L0oooo0:ZZZP000000EEEE0?ooo`000000ZZZZ0080oooo1@1EEED020000000EEEE0000001EEED0
oooo0:ZZZP000000oooo0P0000000`3oool0dLfY0=7=Z@080=7=Z@030?ooo`00000000000080oooo
0P2ZZZX40?ooo`0405EEE@3oool0EEEE05EEE@80oooo00H0000005EEE@000000oooo05EEE@2ZZZX2
0000000705EEE@000000000005EEE@000000oooo0:ZZZP020?ooo`050:ZZZP000000oooo0?ooo`00
00000`3oool01@2ZZZX0oooo0000001EEED000000080EEEE00@000000:ZZZP2ZZZX0EEEE0P000002
05EEE@080?ooo`1EEED0EEEE05EEE@000000EEEE0?ooo`2ZZZX20?ooo`80ZZZZ0P3oool200000003
0?ooo`3AcJT0dLfY00X0dLfY000;0=7=Z@0:0?ooo`2ZZZX0oooo0?ooo`2ZZZX0EEEE0?ooo`2ZZZX0
EEEE00000080EEEE0P000000101EEED0oooo0000002ZZZX205EEE@80oooo00D0EEEE0000002ZZZX0
ZZZZ05EEE@020?ooo`0505EEE@2ZZZX0oooo0000002ZZZX00P3oool205EEE@0:0?ooo`000000ZZZZ
0000001EEED0ZZZZ05EEE@2ZZZX0oooo00000080ZZZZ00@0oooo05EEE@3oool0oooo0P1EEED01@3o
ool000000000001EEED0000000D0EEEE0P2ZZZX00`1EEED0ZZZZ0?ooo`030?ooo`X0dLfY00<0oooo
0:ZZZP0000000P1EEED00`2ZZZX0oooo0:ZZZP030?ooo`80000000<0ZZZZ0000000000000`2ZZZX2
000000050:ZZZP000000ZZZZ0?ooo`2ZZZX00`0000020?ooo`<0ZZZZ0P000000101EEED000000000
000000030:ZZZP80oooo00@0EEEE000000000000ZZZZ0P3oool02P000000ZZZZ05EEE@000000ZZZZ
0000002ZZZX0oooo0000002ZZZX2000000<0oooo0`2ZZZX205EEE@030000003oool0oooo00X0dLfY
00<0oooo0:ZZZP3oool00P3oool010000000EEEE0?ooo`1EEED50:ZZZP030?ooo`2ZZZX0ZZZZ0080
ZZZZ00D0EEEE0?ooo`3oool0oooo05EEE@0K0:ZZZP80oooo00<0ZZZZ05EEE@2ZZZX00P2ZZZX20?oo
o`D0ZZZZ00D0EEEE0?ooo`1EEED0000005EEE@040?ooo`X0dLfY00T0oooo0:ZZZP3oool0oooo0:ZZ
ZP3oool000000:ZZZP3oool0101EEED20:ZZZP030000003oool000000080EEEE0P2ZZZX305EEE@07
0:ZZZP3oool0oooo0?ooo`1EEED0000005EEE@02000000050?ooo`1EEED0oooo0?ooo`1EEED00`00
00001@3oool0000005EEE@1EEED0oooo0080ZZZZ00@0EEEE0000001EEED0ZZZZ101EEED20?ooo`80
ZZZZ00<0oooo05EEE@1EEED00P3oool00`2ZZZX0EEEE0?ooo`050?ooo`X0dLfY00L0oooo0:ZZZP3o
ool000000?ooo`000000oooo008000000`3oool205EEE@030000001EEED0ZZZZ0080000000@0ZZZZ
0?ooo`3oool0EEEE0P3oool0102ZZZX0oooo0?ooo`2ZZZX20?ooo`040000003oool000000:ZZZP@0
oooo00<0EEEE0000003oool00`3oool01`2ZZZX0oooo0:ZZZP2ZZZX0oooo0:ZZZP1EEED00P3oool0
1P2ZZZX000000000002ZZZX0EEEE00000080EEEE0`3oool2000000040?ooo`000000EEEE000000<0
oooo303AcJT000/0dLfY0`3oool20:ZZZP0305EEE@3oool0oooo00<0EEEE0`2ZZZX01P3oool0EEEE
000000000000ZZZZ05EEE@<0ZZZZ00@0EEEE0000002ZZZX0EEEE0P3oool01@2ZZZX0EEEE05EEE@00
0000ZZZZ00<0oooo00d000000?ooo`1EEED0ZZZZ0000002ZZZX0EEEE0:ZZZP1EEED0oooo0000002Z
ZZX0000000<0ZZZZ00<0oooo05EEE@2ZZZX00P000000202ZZZX0oooo0:ZZZP3oool0ZZZZ05EEE@2Z
ZZX0EEEE0P3oool205EEE@040:ZZZP3oool0oooo0?ooo`X0dLfY0`3oool00`2ZZZX0oooo0?ooo`02
0:ZZZP070000002ZZZX000000:ZZZP3oool0EEEE0?ooo`020:ZZZP<0oooo00/0ZZZZ0?ooo`1EEED0
ZZZZ0?ooo`2ZZZX0oooo05EEE@3oool0ZZZZ000000020?ooo`8000000P2ZZZX02P3oool0ZZZZ0:ZZ
ZP000000oooo05EEE@000000ZZZZ0?ooo`1EEED20:ZZZP050?ooo`000000EEEE0?ooo`2ZZZX00`3o
ool20:ZZZP0:0?ooo`1EEED000000:ZZZP000000ZZZZ0000002ZZZX0EEEE0?ooo`80ZZZZ0`3oool:
0=7=Z@<0oooo00<0ZZZZ0?ooo`2ZZZX00P3oool01`2ZZZX0EEEE0:ZZZP2ZZZX0oooo0:ZZZP000000
1@2ZZZX00`000000EEEE0000000L0:ZZZP030000001EEED0ZZZZ00@0ZZZZ00@0EEEE0000002ZZZX0
EEEE102ZZZX20?ooo`<0ZZZZ0`3oool:0=7=Z@<0oooo0P2ZZZX0101EEED0oooo05EEE@1EEED20:ZZ
ZP050000002ZZZX0EEEE0?ooo`1EEED00`0000000`2ZZZX0EEEE00000002000000040:ZZZP1EEED0
ZZZZ000000<0EEEE0P2ZZZX02@1EEED0ZZZZ05EEE@2ZZZX0oooo05EEE@2ZZZX0EEEE0:ZZZP0305EE
E@050?ooo`000000EEEE05EEE@2ZZZX00`0000000`1EEED0ZZZZ00000002000000060:ZZZP3oool0
EEEE0?ooo`000000ZZZZ1@1EEED00`000000ZZZZ0?ooo`020?ooo`X0dLfY0`3oool0102ZZZX00000
0?ooo`1EEED20?ooo`80EEEE0`3oool205EEE@050:ZZZP3oool0oooo0?ooo`2ZZZX00P00000205EE
E@030?ooo`00000000000080ZZZZ0P3oool0101EEED0oooo0?ooo`3oool20:ZZZP<0oooo00<0EEEE
0?ooo`3oool00P2ZZZX2000000030?ooo`1EEED0oooo008000000`3oool010000000ZZZZ0000001E
EED30?ooo`0305EEE@3oool0oooo00@0oooo00@0ZZZZ0?ooo`3oool0oooo303AcJT000/0dLfY103o
ool205EEE@030:ZZZP1EEED0ZZZZ0080oooo00D0EEEE0:ZZZP2ZZZX0ZZZZ0?ooo`03000000050:ZZ
ZP1EEED0oooo0:ZZZP3oool00P00000205EEE@080000002ZZZX000000000002ZZZX0EEEE0000002Z
ZZX20?ooo`030:ZZZP3oool0EEEE0080ZZZZ00D000000:ZZZP3oool0EEEE0:ZZZP020000000305EE
E@2ZZZX0oooo0080ZZZZ0`000000301EEED0ZZZZ0:ZZZP2ZZZX0EEEE0?ooo`1EEED0ZZZZ05EEE@2Z
ZZX0EEEE000000@0oooo2P3AcJT50?ooo`0<0:ZZZP000000oooo0?ooo`1EEED000000?ooo`1EEED0
000005EEE@2ZZZX0EEEE0`0000030?ooo`030000002ZZZX0oooo0080ZZZZ00<000000:ZZZP1EEED0
0P0000000`1EEED0ZZZZ0?ooo`0205EEE@80oooo00/0EEEE0000001EEED0EEEE0:ZZZP3oool0ZZZZ
05EEE@3oool0ZZZZ05EEE@020?ooo`@0000000<0EEEE0000001EEED00P0000000`3oool000000:ZZ
ZP020?ooo`030000002ZZZX0000000@0oooo2P3AcJT40?ooo`80ZZZZ00<0EEEE0:ZZZP1EEED00`2Z
ZZX00`000000oooo0?ooo`040:ZZZP0505EEE@2ZZZX0oooo0:ZZZP1EEED06P2ZZZX01@3oool0ZZZZ
0?ooo`3oool0EEEE00@0ZZZZ0P3oool02@1EEED0ZZZZ0:ZZZP3oool0EEEE0:ZZZP1EEED0ZZZZ0000
00040?ooo`X0dLfY103oool01@000000ZZZZ0000001EEED000000080EEEE00@000000:ZZZP2ZZZX0
EEEE100000000`3oool0EEEE05EEE@0305EEE@030000001EEED0EEEE0080ZZZZ00D0EEEE0:ZZZP2Z
ZZX0ZZZZ0?ooo`020:ZZZP030000002ZZZX0EEEE00<0ZZZZ00@0EEEE0:ZZZP1EEED0EEEE0P000004
05EEE@80oooo00<000000?ooo`0000000P1EEED20:ZZZP080000001EEED000000000001EEED0oooo
0:ZZZP0000040?ooo`X0dLfY103oool20000000305EEE@3oool000000080oooo00@0EEEE0000001E
EED0oooo0P2ZZZX01P1EEED000000000003oool0ZZZZ0?ooo`80EEEE00<000000:ZZZP3oool00P3o
ool00`000000EEEE0?ooo`030?ooo`030000003oool0oooo00<0oooo0P0000002P3oool000000?oo
o`3oool0000005EEE@000000oooo0:ZZZP1EEED200000080ZZZZ0P3oool01P1EEED0000005EEE@3o
ool0EEEE00000080oooo0P0000040?ooo``0dLfY000;0=7=Z@@0oooo0P2ZZZX00`1EEED0ZZZZ05EE
E@030?ooo`080:ZZZP3oool0EEEE05EEE@2ZZZX0EEEE0:ZZZP0000020:ZZZP0305EEE@000000ZZZZ
0080EEEE0P3oool0202ZZZX0EEEE05EEE@2ZZZX0oooo0000001EEED0oooo0P1EEED01P2ZZZX0oooo
0:ZZZP000000EEEE0:ZZZP80oooo00H0000005EEE@2ZZZX0oooo05EEE@2ZZZX2000000070:ZZZP00
0000ZZZZ0:ZZZP1EEED0oooo05EEE@030?ooo`0405EEE@2ZZZX0oooo0:ZZZPD0oooo2P3AcJT40?oo
o`090:ZZZP000000oooo0000002ZZZX0EEEE0?ooo`000000ZZZZ0080oooo00P000000:ZZZP2ZZZX0
ZZZZ0000002ZZZX0EEEE0:ZZZP80oooo0P0000001P1EEED0ZZZZ0000001EEED000000?ooo`80EEEE
00L0ZZZZ0?ooo`2ZZZX0ZZZZ0?ooo`1EEED0oooo0080EEEE00H000000:ZZZP1EEED0ZZZZ0000003o
ool20:ZZZP0705EEE@2ZZZX000000:ZZZP000000ZZZZ05EEE@020?ooo`080:ZZZP000000oooo0?oo
o`2ZZZX0000005EEE@0000050?ooo`X0dLfY103oool00`2ZZZX0EEEE0?ooo`0205EEE@<0ZZZZ0P00
00050:ZZZP0505EEE@3oool0oooo0?ooo`1EEED06P2ZZZX01@000000oooo0?ooo`000000EEEE00D0
ZZZZ00@0000005EEE@2ZZZX0ZZZZ0`1EEED00`3oool0EEEE0?ooo`040?ooo`X0dLfY103oool01@2Z
ZZX0oooo0000002ZZZX0oooo0080ZZZZ0`1EEED020000000EEEE0:ZZZP2ZZZX0EEEE0000001EEED0
oooo0P1EEED30?ooo`030:ZZZP1EEED0oooo00@0ZZZZ0P1EEED00`2ZZZX0000005EEE@050:ZZZP04
0?ooo`2ZZZX0ZZZZ0:ZZZP<0oooo00L0EEEE0?ooo`3oool0000005EEE@000000ZZZZ0080000000@0
EEEE0000001EEED0ZZZZ0P3oool00`2ZZZX0EEEE0?ooo`050?ooo`X0dLfY103oool00`2ZZZX0oooo
05EEE@0205EEE@<0oooo00H0EEEE0?ooo`3oool0oooo0000003oool205EEE@80oooo0P000000102Z
ZZX000000000003oool405EEE@040?ooo`000000oooo05EEE@80000000<0EEEE0000000000000P3o
ool305EEE@80oooo00@000000:ZZZP00000000000P3oool205EEE@030?ooo`000000oooo0080oooo
00@0EEEE0?ooo`3oool0oooo0P1EEED00`000000oooo0?ooo`040?ooo``0dLfY000;0=7=Z@H0oooo
0P0000000`2ZZZX0oooo000000020?ooo`<0ZZZZ00D000000:ZZZP3oool0EEEE0?ooo`080:ZZZP04
0?ooo`1EEED0000000000080ZZZZ0P1EEED01@2ZZZX0EEEE0:ZZZP2ZZZX000000080EEEE00@0oooo
0:ZZZP2ZZZX0oooo0P2ZZZX00`1EEED0ZZZZ0:ZZZP0205EEE@040?ooo`2ZZZX0000005EEE@<0ZZZZ
00H0oooo000000000000ZZZZ0000002ZZZX60?ooo`X0dLfY1P3oool0102ZZZX0oooo0000003oool3
000000050?ooo`1EEED0EEEE05EEE@2ZZZX00P000000103oool0EEEE05EEE@2ZZZX50?ooo`040000
002ZZZX00000000000<0EEEE00`0oooo0:ZZZP1EEED0000005EEE@000000EEEE0:ZZZP000000ZZZZ
0?ooo`0000020?ooo`040000001EEED0EEEE05EEE@8000000P1EEED010000000EEEE0?ooo`1EEED2
0000000405EEE@000000oooo0:ZZZPH0oooo2P3AcJT70?ooo`0305EEE@2ZZZX0ZZZZ00<0ZZZZ0P1E
EED00`3oool000000:ZZZP020:ZZZP0305EEE@000000EEEE01/0ZZZZ0P1EEED01`000000EEEE0:ZZ
ZP2ZZZX0EEEE0000003oool00`1EEED20:ZZZP0405EEE@2ZZZX0EEEE0:ZZZPH0oooo2P3AcJT60?oo
o`040000001EEED0EEEE00000080EEEE00@0oooo05EEE@1EEED0EEEE0P3oool305EEE@080:ZZZP3o
ool0oooo05EEE@000000oooo0:ZZZP1EEED20?ooo`0405EEE@000000EEEE05EEE@80ZZZZ00@0oooo
0:ZZZP3oool0EEEE0P0000020?ooo`0505EEE@2ZZZX0ZZZZ0000001EEED00P3oool01@2ZZZX0oooo
05EEE@1EEED000000080oooo0P1EEED00`000000EEEE05EEE@0305EEE@030:ZZZP3oool0oooo00@0
oooo2P3AcJT70?ooo`070000003oool0oooo0:ZZZP3oool0EEEE0?ooo`0205EEE@050?ooo`1EEED0
EEEE0000001EEED00P0000030?ooo`0:05EEE@3oool0ZZZZ0:ZZZP3oool0EEEE0000002ZZZX0oooo
05EEE@80oooo0P1EEED01@2ZZZX000000?ooo`3oool0ZZZZ0080oooo00@0ZZZZ0?ooo`3oool0oooo
1000000205EEE@030?ooo`1EEED0EEEE00<0oooo0P2ZZZX00`3oool000000:ZZZP060?ooo``0dLfY
000;0=7=Z@H0oooo0`0000000`1EEED0ZZZZ000000020?ooo`090000001EEED0ZZZZ0000002ZZZX0
oooo0:ZZZP1EEED0oooo00<0ZZZZ00D0EEEE0?ooo`1EEED0oooo05EEE@02000000050?ooo`000000
oooo0:ZZZP1EEED00`3oool01P000000oooo05EEE@3oool0ZZZZ0?ooo`@0ZZZZ00T0oooo05EEE@2Z
ZZX0oooo0:ZZZP000000ZZZZ0?ooo`0000000P3oool00`000000ZZZZ0:ZZZP02000000L0oooo2P3A
cJT60?ooo`060000003oool0ZZZZ0:ZZZP000000ZZZZ0`3oool00`000000EEEE000000020:ZZZP03
0000001EEED0EEEE00<0oooo00<0ZZZZ0000000000000P2ZZZX20?ooo`060:ZZZP000000000005EE
E@2ZZZX000000P2ZZZX01P3oool0ZZZZ0:ZZZP2ZZZX0oooo000000<0oooo00@0000005EEE@1EEED0
00000P2ZZZX305EEE@80oooo0P2ZZZX00`000000oooo0:ZZZP080?ooo`X0dLfY1P3oool01@000000
EEEE0:ZZZP2ZZZX0EEEE0080oooo00X0EEEE0?ooo`3oool0oooo0:ZZZP1EEED0ZZZZ0?ooo`2ZZZX0
oooo702ZZZX01P3oool0ZZZZ0:ZZZP2ZZZX0EEEE0:ZZZP<0oooo0P1EEED01@3oool0EEEE0?ooo`2Z
ZZX0EEEE00L0oooo2P3AcJT60?ooo`80000000L0EEEE0000003oool0ZZZZ05EEE@3oool0EEEE0080
ZZZZ00<0EEEE0?ooo`1EEED01@2ZZZX205EEE@050?ooo`000000oooo05EEE@2ZZZX00P3oool20000
0080ZZZZ00d0000005EEE@3oool0oooo0000001EEED0oooo0:ZZZP3oool0000005EEE@2ZZZX00000
0080ZZZZ0P1EEED00`3oool000000:ZZZP0205EEE@070?ooo`000000ZZZZ0?ooo`000000EEEE0000
00070?ooo`X0dLfY1P3oool300000080oooo00<000000?ooo`3oool00`3oool01`1EEED0oooo0?oo
o`3oool0ZZZZ0?ooo`1EEED00P0000001@3oool0EEEE0?ooo`3oool000000080EEEE00@0oooo0:ZZ
ZP000000EEEE0P0000000`2ZZZX0oooo05EEE@02000000040?ooo`000000EEEE0?ooo`<0000000<0
oooo0:ZZZP2ZZZX0103oool01@1EEED0oooo0?ooo`1EEED000000080oooo0P0000070?ooo``0dLfY
000;0=7=Z@L0oooo00<0ZZZZ0?ooo`0000000P1EEED0103oool0EEEE05EEE@3oool30000000;0:ZZ
ZP1EEED0ZZZZ05EEE@3oool0EEEE0:ZZZP1EEED0oooo0:ZZZP1EEED00P2ZZZX010000000EEEE0000
003oool20:ZZZP060?ooo`000000EEEE0000001EEED0ZZZZ0P1EEED20?ooo`0:0:ZZZP1EEED0ZZZZ
05EEE@2ZZZX0oooo0:ZZZP000000oooo000000H0EEEE0P3oool00`2ZZZX0oooo0?ooo`050?ooo`X0
dLfY1`3oool00`2ZZZX00000000000030:ZZZP0305EEE@2ZZZX0oooo0080oooo00T000000?ooo`2Z
ZZX0oooo0:ZZZP000000oooo0:ZZZP3oool00P0000020?ooo`<0000000H0oooo0:ZZZP1EEED0oooo
0:ZZZP3oool300000080oooo00D0EEEE000000000000ZZZZ0?ooo`020:ZZZP<0oooo00<0000005EE
E@3oool00P2ZZZX01`1EEED0ZZZZ0:ZZZP2ZZZX0EEEE0000002ZZZX01`3oool:0=7=Z@L0oooo0P2Z
ZZX01`000000oooo0000002ZZZX0EEEE0000001EEED00`2ZZZX20?ooo`80EEEE702ZZZX205EEE@07
0000003oool0ZZZZ05EEE@2ZZZX0EEEE0000000205EEE@030000003oool0ZZZZ0080ZZZZ1`3oool:
0=7=Z@L0oooo00<0ZZZZ0?ooo`3oool00P3oool01@000000EEEE0?ooo`3oool0ZZZZ00@000000P1E
EED00`2ZZZX00000000000020:ZZZP060000003oool0EEEE05EEE@000000oooo0P1EEED01P000000
EEEE05EEE@1EEED0oooo00000080EEEE00@0oooo0000002ZZZX0EEEE0`00000305EEE@80000000H0
EEEE0:ZZZP1EEED0oooo05EEE@0000020?ooo`030:ZZZP3oool0ZZZZ00L0oooo2P3AcJT70?ooo`04
0:ZZZP3oool0EEEE0?ooo`80000000D0EEEE000000000000ZZZZ05EEE@0200000080oooo0P000000
102ZZZX0oooo0?ooo`3oool405EEE@80oooo00@000000?ooo`3oool0ZZZZ1@3oool305EEE@<0oooo
00<0ZZZZ0000000000000P3oool20000000;05EEE@2ZZZX0ZZZZ0000001EEED0ZZZZ0000003oool0
00000?ooo`2ZZZX01`3oool<0=7=Z@002`3AcJT90?ooo`0505EEE@2ZZZX0ZZZZ0000002ZZZX00P3o
ool00`000000ZZZZ0?ooo`030?ooo`80EEEE00<0ZZZZ05EEE@3oool00`0000020:ZZZP80000000H0
EEEE0?ooo`1EEED0EEEE0?ooo`1EEED2000000040?ooo`2ZZZX000000:ZZZP80000000@0EEEE0:ZZ
ZP2ZZZX0EEEE1@3oool01@000000ZZZZ0?ooo`2ZZZX0oooo00<0ZZZZ2@3oool:0=7=Z@T0oooo00@0
ZZZZ0?ooo`1EEED0EEEE0P2ZZZX20?ooo`030:ZZZP3oool000000080ZZZZ00D0oooo0:ZZZP3oool0
EEEE000000020:ZZZP030000002ZZZX0ZZZZ00@0ZZZZ0P1EEED0202ZZZX0EEEE0:ZZZP2ZZZX0EEEE
0:ZZZP000000oooo0P2ZZZX02P1EEED0oooo0:ZZZP3oool0ZZZZ05EEE@000000oooo0:ZZZP3oool3
0:ZZZP040000001EEED0oooo0:ZZZPT0oooo2P3AcJT90?ooo`80EEEE00`000000:ZZZP1EEED0oooo
05EEE@2ZZZX000000?ooo`2ZZZX0oooo05EEE@00000K0:ZZZP0?05EEE@000000EEEE0?ooo`2ZZZX0
oooo05EEE@2ZZZX000000?ooo`1EEED0oooo0000001EEED0ZZZZ00T0oooo2P3AcJT90?ooo`040000
003oool0oooo0?ooo`80EEEE0`0000020:ZZZP<0000000h0EEEE0:ZZZP2ZZZX0ZZZZ05EEE@3oool0
ZZZZ05EEE@000000oooo0000002ZZZX0EEEE0?ooo`80EEEE00L0ZZZZ0000003oool0oooo05EEE@2Z
ZZX0oooo0080EEEE0`2ZZZX2000000@0ZZZZ00<000000:ZZZP1EEED00P1EEED20?ooo`030:ZZZP3o
ool0oooo00L0oooo2P3AcJT:0?ooo`070000003oool0EEEE0000001EEED0oooo000000020?ooo`04
0000001EEED00000000000<0oooo0P2ZZZX01`3oool0EEEE0?ooo`3oool0EEEE0?ooo`2ZZZX0103o
ool01`000000oooo05EEE@1EEED0oooo05EEE@3oool00P2ZZZX30?ooo`@000000P3oool010000000
oooo05EEE@0000020?ooo`030000002ZZZX0oooo00P0oooo303AcJT000/0dLfY2@3oool00`000000
EEEE05EEE@020000000>0:ZZZP1EEED0EEEE0?ooo`2ZZZX000000:ZZZP000000oooo0:ZZZP1EEED0
oooo0:ZZZP00000305EEE@060000002ZZZX0EEEE0?ooo`1EEED0ZZZZ0P1EEED010000000EEEE0:ZZ
ZP00000305EEE@030000003oool0oooo0080EEEE00D0oooo0000003oool000000:ZZZP0205EEE@04
0?ooo`2ZZZX0000000000080EEEE2P3oool:0=7=Z@T0oooo00<000000?ooo`2ZZZX00P000000103o
ool000000:ZZZP1EEED20:ZZZP080000003oool0000005EEE@3oool0EEEE0:ZZZP3oool205EEE@80
ZZZZ00D0EEEE0?ooo`2ZZZX0ZZZZ0?ooo`030:ZZZP040?ooo`1EEED0oooo0:ZZZP80EEEE0P3oool0
1P1EEED0oooo0:ZZZP000000oooo00000080ZZZZ00D0oooo0:ZZZP3oool0oooo000000020:ZZZP/0
oooo2P3AcJT90?ooo`<0000000<0EEEE0?ooo`3oool00P2ZZZX30?ooo`0305EEE@3oool0oooo01`0
ZZZZ0P3oool00`000000oooo0?ooo`020:ZZZP<0oooo00<0EEEE0000000000002P3oool:0=7=Z@T0
oooo0`0000001@1EEED0oooo05EEE@2ZZZX0oooo0080000000L0ZZZZ0000003oool000000:ZZZP3o
ool0EEEE0080ZZZZ00D0EEEE0:ZZZP3oool0EEEE0:ZZZP0305EEE@80oooo00P0EEEE0000001EEED0
ZZZZ0000003oool0ZZZZ05EEE@80ZZZZ00P0EEEE0?ooo`00000000000?ooo`000000ZZZZ000000<0
oooo00<0EEEE0?ooo`0000000P00000:0?ooo`X0dLfY2@3oool30000000305EEE@3oool0EEEE0080
000000D0oooo00000000000000000:ZZZP040?ooo`040000003oool0oooo0?ooo`80EEEE0P3oool0
1@2ZZZX0EEEE0?ooo`000000EEEE00<0oooo00<0000005EEE@3oool01`3oool00`2ZZZX000000000
0003000000040?ooo`1EEED0oooo0?ooo`8000002P3oool<0=7=Z@002`3AcJT;0?ooo`070000002Z
ZZX000000000003oool0000005EEE@02000000<0oooo00<0EEEE0?ooo`2ZZZX00P1EEED20:ZZZP80
EEEE00D000000?ooo`00000000000:ZZZP02000000030:ZZZP3oool000000080EEEE00L0ZZZZ05EE
E@1EEED000000:ZZZP3oool0ZZZZ0080oooo00H0ZZZZ000000000000oooo0000001EEED200000003
0?ooo`000000oooo00X0oooo2P3AcJT;0?ooo`030000001EEED0EEEE0080000000@0EEEE0:ZZZP00
0000EEEE0P2ZZZX01P3oool0EEEE0:ZZZP000000ZZZZ0?ooo`@0ZZZZ00D0oooo0000003oool0oooo
0:ZZZP020?ooo`030:ZZZP000000oooo00<0ZZZZ00@0EEEE0?ooo`2ZZZX000000P2ZZZX01P3oool0
ZZZZ05EEE@1EEED000000?ooo`80EEEE00@0000005EEE@1EEED000002`3oool:0=7=Z@/0oooo00H0
000005EEE@1EEED000000?ooo`0000020:ZZZP<0oooo0`2ZZZX00`1EEED0ZZZZ0:ZZZP0D0:ZZZP09
05EEE@2ZZZX0EEEE0:ZZZP3oool0ZZZZ0?ooo`2ZZZX0EEEE00<000000P1EEED00`000000oooo0?oo
o`090?ooo`X0dLfY2`3oool01@000000oooo0:ZZZP1EEED0oooo00<0ZZZZ0P3oool505EEE@0:0?oo
o`000000EEEE05EEE@2ZZZX0EEEE0000001EEED0ZZZZ05EEE@80ZZZZ0`1EEED00`000000EEEE0:ZZ
ZP0205EEE@050000002ZZZX0EEEE05EEE@3oool00P1EEED02P2ZZZX0oooo0:ZZZP1EEED0ZZZZ0000
001EEED0ZZZZ05EEE@00000;0?ooo`X0dLfY2`3oool2000000030:ZZZP000000000000@0oooo00@0
00000?ooo`3oool0oooo0P2ZZZX01@1EEED0oooo0:ZZZP1EEED0000000<0oooo00<000000:ZZZP3o
ool00`2ZZZX20?ooo`0405EEE@000000EEEE0:ZZZP80oooo0P2ZZZX0101EEED0oooo0?ooo`000004
0?ooo`80000000<0ZZZZ0000000000002`3oool<0=7=Z@002`3AcJT<0?ooo`<000000P1EEED20?oo
o`0:0:ZZZP1EEED0EEEE0?ooo`2ZZZX0EEEE0:ZZZP3oool0EEEE000000@0oooo00D0ZZZZ00000000
000000000?ooo`02000000030:ZZZP3oool0EEEE00<0oooo00<0EEEE0?ooo`2ZZZX00P1EEED01@3o
ool0EEEE0?ooo`2ZZZX0oooo0080EEEE00@0oooo000000000000ZZZZ303oool:0=7=Z@`0oooo0140
ZZZZ0?ooo`2ZZZX0ZZZZ0?ooo`000000EEEE0?ooo`1EEED0ZZZZ0000003oool0EEEE0:ZZZP3oool0
ZZZZ000000030?ooo`040000002ZZZX0ZZZZ05EEE@80ZZZZ00<0EEEE0:ZZZP2ZZZX00P0000020?oo
o`080000002ZZZX0EEEE0:ZZZP1EEED0oooo0000002ZZZX20?ooo`0705EEE@2ZZZX0oooo0?ooo`2Z
ZZX0oooo0:ZZZP0<0?ooo`X0dLfY303oool00`2ZZZX0oooo0:ZZZP020?ooo`040:ZZZP1EEED0ZZZZ
0:ZZZP80EEEE00D0oooo0000002ZZZX0oooo05EEE@0B0:ZZZP80EEEE00<0ZZZZ0000003oool00`1E
EED00`2ZZZX0EEEE0:ZZZP020?ooo`030:ZZZP3oool0ZZZZ00`0oooo2P3AcJT<0?ooo`0:0000002Z
ZZX000000000001EEED0oooo0:ZZZP1EEED000000?ooo`80ZZZZ00<0oooo0000000000000`2ZZZX3
0?ooo`040:ZZZP3oool0EEEE00000080EEEE0P2ZZZX01@3oool0EEEE0?ooo`2ZZZX0EEEE0080ZZZZ
00D000000?ooo`000000ZZZZ0?ooo`0205EEE@050:ZZZP1EEED0EEEE0?ooo`0000000P2ZZZX<0?oo
o`X0dLfY3@3oool01P000000oooo0?ooo`000000ZZZZ05EEE@<0000000D0EEEE0?ooo`3oool00000
05EEE@030?ooo`0605EEE@000000000005EEE@3oool000000P3oool010000000ZZZZ05EEE@000002
05EEE@050?ooo`000000oooo0?ooo`0000000P3oool0101EEED0000000000000000205EEE@050000
002ZZZX0oooo0000002ZZZX0303oool<0=7=Z@002`3AcJT<0?ooo`<0000000<0EEEE0?ooo`1EEED0
0P0000001@3oool0ZZZZ0:ZZZP1EEED0000000<0oooo0P1EEED20?ooo`80EEEE00H0ZZZZ05EEE@00
0000000005EEE@00000305EEE@030?ooo`1EEED0EEEE00<0oooo00<0000005EEE@2ZZZX00P2ZZZX3
000000040?ooo`0000000000000000d0oooo2P3AcJT<0?ooo`040000003oool0ZZZZ0:ZZZP800000
0`1EEED01P3oool0ZZZZ0000002ZZZX0000005EEE@@0oooo00@0ZZZZ0000002ZZZX0oooo102ZZZX0
0`1EEED0ZZZZ000000030?ooo`070:ZZZP3oool0EEEE0000002ZZZX0oooo0:ZZZP020?ooo`80EEEE
00@0oooo0000001EEED0ZZZZ3P3oool:0=7=Z@`0oooo00H000000:ZZZP2ZZZX0EEEE0:ZZZP3oool2
0:ZZZP030?ooo`1EEED0oooo0080oooo00<0ZZZZ0000001EEED04P2ZZZX205EEE@050:ZZZP3oool0
oooo0?ooo`1EEED00`2ZZZX00`1EEED0ZZZZ05EEE@020:ZZZPd0oooo2P3AcJT<0?ooo`80000000T0
ZZZZ05EEE@1EEED0EEEE0000001EEED000000?ooo`1EEED00`0000001@3oool0ZZZZ0:ZZZP3oool0
EEEE00@000000P2ZZZX00`3oool0ZZZZ0:ZZZP030000000505EEE@3oool0EEEE0:ZZZP3oool00P00
00001`2ZZZX0EEEE0?ooo`000000EEEE0000003oool00P1EEED00`2ZZZX000000?ooo`0<0?ooo`X0
dLfY303oool300000080oooo0P2ZZZX01P3oool0ZZZZ0?ooo`3oool000000?ooo`80EEEE0P000000
1@1EEED0oooo05EEE@1EEED0oooo0080000000<0oooo0000000000000P3oool0101EEED0oooo0?oo
o`1EEED200000080EEEE00<0oooo05EEE@3oool00`3oool20:ZZZP80oooo0P00000=0?ooo``0dLfY
000;0=7=Z@h0oooo00@000000?ooo`1EEED0EEEE0`000000102ZZZX0oooo05EEE@1EEED20:ZZZP03
05EEE@3oool0EEEE0080oooo00T0EEEE0?ooo`1EEED0000005EEE@3oool0000005EEE@3oool00P1E
EED00`3oool0EEEE05EEE@0205EEE@050:ZZZP1EEED0ZZZZ0?ooo`2ZZZX00`000000102ZZZX0EEEE
0:ZZZP00000>0?ooo`X0dLfY3P3oool010000000EEEE0000002ZZZX20?ooo`0405EEE@2ZZZX0oooo
05EEE@80000000D0oooo0000002ZZZX000000:ZZZP020?ooo`030000003oool0ZZZZ0080oooo00@0
ZZZZ000000000000oooo0P2ZZZX00`000000ZZZZ0000000300000080oooo0P2ZZZX20?ooo`0405EE
E@000000EEEE000000h0oooo2P3AcJT>0?ooo`030000002ZZZX0ZZZZ00@0ZZZZ00L0oooo0:ZZZP2Z
ZZX0oooo0:ZZZP3oool000000140ZZZZ00D0EEEE0000001EEED0ZZZZ0?ooo`020:ZZZP060?ooo`2Z
ZZX0ZZZZ0:ZZZP3oool0ZZZZ0P00000>0?ooo`X0dLfY3P3oool30000000405EEE@2ZZZX000000000
0080ZZZZ0P3oool20:ZZZP0705EEE@000000EEEE05EEE@3oool0EEEE0:ZZZP0205EEE@070000001E
EED0EEEE05EEE@2ZZZX0EEEE0000000205EEE@060:ZZZP1EEED0ZZZZ0:ZZZP3oool000000`2ZZZX0
1P000000ZZZZ000000000000EEEE000000h0oooo2P3AcJT>0?ooo`80000000<0ZZZZ05EEE@1EEED0
0P1EEED200000080oooo0P1EEED20?ooo`0605EEE@3oool0000005EEE@2ZZZX00000103oool01P1E
EED0ZZZZ05EEE@1EEED0oooo05EEE@<0oooo00<0EEEE0?ooo`1EEED00P0000000`3oool0EEEE05EE
E@020:ZZZP8000003P3oool<0=7=Z@002`3AcJT?0?ooo`0905EEE@2ZZZX0oooo0?ooo`2ZZZX0oooo
0:ZZZP1EEED0oooo0080ZZZZ00D0oooo05EEE@3oool0oooo05EEE@020:ZZZP090000001EEED00000
0?ooo`2ZZZX000000?ooo`000000ZZZZ0080EEEE0P3oool00`1EEED0ZZZZ0:ZZZP020:ZZZP0605EE
E@2ZZZX0oooo0:ZZZP3oool0EEEE0P2ZZZX?0?ooo`X0dLfY3`3oool00`2ZZZX0oooo05EEE@020:ZZ
ZP80oooo00P000000?ooo`2ZZZX0oooo0:ZZZP000000EEEE00000080oooo00@0ZZZZ0000002ZZZX0
EEEE0P0000002@1EEED0ZZZZ0000002ZZZX000000?ooo`000000ZZZZ000000020?ooo`80ZZZZ00<0
00000?ooo`1EEED00P2ZZZX20?ooo`030:ZZZP3oool0oooo00d0oooo2P3AcJT@0?ooo`80EEEE0P2Z
ZZX0101EEED0ZZZZ05EEE@2ZZZX205EEE@80oooo4P2ZZZX20?ooo`80EEEE00<0ZZZZ05EEE@2ZZZX0
102ZZZX00`1EEED0ZZZZ0?ooo`0>0?ooo`X0dLfY3`3oool00`000000EEEE000000020?ooo`0805EE
E@000000EEEE05EEE@2ZZZX0EEEE0:ZZZP1EEED20?ooo`80EEEE0P2ZZZX0103oool0ZZZZ0?ooo`00
00040:ZZZP80EEEE00H0oooo0:ZZZP1EEED0oooo05EEE@2ZZZX205EEE@070000002ZZZX0oooo0?oo
o`2ZZZX0EEEE0:ZZZP0?0?ooo`X0dLfY403oool00`000000oooo05EEE@020?ooo`80EEEE0`3oool0
1P000000EEEE05EEE@000000EEEE0?ooo`80ZZZZ1@3oool30:ZZZP040?ooo`1EEED000000:ZZZP80
EEEE0`3oool205EEE@80oooo00@0EEEE0?ooo`000000ZZZZ3`3oool<0=7=Z@002`3AcJT?0?ooo`04
0000001EEED0ZZZZ0:ZZZP<0EEEE00@000000?ooo`3oool000000P3oool0101EEED0oooo05EEE@00
00020?ooo`040000002ZZZX0oooo05EEE@80ZZZZ0`3oool00`1EEED0oooo05EEE@020?ooo`080000
003oool0oooo0000001EEED0oooo05EEE@2ZZZX205EEEA00oooo2P3AcJT?0?ooo`050000003oool0
00000000003oool00P1EEED20?ooo`040:ZZZP1EEED0ZZZZ0:ZZZP80EEEE00L0ZZZZ0000003oool0
oooo05EEE@3oool0ZZZZ0080oooo00<0ZZZZ0?ooo`3oool00P2ZZZX02@1EEED000000:ZZZP2ZZZX0
EEEE0:ZZZP000000oooo05EEE@020?ooo`030000002ZZZX0oooo0100oooo2P3AcJT?0?ooo`040000
001EEED0oooo0:ZZZP80EEEE00H0oooo05EEE@1EEED0ZZZZ0000001EEEDB0:ZZZP0705EEE@2ZZZX0
EEEE0000002ZZZX0oooo05EEE@020?ooo`0405EEE@2ZZZX0ZZZZ05EEEA00oooo2P3AcJT?0?ooo`80
00000P1EEED01P2ZZZX0oooo0?ooo`2ZZZX0oooo0:ZZZP80EEEE00<0oooo0:ZZZP1EEED00`1EEED0
0`000000EEEE0:ZZZP020?ooo`050:ZZZP1EEED0000005EEE@3oool00`1EEED00`3oool0ZZZZ05EE
E@030:ZZZP030?ooo`1EEED0ZZZZ0080EEEE00<000000?ooo`3oool03P3oool:0=7=Z@l0oooo0P00
0000103oool0EEEE0?ooo`1EEED20?ooo`80000000@0EEEE0?ooo`2ZZZX0ZZZZ0P3oool01P000000
oooo0?ooo`3oool0000005EEE@<000000P3oool00`1EEED0oooo0?ooo`020:ZZZP040?ooo`1EEED0
000005EEE@80oooo00<000000?ooo`1EEED00P00000@0?ooo``0dLfY000;0=7=ZA80oooo0P2ZZZX0
1@3oool0EEEE0?ooo`1EEED000000080oooo00D0EEEE0?ooo`000000EEEE0:ZZZP020?ooo`050000
001EEED0EEEE0:ZZZP1EEED00`3oool205EEE@050000003oool0EEEE05EEE@3oool00P0000000`3o
ool0EEEE0:ZZZP020:ZZZP030000003oool0oooo00l0oooo2P3AcJTA0?ooo`80EEEE0P3oool00`2Z
ZZX0EEEE0?ooo`0505EEE@040:ZZZP1EEED0EEEE00000080oooo00@0EEEE0000001EEED0EEEE0P3o
ool20000000305EEE@2ZZZX0EEEE00@0EEEE00L0oooo05EEE@2ZZZX000000?ooo`1EEED000000140
oooo2P3AcJTA0?ooo`030:ZZZP3oool0oooo00<0ZZZZ00<0oooo05EEE@2ZZZX00P1EEEDB0:ZZZP80
EEEE00<0ZZZZ05EEE@3oool00P2ZZZX30?ooo`030000003oool0oooo00l0oooo2P3AcJTA0?ooo`80
EEEE10000000203oool0EEEE0?ooo`1EEED0oooo05EEE@000000EEEE0`3oool5000000<0oooo0P1E
EED01P000000oooo0?ooo`2ZZZX0oooo05EEE@D0000000<0EEEE0000003oool0403oool:0=7=ZA40
oooo0P000000102ZZZX0000005EEE@00000205EEE@060000003oool000000000003oool000000P3o
ool00`1EEED0ZZZZ000000020?ooo`070000002ZZZX0EEEE0?ooo`1EEED000000?ooo`0400000006
05EEE@000000000005EEE@000000ZZZZ0P00000A0?ooo``0dLfY000;0=7=ZA40oooo00D0ZZZZ0000
0000000000000?ooo`0205EEE@080:ZZZP000000EEEE05EEE@2ZZZX0EEEE0000001EEED30:ZZZP80
000000<0ZZZZ0000001EEED00P2ZZZX0203oool0000005EEE@2ZZZX0EEEE0?ooo`000000ZZZZ0P1E
EED0103oool0ZZZZ00000000000B0?ooo`X0dLfY4@3oool20:ZZZP050?ooo`1EEED000000:ZZZP3o
ool01`2ZZZX00`3oool0EEEE00000003000000060:ZZZP00000000000000001EEED0oooo0P2ZZZX0
0`3oool0ZZZZ0?ooo`020:ZZZP060000002ZZZX000000000003oool0ZZZZ4P3oool:0=7=ZA40oooo
00X0ZZZZ05EEE@1EEED0oooo0:ZZZP1EEED0000005EEE@2ZZZX0oooo5P2ZZZX01@1EEED0oooo05EE
E@2ZZZX000000080EEEE4P3oool:0=7=ZA40oooo00L0ZZZZ0000003oool000000?ooo`000000oooo
0080EEEE00D0oooo0000003oool0oooo0:ZZZP0205EEE@030:ZZZP1EEED0EEEE00@0EEEE00P0ZZZZ
05EEE@2ZZZX0ZZZZ0?ooo`1EEED000000:ZZZP80EEEE0P000000103oool000000?ooo`00000B0?oo
o`X0dLfY4@3oool02@2ZZZX0oooo0000002ZZZX0oooo0:ZZZP3oool0EEEE0?ooo`0505EEE@<0oooo
00<0ZZZZ0?ooo`3oool00P3oool0101EEED0oooo0?ooo`3oool205EEE@070?ooo`1EEED0EEEE0?oo
o`1EEED0oooo0:ZZZP020?ooo`030000003oool0oooo0140oooo303AcJT000/0dLfY4P3oool20000
00050:ZZZP1EEED0ZZZZ05EEE@2ZZZX00P3oool02@1EEED0ZZZZ05EEE@1EEED0oooo0000003oool0
EEEE0:ZZZP02000000040:ZZZP3oool0oooo000000<0EEEE00P0oooo05EEE@3oool0oooo0:ZZZP1E
EED0ZZZZ05EEE@<000004P3oool:0=7=ZA80oooo00D000000?ooo`3oool0ZZZZ0?ooo`0200000080
oooo0P000000303oool0000005EEE@000000EEEE0000001EEED0ZZZZ0?ooo`1EEED0oooo05EEE@<0
000000<0oooo0000000000000P3oool00`000000EEEE0?ooo`020:ZZZP030?ooo`000000oooo0140
oooo2P3AcJTB0?ooo`8000000P1EEED20?ooo`<0ZZZZ00<0EEEE0:ZZZP2ZZZX0402ZZZX205EEE@80
ZZZZ0P3oool0101EEED0000000000000000B0?ooo`X0dLfY4P3oool2000000060?ooo`000000EEEE
0000002ZZZX0oooo0P1EEED00`3oool0000005EEE@020000000605EEE@3oool0oooo0?ooo`1EEED0
oooo0P1EEED010000000EEEE05EEE@00000205EEE@050:ZZZP3oool0ZZZZ0:ZZZP1EEED01000000B
0?ooo`X0dLfY4P3oool2000000<0oooo00@0EEEE0?ooo`3oool0EEEE0P3oool00`1EEED0oooo0?oo
o`020?ooo`0505EEE@2ZZZX0EEEE0000002ZZZX01@3oool00`1EEED0oooo0?ooo`030?ooo`030000
003oool0oooo00<000004P3oool<0=7=Z@002`3AcJTD0?ooo`040:ZZZP3oool0oooo0?ooo`80ZZZZ
00D0EEEE0:ZZZP1EEED0ZZZZ000000020?ooo`0;0000001EEED0000005EEE@2ZZZX0000005EEE@00
0000oooo0:ZZZP0000000`2ZZZX0101EEED0ZZZZ0:ZZZP1EEED20?ooo`030000003oool0oooo0180
oooo2P3AcJTD0?ooo`80EEEE00<0ZZZZ0?ooo`3oool00`3oool01@000000ZZZZ0?ooo`000000EEEE
0080ZZZZ00@000000?ooo`1EEED000000P2ZZZX0101EEED000000?ooo`2ZZZX50?ooo`040000002Z
ZZX0EEEE000001@0oooo2P3AcJTD0?ooo`<0EEEE00L000000?ooo`000000ZZZZ05EEE@3oool0EEEE
00h0ZZZZ00L0EEEE0:ZZZP1EEED0EEEE0000003oool000000080EEEE00<000000?ooo`3oool04P3o
ool:0=7=ZA@0oooo00<0EEEE0?ooo`000000100000020?ooo`060:ZZZP000000ZZZZ0:ZZZP000000
oooo101EEED2000000040:ZZZP00000000000:ZZZP80oooo0`000000103oool000000?ooo`00000D
0?ooo`X0dLfY503oool2000000030:ZZZP1EEED0oooo0080EEEE0P2ZZZX0103oool0ZZZZ0?ooo`3o
ool205EEE@040000003oool0oooo00000080EEEE0P3oool01`2ZZZX0oooo0:ZZZP2ZZZX0oooo05EE
E@3oool00P2ZZZX2000001@0oooo303AcJT000/0dLfY503oool03`2ZZZX0EEEE0:ZZZP3oool00000
0?ooo`1EEED0000005EEE@2ZZZX0oooo0000002ZZZX0oooo05EEE@02000000050:ZZZP000000oooo
0?ooo`2ZZZX00P3oool00`2ZZZX0EEEE000000020?ooo`040000002ZZZX0ZZZZ05EEEAD0oooo2P3A
cJTD0?ooo`80ZZZZ00<0oooo000000000000100000000`3oool000000:ZZZP0300000080oooo00<0
EEEE0?ooo`3oool00P0000001P2ZZZX000000?ooo`1EEED0000005EEE@80000000<0EEEE0?ooo`2Z
ZZX05@3oool:0=7=ZA@0oooo0P2ZZZX40?ooo`80ZZZZ00<0000005EEE@2ZZZX03@2ZZZX0101EEED0
oooo0:ZZZP2ZZZX20?ooo`030:ZZZP3oool0ZZZZ01D0oooo2P3AcJTD0?ooo`030:ZZZP000000ZZZZ
00L0EEEE00@0000005EEE@3oool0ZZZZ0`3oool02@1EEED0oooo0?ooo`2ZZZX0oooo0:ZZZP000000
EEEE0:ZZZP0505EEE@030:ZZZP000000oooo01@0oooo2P3AcJTD0?ooo`060:ZZZP3oool000000?oo
o`1EEED000001@3oool00`1EEED0000000000002000000040?ooo`00000000000:ZZZP<000000P3o
ool01`000000oooo05EEE@000000EEEE0?ooo`0000005P3oool<0=7=Z@002`3AcJTE0?ooo`0?0000
001EEED000000000003oool000000:ZZZP1EEED0ZZZZ0?ooo`2ZZZX0EEEE0?ooo`1EEED0ZZZZ0080
000000P0ZZZZ05EEE@3oool0EEEE0000003oool0ZZZZ05EEE@80ZZZZ00D0oooo0000001EEED0EEEE
0000000E0?ooo`X0dLfY5@3oool01@000000oooo0:ZZZP000000ZZZZ0080oooo00H0ZZZZ0000003o
ool0ZZZZ0000002ZZZX205EEE@80oooo00T0EEEE0:ZZZP2ZZZX0000005EEE@3oool000000:ZZZP3o
ool00P2ZZZX010000000ZZZZ0?ooo`00000E0?ooo`X0dLfY5@3oool02@000000ZZZZ05EEE@1EEED0
ZZZZ0?ooo`2ZZZX0000005EEE@0>0:ZZZP0605EEE@000000ZZZZ05EEE@2ZZZX0EEEE0P2ZZZX00`00
0000oooo0?ooo`0C0?ooo`X0dLfY5@3oool2000000030?ooo`000000ZZZZ0080ZZZZ00P0EEEE0?oo
o`3oool0EEEE0:ZZZP1EEED0000005EEE@80oooo00<0EEEE0?ooo`1EEED00P2ZZZX30?ooo`050:ZZ
ZP3oool0ZZZZ0000002ZZZX00P00000E0?ooo`X0dLfY5@3oool2000000040?ooo`1EEED0oooo0?oo
o`80000000@0oooo000000000000ZZZZ0P3oool01`2ZZZX0oooo0?ooo`2ZZZX000000?ooo`2ZZZX0
0P0000001P3oool000000000001EEED0oooo05EEE@<000005@3oool<0=7=Z@002`3AcJTH0?ooo`09
0:ZZZP00000000000000002ZZZX000000?ooo`000000oooo00<0000000P0oooo000000000000ZZZZ
0000003oool0EEEE0?ooo`D0000000<0ZZZZ0000003oool05P3oool:0=7=ZAL0oooo0`1EEED20?oo
o`090:ZZZP000000ZZZZ0:ZZZP000000EEEE0:ZZZP3oool0ZZZZ0080oooo0P1EEED2000000050:ZZ
ZP000000oooo0?ooo`0000000P1EEED00`000000oooo0?ooo`0E0?ooo`X0dLfY5`3oool00`000000
ZZZZ0:ZZZP020:ZZZP0305EEE@2ZZZX0ZZZZ00h0ZZZZ00<0EEEE0:ZZZP3oool00P2ZZZX00`000000
oooo0?ooo`0E0?ooo`X0dLfY5`3oool00`1EEED000000:ZZZP0405EEE@040?ooo`00000000000:ZZ
ZPD0EEEE00D0oooo0:ZZZP00000000000?ooo`0305EEE@040000002ZZZX00000000001L0oooo2P3A
cJTG0?ooo`80000000<0ZZZZ0000000000000`3oool2000000H0oooo00<0ZZZZ0?ooo`000000103o
ool2000000030:ZZZP000000000001L0oooo303AcJT000/0dLfY5`3oool00`2ZZZX0000000000003
000000030:ZZZP1EEED0EEEE0080000000H0oooo0:ZZZP3oool0oooo0:ZZZP3oool2000000030:ZZ
ZP1EEED0ZZZZ00D00000603oool:0=7=ZAL0oooo0P2ZZZX20?ooo`040000003oool0EEEE00000080
ZZZZ00<000000:ZZZP1EEED00P2ZZZX00`1EEED00000000000020:ZZZP070000001EEED0ZZZZ0000
002ZZZX0oooo0:ZZZP0H0?ooo`X0dLfY5`3oool0102ZZZX0oooo05EEE@1EEED30:ZZZP0305EEE@2Z
ZZX0ZZZZ00X0ZZZZ00<0EEEE0:ZZZP3oool00P2ZZZX00`1EEED0oooo0?ooo`0G0?ooo`X0dLfY5`3o
ool02`2ZZZX0000005EEE@1EEED0oooo05EEE@3oool0EEEE0:ZZZP1EEED0000000<0oooo00L0EEEE
0?ooo`1EEED0000005EEE@000000EEEE00<0oooo0P1EEED00`000000oooo0?ooo`0F0?ooo`X0dLfY
5`3oool0202ZZZX0oooo0000002ZZZX0oooo05EEE@2ZZZX0EEEE0`0000060?ooo`<0000000<0EEEE
0:ZZZP0000000P3oool00`000000oooo0?ooo`0G0?ooo``0dLfY000;0=7=ZAP0oooo1P0000020:ZZ
ZP80oooo00<000000?ooo`3oool00P3oool00`2ZZZX0oooo0?ooo`020:ZZZP030000003oool00000
00<00000603oool:0=7=ZAP0oooo00/000000?ooo`1EEED0ZZZZ0?ooo`1EEED0oooo0000003oool0
00000?ooo`040:ZZZP0505EEE@000000oooo0000003oool00P1EEED20:ZZZP030?ooo`000000oooo
01L0oooo2P3AcJTH0?ooo`060000001EEED0oooo0:ZZZP1EEED0oooo3P2ZZZX01P3oool0EEEE0:ZZ
ZP2ZZZX0EEEE000001P0oooo2P3AcJTH0?ooo`D0000000L0EEEE0?ooo`2ZZZX0EEEE0:ZZZP3oool0
EEEE0080000000@0EEEE0000002ZZZX0EEEE0P3oool0101EEED000000000001EEED2000001P0oooo
2P3AcJTH0?ooo`8000000P3oool30:ZZZP030?ooo`2ZZZX0oooo00L0oooo00@0ZZZZ0?ooo`2ZZZX0
ZZZZ0P3oool3000001P0oooo303AcJT000/0dLfY6P3oool00`2ZZZX0oooo05EEE@0205EEE@080000
002ZZZX0EEEE05EEE@2ZZZX0EEEE0?ooo`2ZZZX205EEE@030:ZZZP1EEED0EEEE0080EEEE00<0oooo
0000003oool06@3oool:0=7=ZAX0oooo0`1EEED02@3oool000000:ZZZP000000EEEE0:ZZZP3oool0
EEEE000000020?ooo`0805EEE@000000oooo0000003oool0000005EEE@00000J0?ooo`X0dLfY6P3o
ool01P2ZZZX0oooo0?ooo`2ZZZX0oooo05EEE@X0ZZZZ00<000000?ooo`2ZZZX00P3oool00`000000
oooo0?ooo`0H0?ooo`X0dLfY6P3oool305EEE@050?ooo`000000EEEE0?ooo`2ZZZX00`3oool01@1E
EED0oooo0?ooo`2ZZZX0oooo0080000000@0oooo0:ZZZP1EEED000006P3oool:0=7=ZAX0oooo0P00
00002@2ZZZX0EEEE05EEE@3oool0EEEE0000001EEED0000005EEE@04000000@0EEEE00<0ZZZZ0000
000000006P3oool<0=7=Z@002`3AcJTJ0?ooo`050:ZZZP1EEED0EEEE05EEE@2ZZZX00P1EEED01@00
0000EEEE0?ooo`000000ZZZZ0080oooo00L0000005EEE@1EEED0ZZZZ05EEE@2ZZZX0EEEE01/0oooo
2P3AcJTJ0?ooo`80ZZZZ00<0oooo05EEE@1EEED00P2ZZZX200000080oooo00@0ZZZZ0?ooo`000000
00000P2ZZZX205EEE@030?ooo`2ZZZX0oooo01X0oooo2P3AcJTJ0?ooo`030:ZZZP1EEED000000080
oooo2`2ZZZX30?ooo`80EEEE6`3oool:0=7=ZAX0oooo00X0ZZZZ0000003oool0EEEE0000001EEED0
ZZZZ05EEE@000000EEEE0P3oool00`1EEED0oooo05EEE@020:ZZZP040000001EEED0oooo000001/0
oooo2P3AcJTJ0?ooo`050:ZZZP3oool0oooo0?ooo`1EEED00P3oool01P1EEED0oooo0?ooo`3oool0
ZZZZ0?ooo`80EEEE0P3oool00`1EEED0oooo0000000L0?ooo``0dLfY000;0=7=ZA/0oooo00T00000
05EEE@2ZZZX0EEEE0?ooo`1EEED000000?ooo`2ZZZX00P0000020:ZZZP070000001EEED0oooo05EE
E@2ZZZX0EEEE0000000K0?ooo`X0dLfY6`3oool040000000ZZZZ000000000000EEEE0?ooo`2ZZZX0
oooo0:ZZZP1EEED000000:ZZZP3oool0ZZZZ0?ooo`2ZZZX2000000030?ooo`000000oooo01X0oooo
2P3AcJTK0?ooo`8000000`1EEED;0:ZZZP80EEEE0P00000K0?ooo`X0dLfY6`3oool30000000305EE
E@3oool0ZZZZ0080EEEE100000001@2ZZZX0EEEE0:ZZZP2ZZZX0EEEE00<000006`3oool:0=7=ZA/0
oooo0P0000001`3oool0EEEE0000001EEED0oooo05EEE@0000000P3oool01`000000oooo0?ooo`1E
EED0oooo05EEE@3oool00P00000K0?ooo``0dLfY000;0=7=ZA`0oooo00<000000?ooo`2ZZZX00P1E
EED0102ZZZX0oooo0:ZZZP3oool20:ZZZP030?ooo`2ZZZX0EEEE0080ZZZZ7P3oool:0=7=ZA`0oooo
00X0000005EEE@1EEED0000005EEE@2ZZZX0oooo0:ZZZP1EEED000000`2ZZZX0101EEED0oooo05EE
E@1EEEDM0?ooo`X0dLfY703oool00`000000EEEE05EEE@0;0:ZZZP<0EEEE7@3oool:0=7=ZA`0oooo
00<0000005EEE@3oool00P3oool0302ZZZX0EEEE0?ooo`3oool0EEEE0?ooo`1EEED0ZZZZ0?ooo`2Z
ZZX0oooo05EEEAd0oooo2P3AcJTL0?ooo`D0000000@0EEEE0000001EEED000000P1EEED010000000
EEEE0000002ZZZX2000001d0oooo303AcJT000/0dLfY7@3oool03@2ZZZX000000:ZZZP2ZZZX0oooo
05EEE@3oool0EEEE0:ZZZP3oool0EEEE0?ooo`2ZZZX00P0000000`2ZZZX0oooo0?ooo`0K0?ooo`X0
dLfY7@3oool20:ZZZP040000001EEED0EEEE05EEE@80oooo00<0ZZZZ0?ooo`1EEED00P1EEED00`3o
ool0ZZZZ0:ZZZP0M0?ooo`X0dLfY7@3oool30:ZZZP0305EEE@3oool0ZZZZ00@0ZZZZ00@0EEEE0?oo
o`1EEED0oooo0P2ZZZXM0?ooo`X0dLfY7@3oool00`2ZZZX00000000000020:ZZZP0405EEE@2ZZZX0
ZZZZ05EEE@D0ZZZZ00<000000:ZZZP3oool0703oool:0=7=ZAd0oooo00@0ZZZZ0?ooo`3oool0ZZZZ
103oool0201EEED0oooo0:ZZZP3oool0ZZZZ0000003oool0ZZZZ7@3oool<0=7=Z@002`3AcJTQ0?oo
o`060000001EEED0oooo0000001EEED0oooo0P0000000`3oool0ZZZZ0?ooo`0N0?ooo`X0dLfY7`3o
ool010000000EEEE0000001EEED20:ZZZP060000002ZZZX0ZZZZ0000001EEED0ZZZZ7`3oool:0=7=
ZAl0oooo00<0EEEE0?ooo`3oool01P2ZZZX20?ooo`030:ZZZP3oool0oooo01d0oooo2P3AcJTP0?oo
o`80EEEE00@0oooo0:ZZZP1EEED0EEEE0P2ZZZX205EEE@030:ZZZP3oool0oooo01d0oooo2P3AcJTP
0?ooo`0;0000001EEED000000:ZZZP1EEED000000:ZZZP3oool0EEEE0000002ZZZX07`3oool<0=7=
Z@002`3AcJTO0?ooo`030000002ZZZX0oooo0080ZZZZ0P1EEED0102ZZZX0oooo0?ooo`2ZZZXP0?oo
o`X0dLfY7`3oool01@000000EEEE05EEE@3oool0ZZZZ0080EEEE0P2ZZZX205EEEB00oooo2P3AcJTO
0?ooo`800000202ZZZX00`000000oooo0?ooo`0N0?ooo`X0dLfY7`3oool00`000000EEEE00000002
0:ZZZP030?ooo`2ZZZX0ZZZZ0080000000<0EEEE0?ooo`3oool07P3oool:0=7=ZAl0oooo0`000000
1P2ZZZX0EEEE05EEE@3oool0EEEE0:ZZZP800000803oool<0=7=Z@002`3AcJTP0?ooo`050:ZZZP1E
EED0ZZZZ0:ZZZP0000000`2ZZZX00`1EEED0ZZZZ0?ooo`0O0?ooo`X0dLfY803oool20:ZZZP80EEEE
00@0000005EEE@1EEED0oooo0P2ZZZXP0?ooo`X0dLfY803oool00`2ZZZX0oooo0:ZZZP040:ZZZP03
05EEE@3oool0ZZZZ0200oooo2P3AcJTP0?ooo`0:0:ZZZP000000ZZZZ0?ooo`2ZZZX0EEEE0?ooo`1E
EED000000:ZZZR00oooo2P3AcJTP0?ooo`0:0:ZZZP3oool0oooo0?ooo`000000EEEE0?ooo`000000
oooo0:ZZZR00oooo303AcJT000/0dLfY8P3oool00`2ZZZX0oooo05EEE@020?ooo`030:ZZZP3oool0
oooo0200oooo2P3AcJTR0?ooo`060000001EEED0ZZZZ0:ZZZP1EEED0ZZZZ8P3oool:0=7=ZB80oooo
0P2ZZZX0101EEED0ZZZZ0:ZZZP2ZZZXR0?ooo`X0dLfY8`3oool50:ZZZR80oooo2P3AcJTS0?ooo`05
0000001EEED0EEEE0000002ZZZX08P3oool<0=7=Z@002`3AcJTR0?ooo`040000003oool000000:ZZ
ZR@0oooo2P3AcJTR0?ooo`030000001EEED0EEEE0080EEEE8`3oool:0=7=ZB80oooo00D000000:ZZ
ZP1EEED0oooo0:ZZZP0S0?ooo`X0dLfY8P3oool00`000000EEEE0000000205EEEB<0oooo2P3AcJTR
0?ooo`80000000<0ZZZZ0000000000008`3oool<0=7=Z@002`3AcJTS0?ooo`040:ZZZP0000000000
0:ZZZR<0oooo2P3AcJTS0?ooo`040:ZZZP3oool0ZZZZ0:ZZZR<0oooo2P3AcJTS0?ooo`040:ZZZP1E
EED0EEEE0:ZZZR<0oooo2P3AcJTS0?ooo`040:ZZZP3oool000000:ZZZR<0oooo2P3AcJTS0?ooo`04
0:ZZZP000000oooo0:ZZZR<0oooo303AcJT000/0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0
dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0
dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo``0
dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80
dLfY000;0=7=Z@80oooo0`1EEED20?ooo`0305EEE@3oool0000000<0EEEE00<0oooo0:ZZZP2ZZZX0
0P2ZZZX00`1EEED000000?ooo`020?ooo`80ZZZZ00@0EEEE0:ZZZP3oool0EEEE0P0000000`3oool0
EEEE0?ooo`0205EEE@030?ooo`2ZZZX0EEEE0080oooo00H0EEEE000000000000000005EEE@3oool2
05EEE@070:ZZZP1EEED0oooo0?ooo`1EEED0000005EEE@040:ZZZP80oooo0P1EEED00`000000oooo
05EEE@020?ooo`030:ZZZP1EEED0EEEE0080oooo2P3AcJT20?ooo`<0EEEE00H0oooo05EEE@000000
000005EEE@3oool205EEE@80ZZZZ00D0oooo05EEE@000000ZZZZ05EEE@020000000405EEE@2ZZZX0
ZZZZ05EEE@8000000P1EEED00`000000EEEE05EEE@0305EEE@040?ooo`1EEED0EEEE0?ooo`80EEEE
0P0000001@1EEED000000000003oool0EEEE0080ZZZZ00L0EEEE000000000000EEEE0:ZZZP000000
EEEE00<0ZZZZ0P1EEED01P3oool0EEEE000000000000EEEE0?ooo`<0EEEE0P3oool:0=7=Z@040?oo
o`1EEED0EEEE0?ooo`8000000P2ZZZX205EEE@060000002ZZZX0EEEE0:ZZZP1EEED0ZZZZ0P000000
0`2ZZZX0EEEE05EEE@030:ZZZP0305EEE@000000EEEE00@0ZZZZ101EEED0102ZZZX0oooo0000002Z
ZZX405EEE@80ZZZZ00H0EEEE0:ZZZP1EEED0000005EEE@3oool30:ZZZP0405EEE@2ZZZX0oooo0000
0080EEEE0`2ZZZX010000000EEEE05EEE@2ZZZX20000000305EEE@3oool0EEEE0080oooo2P3AcJT0
2P3oool00000000000000000oooo0000003oool0EEEE0?ooo`2ZZZX205EEE@050?ooo`1EEED00000
0?ooo`1EEED00`3oool01@2ZZZX0EEEE0?ooo`1EEED0oooo0080ZZZZ00L0oooo0:ZZZP3oool0oooo
05EEE@3oool0ZZZZ00H0oooo00<0ZZZZ0?ooo`3oool00P3oool02@2ZZZX0oooo0:ZZZP2ZZZX0oooo
05EEE@3oool0EEEE0:ZZZP030?ooo`80EEEE00<0000005EEE@3oool00P1EEED00`000000oooo05EE
E@02000000050:ZZZP00000000000000003oool02P3AcJT00`3oool0EEEE0:ZZZP040?ooo`80EEEE
00@0oooo0000002ZZZX0ZZZZ0P3oool01P1EEED0ZZZZ0000001EEED0oooo0:ZZZP80EEEE1@3oool4
0:ZZZP030000003oool0oooo0080000000H0oooo0000003oool0oooo0000003oool20:ZZZP80oooo
00@0ZZZZ0?ooo`3oool0oooo0P1EEED01P2ZZZX0oooo05EEE@1EEED0ZZZZ05EEE@<0oooo00<0ZZZZ
0000002ZZZX00P1EEED01`000000oooo0:ZZZP3oool0ZZZZ0000003oool0303AcJT000/0dLfY0`3o
ool205EEE@060?ooo`1EEED0oooo0?ooo`2ZZZX0oooo0P2ZZZX00`3oool0EEEE0?ooo`0205EEE@80
oooo0`2ZZZX01P000000EEEE0:ZZZP1EEED0oooo0:ZZZP<0oooo00@0EEEE0?ooo`1EEED0EEEE0P2Z
ZZX01@1EEED0ZZZZ0?ooo`1EEED0ZZZZ0080oooo00D0ZZZZ0?ooo`1EEED0ZZZZ05EEE@040:ZZZP80
oooo101EEED00`3oool0ZZZZ0:ZZZP040?ooo`040:ZZZP3oool0oooo05EEE@<0oooo2P3AcJT30?oo
o`0405EEE@3oool0EEEE0:ZZZP80oooo00<0ZZZZ0?ooo`1EEED00P1EEED0202ZZZX0EEEE0000003o
ool0000005EEE@2ZZZX0EEEE1000000305EEE@<0oooo0P2ZZZX205EEE@80oooo00<0EEEE0?ooo`2Z
ZZX00P2ZZZX20?ooo`<0EEEE100000000`1EEED0000005EEE@030000000705EEE@2ZZZX0EEEE0?oo
o`1EEED0oooo0:ZZZP020?ooo`040:ZZZP1EEED0EEEE05EEE@<0oooo2P3AcJT20?ooo`0805EEE@3o
ool0ZZZZ05EEE@2ZZZX000000:ZZZP1EEED30:ZZZP<0EEEE0P2ZZZX205EEE@040:ZZZP000000ZZZZ
0:ZZZP80000000@0ZZZZ05EEE@1EEED0ZZZZ1P1EEED20:ZZZPH0EEEE00<0ZZZZ05EEE@1EEED00`00
00020:ZZZP040000001EEED0EEEE05EEE@80ZZZZ0`1EEED02`000000ZZZZ0:ZZZP000000ZZZZ0000
002ZZZX0EEEE0:ZZZP3oool0EEEE0080oooo2P3AcJT0103oool0ZZZZ0?ooo`3oool305EEE@80oooo
00@0ZZZZ05EEE@000000oooo0P00000205EEE@050:ZZZP1EEED0EEEE0?ooo`1EEED01P3oool01@00
0000oooo05EEE@2ZZZX0000000P0oooo00<0000005EEE@1EEED00`3oool01`000000oooo0?ooo`1E
EED0oooo05EEE@2ZZZX0101EEED01P2ZZZX000000000002ZZZX0000005EEE@<0oooo00<0000005EE
E@2ZZZX0103oool:0=7=Z@040?ooo`2ZZZX0ZZZZ00000080EEEE00<0ZZZZ0?ooo`2ZZZX00P000002
0?ooo`040000002ZZZX0ZZZZ0:ZZZP80oooo00D0EEEE0:ZZZP3oool0ZZZZ05EEE@020:ZZZP0605EE
E@000000EEEE0:ZZZP1EEED0oooo1000000205EEE@040000002ZZZX0000000000080EEEE00@0ZZZZ
05EEE@000000EEEE102ZZZX0103oool0EEEE05EEE@3oool20:ZZZP030?ooo`2ZZZX000000080oooo
00T000000:ZZZP2ZZZX0oooo0000001EEED0oooo0000002ZZZX00P3oool<0=7=Z@002`3AcJT40?oo
o`80EEEE00<0oooo0:ZZZP1EEED00P3oool205EEE@80ZZZZ00D0EEEE0:ZZZP2ZZZX0EEEE0:ZZZP02
05EEE@040000001EEED0ZZZZ05EEE@80ZZZZ00<0EEEE0?ooo`1EEED00`3oool01P1EEED000000000
002ZZZX000000:ZZZP80oooo0P1EEED02@3oool0EEEE0:ZZZP2ZZZX0EEEE0:ZZZP1EEED0000005EE
E@020:ZZZP0305EEE@2ZZZX0ZZZZ00<0ZZZZ0P1EEED00`3oool0000005EEE@020:ZZZP0305EEE@3o
ool0oooo00<0oooo2P3AcJT40?ooo`D0EEEE00<000000:ZZZP2ZZZX00P3oool01P1EEED0000005EE
E@000000oooo0:ZZZP80oooo00P0EEEE0?ooo`1EEED0EEEE0?ooo`000000ZZZZ05EEE@80oooo00@0
00000:ZZZP1EEED0oooo0P1EEED02P3oool0ZZZZ0:ZZZP000000ZZZZ0?ooo`1EEED0oooo0000003o
ool405EEE@80oooo00P0ZZZZ0?ooo`1EEED0EEEE0?ooo`1EEED0oooo000000<0ZZZZ101EEED50?oo
o`X0dLfY103oool3000000050?ooo`000000ZZZZ05EEE@2ZZZX01@1EEED00`2ZZZX0000005EEE@02
05EEE@80ZZZZ0P1EEED00`2ZZZX0EEEE0:ZZZP020000000305EEE@000000EEEE00<0000000H0ZZZZ
0000002ZZZX0EEEE0000002ZZZX2000000030:ZZZP1EEED0EEEE00<0EEEE00D0ZZZZ05EEE@1EEED0
EEEE0000000605EEE@080:ZZZP1EEED0EEEE0000003oool0EEEE0000001EEED40?ooo`X0dLfY0`3o
ool20:ZZZP060000002ZZZX0EEEE0?ooo`1EEED0ZZZZ0P1EEED40?ooo`060:ZZZP3oool0oooo0:ZZ
ZP000000EEEE0P3oool01@2ZZZX0EEEE0?ooo`1EEED0oooo0080ZZZZ0P1EEED01P2ZZZX0EEEE05EE
E@2ZZZX0EEEE0:ZZZP80EEEE00L0oooo0:ZZZP3oool000000?ooo`1EEED0ZZZZ0080oooo00<0EEEE
0000003oool0103oool01P2ZZZX0oooo0?ooo`3oool0EEEE0:ZZZP80oooo00D0EEEE0?ooo`000000
EEEE0:ZZZP030?ooo`X0dLfY0`3oool01@2ZZZX000000:ZZZP2ZZZX0oooo0080ZZZZ0P3oool00`1E
EED000000:ZZZP020:ZZZP<0000000@0oooo0:ZZZP3oool000000P2ZZZX010000000oooo0?ooo`00
00020?ooo`8000001@1EEED300000080oooo00<000000?ooo`3oool0102ZZZX00`3oool0ZZZZ0:ZZ
ZP03000000050:ZZZP3oool0ZZZZ0000002ZZZX00P3oool20:ZZZP030?ooo`000000ZZZZ0080ZZZZ
0`3oool<0=7=Z@002`3AcJT50?ooo`80EEEE0P2ZZZX30?ooo`090000003oool0000005EEE@3oool0
EEEE0?ooo`000000EEEE0080oooo00<0ZZZZ0?ooo`0000000P2ZZZX00`1EEED0ZZZZ0?ooo`030:ZZ
ZP80EEEE00<0ZZZZ0000001EEED0102ZZZX0203oool0ZZZZ05EEE@2ZZZX0EEEE0000003oool0ZZZZ
0P3oool2000000030?ooo`1EEED0oooo0080000000<0oooo05EEE@3oool00P3oool20:ZZZP030?oo
o`1EEED0oooo00@0oooo2P3AcJT50?ooo`0405EEE@3oool0EEEE05EEE@<000000`3oool0102ZZZX0
00000:ZZZP3oool305EEE@030000001EEED0EEEE0080oooo00L000000:ZZZP2ZZZX0EEEE0000003o
ool000000080oooo00D0EEEE0?ooo`3oool0EEEE000000020?ooo`0405EEE@2ZZZX0000000000080
oooo00H0EEEE000000000000EEEE0000001EEED20?ooo`040000001EEED0oooo0?ooo`<0000000<0
oooo05EEE@1EEED00P1EEED50?ooo`X0dLfY103oool205EEE@050?ooo`2ZZZX0EEEE0000002ZZZX0
0P1EEED010000000EEEE0:ZZZP0000020:ZZZP0305EEE@000000EEEE0080000000L0EEEE0000001E
EED0EEEE0:ZZZP1EEED0ZZZZ00<0000000H0ZZZZ05EEE@1EEED0ZZZZ05EEE@2ZZZX200000080ZZZZ
0`1EEED02@2ZZZX0000005EEE@3oool0000005EEE@000000EEEE0:ZZZP030000000405EEE@000000
EEEE05EEE@80ZZZZ00@0EEEE0:ZZZP3oool0EEEE1@3oool:0=7=Z@@0oooo0P0000020:ZZZP030?oo
o`2ZZZX0EEEE0080oooo0P1EEED00`2ZZZX0000005EEE@030:ZZZP80oooo00L0EEEE0:ZZZP1EEED0
oooo05EEE@000000oooo0080ZZZZ00H0oooo0:ZZZP2ZZZX0ZZZZ05EEE@3oool30:ZZZP0:0?ooo`1E
EED0ZZZZ0?ooo`000000EEEE0?ooo`1EEED0ZZZZ05EEE@80oooo00H0EEEE0:ZZZP2ZZZX0oooo0000
003oool205EEE@80oooo00<0EEEE0000003oool00P2ZZZX2000000@0oooo2P3AcJT40?ooo`0405EE
E@2ZZZX0oooo000000<0ZZZZ00H0EEEE0?ooo`2ZZZX0oooo05EEE@2ZZZX200000080EEEE00D0ZZZZ
0?ooo`3oool000000?ooo`02000000030?ooo`00000000000080000000<0oooo0000000000001000
00000`3oool000000:ZZZP02000000040:ZZZP000000EEEE0?ooo`80000000T0oooo0:ZZZP2ZZZX0
EEEE0000001EEED0ZZZZ05EEE@3oool00P2ZZZX0201EEED0ZZZZ0:ZZZP2ZZZX000000?ooo`2ZZZX0
0000103oool<0=7=Z@002`3AcJT60?ooo`80EEEE00<0ZZZZ05EEE@2ZZZX00P2ZZZX01@3oool0EEEE
0:ZZZP2ZZZX0EEEE00<0ZZZZ00D0EEEE0:ZZZP1EEED0EEEE0?ooo`0305EEE@050:ZZZP1EEED0oooo
0?ooo`2ZZZX00P1EEED020000000EEEE05EEE@3oool0ZZZZ0?ooo`2ZZZX0EEEE0P2ZZZX0101EEED0
ZZZZ0?ooo`1EEED20:ZZZP0505EEE@2ZZZX0ZZZZ0:ZZZP1EEED00P2ZZZX00`1EEED0oooo05EEE@04
0:ZZZP0305EEE@3oool0oooo00D0oooo2P3AcJT60?ooo`<0EEEE00<0oooo05EEE@1EEED00`1EEED0
1@3oool000000?ooo`1EEED000000080oooo00@0EEEE0?ooo`3oool0oooo0P0000000`1EEED00000
0:ZZZP020:ZZZP0>05EEE@3oool0oooo0000001EEED0oooo0000001EEED0ZZZZ05EEE@2ZZZX00000
0:ZZZP0000030?ooo`80EEEE0P3oool01@000000EEEE000000000000oooo0080EEEE00<0oooo05EE
E@1EEED00`1EEED70?ooo`X0dLfY1P3oool01P2ZZZX0EEEE0000001EEED0ZZZZ05EEE@80ZZZZ0P1E
EED30:ZZZP80EEEE00@0ZZZZ05EEE@1EEED0ZZZZ1@1EEED01@2ZZZX000000:ZZZP000000ZZZZ00@0
EEEE00<0ZZZZ0000002ZZZX00P2ZZZX505EEE@040:ZZZP3oool0EEEE0:ZZZP80EEEE00<0ZZZZ0000
002ZZZX00P1EEED20:ZZZP0405EEE@2ZZZX0EEEE00000080EEEE1P3oool:0=7=Z@D0oooo00<00000
0?ooo`3oool00P3oool200000080oooo00<0EEEE0?ooo`3oool00P1EEED00`000000EEEE0:ZZZP02
05EEE@040000003oool00000000000<0EEEE00<0oooo05EEE@2ZZZX00P3oool205EEE@050?ooo`00
0000ZZZZ05EEE@2ZZZX00P1EEED200000080oooo00P000000:ZZZP1EEED0ZZZZ05EEE@000000EEEE
00000080oooo00<0EEEE0?ooo`1EEED00P0000030?ooo`030:ZZZP000000oooo00@0oooo2P3AcJT5
0?ooo`030000002ZZZX0ZZZZ0080000000<0oooo0:ZZZP1EEED00P1EEED20:ZZZP8000000P2ZZZX4
00000080oooo0P0000001`1EEED0oooo0:ZZZP000000EEEE0?ooo`2ZZZX00P3oool20:ZZZP0705EE
E@000000oooo0?ooo`1EEED0ZZZZ000000020?ooo`@000000P2ZZZX010000000ZZZZ0:ZZZP2ZZZX2
05EEE@80ZZZZ00H0oooo000000000000ZZZZ05EEE@0000050?ooo``0dLfY000;0=7=Z@L0oooo00<0
EEEE0?ooo`1EEED00P2ZZZX0101EEED0oooo0:ZZZP1EEED30:ZZZP0405EEE@2ZZZX0EEEE05EEE@80
oooo00<0EEEE0000002ZZZX00`1EEED30:ZZZP80oooo00@0000005EEE@3oool0EEEE0`2ZZZX205EE
E@<0ZZZZ00<0EEEE0?ooo`1EEED00P1EEED0102ZZZX0EEEE0:ZZZP0000030:ZZZP070?ooo`1EEED0
ZZZZ0:ZZZP1EEED0oooo05EEE@070?ooo`X0dLfY1`3oool305EEE@80ZZZZ0P1EEED40?ooo`80EEEE
00<0000005EEE@1EEED00`3oool2000000<0EEEE00`0ZZZZ0000002ZZZX0oooo0000002ZZZX0oooo
0000003oool0ZZZZ0000002ZZZX205EEE@030?ooo`000000oooo00<0oooo1@1EEED01P2ZZZX0oooo
0?ooo`3oool0EEEE0?ooo`80ZZZZ00<0oooo05EEE@1EEED01`3oool:0=7=Z@H0oooo00@0EEEE0000
00000000ZZZZ0P1EEED00`2ZZZX0EEEE05EEE@0205EEE@050:ZZZP000000ZZZZ05EEE@0000000P3o
ool010000000EEEE0:ZZZP00000405EEE@030:ZZZP1EEED0EEEE00@0EEEE00@0ZZZZ05EEE@2ZZZX0
ZZZZ0`1EEED20000000405EEE@00000000000?ooo`80000000<0ZZZZ0000002ZZZX01`1EEED30000
00L0oooo2P3AcJT60?ooo`0605EEE@2ZZZX0ZZZZ0?ooo`2ZZZX0oooo0P1EEED30?ooo`80ZZZZ00<0
oooo05EEE@3oool00P2ZZZX30?ooo`070:ZZZP3oool0EEEE0?ooo`000000EEEE0:ZZZP020?ooo`06
05EEE@3oool0oooo0?ooo`2ZZZX0EEEE0P3oool00`1EEED0oooo0:ZZZP030?ooo`80ZZZZ0`3oool0
0`2ZZZX0oooo0?ooo`020?ooo`0505EEE@3oool0oooo0:ZZZP0000000`2ZZZX60?ooo`X0dLfY1P3o
ool00`2ZZZX000000:ZZZP0200000080ZZZZ00<0oooo0:ZZZP2ZZZX00P2ZZZX00`1EEED000000?oo
o`04000000040?ooo`00000000000?ooo`<0ZZZZ0P3oool20:ZZZP0405EEE@2ZZZX0ZZZZ05EEE@80
oooo00T0EEEE0:ZZZP2ZZZX0oooo0000002ZZZX0oooo0000001EEED00P000000103oool0000005EE
E@0000030:ZZZP080?ooo`2ZZZX0ZZZZ0000001EEED0ZZZZ0000002ZZZX60?ooo``0dLfY000;0=7=
Z@P0oooo0`1EEED30?ooo`030000001EEED0EEEE0080000000H0oooo05EEE@3oool000000?ooo`2Z
ZZX205EEE@040000001EEED0oooo0?ooo`<0EEEE00D0ZZZZ0?ooo`000000EEEE0?ooo`0405EEE@80
oooo0P00000205EEE@070:ZZZP1EEED000000?ooo`1EEED0oooo0000000205EEE@080:ZZZP000000
oooo05EEE@3oool0EEEE0:ZZZP1EEED80?ooo`X0dLfY203oool01`1EEED00000000000000000ZZZZ
0?ooo`0000000P3oool205EEE@030?ooo`1EEED0EEEE00@0oooo0P0000001`3oool0EEEE0?ooo`00
0000oooo0000001EEED00P0000002P2ZZZX0000005EEE@000000oooo05EEE@3oool0EEEE0?ooo`00
00050?ooo`80EEEE00<0oooo05EEE@0000000P3oool00`000000oooo0000000200000080EEEE203o
ool:0=7=Z@L0oooo0`1EEED2000000D0EEEE00X0ZZZZ05EEE@2ZZZX0ZZZZ0000003oool0ZZZZ05EE
E@2ZZZX0oooo101EEED00`2ZZZX000000:ZZZP0605EEE@030:ZZZP000000EEEE00@0EEEE00<00000
0:ZZZP1EEED00P3oool00`000000EEEE0:ZZZP0605EEE@040:ZZZP00000000000?ooo`80EEEE1`3o
ool:0=7=Z@H0oooo0`0000000`2ZZZX0oooo05EEE@020?ooo`0;05EEE@2ZZZX0EEEE0:ZZZP3oool0
EEEE0:ZZZP000000oooo0000003oool00P2ZZZX00`3oool0EEEE0?ooo`020?ooo`80ZZZZ0`1EEED0
0`3oool0EEEE0:ZZZP020:ZZZP<0oooo00@0EEEE0?ooo`000000ZZZZ0`3oool010000000EEEE05EE
E@3oool405EEE@040?ooo`1EEED0EEEE0?ooo`<000001`3oool:0=7=Z@H0oooo00@0000005EEE@2Z
ZZX0ZZZZ0`3oool205EEE@040?ooo`1EEED0ZZZZ0:ZZZP<0oooo0P2ZZZX20?ooo`80000000@0ZZZZ
0000002ZZZX0oooo0P1EEED01P3oool0000005EEE@3oool000000?ooo`80EEEE0P2ZZZX00`000000
oooo000000040?ooo`080:ZZZP3oool0oooo0?ooo`2ZZZX0000005EEE@2ZZZX205EEE@060000003o
ool0oooo0?ooo`2ZZZX0EEEE1`3oool<0=7=Z@002`3AcJT90?ooo`0605EEE@3oool0EEEE0:ZZZP1E
EED0oooo0P0000002`2ZZZX0oooo05EEE@2ZZZX0EEEE0:ZZZP1EEED000000:ZZZP1EEED0ZZZZ00@0
EEEE0P0000001@2ZZZX0oooo0000001EEED0oooo00<000000`1EEED01`3oool0ZZZZ0000002ZZZX0
00000?ooo`2ZZZX00`1EEED0203oool0EEEE0000002ZZZX0oooo05EEE@3oool0EEEE2`3oool:0=7=
Z@T0oooo0P1EEED02@3oool0EEEE0?ooo`000000oooo0:ZZZP3oool0000005EEE@070?ooo`040000
001EEED0oooo00000080oooo00<0ZZZZ0000002ZZZX00P3oool30:ZZZP060?ooo`1EEED000000?oo
o`1EEED000000`3oool00`000000oooo0?ooo`0205EEE@090000001EEED0ZZZZ0?ooo`000000oooo
05EEE@3oool0EEEE00X0oooo2P3AcJT90?ooo`080:ZZZP1EEED0EEEE0:ZZZP000000oooo05EEE@2Z
ZZX2000000030:ZZZP1EEED0oooo0080000000<0EEEE0:ZZZP2ZZZX00P0000030:ZZZP/0EEEE0P2Z
ZZX200000080ZZZZ00L0EEEE0?ooo`000000oooo05EEE@2ZZZX0000000<0ZZZZ00<0oooo0000001E
EED00`1EEED90?ooo`X0dLfY203oool01P000000oooo05EEE@3oool0EEEE0?ooo`@0EEEE00D0oooo
05EEE@1EEED0oooo0:ZZZP02000000040:ZZZP1EEED0oooo05EEE@80oooo00H0EEEE0?ooo`1EEED0
00000:ZZZP3oool30:ZZZP0305EEE@3oool0oooo00@0oooo0P2ZZZX2000000090:ZZZP3oool0EEEE
05EEE@3oool0000005EEE@3oool0EEEE00<0oooo00<0EEEE0:ZZZP000000203oool:0=7=Z@P0oooo
00<000000:ZZZP2ZZZX00P3oool305EEE@030000003oool0ZZZZ0080ZZZZ00@0oooo05EEE@2ZZZX0
oooo0P0000020?ooo`80ZZZZ00<0oooo0:ZZZP0000000P0000020?ooo`<00000102ZZZX20?ooo`06
0:ZZZP000000oooo0000001EEED0oooo0`2ZZZX2000000080:ZZZP1EEED0EEEE0:ZZZP3oool0ZZZZ
05EEE@0000080?ooo``0dLfY000;0=7=Z@X0oooo00D0EEEE0:ZZZP3oool0EEEE0?ooo`0200000003
0:ZZZP1EEED0oooo0080EEEE0P2ZZZX20000000=05EEE@2ZZZX0ZZZZ0000002ZZZX000000:ZZZP00
0000ZZZZ0?ooo`000000EEEE0?ooo`02000000<0ZZZZ00@000000:ZZZP2ZZZX0EEEE0P0000020:ZZ
ZP0805EEE@3oool0oooo05EEE@2ZZZX000000:ZZZP3oool205EEE@030:ZZZP1EEED0oooo00T0oooo
2P3AcJT:0?ooo`80EEEE00D0000005EEE@1EEED0000005EEE@020?ooo`040:ZZZP3oool0EEEE0:ZZ
ZP@0oooo00@0000005EEE@000000EEEE102ZZZX01@1EEED0000005EEE@1EEED0000000<0ZZZZ00@0
EEEE0000000000000000103oool0102ZZZX0EEEE0:ZZZP2ZZZX20?ooo`@0EEEE00<0000005EEE@1E
EED02P3oool:0=7=Z@T0oooo00H0EEEE00000000000000000?ooo`2ZZZX305EEE@80ZZZZ00@0EEEE
0:ZZZP3oool0oooo1P2ZZZX00`000000EEEE05EEE@0905EEE@060:ZZZP000000ZZZZ05EEE@2ZZZX0
00000P2ZZZX010000000oooo0:ZZZP0000030:ZZZP80EEEE00<0ZZZZ0?ooo`1EEED00P00000:0?oo
o`X0dLfY2@3oool00`1EEED0ZZZZ000000020:ZZZP0405EEE@3oool000000:ZZZP@0EEEE0`3oool0
3@2ZZZX0oooo0?ooo`3oool0EEEE0000001EEED0oooo05EEE@2ZZZX0oooo0:ZZZP1EEED00P3oool0
1@1EEED0oooo0?ooo`000000EEEE0080oooo00D0EEEE0:ZZZP3oool0ZZZZ0?ooo`0405EEE@<00000
00@0EEEE0:ZZZP3oool000000P2ZZZX90?ooo`X0dLfY2@3oool01@2ZZZX000000:ZZZP2ZZZX0oooo
0080ZZZZ00H0oooo0:ZZZP000000ZZZZ0000002ZZZX20?ooo`80EEEE00@0ZZZZ0000002ZZZX00000
0P2ZZZX405EEE@030000001EEED0EEEE00<0EEEE0P2ZZZX3000000<0EEEE00<0ZZZZ0?ooo`2ZZZX0
0P2ZZZX00`000000oooo0?ooo`020:ZZZP050?ooo`000000ZZZZ0000002ZZZX02@3oool<0=7=Z@00
2`3AcJT=0?ooo`0505EEE@2ZZZX0oooo0?ooo`0000000`3oool00`000000EEEE0000000205EEE@0=
0000002ZZZX0EEEE05EEE@000000EEEE0:ZZZP1EEED000000?ooo`1EEED0ZZZZ0?ooo`0205EEE@03
0:ZZZP1EEED000000080EEEE00<0ZZZZ05EEE@1EEED00`1EEED01P000000oooo0?ooo`3oool0EEEE
0?ooo`80ZZZZ0P1EEED<0?ooo`X0dLfY303oool0101EEED0oooo05EEE@2ZZZX20?ooo`0505EEE@3o
ool0oooo0:ZZZP0000000`3oool20000000705EEE@00000000000000003oool0EEEE0:ZZZP020?oo
o`0505EEE@3oool0000005EEE@3oool00`0000000`2ZZZX000000?ooo`020?ooo`8000000P2ZZZX0
203oool0EEEE0000003oool0ZZZZ05EEE@3oool0EEEE303oool:0=7=Z@/0oooo00<0EEEE0:ZZZP1E
EED0101EEED30:ZZZP030000003oool000000080EEEE00@0ZZZZ05EEE@1EEED0ZZZZ3P1EEED20:ZZ
ZP@0EEEE0P3oool200000080ZZZZ1@1EEED00`3oool0EEEE0?ooo`0:0?ooo`X0dLfY2P3oool00`2Z
ZZX0oooo000000020?ooo`80ZZZZ00<0oooo05EEE@3oool00P1EEED0303oool0000005EEE@2ZZZX0
oooo0:ZZZP3oool0EEEE0:ZZZP000000oooo00000080oooo00<0ZZZZ0?ooo`3oool00P000000103o
ool0ZZZZ0:ZZZP1EEED20:ZZZP0505EEE@2ZZZX0EEEE05EEE@3oool00P1EEED01@3oool0EEEE05EE
E@2ZZZX0000000@0oooo00<0ZZZZ0?ooo`3oool0203oool:0=7=Z@X0oooo0P2ZZZX0103oool0ZZZZ
0?ooo`0000020?ooo`050:ZZZP000000oooo0:ZZZP3oool00P2ZZZX01@000000oooo000000000000
oooo0080ZZZZ00@000000:ZZZP1EEED0EEEE0P2ZZZX01`1EEED0ZZZZ0:ZZZP000000oooo0:ZZZP3o
ool00P0000001P3oool000000:ZZZP2ZZZX0oooo0:ZZZP80000000L0ZZZZ05EEE@3oool0EEEE0?oo
o`2ZZZX000000080ZZZZ2P3oool<0=7=Z@002`3AcJT<0?ooo`0305EEE@2ZZZX0EEEE0080ZZZZ1@3o
ool01@2ZZZX0oooo0?ooo`1EEED0oooo00<0ZZZZ00D0oooo05EEE@3oool0EEEE0?ooo`020:ZZZP04
05EEE@2ZZZX0oooo05EEE@<0oooo00H0ZZZZ0000002ZZZX0oooo05EEE@3oool20:ZZZP@0oooo0`2Z
ZZX00`1EEED0ZZZZ0?ooo`0<0?ooo`X0dLfY303oool205EEE@<0000000H0EEEE0?ooo`1EEED0EEEE
0?ooo`0000030?ooo`8000001@1EEED00`000000oooo05EEE@020:ZZZP0305EEE@000000000000@0
EEEE00<0oooo0000003oool00P3oool2000000050?ooo`2ZZZX0EEEE0?ooo`2ZZZX00`0000000`1E
EED0oooo0?ooo`0;0?ooo`X0dLfY303oool00`2ZZZX0EEEE0000000405EEE@80ZZZZ00H0EEEE0:ZZ
ZP1EEED0EEEE0000001EEED20:ZZZQ00EEEE00L000000:ZZZP1EEED0000005EEE@3oool0ZZZZ0080
EEEE00<0ZZZZ05EEE@1EEED00P1EEED00`000000EEEE05EEE@0<0?ooo`X0dLfY2`3oool01P000000
oooo0?ooo`3oool0ZZZZ05EEE@80oooo101EEED01@3oool0ZZZZ0:ZZZP3oool000000080oooo00<0
EEEE0?ooo`3oool00P3oool01@000000ZZZZ0:ZZZP000000ZZZZ0080oooo00D0ZZZZ05EEE@3oool0
oooo000000030:ZZZP030?ooo`1EEED0EEEE0080EEEE0P3oool01P1EEED0oooo0?ooo`3oool0ZZZZ
000000/0oooo2P3AcJT;0?ooo`030000002ZZZX0ZZZZ0080000000<0oooo0:ZZZP1EEED00P1EEED0
203oool0ZZZZ0:ZZZP2ZZZX0000005EEE@000000EEEE0P2ZZZX305EEE@030?ooo`2ZZZX0ZZZZ00<0
ZZZZ0P1EEED30:ZZZP80000000H0EEEE0000002ZZZX000000:ZZZP3oool305EEE@070:ZZZP3oool0
00000000002ZZZX0EEEE0000000;0?ooo``0dLfY000;0=7=Z@d0oooo0P1EEED00`2ZZZX0EEEE0:ZZ
ZP060:ZZZP030?ooo`1EEED0ZZZZ0080EEEE0`2ZZZX00`3oool0EEEE0:ZZZP0205EEE@050:ZZZP1E
EED0oooo05EEE@3oool00`2ZZZX01P000000EEEE0?ooo`1EEED0oooo05EEE@H0ZZZZ00@0EEEE0:ZZ
ZP1EEED0EEEE3@3oool:0=7=Z@d0oooo101EEED30:ZZZP0305EEE@3oool0ZZZZ00@0oooo00D0ZZZZ
05EEE@3oool0EEEE0?ooo`0305EEE@@000001@1EEED20?ooo`030:ZZZP3oool0oooo0080oooo00<0
ZZZZ0?ooo`1EEED00P2ZZZX505EEE@d0oooo2P3AcJT<0?ooo`0405EEE@00000000000:ZZZP80EEEE
00<0ZZZZ0000001EEED00P1EEED01@3oool0ZZZZ0:ZZZP000000ZZZZ0140EEEE0P2ZZZX0101EEED0
ZZZZ0:ZZZP2ZZZX205EEE@050:ZZZP000000ZZZZ0000001EEED00`00000=0?ooo`X0dLfY303oool0
0`1EEED0ZZZZ0:ZZZP020?ooo`0505EEE@3oool0EEEE0?ooo`1EEED00`3oool01@000000oooo0?oo
o`000000oooo0080ZZZZ00<000000:ZZZP1EEED0100000000`3oool0ZZZZ000000020:ZZZP050?oo
o`2ZZZX0oooo0?ooo`0000000`3oool01`1EEED0oooo05EEE@3oool0EEEE0?ooo`0000000`2ZZZX<
0?ooo`X0dLfY303oool00`2ZZZX000000:ZZZP0200000080ZZZZ00<0oooo0:ZZZP3oool00P000002
0?ooo`030:ZZZP3oool0ZZZZ00<0ZZZZ00D0oooo0:ZZZP2ZZZX0EEEE0:ZZZP0205EEE@80ZZZZ00@0
oooo0:ZZZP2ZZZX0ZZZZ0P3oool0202ZZZX0oooo0?ooo`1EEED000000?ooo`2ZZZX0oooo0P2ZZZX0
1@000000EEEE0:ZZZP000000ZZZZ00`0oooo303AcJT000/0dLfY3`3oool01P2ZZZX0EEEE0?ooo`1E
EED0oooo05EEE@80ZZZZ00L0EEEE0:ZZZP3oool0000005EEE@3oool0ZZZZ0080EEEE01<0oooo05EE
E@2ZZZX0oooo05EEE@000000oooo0:ZZZP1EEED0oooo0000001EEED0ZZZZ0?ooo`1EEED000000?oo
o`2ZZZX0EEEE0080ZZZZ00<0EEEE0?ooo`1EEED00`1EEED?0?ooo`X0dLfY3`3oool00`1EEED00000
05EEE@0205EEE@80ZZZZ1P1EEED20?ooo`070000003oool0ZZZZ0:ZZZP3oool0EEEE0?ooo`0305EE
E@80ZZZZ00<0EEEE0000003oool00P1EEED01`000000EEEE05EEE@000000EEEE0:ZZZP3oool00P1E
EED20000000305EEE@3oool0oooo00d0oooo2P3AcJT>0?ooo`0305EEE@2ZZZX0ZZZZ0080ZZZZ0P00
00000`1EEED0ZZZZ000000020:ZZZP80EEEE00<0000005EEE@1EEED03P1EEED00`2ZZZX0EEEE05EE
E@040:ZZZP0805EEE@2ZZZX000000:ZZZP1EEED0ZZZZ0?ooo`1EEED>0?ooo`X0dLfY3@3oool01P2Z
ZZX0oooo0:ZZZP1EEED0000005EEE@80oooo00<0ZZZZ05EEE@2ZZZX00`3oool20:ZZZP030000002Z
ZZX0oooo0080oooo0P00000205EEE@8000000`3oool01@2ZZZX000000:ZZZP2ZZZX0EEEE0080oooo
00<0000005EEE@2ZZZX00P3oool305EEE@80oooo00<0ZZZZ0?ooo`3oool02`3oool:0=7=Z@d0oooo
0P2ZZZX01P3oool0EEEE0000002ZZZX0oooo0:ZZZPD000000P2ZZZX02@1EEED000000?ooo`000000
EEEE0:ZZZP3oool0EEEE0:ZZZP0205EEE@80ZZZZ00H0EEEE0?ooo`3oool000000?ooo`2ZZZX30000
000605EEE@00000000000:ZZZP3oool0ZZZZ0P1EEED00`000000ZZZZ0:ZZZP0=0?ooo``0dLfY000;
0=7=Z@l0oooo0`1EEED20?ooo`0705EEE@3oool0EEEE0:ZZZP1EEED0ZZZZ0?ooo`030:ZZZP0505EE
E@000000oooo0?ooo`1EEED00P3oool00`2ZZZX0oooo05EEE@020?ooo`80EEEE0`2ZZZX00`3oool0
ZZZZ05EEE@0205EEE@@0oooo00<0ZZZZ05EEE@3oool03`3oool:0=7=Z@l0oooo0`1EEED0103oool0
EEEE0000003oool205EEE@070?ooo`1EEED0EEEE0?ooo`1EEED0000005EEE@020:ZZZP030000003o
ool0EEEE0080oooo00<0EEEE0:ZZZP0000000P2ZZZX0101EEED0000005EEE@3oool205EEE@040?oo
o`1EEED0EEEE0?ooo`80EEEE00<0oooo05EEE@1EEED0403oool:0=7=Z@l0oooo00@0ZZZZ05EEE@1E
EED0ZZZZ0P1EEED00`2ZZZX000000:ZZZP0205EEE@80000000P0ZZZZ05EEE@00000000000:ZZZP00
0000EEEE00000080EEEE00X0000005EEE@000000ZZZZ05EEE@000000EEEE0:ZZZP000000ZZZZ0P1E
EED01P2ZZZX000000:ZZZP2ZZZX0EEEE0:ZZZP<0EEEE3`3oool:0=7=Z@h0oooo00@000000?ooo`1E
EED0oooo0P2ZZZX0101EEED0ZZZZ0?ooo`3oool205EEE@@0oooo00D0ZZZZ05EEE@3oool0EEEE0000
000405EEE@070000001EEED0oooo05EEE@2ZZZX0oooo000000020?ooo`80EEEE00@0ZZZZ0?ooo`2Z
ZZX0EEEE0P2ZZZX0103oool0EEEE0:ZZZP00000>0?ooo`X0dLfY3P3oool020000000ZZZZ0:ZZZP2Z
ZZX0oooo05EEE@2ZZZX0EEEE0P0000001@1EEED000000?ooo`1EEED0ZZZZ00<0oooo0`2ZZZX01@3o
ool0ZZZZ0:ZZZP3oool000000080ZZZZ0`3oool01@2ZZZX0EEEE000000000000EEEE008000000`1E
EED20?ooo`030:ZZZP1EEED0000000h0oooo303AcJT000/0dLfY403oool205EEE@030?ooo`2ZZZX0
oooo00<0oooo00@0EEEE0?ooo`2ZZZX0oooo0P0000001P1EEED0oooo0:ZZZP1EEED0oooo05EEE@80
ZZZZ00H0EEEE0?ooo`1EEED0ZZZZ0?ooo`1EEED2000000030?ooo`1EEED0oooo0080EEEE0P3oool0
1@1EEED0ZZZZ0?ooo`3oool0EEEE0100oooo2P3AcJT@0?ooo`0405EEE@3oool0EEEE0:ZZZPL0oooo
00<0EEEE0:ZZZP1EEED0100000000`1EEED0ZZZZ0:ZZZP020:ZZZP030?ooo`000000000000800000
00@0EEEE0:ZZZP1EEED0EEEE0P3oool00`1EEED0oooo0?ooo`020:ZZZP<0EEEE403oool:0=7=Z@l0
oooo00L0EEEE0000001EEED000000?ooo`1EEED0ZZZZ00@0EEEE0P2ZZZX0101EEED0ZZZZ00000000
00020:ZZZP80000000@0ZZZZ000000000000EEEE0P2ZZZX01@3oool000000:ZZZP1EEED0ZZZZ00<0
EEEE00D0ZZZZ05EEE@2ZZZX000000?ooo`0300000100oooo2P3AcJT?0?ooo`0:05EEE@2ZZZX0oooo
0:ZZZP1EEED0oooo05EEE@2ZZZX0oooo05EEE@<0oooo00H0ZZZZ0000003oool0EEEE0?ooo`000005
05EEE@8000000`3oool00`000000oooo0?ooo`020?ooo`80EEEE00H0ZZZZ05EEE@3oool0EEEE0:ZZ
ZP0000020:ZZZPl0oooo2P3AcJT?0?ooo`050:ZZZP00000000000:ZZZP3oool00P2ZZZX0103oool0
ZZZZ0?ooo`2ZZZX20?ooo`050000003oool0ZZZZ0?ooo`2ZZZX00P1EEED40:ZZZP80EEEE00D0ZZZZ
0000002ZZZX0oooo05EEE@020?ooo`040:ZZZP3oool0oooo0?ooo`80ZZZZ00D0oooo0:ZZZP2ZZZX0
00000:ZZZP0?0?ooo``0dLfY000;0=7=ZA40oooo0P1EEED20:ZZZP0605EEE@000000oooo0000003o
ool0EEEE0`2ZZZX205EEE@050?ooo`2ZZZX0ZZZZ05EEE@2ZZZX00P1EEED20:ZZZP80oooo00d0EEEE
0:ZZZP2ZZZX0ZZZZ05EEE@3oool000000?ooo`000000EEEE0?ooo`2ZZZX0EEEE0180oooo2P3AcJTA
0?ooo`D0EEEE00D0ZZZZ05EEE@00000000000:ZZZP020?ooo`0505EEE@3oool0EEEE05EEE@3oool0
1P1EEED01P3oool0EEEE0?ooo`3oool0EEEE0:ZZZP80oooo0`0000000`2ZZZX0EEEE05EEE@0205EE
EA80oooo2P3AcJTB0?ooo`030:ZZZP1EEED0EEEE0080ZZZZ00<000000?ooo`0000001`1EEED01@00
0000oooo05EEE@1EEED0ZZZZ0080EEEE00<0000005EEE@2ZZZX0101EEED0102ZZZX000000?ooo`00
00020:ZZZP80EEEE00<0ZZZZ05EEE@3oool0403oool:0=7=ZA00oooo00<0ZZZZ0?ooo`0000000P3o
ool00`2ZZZX0EEEE0?ooo`0305EEE@030?ooo`1EEED0ZZZZ00<0ZZZZ00@0oooo05EEE@3oool0EEEE
103oool0102ZZZX0EEEE0:ZZZP2ZZZX20?ooo`<0EEEE00<0000005EEE@2ZZZX00P3oool00`000000
oooo0:ZZZP0@0?ooo`X0dLfY403oool01P2ZZZX000000?ooo`2ZZZX0EEEE00000080oooo0P2ZZZX0
1P3oool000000:ZZZP1EEED0ZZZZ00000080oooo0P2ZZZX010000000ZZZZ0:ZZZP0000020?ooo`04
0000002ZZZX0EEEE0?ooo`8000000P2ZZZX01P1EEED0oooo0000003oool0ZZZZ0?ooo`80ZZZZ403o
ool<0=7=Z@002`3AcJTB0?ooo`0405EEE@3oool0ZZZZ0:ZZZP<0oooo00D0ZZZZ05EEE@2ZZZX0EEEE
000000020:ZZZP060?ooo`1EEED0oooo05EEE@3oool000000`1EEED0103oool0ZZZZ0:ZZZP000002
0:ZZZP0305EEE@2ZZZX0oooo0080oooo00@0ZZZZ05EEE@3oool0EEEE4P3oool:0=7=ZA80oooo101E
EED0103oool0000005EEE@2ZZZX200000080ZZZZ00<0EEEE0:ZZZP2ZZZX00P1EEED20?ooo`0705EE
E@3oool0oooo05EEE@2ZZZX0oooo05EEE@020:ZZZP80000000H0ZZZZ05EEE@000000oooo05EEE@3o
ool205EEEA80oooo2P3AcJTA0?ooo`0305EEE@2ZZZX0EEEE0080EEEE102ZZZX505EEE@030:ZZZP00
000000000080oooo00<0000005EEE@3oool00`00000605EEE@80ZZZZ00H0EEEE0:ZZZP1EEED00000
05EEE@2ZZZXB0?ooo`X0dLfY4@3oool00`2ZZZX0oooo0?ooo`020?ooo`030000001EEED0oooo00@0
oooo00L0EEEE0:ZZZP2ZZZX0EEEE0?ooo`1EEED0ZZZZ0080EEEE00L0ZZZZ0000003oool0EEEE0?oo
o`2ZZZX0EEEE0080oooo00<0EEEE0?ooo`3oool00P0000040?ooo`030000003oool0oooo00l0oooo
2P3AcJTA0?ooo`0305EEE@2ZZZX0ZZZZ0080000000D0oooo0:ZZZP1EEED0oooo000000020:ZZZP05
0?ooo`2ZZZX000000:ZZZP0000000P3oool00`1EEED000000?ooo`020000000;0:ZZZP1EEED0ZZZZ
0?ooo`1EEED0ZZZZ0000003oool0EEEE0:ZZZP3oool00P0000020:ZZZP030000003oool0oooo00l0
oooo303AcJT000/0dLfY503oool00`1EEED0ZZZZ0:ZZZP020:ZZZP<0EEEE00@0oooo0000001EEED0
EEEE0P2ZZZX00`1EEED0ZZZZ0:ZZZP050:ZZZP80EEEE00L0000005EEE@1EEED0ZZZZ05EEE@2ZZZX0
EEEE0080ZZZZ00<0EEEE0?ooo`3oool04P3oool:0=7=ZA@0oooo1@1EEED30?ooo`0;0000001EEED0
EEEE0:ZZZP000000ZZZZ0?ooo`1EEED000000:ZZZP1EEED00P2ZZZX02P000000EEEE05EEE@1EEED0
00000?ooo`2ZZZX0oooo05EEE@3oool305EEEA@0oooo2P3AcJTC0?ooo`0505EEE@3oool0EEEE0000
002ZZZX00P1EEED01`000000EEEE0000001EEED0000005EEE@0000000P3oool2000000090?ooo`00
0000EEEE0?ooo`000000ZZZZ0000001EEED0ZZZZ00@0EEEE0P00000305EEEA<0oooo2P3AcJTB0?oo
o`<0000000<0ZZZZ0?ooo`1EEED00P3oool01@1EEED0ZZZZ05EEE@3oool0EEEE0080ZZZZ00H0EEEE
0?ooo`2ZZZX0oooo05EEE@2ZZZX205EEE@070:ZZZP3oool0EEEE0?ooo`1EEED0ZZZZ05EEE@020?oo
o`0305EEE@3oool0ZZZZ00<000004P3oool:0=7=ZA80oooo00H0000005EEE@3oool0ZZZZ0?ooo`00
00020?ooo`050:ZZZP3oool000000000003oool00P2ZZZX0101EEED000000000003oool300000006
05EEE@2ZZZX0EEEE0?ooo`000000ZZZZ1P3oool20:ZZZP0305EEE@000000oooo0140oooo303AcJT0
00/0dLfY503oool00`1EEED0oooo05EEE@020:ZZZP0;05EEE@3oool0oooo0?ooo`2ZZZX0oooo0:ZZ
ZP3oool0000005EEE@3oool00P1EEED02@3oool000000000003oool0ZZZZ0?ooo`2ZZZX0EEEE0?oo
o`0205EEE@030:ZZZP1EEED0EEEE01H0oooo2P3AcJTD0?ooo`80EEEE00D0oooo0:ZZZP2ZZZX0oooo
0000000305EEE@040?ooo`1EEED0ZZZZ00000080ZZZZ0P1EEED20:ZZZP040000002ZZZX0EEEE0?oo
o`@0EEEE00D0oooo0:ZZZP1EEED0oooo05EEE@0E0?ooo`X0dLfY5@3oool30:ZZZP0905EEE@000000
oooo0:ZZZP000000oooo0000002ZZZX0oooo0080000000<0oooo05EEE@2ZZZX00P3oool01@000000
oooo0:ZZZP000000oooo0080ZZZZ0P00000205EEE@80ZZZZ00<0EEEE0?ooo`3oool04P3oool:0=7=
ZA<0oooo00<0ZZZZ0?ooo`2ZZZX00`1EEED30?ooo`080000003oool0EEEE05EEE@2ZZZX0oooo0:ZZ
ZP1EEED20?ooo`0;05EEE@2ZZZX0oooo0:ZZZP3oool0EEEE0?ooo`000000oooo05EEE@3oool00`1E
EED00`2ZZZX0oooo0:ZZZP0C0?ooo`X0dLfY4`3oool0102ZZZX000000?ooo`1EEED2000000030:ZZ
ZP3oool0oooo0080000000H0oooo0:ZZZP2ZZZX0ZZZZ0?ooo`2ZZZX20?ooo`030:ZZZP3oool0ZZZZ
0080ZZZZ00L0oooo0000003oool0oooo0000002ZZZX000000080EEEE00<0oooo0:ZZZP2ZZZX04`3o
ool<0=7=Z@002`3AcJTE0?ooo`0805EEE@2ZZZX0EEEE0?ooo`1EEED0oooo0000001EEED20:ZZZP03
05EEE@2ZZZX0oooo0080ZZZZ00<0oooo0:ZZZP2ZZZX00P3oool40:ZZZP080?ooo`000000oooo05EE
E@3oool0EEEE0:ZZZP1EEEDE0?ooo`X0dLfY5@3oool205EEE@<000000P3oool0101EEED0oooo05EE
E@2ZZZX205EEE@030:ZZZP1EEED0oooo00D0EEEE00H0ZZZZ05EEE@3oool0EEEE0?ooo`2ZZZX30000
0080EEEE5@3oool:0=7=ZA@0oooo00P0EEEE0:ZZZP1EEED0EEEE0:ZZZP000000ZZZZ05EEE@<0ZZZZ
00D0EEEE0:ZZZP3oool0oooo0:ZZZP0205EEE@050:ZZZP000000oooo0:ZZZP1EEED00P2ZZZX205EE
E@030?ooo`000000ZZZZ0080EEEE00<0ZZZZ0?ooo`3oool04`3oool:0=7=ZA@0oooo00D0ZZZZ0?oo
o`1EEED0oooo05EEE@020?ooo`0305EEE@000000EEEE0080oooo00D0EEEE0:ZZZP3oool0ZZZZ05EE
E@020:ZZZP0305EEE@2ZZZX0EEEE0080oooo101EEED01P3oool0EEEE0?ooo`1EEED0oooo000001@0
oooo2P3AcJTD0?ooo`0405EEE@2ZZZX0ZZZZ0:ZZZP80oooo00D000000:ZZZP000000oooo00000002
0:ZZZP800000103oool02@2ZZZX000000:ZZZP2ZZZX000000?ooo`000000ZZZZ000000030?ooo`80
ZZZZ00<000000?ooo`3oool04P3oool<0=7=Z@002`3AcJTH0?ooo`0505EEE@3oool0EEEE0?ooo`00
00000P2ZZZX01P000000ZZZZ05EEE@2ZZZX0EEEE0?ooo`80EEEE00<0ZZZZ05EEE@2ZZZX0102ZZZX0
0`3oool0ZZZZ0?ooo`0205EEEAL0oooo2P3AcJTG0?ooo`0905EEE@3oool0EEEE0?ooo`000000ZZZZ
05EEE@3oool0000000<0EEEE1@2ZZZX205EEE@050:ZZZP3oool0EEEE0?ooo`0000000P1EEED00`3o
ool0EEEE0?ooo`0F0?ooo`X0dLfY5P3oool0101EEED0oooo0?ooo`2ZZZX405EEE@040:ZZZP1EEED0
EEEE0?ooo`D0EEEE00D0ZZZZ0?ooo`1EEED000000:ZZZP0405EEE@040:ZZZP3oool0EEEE05EEEAH0
oooo2P3AcJTE0?ooo`8000000`2ZZZX20?ooo`030:ZZZP3oool0EEEE0080oooo00D0ZZZZ0?ooo`3o
ool0ZZZZ05EEE@020?ooo`040:ZZZP3oool0oooo05EEE@<0oooo0`2ZZZX3000001D0oooo2P3AcJTE
0?ooo`060000001EEED0oooo0?ooo`000000oooo0P2ZZZX00`1EEED000000:ZZZP020?ooo`030000
001EEED0oooo00<0EEEE0P3oool20000000305EEE@3oool0ZZZZ0080000000@0oooo0:ZZZP1EEED0
00005@3oool<0=7=Z@002`3AcJTG0?ooo`0505EEE@2ZZZX0EEEE05EEE@3oool00`00000305EEE@06
0000001EEED000000?ooo`1EEED0ZZZZ0P1EEED3000000050:ZZZP3oool0oooo05EEE@2ZZZX0603o
ool:0=7=ZAL0oooo0P1EEED01P000000EEEE05EEE@000000oooo0:ZZZP80EEEE00<0oooo00000000
00000`0000001P1EEED0oooo05EEE@1EEED0ZZZZ0?ooo`80EEEE0P0000000`1EEED0oooo0?ooo`0F
0?ooo`X0dLfY603oool00`2ZZZX0EEEE05EEE@0405EEE@030:ZZZP3oool0ZZZZ00H0EEEE00<0ZZZZ
0?ooo`2ZZZX01P1EEED00`2ZZZX0EEEE0?ooo`0F0?ooo`X0dLfY5P3oool0202ZZZX0oooo0000003o
ool000000:ZZZP1EEED0oooo0`1EEED00`3oool000000?ooo`020:ZZZP070?ooo`2ZZZX0oooo05EE
E@3oool0EEEE0?ooo`020:ZZZP80oooo00<000000?ooo`2ZZZX05P3oool:0=7=ZAH0oooo00@0ZZZZ
0000003oool0ZZZZ0P3oool20:ZZZP040?ooo`2ZZZX0EEEE0:ZZZP<0oooo00D0EEEE0?ooo`2ZZZX0
ZZZZ05EEE@020?ooo`060:ZZZP000000oooo0?ooo`2ZZZX0oooo0P2ZZZXF0?ooo``0dLfY000;0=7=
ZAT0oooo0P1EEED00`2ZZZX0oooo0?ooo`0205EEE@060?ooo`2ZZZX0ZZZZ0?ooo`1EEED0ZZZZ0P3o
ool01@2ZZZX0oooo0000001EEED0oooo0080ZZZZ00<0oooo05EEE@3oool0603oool:0=7=ZAT0oooo
00X0EEEE0?ooo`1EEED0ZZZZ0?ooo`2ZZZX0EEEE0000003oool0EEEE0P3oool02@1EEED0oooo0?oo
o`3oool000000?ooo`2ZZZX0oooo0:ZZZP0305EEEAT0oooo2P3AcJTH0?ooo`0405EEE@0000000000
0:ZZZP80000000H0EEEE0000003oool000000:ZZZP00000205EEE@040000003oool000000?ooo`80
EEEE00<0000005EEE@2ZZZX00P0000000`1EEED0oooo0?ooo`0F0?ooo`X0dLfY5`3oool01@2ZZZX0
EEEE0:ZZZP000000oooo0080EEEE0`3oool0301EEED0ZZZZ0000002ZZZX0oooo0000003oool0EEEE
0?ooo`1EEED0oooo05EEE@80oooo0P2ZZZX00`1EEED0oooo0?ooo`0F0?ooo`X0dLfY5`3oool20:ZZ
ZP040000001EEED0ZZZZ0?ooo`80EEEE0P2ZZZX0103oool000000000002ZZZX3000000030?ooo`2Z
ZZX0EEEE0080EEEE00D0oooo0:ZZZP2ZZZX000000:ZZZP0H0?ooo``0dLfY000;0=7=ZAX0oooo00<0
ZZZZ05EEE@2ZZZX00P2ZZZX0103oool0EEEE0:ZZZP2ZZZX205EEE@060?ooo`1EEED0ZZZZ0:ZZZP1E
EED0oooo0`2ZZZX205EEEAX0oooo2P3AcJTJ0?ooo`0405EEE@000000000000000080ZZZZ0`3oool0
101EEED0ZZZZ0:ZZZP1EEED30?ooo`80ZZZZ0`0000000`1EEED0oooo0?ooo`0H0?ooo`X0dLfY6@3o
ool00`1EEED0oooo05EEE@030000000405EEE@2ZZZX0oooo0?ooo`@0EEEE00@000000?ooo`2ZZZX0
ZZZZ0`00000305EEEAT0oooo2P3AcJTH0?ooo`<0000000<0ZZZZ0000000000000P3oool205EEE@05
0?ooo`2ZZZX000000?ooo`2ZZZX0101EEED0103oool000000?ooo`2ZZZX3000001P0oooo2P3AcJTH
0?ooo`030000001EEED0oooo00<0ZZZZ00<0oooo0:ZZZP2ZZZX010000000103oool000000?ooo`00
00020:ZZZP030?ooo`2ZZZX0EEEE0080ZZZZ00<0EEEE0000003oool05`3oool<0=7=Z@002`3AcJTJ
0?ooo`80EEEE00<0ZZZZ05EEE@2ZZZX00P2ZZZX020000000ZZZZ0:ZZZP1EEED0oooo0:ZZZP1EEED0
00000`2ZZZX00`1EEED0ZZZZ05EEE@0K0?ooo`X0dLfY6P3oool705EEE@030000001EEED0000000<0
000000@0EEEE0000001EEED0ZZZZ101EEEDK0?ooo`X0dLfY6`3oool0102ZZZX0EEEE0:ZZZP2ZZZX2
05EEE@040:ZZZP3oool000000:ZZZP80000000@0oooo0:ZZZP1EEED0EEEE102ZZZX00`1EEED0oooo
0?ooo`0H0?ooo`X0dLfY6@3oool01P2ZZZX0oooo0:ZZZP1EEED0000005EEE@80oooo00D0EEEE0?oo
o`3oool0ZZZZ000000020?ooo`0905EEE@3oool0oooo05EEE@000000EEEE0:ZZZP3oool0ZZZZ01T0
oooo2P3AcJTI0?ooo`090:ZZZP000000oooo0?ooo`000000oooo05EEE@3oool0ZZZZ008000000P1E
EED02@000000oooo0:ZZZP3oool0ZZZZ0?ooo`000000EEEE0?ooo`020:ZZZQT0oooo303AcJT000/0
dLfY703oool01@2ZZZX0EEEE05EEE@1EEED0000000<0EEEE0P2ZZZX305EEE@030000003oool0EEEE
0080EEEE703oool:0=7=ZA`0oooo00<0EEEE0000000000000P1EEED01@2ZZZX0EEEE0?ooo`3oool0
EEEE0080oooo00<0ZZZZ05EEE@1EEED00P0000000`1EEED0oooo0?ooo`0J0?ooo`X0dLfY6`3oool0
0`1EEED0000005EEE@02000000030:ZZZP1EEED0oooo0080EEEE00X0ZZZZ05EEE@2ZZZX0EEEE0:ZZ
ZP3oool0000005EEE@000000EEEE6`3oool:0=7=ZAX0oooo00D0ZZZZ05EEE@000000oooo0:ZZZP02
0?ooo`040000001EEED0oooo0:ZZZP80oooo0P0000001P3oool0EEEE0:ZZZP3oool0ZZZZ05EEEA/0
oooo2P3AcJTJ0?ooo`<0ZZZZ00<0000005EEE@3oool00P1EEED01@3oool0ZZZZ000000000000ZZZZ
00<0EEEE00D0ZZZZ05EEE@00000000000:ZZZP0K0?ooo``0dLfY000;0=7=ZA`0oooo0P1EEED01`2Z
ZZX0oooo0?ooo`2ZZZX0oooo0:ZZZP1EEED0102ZZZX0103oool0EEEE0:ZZZP1EEEDM0?ooo`X0dLfY
703oool305EEE@80oooo0P1EEED20000000505EEE@000000000005EEE@3oool00`1EEEDM0?ooo`X0
dLfY703oool01P1EEED0oooo0?ooo`1EEED0ZZZZ05EEE@80oooo00D0000005EEE@3oool0000005EE
E@020:ZZZP80oooo00<0EEEE0?ooo`3oool06P3oool:0=7=ZA/0oooo0P0000020:ZZZP080?ooo`00
0000EEEE0000002ZZZX000000?ooo`2ZZZX205EEE@040000002ZZZX0ZZZZ0:ZZZP8000006`3oool:
0=7=ZA/0oooo00@000000:ZZZP3oool0oooo0P2ZZZX00`3oool0ZZZZ05EEE@0305EEE@040:ZZZP3o
ool0ZZZZ05EEE@80oooo00<0EEEE0000003oool06P3oool<0=7=Z@002`3AcJTN0?ooo`80EEEE00H0
oooo05EEE@00000000000?ooo`1EEED20000000405EEE@3oool0ZZZZ05EEEAh0oooo2P3AcJTN0?oo
o`0405EEE@000000000000000080ZZZZ0P0000020:ZZZP8000000P1EEEDN0?ooo`X0dLfY7@3oool0
0`1EEED0ZZZZ0000000205EEE@80ZZZZ00@0EEEE0:ZZZP2ZZZX0ZZZZ0`1EEED00`2ZZZX0EEEE0?oo
o`0L0?ooo`X0dLfY703oool00`000000ZZZZ0?ooo`040?ooo`0505EEE@000000000005EEE@000000
103oool00`2ZZZX0oooo0?ooo`0K0?ooo`X0dLfY703oool010000000EEEE0:ZZZP0000020:ZZZP05
0?ooo`000000oooo0?ooo`0000001@2ZZZX00`1EEED0oooo0?ooo`0K0?ooo``0dLfY000;0=7=ZAl0
oooo00<0EEEE0:ZZZP3oool00P3oool20:ZZZP050?ooo`2ZZZX0oooo0:ZZZP1EEED07`3oool:0=7=
ZAl0oooo0`1EEED00`2ZZZX0EEEE05EEE@0605EEEAl0oooo2P3AcJTN0?ooo`0605EEE@0000000000
0:ZZZP1EEED0ZZZZ0P1EEED00`2ZZZX0EEEE0:ZZZP020000000305EEE@3oool0oooo01`0oooo2P3A
cJTM0?ooo`040:ZZZP1EEED0ZZZZ00000080oooo00X0000005EEE@00000000000:ZZZP3oool00000
0:ZZZP1EEED0ZZZZ7@3oool:0=7=ZAd0oooo0`2ZZZX205EEE@030?ooo`000000ZZZZ0080000000@0
ZZZZ05EEE@1EEED000000P2ZZZXM0?ooo``0dLfY000;0=7=ZAl0oooo00<0EEEE0?ooo`1EEED00P2Z
ZZX01@1EEED0ZZZZ0:ZZZP2ZZZX0EEEE0240oooo2P3AcJTO0?ooo`80EEEE00@0oooo05EEE@2ZZZX0
oooo0P2ZZZX00`1EEED0oooo05EEE@0P0?ooo`X0dLfY7`3oool0101EEED0oooo05EEE@2ZZZX405EE
E@040000001EEED0oooo05EEEAl0oooo2P3AcJTN0?ooo`<0000000<0ZZZZ05EEE@0000000P1EEED0
0`000000oooo0:ZZZP03000001h0oooo2P3AcJTN0?ooo`040000002ZZZX0oooo0:ZZZP<0000000L0
oooo0000002ZZZX0ZZZZ0?ooo`1EEED0000001h0oooo303AcJT000/0dLfY8@3oool00`1EEED0ZZZZ
0:ZZZP0205EEE@030:ZZZP1EEED0EEEE0240oooo2P3AcJTQ0?ooo`<0EEEE00<0ZZZZ0?ooo`1EEED0
0P1EEEDQ0?ooo`X0dLfY803oool00`1EEED0ZZZZ05EEE@0505EEE@030:ZZZP1EEED0oooo01l0oooo
2P3AcJTO0?ooo`050000002ZZZX0oooo0?ooo`2ZZZX00P3oool0102ZZZX0EEEE0?ooo`2ZZZXP0?oo
o`X0dLfY7`3oool00`000000EEEE0:ZZZP020?ooo`030000002ZZZX0oooo0080ZZZZ00<0EEEE0?oo
o`3oool07P3oool<0=7=Z@002`3AcJTS0?ooo`0305EEE@2ZZZX0EEEE0080EEEE8P3oool:0=7=ZB80
oooo00H0EEEE0?ooo`2ZZZX0EEEE0?ooo`1EEEDR0?ooo`X0dLfY8@3oool0201EEED000000:ZZZP1E
EED000000:ZZZP000000EEEE8@3oool:0=7=ZB00oooo00<0ZZZZ05EEE@000000103oool00`2ZZZX0
EEEE0:ZZZP0P0?ooo`X0dLfY803oool30:ZZZP050?ooo`1EEED000000?ooo`0000000P2ZZZXP0?oo
o``0dLfY000;0=7=ZB80oooo00D0EEEE0:ZZZP1EEED0EEEE0:ZZZP0S0?ooo`X0dLfY8P3oool205EE
E@80000000<0EEEE0?ooo`3oool08@3oool:0=7=ZB80oooo00H0EEEE0?ooo`2ZZZX000000?ooo`1E
EEDR0?ooo`X0dLfY8@3oool2000000040:ZZZP1EEED0ZZZZ0:ZZZP8000008@3oool:0=7=ZB40oooo
00<000000:ZZZP3oool00P0000000`3oool0EEEE0000000Q0?ooo``0dLfY000;0=7=ZB<0oooo00@0
00000?ooo`1EEED000008`3oool:0=7=ZBD0oooo00<0EEEE0?ooo`3oool08P3oool:0=7=ZB<0oooo
0P1EEED00`2ZZZX0EEEE0?ooo`0R0?ooo`X0dLfY8P3oool01@000000ZZZZ0?ooo`3oool0ZZZZ02<0
oooo2P3AcJTR0?ooo`040000003oool00000000002@0oooo303AcJT000/0dLfY903oool20:ZZZR@0
oooo2P3AcJTT0?ooo`030:ZZZP000000oooo02<0oooo2P3AcJTT0?ooo`030000001EEED0oooo02<0
oooo2P3AcJTS0?ooo`80ZZZZ00<0EEEE0:ZZZP3oool08P3oool:0=7=ZB<0oooo00@0ZZZZ05EEE@00
0000ZZZZ8`3oool<0=7=Z@002`3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`03
0:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`03
0:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo303AcJT00?l0dLfY
/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY
/P3AcJT000/0dLfY00P0oooo0000003oool000000?ooo`2ZZZX000000?ooo`80ZZZZ00<000000:ZZ
ZP0000000P0000001`1EEED0oooo05EEE@1EEED0ZZZZ05EEE@2ZZZX00P1EEED01@3oool0ZZZZ05EE
E@3oool000000080oooo00H0000005EEE@1EEED0oooo0000001EEED2000000<0EEEE00D000000?oo
o`3oool000000?ooo`020:ZZZP030?ooo`2ZZZX0EEEE00<0ZZZZ0P1EEED01`3oool0000000000000
0000oooo0:ZZZP0000000P2ZZZX0203oool0ZZZZ0:ZZZP1EEED000000?ooo`000000oooo2P3AcJT0
103oool0000005EEE@2ZZZX205EEE@8000000P2ZZZX01@000000ZZZZ0000002ZZZX0EEEE0080oooo
00@0ZZZZ000000000000ZZZZ0P3oool70:ZZZP0305EEE@2ZZZX000000080000000@0ZZZZ0000002Z
ZZX0ZZZZ0`000000103oool0EEEE0:ZZZP0000050:ZZZP80oooo0`000000101EEED0oooo0?ooo`1E
EED30:ZZZP050000003oool0ZZZZ0000003oool00P1EEED0102ZZZX0EEEE0000003oool:0=7=Z@05
0?ooo`00000000000?ooo`2ZZZX00`0000001@1EEED0oooo05EEE@2ZZZX0EEEE0080ZZZZ00<00000
0?ooo`2ZZZX00`2ZZZX03`000000ZZZZ0000002ZZZX0oooo05EEE@3oool0ZZZZ05EEE@3oool0ZZZZ
0000001EEED000000:ZZZP02000000030:ZZZP1EEED0EEEE0080000000/0oooo05EEE@1EEED0oooo
0:ZZZP3oool0ZZZZ05EEE@2ZZZX0000005EEE@020:ZZZP<0oooo102ZZZX00`1EEED0oooo05EEE@04
000000040?ooo`00000000000?ooo`X0dLfY00<0oooo0000002ZZZX00P2ZZZX01`3oool000000:ZZ
ZP3oool0ZZZZ05EEE@2ZZZX00`1EEED0103oool0ZZZZ0:ZZZP2ZZZX2000000030:ZZZP000000ZZZZ
0080ZZZZ00D000000:ZZZP1EEED0ZZZZ0?ooo`020:ZZZP80oooo0P2ZZZX02`1EEED0ZZZZ0?ooo`3o
ool0ZZZZ0000003oool0ZZZZ05EEE@2ZZZX000000080ZZZZ0P0000001P2ZZZX000000000002ZZZX0
EEEE0:ZZZP<0EEEE0P2ZZZX205EEE@040?ooo`2ZZZX0EEEE0?ooo`<0ZZZZ00<000000?ooo`3AcJT0
2@3AcJT02@3oool00000000000000000oooo0000001EEED0oooo000000020?ooo`80EEEE00@00000
0:ZZZP2ZZZX0ZZZZ0P3oool3000000050:ZZZP3oool0oooo0?ooo`1EEED00P3oool00`000000oooo
00000002000000060:ZZZP000000oooo0?ooo`000000ZZZZ0P0000020?ooo`040000003oool0oooo
0:ZZZP<0oooo00D0ZZZZ00000000000000000?ooo`040:ZZZP040000001EEED0EEEE0?ooo`800000
00@0oooo0:ZZZP000000oooo0`0000000`3oool0dLfY0=7=Z@0:0=7=Z@002`3AcJT01`3oool00000
0?ooo`2ZZZX0EEEE0?ooo`1EEED01@2ZZZX01P000000oooo0?ooo`3oool0EEEE0:ZZZP<0EEEE00<0
ZZZZ0000003oool00`1EEED30:ZZZP0905EEE@3oool0EEEE0000002ZZZX0oooo0:ZZZP1EEED0oooo
0080000000<0EEEE0:ZZZP1EEED00`2ZZZX305EEE@80000000<0ZZZZ05EEE@1EEED00`1EEED01000
0000oooo0?ooo`3oool20:ZZZP030?ooo`2ZZZX0ZZZZ0080oooo00<0EEEE0:ZZZP3oool00P3oool:
0=7=Z@060?ooo`000000oooo0000001EEED000000`2ZZZX0101EEED000000000003oool205EEE@03
0:ZZZP1EEED0EEEE00<000000P2ZZZX00`000000ZZZZ000000020:ZZZP030?ooo`1EEED0EEEE00H0
ZZZZ00<0oooo0:ZZZP2ZZZX00P2ZZZX305EEE@060?ooo`2ZZZX0oooo0000002ZZZX000000P2ZZZX3
000000D0EEEE00@0ZZZZ000000000000EEEE0`2ZZZX00`000000ZZZZ000000030?ooo`X0dLfY00@0
oooo0000003oool0oooo1@2ZZZX0101EEED0ZZZZ0:ZZZP2ZZZX2000000<0ZZZZ0P0000030:ZZZP03
0000003oool000000080ZZZZ00L0oooo0000002ZZZX0ZZZZ0?ooo`1EEED0oooo00@0ZZZZ0P1EEED0
0`3oool0ZZZZ0:ZZZP02000000030:ZZZP1EEED000000080oooo0P2ZZZX0103oool0000000000000
00020:ZZZP80000000@0oooo0:ZZZP2ZZZX0EEEE102ZZZX50?ooo`X0dLfY00H0oooo0000003oool0
EEEE0000001EEED20:ZZZP030000001EEED0ZZZZ0080ZZZZ0`00000205EEE@@0oooo00L0EEEE0?oo
o`2ZZZX0ZZZZ0?ooo`000000EEEE0080oooo0P2ZZZX02@000000ZZZZ000000000000ZZZZ0000001E
EED000000:ZZZP030?ooo`0305EEE@000000oooo00<0ZZZZ00<0EEEE0?ooo`2ZZZX00`3oool00`1E
EED0ZZZZ0000000200000080ZZZZ00L0EEEE0000002ZZZX0ZZZZ05EEE@3oool0EEEE00<0oooo2P3A
cJT00`3oool000000:ZZZP030?ooo`0@0:ZZZP00000000000000002ZZZX000000:ZZZP000000oooo
0000003oool000000:ZZZP000000ZZZZ05EEE@@0oooo00<0EEEE0000000000000`0000020?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool0ZZZZ0P0000000`1EEED000000?ooo`040?oo
o`0<05EEE@3oool000000:ZZZP000000oooo0000003oool000000:ZZZP000000ZZZZ0`0000001@2Z
ZZX0oooo0?ooo`3oool0ZZZZ0080oooo303AcJT000/0dLfY0`3oool01P000000EEEE05EEE@1EEED0
000005EEE@80ZZZZ00@0EEEE0?ooo`00000000000P1EEED20?ooo`040000003oool0ZZZZ05EEE@80
ZZZZ00X0oooo0000001EEED0EEEE0000001EEED0oooo0:ZZZP000000oooo102ZZZX2000000030:ZZ
ZP3oool0EEEE0080000000<0EEEE0?ooo`3oool00P2ZZZX0201EEED0ZZZZ05EEE@000000oooo0:ZZ
ZP1EEED0oooo0P00000205EEE@040:ZZZP1EEED0EEEE00000080EEEE0P0000030?ooo`X0dLfY0`3o
ool00`000000EEEE0:ZZZP02000000<0ZZZZ100000000`2ZZZX0oooo000000040000000405EEE@2Z
ZZX0000000000080oooo0P000000101EEED0ZZZZ0:ZZZP0000020:ZZZP0305EEE@3oool0ZZZZ0080
00000P2ZZZX01@1EEED000000:ZZZP3oool0ZZZZ008000000P1EEED40000000305EEE@3oool0oooo
0080000000<0ZZZZ0000002ZZZX00P2ZZZX00`000000ZZZZ0:ZZZP02000000<0oooo2P3AcJT30?oo
o`040000002ZZZX0ZZZZ05EEE@D0ZZZZ00D0EEEE0?ooo`1EEED0ZZZZ0000000205EEE@030000002Z
ZZX0oooo0080EEEE00<0oooo0000001EEED01@3oool00`000000ZZZZ00000005000000030:ZZZP00
0000ZZZZ00D0oooo00@000000?ooo`1EEED0EEEE0P3oool00`000000EEEE0:ZZZP020000000305EE
E@3oool0oooo00P0ZZZZ00@000000?ooo`3oool0oooo2P3AcJT30?ooo`050000001EEED0EEEE0000
002ZZZX00`1EEED2000000090?ooo`1EEED0EEEE05EEE@3oool000000?ooo`1EEED0oooo00@0EEEE
0P2ZZZX2000000040:ZZZP000000ZZZZ0:ZZZP80000000@0EEEE0?ooo`000000EEEE0P2ZZZX01P00
0000ZZZZ0000001EEED0ZZZZ0?ooo`@0EEEE00D0oooo05EEE@3oool000000:ZZZP0305EEE@070?oo
o`000000000005EEE@2ZZZX0EEEE0:ZZZP0205EEE@030?ooo`000000oooo0080oooo2P3AcJT30?oo
o`030000002ZZZX000000080oooo00@0000005EEE@000000ZZZZ0P0000000`3oool0ZZZZ05EEE@02
0?ooo`80ZZZZ00D000000:ZZZP2ZZZX0ZZZZ000000030:ZZZP8000000P3oool20000000405EEE@00
0000EEEE05EEE@80000000P0oooo0:ZZZP00000000000?ooo`2ZZZX0oooo000000<0ZZZZ00<00000
05EEE@2ZZZX00P3oool01P1EEED0oooo0?ooo`000000EEEE0:ZZZP<000000P3oool00`000000ZZZZ
000000030?ooo``0dLfY000;0=7=Z@D0oooo00@0EEEE0?ooo`1EEED0ZZZZ0`1EEED01@3oool0ZZZZ
0?ooo`1EEED000000080ZZZZ00<0EEEE0000002ZZZX01@1EEED01@2ZZZX0oooo0000003oool0EEEE
00<0oooo100000002@2ZZZX0oooo0?ooo`1EEED0oooo0000001EEED0ZZZZ0?ooo`0405EEE@0:0:ZZ
ZP3oool0EEEE0:ZZZP1EEED0000005EEE@3oool0ZZZZ000000<0EEEE00D0ZZZZ05EEE@000000EEEE
000000040?ooo`X0dLfY1@3oool01@000000oooo0?ooo`2ZZZX0oooo0080ZZZZ0P3oool00`2ZZZX0
EEEE0?ooo`050000000405EEE@000000000000000080ZZZZ0`0000020:ZZZP030?ooo`2ZZZX0ZZZZ
0080EEEE00D0ZZZZ05EEE@3oool0ZZZZ0?ooo`03000000060:ZZZP00000000000000002ZZZX0EEEE
1@000000103oool0EEEE0:ZZZP3oool50:ZZZP040?ooo`2ZZZX00000000000@0oooo2P3AcJT40?oo
o`060000001EEED000000000002ZZZX000000P1EEED20:ZZZP060000003oool0EEEE0000003oool0
ZZZZ0P1EEED01`2ZZZX0EEEE0:ZZZP1EEED000000:ZZZP0000000P2ZZZX00`1EEED0oooo0:ZZZP07
0:ZZZP030?ooo`000000ZZZZ00<0ZZZZ00<0oooo05EEE@2ZZZX00P2ZZZX205EEE@070:ZZZP3oool0
ZZZZ05EEE@3oool000000:ZZZP0305EEE@060000002ZZZX000000000001EEED00000103oool:0=7=
Z@@0oooo00D000000:ZZZP3oool0oooo05EEE@020:ZZZP0405EEE@2ZZZX0EEEE00000080EEEE0P3o
ool00`000000ZZZZ0000000205EEE@8000000P1EEED30:ZZZP0805EEE@2ZZZX0EEEE0?ooo`2ZZZX0
000005EEE@2ZZZX205EEE@030:ZZZP3oool0ZZZZ0080ZZZZ00<0EEEE0:ZZZP0000000P000000101E
EED000000000000000020?ooo`0705EEE@000000000005EEE@3oool0EEEE0:ZZZP0205EEE@040?oo
o`000000ZZZZ000000@0oooo2P3AcJT40?ooo`030000003oool0oooo00<0oooo00<0EEEE0:ZZZP2Z
ZZX00`3oool0101EEED000000:ZZZP0000020?ooo`070000003oool000000000002ZZZX0EEEE0000
00020?ooo`050000001EEED0EEEE0:ZZZP0000000P2ZZZX01@000000oooo05EEE@1EEED000000080
oooo00<0000005EEE@000000100000001P3oool0EEEE0000002ZZZX0000005EEE@<0oooo00@00000
0:ZZZP1EEED00000103oool00`000000oooo0?ooo`020?ooo``0dLfY000;0=7=Z@D0oooo00X00000
0?ooo`000000EEEE0000003oool0EEEE0:ZZZP1EEED0ZZZZ0P1EEED30:ZZZP030?ooo`000000ZZZZ
0080ZZZZ00<000000?ooo`1EEED00P1EEED00`3oool00000000000020?ooo`070:ZZZP3oool00000
0:ZZZP1EEED0oooo000000020?ooo`0505EEE@2ZZZX0EEEE0?ooo`0000000`2ZZZX00`000000ZZZZ
0:ZZZP020:ZZZP80EEEE00@0ZZZZ05EEE@2ZZZX0EEEE0P3oool0101EEED000000000000000050?oo
o`X0dLfY1@3oool01@000000EEEE0:ZZZP1EEED0oooo00<0ZZZZ00@0oooo0000003oool0oooo1P00
00001@2ZZZX000000000003oool000000080ZZZZ00H000000?ooo`000000EEEE0?ooo`0000020?oo
o`030000002ZZZX0EEEE00<0000000@0ZZZZ000000000000ZZZZ0P0000000`3oool0000000000004
00000080oooo00<000000?ooo`2ZZZX00P2ZZZX00`3oool0EEEE0:ZZZP02000000D0oooo2P3AcJT5
0?ooo`030000002ZZZX0EEEE00@0EEEE00<0oooo05EEE@0000000P0000000`1EEED0ZZZZ0:ZZZP03
0:ZZZP<0oooo00<000000:ZZZP2ZZZX00P1EEED;000000<0EEEE00<000000:ZZZP0000000P3oool6
0:ZZZP0605EEE@00000000000000001EEED0oooo1P1EEED00`000000oooo0?ooo`030?ooo`X0dLfY
1@3oool00`000000ZZZZ0:ZZZP020:ZZZP030000001EEED0000000@000000P2ZZZX305EEE@030?oo
o`1EEED0000000<0EEEE00@000000:ZZZP000000oooo0P1EEED00`3oool0EEEE0:ZZZP0505EEE@08
0:ZZZP000000ZZZZ0?ooo`1EEED0ZZZZ05EEE@0000020?ooo`<0EEEE0P2ZZZX400000080EEEE00@0
000005EEE@2ZZZX0ZZZZ0P0000050?ooo`X0dLfY1@3oool3000000040?ooo`000000ZZZZ05EEE@<0
000000<0ZZZZ0000000000000P1EEED20?ooo`070000002ZZZX0000005EEE@000000oooo0:ZZZP03
000000030?ooo`00000000000080000000H0ZZZZ00000000000000000?ooo`2ZZZX3000000070?oo
o`000000EEEE0000003oool000000?ooo`0305EEE@030:ZZZP000000oooo00<0000000@0EEEE0:ZZ
ZP3oool0oooo0`0000050?ooo``0dLfY000;0=7=Z@L0oooo00@0ZZZZ05EEE@3oool0ZZZZ0`000000
4@2ZZZX0EEEE000000000000oooo0000003oool0ZZZZ0?ooo`2ZZZX0oooo0:ZZZP000000ZZZZ05EE
E@3oool000000080oooo0P2ZZZX04P3oool0EEEE0:ZZZP3oool000000:ZZZP3oool0ZZZZ0000003o
ool000000:ZZZP3oool0ZZZZ0?ooo`2ZZZX0oooo0:ZZZP80000000D0oooo000000000000EEEE0:ZZ
ZP03000000050:ZZZP1EEED0EEEE0:ZZZP0000001P3oool:0=7=Z@L0oooo00<000000:ZZZP1EEED0
0P2ZZZX010000000ZZZZ0:ZZZP0000070:ZZZP030000003oool0oooo00<0ZZZZ00D0oooo0000003o
ool0oooo000000020:ZZZP030000002ZZZX0ZZZZ008000000P3oool01@000000oooo0:ZZZP2ZZZX0
00000080oooo2`2ZZZX01@3oool0ZZZZ0:ZZZP1EEED0ZZZZ008000001P3oool:0=7=Z@H0oooo00@0
ZZZZ05EEE@2ZZZX0EEEE0P2ZZZX00`1EEED0ZZZZ0:ZZZP020:ZZZP0305EEE@2ZZZX000000080EEEE
00H000000:ZZZP1EEED0EEEE0?ooo`1EEED20:ZZZP0305EEE@2ZZZX0ZZZZ00X0ZZZZ00D0EEEE0:ZZ
ZP3oool0EEEE0:ZZZP0305EEE@040000001EEED00000000000H0ZZZZ00<0EEEE0:ZZZP2ZZZX00P2Z
ZZX00`1EEED000000?ooo`050?ooo`X0dLfY1`3oool00`1EEED0oooo0:ZZZP030:ZZZP@0oooo00H0
ZZZZ0000002ZZZX000000:ZZZP0000030:ZZZP0505EEE@000000ZZZZ0?ooo`2ZZZX00P1EEED01@3o
ool0EEEE05EEE@1EEED0oooo0080EEEE00P0oooo05EEE@1EEED0ZZZZ0?ooo`1EEED0000005EEE@80
ZZZZ00T0EEEE0000002ZZZX0oooo0:ZZZP000000ZZZZ0?ooo`2ZZZX00P3oool01`1EEED0ZZZZ0:ZZ
ZP000000oooo05EEE@0000001P3oool:0=7=Z@H0oooo00@0ZZZZ0?ooo`3oool0oooo0P2ZZZX20?oo
o`030:ZZZP000000oooo0080EEEE00H0ZZZZ05EEE@00000000000:ZZZP1EEED30?ooo`<000001@3o
ool2000000040?ooo`000000oooo0?ooo`<000000P3oool00`000000oooo05EEE@030000000305EE
E@2ZZZX0EEEE0080oooo00@000000:ZZZP3oool000000P2ZZZX30?ooo`030000003oool0oooo00@0
oooo303AcJT000/0dLfY1P3oool00`000000ZZZZ05EEE@020:ZZZP090?ooo`2ZZZX0oooo0?ooo`00
0000oooo0:ZZZP1EEED0ZZZZ00<0EEEE00@0oooo05EEE@1EEED0oooo0P2ZZZX01@000000oooo05EE
E@1EEED0oooo0080ZZZZ00<0000005EEE@2ZZZX00P3oool0101EEED0oooo0?ooo`0000020:ZZZP<0
EEEE00H0oooo05EEE@1EEED0oooo0:ZZZP1EEED20?ooo`0305EEE@3oool0oooo0080oooo00@0ZZZZ
05EEE@1EEED0ZZZZ1`3oool:0=7=Z@H0oooo00@0000005EEE@000000ZZZZ0P0000020:ZZZP040?oo
o`2ZZZX0ZZZZ0:ZZZP<0000000<0oooo0:ZZZP3oool00P3oool00`000000ZZZZ000000020:ZZZP05
0000002ZZZX0ZZZZ0:ZZZP3oool00P2ZZZX00`3oool0ZZZZ0:ZZZP040:ZZZP030000002ZZZX0oooo
0080oooo0P2ZZZX01@3oool0ZZZZ000000000000oooo0080ZZZZ00<0oooo0:ZZZP2ZZZX00P000000
0`1EEED0000005EEE@070?ooo`X0dLfY1P3oool4000000040:ZZZP000000000000000080EEEE00<0
00000?ooo`2ZZZX00P2ZZZX00`1EEED0ZZZZ00000002000000030?ooo`1EEED0ZZZZ008000000P1E
EED010000000oooo0000002ZZZX40000000405EEE@000000000000000080EEEE0`0000000`3oool0
ZZZZ05EEE@030:ZZZP8000000P1EEED3000000040:ZZZP3oool00000000000L0oooo2P3AcJT60?oo
o`80000000<0ZZZZ0?ooo`3oool00P1EEED01P000000ZZZZ05EEE@1EEED0ZZZZ05EEE@80oooo0P2Z
ZZX205EEE@<0ZZZZ0`1EEED0302ZZZX0EEEE0:ZZZP000000ZZZZ05EEE@000000ZZZZ0000002ZZZX0
EEEE0:ZZZP80EEEE0P2ZZZX00`1EEED0ZZZZ05EEE@030:ZZZP80oooo101EEED0202ZZZX000000?oo
o`1EEED0oooo05EEE@2ZZZX000001`3oool:0=7=Z@H0oooo0P0000001@1EEED000000000003oool0
ZZZZ0080000000P0ZZZZ0000002ZZZX0ZZZZ0000003oool000000?ooo`80ZZZZ0P0000000`2ZZZX0
000000000002000000050:ZZZP000000000005EEE@3oool00P1EEED2000000030:ZZZP0000000000
0080000000@0ZZZZ000000000000ZZZZ0P3oool010000000EEEE0000002ZZZX2000000060?ooo`00
000000000000003oool000000P1EEED00`000000oooo0?ooo`050?ooo``0dLfY000;0=7=Z@P0oooo
00D0000005EEE@000000oooo05EEE@020:ZZZP030000003oool0EEEE0080000000H0oooo05EEE@2Z
ZZX0EEEE0?ooo`00000205EEE@060:ZZZP1EEED0EEEE05EEE@2ZZZX0EEEE0P2ZZZX01P3oool0ZZZZ
0:ZZZP000000EEEE0:ZZZP<0EEEE00L0ZZZZ05EEE@3oool000000?ooo`1EEED0ZZZZ0080EEEE0P00
00000`2ZZZX0oooo000000020:ZZZP0505EEE@3oool000000?ooo`000000203oool:0=7=Z@P0oooo
0P0000000`2ZZZX0oooo0:ZZZP0200000080ZZZZ00T0EEEE0?ooo`000000ZZZZ0?ooo`000000oooo
05EEE@3oool00P0000000`2ZZZX00000000000020:ZZZP@0000000@0ZZZZ00000000000000000P2Z
ZZX2000000080:ZZZP000000ZZZZ0?ooo`1EEED0oooo0000003oool200000080oooo00T0ZZZZ0000
0000000000000:ZZZP3oool0ZZZZ0?ooo`000000203oool:0=7=Z@P0oooo00@000000?ooo`000000
00000P1EEED2000000040:ZZZP000000oooo0?ooo`<0ZZZZ00<0oooo0:ZZZP2ZZZX00P2ZZZX00`00
0000EEEE05EEE@03000000060:ZZZP00000000000:ZZZP000000ZZZZ0P00000305EEE@80ZZZZ00<0
oooo0:ZZZP2ZZZX0102ZZZX20?ooo`040000002ZZZX0000000000080EEEE0P0000000`1EEED00000
0?ooo`070?ooo`X0dLfY203oool010000000ZZZZ0000003oool305EEE@030:ZZZP3oool0EEEE0080
000000d0EEEE000000000000EEEE0000002ZZZX0oooo0:ZZZP1EEED0ZZZZ05EEE@2ZZZX0oooo0080
EEEE0P2ZZZX010000000ZZZZ05EEE@1EEED20?ooo`0605EEE@2ZZZX0oooo0:ZZZP3oool0ZZZZ1000
0000101EEED000000000002ZZZX20?ooo`80EEEE00<0ZZZZ0?ooo`0000000P0000080?ooo`X0dLfY
203oool00`000000oooo0?ooo`020?ooo`040000003oool0ZZZZ0:ZZZP@0EEEE00d0oooo05EEE@1E
EED0oooo0000002ZZZX000000?ooo`000000ZZZZ0?ooo`000000ZZZZ0080000000X0oooo05EEE@00
000000000:ZZZP000000oooo0:ZZZP000000oooo0`000000103oool0EEEE05EEE@3oool305EEE@05
0000002ZZZX0oooo0?ooo`0000000`3oool2000000P0oooo303AcJT000/0dLfY2@3oool30:ZZZP0;
05EEE@000000ZZZZ0?ooo`2ZZZX0EEEE0?ooo`2ZZZX0EEEE0?ooo`0000000P2ZZZX205EEE@<00000
00H0EEEE0:ZZZP1EEED000000?ooo`1EEED20?ooo`0305EEE@3oool0000000<0EEEE0`0000000`3o
ool0EEEE0:ZZZP020000000:0?ooo`1EEED0ZZZZ0?ooo`000000ZZZZ05EEE@2ZZZX0000005EEE@80
ZZZZ00<000000?ooo`3oool01`3oool:0=7=Z@T0oooo00H0EEEE0000001EEED0oooo05EEE@2ZZZX2
05EEE@040?ooo`000000EEEE00000080ZZZZ00<000000:ZZZP1EEED00P0000001`2ZZZX0oooo05EE
E@2ZZZX0oooo0000003oool00P2ZZZX0203oool0ZZZZ0?ooo`000000oooo0:ZZZP1EEED0oooo0P00
000205EEE@@0ZZZZ00X0000005EEE@000000000005EEE@3oool0ZZZZ05EEE@3oool0EEEE0P000009
0?ooo`X0dLfY2@3oool30:ZZZP0305EEE@2ZZZX0ZZZZ0080ZZZZ00@0EEEE0:ZZZP1EEED0EEEE0P00
000205EEE@030000002ZZZX0oooo0080ZZZZ00D0EEEE0:ZZZP2ZZZX0ZZZZ0?ooo`020:ZZZP030?oo
o`2ZZZX0ZZZZ00<0ZZZZ00P0EEEE0:ZZZP2ZZZX0oooo0:ZZZP000000EEEE0:ZZZP8000000P1EEED0
0`2ZZZX0oooo0:ZZZP060:ZZZP030000003oool0oooo00L0oooo2P3AcJT:0?ooo`0305EEE@2ZZZX0
ZZZZ008000000P1EEED30:ZZZP0305EEE@2ZZZX0oooo00<0ZZZZ00<0EEEE0:ZZZP0000000P000000
0`2ZZZX0EEEE0000000205EEE@030?ooo`2ZZZX0EEEE008000000P1EEED20000000305EEE@2ZZZX0
00000080ZZZZ00<0EEEE0?ooo`2ZZZX00`2ZZZX205EEE@070:ZZZP00000000000000002ZZZX0EEEE
000000090?ooo`X0dLfY2@3oool00`2ZZZX00000000000040000000805EEE@2ZZZX000000:ZZZP00
0000ZZZZ0000002ZZZX3000000<0oooo00/000000:ZZZP000000oooo0:ZZZP3oool0000005EEE@3o
ool000000?ooo`03000000<0oooo0`0000000`2ZZZX000000:ZZZP020:ZZZP040000002ZZZX0EEEE
0:ZZZP80000000@0ZZZZ00000000000000002@3oool<0=7=Z@002`3AcJT:0?ooo`060000003oool0
EEEE05EEE@3oool0EEEE0P2ZZZX305EEE@040?ooo`1EEED0EEEE05EEE@80ZZZZ00<0oooo0:ZZZP3o
ool00`2ZZZX405EEE@040:ZZZP1EEED0EEEE05EEE@<0ZZZZ00<0oooo0:ZZZP3oool00P2ZZZX01@1E
EED0oooo05EEE@3oool0ZZZZ0080EEEE0P2ZZZX20?ooo`0405EEE@2ZZZX0oooo000000X0oooo2P3A
cJT:0?ooo`050000003oool0ZZZZ05EEE@0000000P2ZZZX00`000000ZZZZ0:ZZZP030:ZZZP030?oo
o`2ZZZX0oooo0080000000X0EEEE0:ZZZP000000oooo0000002ZZZX000000?ooo`1EEED0ZZZZ0P3o
ool01@2ZZZX000000?ooo`000000ZZZZ00<0000000<0oooo0:ZZZP3oool0202ZZZX01@000000EEEE
0000003oool0000000X0oooo2P3AcJT:0?ooo`040000003oool0oooo0?ooo`@0ZZZZ00@0000005EE
E@2ZZZX0ZZZZ100000020?ooo`@0ZZZZ00@0EEEE0:ZZZP2ZZZX000000P3oool010000000oooo0:ZZ
ZP1EEED30:ZZZP0305EEE@3oool0EEEE0080000000L0ZZZZ0000002ZZZX0oooo05EEE@000000EEEE
00<0ZZZZ00@0oooo0:ZZZP3oool000002P3oool:0=7=Z@X0oooo00<000000?ooo`3oool00P000000
202ZZZX0EEEE0:ZZZP2ZZZX0EEEE0000001EEED0ZZZZ0`1EEED20?ooo`090:ZZZP000000EEEE05EE
E@3oool0EEEE0:ZZZP000000oooo00<0000000L0EEEE0?ooo`3oool0EEEE0000001EEED0oooo00<0
EEEE00<0oooo0:ZZZP1EEED00P1EEED0102ZZZX0EEEE05EEE@2ZZZX20000000305EEE@3oool00000
00X0oooo2P3AcJT:0?ooo`030000002ZZZX0oooo0080oooo00@0ZZZZ00000000000000000P2ZZZX0
0`000000ZZZZ0:ZZZP020000000305EEE@2ZZZX0oooo0080EEEE00H0ZZZZ00000000000000000?oo
o`1EEED20?ooo`040:ZZZP00000000000?ooo`80EEEE00<0oooo0:ZZZP0000000`000000102ZZZX0
00000000002ZZZX3000000060:ZZZP3oool0oooo0?ooo`2ZZZX000002P3oool<0=7=Z@002`3AcJT;
0?ooo`040000001EEED0EEEE0:ZZZP@0EEEE00D000000?ooo`1EEED0EEEE0:ZZZP03000000030?oo
o`2ZZZX0oooo00H0000000@0ZZZZ05EEE@000000ZZZZ100000000`3oool0ZZZZ0?ooo`0300000003
0:ZZZP1EEED0EEEE008000000`1EEED20:ZZZP0305EEE@2ZZZX0000000/0oooo2P3AcJT;0?ooo`80
00000140EEEE0:ZZZP2ZZZX0ZZZZ0000003oool0ZZZZ0?ooo`2ZZZX0000005EEE@000000EEEE0:ZZ
ZP3oool0ZZZZ000000030?ooo`050000002ZZZX0ZZZZ0?ooo`0000000P2ZZZX01P000000oooo0?oo
o`3oool0000005EEE@80oooo00@0EEEE0000003oool000000`2ZZZX20?ooo`030:ZZZP3oool0ZZZZ
0080EEEE00<000000?ooo`3oool02@3oool:0=7=Z@/0oooo00<000000:ZZZP1EEED00`1EEED20?oo
o`030000002ZZZX0oooo0080ZZZZ0P3oool20:ZZZP030?ooo`000000000000<0000000<0ZZZZ0?oo
o`3oool00P3oool0102ZZZX000000000002ZZZX3000000030:ZZZP000000oooo0080oooo00D0ZZZZ
0?ooo`2ZZZX000000?ooo`0605EEE@030000003oool0oooo00T0oooo2P3AcJT;0?ooo`060000002Z
ZZX0EEEE0?ooo`2ZZZX000000P2ZZZX01@000000ZZZZ05EEE@2ZZZX000000080EEEE00<000000?oo
o`2ZZZX00P2ZZZX200000080oooo00<0ZZZZ0?ooo`3oool00P2ZZZX00`3oool0000005EEE@020:ZZ
ZP030000003oool0000000<0EEEE00D0ZZZZ05EEE@3oool000000:ZZZP02000000030:ZZZP3oool0
EEEE008000002`3oool:0=7=Z@/0oooo00H0000005EEE@1EEED000000?ooo`0000020?ooo`80ZZZZ
0P3oool205EEE@040?ooo`1EEED0ZZZZ00000080ZZZZ00<000000?ooo`3oool00`0000000`2ZZZX0
0000000000020?ooo`070000002ZZZX0ZZZZ0000002ZZZX0EEEE0?ooo`0205EEE@80oooo0P2ZZZX0
0`3oool0ZZZZ000000020000000305EEE@000000000000/0oooo303AcJT000/0dLfY303oool05@00
0000EEEE05EEE@1EEED0000005EEE@2ZZZX0EEEE0:ZZZP000000ZZZZ0?ooo`2ZZZX0oooo0:ZZZP3o
ool000000?ooo`2ZZZX0oooo0:ZZZP020?ooo`0;0:ZZZP1EEED0EEEE0:ZZZP1EEED0oooo0:ZZZP3o
ool0ZZZZ0?ooo`0000000`3oool30:ZZZP060000003oool0EEEE0:ZZZP1EEED000000`1EEED00`00
0000oooo0?ooo`0:0?ooo`X0dLfY303oool00`000000EEEE0:ZZZP0200000080ZZZZ00@000000:ZZ
ZP2ZZZX0EEEE0`00000205EEE@030000003oool0oooo00<0oooo00@0ZZZZ0000003oool0oooo0P00
00050?ooo`030:ZZZP1EEED0oooo0080000000<0oooo05EEE@2ZZZX00P0000020:ZZZP050000002Z
ZZX0ZZZZ05EEE@000000303oool:0=7=Z@`0oooo00D0ZZZZ05EEE@2ZZZX0EEEE0:ZZZP0205EEE@<0
ZZZZ00@000000?ooo`3oool0oooo0P2ZZZX20?ooo`80ZZZZ0P3oool00`000000ZZZZ000000020:ZZ
ZP050000003oool0oooo0?ooo`2ZZZX00P3oool02P2ZZZX0oooo0?ooo`3oool0EEEE0000002ZZZX0
oooo0:ZZZP1EEED40:ZZZP0305EEE@000000oooo00/0oooo2P3AcJT=0?ooo`80EEEE00@0ZZZZ05EE
E@2ZZZX0ZZZZ0P3oool205EEE@80ZZZZ00<0EEEE0?ooo`3oool00P2ZZZX00`000000oooo05EEE@02
0:ZZZP@0EEEE00H000000:ZZZP1EEED0ZZZZ0000002ZZZX20?ooo`040:ZZZP1EEED0ZZZZ0:ZZZP80
EEEE0P3oool00`2ZZZX0oooo05EEE@0305EEE@030000003oool0oooo00X0oooo2P3AcJT<0?ooo`80
ZZZZ00L000000?ooo`3oool0000005EEE@000000EEEE0080000000<0ZZZZ0000002ZZZX00P2ZZZX0
103oool000000000002ZZZX200000080oooo0P0000001@3oool0ZZZZ000000000000oooo00800000
00H0oooo0:ZZZP000000ZZZZ0000002ZZZX2000000040:ZZZP000000EEEE00000080oooo00<00000
0:ZZZP000000303oool<0=7=Z@002`3AcJT=0?ooo`030000002ZZZX0ZZZZ0080EEEE00@0000005EE
E@2ZZZX0EEEE0`2ZZZX02`1EEED0ZZZZ0:ZZZP2ZZZX0oooo0000003oool0EEEE0?ooo`000000ZZZZ
008000000P2ZZZX01`3oool0EEEE000000000000oooo05EEE@2ZZZX00P1EEED01`2ZZZX0EEEE0:ZZ
ZP1EEED0000005EEE@0000000P1EEED20:ZZZP030000003oool0oooo00/0oooo2P3AcJT=0?ooo`06
0000001EEED0EEEE0?ooo`2ZZZX000000P2ZZZX02@1EEED000000:ZZZP3oool0ZZZZ0000001EEED0
ZZZZ0?ooo`040:ZZZP030000002ZZZX000000080ZZZZ00/0oooo0:ZZZP2ZZZX0oooo0:ZZZP3oool0
ZZZZ05EEE@000000ZZZZ0?ooo`020000000305EEE@000000ZZZZ0080000000@0oooo0000001EEED0
00003@3oool:0=7=Z@d0oooo00<000000?ooo`3oool0102ZZZX205EEE@040:ZZZP3oool0ZZZZ0?oo
o`80ZZZZ00P0oooo0:ZZZP3oool0oooo0:ZZZP1EEED000000:ZZZP80EEEE00<0ZZZZ0000001EEED0
0P2ZZZX00`3oool0ZZZZ0:ZZZP020:ZZZP050?ooo`2ZZZX0ZZZZ0:ZZZP1EEED01@2ZZZX20?ooo`03
0000003oool0oooo00/0oooo2P3AcJT=0?ooo`0:0000003oool0ZZZZ0000002ZZZX000000:ZZZP1E
EED0000005EEE@80oooo00<0EEEE0000001EEED00`0000000`2ZZZX0oooo0?ooo`030?ooo`030:ZZ
ZP3oool0EEEE0080oooo00<0EEEE0000000000000P1EEED020000000EEEE0?ooo`3oool0EEEE0000
003oool0ZZZZ0`0000000`1EEED0oooo0000000=0?ooo`X0dLfY3@3oool010000000ZZZZ0000002Z
ZZX2000000030:ZZZP3oool000000080000000L0ZZZZ000000000000ZZZZ0000001EEED0000000<0
oooo00@000000?ooo`000000EEEE103oool0102ZZZX0000005EEE@0000020:ZZZP030000002ZZZX0
ZZZZ008000000P2ZZZX2000000040:ZZZP000000ZZZZ000000d0oooo303AcJT000/0dLfY3P3oool0
2@000000oooo0000003oool000000?ooo`2ZZZX000000:ZZZP0305EEE@80000000@0EEEE0:ZZZP2Z
ZZX0ZZZZ0P1EEED00`3oool0ZZZZ0:ZZZP020:ZZZP030?ooo`1EEED0EEEE00<0ZZZZ0`00000305EE
E@060:ZZZP000000EEEE0?ooo`000000EEEE0`00000>0?ooo`X0dLfY3P3oool00`000000EEEE0:ZZ
ZP020?ooo`80ZZZZ00<0EEEE0000000000000P2ZZZX0103oool000000:ZZZP0000020:ZZZP800000
0`2ZZZX00`3oool0ZZZZ0:ZZZP03000000050:ZZZP00000000000000003oool00P2ZZZX200000006
05EEE@2ZZZX0ZZZZ0?ooo`1EEED0ZZZZ0P00000>0?ooo`X0dLfY3P3oool00`000000oooo00000003
05EEE@@0000000<0ZZZZ0000000000000P000000202ZZZX000000000002ZZZX000000?ooo`2ZZZX0
EEEE0P2ZZZX01@3oool000000:ZZZP2ZZZX000000080ZZZZ00<000000:ZZZP0000000P2ZZZX30000
0080EEEE0P0000000`1EEED000000?ooo`0=0?ooo`X0dLfY3P3oool020000000ZZZZ0:ZZZP2ZZZX0
oooo05EEE@2ZZZX0oooo101EEED00`2ZZZX0EEEE0:ZZZP020:ZZZP<0EEEE00D000000:ZZZP1EEED0
EEEE0:ZZZP0305EEE@@0ZZZZ00<0EEEE0?ooo`1EEED00`1EEED0103oool0000005EEE@3oool20:ZZ
ZP8000003P3oool:0=7=Z@h0oooo0`0000000`3oool000000:ZZZP0300000080oooo0P1EEED0103o
ool000000?ooo`1EEED2000000030:ZZZP00000000000080ZZZZ0P000000102ZZZX000000:ZZZP1E
EED30?ooo`80EEEE00P0oooo000000000000000005EEE@2ZZZX000000?ooo`<000003P3oool<0=7=
Z@002`3AcJT@0?ooo`050:ZZZP1EEED0oooo0:ZZZP0000000P3oool01P000000EEEE0000003oool0
ZZZZ0?ooo`80000000<0oooo0000001EEED01@1EEED00`3oool0EEEE000000030000000405EEE@2Z
ZZX0oooo00000080EEEE0P3oool01P000000ZZZZ0?ooo`1EEED0ZZZZ000000l0oooo2P3AcJT@0?oo
o`050000001EEED0EEEE0:ZZZP3oool0100000040:ZZZP80oooo0`2ZZZX0103oool0ZZZZ0:ZZZP00
00040:ZZZP0305EEE@3oool0oooo0080ZZZZ00<000000:ZZZP0000000`0000020:ZZZP0405EEE@2Z
ZZX00000000000l0oooo2P3AcJT?0?ooo`<0ZZZZ00<0EEEE0:ZZZP2ZZZX00P2ZZZX00`3oool0EEEE
0?ooo`020:ZZZP030?ooo`1EEED0oooo0080ZZZZ103oool0101EEED0oooo0?ooo`3oool20:ZZZP03
0?ooo`1EEED0ZZZZ0080ZZZZ00<0oooo05EEE@2ZZZX0102ZZZX0101EEED0ZZZZ0:ZZZP00000?0?oo
o`X0dLfY403oool00`1EEED0000005EEE@020:ZZZP060000001EEED0000005EEE@000000ZZZZ0`1E
EED01`2ZZZX0EEEE0?ooo`1EEED0oooo0:ZZZP1EEED00P2ZZZX205EEE@050?ooo`1EEED0ZZZZ05EE
E@2ZZZX00P1EEED01@000000EEEE05EEE@1EEED000000080ZZZZ00@0EEEE0?ooo`1EEED000003`3o
ool:0=7=Z@l0oooo00H0ZZZZ0?ooo`3oool0oooo0:ZZZP0000020?ooo`80000000<0ZZZZ0000002Z
ZZX00P0000000`2ZZZX0oooo0?ooo`03000000030?ooo`00000000000080000000<0oooo0:ZZZP2Z
ZZX00P0000030:ZZZP040000002ZZZX0oooo0?ooo`80ZZZZ0`3oool00`000000oooo0?ooo`0=0?oo
o``0dLfY000;0=7=ZA00oooo00L0000005EEE@1EEED0EEEE0?ooo`1EEED0oooo0080000000<0oooo
05EEE@2ZZZX01@1EEED20:ZZZP80oooo00@0ZZZZ0?ooo`2ZZZX0ZZZZ1@1EEED01P2ZZZX0EEEE0?oo
o`000000ZZZZ0?ooo`@0EEEE0P00000@0?ooo`X0dLfY403oool00`000000EEEE0:ZZZP020:ZZZP03
0?ooo`2ZZZX0oooo0080ZZZZ00@0EEEE0:ZZZP1EEED000000`2ZZZX00`3oool0ZZZZ0:ZZZP0205EE
E@030:ZZZP3oool0oooo00<0ZZZZ0P0000000`2ZZZX0EEEE0:ZZZP030:ZZZP040?ooo`2ZZZX0ZZZZ
0:ZZZP800000403oool:0=7=ZA00oooo00@000000:ZZZP3oool0oooo1@2ZZZX00`3oool0EEEE0:ZZ
ZP03000000030:ZZZP3oool000000080000000<0oooo0:ZZZP0000000P0000020?ooo`80000000H0
oooo0:ZZZP2ZZZX0oooo0:ZZZP1EEED30:ZZZP<0oooo00<000000?ooo`3oool03P3oool:0=7=ZA00
oooo00T0000005EEE@1EEED0EEEE0:ZZZP1EEED0ZZZZ05EEE@0000001@2ZZZX305EEE@0;0?ooo`00
000000000?ooo`1EEED000000:ZZZP3oool0EEEE0:ZZZP1EEED00`2ZZZX01`3oool0ZZZZ0000001E
EED0ZZZZ05EEE@0000000P1EEED00`3oool000000?ooo`0?0?ooo`X0dLfY403oool00`000000ZZZZ
000000020?ooo`<0000000<0ZZZZ05EEE@1EEED0100000020?ooo`0405EEE@00000000000:ZZZP80
00000P1EEED02@3oool0ZZZZ000000000000ZZZZ0000002ZZZX0EEEE0:ZZZP0300000080oooo00<0
00000:ZZZP000000403oool<0=7=Z@002`3AcJTB0?ooo`0505EEE@000000EEEE05EEE@2ZZZX00P3o
ool20:ZZZP80000000<0EEEE000000000000101EEED20?ooo`D0EEEE00<0000005EEE@1EEED00P00
00002@2ZZZX0oooo0:ZZZP2ZZZX0EEEE0?ooo`000000EEEE0000000A0?ooo`X0dLfY4P3oool01@00
0000ZZZZ0:ZZZP2ZZZX000000080ZZZZ00@0oooo0000003oool0EEEE0P0000001P3oool0ZZZZ0:ZZ
ZP2ZZZX000000?ooo`<000000`2ZZZX2000000050:ZZZP3oool000000?ooo`2ZZZX00P0000000`2Z
ZZX0oooo0:ZZZP0200000140oooo2P3AcJTA0?ooo`0305EEE@2ZZZX0EEEE00<0EEEE0P3oool0201E
EED000000000003oool0ZZZZ0?ooo`000000EEEE0P3oool01P1EEED000000:ZZZP1EEED0ZZZZ0?oo
o`80EEEE00<0oooo0:ZZZP1EEED00P0000000`1EEED0oooo05EEE@0405EEE@030:ZZZP000000oooo
0100oooo2P3AcJTA0?ooo`040000002ZZZX000000?ooo`80EEEE00L0ZZZZ05EEE@3oool0oooo05EE
E@3oool0EEEE008000000P1EEED01@2ZZZX0oooo05EEE@1EEED0oooo00<0EEEE0P0000000`1EEED0
oooo05EEE@020?ooo`0805EEE@2ZZZX0EEEE05EEE@3oool000000:ZZZP00000A0?ooo`X0dLfY4@3o
ool00`000000oooo0?ooo`020?ooo`060000003oool0ZZZZ0:ZZZP1EEED0oooo0`2ZZZX200000006
0:ZZZP000000oooo0?ooo`2ZZZX0oooo0P2ZZZX00`000000EEEE0:ZZZP020:ZZZP060?ooo`000000
ZZZZ0:ZZZP3oool00000103oool00`000000oooo0?ooo`0?0?ooo``0dLfY000;0=7=ZA80oooo0`00
00001P1EEED0oooo0:ZZZP000000EEEE0:ZZZP80EEEE0P2ZZZX405EEE@050000003oool0EEEE0000
002ZZZX00P1EEED30:ZZZP80EEEE00L0ZZZZ05EEE@000000ZZZZ0?ooo`1EEED0oooo008000004P3o
ool:0=7=ZA80oooo0P0000001`2ZZZX0EEEE05EEE@3oool000000?ooo`2ZZZX0103oool00`2ZZZX0
00000?ooo`020:ZZZP060000002ZZZX0ZZZZ0000003oool000000`3oool01@000000oooo0:ZZZP3o
ool0000000@0EEEE0P00000B0?ooo`X0dLfY4P3oool2000000030?ooo`000000ZZZZ00<000000`1E
EED01P3oool0EEEE0000002ZZZX000000:ZZZP@0EEEE00<0oooo0000002ZZZX00P1EEED0103oool0
EEEE05EEE@1EEED3000000030:ZZZP0000000000008000004P3oool:0=7=ZA80oooo0P0000020:ZZ
ZP0705EEE@000000EEEE05EEE@000000ZZZZ0?ooo`0205EEE@<000000P2ZZZX00`3oool0EEEE0:ZZ
ZP03000000060:ZZZP1EEED0EEEE0?ooo`2ZZZX000000P1EEED0102ZZZX0EEEE0:ZZZP2ZZZX20000
0180oooo2P3AcJTB0?ooo`<000000P3oool01@2ZZZX0EEEE0?ooo`000000oooo00<000000P2ZZZX0
1P000000ZZZZ0:ZZZP3oool000000:ZZZP80000000X0ZZZZ00000000000000000:ZZZP3oool00000
0?ooo`1EEED000000P3oool300000180oooo303AcJT000/0dLfY4`3oool02@000000ZZZZ05EEE@1E
EED0oooo05EEE@2ZZZX000000:ZZZP04000000030:ZZZP000000oooo0080EEEE00D0ZZZZ05EEE@00
000000000:ZZZP0300000080ZZZZ00@0EEEE0:ZZZP1EEED0oooo0P1EEED00`3oool000000?ooo`0B
0?ooo`X0dLfY4`3oool2000000030:ZZZP1EEED0ZZZZ0080ZZZZ00H000000:ZZZP2ZZZX000000:ZZ
ZP0000020?ooo`050:ZZZP000000ZZZZ0?ooo`0000000`3oool20:ZZZP040000002ZZZX0ZZZZ0000
0080ZZZZ00D0000005EEE@2ZZZX0oooo0000000C0?ooo`X0dLfY4`3oool00`000000oooo0?ooo`04
0:ZZZP0505EEE@2ZZZX0EEEE0:ZZZP1EEED00P2ZZZX00`3oool00000000000030000000505EEE@3o
ool0ZZZZ0:ZZZP1EEED0202ZZZX20?ooo`030000003oool0oooo0140oooo2P3AcJTC0?ooo`040000
001EEED0oooo00000080ZZZZ00H0EEEE0?ooo`1EEED0ZZZZ05EEE@2ZZZX20?ooo`030:ZZZP3oool0
oooo0080EEEE00@0oooo05EEE@2ZZZX0oooo0P2ZZZX01@1EEED0000005EEE@2ZZZX0EEEE0080ZZZZ
00@000000?ooo`3oool000004`3oool:0=7=ZA<0oooo00@000000?ooo`3oool0oooo0P2ZZZX30000
000305EEE@2ZZZX0oooo0080000000<0oooo0000000000000P3oool010000000oooo0?ooo`000002
0?ooo`80ZZZZ0`0000001P2ZZZX0oooo0?ooo`3oool0ZZZZ000001<0oooo303AcJT000/0dLfY503o
ool0102ZZZX0EEEE05EEE@2ZZZX205EEE@030:ZZZP3oool0ZZZZ00@0ZZZZ00H0oooo0000002ZZZX0
EEEE0000002ZZZX20?ooo`D0ZZZZ00D0oooo05EEE@1EEED0EEEE0:ZZZP0205EEE@030000003oool0
oooo0180oooo2P3AcJTD0?ooo`0405EEE@000000EEEE0?ooo`80ZZZZ00D0oooo0:ZZZP3oool00000
0?ooo`020:ZZZP080000002ZZZX0oooo0000001EEED0oooo0:ZZZP0000020:ZZZP050?ooo`000000
ZZZZ0:ZZZP3oool00`2ZZZX00`1EEED000000000000D0?ooo`X0dLfY503oool00`1EEED0oooo0000
000305EEE@<0000000<0oooo0000000000000P1EEED60:ZZZP80EEEE00@0ZZZZ0000003oool0ZZZZ
0P00000205EEE@80000000<0oooo0000003oool04`3oool:0=7=ZA@0oooo00/000000:ZZZP1EEED0
oooo05EEE@3oool000000:ZZZP1EEED0oooo05EEE@030?ooo`80EEEE00@0oooo05EEE@1EEED0EEEE
0`3oool02`1EEED0oooo0?ooo`2ZZZX0EEEE0?ooo`1EEED0oooo05EEE@2ZZZX0000001@0oooo2P3A
cJTD0?ooo`060000001EEED0EEEE0000003oool000000P3oool00`2ZZZX0000005EEE@04000000@0
oooo00`0ZZZZ000000000000000005EEE@000000ZZZZ0?ooo`2ZZZX000000?ooo`00000205EEE@03
0000003oool0oooo0180oooo303AcJT000/0dLfY5@3oool010000000oooo0000003oool205EEE@80
oooo00<0EEEE0?ooo`3oool00P3oool20:ZZZP80EEEE00L0ZZZZ05EEE@3oool0oooo05EEE@3oool0
EEEE0080oooo00H0ZZZZ05EEE@3oool0EEEE0?ooo`00000E0?ooo`X0dLfY5@3oool00`000000oooo
0:ZZZP020?ooo`0=0:ZZZP3oool000000:ZZZP000000oooo0000002ZZZX0000005EEE@2ZZZX0oooo
05EEE@020:ZZZP040000003oool000000:ZZZP80oooo00H0ZZZZ0?ooo`3oool000000?ooo`00000E
0?ooo`X0dLfY5@3oool70000000305EEE@2ZZZX0EEEE0080000000@0oooo0:ZZZP2ZZZX0EEEE0`2Z
ZZX0203oool0000005EEE@1EEED0ZZZZ05EEE@000000ZZZZ0P0000000`1EEED000000000000E0?oo
o`X0dLfY5@3oool3000000040?ooo`2ZZZX0EEEE05EEE@D0ZZZZ00@0EEEE0:ZZZP2ZZZX0EEEE0`2Z
ZZX00`1EEED0ZZZZ05EEE@020:ZZZP060?ooo`1EEED0EEEE0:ZZZP3oool0ZZZZ0P00000E0?ooo`X0
dLfY5@3oool2000000<0oooo00/000000?ooo`2ZZZX000000:ZZZP1EEED000000?ooo`000000EEEE
0000000205EEE@070000003oool0000005EEE@2ZZZX0000005EEE@050?ooo`8000005@3oool<0=7=
Z@002`3AcJTF0?ooo`030000002ZZZX0ZZZZ0080EEEE00<0ZZZZ05EEE@2ZZZX00P1EEED20:ZZZP80
EEEE00@0ZZZZ05EEE@1EEED0EEEE0`2ZZZX0101EEED0ZZZZ0:ZZZP2ZZZX205EEE@80ZZZZ00<00000
0?ooo`3oool0503oool:0=7=ZAH0oooo0P000000101EEED0oooo0:ZZZP0000020:ZZZP<0oooo00D0
ZZZZ000000000000EEEE0?ooo`02000000040:ZZZP3oool0oooo0?ooo`80ZZZZ0P000000103oool0
EEEE05EEE@00000F0?ooo`X0dLfY5P3oool010000000ZZZZ0?ooo`3oool20:ZZZP0805EEE@2ZZZX0
00000:ZZZP3oool0EEEE0000002ZZZX2000000030:ZZZP000000EEEE0080oooo00<000000:ZZZP2Z
ZZX00P2ZZZX30?ooo`030000003oool0oooo01@0oooo2P3AcJTF0?ooo`030000001EEED0ZZZZ00<0
000000D0ZZZZ05EEE@1EEED0ZZZZ0?ooo`040:ZZZP060000002ZZZX000000:ZZZP3oool0ZZZZ0`1E
EED01P000000ZZZZ0000002ZZZX0oooo000001H0oooo2P3AcJTF0?ooo`<0000000@0ZZZZ00000000
0000ZZZZ0P3oool01@000000oooo0?ooo`2ZZZX000000080ZZZZ00D000000?ooo`3oool0oooo05EE
E@020?ooo`070:ZZZP00000000000:ZZZP000000ZZZZ0000000F0?ooo``0dLfY000;0=7=ZAL0oooo
00@000000?ooo`2ZZZX0EEEE0`3oool205EEE@80oooo0P1EEED0102ZZZX0EEEE05EEE@0000020?oo
o`070000001EEED0oooo0:ZZZP3oool0EEEE0:ZZZP0I0?ooo`X0dLfY5`3oool00`000000oooo0000
000205EEE@@0ZZZZ00D0oooo0000002ZZZX000000?ooo`02000000040:ZZZP000000oooo05EEE@<0
ZZZZ00<0EEEE0:ZZZP0000006@3oool:0=7=ZAL0oooo00H000000:ZZZP1EEED0ZZZZ05EEE@2ZZZX2
05EEE@080?ooo`000000000005EEE@3oool0000005EEE@3oool3000000080:ZZZP1EEED0EEEE0:ZZ
ZP1EEED0ZZZZ05EEE@2ZZZXH0?ooo`X0dLfY5`3oool00`000000oooo05EEE@02000000050:ZZZP3o
ool0oooo0:ZZZP3oool00P1EEED0102ZZZX0000005EEE@2ZZZX205EEE@080?ooo`2ZZZX0oooo0?oo
o`2ZZZX000000?ooo`1EEEDI0?ooo`X0dLfY5`3oool00`000000ZZZZ0?ooo`020?ooo`090:ZZZP00
0000oooo05EEE@000000EEEE0000002ZZZX000000080ZZZZ00L0000005EEE@000000EEEE0?ooo`00
0000ZZZZ00<0oooo00<0ZZZZ0?ooo`3oool05P3oool<0=7=Z@002`3AcJTH0?ooo`060000002ZZZX0
EEEE0:ZZZP3oool000000P2ZZZX010000000oooo05EEE@1EEED20000000405EEE@2ZZZX0oooo0000
0080ZZZZ00H000000:ZZZP2ZZZX0EEEE0:ZZZP00000H0?ooo`X0dLfY603oool01P000000EEEE05EE
E@2ZZZX000000:ZZZP8000000P2ZZZX01@3oool000000?ooo`3oool0000000<0ZZZZ00P0oooo0000
002ZZZX000000:ZZZP000000EEEE000001P0oooo2P3AcJTH0?ooo`80000000<0oooo000000000000
0P0000000`1EEED0oooo0:ZZZP0205EEE@80ZZZZ00@0EEEE0?ooo`2ZZZX0oooo0`0000000`2ZZZX0
000000000002000001P0oooo2P3AcJTH0?ooo`80000000@0EEEE0?ooo`2ZZZX000001P1EEED20:ZZ
ZP0:05EEE@3oool0EEEE05EEE@2ZZZX0EEEE0000002ZZZX0oooo0:ZZZP800000603oool:0=7=ZAP0
oooo0P000000101EEED000000?ooo`0000040:ZZZP<0oooo00<0EEEE0?ooo`0000000P2ZZZX00`00
0000ZZZZ000000020000000305EEE@000000000001P0oooo303AcJT000/0dLfY6@3oool02P000000
EEEE05EEE@1EEED0oooo0:ZZZP3oool0ZZZZ0?ooo`0000040:ZZZP030000003oool0ZZZZ0080ZZZZ
00<0oooo05EEE@1EEED00P00000I0?ooo`X0dLfY6@3oool00`000000EEEE0:ZZZP020:ZZZP80oooo
00D0ZZZZ0000002ZZZX0ZZZZ000000020:ZZZP80000000<0ZZZZ0?ooo`3oool00`2ZZZX2000001T0
oooo2P3AcJTI0?ooo`030000003oool0oooo00@0ZZZZ0P1EEED20:ZZZP030000001EEED0ZZZZ00<0
EEEE102ZZZX20?ooo`030000003oool0oooo01L0oooo2P3AcJTI0?ooo`060000001EEED0EEEE0:ZZ
ZP1EEED0oooo0P0000001@1EEED0ZZZZ0000001EEED0oooo0080000000@0EEEE0000001EEED0oooo
0`1EEED00`3oool000000?ooo`0H0?ooo`X0dLfY6@3oool00`000000ZZZZ000000020?ooo`800000
00<0oooo0000000000000P2ZZZX01@000000ZZZZ000000000000oooo008000000P3oool00`000000
ZZZZ0000000I0?ooo``0dLfY000;0=7=ZAX0oooo00<000000:ZZZP2ZZZX00P1EEED0103oool0EEEE
05EEE@1EEED40:ZZZP040?ooo`1EEED0EEEE00000080EEEE0P2ZZZXK0?ooo`X0dLfY6P3oool00`00
0000EEEE05EEE@020?ooo`D000000P2ZZZX4000000050:ZZZP3oool0oooo0000001EEED06`3oool:
0=7=ZAX0oooo00D000000:ZZZP2ZZZX0ZZZZ05EEE@050:ZZZP030000001EEED0ZZZZ00@0ZZZZ00@0
EEEE0:ZZZP2ZZZX0ZZZZ6`3oool:0=7=ZAX0oooo00<000000?ooo`2ZZZX00`0000020:ZZZP80EEEE
0P2ZZZX205EEE@80ZZZZ00@0EEEE000000000000EEEE703oool:0=7=ZAX0oooo00@000000:ZZZP00
0000ZZZZ0P00000205EEE@80ZZZZ0P3oool0102ZZZX0000005EEE@1EEED2000000030:ZZZP000000
ZZZZ01/0oooo303AcJT000/0dLfY6`3oool01`000000oooo0000001EEED0ZZZZ0000002ZZZX01@1E
EED20:ZZZP030000003oool0EEEE00<000006`3oool:0=7=ZA/0oooo00@0000005EEE@2ZZZX0EEEE
1@0000000`2ZZZX000000000000300000080EEEE00<0ZZZZ0000000000006`3oool:0=7=ZA/0oooo
00D0000005EEE@00000000000:ZZZP030000000505EEE@2ZZZX0ZZZZ05EEE@2ZZZX01`00000K0?oo
o`X0dLfY6`3oool01@000000ZZZZ0:ZZZP2ZZZX0EEEE0080oooo00<0EEEE0000000000000P000000
0`1EEED0oooo0?ooo`030:ZZZP8000006`3oool:0=7=ZA/0oooo0`0000001`3oool000000:ZZZP2Z
ZZX0oooo0000002ZZZX00`0000020:ZZZP80oooo0`00000K0?ooo``0dLfY000;0=7=ZA`0oooo00<0
00000:ZZZP1EEED00P2ZZZX00`1EEED0ZZZZ0?ooo`020:ZZZP80oooo00D0EEEE0:ZZZP1EEED0EEEE
0:ZZZP0M0?ooo`X0dLfY703oool010000000EEEE0000002ZZZX40?ooo`80000000L0oooo0:ZZZP3o
ool0oooo05EEE@000000EEEE01d0oooo2P3AcJTL0?ooo`040000001EEED0ZZZZ05EEE@80000000<0
EEEE0:ZZZP1EEED00P2ZZZX01P1EEED000000000001EEED0ZZZZ05EEEAd0oooo2P3AcJTL0?ooo`80
000000<0ZZZZ0?ooo`1EEED00P2ZZZX00`1EEED0ZZZZ05EEE@0205EEE@050:ZZZP1EEED0EEEE0:ZZ
ZP0000007@3oool:0=7=ZA`0oooo0P000000101EEED0000000000000000205EEE@030:ZZZP000000
EEEE00<000000P1EEED00`000000oooo0?ooo`0K0?ooo``0dLfY000;0=7=ZAd0oooo0P00000305EE
E@060:ZZZP3oool000000000003oool0ZZZZ0`1EEED2000001d0oooo2P3AcJTM0?ooo`8000000P2Z
ZZX2000000D0ZZZZ00<000000:ZZZP1EEED00P00000M0?ooo`X0dLfY7@3oool00`000000ZZZZ0:ZZ
ZP020:ZZZP0405EEE@2ZZZX00000000000@0ZZZZ00<0EEEE0:ZZZP0000007@3oool:0=7=ZAd0oooo
00D000000?ooo`1EEED0EEEE000000030:ZZZP0405EEE@2ZZZX0oooo00000080EEEE00<0oooo0000
003oool0703oool:0=7=ZAd0oooo00<000000:ZZZP0000000P3oool20:ZZZP040?ooo`000000ZZZZ
00000080oooo0P2ZZZX00`000000oooo0?ooo`0K0?ooo``0dLfY000;0=7=ZAh0oooo00<0000005EE
E@0000000`3oool0202ZZZX0oooo0?ooo`1EEED0oooo0000003oool000007P3oool:0=7=ZAh0oooo
0P0000001@2ZZZX0oooo05EEE@2ZZZX0oooo0080ZZZZ0P3oool00`2ZZZX0oooo0000000N0?ooo`X0
dLfY7P3oool2000000030?ooo`000000oooo00@0ZZZZ0P0000000`3oool000000000000N0?ooo`X0
dLfY7P3oool00`000000ZZZZ000000020?ooo`0405EEE@000000000005EEE@80oooo0`00000N0?oo
o`X0dLfY7P3oool010000000oooo0?ooo`3oool200000080oooo00@000000?ooo`3oool0oooo0P00
000N0?ooo``0dLfY000;0=7=ZAl0oooo0P0000002@3oool0EEEE0?ooo`000000EEEE0?ooo`000000
oooo0000000P0?ooo`X0dLfY7`3oool200000080EEEE00L0oooo0:ZZZP2ZZZX0oooo0:ZZZP1EEED0
00000200oooo2P3AcJTO0?ooo`030000001EEED0oooo00H0000000<0oooo05EEE@3oool07`3oool:
0=7=ZAl0oooo0P0000020:ZZZP0405EEE@2ZZZX0EEEE05EEE@80ZZZZ00<000000?ooo`3oool07P3o
ool:0=7=ZAl0oooo0`0000050?ooo`<00000803oool<0=7=Z@002`3AcJTP0?ooo`0:0000003oool0
EEEE05EEE@000000oooo05EEE@2ZZZX0oooo00000200oooo2P3AcJTP0?ooo`050000003oool0ZZZZ
05EEE@3oool00P1EEED00`000000oooo0000000P0?ooo`X0dLfY803oool00`000000ZZZZ0:ZZZP06
0:ZZZP030000003oool0oooo01h0oooo2P3AcJTP0?ooo`0:0000003oool0oooo0000003oool0ZZZZ
0000001EEED0oooo00000200oooo2P3AcJTP0?ooo`030000002ZZZX0oooo00D0oooo00<0ZZZZ0000
003oool07`3oool<0=7=Z@002`3AcJTQ0?ooo`030000001EEED0EEEE0080ZZZZ00<0EEEE0:ZZZP00
00008@3oool:0=7=ZB40oooo0P0000000`1EEED000000:ZZZP0205EEE@030000003oool0oooo01l0
oooo2P3AcJTQ0?ooo`040000001EEED000000:ZZZP@000008@3oool:0=7=ZB40oooo00<000000:ZZ
ZP1EEED00P3oool00`1EEED000000000000Q0?ooo`X0dLfY8@3oool010000000EEEE0000001EEED4
00000240oooo303AcJT000/0dLfY8P3oool010000000oooo0000001EEEDT0?ooo`X0dLfY8P3oool0
10000000oooo0:ZZZP00000T0?ooo`X0dLfY8P3oool01@000000EEEE05EEE@2ZZZX0EEEE02<0oooo
2P3AcJTR0?ooo`<0000000<0EEEE0000003oool08P3oool:0=7=ZB80oooo0P0000000`1EEED0oooo
0000000S0?ooo``0dLfY000;0=7=ZB<0oooo00@000000:ZZZP2ZZZX000008`3oool:0=7=ZB<0oooo
0P0000000`1EEED000000?ooo`0R0?ooo`X0dLfY8`3oool010000000EEEE0:ZZZP00000S0?ooo`X0
dLfY8`3oool010000000ZZZZ0?ooo`00000S0?ooo`X0dLfY8`3oool2000000030:ZZZP000000oooo
0280oooo303AcJT000/0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0
oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0
oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo``0dLfY003o0=7=ZK80dLfY
003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY000;0=7=Z@070?oo
o`1EEED0EEEE05EEE@000000oooo05EEE@02000000040:ZZZP000000EEEE0:ZZZP@0EEEE0`000000
201EEED000000:ZZZP3oool000000:ZZZP000000ZZZZ0P0000001P1EEED0ZZZZ05EEE@2ZZZX0EEEE
00000080oooo0P0000001@2ZZZX0EEEE0?ooo`1EEED000000080ZZZZ00L000000:ZZZP000000oooo
0:ZZZP000000EEEE0080000000<0ZZZZ05EEE@1EEED0101EEED4000000030:ZZZP3oool0ZZZZ0080
EEEE00<000000?ooo`3AcJT02@3AcJT00`3oool0EEEE0:ZZZP030:ZZZP030000002ZZZX0EEEE0080
oooo0`0000020:ZZZP030000001EEED0oooo00<0ZZZZ00@0oooo0:ZZZP00000000000`3oool01P1E
EED0ZZZZ0?ooo`2ZZZX0oooo0:ZZZP80oooo00P0ZZZZ0?ooo`1EEED0oooo0:ZZZP3oool0ZZZZ05EE
E@<0oooo0P0000000`1EEED0oooo0:ZZZP020:ZZZP80oooo0P0000001`2ZZZX0000005EEE@000000
oooo0000001EEED01P2ZZZX00`000000oooo0=7=Z@090=7=Z@050?ooo`000000000005EEE@000000
0P1EEED01@2ZZZX0EEEE0?ooo`3oool000000080oooo0`0000001P1EEED000000?ooo`2ZZZX0EEEE
0?ooo`80ZZZZ00H000000:ZZZP2ZZZX0ZZZZ05EEE@2ZZZX205EEE@040:ZZZP000000EEEE0?ooo`80
EEEE00H000000:ZZZP1EEED0EEEE0:ZZZP1EEED20:ZZZP80000000@0ZZZZ0000003oool0EEEE0P3o
ool5000000070?ooo`00000000000?ooo`2ZZZX0EEEE0:ZZZP0205EEE@050000001EEED000000000
003oool02P3AcJT02@3oool0ZZZZ05EEE@000000EEEE0:ZZZP1EEED000000:ZZZP020?ooo`800000
00@0EEEE0?ooo`1EEED0EEEE0P000000101EEED0ZZZZ0?ooo`1EEED20?ooo`80EEEE0`2ZZZX01@00
0000oooo05EEE@2ZZZX000000080oooo00@0EEEE0?ooo`1EEED0ZZZZ0P1EEED010000000ZZZZ0?oo
o`2ZZZX205EEE@040?ooo`2ZZZX0EEEE0?ooo`80EEEE00H0000005EEE@1EEED0ZZZZ0?ooo`1EEED2
00000080oooo00T0ZZZZ000000000000ZZZZ05EEE@000000EEEE0000003oool02P3AcJT00`3oool0
00000?ooo`02000000050?ooo`1EEED0oooo0?ooo`1EEED00P3oool01@000000oooo05EEE@2ZZZX0
oooo00<0EEEE0`3oool0202ZZZX000000000001EEED0ZZZZ0000002ZZZX0oooo0P1EEED40:ZZZP04
0?ooo`2ZZZX000000:ZZZP80EEEE00D0oooo0:ZZZP1EEED0ZZZZ0?ooo`02000000<0oooo0`1EEED3
0?ooo`0305EEE@3oool0ZZZZ0080oooo00@0ZZZZ0?ooo`3oool0EEEE0P3oool010000000oooo0000
003oool<0=7=Z@002`3AcJT01`3oool0ZZZZ0000003oool0EEEE0000002ZZZX00`3oool02@2ZZZX0
oooo0:ZZZP1EEED0ZZZZ05EEE@3oool0ZZZZ000000030:ZZZP080000001EEED000000?ooo`1EEED0
oooo05EEE@0000020?ooo`80EEEE00<0ZZZZ0?ooo`3oool00P3oool305EEE@80oooo00P000000?oo
o`3oool000000?ooo`000000EEEE000000<0ZZZZ00<000000:ZZZP3oool00P2ZZZX00`1EEED00000
0?ooo`020:ZZZP80oooo00D0EEEE0000003oool0oooo000000020?ooo`X0dLfY00L0oooo0:ZZZP1E
EED000000:ZZZP000000oooo0080ZZZZ0P1EEED20:ZZZP0405EEE@2ZZZX0oooo00000080ZZZZ00H0
000005EEE@1EEED0EEEE0?ooo`2ZZZX50?ooo`<0000000<0EEEE0:ZZZP2ZZZX00P0000000`2ZZZX0
oooo05EEE@03000000D0oooo0P2ZZZX205EEE@8000000P2ZZZX2000000050:ZZZP1EEED0ZZZZ0:ZZ
ZP1EEED00`2ZZZX20000000305EEE@000000EEEE0080oooo2P3AcJT00`3oool0ZZZZ0?ooo`060000
000505EEE@2ZZZX0EEEE0:ZZZP000000102ZZZX30?ooo`0305EEE@2ZZZX0000000<0EEEE00D00000
05EEE@000000000005EEE@02000000040?ooo`000000oooo0?ooo`L0000000<0EEEE0000001EEED0
0`1EEED00`2ZZZX0EEEE0?ooo`020?ooo`0905EEE@2ZZZX0EEEE0:ZZZP000000ZZZZ05EEE@2ZZZX0
EEEE0080000000@0EEEE0000003oool000000`3oool:0=7=Z@060?ooo`2ZZZX0ZZZZ0:ZZZP3oool0
ZZZZ0P1EEED40?ooo`050000003oool0oooo05EEE@2ZZZX00P1EEED0103oool0EEEE0000001EEED3
0?ooo`0:05EEE@3oool0oooo05EEE@3oool0000005EEE@3oool000000:ZZZP80EEEE00<0ZZZZ0?oo
o`3oool00P1EEED01@3oool0EEEE0?ooo`3oool0000000<0oooo00L0EEEE000000000000oooo05EE
E@3oool0ZZZZ00<0oooo00<0ZZZZ0?ooo`3oool00P3oool0101EEED0ZZZZ0:ZZZP1EEED20:ZZZP80
oooo2P3AcJT00`3oool000000?ooo`020:ZZZP060?ooo`000000oooo0:ZZZP000000oooo0P1EEED0
10000000oooo05EEE@1EEED3000000050?ooo`1EEED0000005EEE@3oool00P2ZZZX00`000000oooo
0?ooo`0405EEE@060000002ZZZX0ZZZZ0000002ZZZX00000101EEED01@3oool000000000001EEED0
ZZZZ0080oooo00<0000005EEE@0000000P000000103oool0EEEE0000003oool20000000905EEE@3o
ool000000:ZZZP3oool000000?ooo`1EEED0ZZZZ00<0oooo303AcJT000/0dLfY0`3oool01@000000
oooo0?ooo`3oool0ZZZZ0080oooo00P0ZZZZ0?ooo`3oool0ZZZZ0000002ZZZX0oooo05EEE@80ZZZZ
00@0EEEE0:ZZZP3oool000000P3oool0101EEED000000000001EEED20?ooo`060000002ZZZX0oooo
0000003oool0EEEE0P000000102ZZZX000000:ZZZP3oool205EEE@8000000P3oool00`000000oooo
0:ZZZP030:ZZZP040000003oool0000000000080ZZZZ00D0oooo0:ZZZP000000oooo0:ZZZP020?oo
o`0305EEE@000000oooo0080oooo2P3AcJT30?ooo`040000002ZZZX000000?ooo`80ZZZZ0P1EEED2
000000050:ZZZP00000000000000002ZZZX00P1EEED20:ZZZP080000003oool0oooo0:ZZZP3oool0
00000:ZZZP3oool20:ZZZP0:0?ooo`2ZZZX0EEEE0?ooo`000000EEEE0?ooo`1EEED0ZZZZ0?ooo`80
ZZZZ00<0oooo0000000000000P2ZZZX0103oool0ZZZZ0000002ZZZX305EEE@@0000000D0ZZZZ0000
00000000EEEE000000030:ZZZP<000000`3oool:0=7=Z@<0oooo0`0000020:ZZZP80000000<0oooo
0000000000000P3oool010000000oooo0000001EEED3000000090:ZZZP3oool0EEEE05EEE@2ZZZX0
000005EEE@000000ZZZZ0080EEEE00<0ZZZZ0000001EEED00P0000000`1EEED000000:ZZZP0205EE
E@050:ZZZP000000oooo0000003oool00P1EEED20:ZZZP070000001EEED0000005EEE@000000oooo
000000030?ooo`060000003oool0oooo0000002ZZZX0EEEE0`0000030?ooo`X0dLfY0`3oool00`00
0000oooo0:ZZZP0505EEE@030000001EEED0oooo0080ZZZZ0`1EEED02@3oool0ZZZZ0?ooo`2ZZZX0
EEEE0:ZZZP1EEED0ZZZZ000000040:ZZZP030?ooo`2ZZZX0oooo0080oooo00D0EEEE0?ooo`3oool0
ZZZZ0?ooo`030:ZZZP0<0?ooo`000000EEEE05EEE@2ZZZX0EEEE0:ZZZP3oool0ZZZZ0?ooo`1EEED0
00000P1EEED0102ZZZX0oooo0:ZZZP00000405EEE@040?ooo`2ZZZX00000000000<0oooo2P3AcJT3
0?ooo`030000003oool000000080EEEE00<0000005EEE@2ZZZX00P3oool01@2ZZZX0EEEE05EEE@00
0000oooo0080ZZZZ00<0EEEE0000000000000P3oool4000000030:ZZZP3oool0000000<0oooo0P00
00000`3oool00000000000040?ooo`030:ZZZP1EEED00000008000000P3oool20000000305EEE@2Z
ZZX0ZZZZ008000000P1EEED0102ZZZX000000?ooo`2ZZZX20000000305EEE@3oool0000000800000
0`3oool<0=7=Z@002`3AcJT40?ooo`80000000D0EEEE0000002ZZZX0ZZZZ0000000205EEE@080000
002ZZZX0000005EEE@2ZZZX0oooo0:ZZZP3oool2000000030:ZZZP00000000000080ZZZZ00P0oooo
05EEE@1EEED0ZZZZ0000002ZZZX0EEEE00000080oooo00<0000005EEE@2ZZZX00P00000205EEE@03
0000002ZZZX0ZZZZ0080000000<0ZZZZ0000000000000P2ZZZX00`3oool0EEEE05EEE@020:ZZZP03
0000001EEED0EEEE0080000000D0ZZZZ0000001EEED000000:ZZZP040?ooo`X0dLfY1@3oool0102Z
ZZX000000000001EEED50:ZZZP030?ooo`2ZZZX0000000@0ZZZZ00<0oooo0:ZZZP0000000`000000
0`3oool000000000000200000080ZZZZ00H0EEEE0:ZZZP3oool0EEEE0:ZZZP3oool20:ZZZP0605EE
E@00000000000:ZZZP3oool0EEEE0`0000000`2ZZZX0oooo0:ZZZP020:ZZZP060?ooo`000000oooo
0?ooo`2ZZZX0EEEE0`2ZZZX00`1EEED00000000000020:ZZZP@0oooo2P3AcJT50?ooo`050000001E
EED0EEEE0000002ZZZX00P1EEED0102ZZZX000000:ZZZP1EEED30000000405EEE@3oool000000000
00<0ZZZZ0P000000101EEED0ZZZZ0000001EEED2000000040?ooo`000000ZZZZ0?ooo`H0000000<0
ZZZZ0?ooo`0000000`2ZZZX3000000050:ZZZP1EEED000000?ooo`0000000P2ZZZX01`000000EEEE
05EEE@1EEED0ZZZZ0000001EEED00P0000000`2ZZZX0oooo0?ooo`020?ooo`X0dLfY103oool20000
000405EEE@2ZZZX0EEEE0:ZZZP80EEEE00<0oooo0000000000000P3oool20:ZZZP040000001EEED0
000005EEE@80oooo0100EEEE0?ooo`2ZZZX0000005EEE@000000EEEE0000001EEED0ZZZZ05EEE@3o
ool0000005EEE@000000EEEE0`000000201EEED000000:ZZZP2ZZZX0EEEE0?ooo`000000EEEE0`00
0000102ZZZX000000?ooo`1EEED2000000030?ooo`1EEED0EEEE0080EEEE00@0ZZZZ05EEE@000000
ZZZZ103oool:0=7=Z@D0oooo0P2ZZZX010000000EEEE0000000000020:ZZZP<0000000H0oooo0000
002ZZZX000000?ooo`0000060?ooo`030000001EEED0EEEE0080ZZZZ00P0EEEE0?ooo`000000ZZZZ
0?ooo`000000ZZZZ05EEE@80ZZZZ0P1EEED00`000000oooo000000040?ooo`<0000000<0ZZZZ0?oo
o`3oool00`0000020:ZZZP80000000D0EEEE0000001EEED0ZZZZ000000040?ooo``0dLfY000;0=7=
Z@@0oooo00D0EEEE0000002ZZZX000000:ZZZP0205EEE@070:ZZZP1EEED0EEEE0:ZZZP1EEED0oooo
0000000305EEE@040000003oool0oooo0?ooo`<0ZZZZ0P3oool01@000000ZZZZ0?ooo`3oool0ZZZZ
00@0oooo00D0EEEE0?ooo`3oool0ZZZZ000000020?ooo`070:ZZZP3oool0ZZZZ0?ooo`1EEED0oooo
0000000305EEE@070:ZZZP3oool000000:ZZZP1EEED0oooo0:ZZZP0205EEE@040:ZZZP000000oooo
000000D0oooo2P3AcJT40?ooo`0505EEE@000000oooo0?ooo`2ZZZX00P0000000`1EEED0oooo0:ZZ
ZP020:ZZZP80EEEE0`0000020:ZZZP050000002ZZZX0oooo0000002ZZZX00P3oool0102ZZZX0EEEE
05EEE@1EEED20?ooo`040:ZZZP1EEED0oooo00000080EEEE00<0oooo0:ZZZP3oool00P2ZZZX20?oo
o`050:ZZZP3oool0ZZZZ0:ZZZP1EEED00P0000000`2ZZZX0EEEE000000030:ZZZP0705EEE@000000
EEEE0:ZZZP3oool0ZZZZ000000050?ooo`X0dLfY103oool01@1EEED0000005EEE@3oool0ZZZZ0080
000000@0EEEE0000002ZZZX0oooo0P2ZZZX205EEE@060?ooo`2ZZZX000000?ooo`000000ZZZZ0P00
0000103oool0EEEE0000001EEED20:ZZZP0805EEE@2ZZZX0000005EEE@3oool000000:ZZZP1EEED2
0:ZZZP0405EEE@00000000000?ooo`80000000H0ZZZZ0000003oool000000:ZZZP3oool205EEE@80
ZZZZ00@0oooo0:ZZZP000000EEEE0P000000102ZZZX0oooo0:ZZZP0000050?ooo`X0dLfY103oool2
05EEE@060000001EEED0000005EEE@3oool000000P1EEED00`3oool0000005EEE@020?ooo`0705EE
E@3oool0ZZZZ0?ooo`1EEED0000005EEE@020?ooo`0405EEE@3oool000000?ooo`80EEEE00H0ZZZZ
0?ooo`1EEED0EEEE0?ooo`2ZZZX205EEE@040:ZZZP000000oooo05EEE@80oooo00D0EEEE0000001E
EED0oooo0:ZZZP0205EEE@050?ooo`1EEED0EEEE05EEE@3oool00P1EEED01`000000oooo0?ooo`00
0000EEEE0?ooo`1EEED01@3oool:0=7=Z@@0oooo00<0000005EEE@1EEED00P000000103oool0ZZZZ
0?ooo`2ZZZX30?ooo`0405EEE@2ZZZX0oooo0:ZZZP80oooo00@0ZZZZ0?ooo`2ZZZX000000P3oool0
10000000oooo0000002ZZZX2000000050:ZZZP3oool0000005EEE@3oool01@0000040?ooo`040000
002ZZZX000000:ZZZP80oooo00D0ZZZZ0?ooo`1EEED0EEEE0:ZZZP020?ooo`040:ZZZP3oool0ZZZZ
0?ooo`8000000P1EEED50?ooo``0dLfY000;0=7=Z@H0oooo00P000000?ooo`3oool0000005EEE@2Z
ZZX0oooo0:ZZZP80oooo00T000000:ZZZP3oool0ZZZZ05EEE@2ZZZX000000:ZZZP0000000`1EEED0
1P2ZZZX0oooo05EEE@1EEED0oooo000000H0oooo00@000000?ooo`000000EEEE0P3oool0301EEED0
oooo05EEE@000000ZZZZ0000002ZZZX000000:ZZZP3oool0ZZZZ00000080oooo00<0ZZZZ0?ooo`2Z
ZZX00P1EEED20?ooo`030:ZZZP3oool0oooo00@0oooo2P3AcJT60?ooo`030:ZZZP1EEED0000000<0
ZZZZ00@0EEEE0:ZZZP2ZZZX0EEEE0P0000020?ooo`80EEEE00D0oooo0:ZZZP2ZZZX0oooo05EEE@03
0?ooo`040:ZZZP000000oooo00000080oooo0P000000203oool000000000003oool000000:ZZZP3o
ool0ZZZZ0`3oool20:ZZZP030?ooo`1EEED000000080oooo00<0EEEE0000001EEED00P2ZZZX01`00
0000ZZZZ0:ZZZP2ZZZX0000005EEE@2ZZZX01P3oool:0=7=Z@L0oooo00T000000?ooo`000000EEEE
0?ooo`000000ZZZZ0?ooo`2ZZZX0100000000`3oool0ZZZZ0:ZZZP020:ZZZP80000000T0ZZZZ0000
00000000EEEE0000003oool0ZZZZ05EEE@2ZZZX00P0000001`2ZZZX0oooo0:ZZZP3oool0ZZZZ05EE
E@0000000`2ZZZX00`000000ZZZZ0:ZZZP020:ZZZPD0000000D0ZZZZ0?ooo`2ZZZX0EEEE0?ooo`02
05EEE@030?ooo`000000ZZZZ00H0oooo2P3AcJT60?ooo`<0EEEE00D0oooo0:ZZZP2ZZZX0oooo05EE
E@020000000505EEE@2ZZZX0ZZZZ0:ZZZP3oool00P1EEED01`3oool0EEEE05EEE@000000EEEE0000
003oool0101EEED00`2ZZZX0oooo05EEE@030?ooo`80EEEE00@0000005EEE@3oool0ZZZZ101EEED0
0`3oool0EEEE05EEE@030:ZZZP80EEEE0P0000001@1EEED0ZZZZ0:ZZZP2ZZZX0oooo0080EEEE00<0
ZZZZ0?ooo`3oool0103oool:0=7=Z@L0oooo00@0ZZZZ05EEE@2ZZZX000000P3oool3000000050?oo
o`2ZZZX0oooo0:ZZZP0000000P1EEED00`3oool0ZZZZ0000000205EEE@030:ZZZP3oool000000080
ZZZZ00<0oooo05EEE@1EEED00P000000101EEED000000?ooo`2ZZZX2000000070?ooo`1EEED0EEEE
05EEE@000000ZZZZ0000000205EEE@030000002ZZZX0oooo0080oooo00X0ZZZZ0000000000000000
0?ooo`000000ZZZZ05EEE@2ZZZX000001P3oool<0=7=Z@002`3AcJT60?ooo`0305EEE@0000000000
0080oooo00<0000005EEE@1EEED00P1EEED300000080EEEE00@0ZZZZ0000001EEED000000P3oool2
00000080EEEE00<000000:ZZZP0000000`0000001P1EEED000000:ZZZP000000ZZZZ0?ooo`80EEEE
00L0ZZZZ0000003oool0oooo0000002ZZZX000000080ZZZZ00<0EEEE0000003oool00P00000205EE
E@80000000@0oooo0:ZZZP00000000001`3oool:0=7=Z@H0oooo00<0EEEE0?ooo`2ZZZX00`1EEED0
103oool0ZZZZ0:ZZZP1EEED20:ZZZP80EEEE0`2ZZZX00`000000ZZZZ000000020:ZZZP<000000`3o
ool00`000000ZZZZ05EEE@030:ZZZP80oooo00@0ZZZZ00000000000000000P2ZZZX00`000000ZZZZ
000000030:ZZZP80EEEE0P2ZZZX00`3oool0ZZZZ0:ZZZP0305EEE@030000002ZZZX0oooo00L0oooo
2P3AcJT60?ooo`0505EEE@000000ZZZZ0:ZZZP1EEED00P3oool20:ZZZP060000002ZZZX0ZZZZ0:ZZ
ZP1EEED0ZZZZ0`0000000`2ZZZX0000005EEE@0205EEE@80ZZZZ0`3oool2000000040?ooo`000000
000005EEE@80oooo0`2ZZZX01@000000EEEE05EEE@000000ZZZZ00<0000000H0ZZZZ05EEE@2ZZZX0
EEEE0:ZZZP0000020:ZZZP030000003oool0EEEE0080ZZZZ00<000000?ooo`3oool01@3oool:0=7=
Z@H0oooo00<0EEEE0000003oool00P3oool0101EEED0oooo0?ooo`0000020?ooo`0705EEE@000000
00000000001EEED0oooo000000020:ZZZP030000003oool0EEEE0080EEEE0`2ZZZX0101EEED00000
0:ZZZP1EEED2000000<0ZZZZ0P1EEED20?ooo`<0ZZZZ00@000000?ooo`1EEED0EEEE0`0000000`3o
ool0ZZZZ000000020?ooo`0505EEE@3oool0oooo0?ooo`0000001`3oool:0=7=Z@H0oooo00H00000
05EEE@1EEED0000005EEE@0000020?ooo`80ZZZZ00P0oooo05EEE@1EEED0oooo0000003oool00000
05EEE@80oooo00D000000?ooo`000000ZZZZ0?ooo`020:ZZZP80oooo00<0000005EEE@0000000P00
0000203oool0ZZZZ0?ooo`3oool0ZZZZ0000003oool000000P3oool2000000<0oooo00D0EEEE0000
003oool0oooo0:ZZZP020?ooo`030000001EEED0EEEE0080EEEE1`3oool<0=7=Z@002`3AcJT70?oo
o`030000001EEED0oooo00<0oooo00<000000?ooo`3oool00P0000000`3oool0EEEE05EEE@020?oo
o`050:ZZZP1EEED0EEEE0000002ZZZX00P3oool2000000030:ZZZP1EEED0EEEE0080ZZZZ00@0EEEE
0:ZZZP1EEED0EEEE0P2ZZZX01@000000oooo0:ZZZP2ZZZX000000080EEEE00<0ZZZZ0?ooo`3oool0
0P1EEED01`3oool0EEEE0000002ZZZX0oooo0000002ZZZX00`3oool00`1EEED000000?ooo`060?oo
o`X0dLfY1`3oool00`000000EEEE0:ZZZP030:ZZZP8000001@2ZZZX01P3oool0ZZZZ0:ZZZP000000
ZZZZ05EEE@8000000P3oool01P2ZZZX00000000000000000ZZZZ0?ooo`80ZZZZ00<0oooo00000000
00000P000000202ZZZX0oooo0:ZZZP000000ZZZZ05EEE@2ZZZX0oooo1@2ZZZX00`3oool0ZZZZ0:ZZ
ZP02000000@0ZZZZ00<0EEEE0000003oool01P3oool:0=7=Z@L0oooo1000000205EEE@040000001E
EED0EEEE05EEE@<0000000<0EEEE0000002ZZZX00P2ZZZX30?ooo`050000001EEED0EEEE05EEE@3o
ool00P0000020:ZZZP0605EEE@2ZZZX0EEEE0000003oool000000P1EEED02@000000oooo0000003o
ool0ZZZZ05EEE@2ZZZX0000005EEE@03000000<0EEEE00<000000?ooo`1EEED0100000070?ooo`X0
dLfY1`3oool00`000000ZZZZ0000000205EEE@030000001EEED0EEEE0080oooo00@0ZZZZ05EEE@2Z
ZZX0ZZZZ0P1EEED00`3oool0EEEE0?ooo`0305EEE@0:0:ZZZP1EEED0oooo05EEE@3oool0ZZZZ05EE
E@3oool0ZZZZ05EEE@80oooo00@0EEEE0?ooo`1EEED0ZZZZ0P1EEED20?ooo`@0EEEE0P2ZZZX0101E
EED0oooo0?ooo`3oool205EEE@060:ZZZP1EEED0EEEE05EEE@2ZZZX000001`3oool:0=7=Z@L0oooo
0`000000103oool0000005EEE@1EEED20?ooo`0405EEE@000000oooo000000@0oooo00L0000005EE
E@2ZZZX0EEEE0?ooo`1EEED0oooo0080EEEE00D000000?ooo`3oool0oooo000000020?ooo`090000
001EEED000000?ooo`1EEED0ZZZZ05EEE@3oool0EEEE008000000P3oool01@2ZZZX000000?ooo`00
0000EEEE0080oooo00<0EEEE0?ooo`0000000P3oool2000000L0oooo303AcJT000/0dLfY2@3oool0
10000000oooo0:ZZZP2ZZZX205EEE@070:ZZZP3oool0oooo0?ooo`2ZZZX0oooo0:ZZZP020?ooo`80
00000P3oool01P2ZZZX0oooo0000001EEED0ZZZZ0?ooo`80ZZZZ0P3oool20:ZZZP040?ooo`2ZZZX0
EEEE000000<0oooo00/0ZZZZ000000000000ZZZZ0?ooo`2ZZZX0oooo0:ZZZP3oool0EEEE0?ooo`03
05EEE@040000002ZZZX0oooo05EEE@T0oooo2P3AcJT90?ooo`<0ZZZZ00@000000:ZZZP2ZZZX0oooo
102ZZZX00`1EEED0ZZZZ0:ZZZP0205EEE@80000000L0oooo0:ZZZP2ZZZX0ZZZZ0000001EEED00000
00D0ZZZZ00@0oooo0000001EEED0oooo0`2ZZZX0103oool0EEEE0000001EEED80:ZZZP040?ooo`2Z
ZZX0ZZZZ0?ooo`80ZZZZ00<0EEEE0?ooo`3oool01`3oool:0=7=Z@T0oooo00D000000:ZZZP1EEED0
ZZZZ05EEE@020:ZZZP0705EEE@00000000000000001EEED0ZZZZ0?ooo`0405EEE@80000000D0oooo
05EEE@2ZZZX0oooo05EEE@0200000080ZZZZ0P0000001@1EEED0oooo0000001EEED0oooo00<00000
0`1EEED00`3oool0ZZZZ05EEE@030000000305EEE@2ZZZX0ZZZZ00<0EEEE00<0ZZZZ05EEE@3oool0
203oool:0=7=Z@/0oooo00L0000005EEE@000000oooo0:ZZZP3oool0000000<0oooo0P0000001`3o
ool00000000000000000ZZZZ05EEE@0000000P1EEED00`2ZZZX0oooo000000040?ooo`060:ZZZP3o
ool0ZZZZ0?ooo`1EEED000000P2ZZZX6000000<0oooo00@0ZZZZ0?ooo`000000oooo0`0000000`3o
ool0EEEE0?ooo`080?ooo`X0dLfY2@3oool305EEE@80oooo00X0ZZZZ0000001EEED0ZZZZ0000003o
ool0ZZZZ0?ooo`1EEED000000P3oool2000000<0oooo00P0000005EEE@1EEED0ZZZZ0?ooo`000000
ZZZZ0?ooo`<0EEEE00<000000?ooo`3oool00P0000030?ooo`80EEEE00X0oooo0:ZZZP3oool00000
0?ooo`1EEED000000:ZZZP3oool000000P1EEED00`000000oooo0?ooo`070?ooo``0dLfY000;0=7=
Z@T0oooo00L0000005EEE@1EEED0ZZZZ0000003oool0EEEE0080000000D0ZZZZ0000001EEED00000
0:ZZZP0205EEE@030:ZZZP00000000000080EEEE00<000000:ZZZP0000000`1EEED00`000000EEEE
05EEE@0205EEE@030000003oool000000080EEEE00X0000005EEE@2ZZZX0EEEE0000002ZZZX00000
05EEE@000000ZZZZ0P0000000`2ZZZX0oooo0000000305EEE@X0oooo2P3AcJT90?ooo`8000000P2Z
ZZX0303oool0ZZZZ0000002ZZZX000000:ZZZP000000ZZZZ0?ooo`2ZZZX0oooo05EEE@80ZZZZ101E
EED30:ZZZPH0EEEE0P2ZZZX505EEE@80ZZZZ00P0EEEE0:ZZZP2ZZZX0oooo05EEE@000000ZZZZ05EE
E@<0ZZZZ00@0oooo0000002ZZZX000002P3oool:0=7=Z@T0oooo100000001P1EEED0000005EEE@00
0000oooo0:ZZZP<00000102ZZZX02@1EEED0oooo05EEE@1EEED0ZZZZ0?ooo`1EEED000000?ooo`06
0000000305EEE@3oool0ZZZZ0080EEEE00<0oooo0:ZZZP2ZZZX00`2ZZZX010000000EEEE0000002Z
ZZX20000000405EEE@000000EEEE05EEE@8000002P3oool:0=7=Z@T0oooo0P0000020?ooo`80EEEE
0P3oool505EEE@070?ooo`1EEED0EEEE0?ooo`1EEED0oooo05EEE@020:ZZZP0305EEE@3oool0oooo
00D0EEEE0`3oool00`000000ZZZZ0:ZZZP020?ooo`0505EEE@3oool0EEEE05EEE@3oool0101EEED2
0?ooo`<0EEEE00<0ZZZZ0?ooo`0000002P3oool:0=7=Z@T0oooo0P0000020?ooo`80EEEE00<00000
05EEE@2ZZZX00P3oool00`1EEED0oooo000000040?ooo`060:ZZZP3oool0oooo0?ooo`000000oooo
0P0000020:ZZZP040?ooo`2ZZZX00000000000D0oooo00@0ZZZZ0?ooo`3oool0oooo0P0000040?oo
o`030:ZZZP1EEED000000080EEEE00<000000?ooo`0000002P3oool<0=7=Z@002`3AcJT;0?ooo`04
05EEE@000000ZZZZ0?ooo`8000000P1EEED2000000030:ZZZP1EEED000000080ZZZZ0`0000000`1E
EED0ZZZZ000000020?ooo`80000000<0oooo0:ZZZP0000000`3oool00`1EEED0ZZZZ05EEE@020000
00050?ooo`2ZZZX0ZZZZ0000001EEED00P2ZZZX010000000EEEE05EEE@0000020?ooo`030:ZZZP00
0000EEEE00/0oooo2P3AcJT;0?ooo`0605EEE@2ZZZX0oooo0?ooo`1EEED000000`2ZZZX20000000C
0?ooo`000000EEEE05EEE@2ZZZX000000:ZZZP1EEED000000?ooo`000000EEEE0000001EEED0ZZZZ
0000001EEED0ZZZZ05EEE@030000000305EEE@000000000000<0EEEE00<0ZZZZ0?ooo`000000102Z
ZZX01P000000ZZZZ0?ooo`3oool0000005EEE@/0oooo2P3AcJT;0?ooo`0605EEE@2ZZZX0ZZZZ05EE
E@3oool000000P1EEED00`000000ZZZZ00000003000000090?ooo`000000oooo0?ooo`1EEED0ZZZZ
05EEE@2ZZZX0EEEE00D0ZZZZ00H0000005EEE@2ZZZX0EEEE0:ZZZP1EEED20?ooo`040000003oool0
00000?ooo`80000000D0ZZZZ0000001EEED0EEEE0000000205EEE@030:ZZZP000000EEEE00/0oooo
2P3AcJT;0?ooo`0405EEE@3oool0000005EEE@80oooo00`0ZZZZ000000000000ZZZZ05EEE@2ZZZX0
EEEE0?ooo`000000oooo05EEE@2ZZZX20000000505EEE@00000000000000001EEED00P0000001@1E
EED00000000000000000oooo0080000000@0ZZZZ05EEE@3oool000000P3oool00`2ZZZX0EEEE0000
0002000000050:ZZZP3oool0000005EEE@0000000P1EEED;0?ooo`X0dLfY2`3oool010000000EEEE
05EEE@0000030?ooo`050:ZZZP3oool000000?ooo`0000000P1EEED010000000EEEE05EEE@3oool2
0:ZZZP<0oooo00D0ZZZZ000000000000oooo000000040?ooo`80ZZZZ0P1EEED0202ZZZX0000005EE
E@1EEED000000?ooo`000000oooo0P2ZZZX00`3oool000000000000205EEE@030000003oool0oooo
00T0oooo303AcJT000/0dLfY303oool01`1EEED0oooo0?ooo`3oool0ZZZZ0000003oool00P2ZZZX0
2P3oool0ZZZZ05EEE@2ZZZX0000005EEE@2ZZZX0EEEE0:ZZZP3oool205EEE@0C0000001EEED0ZZZZ
0000001EEED0ZZZZ05EEE@000000EEEE0:ZZZP3oool0ZZZZ05EEE@2ZZZX0EEEE0000002ZZZX0EEEE
0:ZZZP020?ooo`040:ZZZP3oool0oooo0:ZZZP<0oooo00<000000?ooo`3oool02P3oool:0=7=Z@`0
oooo00@0ZZZZ0000002ZZZX0oooo101EEED00`2ZZZX0oooo000000040:ZZZP030?ooo`2ZZZX0ZZZZ
0080ZZZZ00@0EEEE0:ZZZP2ZZZX0oooo0P1EEED20?ooo`030:ZZZP1EEED0EEEE0080ZZZZ0P3oool3
0:ZZZP0405EEE@000000oooo000000@0EEEE0P2ZZZX2000000`0oooo2P3AcJT<0?ooo`@000000`3o
ool20000000;0:ZZZP1EEED0oooo0000002ZZZX0EEEE0:ZZZP1EEED0ZZZZ0?ooo`1EEED00P3oool6
00000080oooo00@0ZZZZ0?ooo`2ZZZX0EEEE0`2ZZZX20000000805EEE@2ZZZX000000000003oool0
00000?ooo`1EEED3000000`0oooo2P3AcJT<0?ooo`80EEEE00<0oooo0:ZZZP000000100000000`1E
EED0oooo0?ooo`02000000030?ooo`0000000000008000000P3oool0102ZZZX000000:ZZZP1EEED2
0:ZZZP030?ooo`2ZZZX0oooo00<0000000<0EEEE0000000000000P0000020?ooo`0505EEE@000000
00000000001EEED00P0000000`3oool0EEEE0000000<0?ooo`X0dLfY303oool00`000000oooo0000
00020?ooo`0505EEE@000000EEEE0:ZZZP3oool01000000305EEE@80oooo00<0EEEE0?ooo`1EEED0
0P3oool00`1EEED000000?ooo`0205EEE@040?ooo`1EEED0oooo0?ooo`<0EEEE0P0000001P3oool0
00000?ooo`3oool0EEEE000000<0oooo00<000000?ooo`000000303oool<0=7=Z@002`3AcJT<0?oo
o`040:ZZZP000000000005EEE@80000000/0ZZZZ0000001EEED0EEEE0000003oool0EEEE0?ooo`2Z
ZZX0oooo05EEE@020?ooo`0305EEE@2ZZZX0ZZZZ0080oooo00@0ZZZZ05EEE@3oool000000P2ZZZX3
0?ooo`070:ZZZP3oool000000?ooo`1EEED0ZZZZ0000000205EEE@050000002ZZZX0ZZZZ0000001E
EED00P00000=0?ooo`X0dLfY303oool20:ZZZP0305EEE@2ZZZX0ZZZZ00<0ZZZZ00P0EEEE0000003o
ool0EEEE0000002ZZZX000000:ZZZP80000000<0ZZZZ0?ooo`3oool00P0000040:ZZZP80000000@0
oooo05EEE@2ZZZX000000P2ZZZX01P000000ZZZZ0000002ZZZX0oooo000000D0ZZZZ00<0000005EE
E@2ZZZX03@3oool:0=7=Z@`0oooo00L0ZZZZ0?ooo`000000EEEE0:ZZZP000000oooo00<0EEEE00<0
00000?ooo`1EEED00P1EEED3000000070:ZZZP3oool0EEEE0000002ZZZX0oooo0:ZZZP030?ooo`06
0000001EEED0ZZZZ0:ZZZP000000EEEE0P00000205EEE@8000000`1EEED00`3oool0EEEE0:ZZZP02
000000h0oooo2P3AcJT<0?ooo`030:ZZZP1EEED0EEEE0080oooo00<0EEEE0:ZZZP2ZZZX00P2ZZZX0
10000000EEEE05EEE@3oool205EEE@080000002ZZZX0oooo0:ZZZP000000EEEE0:ZZZP3oool20:ZZ
ZP030?ooo`000000EEEE0080000000<0oooo0:ZZZP3oool00P1EEED01P3oool0EEEE05EEE@000000
ZZZZ05EEE@<0ZZZZ00@0oooo05EEE@1EEED0EEEE3@3oool:0=7=Z@`0oooo00<000000?ooo`2ZZZX0
0P2ZZZX00`3oool000000?ooo`0205EEE@0=0:ZZZP000000oooo0?ooo`000000oooo0000003oool0
EEEE0:ZZZP1EEED0ZZZZ05EEE@020?ooo`0;0000003oool000000:ZZZP1EEED0000005EEE@3oool0
00000?ooo`0000000`3oool0102ZZZX0EEEE0000003oool2000000030:ZZZP1EEED0ZZZZ00h0oooo
303AcJT000/0dLfY3P3oool01P000000EEEE05EEE@000000oooo0:ZZZP<0000000<0oooo05EEE@00
00000`3oool00`000000ZZZZ0000000305EEE@040:ZZZP000000EEEE0:ZZZP<0EEEE0P2ZZZX01P00
0000oooo0?ooo`3oool0000005EEE@<0000000@0EEEE0:ZZZP3oool0ZZZZ0P1EEED00`000000oooo
0?ooo`0<0?ooo`X0dLfY3P3oool00`000000ZZZZ0:ZZZP030:ZZZP@0oooo0P0000000`2ZZZX00000
0:ZZZP0205EEE@050000003oool0ZZZZ0000002ZZZX00P0000030:ZZZP030?ooo`000000EEEE0080
EEEE00@000000:ZZZP00000000000`3oool00`1EEED0ZZZZ0:ZZZP020:ZZZP0305EEE@000000oooo
00d0oooo2P3AcJT>0?ooo`80000000<0EEEE00000000000010000000201EEED0ZZZZ05EEE@1EEED0
oooo0:ZZZP000000oooo0`000000101EEED000000:ZZZP2ZZZX5000000040?ooo`000000ZZZZ0?oo
o`80EEEE00<0ZZZZ00000000000010000000103oool0EEEE00000000000>0?ooo`X0dLfY3P3oool0
10000000EEEE0000001EEED20:ZZZP80EEEE00H0000005EEE@3oool0000005EEE@3oool305EEE@80
000000T0EEEE00000000000000000:ZZZP000000oooo05EEE@0000000`1EEED0102ZZZX0oooo0?oo
o`0000020?ooo`030000001EEED0EEEE0080ZZZZ00@0EEEE0000002ZZZX000003P3oool:0=7=Z@h0
oooo00P000000?ooo`00000000000?ooo`1EEED0oooo0:ZZZP80oooo0P0000030:ZZZP030000003o
ool000000080000000H0oooo0000001EEED0EEEE0000003oool200000080oooo0P0000001`2ZZZX0
0000000000000000EEEE0?ooo`2ZZZX00P1EEED20?ooo`<000003P3oool<0=7=Z@002`3AcJT?0?oo
o`050000003oool0EEEE0000001EEED00P3oool01P2ZZZX0oooo0?ooo`000000EEEE00000080EEEE
00@0ZZZZ05EEE@3oool0ZZZZ0P3oool02@2ZZZX0EEEE0?ooo`000000ZZZZ0?ooo`000000ZZZZ05EE
E@020000000905EEE@000000oooo0?ooo`2ZZZX0oooo0:ZZZP1EEED000000080oooo00<0ZZZZ0?oo
o`3oool03@3oool:0=7=Z@l0oooo00<0EEEE0000002ZZZX00P0000050?ooo`070:ZZZP1EEED0ZZZZ
0:ZZZP3oool0EEEE0:ZZZP0305EEE@040?ooo`2ZZZX0oooo0?ooo`<0EEEE00<0ZZZZ05EEE@3oool0
0P2ZZZX00`000000ZZZZ0?ooo`040?ooo`80000000<0EEEE0000002ZZZX03`3oool:0=7=ZA00oooo
00<0000005EEE@1EEED0101EEED00`3oool0ZZZZ0:ZZZP020:ZZZP030000002ZZZX0EEEE00<0EEEE
00D0oooo0:ZZZP00000000000:ZZZP0505EEE@030:ZZZP000000ZZZZ00<0ZZZZ1P1EEED00`3oool0
00000:ZZZP0?0?ooo`X0dLfY3`3oool20:ZZZP050?ooo`2ZZZX0ZZZZ05EEE@2ZZZX00P3oool20000
0080oooo00<0EEEE0000003oool00P2ZZZX205EEE@80oooo00P0EEEE0?ooo`1EEED0EEEE0:ZZZP1E
EED0oooo00000080oooo0`0000020?ooo`050:ZZZP3oool0ZZZZ0:ZZZP1EEED00P2ZZZX?0?ooo`X0
dLfY403oool20:ZZZP030?ooo`000000oooo0080ZZZZ00@000000?ooo`3oool0oooo0P2ZZZX30?oo
o`040000003oool0oooo0?ooo`8000000`3oool010000000oooo0?ooo`3oool30:ZZZP80oooo00<0
EEEE0:ZZZP2ZZZX00P000000103oool0EEEE0:ZZZP00000?0?ooo``0dLfY000;0=7=Z@l0oooo00<0
EEEE0000002ZZZX00P3oool020000000EEEE05EEE@000000EEEE0000002ZZZX000000P2ZZZX0101E
EED0oooo0?ooo`3oool2000000040?ooo`2ZZZX0000005EEE@80oooo00L0000005EEE@2ZZZX0ZZZZ
0000003oool0000000@0EEEE00<000000?ooo`3oool00P00000@0?ooo`X0dLfY3`3oool02@1EEED0
ZZZZ0:ZZZP3oool000000:ZZZP000000ZZZZ000000020:ZZZP040?ooo`000000EEEE05EEE@L0ZZZZ
00<000000:ZZZP2ZZZX00P2ZZZX00`3oool0ZZZZ05EEE@02000000030?ooo`2ZZZX0ZZZZ0080ZZZZ
00@000000:ZZZP000000oooo0P2ZZZX@0?ooo`X0dLfY3`3oool00`1EEED000000:ZZZP060:ZZZP@0
000000<0oooo0:ZZZP2ZZZX0102ZZZX010000000oooo0000000000060:ZZZPD000001`2ZZZX00`00
0000oooo0?ooo`0>0?ooo`X0dLfY3`3oool0101EEED0oooo00000000000205EEE@@0oooo00H0ZZZZ
0?ooo`3oool0oooo0000002ZZZX20?ooo`<0EEEE00T0oooo0000001EEED0ZZZZ05EEE@3oool0EEEE
0:ZZZP0000000`3oool00`2ZZZX0oooo0?ooo`020?ooo`030000001EEED000000180oooo2P3AcJT?
0?ooo`060000001EEED0EEEE0000003oool0ZZZZ0P0000001P1EEED0oooo000000000000ZZZZ0000
00<0ZZZZ103oool00`2ZZZX0oooo0?ooo`030?ooo`040000002ZZZX0ZZZZ00000080ZZZZ00<00000
0?ooo`2ZZZX00P0000020?ooo`030000001EEED0EEEE0100oooo303AcJT000/0dLfY4@3oool20000
000305EEE@000000ZZZZ0080000000T0EEEE0000002ZZZX0EEEE0?ooo`2ZZZX0EEEE0000001EEED0
0P0000040?ooo`0>05EEE@000000EEEE0000001EEED0ZZZZ0?ooo`1EEED0oooo0000001EEED0ZZZZ
0000002ZZZX205EEE@030000002ZZZX0oooo0100oooo2P3AcJTB0?ooo`050:ZZZP000000000005EE
E@2ZZZX010000000102ZZZX0EEEE0:ZZZP2ZZZX20?ooo`0:0000002ZZZX000000?ooo`2ZZZX00000
0?ooo`000000oooo00000080ZZZZ00<0EEEE0:ZZZP3oool00P0000000`3oool0ZZZZ05EEE@020000
0080ZZZZ4@3oool:0=7=ZA80oooo100000000`3oool00000000000020?ooo`050000001EEED0EEEE
0000001EEED0102ZZZX0101EEED0oooo0:ZZZP1EEED30:ZZZP060000001EEED0EEEE0000001EEED0
oooo0P0000000`3oool000000?ooo`02000000030:ZZZP3oool0oooo00l0oooo2P3AcJTA0?ooo`80
000000D0EEEE0:ZZZP3oool0ZZZZ05EEE@020:ZZZP0505EEE@3oool0oooo05EEE@0000000P2ZZZX2
05EEE@@0oooo00P0000005EEE@2ZZZX0EEEE0000001EEED000000?ooo`<0ZZZZ00<0oooo0:ZZZP3o
ool00P1EEED00`000000ZZZZ0?ooo`0@0?ooo`X0dLfY4P3oool0102ZZZX0EEEE0000001EEED30000
00<0oooo00<0EEEE0?ooo`3oool00P1EEED00`3oool0ZZZZ0?ooo`0205EEE@030?ooo`2ZZZX0oooo
0080EEEE0P3oool0101EEED0oooo05EEE@3oool30000000505EEE@2ZZZX0EEEE0:ZZZP0000004@3o
ool<0=7=Z@002`3AcJTA0?ooo`0505EEE@000000oooo0000002ZZZX00P1EEED02P2ZZZX0oooo0?oo
o`1EEED0000005EEE@2ZZZX0oooo0:ZZZP0000050?ooo`050:ZZZP000000ZZZZ0?ooo`2ZZZX00`1E
EED20?ooo`030:ZZZP1EEED0EEEE0080ZZZZ00<0oooo0000003oool04@3oool:0=7=ZA40oooo00P0
EEEE0000002ZZZX0oooo0:ZZZP1EEED0oooo0:ZZZP80oooo0`2ZZZX0103oool000000:ZZZP2ZZZX2
05EEE@80oooo0P1EEED30:ZZZP040?ooo`2ZZZX0ZZZZ0:ZZZP80oooo00L0ZZZZ0000001EEED0ZZZZ
0?ooo`2ZZZX000000180oooo2P3AcJTA0?ooo`0305EEE@000000ZZZZ00<0EEEE00@000000?ooo`00
000000000`3oool200000080EEEE0P0000020:ZZZP8000000P1EEED2000000070?ooo`000000oooo
05EEE@000000oooo0:ZZZP0305EEE@030:ZZZP000000oooo0140oooo2P3AcJTA0?ooo`80EEEE00<0
oooo05EEE@0000000P1EEED30?ooo`8000000P2ZZZX20?ooo`0405EEE@2ZZZX000000?ooo`800000
00@0ZZZZ05EEE@3oool0EEEE0P2ZZZX20000000505EEE@3oool0oooo0000001EEED00P0000000`3o
ool0EEEE0?ooo`0A0?ooo`X0dLfY4@3oool00`000000EEEE05EEE@02000000030?ooo`2ZZZX0oooo
0080EEEE00<0oooo0000003oool0101EEED00`3oool0EEEE05EEE@0205EEE@030?ooo`1EEED0EEEE
0080EEEE00<0oooo0000003oool00P1EEED30?ooo`040000001EEED0EEEE05EEEA80oooo303AcJT0
00/0dLfY4P3oool03`000000EEEE05EEE@2ZZZX000000:ZZZP1EEED000000:ZZZP000000oooo0:ZZ
ZP1EEED000000:ZZZP0205EEE@040000001EEED0000000000080EEEE00D0ZZZZ0000001EEED0ZZZZ
0?ooo`030000000405EEE@3oool000000:ZZZP80EEEE00<000000?ooo`3oool0403oool:0=7=ZA80
oooo00/000000:ZZZP2ZZZX0ZZZZ0?ooo`1EEED0ZZZZ0000002ZZZX000000:ZZZP02000000030:ZZ
ZP3oool0ZZZZ0080ZZZZ00<000000:ZZZP2ZZZX00P2ZZZX00`3oool0000000000003000000090:ZZ
ZP000000ZZZZ05EEE@3oool0ZZZZ0000002ZZZX000000180oooo2P3AcJTB0?ooo`80000000<0EEEE
0000000000000P1EEED20:ZZZP80EEEE00L0ZZZZ05EEE@000000EEEE0000003oool0ZZZZ00800000
00L0ZZZZ000000000000EEEE0:ZZZP1EEED0ZZZZ0080EEEE0P2ZZZX205EEE@D000004P3oool:0=7=
ZA80oooo00D0000005EEE@3oool000000:ZZZP0305EEE@050?ooo`000000oooo0?ooo`1EEED00P00
00000`3oool0EEEE0?ooo`0205EEE@<0oooo00D000000?ooo`1EEED0oooo0:ZZZP0200000080EEEE
0P2ZZZX010000000EEEE05EEE@00000B0?ooo`X0dLfY4P3oool3000000<0oooo101EEED00`2ZZZX0
oooo00000003000000D0EEEE00<0oooo0000000000000P0000020?ooo`@0EEEE103oool200000180
oooo303AcJT000/0dLfY503oool2000000030:ZZZP3oool000000080000000<0ZZZZ05EEE@2ZZZX0
0P2ZZZX0103oool0ZZZZ05EEE@0000020?ooo`80000000<0ZZZZ0?ooo`3oool00P2ZZZX00`1EEED0
ZZZZ05EEE@02000000040?ooo`2ZZZX0000005EEEA@0oooo2P3AcJTE0?ooo`030:ZZZP000000EEEE
0080EEEE00X0ZZZZ05EEE@1EEED0ZZZZ0000002ZZZX0oooo0:ZZZP000000oooo0P2ZZZX20?ooo`05
0:ZZZP3oool0ZZZZ0000002ZZZX00P1EEED01`2ZZZX0EEEE05EEE@1EEED000000:ZZZP1EEED0503o
ool:0=7=ZA@0oooo00<000000:ZZZP2ZZZX00P000000103oool000000?ooo`3oool2000000030?oo
o`000000EEEE00D0ZZZZ0P1EEED00`000000oooo00000002000000050?ooo`000000oooo0000001E
EED00P2ZZZX00`1EEED0oooo0?ooo`0B0?ooo`X0dLfY503oool02@000000oooo0?ooo`3oool00000
0:ZZZP3oool0ZZZZ0000000205EEE@090?ooo`1EEED0EEEE0?ooo`000000EEEE0?ooo`000000oooo
00H0EEEE00@0ZZZZ05EEE@2ZZZX000000`3oool00`1EEED0oooo0?ooo`0B0?ooo`X0dLfY503oool4
05EEE@040000003oool0ZZZZ0?ooo`80EEEE00<0ZZZZ0000002ZZZX00`000000203oool000000000
003oool000000:ZZZP3oool0ZZZZ0P1EEED30?ooo`8000000P1EEED00`000000oooo0?ooo`0B0?oo
o``0dLfY000;0=7=ZA@0oooo00<0000005EEE@3oool00P3oool01@2ZZZX0000005EEE@2ZZZX0EEEE
008000000P1EEED00`2ZZZX0oooo0?ooo`020?ooo`<0EEEE00L0ZZZZ0000001EEED0ZZZZ05EEE@3o
ool0ZZZZ00<0oooo00<0EEEE0?ooo`3oool04`3oool:0=7=ZA@0oooo00<0000005EEE@2ZZZX00`2Z
ZZX00`3oool0ZZZZ0?ooo`020:ZZZP<0000000<0ZZZZ05EEE@1EEED00P1EEED0102ZZZX000000000
001EEED20:ZZZP0305EEE@2ZZZX0ZZZZ00@0ZZZZ00<0EEEE0?ooo`3oool04`3oool:0=7=ZA@0oooo
0`0000002`1EEED0ZZZZ0:ZZZP3oool000000:ZZZP1EEED000000:ZZZP000000EEEE00H0000000@0
EEEE0000002ZZZX000000P1EEED200000080ZZZZ0`00000E0?ooo`X0dLfY503oool00`000000ZZZZ
05EEE@0205EEE@060?ooo`00000000000?ooo`1EEED000000P3oool020000000ZZZZ000000000000
oooo0000001EEED000000P3oool010000000EEEE05EEE@0000020?ooo`0405EEE@000000EEEE0:ZZ
ZQD0oooo2P3AcJTD0?ooo`8000000P3oool00`000000oooo05EEE@0400000080ZZZZ0P3oool01000
0000oooo0?ooo`0000020?ooo`80ZZZZ0P000000103oool0000005EEE@3oool2000000030?ooo`00
0000oooo01@0oooo303AcJT000/0dLfY5@3oool0102ZZZX0000005EEE@1EEED2000000@0ZZZZ00<0
EEEE0?ooo`1EEED01@3oool205EEE@050?ooo`000000ZZZZ0:ZZZP3oool00P2ZZZX01@000000EEEE
000000000000ZZZZ01D0oooo2P3AcJTE0?ooo`050:ZZZP1EEED0EEEE0:ZZZP0000000P2ZZZX01@1E
EED0000005EEE@3oool0000000H0ZZZZ00P0oooo0:ZZZP000000ZZZZ05EEE@000000oooo0:ZZZP80
000000@0ZZZZ0000001EEED0ZZZZ5@3oool:0=7=ZAD0oooo00<0ZZZZ0?ooo`0000000P1EEED20:ZZ
ZP80oooo0`0000001P3oool0ZZZZ0000002ZZZX0oooo00000080oooo0`000000103oool0EEEE0:ZZ
ZP00000205EEE@030000003oool0ZZZZ01D0oooo2P3AcJTE0?ooo`80ZZZZ00X0EEEE0?ooo`000000
ZZZZ0?ooo`1EEED0ZZZZ05EEE@000000EEEE0P2ZZZX0103oool000000000003oool20:ZZZP0605EE
E@2ZZZX0EEEE0:ZZZP000000oooo0P000000103oool0ZZZZ0:ZZZP2ZZZXE0?ooo`X0dLfY5@3oool0
1P000000oooo05EEE@2ZZZX0oooo00000080oooo00<0ZZZZ0?ooo`1EEED0103oool00`000000ZZZZ
0?ooo`050?ooo`050:ZZZP3oool0oooo0000003oool00P2ZZZX00`3oool000000?ooo`0D0?ooo``0
dLfY000;0=7=ZAL0oooo0`1EEED01@000000oooo0000001EEED0ZZZZ0080000000D0EEEE0?ooo`00
0000oooo05EEE@020000000505EEE@000000ZZZZ0:ZZZP1EEED00P3oool0102ZZZX0EEEE05EEE@00
000G0?ooo`X0dLfY5`3oool01`000000ZZZZ0000003oool0ZZZZ05EEE@0000000P2ZZZX010000000
oooo0:ZZZP1EEED20:ZZZP0405EEE@000000oooo00000080ZZZZ00L000000?ooo`2ZZZX0ZZZZ0000
002ZZZX0000001L0oooo2P3AcJTG0?ooo`80000000L0EEEE0?ooo`2ZZZX000000?ooo`1EEED0oooo
00<0000000@0oooo05EEE@000000oooo0`00000205EEE@80oooo00<0ZZZZ0?ooo`1EEED00P00000G
0?ooo`X0dLfY5`3oool02@000000oooo0:ZZZP000000ZZZZ0000001EEED0000005EEE@020:ZZZP04
05EEE@2ZZZX0EEEE05EEE@@0ZZZZ0P0000001`1EEED0ZZZZ0:ZZZP3oool0ZZZZ0?ooo`0000005`3o
ool:0=7=ZAL0oooo00<000000?ooo`0000000P1EEED00`000000ZZZZ0:ZZZP020?ooo`040:ZZZP3o
ool0oooo05EEE@80oooo0P2ZZZX20?ooo`80ZZZZ00H0000005EEE@3oool000000?ooo`00000G0?oo
o``0dLfY000;0=7=ZAL0oooo00@0ZZZZ0000003oool0EEEE0P0000001`3oool0ZZZZ0?ooo`3oool0
ZZZZ05EEE@0000000P3oool010000000EEEE0:ZZZP3oool20:ZZZP030?ooo`1EEED000000080oooo
00<000000?ooo`3oool05P3oool:0=7=ZAL0oooo00<0ZZZZ0?ooo`2ZZZX00P000000103oool0ZZZZ
0?ooo`2ZZZX20?ooo`80ZZZZ00<0oooo0:ZZZP2ZZZX00`3oool0102ZZZX0oooo0:ZZZP1EEED20000
00030:ZZZP3oool0oooo01L0oooo2P3AcJTG0?ooo`0:0:ZZZP3oool0000005EEE@000000oooo05EE
E@000000EEEE0?ooo`<0EEEE0P2ZZZX305EEE@030?ooo`00000000000080EEEE00<000000?ooo`00
00006@3oool:0=7=ZAL0oooo00D0ZZZZ000000000000EEEE0?ooo`0205EEE@030:ZZZP1EEED0oooo
0080oooo00D0ZZZZ0000002ZZZX0ZZZZ05EEE@020?ooo`80ZZZZ00@0EEEE0?ooo`3oool0EEEE0P00
000H0?ooo`X0dLfY5`3oool010000000oooo0:ZZZP2ZZZX3000000060:ZZZP3oool0EEEE0000001E
EED0oooo0P1EEED02`3oool0EEEE0000001EEED000000:ZZZP000000EEEE0000001EEED0ZZZZ01T0
oooo303AcJT000/0dLfY603oool01@1EEED000000:ZZZP3oool0000000<0EEEE00D0000005EEE@2Z
ZZX0EEEE0000000205EEE@030:ZZZP1EEED0000000<0EEEE0P3oool20000000305EEE@3oool0oooo
01H0oooo2P3AcJTH0?ooo`0405EEE@000000oooo0?ooo`80EEEE1@000000103oool000000000003o
ool3000000080?ooo`000000EEEE0:ZZZP3oool0ZZZZ0000001EEEDH0?ooo`X0dLfY603oool01P1E
EED000000:ZZZP2ZZZX0oooo00000080oooo00<0EEEE0000001EEED01P0000001@1EEED0ZZZZ0?oo
o`000000EEEE0080ZZZZ00<0000005EEE@3oool05`3oool:0=7=ZAP0oooo0P1EEED01P000000EEEE
05EEE@2ZZZX0oooo0:ZZZP8000000`3oool00`1EEED0oooo0?ooo`02000000030:ZZZP3oool0ZZZZ
0080EEEE00<0oooo05EEE@1EEED0603oool:0=7=ZAP0oooo00@0000005EEE@1EEED000000P3oool2
0:ZZZP030000001EEED0ZZZZ00@0EEEE00<0000005EEE@0000000P2ZZZX00`3oool0000000000002
05EEE@030000003oool0oooo01H0oooo303AcJT000/0dLfY6P3oool400000080oooo00H000000:ZZ
ZP000000EEEE0?ooo`2ZZZX205EEE@080:ZZZP000000oooo0?ooo`000000EEEE0000002ZZZXJ0?oo
o`X0dLfY6P3oool00`2ZZZX0EEEE0:ZZZP030:ZZZP040000002ZZZX0ZZZZ0?ooo`80ZZZZ00D0oooo
0000002ZZZX000000?ooo`020:ZZZP030000001EEED0ZZZZ01X0oooo2P3AcJTK0?ooo`060000003o
ool0oooo0?ooo`000000EEEE0`3oool20:ZZZP<0oooo00@0EEEE0000003oool0oooo0P0000000`2Z
ZZX0oooo0?ooo`0H0?ooo`X0dLfY6P3oool205EEE@060?ooo`00000000000000002ZZZX000000P2Z
ZZX01@3oool000000:ZZZP2ZZZX000000080ZZZZ0P00000205EEE@030:ZZZP3oool0oooo01P0oooo
2P3AcJTK0?ooo`<0ZZZZ0P0000001@2ZZZX0oooo000000000000oooo008000000P3oool01`2ZZZX0
oooo0000002ZZZX0EEEE0:ZZZP0000006P3oool<0=7=Z@002`3AcJTJ0?ooo`0305EEE@000000ZZZZ
00@0oooo00<0ZZZZ05EEE@1EEED00P3oool00`1EEED0ZZZZ0:ZZZP050?ooo`030000003oool0oooo
01T0oooo2P3AcJTJ0?ooo`0305EEE@3oool000000080EEEE00@0ZZZZ0000003oool0ZZZZ101EEED0
0`000000oooo0000000305EEE@030:ZZZP3oool0oooo01X0oooo2P3AcJTJ0?ooo`0405EEE@000000
EEEE05EEE@H0ZZZZ0P0000002@2ZZZX000000:ZZZP2ZZZX0EEEE0:ZZZP1EEED0ZZZZ0000000K0?oo
o`X0dLfY6P3oool0101EEED000000?ooo`3oool20:ZZZP040?ooo`2ZZZX0ZZZZ0:ZZZP80oooo00<0
ZZZZ0?ooo`2ZZZX00P3oool0102ZZZX0oooo0?ooo`00000K0?ooo`X0dLfY6P3oool01@000000EEEE
05EEE@000000EEEE0080oooo00<0EEEE0?ooo`2ZZZX00P3oool01`2ZZZX0EEEE05EEE@3oool00000
05EEE@0000000P1EEEDK0?ooo``0dLfY000;0=7=ZA/0oooo00<0000005EEE@1EEED00`0000000`1E
EED000000?ooo`030?ooo`050:ZZZP1EEED0000005EEE@0000000P1EEED00`000000oooo0?ooo`0I
0?ooo`X0dLfY6`3oool00`000000ZZZZ0:ZZZP020:ZZZP80oooo1@2ZZZX30?ooo`<0ZZZZ00<0EEEE
0000003oool06P3oool:0=7=ZA/0oooo0P0000000`1EEED000000000000205EEE@030:ZZZP000000
oooo00<000000`1EEED010000000EEEE00000000000K0?ooo`X0dLfY6`3oool00`000000EEEE0000
000205EEE@050000001EEED0EEEE0000003oool00`0000001`1EEED000000000001EEED000000:ZZ
ZP0000006`3oool:0=7=ZA/0oooo00<000000?ooo`0000000P3oool305EEE@@0oooo0`1EEED00`00
0000oooo00000002000001/0oooo303AcJT000/0dLfY703oool00`1EEED000000000000405EEE@04
0000001EEED00000000000<0EEEE00<0ZZZZ0000000000007@3oool:0=7=ZA`0oooo00<0EEEE0:ZZ
ZP2ZZZX00`1EEED20?ooo`030:ZZZP000000oooo00<0EEEE00<0oooo0:ZZZP2ZZZX07@3oool:0=7=
ZA`0oooo00<0EEEE0000002ZZZX00P1EEED00`3oool0EEEE05EEE@020000000405EEE@000000oooo
05EEE@80ZZZZ00<000000?ooo`3oool06`3oool:0=7=ZA`0oooo00<0EEEE0?ooo`3oool00P1EEED0
0`3oool0EEEE000000020:ZZZP050000003oool0oooo05EEE@0000007`3oool:0=7=ZA`0oooo00@0
000005EEE@1EEED000000`3oool205EEE@030000001EEED0ZZZZ0080oooo0`1EEEDM0?ooo``0dLfY
000;0=7=ZAd0oooo00D0000005EEE@3oool000000:ZZZP0305EEE@080:ZZZP1EEED0oooo0:ZZZP00
0000oooo05EEE@00000M0?ooo`X0dLfY7@3oool2000000@0ZZZZ00@000000?ooo`2ZZZX00000102Z
ZZX2000001d0oooo2P3AcJTM0?ooo`<0000000D0EEEE000000000000oooo0:ZZZP030?ooo`030000
001EEED00000008000007@3oool:0=7=ZAd0oooo0P0000001P2ZZZX0EEEE05EEE@1EEED0ZZZZ0?oo
o`80ZZZZ0`1EEED00`3oool000000000000M0?ooo`X0dLfY7@3oool3000000030?ooo`1EEED00000
0080oooo00@000000?ooo`1EEED0EEEE0P3oool2000001d0oooo303AcJT000/0dLfY7`3oool00`00
0000oooo0?ooo`020?ooo`80ZZZZ103oool00`1EEED0oooo0?ooo`0M0?ooo`X0dLfY7`3oool01P00
0000ZZZZ05EEE@000000ZZZZ05EEE@80ZZZZ0P1EEED00`2ZZZX0EEEE0?ooo`0N0?ooo`X0dLfY7`3o
ool01@000000ZZZZ05EEE@3oool000000080ZZZZ00D000000?ooo`1EEED0ZZZZ05EEE@0O0?ooo`X0
dLfY7`3oool0101EEED0oooo0000000000040?ooo`80000000<0oooo05EEE@3oool07P3oool:0=7=
ZAl0oooo0`1EEED00`000000oooo0?ooo`020?ooo`040000001EEED0EEEE000001l0oooo303AcJT0
00/0dLfY7`3oool01P000000EEEE0000001EEED000000?ooo`@0000000<0EEEE0?ooo`3oool07P3o
ool:0=7=ZAl0oooo00D000000:ZZZP1EEED0ZZZZ0?ooo`020:ZZZP80oooo00<0EEEE0:ZZZP3oool0
7`3oool:0=7=ZAl0oooo0`0000000`3oool00000000000020000000305EEE@00000000000200oooo
2P3AcJTO0?ooo`030000001EEED0EEEE0080EEEE00@0000005EEE@1EEED0oooo0P1EEEDP0?ooo`X0
dLfY7`3oool2000000H0oooo00<000000?ooo`000000803oool<0=7=Z@002`3AcJTP0?ooo`030:ZZ
ZP000000ZZZZ0080ZZZZ00D000000:ZZZP2ZZZX000000:ZZZP0P0?ooo`X0dLfY803oool20:ZZZP80
000000<0oooo0000000000000`2ZZZXP0?ooo`X0dLfY803oool00`2ZZZX0oooo0?ooo`0405EEE@03
0000003oool0ZZZZ0200oooo2P3AcJTP0?ooo`070:ZZZP1EEED0EEEE0:ZZZP3oool0EEEE0:ZZZP02
05EEE@030:ZZZP3oool0oooo01h0oooo2P3AcJTP0?ooo`050000003oool0EEEE0:ZZZP0000000`2Z
ZZX00`3oool000000?ooo`0O0?ooo``0dLfY000;0=7=ZB80oooo00H0EEEE0:ZZZP3oool0oooo0:ZZ
ZP00000R0?ooo`X0dLfY8P3oool00`1EEED0oooo0?ooo`020?ooo`030000003oool0oooo0200oooo
2P3AcJTR0?ooo`80000000@0ZZZZ00000000000000008P3oool:0=7=ZB80oooo00@0ZZZZ0000003o
ool0EEEE0P00000R0?ooo`X0dLfY8P3oool01P000000oooo0?ooo`000000oooo00000280oooo303A
cJT000/0dLfY8P3oool01@2ZZZX0EEEE05EEE@000000EEEE02<0oooo2P3AcJTR0?ooo`030:ZZZP1E
EED0ZZZZ0080EEEE8`3oool:0=7=ZB80oooo00@0ZZZZ0?ooo`2ZZZX00000903oool:0=7=ZB80oooo
0P2ZZZX205EEE@030:ZZZP3oool0oooo0240oooo2P3AcJTR0?ooo`040000003oool0EEEE0:ZZZR@0
oooo303AcJT000/0dLfY8`3oool205EEE@030:ZZZP1EEED0oooo0280oooo2P3AcJTS0?ooo`0405EE
E@3oool0ZZZZ05EEEB<0oooo2P3AcJTS0?ooo`0405EEE@2ZZZX0000005EEEB<0oooo2P3AcJTS0?oo
o`0405EEE@000000oooo05EEEB<0oooo2P3AcJTS0?ooo`040000001EEED0EEEE000002<0oooo303A
cJT000/0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S
0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S
0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo``0dLfY003o0=7=ZK80dLfY003o0=7=ZK80
dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY000;0=7=Z@040?ooo`000000ZZZZ
0:ZZZP80EEEE0P3oool0101EEED0oooo0:ZZZP1EEED30:ZZZP0405EEE@3oool0ZZZZ000000<0EEEE
00`0oooo05EEE@3oool0ZZZZ05EEE@3oool000000?ooo`000000EEEE0?ooo`1EEED20?ooo`030:ZZ
ZP3oool0oooo0080EEEE00P0oooo05EEE@000000oooo05EEE@3oool0EEEE0:ZZZP<0oooo00@0EEEE
0?ooo`1EEED000000P3oool01@000000ZZZZ0:ZZZP000000EEEE0080ZZZZ00@0EEEE0?ooo`3oool0
EEEE0`2ZZZX00`000000oooo0=7=Z@090=7=Z@050?ooo`2ZZZX000000?ooo`0000000P3oool00`00
0000oooo0:ZZZP040:ZZZP040?ooo`1EEED0EEEE000000@0oooo0P1EEED0103oool0EEEE0?ooo`3o
ool30000000:05EEE@3oool000000?ooo`000000oooo0:ZZZP000000ZZZZ00000080oooo0`000000
103oool0ZZZZ05EEE@3oool205EEE@D0oooo0P1EEED00`3oool0ZZZZ05EEE@020:ZZZP80oooo0P00
00000`3oool000000?ooo`02000000030?ooo`3AcJT0dLfY00P0dLfY00D0oooo0000000000000000
05EEE@020000000805EEE@3oool000000?ooo`1EEED0ZZZZ05EEE@2ZZZX5000000040:ZZZP1EEED0
ZZZZ000000@0ZZZZ00<000000:ZZZP000000101EEED01@000000EEEE0:ZZZP000000ZZZZ0080EEEE
00@0oooo0000002ZZZX00000102ZZZX010000000ZZZZ05EEE@2ZZZX5000000080:ZZZP1EEED00000
05EEE@3oool000000?ooo`1EEED6000000030?ooo`3AcJT0dLfY00P0dLfY00X0oooo0:ZZZP2ZZZX0
ZZZZ0000001EEED0000005EEE@000000ZZZZ0P1EEED00`2ZZZX0EEEE05EEE@040:ZZZP0305EEE@00
0000EEEE00<0EEEE00P0ZZZZ05EEE@00000000000?ooo`1EEED0ZZZZ05EEE@80000000X0EEEE0000
00000000EEEE0?ooo`000000EEEE0:ZZZP1EEED0oooo0P0000000`1EEED0ZZZZ05EEE@0305EEE@03
0000001EEED0ZZZZ00<0ZZZZ0P1EEED01@000000EEEE05EEE@1EEED0000000<0EEEE00D000000:ZZ
ZP2ZZZX000000?ooo`0:0=7=Z@030?ooo`2ZZZX0EEEE00<0EEEE00<0ZZZZ05EEE@0000000`1EEED0
102ZZZX0EEEE05EEE@2ZZZX405EEE@050:ZZZP00000000000:ZZZP3oool00P1EEED0103oool0EEEE
05EEE@1EEED20:ZZZP040?ooo`1EEED0oooo0:ZZZP@0oooo0P2ZZZX205EEE@<0oooo00<0EEEE0?oo
o`0000000`00000405EEE@040?ooo`1EEED0EEEE0:ZZZP80EEEE00H0oooo0000001EEED0oooo05EE
E@2ZZZX205EEE@030000003oool0dLfY00/0dLfY000;0=7=Z@090?ooo`2ZZZX0oooo0:ZZZP3oool0
EEEE0:ZZZP1EEED0ZZZZ0080000000<0oooo0:ZZZP2ZZZX00P3oool00`1EEED0oooo0?ooo`020:ZZ
ZP070?ooo`1EEED0oooo0000002ZZZX0EEEE0:ZZZP020000000605EEE@2ZZZX0EEEE0:ZZZP1EEED0
oooo0P1EEED00`3oool0EEEE0:ZZZP0305EEE@060000002ZZZX0ZZZZ05EEE@2ZZZX000000P1EEED0
103oool0EEEE0:ZZZP3oool205EEE@030:ZZZP3oool0ZZZZ0080oooo00H0000005EEE@2ZZZX0EEEE
0:ZZZP1EEED20:ZZZP<0oooo2P3AcJT01`3oool0ZZZZ0:ZZZP000000EEEE0:ZZZP0000000P1EEED2
0?ooo`0305EEE@2ZZZX0ZZZZ00<0oooo00L000000:ZZZP3oool0ZZZZ05EEE@2ZZZX0EEEE0080ZZZZ
00<0oooo0000002ZZZX00P000000101EEED0oooo05EEE@0000020?ooo`0605EEE@3oool0000005EE
E@3oool0ZZZZ100000030:ZZZP0>0?ooo`2ZZZX0EEEE0000003oool0ZZZZ0000003oool000000?oo
o`2ZZZX0oooo05EEE@3oool305EEE@80ZZZZ00<0EEEE0000002ZZZX00P3oool:0=7=Z@030?ooo`2Z
ZZX0oooo0080oooo00D0EEEE0:ZZZP2ZZZX0ZZZZ05EEE@020:ZZZP<000001@1EEED30000000305EE
E@00000000000080000000H0ZZZZ000000000000ZZZZ05EEE@3oool20:ZZZP8000000P2ZZZX00`3o
ool0EEEE0?ooo`02000000030:ZZZP000000EEEE0080000000<0ZZZZ0000000000001@1EEED00`2Z
ZZX00000000000030:ZZZP0605EEE@2ZZZX0ZZZZ0000001EEED0ZZZZ103oool:0=7=Z@060?ooo`2Z
ZZX0ZZZZ0?ooo`000000oooo0`0000020?ooo`8000000P2ZZZX00`1EEED0ZZZZ0?ooo`020:ZZZP09
05EEE@2ZZZX0EEEE0:ZZZP1EEED0oooo0000003oool000000080EEEE00<0ZZZZ05EEE@1EEED00P00
00000`1EEED000000000000305EEE@040:ZZZP1EEED0EEEE000000<0oooo0`1EEED00`2ZZZX00000
0:ZZZP060:ZZZP040?ooo`000000oooo05EEE@8000000P3oool00`000000oooo0:ZZZP020?ooo`X0
dLfY00D0oooo0:ZZZP2ZZZX0ZZZZ0?ooo`0205EEE@80000000X0ZZZZ05EEE@3oool0ZZZZ0?ooo`1E
EED0ZZZZ0000002ZZZX0EEEE0P3oool02@2ZZZX0oooo0:ZZZP2ZZZX0000005EEE@2ZZZX0EEEE0?oo
o`0505EEE@030:ZZZP1EEED0EEEE0080ZZZZ101EEED01P3oool0EEEE0:ZZZP3oool000000:ZZZP80
oooo0P2ZZZX0103oool0EEEE0?ooo`00000205EEE@050?ooo`2ZZZX0oooo05EEE@2ZZZX00P000000
0`2ZZZX0EEEE0:ZZZP020:ZZZP80oooo303AcJT000/0dLfY0`3oool00`000000oooo0:ZZZP020000
0080EEEE00L0oooo05EEE@3oool0EEEE0:ZZZP000000oooo0080EEEE00@000000:ZZZP000000ZZZZ
0P3oool205EEE@040:ZZZP3oool0ZZZZ0?ooo`<0EEEE00<0oooo0:ZZZP3oool00P2ZZZX405EEE@04
0?ooo`2ZZZX0EEEE0:ZZZP80EEEE0P3oool01@2ZZZX000000:ZZZP000000EEEE0080oooo0P2ZZZX3
05EEE@80oooo00H0EEEE000000000000ZZZZ05EEE@0000030?ooo`X0dLfY0`3oool200000080oooo
00@0ZZZZ0?ooo`2ZZZX0ZZZZ10000000303oool0ZZZZ0:ZZZP2ZZZX0000005EEE@3oool0EEEE0?oo
o`000000ZZZZ0?ooo`80EEEE00H0oooo00000000000000000:ZZZP00000405EEE@070000002ZZZX0
00000?ooo`000000oooo0:ZZZP0205EEE@070:ZZZP000000oooo05EEE@3oool0ZZZZ000000030:ZZ
ZP0=0?ooo`00000000000?ooo`000000ZZZZ0000003oool0ZZZZ0000003oool0ZZZZ000000030?oo
o`X0dLfY0`3oool010000000ZZZZ0000001EEED20000000305EEE@000000oooo008000000P2ZZZX5
05EEE@80ZZZZ00L0000005EEE@2ZZZX000000?ooo`1EEED000000080oooo00<000000:ZZZP2ZZZX0
102ZZZX00`000000ZZZZ000000020?ooo`80000000@0oooo0:ZZZP2ZZZX0EEEE0`2ZZZX505EEE@03
0000002ZZZX000000080oooo00P000000?ooo`00000000000?ooo`000000oooo000000<0oooo2P3A
cJT30?ooo`@0000000<0EEEE0000002ZZZX00`1EEED00`3oool0ZZZZ0?ooo`0305EEE@030000001E
EED0ZZZZ00<0ZZZZ00H0000005EEE@1EEED0ZZZZ0000003oool20:ZZZP0305EEE@00000000000080
EEEE00<0000005EEE@1EEED00P2ZZZX0203oool0000005EEE@1EEED0ZZZZ0000002ZZZX0EEEE0P2Z
ZZX01@3oool0000005EEE@000000EEEE0080ZZZZ00<0oooo05EEE@1EEED00P1EEED01P000000EEEE
000000000000EEEE000000<0oooo2P3AcJT30?ooo`030000003oool0ZZZZ00<0oooo00<000000:ZZ
ZP1EEED0202ZZZX20?ooo`0405EEE@3oool0ZZZZ0?ooo`80EEEE00<0ZZZZ0?ooo`2ZZZX00P1EEED2
0?ooo`0405EEE@000000EEEE05EEE@80oooo0P1EEED00`2ZZZX0oooo05EEE@0205EEE@050?ooo`2Z
ZZX0ZZZZ05EEE@3oool00`2ZZZX00`000000ZZZZ0?ooo`030:ZZZP0305EEE@2ZZZX0EEEE00<0oooo
00<0ZZZZ05EEE@0000000`3oool<0=7=Z@002`3AcJT40?ooo`0>05EEE@2ZZZX000000000002ZZZX0
EEEE0?ooo`1EEED0oooo0000003oool000000:ZZZP0000020?ooo`050:ZZZP3oool0oooo05EEE@3o
ool00`1EEED20:ZZZP060?ooo`1EEED0oooo0:ZZZP3oool0EEEE0P3oool205EEE@050:ZZZP3oool0
00000?ooo`2ZZZX00P1EEED0102ZZZX0EEEE0?ooo`1EEED20?ooo`0;0:ZZZP3oool0oooo0?ooo`2Z
ZZX000000?ooo`000000ZZZZ05EEE@3oool00P2ZZZX200000080ZZZZ103oool:0=7=Z@@0oooo00<0
ZZZZ0000001EEED00P3oool20:ZZZP80oooo00<0ZZZZ0?ooo`3oool00`3oool00`1EEED000000000
00030?ooo`80ZZZZ00@0EEEE0?ooo`000000ZZZZ0P1EEED00`000000ZZZZ0:ZZZP030:ZZZP800000
00H0EEEE0000002ZZZX000000?ooo`1EEED20:ZZZP<0oooo0P0000000`1EEED0oooo05EEE@030?oo
o`040:ZZZP3oool0oooo0:ZZZP<0oooo00<0EEEE0000002ZZZX0103oool:0=7=Z@@0oooo0P000000
0`2ZZZX0EEEE05EEE@020:ZZZP040000002ZZZX0oooo0?ooo`L0000000<0ZZZZ0000003oool00P3o
ool02P000000ZZZZ0:ZZZP000000ZZZZ0000001EEED0ZZZZ0000002ZZZX30000000405EEE@000000
oooo00000080ZZZZ00H0000005EEE@3oool0oooo0000002ZZZX60000000505EEE@3oool0oooo0?oo
o`0000000P2ZZZX205EEE@030?ooo`000000ZZZZ00@0oooo2P3AcJT40?ooo`0405EEE@000000oooo
00000080EEEE00<0ZZZZ05EEE@0000000P1EEED20?ooo`<0000000@0EEEE0:ZZZP2ZZZX0EEEE0P3o
ool30:ZZZP80oooo0P1EEED20?ooo`D0000000<0oooo05EEE@3oool00P3oool30:ZZZP80oooo00@0
EEEE0:ZZZP2ZZZX0EEEE0`0000020?ooo`80EEEE00D0oooo05EEE@2ZZZX0ZZZZ05EEE@0300000003
0:ZZZP3oool0oooo0080oooo2P3AcJT40?ooo`80EEEE00<0ZZZZ05EEE@1EEED00P3oool405EEE@03
0:ZZZP000000EEEE00<0EEEE00H0ZZZZ05EEE@000000ZZZZ05EEE@3oool20:ZZZP090000002ZZZX0
oooo0:ZZZP1EEED0ZZZZ05EEE@2ZZZX0oooo00<0EEEE00H0ZZZZ05EEE@2ZZZX0000005EEE@2ZZZX2
05EEE@80ZZZZ00<0EEEE0:ZZZP1EEED00`1EEED00`000000EEEE05EEE@0305EEE@030?ooo`2ZZZX0
EEEE00<0EEEE00<0ZZZZ0?ooo`3oool00P3oool<0=7=Z@002`3AcJT50?ooo`0<0000002ZZZX00000
05EEE@2ZZZX000000:ZZZP1EEED0000005EEE@2ZZZX0oooo0P1EEED00`3oool0EEEE0:ZZZP020:ZZ
ZP0405EEE@3oool0oooo05EEE@<00000102ZZZX0103oool0ZZZZ0:ZZZP3oool30:ZZZP0505EEE@00
000000000000001EEED00P3oool01`1EEED000000:ZZZP2ZZZX0EEEE0?ooo`1EEED00P3oool205EE
E@040000001EEED0ZZZZ00000080EEEE0`0000050?ooo`X0dLfY1@3oool2000000040?ooo`000000
oooo000000L0oooo0P2ZZZX00`3oool000000?ooo`020?ooo`040000001EEED0oooo0?ooo`800000
00<0oooo05EEE@1EEED00`3oool00`1EEED0oooo0?ooo`0205EEE@<0000000T0EEEE0?ooo`2ZZZX0
00000?ooo`000000oooo0000001EEED00P2ZZZX50?ooo`030000003oool000000080000000<0oooo
0:ZZZP0000001@3oool:0=7=Z@D0oooo00<000000:ZZZP3oool0102ZZZX2000000030?ooo`2ZZZX0
ZZZZ00H0ZZZZ1@0000001P3oool000000?ooo`000000ZZZZ0?ooo`80EEEE0P2ZZZX0101EEED0ZZZZ
0?ooo`2ZZZX20?ooo`<0000000<0ZZZZ0000000000002@2ZZZX00`3oool0000005EEE@020:ZZZP03
05EEE@2ZZZX0oooo008000001@3oool:0=7=Z@D0oooo00<0000005EEE@1EEED00`2ZZZX01P3oool0
00000000001EEED000000?ooo`8000000P1EEED01@3oool0EEEE0000003oool000000080oooo0P1E
EED00`000000EEEE00000004000000030?ooo`00000000000080000000@0EEEE0000001EEED00000
0P3oool01`000000oooo05EEE@1EEED0oooo0000001EEED00P000000303oool0ZZZZ05EEE@000000
EEEE0?ooo`2ZZZX0EEEE0:ZZZP1EEED0ZZZZ000000D0oooo2P3AcJT50?ooo`050000002ZZZX0EEEE
05EEE@3oool0102ZZZX205EEE@030000001EEED0oooo0080EEEE0P2ZZZX00`1EEED0ZZZZ00000003
0:ZZZP<0EEEE00D0oooo0:ZZZP1EEED0EEEE0?ooo`0305EEE@030:ZZZP3oool0EEEE00<0EEEE00D0
ZZZZ05EEE@000000ZZZZ05EEE@030:ZZZP0405EEE@3oool0000000000080EEEE00D0ZZZZ0?ooo`2Z
ZZX0ZZZZ0?ooo`0205EEE@030:ZZZP000000oooo00@0oooo303AcJT000/0dLfY1`3oool02`2ZZZX0
oooo0000002ZZZX000000?ooo`2ZZZX0oooo0:ZZZP000000ZZZZ0080EEEE00L000000?ooo`000000
ZZZZ05EEE@3oool0EEEE00<0oooo00<0ZZZZ05EEE@3oool00`3oool0101EEED0oooo0?ooo`1EEED3
0?ooo`070:ZZZP3oool0ZZZZ0?ooo`1EEED0oooo05EEE@0200000080oooo0P1EEED02P3oool00000
05EEE@3oool0ZZZZ05EEE@000000ZZZZ05EEE@3oool20:ZZZPH0oooo2P3AcJT60?ooo`030:ZZZP00
0000EEEE0080ZZZZ00<0000005EEE@1EEED0101EEED20?ooo`060:ZZZP000000ZZZZ05EEE@3oool0
EEEE0P0000020?ooo`030:ZZZP3oool0oooo00<000000P3oool00`000000oooo000000020?ooo`03
0:ZZZP3oool0oooo0080000000H0EEEE0?ooo`1EEED0ZZZZ0000001EEED20?ooo`H0EEEE00H00000
0:ZZZP1EEED0EEEE0000002ZZZX60?ooo`X0dLfY1`3oool0102ZZZX000000000002ZZZX200000004
0?ooo`1EEED0000005EEE@80000000T0EEEE0000001EEED0EEEE0000003oool000000:ZZZP1EEED0
0P2ZZZX010000000ZZZZ0?ooo`2ZZZX2000000050:ZZZP00000000000000002ZZZX00P3oool01000
0000ZZZZ05EEE@1EEED2000000070?ooo`000000EEEE05EEE@000000EEEE0000000405EEE@040?oo
o`00000000000:ZZZP8000000P2ZZZX60?ooo`X0dLfY1P3oool30:ZZZP0305EEE@3oool0oooo0080
000000D0oooo05EEE@1EEED0000005EEE@02000000<0EEEE00@0000005EEE@1EEED0EEEE0`000000
0`3oool000000000000200000080EEEE00D0000005EEE@00000000000?ooo`030000000505EEE@00
0000EEEE0000002ZZZX00P1EEED0103oool0000005EEE@00000205EEE@030?ooo`000000oooo0080
oooo00@0EEEE0:ZZZP2ZZZX0ZZZZ1P3oool:0=7=Z@H0oooo00<0ZZZZ0?ooo`1EEED00`1EEED00`2Z
ZZX0000005EEE@03000000030?ooo`1EEED0EEEE0080oooo00<0ZZZZ0?ooo`2ZZZX00P0000020:ZZ
ZP<0EEEE0180ZZZZ0?ooo`2ZZZX0ZZZZ05EEE@2ZZZX000000:ZZZP1EEED0oooo05EEE@2ZZZX0oooo
0000003oool0ZZZZ0?ooo`1EEED20?ooo`80EEEE00H0oooo0:ZZZP000000000005EEE@00000305EE
E@040:ZZZP1EEED0oooo0:ZZZPH0oooo303AcJT000/0dLfY1P3oool305EEE@030:ZZZP3oool0ZZZZ
00<0EEEE0P000000101EEED0ZZZZ0?ooo`1EEED20000000;0:ZZZP1EEED0oooo0:ZZZP1EEED00000
0?ooo`2ZZZX0EEEE0?ooo`1EEED00`2ZZZX01@1EEED0ZZZZ05EEE@1EEED0oooo0080ZZZZ00H0oooo
0:ZZZP1EEED0EEEE0?ooo`1EEED30000000305EEE@3oool0ZZZZ0080000000D0oooo05EEE@1EEED0
oooo0:ZZZP020?ooo`80EEEE1`3oool:0=7=Z@H0oooo00D0EEEE0?ooo`000000oooo05EEE@030?oo
o`040000003oool000000?ooo`80000000<0oooo05EEE@0000000P0000000`3oool0ZZZZ0?ooo`03
0?ooo`80EEEE00P0oooo0:ZZZP2ZZZX0oooo0000002ZZZX000000?ooo`80EEEE1P3oool30000000>
05EEE@3oool000000000003oool000000?ooo`000000oooo0000003oool0EEEE0?ooo`0000080?oo
o`X0dLfY1P3oool205EEE@80000000D0EEEE0000002ZZZX000000?ooo`03000000030?ooo`000000
00000080000000<0oooo0000002ZZZX00`00000205EEE@<0oooo00H000000?ooo`1EEED000000?oo
o`1EEED20?ooo`<0EEEE0P0000020:ZZZP@0000000<0oooo0000003oool00P0000020?ooo`070000
002ZZZX0000005EEE@3oool0000005EEE@070?ooo`X0dLfY1P3oool205EEE@030?ooo`000000EEEE
0080EEEE00H0ZZZZ00000000000000000?ooo`00000205EEE@030:ZZZP1EEED0oooo0080000000T0
oooo05EEE@000000EEEE0000002ZZZX0000005EEE@3oool01@0000001`1EEED00000000000000000
EEEE0000001EEED00`0000001@3oool0EEEE0:ZZZP000000EEEE00D0000000@0ZZZZ0000001EEED0
EEEE0P3oool00`1EEED0oooo0?ooo`050?ooo`X0dLfY1P3oool0101EEED0oooo0000001EEED20:ZZ
ZP80oooo00<0ZZZZ0000002ZZZX00P1EEED00`2ZZZX0EEEE05EEE@020:ZZZP040000002ZZZX0EEEE
00000080oooo00@0EEEE0:ZZZP2ZZZX0ZZZZ0P3oool205EEE@80oooo0P2ZZZX205EEE@0B0?ooo`1E
EED0000005EEE@2ZZZX0000005EEE@2ZZZX0EEEE0?ooo`2ZZZX0EEEE0000002ZZZX000000:ZZZP3o
ool0EEEE0`2ZZZX00`000000oooo0?ooo`060?ooo``0dLfY000;0=7=Z@P0oooo0P2ZZZX00`1EEED0
ZZZZ0:ZZZP020?ooo`060000001EEED0ZZZZ0?ooo`2ZZZX000000P1EEED20?ooo`0705EEE@2ZZZX0
EEEE05EEE@000000EEEE0?ooo`020:ZZZP0605EEE@000000ZZZZ0:ZZZP000000EEEE0P2ZZZX00`3o
ool0EEEE0000000205EEE@040?ooo`1EEED0oooo0:ZZZP80EEEE00<0oooo0:ZZZP3oool00P1EEED3
0?ooo`0505EEE@2ZZZX0EEEE05EEE@2ZZZX0203oool:0=7=Z@P0oooo00@0ZZZZ0000001EEED0EEEE
0P3oool00`2ZZZX0000005EEE@020:ZZZP050?ooo`2ZZZX000000:ZZZP3oool00`000000103oool0
ZZZZ0?ooo`00000405EEE@D0oooo0P1EEED01@2ZZZX000000?ooo`000000oooo00<0000000<0EEEE
0:ZZZP0000000P3oool00`2ZZZX0000005EEE@020:ZZZP80oooo0P1EEED20:ZZZPP0oooo2P3AcJT8
0?ooo`80ZZZZ0P00000205EEE@8000000P2ZZZX205EEE@@0000000D0ZZZZ0000003oool0oooo05EE
E@07000000040:ZZZP3oool000000:ZZZP80000000P0ZZZZ00000000000000000?ooo`1EEED00000
0:ZZZP@000000P1EEED20:ZZZP80000000<0EEEE0:ZZZP0000000P0000000`2ZZZX0oooo0?ooo`06
0?ooo`X0dLfY203oool00`2ZZZX0EEEE05EEE@0205EEE@070000003oool000000?ooo`000000oooo
000000030?ooo`D000000`1EEED01@000000ZZZZ0?ooo`000000oooo0080000000@0oooo05EEE@3o
ool0ZZZZ101EEED500000080oooo0P0000050?ooo`030000001EEED0EEEE0080EEEE00<0ZZZZ0?oo
o`3oool01P3oool:0=7=Z@P0oooo00D0ZZZZ0?ooo`1EEED000000?ooo`020000000405EEE@3oool0
000000000080ZZZZ101EEED01`2ZZZX0oooo0?ooo`3oool0ZZZZ0000003oool00`1EEED00`3oool0
00000:ZZZP020?ooo`80EEEE00<0ZZZZ0000002ZZZX00P3oool00`1EEED0ZZZZ05EEE@0305EEE@06
0?ooo`2ZZZX000000:ZZZP3oool0EEEE0P0000001@3oool0000005EEE@1EEED0ZZZZ00P0oooo303A
cJT000/0dLfY2@3oool00`2ZZZX000000:ZZZP040?ooo`030:ZZZP1EEED0EEEE0080oooo00P0ZZZZ
05EEE@1EEED0oooo05EEE@2ZZZX0oooo0:ZZZP80oooo00H0ZZZZ0?ooo`2ZZZX0ZZZZ0000003oool2
00000080ZZZZ00T0oooo0000003oool0oooo05EEE@3oool0ZZZZ05EEE@3oool00P1EEED00`2ZZZX0
oooo0?ooo`0205EEE@080:ZZZP3oool0oooo0?ooo`1EEED0ZZZZ0000001EEED90?ooo`X0dLfY2P3o
ool00`000000oooo0?ooo`030?ooo`030000001EEED0oooo0080oooo00@0EEEE000000000000oooo
0P1EEED00`3oool00000000000020?ooo`0B0:ZZZP1EEED0EEEE0:ZZZP3oool000000:ZZZP3oool0
EEEE0:ZZZP1EEED0oooo0000001EEED0oooo0000001EEED0oooo0P0000000`1EEED0oooo0?ooo`02
0?ooo`030000001EEED0oooo00<0oooo00<0000005EEE@3oool0203oool:0=7=Z@T0oooo00<00000
05EEE@2ZZZX020000000103oool0000005EEE@00000205EEE@050?ooo`000000ZZZZ0:ZZZP000000
0`1EEED01@000000oooo0:ZZZP000000oooo00@0EEEE00D000000:ZZZP2ZZZX000000:ZZZP0205EE
E@030?ooo`1EEED0000000<0000000<0ZZZZ0000003oool00`0000000`2ZZZX0EEEE05EEE@090?oo
o`X0dLfY2@3oool00`2ZZZX0EEEE05EEE@0405EEE@040000001EEED0EEEE00000080EEEE0`000000
0`3oool0000005EEE@020?ooo`030000003oool0ZZZZ00800000101EEED20000000<0:ZZZP3oool0
00000?ooo`000000EEEE0000003oool0000005EEE@000000EEEE0P00000205EEE@8000000P1EEED0
102ZZZX0EEEE05EEE@1EEED90?ooo`X0dLfY2@3oool00`1EEED0ZZZZ0?ooo`020?ooo`030:ZZZP1E
EED0EEEE0080000000L0ZZZZ05EEE@1EEED0oooo05EEE@2ZZZX0oooo00D0EEEE0P2ZZZX205EEE@03
0:ZZZP000000EEEE0080ZZZZ00<0EEEE0:ZZZP0000000P1EEED0102ZZZX0EEEE0:ZZZP3oool20:ZZ
ZP090?ooo`1EEED0EEEE0:ZZZP000000ZZZZ05EEE@3oool0ZZZZ00<0oooo00<0ZZZZ05EEE@3oool0
203oool<0=7=Z@002`3AcJT:0?ooo`040:ZZZP3oool0EEEE0?ooo`80EEEE0P2ZZZX010000000ZZZZ
05EEE@1EEED20:ZZZP80EEEE00@0oooo05EEE@00000000001@2ZZZX2000000030:ZZZP000000ZZZZ
0080ZZZZ00<0EEEE0:ZZZP0000000P1EEED01P3oool0EEEE05EEE@3oool0ZZZZ05EEE@80ZZZZ00T0
000005EEE@2ZZZX0ZZZZ05EEE@3oool0ZZZZ0?ooo`2ZZZX02P3oool:0=7=Z@X0oooo0P2ZZZX205EE
E@030:ZZZP000000EEEE0080ZZZZ00D0EEEE0000002ZZZX0ZZZZ0?ooo`02000000040?ooo`1EEED0
oooo05EEE@<0000000<0oooo05EEE@3oool01@3oool01`000000oooo0000001EEED0oooo05EEE@2Z
ZZX00P0000000`1EEED0ZZZZ0:ZZZP0205EEE@030:ZZZP000000EEEE0080ZZZZ00@0EEEE0000002Z
ZZX0ZZZZ2P3oool:0=7=Z@X0oooo00@0ZZZZ0?ooo`1EEED0ZZZZ0P000000201EEED0oooo0?ooo`3o
ool000000:ZZZP3oool0EEEE0`0000020?ooo`<00000101EEED20:ZZZP0305EEE@000000EEEE0080
EEEE0`0000000`3oool0ZZZZ00000002000000030?ooo`2ZZZX000000080oooo00D0ZZZZ05EEE@00
000000000:ZZZP020?ooo`030:ZZZP3oool0oooo00P0oooo2P3AcJT:0?ooo`80ZZZZ00<0000005EE
E@1EEED00P00000205EEE@060000001EEED0EEEE0000003oool000000P3oool02`000000oooo05EE
E@000000EEEE0:ZZZP000000EEEE0000003oool0EEEE00<000000P2ZZZX00`000000EEEE00000002
000000080?ooo`00000000000000001EEED0ZZZZ0000001EEED2000000<0EEEE00<0oooo0:ZZZP2Z
ZZX02P3oool:0=7=Z@X0oooo0`2ZZZX02@3oool0EEEE0:ZZZP3oool0ZZZZ0000002ZZZX000000:ZZ
ZP0305EEE@040:ZZZP1EEED0oooo0?ooo`80EEEE00<0ZZZZ05EEE@3oool00P2ZZZX205EEE@030:ZZ
ZP000000oooo00@0EEEE0P3oool03P1EEED0ZZZZ05EEE@3oool0EEEE0:ZZZP1EEED0ZZZZ0000002Z
ZZX0oooo0:ZZZP1EEED0oooo0`2ZZZX:0?ooo``0dLfY000;0=7=Z@/0oooo0P1EEED20:ZZZP030?oo
o`1EEED0000000<000000P3oool205EEE@<0ZZZZ0P0000000`2ZZZX0EEEE05EEE@0305EEE@030:ZZ
ZP000000EEEE00@0EEEE00H0ZZZZ0000002ZZZX0ZZZZ05EEE@2ZZZX205EEE@<0oooo0P0000000`3o
ool0EEEE0:ZZZP020:ZZZP80EEEE2`3oool:0=7=Z@/0oooo00<0EEEE0000003oool00P3oool00`00
0000EEEE0?ooo`020?ooo`0705EEE@3oool000000:ZZZP000000EEEE0:ZZZP0300000080EEEE00<0
ZZZZ0?ooo`3oool00`3oool010000000ZZZZ05EEE@2ZZZX2000000050?ooo`2ZZZX000000000002Z
ZZX00P3oool00`1EEED000000?ooo`020?ooo`030000001EEED0oooo0080oooo00<0EEEE0?ooo`3o
ool02@3oool:0=7=Z@/0oooo00/0EEEE0?ooo`2ZZZX0ZZZZ05EEE@3oool0ZZZZ05EEE@2ZZZX00000
0:ZZZP02000000060?ooo`1EEED0EEEE0:ZZZP000000oooo0P0000020?ooo`80000000@0EEEE0000
0000000000000P3oool2000000050?ooo`2ZZZX0ZZZZ0000001EEED00P3oool020000000ZZZZ0:ZZ
ZP2ZZZX0EEEE0:ZZZP3oool000000P2ZZZX205EEE@/0oooo2P3AcJT;0?ooo`0305EEE@0000000000
0080000000D0EEEE00000000000000000:ZZZP0305EEE@030000002ZZZX0EEEE0080EEEE00D00000
0?ooo`2ZZZX0ZZZZ05EEE@0200000080oooo0P0000001@1EEED0ZZZZ0000003oool000000080EEEE
00<000000:ZZZP0000000`1EEED01@3oool00000000000000000EEEE00<000000P1EEED;0?ooo`X0
dLfY2`3oool01`1EEED0oooo05EEE@000000oooo0000002ZZZX00P0000001@3oool0ZZZZ0:ZZZP1E
EED0oooo00D0ZZZZ00@0EEEE0:ZZZP3oool000000P1EEED02P3oool0EEEE05EEE@1EEED000000?oo
o`2ZZZX0EEEE0:ZZZP0000030:ZZZP050?ooo`1EEED0ZZZZ0:ZZZP3oool00P0000001`1EEED00000
000000000000EEEE0?ooo`1EEED02`3oool<0=7=Z@002`3AcJT<0?ooo`0505EEE@3oool0oooo0?oo
o`1EEED00`00000205EEE@040?ooo`000000oooo05EEE@<0ZZZZ0P3oool0102ZZZX0EEEE05EEE@1E
EED20?ooo`030:ZZZP3oool0ZZZZ00<0EEEE0`3oool01`2ZZZX0oooo05EEE@3oool0EEEE0?ooo`1E
EED01000000205EEE@80oooo00<000000?ooo`3oool02P3oool:0=7=Z@`0oooo00L0ZZZZ0000003o
ool0oooo0:ZZZP000000oooo008000000`3oool20:ZZZP80000000<0ZZZZ05EEE@1EEED00`000006
05EEE@<000000`1EEED200000080ZZZZ0`3oool01`2ZZZX000000?ooo`3oool0ZZZZ0000003oool0
0P00000<0?ooo`X0dLfY3@3oool20:ZZZP030?ooo`000000000000<0000000<0EEEE0000003oool0
0P3oool20000000305EEE@2ZZZX0ZZZZ0080ZZZZ0P1EEED020000000ZZZZ0:ZZZP000000ZZZZ05EE
E@2ZZZX000000P2ZZZX00`1EEED00000000000020?ooo`040:ZZZP000000EEEE0:ZZZP80000000<0
ZZZZ0000003oool00P2ZZZX00`000000oooo0?ooo`0:0?ooo`X0dLfY303oool00`1EEED000000000
00020000000805EEE@000000000005EEE@3oool0ZZZZ05EEE@2ZZZX2000000040?ooo`000000EEEE
00000080ZZZZ0`1EEED00`000000EEEE05EEE@0205EEE@040:ZZZP1EEED0000005EEE@<0oooo00H0
00000:ZZZP1EEED0ZZZZ0?ooo`1EEED40000000405EEE@0000000000000000`0oooo2P3AcJT<0?oo
o`0305EEE@3oool0ZZZZ0080oooo00L0000005EEE@1EEED0oooo05EEE@3oool0000000@0ZZZZ00<0
oooo05EEE@3oool00`3oool01P1EEED0oooo0:ZZZP1EEED0oooo0:ZZZP80oooo00H0EEEE0?ooo`1E
EED0oooo0:ZZZP3oool20:ZZZP80oooo00D0EEEE0000001EEED0EEEE0:ZZZP020?ooo`030:ZZZP3o
ool0000000`0oooo303AcJT000/0dLfY3@3oool00`1EEED0ZZZZ05EEE@0205EEE@050?ooo`1EEED0
EEEE0?ooo`2ZZZX00P3oool20:ZZZP0605EEE@2ZZZX0EEEE05EEE@2ZZZX0oooo0P2ZZZX205EEE@06
0:ZZZP1EEED0oooo0:ZZZP3oool0ZZZZ0P1EEED01@2ZZZX0EEEE05EEE@2ZZZX0oooo0080ZZZZ00<0
oooo05EEE@1EEED00P3oool0101EEED000000:ZZZP1EEED=0?ooo`X0dLfY3@3oool00`1EEED0oooo
0?ooo`030?ooo`0305EEE@3oool0oooo00<000000P3oool0101EEED0ZZZZ0?ooo`2ZZZX20?ooo`04
0:ZZZP3oool0ZZZZ0?ooo`@0ZZZZ00P0oooo0:ZZZP2ZZZX0oooo0:ZZZP1EEED000000?ooo`<00000
00<0oooo0000001EEED00`3oool00`000000oooo05EEE@0=0?ooo`X0dLfY3@3oool0101EEED00000
0000003oool20000000305EEE@2ZZZX0oooo00D0000000@0ZZZZ0000001EEED0EEEE0P3oool00`1E
EED0oooo0?ooo`0200000080oooo00<0EEEE0?ooo`3oool00P1EEED00`000000ZZZZ0:ZZZP020000
00050:ZZZP000000oooo0?ooo`1EEED00P000000103oool0ZZZZ0000001EEED=0?ooo`X0dLfY3@3o
ool00`1EEED0ZZZZ05EEE@02000000050:ZZZP1EEED0EEEE0000001EEED00`2ZZZX30000000505EE
E@000000ZZZZ0:ZZZP0000000P1EEED20000000405EEE@00000000000:ZZZP80000000@0EEEE0000
00000000EEEE0P2ZZZX205EEE@050000001EEED0EEEE0:ZZZP1EEED00P0000000`2ZZZX0EEEE0?oo
o`0<0?ooo`X0dLfY3@3oool305EEE@070?ooo`2ZZZX0oooo0?ooo`1EEED0ZZZZ0000000205EEE@04
0000003oool0oooo0:ZZZP80oooo00@000000:ZZZP1EEED0ZZZZ0P0000001@2ZZZX000000?ooo`1E
EED0ZZZZ00<0oooo00@0ZZZZ0?ooo`00000000000P1EEED00`000000ZZZZ0:ZZZP020?ooo`0305EE
E@3oool0oooo0080EEEE3@3oool<0=7=Z@002`3AcJT>0?ooo`030000002ZZZX0ZZZZ0080EEEE00@0
oooo05EEE@3oool0EEEE0`3oool010000000ZZZZ0?ooo`2ZZZX305EEE@80oooo00@0EEEE0000002Z
ZZX0EEEE0P3oool305EEE@<0ZZZZ00T0EEEE0?ooo`3oool0oooo05EEE@3oool0ZZZZ0?ooo`1EEED0
0P2ZZZX2000000h0oooo2P3AcJT>0?ooo`80000000@0oooo0000003oool000000P1EEED02@3oool0
EEEE05EEE@2ZZZX000000?ooo`1EEED0oooo05EEE@040?ooo`0305EEE@3oool0oooo0080EEEE0`3o
ool0101EEED0oooo0?ooo`3oool20:ZZZP0;05EEE@000000oooo05EEE@3oool000000?ooo`000000
oooo0:ZZZP0000003P3oool:0=7=Z@h0oooo00H000000:ZZZP2ZZZX000000?ooo`0000020:ZZZP04
05EEE@000000oooo00000080EEEE0`2ZZZX01P1EEED0ZZZZ0:ZZZP1EEED0ZZZZ000000P0ZZZZ00d0
000005EEE@1EEED000000?ooo`000000EEEE0:ZZZP3oool000000?ooo`1EEED0ZZZZ008000003P3o
ool:0=7=Z@h0oooo00T0000005EEE@1EEED0ZZZZ0000003oool000000?ooo`0000000P3oool00`1E
EED000000000000300000080ZZZZ00@0EEEE000000000000EEEE0`0000000`1EEED0ZZZZ05EEE@02
000000070?ooo`000000oooo05EEE@3oool0EEEE000000030?ooo`050000001EEED0EEEE0:ZZZP00
00003P3oool:0=7=Z@h0oooo00<000000:ZZZP1EEED00`3oool00`1EEED0ZZZZ0000000200000003
05EEE@000000oooo00@0oooo0P2ZZZX205EEE@040:ZZZP000000EEEE05EEE@80ZZZZ0`3oool0101E
EED0oooo05EEE@1EEED3000000040:ZZZP3oool0oooo0?ooo`80EEEE00<0ZZZZ0000003oool03@3o
ool<0=7=Z@002`3AcJT@0?ooo`050:ZZZP3oool0EEEE0:ZZZP3oool00P1EEED00`2ZZZX0EEEE0:ZZ
ZP03000000070:ZZZP1EEED0ZZZZ05EEE@3oool0EEEE0?ooo`02000000030?ooo`1EEED0oooo00<0
EEEE00<0ZZZZ0?ooo`0000000P2ZZZX0101EEED0ZZZZ05EEE@1EEED20:ZZZP0405EEE@2ZZZX0ZZZZ
0:ZZZPl0oooo2P3AcJT?0?ooo`030:ZZZP000000EEEE0080ZZZZ0P3oool00`000000ZZZZ0:ZZZP02
0:ZZZP030?ooo`000000000000@0oooo0P0000000`3oool00000000000050?ooo`8000000P3oool3
0:ZZZP030000003oool000000080ZZZZ00<0EEEE0000002ZZZX03`3oool:0=7=ZA00oooo0P2ZZZX0
0`000000oooo05EEE@02000000030?ooo`000000ZZZZ0080ZZZZ0P000000102ZZZX000000000002Z
ZZX3000000040:ZZZP00000000000:ZZZP80000000<0ZZZZ0000002ZZZX00`2ZZZX40000000305EE
E@3oool0000000<0ZZZZ3`3oool:0=7=Z@l0oooo0`2ZZZX0101EEED0000005EEE@1EEED200000003
0:ZZZP00000000000080EEEE00L000000:ZZZP3oool0oooo05EEE@000000EEEE0080000000H0EEEE
0:ZZZP1EEED0oooo05EEE@2ZZZX20000000405EEE@2ZZZX000000:ZZZP8000000P1EEED00`000000
EEEE0:ZZZP020:ZZZPl0oooo2P3AcJT?0?ooo`030:ZZZP3oool0ZZZZ00<0EEEE00<0ZZZZ0000002Z
ZZX00`0000001P2ZZZX0EEEE05EEE@2ZZZX0EEEE0:ZZZP<000000P1EEED01`000000EEEE0000002Z
ZZX0EEEE0:ZZZP1EEED00P2ZZZX500000080ZZZZ0`1EEED00`3oool0ZZZZ0?ooo`0>0?ooo``0dLfY
000;0=7=ZA00oooo00<000000?ooo`2ZZZX00P000000201EEED0ZZZZ0:ZZZP2ZZZX0000005EEE@2Z
ZZX0oooo0P2ZZZX01P1EEED000000:ZZZP1EEED0oooo0:ZZZP80oooo00<0EEEE0:ZZZP0000000`2Z
ZZX0203oool0ZZZZ05EEE@000000ZZZZ05EEE@2ZZZX0EEEE0P0000000`2ZZZX0EEEE0000000@0?oo
o`X0dLfY403oool2000000030?ooo`000000ZZZZ0080oooo00@000000:ZZZP1EEED0EEEE0P2ZZZX0
1@000000oooo0000003oool000000080oooo00D0EEEE0:ZZZP3oool0oooo000000030?ooo`060000
002ZZZX0ZZZZ0?ooo`1EEED0ZZZZ103oool010000000oooo0:ZZZP00000@0?ooo`X0dLfY403oool6
0000000;0:ZZZP3oool0EEEE0?ooo`1EEED000000:ZZZP3oool0EEEE0000003oool00P0000040:ZZ
ZP070?ooo`000000oooo0:ZZZP1EEED0oooo0:ZZZP02000000060?ooo`1EEED0ZZZZ0:ZZZP000000
ZZZZ0P0000000`3oool000000?ooo`0?0?ooo`X0dLfY403oool020000000EEEE0000003oool00000
05EEE@000000ZZZZ0P3oool40:ZZZP<0EEEE00<000000:ZZZP2ZZZX00`2ZZZX0201EEED0000005EE
E@000000EEEE0:ZZZP000000ZZZZ0`3oool0202ZZZX0000005EEE@000000oooo0000001EEED00000
403oool:0=7=ZA00oooo00H0000005EEE@1EEED0oooo05EEE@00000205EEE@80000000@0EEEE0?oo
o`1EEED0ZZZZ0P1EEED30?ooo`0505EEE@000000EEEE05EEE@2ZZZX00P3oool01P2ZZZX0EEEE0:ZZ
ZP2ZZZX0oooo05EEE@8000000P1EEED00`000000oooo0?ooo`0205EEE@030000003oool0oooo00h0
oooo303AcJT000/0dLfY4@3oool0101EEED0ZZZZ0000000000020:ZZZP0305EEE@3oool0oooo0080
EEEE00D0oooo05EEE@3oool0EEEE0000000205EEE@070?ooo`1EEED0EEEE0?ooo`2ZZZX0EEEE0000
00020?ooo`<0EEEE00@0ZZZZ0?ooo`3oool0oooo0P2ZZZX200000080ZZZZ4@3oool:0=7=ZA40oooo
00<0ZZZZ0000001EEED0103oool20:ZZZP0605EEE@3oool0EEEE0?ooo`000000oooo0P1EEED01P2Z
ZZX0EEEE000000000000EEEE00000080EEEE0P0000030?ooo`<0ZZZZ0`3oool205EEE@030000002Z
ZZX0oooo0100oooo2P3AcJTA0?ooo`060000002ZZZX0ZZZZ0000003oool0EEEE0P3oool01@000000
ZZZZ0:ZZZP000000ZZZZ0080oooo00D000000:ZZZP1EEED000000:ZZZP0200000080ZZZZ00D00000
05EEE@3oool0ZZZZ000000020:ZZZP060000003oool0oooo05EEE@3oool000000`2ZZZXA0?ooo`X0
dLfY4@3oool305EEE@030:ZZZP1EEED0EEEE00@0oooo0P1EEED00`3oool0EEEE0000000200000006
0?ooo`1EEED0EEEE0?ooo`1EEED0oooo0`000000101EEED0oooo05EEE@1EEED30?ooo`<0EEEE00@0
000005EEE@1EEED0ZZZZ4@3oool:0=7=ZA40oooo00<0EEEE0?ooo`1EEED00P3oool20:ZZZP80oooo
00D0EEEE0:ZZZP00000000000?ooo`020:ZZZP080000001EEED0EEEE0:ZZZP3oool0EEEE0:ZZZP00
00020:ZZZP030?ooo`000000EEEE0080ZZZZ0P3oool01`1EEED0ZZZZ0?ooo`000000EEEE0?ooo`2Z
ZZX04@3oool<0=7=Z@002`3AcJTB0?ooo`<000000P1EEED01`000000EEEE05EEE@3oool0EEEE0?oo
o`1EEED00P2ZZZX20?ooo`030:ZZZP3oool0EEEE0080oooo00T000000?ooo`3oool0EEEE0:ZZZP1E
EED0oooo05EEE@3oool00P1EEED0102ZZZX0EEEE05EEE@2ZZZX200000180oooo2P3AcJTB0?ooo`03
0000002ZZZX0oooo0080000000<0ZZZZ0000003oool00P3oool20:ZZZP0405EEE@000000ZZZZ0000
00<0ZZZZ00L0oooo0:ZZZP3oool000000:ZZZP3oool0EEEE0080ZZZZ0`3oool00`000000oooo0000
0002000000030:ZZZP000000oooo0140oooo2P3AcJTB0?ooo`@0000000@0EEEE000000000000EEEE
0P2ZZZX2000000040:ZZZP3oool0oooo05EEE@8000000P2ZZZX00`000000EEEE05EEE@020?ooo`06
0:ZZZP000000ZZZZ0:ZZZP000000EEEE0P0000000`1EEED000000000000200000180oooo2P3AcJTB
0?ooo`030000002ZZZX0ZZZZ0080000000@0EEEE0000001EEED000000P1EEED02@000000EEEE05EE
E@1EEED0000005EEE@2ZZZX0oooo000000020:ZZZP050000001EEED0EEEE05EEE@000000101EEED0
10000000EEEE0000000000020:ZZZP030000003oool0oooo0100oooo2P3AcJTB0?ooo`090000002Z
ZZX0EEEE0:ZZZP1EEED0oooo0:ZZZP1EEED000000080ZZZZ0`1EEED01@2ZZZX0EEEE05EEE@1EEED0
oooo00@0EEEE0P2ZZZX205EEE@050000002ZZZX0000005EEE@2ZZZX00P1EEED0102ZZZX0EEEE0:ZZ
ZP00000B0?ooo``0dLfY000;0=7=ZA<0oooo0P2ZZZX01P3oool0EEEE0:ZZZP000000ZZZZ05EEE@@0
ZZZZ00P0EEEE0?ooo`1EEED000000:ZZZP000000oooo0:ZZZP80EEEE0P3oool20:ZZZP0405EEE@2Z
ZZX0ZZZZ0:ZZZP80000000@0EEEE0?ooo`3oool0ZZZZ4`3oool:0=7=ZA<0oooo00D0ZZZZ0000001E
EED0EEEE0:ZZZP040?ooo`0305EEE@3oool0oooo0080ZZZZ0P3oool205EEE@060?ooo`1EEED0oooo
0?ooo`2ZZZX000001`3oool00`2ZZZX0EEEE05EEE@020:ZZZQ<0oooo2P3AcJTC0?ooo`050:ZZZP3o
ool0ZZZZ0?ooo`0000000P2ZZZX300000080ZZZZ00@000000:ZZZP3oool0ZZZZ0P1EEED01P000000
EEEE05EEE@3oool0ZZZZ0?ooo`80ZZZZ00<0EEEE0000002ZZZX00P2ZZZX01@1EEED0oooo0:ZZZP3o
ool0ZZZZ01<0oooo2P3AcJTC0?ooo`050:ZZZP3oool000000000003oool00`0000001`3oool00000
0?ooo`000000oooo0000003oool00P2ZZZX020000000EEEE0:ZZZP000000oooo0000003oool00000
0`3oool3000000030?ooo`00000000000080ZZZZ4`3oool:0=7=ZA<0oooo0`2ZZZX01P3oool0ZZZZ
05EEE@000000ZZZZ00000080EEEE0P3oool00`1EEED0oooo0:ZZZP020:ZZZP0405EEE@2ZZZX0EEEE
0?ooo`80EEEE00<0oooo05EEE@1EEED00`00000205EEE@040?ooo`2ZZZX0ZZZZ0:ZZZQ<0oooo303A
cJT000/0dLfY503oool205EEE@80oooo00@0ZZZZ0?ooo`2ZZZX000000P3oool205EEE@<0ZZZZ0P00
00000`1EEED00000000000020:ZZZP070?ooo`1EEED0oooo05EEE@000000ZZZZ0?ooo`020:ZZZP03
0?ooo`1EEED0EEEE01@0oooo2P3AcJTE0?ooo`0;0000003oool0EEEE0?ooo`1EEED0oooo05EEE@3o
ool0ZZZZ0000001EEED0103oool2000000D0oooo00<000000:ZZZP1EEED00`1EEED30?ooo`030000
001EEED0oooo01<0oooo2P3AcJTD0?ooo`0305EEE@3oool0oooo0080000000D0ZZZZ0000003oool0
oooo05EEE@020?ooo`80ZZZZ0P3oool2000000040?ooo`1EEED0ZZZZ0:ZZZP80oooo00H0EEEE0000
003oool000000:ZZZP0000030?ooo`0305EEE@3oool0oooo0180oooo2P3AcJTD0?ooo`0405EEE@00
0000000005EEE@D000000P1EEED00`000000EEEE000000020:ZZZP80EEEE00<0ZZZZ05EEE@000000
101EEED00`2ZZZX000000?ooo`020000000405EEE@000000000005EEEA@0oooo2P3AcJTF0?ooo`03
05EEE@000000oooo0080oooo00<0ZZZZ05EEE@1EEED00P3oool0101EEED0ZZZZ0?ooo`3oool205EE
E@080?ooo`1EEED0ZZZZ05EEE@000000oooo05EEE@3oool20:ZZZP80oooo00@0000005EEE@3oool0
EEEE503oool<0=7=Z@002`3AcJTE0?ooo`070:ZZZP1EEED0EEEE0:ZZZP1EEED0oooo0000000405EE
E@030:ZZZP1EEED0ZZZZ0080oooo00D0ZZZZ0?ooo`3oool0EEEE0:ZZZP0305EEE@040:ZZZP000000
ZZZZ05EEE@80ZZZZ00<0EEEE0:ZZZP3oool0503oool:0=7=ZAD0oooo0P2ZZZX205EEE@040?ooo`2Z
ZZX0EEEE05EEE@8000001P1EEED00`3oool0EEEE0?ooo`0305EEE@80000000H0ZZZZ05EEE@000000
oooo05EEE@0000020:ZZZQD0oooo2P3AcJTE0?ooo`050:ZZZP000000oooo0:ZZZP1EEED00`2ZZZX0
1@3oool0ZZZZ0:ZZZP3oool0ZZZZ008000000P1EEED2000000050:ZZZP3oool0ZZZZ0:ZZZP3oool0
0P2ZZZX205EEE@040:ZZZP00000000000:ZZZQD0oooo2P3AcJTE0?ooo`070:ZZZP1EEED000000?oo
o`000000ZZZZ05EEE@020000000305EEE@000000000000<0EEEE00H0oooo0:ZZZP1EEED0000005EE
E@00000205EEE@090000002ZZZX0EEEE05EEE@000000oooo0000001EEED0ZZZZ01D0oooo2P3AcJTE
0?ooo`080:ZZZP1EEED0EEEE0:ZZZP1EEED0ZZZZ0?ooo`1EEED20?ooo`080:ZZZP000000ZZZZ0:ZZ
ZP3oool0ZZZZ05EEE@3oool20:ZZZP800000103oool205EEE@040:ZZZP1EEED0EEEE0:ZZZQD0oooo
303AcJT000/0dLfY5P3oool0101EEED000000:ZZZP1EEED20?ooo`@0ZZZZ00<0000005EEE@1EEED0
0P3oool01@1EEED0oooo0?ooo`1EEED0000000@0ZZZZ0P3oool0101EEED0ZZZZ0:ZZZP1EEEDF0?oo
o`X0dLfY5P3oool0101EEED000000?ooo`3oool20:ZZZP050?ooo`1EEED000000?ooo`0000000P3o
ool2000000080?ooo`000000oooo0?ooo`000000oooo0000001EEED20:ZZZP@0oooo00<0EEEE0?oo
o`3oool0503oool:0=7=ZAH0oooo00@0EEEE0:ZZZP3oool0ZZZZ203oool00`000000ZZZZ0:ZZZP02
0:ZZZP0405EEE@3oool0oooo05EEE@80oooo00L0EEEE0?ooo`1EEED0ZZZZ0?ooo`000000EEEE01H0
oooo2P3AcJTF0?ooo`0405EEE@000000EEEE05EEE@80ZZZZ00P0EEEE00000000000000000?ooo`00
0000ZZZZ05EEE@80oooo0P1EEED00`000000oooo0000000200000080ZZZZ0`1EEED00`2ZZZX0EEEE
0?ooo`0E0?ooo`X0dLfY5P3oool01P1EEED0oooo05EEE@3oool0ZZZZ00000080ZZZZ0P00000405EE
E@030?ooo`2ZZZX0EEEE00<0EEEE00L0ZZZZ0000002ZZZX0ZZZZ0000001EEED0oooo00<0EEEE5P3o
ool<0=7=Z@002`3AcJTG0?ooo`040:ZZZP3oool0ZZZZ0?ooo`<0EEEE00<0ZZZZ05EEE@2ZZZX00P3o
ool0101EEED000000:ZZZP1EEED20?ooo`050:ZZZP3oool0ZZZZ05EEE@2ZZZX00P1EEED00`2ZZZX0
oooo0?ooo`0G0?ooo`X0dLfY5`3oool20:ZZZP050000001EEED0ZZZZ0?ooo`2ZZZX00P0000020?oo
o`040000003oool0EEEE000000@0oooo00P0EEEE0000002ZZZX0oooo0:ZZZP1EEED000000:ZZZQP0
oooo2P3AcJTG0?ooo`030:ZZZP3oool0ZZZZ00P0000000H0EEEE000000000000oooo0000001EEED2
000000040:ZZZP00000000000:ZZZP80000000<0ZZZZ0?ooo`3oool05`3oool:0=7=ZAL0oooo0`2Z
ZZX205EEE@040?ooo`000000oooo0:ZZZP80EEEE0P3oool00`1EEED000000?ooo`0405EEE@040?oo
o`000000oooo05EEE@<0ZZZZ603oool:0=7=ZAL0oooo0P2ZZZX00`3oool0ZZZZ05EEE@0205EEE@80
ZZZZ0P1EEED00`3oool0EEEE0:ZZZP0205EEE@050?ooo`1EEED0EEEE0000002ZZZX0101EEED00`3o
ool0ZZZZ0?ooo`0G0?ooo``0dLfY000;0=7=ZAP0oooo0P1EEED20:ZZZP080?ooo`1EEED000000?oo
o`1EEED0oooo05EEE@3oool2000000070?ooo`1EEED0oooo05EEE@2ZZZX0000005EEE@020:ZZZP<0
EEEE603oool:0=7=ZAP0oooo00D0EEEE0?ooo`3oool0oooo05EEE@020?ooo`80EEEE00<0oooo05EE
E@2ZZZX00P0000001@2ZZZX0EEEE0?ooo`1EEED0ZZZZ0080oooo00D0EEEE0?ooo`000000oooo05EE
E@0H0?ooo`X0dLfY603oool205EEE@070?ooo`00000000000:ZZZP1EEED000000?ooo`0300000003
0:ZZZP3oool000000080000000D0oooo0000001EEED0ZZZZ05EEE@0200000080EEEE603oool:0=7=
ZAP0oooo0P1EEED00`3oool0000005EEE@02000000030:ZZZP1EEED0oooo0080EEEE0P0000001@1E
EED000000?ooo`1EEED0ZZZZ0080000000<0EEEE0000003oool00P1EEEDH0?ooo`X0dLfY603oool0
1`1EEED0oooo0:ZZZP1EEED0ZZZZ05EEE@3oool00`2ZZZX010000000ZZZZ05EEE@3oool40:ZZZP80
oooo00H0EEEE0:ZZZP1EEED000000?ooo`1EEEDH0?ooo``0dLfY000;0=7=ZAT0oooo00H000000?oo
o`3oool0oooo05EEE@0000030:ZZZP060?ooo`2ZZZX000000000002ZZZX0EEEE0P2ZZZX01`1EEED0
000005EEE@1EEED0oooo05EEE@0000006@3oool:0=7=ZAT0oooo0P0000040?ooo`0305EEE@2ZZZX0
oooo0080oooo00H0000005EEE@3oool000000?ooo`2ZZZX30?ooo`040000003oool0ZZZZ000001T0
oooo2P3AcJTI0?ooo`8000000P2ZZZX20000000:0?ooo`000000ZZZZ0000003oool0ZZZZ0000003o
ool0EEEE0:ZZZP@000000P2ZZZX00`3oool000000?ooo`0H0?ooo`X0dLfY6@3oool00`000000EEEE
000000020000000405EEE@2ZZZX0EEEE05EEE@80000000@0EEEE00000000000000000P1EEED00`2Z
ZZX0EEEE000000020000000305EEE@000000oooo01P0oooo2P3AcJTI0?ooo`060000001EEED0EEEE
0?ooo`1EEED0ZZZZ101EEED010000000ZZZZ0:ZZZP00000405EEE@030:ZZZP1EEED0oooo0080EEEE
00<000000?ooo`3oool05`3oool<0=7=Z@002`3AcJTJ0?ooo`0405EEE@2ZZZX0EEEE05EEE@80oooo
00@0ZZZZ0?ooo`1EEED0oooo0P1EEED02@3oool0ZZZZ0?ooo`2ZZZX0EEEE0?ooo`1EEED000000:ZZ
ZP0K0?ooo`X0dLfY6P3oool01@1EEED0oooo0?ooo`3oool000000080oooo00P0EEEE0:ZZZP1EEED0
EEEE0?ooo`1EEED0oooo05EEE@80oooo00<000000?ooo`000000703oool:0=7=ZAX0oooo00<0EEEE
0000002ZZZX00`00000405EEE@80oooo101EEED30000000305EEE@000000oooo01X0oooo2P3AcJTJ
0?ooo`0505EEE@2ZZZX0EEEE0:ZZZP1EEED00`3oool00`000000EEEE05EEE@0205EEE@030000003o
ool0oooo0080EEEE00<0ZZZZ05EEE@2ZZZX06`3oool:0=7=ZAX0oooo0P1EEED40?ooo`80ZZZZ00@0
EEEE0?ooo`1EEED000000P3oool20:ZZZP0505EEE@3oool0oooo0:ZZZP1EEED06`3oool<0=7=Z@00
2`3AcJTK0?ooo`050000002ZZZX0ZZZZ0:ZZZP1EEED00P3oool00`1EEED0ZZZZ000000020:ZZZP<0
oooo00<0EEEE0:ZZZP2ZZZX00P00000K0?ooo`X0dLfY6`3oool2000000040?ooo`2ZZZX000000000
0080oooo00@0EEEE0:ZZZP2ZZZX0EEEE0P3oool01P000000oooo0:ZZZP3oool0ZZZZ000001/0oooo
2P3AcJTK0?ooo`80000000<0ZZZZ05EEE@2ZZZX0102ZZZX00`1EEED0ZZZZ0:ZZZP030:ZZZP030000
001EEED0ZZZZ008000006`3oool:0=7=ZA/0oooo00D000000:ZZZP000000oooo0000000205EEE@06
0000001EEED000000?ooo`1EEED000000`1EEED0103oool000000:ZZZP00000K0?ooo`X0dLfY6`3o
ool00`000000EEEE05EEE@020:ZZZP0405EEE@000000ZZZZ0:ZZZP8000000P2ZZZX01`000000EEEE
05EEE@2ZZZX0EEEE0:ZZZP0000006`3oool<0=7=Z@002`3AcJTL0?ooo`<0EEEE00@0oooo00000000
0000EEEE0P3oool00`2ZZZX0oooo0?ooo`02000000<0EEEE7@3oool:0=7=ZA`0oooo00@0EEEE0?oo
o`000000EEEE0P3oool010000000ZZZZ0000000000020:ZZZP<0oooo00<000000?ooo`3oool0703o
ool:0=7=ZA`0oooo0P1EEED00`3oool0ZZZZ000000030:ZZZP090000002ZZZX0ZZZZ0000002ZZZX0
00000:ZZZP3oool0EEEE01d0oooo2P3AcJTL0?ooo`80EEEE00<0000005EEE@1EEED00P1EEED40000
00@0EEEE00<0000005EEE@3oool0703oool:0=7=ZA`0oooo00@0EEEE0?ooo`3oool00000101EEED0
102ZZZX0oooo05EEE@3oool305EEEAl0oooo303AcJT000/0dLfY7@3oool00`000000EEEE0:ZZZP02
0000000505EEE@3oool0oooo05EEE@3oool00`0000000`3oool0EEEE0000000M0?ooo`X0dLfY7@3o
ool00`000000ZZZZ0?ooo`020?ooo`0305EEE@000000ZZZZ008000000`3oool00`000000ZZZZ0000
000M0?ooo`X0dLfY7@3oool00`000000oooo0:ZZZP020?ooo`<0000000<0ZZZZ0000001EEED00P3o
ool00`2ZZZX0oooo0000000M0?ooo`X0dLfY7@3oool020000000EEEE0?ooo`1EEED0ZZZZ0?ooo`00
0000EEEE0P0000001P1EEED0ZZZZ05EEE@000000EEEE000001d0oooo2P3AcJTM0?ooo`050000001E
EED0ZZZZ0?ooo`1EEED00P2ZZZX205EEE@030:ZZZP1EEED0EEEE0080oooo00<0EEEE0000003oool0
703oool<0=7=Z@002`3AcJTN0?ooo`80ZZZZ0P0000020:ZZZP030?ooo`1EEED0ZZZZ00<0000000<0
EEEE0:ZZZP3oool07@3oool:0=7=ZAh0oooo00@0ZZZZ0000003oool0ZZZZ0`3oool01@2ZZZX0oooo
0000002ZZZX0oooo0080ZZZZ7P3oool:0=7=ZAh0oooo00<0ZZZZ0000002ZZZX00P3oool00`000000
EEEE05EEE@02000000040?ooo`2ZZZX000000:ZZZQh0oooo2P3AcJTN0?ooo`060:ZZZP000000EEEE
0?ooo`000000EEEE0P00000205EEE@040?ooo`1EEED0EEEE0:ZZZQh0oooo2P3AcJTN0?ooo`070:ZZ
ZP1EEED0EEEE0:ZZZP1EEED0oooo000000030?ooo`040:ZZZP1EEED0EEEE0:ZZZQh0oooo303AcJT0
00/0dLfY7`3oool2000000090:ZZZP1EEED0EEEE0000002ZZZX0EEEE0000002ZZZX000000200oooo
2P3AcJTO0?ooo`030000002ZZZX00000008000000P3oool3000000030:ZZZP3oool0oooo01h0oooo
2P3AcJTO0?ooo`80000000@0ZZZZ05EEE@000000ZZZZ0P0000020:ZZZP030000003oool0oooo01h0
oooo2P3AcJTO0?ooo`060000002ZZZX0EEEE0000003oool000000P3oool00`2ZZZX0EEEE0:ZZZP0P
0?ooo`X0dLfY7`3oool02@000000ZZZZ0:ZZZP1EEED000000:ZZZP3oool0000005EEE@020:ZZZR00
oooo303AcJT000/0dLfY803oool02P2ZZZX0oooo0?ooo`1EEED0ZZZZ0000001EEED0ZZZZ0?ooo`2Z
ZZXP0?ooo`X0dLfY803oool20:ZZZP030000002ZZZX0EEEE0080ZZZZ00<000000:ZZZP2ZZZX0803o
ool:0=7=ZB00oooo00H0ZZZZ0?ooo`2ZZZX0ZZZZ05EEE@0000020:ZZZP030?ooo`2ZZZX0oooo01l0
oooo2P3AcJTP0?ooo`80ZZZZ00D0EEEE0000001EEED0EEEE000000030:ZZZR00oooo2P3AcJTP0?oo
o`80ZZZZ0P1EEED0103oool0000005EEE@3oool20:ZZZR00oooo303AcJT000/0dLfY8@3oool205EE
E@80oooo00@0ZZZZ0?ooo`1EEED0EEEE8@3oool:0=7=ZB40oooo00<0EEEE0000001EEED00P000000
0`1EEED0oooo05EEE@0Q0?ooo`X0dLfY8@3oool00`1EEED00000000000020:ZZZP030000001EEED0
EEEE0240oooo2P3AcJTQ0?ooo`0305EEE@3oool0000000<000000P1EEEDQ0?ooo`X0dLfY8@3oool0
0`1EEED000000:ZZZP020?ooo`030:ZZZP3oool0EEEE0240oooo303AcJT000/0dLfY8P3oool01@2Z
ZZX0EEEE05EEE@2ZZZX0EEEE02<0oooo2P3AcJTR0?ooo`<0ZZZZ00<0oooo0:ZZZP3oool08P3oool:
0=7=ZB80oooo00D0ZZZZ0000002ZZZX0ZZZZ0000000S0?ooo`X0dLfY8P3oool01@2ZZZX0EEEE0000
003oool0EEEE02<0oooo2P3AcJTR0?ooo`050:ZZZP1EEED0EEEE0?ooo`1EEED08`3oool<0=7=Z@00
2`3AcJTS0?ooo`0405EEE@000000ZZZZ05EEEB<0oooo2P3AcJTS0?ooo`80EEEE00<0oooo05EEE@3o
ool08P3oool:0=7=ZB<0oooo0P1EEED00`000000EEEE0?ooo`0R0?ooo`X0dLfY8`3oool205EEE@03
0000001EEED0oooo0280oooo2P3AcJTS0?ooo`80EEEE00<0ZZZZ05EEE@3oool08P3oool<0=7=Z@00
2`3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo
2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo
2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo303AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT0
0?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT000/0dLfY00@0oooo0000003oool0oooo
0P2ZZZX00`000000oooo0?ooo`020:ZZZP040000001EEED0EEEE0?ooo`@0ZZZZ00@000000:ZZZP2Z
ZZX0ZZZZ0`1EEED010000000EEEE05EEE@2ZZZX200000080oooo0P2ZZZX00`1EEED0oooo0:ZZZP04
0?ooo`030000002ZZZX0000000D0EEEE0`2ZZZX010000000ZZZZ0:ZZZP2ZZZX20?ooo`0305EEE@3o
ool000000080ZZZZ0P3oool20:ZZZP050000003oool0oooo0000003oool02P3AcJT01@3oool00000
0000003oool0000000<0ZZZZ00<0EEEE0:ZZZP0000001P2ZZZX02@1EEED0ZZZZ0:ZZZP2ZZZX0oooo
05EEE@2ZZZX000000:ZZZP020000000305EEE@2ZZZX0EEEE0080ZZZZ00<0oooo05EEE@0000000P3o
ool20000000=0?ooo`2ZZZX0ZZZZ05EEE@2ZZZX0EEEE0000001EEED0ZZZZ0000002ZZZX0EEEE0?oo
o`050:ZZZP0305EEE@2ZZZX0ZZZZ0080ZZZZ00<000000:ZZZP1EEED00`2ZZZX01@000000oooo0000
00000000oooo00X0dLfY00D0oooo0000003oool000000?ooo`020:ZZZP040?ooo`2ZZZX000000?oo
o`80EEEE00@0oooo000000000000oooo102ZZZX00`1EEED0oooo0:ZZZP0K0:ZZZP030?ooo`1EEED0
EEEE0080ZZZZ0P3oool200000080oooo00@0EEEE0?ooo`2ZZZX0ZZZZ0P3oool01P2ZZZX000000000
003oool000000?ooo`X0dLfY00<0oooo0:ZZZP3oool00P3oool02P1EEED0oooo0?ooo`1EEED00000
0:ZZZP3oool0EEEE0000002ZZZX50?ooo`070:ZZZP3oool0ZZZZ0:ZZZP1EEED0oooo0:ZZZP030000
00070?ooo`2ZZZX0oooo0:ZZZP3oool0ZZZZ0?ooo`040:ZZZP060?ooo`2ZZZX0oooo0000002ZZZX0
00000P3oool01@1EEED0ZZZZ0:ZZZP3oool0EEEE00@0oooo00P0EEEE0:ZZZP000000EEEE0?ooo`2Z
ZZX0000005EEE@80oooo00H0EEEE0?ooo`3oool0oooo0000003oool:0=7=Z@040?ooo`1EEED0EEEE
0?ooo`80ZZZZ00X0oooo05EEE@1EEED0oooo05EEE@2ZZZX000000:ZZZP1EEED0ZZZZ0P1EEED01P00
0000EEEE0:ZZZP3oool0ZZZZ0?ooo`80EEEE00L0ZZZZ0000001EEED0EEEE0:ZZZP3oool0ZZZZ0080
oooo00`0EEEE0?ooo`3oool0EEEE0:ZZZP3oool0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP00000305EEE@80
ZZZZ0P3oool00`1EEED0000005EEE@0305EEE@050:ZZZP000000ZZZZ05EEE@2ZZZX00P1EEED20:ZZ
ZP80oooo00<0EEEE0000003oool0303AcJT000/0dLfY00@0oooo0:ZZZP3oool000000`2ZZZX02000
0000oooo0:ZZZP3oool0EEEE0000002ZZZX00000102ZZZX01@3oool000000?ooo`000000ZZZZ00<0
00000P2ZZZX00`000000EEEE05EEE@03000000040?ooo`2ZZZX000000?ooo`<0000000@0oooo05EE
E@00000000000P2ZZZX4000000<0oooo0`2ZZZX02@3oool000000:ZZZP000000EEEE0?ooo`2ZZZX0
oooo000000030:ZZZP040000003oool0oooo0?ooo`X0dLfY00H0oooo0:ZZZP3oool0oooo0:ZZZP3o
ool30:ZZZP80oooo00@0ZZZZ0?ooo`3oool0EEEE0`2ZZZX0201EEED0oooo05EEE@2ZZZX0EEEE0?oo
o`2ZZZX0oooo0P1EEED01`3oool0EEEE0:ZZZP2ZZZX0oooo05EEE@2ZZZX0103oool00`000000EEEE
0?ooo`020:ZZZP@0EEEE00D0oooo0:ZZZP2ZZZX0EEEE0:ZZZP020?ooo`0:05EEE@2ZZZX0ZZZZ0:ZZ
ZP1EEED0oooo05EEE@2ZZZX0oooo05EEE@<0ZZZZ1P3oool:0=7=Z@040?ooo`2ZZZX000000:ZZZP80
oooo0P1EEED20:ZZZP090000002ZZZX0EEEE05EEE@2ZZZX0EEEE0:ZZZP1EEED000000080EEEE00<0
00000:ZZZP2ZZZX0702ZZZX01@000000EEEE05EEE@000000EEEE00<0ZZZZ0P1EEED01P2ZZZX00000
0?ooo`2ZZZX0EEEE00000080oooo00@0ZZZZ0000003oool0oooo2P3AcJT01@3oool0ZZZZ0:ZZZP1E
EED0oooo00<0EEEE00L0ZZZZ0?ooo`2ZZZX0ZZZZ0?ooo`2ZZZX0oooo0080EEEE00<0ZZZZ05EEE@2Z
ZZX01@3oool010000000oooo0:ZZZP2ZZZX20?ooo`0305EEE@3oool0EEEE00<0oooo00@0EEEE0?oo
o`3oool0EEEE1@3oool20:ZZZP030000003oool0EEEE0080oooo00T0EEEE0:ZZZP1EEED0ZZZZ05EE
E@2ZZZX0oooo0:ZZZP1EEED00P2ZZZX0103oool0ZZZZ05EEE@2ZZZX305EEE@030:ZZZP3oool0oooo
00X0dLfY00@0oooo0:ZZZP1EEED0oooo0`1EEED01P2ZZZX0oooo0?ooo`1EEED0ZZZZ000000<0ZZZZ
00@0oooo0:ZZZP3oool0oooo0P2ZZZX00`1EEED0ZZZZ0:ZZZP020:ZZZP070?ooo`1EEED0ZZZZ0?oo
o`000000oooo05EEE@020:ZZZP0305EEE@2ZZZX0ZZZZ0080EEEE00@0oooo0:ZZZP3oool0ZZZZ0P3o
ool30:ZZZP80EEEE00H0ZZZZ0000003oool0oooo05EEE@3oool30:ZZZP050000002ZZZX0EEEE05EE
E@3oool00P2ZZZX205EEE@040?ooo`1EEED0oooo0?ooo``0dLfY000;0=7=Z@<0oooo0`2ZZZX01P3o
ool000000000003oool0EEEE000000<0ZZZZ00L000000?ooo`3oool000000:ZZZP3oool000000080
ZZZZ00<0000005EEE@0000001`2ZZZX00`3oool000000:ZZZP02000000040?ooo`2ZZZX0ZZZZ0000
00@0ZZZZ00H0000005EEE@000000oooo0:ZZZP0000020:ZZZP030000002ZZZX0oooo00@0ZZZZ00<0
000005EEE@1EEED00P0000040:ZZZP<0oooo2P3AcJT30?ooo`030:ZZZP1EEED000000080EEEE102Z
ZZX00`1EEED000000:ZZZP030:ZZZP030?ooo`1EEED0oooo0080ZZZZ0`1EEED0202ZZZX0EEEE0?oo
o`1EEED0oooo05EEE@3oool0ZZZZ1P3oool0102ZZZX0oooo0?ooo`3oool305EEE@030:ZZZP1EEED0
EEEE00<0ZZZZ0P1EEED00`3oool0ZZZZ0:ZZZP020:ZZZP080000001EEED0ZZZZ0:ZZZP1EEED0ZZZZ
05EEE@3oool2000000040:ZZZP3oool0oooo0?ooo`X0dLfY0`3oool20:ZZZP030?ooo`000000ZZZZ
00@0oooo00D0ZZZZ0?ooo`3oool0oooo0:ZZZP020000000405EEE@000000EEEE0?ooo`<0ZZZZ00<0
EEEE0:ZZZP3oool0402ZZZX00`1EEED0ZZZZ0?ooo`030:ZZZP040?ooo`1EEED0000005EEE@800000
00<0ZZZZ0?ooo`3oool0103oool01`000000oooo0:ZZZP2ZZZX0oooo05EEE@2ZZZX00`3oool:0=7=
Z@<0oooo00X0000005EEE@3oool0oooo05EEE@2ZZZX0EEEE0?ooo`1EEED0ZZZZ0P3oool0102ZZZX0
oooo0?ooo`2ZZZX50?ooo`80ZZZZ0P3oool01@2ZZZX0000005EEE@2ZZZX0oooo0080ZZZZ103oool0
0`1EEED0ZZZZ0?ooo`0205EEE@040000002ZZZX0oooo00000080ZZZZ1@3oool0102ZZZX0oooo0?oo
o`0000020?ooo`060:ZZZP1EEED0oooo05EEE@2ZZZX0EEEE0P3oool00`2ZZZX000000?ooo`020?oo
o`X0dLfY0`3oool01@000000oooo0?ooo`3oool0EEEE0080ZZZZ00H000000:ZZZP1EEED0ZZZZ0000
003oool20:ZZZP0305EEE@2ZZZX0EEEE0080EEEE102ZZZX30?ooo`0305EEE@000000EEEE0080ZZZZ
00@0oooo05EEE@3oool0oooo0P2ZZZX305EEE@030?ooo`1EEED0oooo00<0ZZZZ00<0oooo05EEE@1E
EED00P2ZZZX01@1EEED0ZZZZ0:ZZZP2ZZZX0000000<0ZZZZ00<000000:ZZZP2ZZZX00P1EEED00`3o
ool0EEEE000000030?ooo``0dLfY000;0=7=Z@@0oooo00<000000?ooo`0000000P2ZZZX2000000D0
ZZZZ0P0000030:ZZZP040000002ZZZX0ZZZZ000000H0ZZZZ00D0oooo000000000000ZZZZ00000002
0:ZZZP050000003oool000000000003oool0102ZZZX01`000000ZZZZ0000001EEED0ZZZZ0000003o
ool00P2ZZZX00`3oool000000:ZZZP040:ZZZP8000000P2ZZZX20?ooo`030000003oool0oooo0080
oooo2P3AcJT40?ooo`040000002ZZZX0EEEE0?ooo`80EEEE00H0ZZZZ0?ooo`00000000000?ooo`1E
EED30:ZZZP030000002ZZZX0ZZZZ0080ZZZZ00<0EEEE0:ZZZP2ZZZX00P2ZZZX0101EEED0ZZZZ05EE
E@0000080?ooo`030000001EEED0ZZZZ0080EEEE0`2ZZZX0101EEED0ZZZZ0:ZZZP2ZZZX200000003
0:ZZZP3oool0ZZZZ0080oooo00X000000:ZZZP3oool0ZZZZ0?ooo`1EEED0oooo05EEE@2ZZZX00000
103oool:0=7=Z@@0oooo00D000000:ZZZP2ZZZX0EEEE0?ooo`020:ZZZP070000002ZZZX0ZZZZ0000
002ZZZX0000005EEE@020000000305EEE@000000ZZZZ00<0ZZZZ00D0000005EEE@1EEED0ZZZZ0?oo
o`0<0:ZZZP040?ooo`2ZZZX0EEEE05EEE@D0ZZZZ1P0000002@2ZZZX000000:ZZZP2ZZZX000000:ZZ
ZP000000oooo05EEE@020:ZZZP030000003oool0oooo0080oooo2P3AcJT40?ooo`80ZZZZ00<0EEEE
0?ooo`2ZZZX00P2ZZZX01@1EEED0oooo05EEE@000000ZZZZ00H0EEEE00`0ZZZZ05EEE@2ZZZX00000
05EEE@2ZZZX0oooo0:ZZZP3oool0ZZZZ0000002ZZZX50?ooo`0505EEE@2ZZZX0000005EEE@3oool0
0`2ZZZX00`1EEED000000:ZZZP020:ZZZP0605EEE@2ZZZX0EEEE05EEE@2ZZZX0EEEE0P0000000`1E
EED0oooo05EEE@030:ZZZP040?ooo`1EEED0ZZZZ0:ZZZP@0oooo2P3AcJT40?ooo`0905EEE@2ZZZX0
ZZZZ05EEE@3oool0EEEE0000001EEED0oooo0080000000D0EEEE0:ZZZP1EEED0ZZZZ0?ooo`030:ZZ
ZP80EEEE00<0ZZZZ05EEE@3oool00P2ZZZX01P1EEED0ZZZZ0?ooo`1EEED0000005EEE@80000000<0
EEEE0?ooo`1EEED00P3oool01`1EEED0ZZZZ05EEE@3oool000000:ZZZP1EEED0102ZZZX00`3oool0
ZZZZ05EEE@020:ZZZP80000000<0oooo05EEE@0000000P3oool0101EEED0ZZZZ0:ZZZP2ZZZX40?oo
o``0dLfY000;0=7=Z@@0oooo00<0ZZZZ0?ooo`2ZZZX00P2ZZZX010000000ZZZZ0:ZZZP3oool40:ZZ
ZP050?ooo`1EEED0oooo0?ooo`1EEED00P0000000`1EEED0oooo0:ZZZP040:ZZZP030000002ZZZX0
ZZZZ0080oooo0P2ZZZX01@3oool000000:ZZZP2ZZZX0oooo00@0ZZZZ0P3oool0101EEED0ZZZZ0000
001EEED20?ooo`0405EEE@000000ZZZZ0?ooo`P0ZZZZ00<000000?ooo`3oool0103oool:0=7=Z@@0
oooo00L0ZZZZ0?ooo`1EEED0oooo0000002ZZZX0EEEE0080oooo0P0000000`3oool0EEEE05EEE@03
0?ooo`80ZZZZ00@0EEEE0?ooo`1EEED0oooo0P1EEED0203oool0EEEE0:ZZZP1EEED0000005EEE@00
0000EEEE0P0000001@3oool0000005EEE@2ZZZX0EEEE0080oooo00<0EEEE0:ZZZP1EEED00P3oool3
0:ZZZP80oooo00<0ZZZZ05EEE@1EEED00`0000001P3oool0EEEE0:ZZZP000000oooo05EEE@H0oooo
2P3AcJT40?ooo`040:ZZZP000000ZZZZ00000080EEEE0P3oool20:ZZZP030?ooo`1EEED0oooo0080
EEEE00@0oooo05EEE@1EEED0oooo0`2ZZZX0103oool0000000000000000>0:ZZZP<00000102ZZZX0
103oool0EEEE05EEE@3oool205EEE@<0oooo0P2ZZZX30?ooo`0405EEE@0000000000000000D0oooo
2P3AcJT40?ooo`0605EEE@3oool000000?ooo`2ZZZX0oooo0P2ZZZX00`1EEED0ZZZZ0?ooo`020:ZZ
ZP080?ooo`1EEED0ZZZZ0:ZZZP1EEED0oooo05EEE@2ZZZX40000000405EEE@2ZZZX0oooo0?ooo`80
ZZZZ00@0EEEE0:ZZZP1EEED0EEEE0P2ZZZX01@3oool0EEEE0:ZZZP1EEED0oooo00<0000000L0ZZZZ
0?ooo`3oool0EEEE0?ooo`2ZZZX0EEEE0080ZZZZ0P3oool60:ZZZPP0oooo2P3AcJT40?ooo`0305EE
E@2ZZZX0ZZZZ00<0ZZZZ0P3oool00`2ZZZX0oooo0?ooo`020:ZZZP0405EEE@2ZZZX0EEEE000000<0
ZZZZ00D0EEEE0?ooo`2ZZZX0EEEE0?ooo`020:ZZZP80EEEE00@0oooo000000000000ZZZZ0P000000
0`2ZZZX0oooo05EEE@040:ZZZP0505EEE@3oool0oooo05EEE@3oool00`2ZZZX00`1EEED0ZZZZ0?oo
o`020:ZZZP80oooo00@000000?ooo`3oool0EEEE0P2ZZZX00`000000ZZZZ0?ooo`040?ooo``0dLfY
000;0=7=Z@H0oooo0`2ZZZX0203oool000000:ZZZP3oool0ZZZZ0000002ZZZX000000P2ZZZX20000
00@0ZZZZ00H000000:ZZZP000000ZZZZ0?ooo`0000040:ZZZP80000000<0oooo0000002ZZZX00`2Z
ZZX01P000000oooo0?ooo`000000ZZZZ000000D0ZZZZ00X000000:ZZZP3oool000000:ZZZP000000
ZZZZ0000002ZZZX00000102ZZZX60?ooo`X0dLfY1P3oool010000000oooo00000000000205EEE@04
0?ooo`2ZZZX0ZZZZ00000080EEEE00@0000005EEE@1EEED0EEEE0P2ZZZX0103oool000000?ooo`00
000205EEE@080?ooo`1EEED0oooo0000003oool000000:ZZZP3oool3000000040?ooo`2ZZZX0oooo
05EEE@80000000X0oooo0000003oool000000:ZZZP1EEED0ZZZZ05EEE@000000oooo0P1EEED20:ZZ
ZP030?ooo`1EEED0EEEE0080000000<0oooo0:ZZZP3oool01@3oool:0=7=Z@H0oooo101EEED30000
00030:ZZZP000000EEEE00@0EEEE0`00000205EEE@040000002ZZZX0000000000140ZZZZ00D00000
0:ZZZP000000EEEE0:ZZZP02000000D0EEEE0P0000020:ZZZP8000000`1EEED00`2ZZZX0oooo0?oo
o`040?ooo`X0dLfY1P3oool0102ZZZX0EEEE05EEE@2ZZZX2000000<0oooo00<0ZZZZ0?ooo`000000
103oool010000000oooo0?ooo`3oool205EEE@030?ooo`2ZZZX0oooo00<0oooo00D000000:ZZZP3o
ool0oooo0:ZZZP050?ooo`030:ZZZP3oool0EEEE00<0oooo0P0000040?ooo`030000003oool0ZZZZ
0080oooo00@0ZZZZ000000000000oooo0P1EEED00`2ZZZX0oooo0?ooo`040?ooo`X0dLfY1P3oool0
1P1EEED0oooo0:ZZZP2ZZZX0EEEE0:ZZZP80EEEE0P2ZZZX0101EEED0ZZZZ0000002ZZZX200000003
0:ZZZP3oool0EEEE00<0ZZZZ0P0000002@2ZZZX0EEEE0?ooo`2ZZZX0oooo0000001EEED0ZZZZ0000
00020:ZZZP050?ooo`1EEED0ZZZZ0000003oool00`2ZZZX0101EEED0oooo0:ZZZP0000020:ZZZP06
0000003oool0EEEE0?ooo`2ZZZX0EEEE0P2ZZZX01@1EEED0ZZZZ0:ZZZP3oool0ZZZZ00H0oooo303A
cJT000/0dLfY1P3oool2000000050?ooo`000000ZZZZ0:ZZZP0000000P3oool20:ZZZP80oooo00<0
EEEE0:ZZZP2ZZZX00`2ZZZX00`3oool000000?ooo`0205EEE@030?ooo`000000oooo00<0oooo00@0
00000:ZZZP3oool000000P3oool010000000oooo05EEE@1EEED30?ooo`@0ZZZZ00@0000005EEE@3o
ool000000P2ZZZX20?ooo`<0ZZZZ0P3oool00`000000oooo0?ooo`050?ooo`X0dLfY1P3oool50000
00@0ZZZZ00@0EEEE000000000000EEEE0P2ZZZX0101EEED0ZZZZ0?ooo`00000405EEE@050000001E
EED0ZZZZ0000002ZZZX00P0000002@1EEED0oooo0000001EEED0ZZZZ0000003oool0EEEE00000002
05EEE@060:ZZZP1EEED000000?ooo`2ZZZX0EEEE0P2ZZZX205EEE@080000002ZZZX0ZZZZ0:ZZZP00
0000ZZZZ0000003oool2000000L0oooo2P3AcJT60?ooo`80000000<0oooo0000003oool00P2ZZZX0
1@3oool0ZZZZ0?ooo`000000oooo00<0000000H0ZZZZ0?ooo`00000000000?ooo`2ZZZX20?oooa00
ZZZZ00D000000?ooo`2ZZZX0oooo000000020?ooo`030:ZZZP3oool0000000@0000000P0ZZZZ0?oo
o`3oool0ZZZZ0?ooo`000000oooo000000L0oooo2P3AcJT60?ooo`0405EEE@3oool0ZZZZ0:ZZZP80
00000P1EEED30?ooo`0<0:ZZZP3oool000000?ooo`1EEED0000005EEE@3oool0EEEE0?ooo`2ZZZX0
EEEE1P3oool0102ZZZX000000:ZZZP2ZZZX60?ooo`0705EEE@2ZZZX0EEEE05EEE@3oool0EEEE0000
000205EEE@080000003oool0oooo0?ooo`1EEED0oooo05EEE@2ZZZX20000000305EEE@2ZZZX0oooo
00L0oooo2P3AcJT60?ooo`0305EEE@2ZZZX0ZZZZ00@0ZZZZ00D0EEEE0?ooo`3oool0EEEE0:ZZZP02
0?ooo`070000001EEED0EEEE0:ZZZP1EEED0oooo05EEE@020?ooo`050:ZZZP3oool0EEEE0?ooo`1E
EED00P3oool20:ZZZP80oooo00D0EEEE0?ooo`2ZZZX0oooo0:ZZZP040?ooo`0305EEE@2ZZZX0EEEE
0080EEEE0P3oool01P2ZZZX0EEEE0?ooo`3oool0EEEE0?ooo`80ZZZZ00<0oooo0:ZZZP2ZZZX01`3o
ool<0=7=Z@002`3AcJT70?ooo`030:ZZZP3oool0ZZZZ00<0ZZZZ00@000000?ooo`2ZZZX0oooo0`00
00001`2ZZZX0oooo0:ZZZP2ZZZX0oooo05EEE@3oool00`000000102ZZZX0oooo0:ZZZP00000205EE
E@0;0:ZZZP3oool0EEEE0?ooo`000000ZZZZ0?ooo`2ZZZX000000:ZZZP0000000P1EEED01@3oool0
ZZZZ0:ZZZP3oool0ZZZZ0080000000D0EEEE0?ooo`2ZZZX0oooo000000030:ZZZP030000003oool0
ZZZZ00L0oooo2P3AcJT70?ooo`040:ZZZP3oool0oooo0:ZZZP80oooo00<0EEEE0?ooo`2ZZZX00P1E
EED40:ZZZP0305EEE@000000EEEE0080ZZZZ00@0EEEE0:ZZZP1EEED000000P3oool20:ZZZP0<0000
003oool0EEEE0000001EEED0ZZZZ0?ooo`1EEED0000005EEE@2ZZZX0EEEE0P2ZZZX00`1EEED0oooo
05EEE@040:ZZZP080000001EEED0ZZZZ0?ooo`1EEED0ZZZZ0?ooo`2ZZZX20?ooo`030:ZZZP3oool0
oooo00D0oooo2P3AcJT70?ooo`030:ZZZP000000oooo0080oooo0P1EEED01@2ZZZX0oooo0?ooo`00
0000ZZZZ0080oooo0`2ZZZX20?ooo`0305EEE@3oool0ZZZZ0100ZZZZ00<000000?ooo`3oool00P3o
ool00`000000ZZZZ0:ZZZP020?ooo`80ZZZZ0P3oool00`2ZZZX0EEEE000000020?ooo`030:ZZZP00
0000ZZZZ00L0oooo2P3AcJT70?ooo`040000002ZZZX0oooo0?ooo`80ZZZZ00@0EEEE0?ooo`3oool0
EEEE0`3oool02P1EEED0ZZZZ0?ooo`000000oooo0:ZZZP3oool0EEEE0:ZZZP1EEED30:ZZZP0=05EE
E@2ZZZX0EEEE0:ZZZP000000EEEE0:ZZZP1EEED0ZZZZ05EEE@2ZZZX0EEEE0?ooo`0205EEE@040:ZZ
ZP3oool0oooo0?ooo`80ZZZZ0P3oool205EEE@090000003oool0EEEE0?ooo`2ZZZX0oooo05EEE@2Z
ZZX0000000L0oooo2P3AcJT70?ooo`050000001EEED0EEEE0000003oool01@2ZZZX0303oool0ZZZZ
0000003oool0ZZZZ05EEE@3oool0EEEE0:ZZZP1EEED0oooo05EEE@80oooo00H0EEEE0:ZZZP2ZZZX0
EEEE0:ZZZP3oool50:ZZZP<0oooo00X0EEEE0?ooo`2ZZZX0ZZZZ05EEE@3oool0EEEE0:ZZZP3oool0
00000`2ZZZX02@1EEED0ZZZZ0:ZZZP000000oooo0000003oool0EEEE000000070?ooo``0dLfY000;
0=7=Z@T0oooo0`2ZZZX01@3oool000000000003oool0EEEE00<0ZZZZ0P0000000`3oool000000000
00020:ZZZP0C0000003oool000000?ooo`2ZZZX000000?ooo`2ZZZX0000005EEE@2ZZZX000000:ZZ
ZP3oool000000:ZZZP3oool000000:ZZZP02000000050:ZZZP00000000000?ooo`0000000`2ZZZX0
0`000000EEEE05EEE@02000000@0ZZZZ2@3oool:0=7=Z@T0oooo00<0000005EEE@0000000`1EEED0
1P000000EEEE0000001EEED0oooo05EEE@80oooo00@0EEEE0?ooo`1EEED000000P3oool20:ZZZP03
0000001EEED000000080ZZZZ00D0000005EEE@2ZZZX0ZZZZ0000000205EEE@80ZZZZ00H0EEEE0?oo
o`000000EEEE0?ooo`1EEED40?ooo`<0EEEE00L0000005EEE@1EEED0oooo0000001EEED0ZZZZ00T0
oooo2P3AcJT90?ooo`0505EEE@2ZZZX0oooo0000002ZZZX00`3oool00`2ZZZX0EEEE05EEE@0205EE
E@030:ZZZP00000000000080oooo00<000000:ZZZP2ZZZX0402ZZZX2000000060?ooo`000000ZZZZ
0:ZZZP1EEED0ZZZZ0P1EEED0102ZZZX0oooo0000003oool20:ZZZP030?ooo`2ZZZX0ZZZZ00T0oooo
2P3AcJT;0?ooo`050000003oool0oooo0?ooo`1EEED00P3oool00`2ZZZX0EEEE0:ZZZP020:ZZZP03
0?ooo`2ZZZX0oooo0080oooo0`2ZZZX0101EEED0000005EEE@0000020?ooo`0605EEE@3oool0oooo
05EEE@000000EEEE0P2ZZZX40?ooo`0:0:ZZZP1EEED0ZZZZ0:ZZZP000000EEEE0:ZZZP1EEED0oooo
0:ZZZP<0oooo00<000000?ooo`1EEED02@3oool:0=7=Z@T0oooo00D0ZZZZ0000003oool000000:ZZ
ZP0205EEE@030?ooo`1EEED0EEEE00<0EEEE00L0oooo0:ZZZP3oool0EEEE0?ooo`2ZZZX0oooo0080
ZZZZ00D0oooo0:ZZZP2ZZZX0EEEE0:ZZZP02000000030:ZZZP1EEED0ZZZZ00H0ZZZZ0P1EEED01@3o
ool0ZZZZ0?ooo`1EEED0oooo0080EEEE00@0ZZZZ0?ooo`2ZZZX0EEEE0P2ZZZX00`3oool0000005EE
E@090?ooo``0dLfY000;0=7=Z@T0oooo0P000000103oool000000:ZZZP2ZZZX2000000@0ZZZZ00H0
00000:ZZZP3oool0ZZZZ0?ooo`0000020:ZZZP80EEEE0P2ZZZX02P000000oooo05EEE@2ZZZX00000
05EEE@3oool000000:ZZZP3oool205EEE@80ZZZZ00H0EEEE0?ooo`2ZZZX0oooo0:ZZZP0000040:ZZ
ZP8000000P2ZZZX20?ooo`030000003oool0oooo00P0oooo2P3AcJT90?ooo`80000000<0ZZZZ05EE
E@3oool0101EEED30:ZZZP060000002ZZZX0EEEE0:ZZZP1EEED000000P1EEED0103oool0ZZZZ0:ZZ
ZP0000030?ooo`80EEEE00/0oooo0000003oool0000005EEE@2ZZZX0oooo0000001EEED0ZZZZ05EE
E@030:ZZZP8000000P2ZZZX020000000EEEE05EEE@1EEED0oooo05EEE@2ZZZX000002P3oool:0=7=
Z@T0oooo0P0000020:ZZZP0605EEE@3oool0ZZZZ0:ZZZP000000ZZZZ0P1EEED0102ZZZX000000:ZZ
ZP3oool2000000030?ooo`2ZZZX0ZZZZ0100ZZZZ00@0oooo05EEE@000000oooo0P0000002@2ZZZX0
000005EEE@2ZZZX000000:ZZZP000000oooo05EEE@020:ZZZP030000003oool0oooo00P0oooo2P3A
cJT90?ooo`030000002ZZZX0oooo00<0oooo00@0EEEE0:ZZZP3oool0EEEE0P3oool20:ZZZP0305EE
E@000000ZZZZ0080EEEE0P0000030?ooo`030:ZZZP1EEED000000080oooo00T0000005EEE@2ZZZX0
oooo0000003oool000000?ooo`1EEED00P2ZZZX00`000000oooo0:ZZZP020:ZZZP040?ooo`1EEED0
EEEE0:ZZZPD0oooo00<0ZZZZ0?ooo`3oool0203oool:0=7=Z@T0oooo00@0000005EEE@1EEED0oooo
0P2ZZZX01@3oool0EEEE0:ZZZP3oool0EEEE00<0ZZZZ00D0EEEE0:ZZZP2ZZZX0ZZZZ05EEE@020:ZZ
ZP070000002ZZZX0ZZZZ0?ooo`1EEED0oooo0:ZZZP020?ooo`060:ZZZP3oool0ZZZZ05EEE@000000
ZZZZ0P1EEED30:ZZZP0605EEE@2ZZZX0ZZZZ0:ZZZP1EEED0oooo0P1EEED30:ZZZP030?ooo`1EEED0
EEEE00X0oooo303AcJT000/0dLfY2`3oool010000000ZZZZ0:ZZZP2ZZZX50?ooo`80000000D0oooo
0:ZZZP000000oooo0:ZZZP0205EEE@040?ooo`2ZZZX0oooo0:ZZZP8000001@2ZZZX01P000000ZZZZ
0?ooo`2ZZZX0oooo00000080EEEE00@0oooo0000002ZZZX0oooo0P0000020?ooo`0305EEE@3oool0
ZZZZ00<0ZZZZ00<000000?ooo`3oool02@3oool:0=7=Z@/0oooo00@0000005EEE@00000000000P3o
ool01@2ZZZX0EEEE0?ooo`3oool0EEEE0080ZZZZ00<0EEEE0:ZZZP2ZZZX00P3oool01@2ZZZX0EEEE
000000000000EEEE00<0ZZZZ00P0EEEE0:ZZZP2ZZZX0EEEE0000003oool0EEEE0:ZZZP80oooo00X0
EEEE0:ZZZP1EEED0EEEE0:ZZZP1EEED000000?ooo`1EEED0ZZZZ0P3oool20000000305EEE@000000
oooo00X0oooo2P3AcJT;0?ooo`070000003oool0EEEE05EEE@2ZZZX000000:ZZZP020?ooo`050000
001EEED0EEEE05EEE@3oool00P2ZZZX00`3oool0ZZZZ0:ZZZP0@0:ZZZP050?ooo`000000ZZZZ0?oo
o`2ZZZX00P1EEED01@2ZZZX0oooo0?ooo`2ZZZX0000000<0EEEE00<0ZZZZ0000003oool02P3oool:
0=7=Z@/0oooo00`0EEEE0:ZZZP1EEED0ZZZZ0?ooo`2ZZZX000000:ZZZP3oool0EEEE0:ZZZP3oool2
0:ZZZP0=0?ooo`000000oooo0000002ZZZX000000?ooo`000000ZZZZ05EEE@3oool0EEEE00000002
0?ooo`0=0:ZZZP000000EEEE0000002ZZZX000000?ooo`000000oooo0:ZZZP1EEED0oooo0:ZZZP02
0?ooo`080:ZZZP3oool0ZZZZ0?ooo`2ZZZX0EEEE0?ooo`1EEED;0?ooo`X0dLfY2`3oool01@1EEED0
ZZZZ0:ZZZP2ZZZX0oooo0080EEEE0P2ZZZX20?ooo`80EEEE00/0ZZZZ05EEE@2ZZZX0ZZZZ05EEE@00
0000ZZZZ0000002ZZZX0oooo05EEE@040:ZZZP80oooo00@0ZZZZ0000002ZZZX000000P2ZZZX01P3o
ool0EEEE0:ZZZP3oool0EEEE0?ooo`<0ZZZZ00<0oooo05EEE@2ZZZX00`2ZZZX00`1EEED0oooo0?oo
o`090?ooo``0dLfY000;0=7=Z@`0oooo0`2ZZZX0103oool000000000003oool30:ZZZP80000000<0
oooo05EEE@0000000P2ZZZX01@000000oooo0?ooo`3oool0EEEE00D0ZZZZ00<0000005EEE@3oool0
0P3oool2000000030:ZZZP1EEED0EEEE0080oooo00L000000:ZZZP000000ZZZZ0?ooo`2ZZZX00000
00@0ZZZZ303oool:0=7=Z@`0oooo00D000000?ooo`000000000005EEE@020:ZZZP80EEEE0P2ZZZX0
0`1EEED0oooo05EEE@050:ZZZP<0EEEE00H0oooo05EEE@1EEED0oooo05EEE@3oool305EEE@80ZZZZ
00D000000:ZZZP2ZZZX0EEEE0?ooo`030:ZZZP80EEEE00<0ZZZZ0?ooo`1EEED00P0000000`3oool0
ZZZZ0?ooo`0;0?ooo`X0dLfY303oool405EEE@050000002ZZZX000000:ZZZP3oool00P0000001P2Z
ZZX0EEEE05EEE@000000ZZZZ0?oooa80ZZZZ00<0000005EEE@1EEED00`0000020:ZZZP<000000`1E
EED00`2ZZZX0oooo0?ooo`0:0?ooo`X0dLfY303oool00`2ZZZX0EEEE0?ooo`020?ooo`0405EEE@00
0000ZZZZ05EEE@80oooo0P0000030?ooo`030:ZZZP3oool0ZZZZ0080EEEE00<000000:ZZZP2ZZZX0
0P0000020:ZZZP040000001EEED0oooo0:ZZZP<0oooo00<0ZZZZ0?ooo`0000000`3oool20:ZZZP03
0000001EEED0oooo0080oooo00<0EEEE0000003oool02`3oool:0=7=Z@`0oooo00D0EEEE0?ooo`3o
ool0oooo05EEE@020:ZZZP0;0000002ZZZX0EEEE0:ZZZP000000oooo05EEE@2ZZZX000000?ooo`2Z
ZZX00`3oool0101EEED0oooo0:ZZZP3oool20:ZZZP80EEEE00P0oooo0:ZZZP3oool0ZZZZ05EEE@00
0000ZZZZ05EEE@80oooo00@0ZZZZ05EEE@2ZZZX000000P2ZZZX205EEE@80oooo00<000000?ooo`3o
ool02P3oool<0=7=Z@002`3AcJT<0?ooo`80000000H0oooo0000002ZZZX0ZZZZ0000003oool30:ZZ
ZP040?ooo`1EEED0EEEE05EEE@80oooo00<0EEEE0000000000000P0000060:ZZZP@0000000@0EEEE
0:ZZZP3oool000000P1EEED00`000000ZZZZ0:ZZZP020?ooo`030000002ZZZX0ZZZZ0080oooo00<0
00000?ooo`3oool02`3oool:0=7=Z@`0oooo1@0000050:ZZZP050?ooo`2ZZZX0EEEE05EEE@3oool0
0P0000020?ooo`0405EEE@3oool0EEEE0:ZZZP80EEEE00H0ZZZZ05EEE@1EEED0EEEE0?ooo`1EEED3
0?ooo`080000003oool0EEEE05EEE@2ZZZX0oooo0:ZZZP1EEED30:ZZZP040000003oool000000000
00d0oooo2P3AcJT<0?ooo`80000000T0oooo0000003oool0oooo0:ZZZP3oool0ZZZZ0000003oool0
0`0000000`2ZZZX000000:ZZZP0@0:ZZZP80000000P0oooo000000000000ZZZZ0?ooo`000000ZZZZ
0?ooo`80ZZZZ00@0oooo0000003oool000003@3oool:0=7=Z@`0oooo0`2ZZZX02@1EEED0oooo0?oo
o`3oool0ZZZZ0?ooo`1EEED000000:ZZZP020?ooo`<0EEEE00P0oooo05EEE@1EEED0ZZZZ0?ooo`1E
EED0oooo0:ZZZP@0oooo00<0ZZZZ0?ooo`1EEED00P3oool00`1EEED0oooo0?ooo`020?ooo`080000
001EEED0ZZZZ0:ZZZP3oool000000?ooo`1EEED20:ZZZPd0oooo2P3AcJT<0?ooo`080:ZZZP1EEED0
ZZZZ0:ZZZP1EEED0oooo05EEE@0000020?ooo`0>0000001EEED0EEEE0?ooo`2ZZZX0oooo0000002Z
ZZX0EEEE0000003oool0ZZZZ0?ooo`1EEED20?ooo`80EEEE00D0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP02
0?ooo`030:ZZZP3oool0EEEE0080000000H0oooo05EEE@000000EEEE0?ooo`1EEED20:ZZZP0305EE
E@3oool0oooo00/0oooo303AcJT000/0dLfY3P3oool020000000ZZZZ0:ZZZP2ZZZX0oooo0:ZZZP00
0000oooo0P0000020:ZZZP040000001EEED0EEEE000000<0ZZZZ00<000000:ZZZP3oool00P2ZZZX0
0`3oool0EEEE000000030:ZZZP030000003oool0EEEE00@0ZZZZ00D000000?ooo`3oool0ZZZZ0?oo
o`030:ZZZP030000003oool0oooo00`0oooo2P3AcJT>0?ooo`8000000P3oool01P1EEED0oooo05EE
E@1EEED0ZZZZ05EEE@80oooo00<0EEEE0?ooo`3oool00P1EEED20:ZZZP80EEEE0P2ZZZX01P1EEED0
ZZZZ0:ZZZP1EEED0ZZZZ0?ooo`80EEEE00<0ZZZZ0?ooo`1EEED00P3oool00`1EEED0ZZZZ05EEE@02
0?ooo`0505EEE@3oool0oooo05EEE@0000003P3oool:0=7=Z@h0oooo0P000000102ZZZX000000?oo
o`0000020:ZZZP060?ooo`000000ZZZZ0:ZZZP3oool000004P2ZZZX010000000oooo0:ZZZP2ZZZX2
0?ooo`040:ZZZP00000000000?ooo`<0ZZZZ00<000000?ooo`3oool0303oool:0=7=Z@h0oooo00H0
00000?ooo`3oool0EEEE0000001EEED20?ooo`80ZZZZ00H0000005EEE@1EEED0oooo0:ZZZP3oool2
0:ZZZP040?ooo`2ZZZX0ZZZZ0:ZZZP80oooo00T0ZZZZ0?ooo`2ZZZX0oooo05EEE@2ZZZX0oooo0:ZZ
ZP3oool00P1EEED01`000000oooo0:ZZZP3oool0ZZZZ05EEE@0000000P3oool00`2ZZZX000000?oo
o`0=0?ooo`X0dLfY3P3oool010000000EEEE05EEE@1EEED30?ooo`<0ZZZZ00<0EEEE0?ooo`2ZZZX0
0`2ZZZX00`3oool0ZZZZ05EEE@020:ZZZP040?ooo`2ZZZX0ZZZZ0?ooo`80ZZZZ00P0EEEE0:ZZZP3o
ool0ZZZZ05EEE@2ZZZX0EEEE0?ooo`80EEEE0P2ZZZX30?ooo`040:ZZZP1EEED0EEEE000000h0oooo
303AcJT000/0dLfY3`3oool30:ZZZP050?ooo`000000EEEE0?ooo`1EEED0102ZZZX2000000D0ZZZZ
00H000000?ooo`2ZZZX0ZZZZ0?ooo`0000050:ZZZP8000000`2ZZZX00`000000EEEE0?ooo`020000
00040?ooo`2ZZZX0ZZZZ0:ZZZPl0oooo2P3AcJT?0?ooo`030000001EEED0oooo00<0EEEE0P2ZZZX0
10000000ZZZZ0:ZZZP0000020:ZZZP8000000`2ZZZX0103oool0EEEE0:ZZZP2ZZZX205EEE@<0ZZZZ
0P0000020:ZZZP040000002ZZZX0ZZZZ0?ooo`<0ZZZZ0P1EEED00`000000EEEE0:ZZZP0?0?ooo`X0
dLfY3`3oool01P1EEED0ZZZZ0:ZZZP000000ZZZZ000000<0oooo0P2ZZZX010000000ZZZZ05EEE@3o
ool>0:ZZZP80oooo102ZZZX40?ooo`030:ZZZP000000oooo0080ZZZZ3`3oool:0=7=Z@l0oooo00@0
ZZZZ05EEE@3oool0ZZZZ0P3oool205EEE@80oooo00@0ZZZZ0?ooo`2ZZZX0EEEE0P2ZZZX0101EEED0
oooo05EEE@1EEED50?ooo`0305EEE@3oool0oooo0080ZZZZ00D000000:ZZZP1EEED0ZZZZ0?ooo`04
05EEE@050?ooo`2ZZZX0EEEE05EEE@2ZZZX03`3oool:0=7=Z@l0oooo00H0EEEE0?ooo`2ZZZX0ZZZZ
05EEE@2ZZZX205EEE@040?ooo`2ZZZX0EEEE0?ooo`80ZZZZ00<0oooo0:ZZZP2ZZZX0102ZZZX205EE
E@070:ZZZP3oool0ZZZZ0:ZZZP000000ZZZZ0?ooo`030:ZZZP0305EEE@2ZZZX0ZZZZ0080EEEE00H0
ZZZZ05EEE@2ZZZX0ZZZZ0?ooo`2ZZZX?0?ooo``0dLfY000;0=7=Z@l0oooo0P0000000`3oool00000
0:ZZZP03000000/0ZZZZ00@000000:ZZZP1EEED0oooo1`2ZZZX00`000000ZZZZ0?ooo`030:ZZZP80
00000P2ZZZX00`000000oooo0000000@0?ooo`X0dLfY3`3oool200000080EEEE0P3oool00`1EEED0
oooo0?ooo`020:ZZZP030?ooo`2ZZZX0ZZZZ0080oooo00@0EEEE0?ooo`3oool0EEEE102ZZZX0101E
EED0oooo0?ooo`2ZZZX20?ooo`80ZZZZ00<0oooo0:ZZZP2ZZZX00P3oool205EEE@040?ooo`1EEED0
ZZZZ00000100oooo2P3AcJT?0?ooo`8000000P2ZZZX00`1EEED000000:ZZZP040:ZZZP80oooo00<0
00000:ZZZP2ZZZX03P2ZZZX00`1EEED0oooo0:ZZZP020:ZZZP050000002ZZZX0ZZZZ0?ooo`1EEED0
0P2ZZZX00`000000oooo0?ooo`0>0?ooo`X0dLfY3`3oool01@1EEED0oooo05EEE@2ZZZX000000080
oooo00@000000?ooo`3oool0oooo0P2ZZZX0103oool000000000001EEED20:ZZZP0505EEE@3oool0
EEEE0000003oool00`2ZZZX01P3oool000000000003oool0ZZZZ05EEE@<0oooo00@000000?ooo`3o
ool000000P2ZZZXA0?ooo`X0dLfY3`3oool00`1EEED0ZZZZ0?ooo`020:ZZZP030?ooo`2ZZZX0EEEE
0080oooo00D0EEEE0000003oool0EEEE0?ooo`0205EEE@030:ZZZP000000oooo00D0ZZZZ00T00000
0:ZZZP000000EEEE0?ooo`000000oooo0:ZZZP1EEED00P3oool00`1EEED0ZZZZ0:ZZZP040:ZZZQ00
oooo303AcJT000/0dLfY4@3oool40:ZZZPD0oooo00<000000:ZZZP2ZZZX00P2ZZZX01@3oool0ZZZZ
0:ZZZP3oool000000080ZZZZ00<000000:ZZZP2ZZZX01P2ZZZX010000000oooo0?ooo`1EEED20?oo
o`<0ZZZZ00<000000?ooo`3oool03`3oool:0=7=ZA40oooo0P1EEED02@000000oooo0?ooo`1EEED0
oooo0:ZZZP000000ZZZZ0000000205EEE@030:ZZZP1EEED0oooo0080EEEE00<0oooo0000003oool0
0P3oool02P1EEED0oooo05EEE@2ZZZX0EEEE0:ZZZP000000ZZZZ0000002ZZZX205EEE@050?ooo`00
0000000005EEE@0000004@3oool:0=7=ZA40oooo00P0ZZZZ0?ooo`1EEED0EEEE0:ZZZP000000ZZZZ
0?ooo`80ZZZZ00<0oooo0000000000003P2ZZZX00`000000oooo0?ooo`020:ZZZP040?ooo`2ZZZX0
00000:ZZZP80EEEE00<0oooo0000003oool0403oool:0=7=ZA40oooo0P2ZZZX205EEE@050000002Z
ZZX0EEEE05EEE@2ZZZX00P000000103oool0ZZZZ0?ooo`1EEED20?ooo`0305EEE@3oool0ZZZZ00L0
oooo0P2ZZZX010000000ZZZZ0:ZZZP1EEED20:ZZZP030000001EEED0EEEE0080ZZZZ4@3oool:0=7=
ZA40oooo00@0EEEE0:ZZZP3oool0oooo0`2ZZZX205EEE@<0ZZZZ00@0EEEE0?ooo`3oool0oooo1P2Z
ZZX00`3oool0ZZZZ0?ooo`020?ooo`80EEEE00D0ZZZZ05EEE@1EEED0EEEE0?ooo`020:ZZZP80oooo
0P2ZZZXA0?ooo``0dLfY000;0=7=ZA40oooo102ZZZX0103oool000000000003oool50:ZZZP050?oo
o`2ZZZX0EEEE0?ooo`000000102ZZZX20?ooo`0305EEE@2ZZZX0oooo00<0ZZZZ00H000000:ZZZP3o
ool0ZZZZ0000003oool30:ZZZQ80oooo2P3AcJTA0?ooo`030:ZZZP000000oooo0080000000<0EEEE
0?ooo`0000000`3oool01@1EEED0ZZZZ0:ZZZP1EEED0ZZZZ0080EEEE00<0ZZZZ05EEE@1EEED00P2Z
ZZX00`1EEED0ZZZZ0:ZZZP030:ZZZP040?ooo`000000oooo00000080EEEE0P0000000`3oool00000
0?ooo`0A0?ooo`X0dLfY4@3oool00`2ZZZX0EEEE05EEE@0205EEE@080000002ZZZX000000:ZZZP00
0000ZZZZ0000003oool>0:ZZZP050?ooo`2ZZZX0ZZZZ0000002ZZZX00`00000405EEEA80oooo2P3A
cJTA0?ooo`0305EEE@3oool0oooo0080oooo00@0ZZZZ0?ooo`1EEED0ZZZZ0P1EEED00`2ZZZX0oooo
0:ZZZP040?ooo`040000003oool0ZZZZ000000<0oooo00P000000:ZZZP3oool0000005EEE@000000
ZZZZ05EEE@80ZZZZ00<0oooo0000003oool04`3oool:0=7=ZA40oooo00D0EEEE0:ZZZP000000ZZZZ
000000020:ZZZP0905EEE@3oool0EEEE05EEE@3oool0ZZZZ05EEE@2ZZZX0EEEE0080ZZZZ1@1EEED0
102ZZZX0EEEE0:ZZZP1EEED20:ZZZP0305EEE@2ZZZX0oooo0080EEEE00D0ZZZZ0000003oool00000
0:ZZZP0B0?ooo``0dLfY000;0=7=ZA80oooo0P0000001P3oool000000:ZZZP2ZZZX000000?ooo`D0
ZZZZ00D000000:ZZZP000000ZZZZ0?ooo`020:ZZZP80oooo00<000000:ZZZP1EEED00P2ZZZX01@3o
ool0ZZZZ0?ooo`3oool000000080ZZZZ00@000000?ooo`00000000004P3oool:0=7=ZA80oooo0P00
00001@3oool00000000000000000ZZZZ0080EEEE00L0ZZZZ0?ooo`1EEED0oooo0:ZZZP1EEED0oooo
0080ZZZZ00P0EEEE0:ZZZP2ZZZX0EEEE0?ooo`1EEED0ZZZZ0?ooo`80EEEE00<0ZZZZ05EEE@1EEED0
0P2ZZZX500000180oooo2P3AcJTB0?ooo`@000000P3oool01@2ZZZX0oooo0000003oool000000100
ZZZZ0P3oool01`2ZZZX0oooo0:ZZZP2ZZZX0oooo0000003oool00P00000B0?ooo`X0dLfY4P3oool0
0`000000ZZZZ0?ooo`030?ooo`0:05EEE@2ZZZX000000000002ZZZX0EEEE0:ZZZP000000EEEE0?oo
o`80000000T0EEEE0:ZZZP000000EEEE0?ooo`1EEED000000:ZZZP1EEED00`0000000`2ZZZX0EEEE
05EEE@030?ooo`030:ZZZP000000oooo0140oooo2P3AcJTB0?ooo`040000001EEED0oooo0?ooo`80
ZZZZ00<0oooo05EEE@2ZZZX00P3oool01@1EEED0oooo0:ZZZP3oool0EEEE00D0ZZZZ00D0oooo05EE
E@3oool0ZZZZ0?ooo`0205EEE@040?ooo`1EEED0EEEE0?ooo`80ZZZZ00@0oooo05EEE@1EEED00000
4P3oool<0=7=Z@002`3AcJTD0?ooo`@0ZZZZ00<0oooo0:ZZZP0000000P3oool00`2ZZZX000000:ZZ
ZP020:ZZZP050000003oool000000:ZZZP3oool0102ZZZX00`000000ZZZZ0?ooo`020?ooo`030:ZZ
ZP3oool0ZZZZ0080ZZZZ00<000000?ooo`3oool04P3oool:0=7=ZA@0oooo00/0EEEE0000003oool0
oooo05EEE@000000EEEE0:ZZZP000000oooo000000020:ZZZP80EEEE00H0ZZZZ0?ooo`1EEED0ZZZZ
0?ooo`1EEED20:ZZZP070000003oool0ZZZZ0:ZZZP1EEED0000005EEE@020?ooo`800000503oool:
0=7=ZA@0oooo00H0ZZZZ0000002ZZZX000000?ooo`0000040:ZZZP030?ooo`2ZZZX0oooo0080ZZZZ
00@000000:ZZZP00000000000P2ZZZX01P3oool0ZZZZ0?ooo`2ZZZX000000:ZZZP80000000<0oooo
0:ZZZP2ZZZX00P00000D0?ooo`X0dLfY5@3oool01@2ZZZX0EEEE0?ooo`2ZZZX0EEEE00<0oooo00P0
EEEE0?ooo`3oool0oooo05EEE@000000ZZZZ0?ooo`<0ZZZZ00D0EEEE0?ooo`3oool0oooo05EEE@02
0?ooo`80EEEE0P2ZZZX00`1EEED0ZZZZ05EEE@0D0?ooo`X0dLfY503oool40:ZZZP030?ooo`1EEED0
EEEE0080ZZZZ00D0oooo0:ZZZP2ZZZX0ZZZZ0?ooo`060:ZZZP050?ooo`2ZZZX0ZZZZ0:ZZZP3oool0
0P2ZZZX00`3oool0EEEE0?ooo`030:ZZZP0305EEE@3oool0oooo0180oooo303AcJT000/0dLfY503o
ool40:ZZZP050?ooo`000000EEEE0?ooo`1EEED00P3oool20:ZZZP080?ooo`1EEED0EEEE0:ZZZP3o
ool0EEEE0:ZZZP3oool20:ZZZP80oooo00D0EEEE0?ooo`00000000000?ooo`030:ZZZQD0oooo2P3A
cJTD0?ooo`040:ZZZP000000EEEE0?ooo`80EEEE00<0oooo05EEE@3oool00P3oool30:ZZZP0605EE
E@3oool000000:ZZZP3oool0EEEE0`2ZZZX20?ooo`030:ZZZP1EEED0EEEE0080EEEE00<0000005EE
E@0000005@3oool:0=7=ZA@0oooo00P0ZZZZ05EEE@2ZZZX0ZZZZ0000002ZZZX000000?ooo`<0ZZZZ
00D000000:ZZZP2ZZZX0ZZZZ05EEE@020:ZZZP0505EEE@3oool0ZZZZ0:ZZZP0000000P2ZZZX30?oo
o`050:ZZZP000000oooo0:ZZZP1EEED05@3oool:0=7=ZA@0oooo00<000000:ZZZP1EEED00P3oool0
1`1EEED0oooo0000003oool000000?ooo`0000000P2ZZZX30?ooo`0305EEE@3oool0ZZZZ00<0ZZZZ
00H0oooo0000001EEED000000:ZZZP1EEED20?ooo`0305EEE@2ZZZX0oooo01@0oooo2P3AcJTD0?oo
o`060000001EEED0oooo05EEE@3oool0EEEE0`2ZZZX0201EEED0ZZZZ05EEE@1EEED0ZZZZ0?ooo`2Z
ZZX0oooo102ZZZX205EEE@030:ZZZP1EEED000000080ZZZZ00D0EEEE0?ooo`3oool0oooo05EEE@0E
0?ooo``0dLfY000;0=7=ZAD0oooo0P0000000`3oool000000:ZZZP02000000030:ZZZP000000oooo
0080ZZZZ00P0oooo0000002ZZZX0oooo0000002ZZZX000000?ooo`80ZZZZ00@0oooo000000000000
00000P2ZZZX010000000oooo00000000000E0?ooo`X0dLfY5@3oool200000080EEEE00D0oooo05EE
E@2ZZZX0ZZZZ000000030:ZZZP080?ooo`1EEED0oooo0?ooo`000000oooo05EEE@3oool30:ZZZP07
0000002ZZZX0ZZZZ05EEE@3oool0EEEE0:ZZZP02000001D0oooo2P3AcJTE0?ooo`8000000P2ZZZX0
0`1EEED000000:ZZZP02000000040:ZZZP3oool0ZZZZ0:ZZZP80000000<0ZZZZ0000000000000`2Z
ZZX00`000000ZZZZ000000020:ZZZP040?ooo`1EEED0ZZZZ0:ZZZP8000005@3oool:0=7=ZAD0oooo
0P2ZZZX205EEE@040?ooo`2ZZZX0000000000080EEEE00D0oooo0:ZZZP2ZZZX0ZZZZ000000020?oo
o`050000003oool0ZZZZ0:ZZZP3oool00P1EEED2000000030:ZZZP3oool0EEEE00<0ZZZZ5@3oool:
0=7=ZAD0oooo00H0ZZZZ05EEE@2ZZZX0ZZZZ05EEE@3oool205EEE@030?ooo`2ZZZX0ZZZZ00<0ZZZZ
00D0000005EEE@2ZZZX000000?ooo`040:ZZZP050?ooo`000000EEEE0?ooo`1EEED00P2ZZZX00`1E
EED0ZZZZ0?ooo`0D0?ooo``0dLfY000;0=7=ZAL0oooo102ZZZX0103oool0EEEE0:ZZZP0000030?oo
o`80ZZZZ0P0000020:ZZZP80oooo00<0ZZZZ0000002ZZZX00P3oool30:ZZZP030000003oool0oooo
01D0oooo2P3AcJTG0?ooo`80EEEE00X000000?ooo`3oool0EEEE0:ZZZP1EEED0oooo0000001EEED0
ZZZZ101EEED00`2ZZZX0EEEE0000000205EEE@030:ZZZP3oool0oooo0080000000<0EEEE0000003o
ool05P3oool:0=7=ZAL0oooo00@0ZZZZ0?ooo`1EEED0EEEE0P2ZZZX010000000ZZZZ05EEE@3oool2
0:ZZZP80000000D0ZZZZ0000002ZZZX0ZZZZ0?ooo`020:ZZZP80000000D0ZZZZ05EEE@1EEED0oooo
0000000G0?ooo`X0dLfY5`3oool01P2ZZZX0oooo0?ooo`1EEED0oooo05EEE@80ZZZZ00<0oooo0:ZZ
ZP3oool01@3oool00`1EEED0oooo0:ZZZP030:ZZZP030000003oool0oooo0080oooo00<000000?oo
o`3oool05@3oool:0=7=ZAL0oooo101EEED30?ooo`D0ZZZZ00@0EEEE0000002ZZZX0EEEE1@2ZZZX3
0?ooo`040:ZZZP1EEED0EEEE000001L0oooo303AcJT000/0dLfY5`3oool40:ZZZP040?ooo`2ZZZX0
000005EEE@<0oooo00<000000?ooo`2ZZZX01P3oool0101EEED000000000003oool30:ZZZQP0oooo
2P3AcJTG0?ooo`030:ZZZP000000oooo0080000000T0oooo05EEE@3oool0EEEE0:ZZZP000000oooo
05EEE@3oool00P1EEED01@3oool000000:ZZZP1EEED0oooo0080EEEE0P0000000`3oool000000?oo
o`0G0?ooo`X0dLfY5`3oool00`2ZZZX0EEEE05EEE@0205EEE@070000002ZZZX0oooo0:ZZZP000000
ZZZZ000000020:ZZZP090?ooo`2ZZZX000000:ZZZP000000EEEE0?ooo`2ZZZX0000000@0EEEE603o
ool:0=7=ZAL0oooo0P2ZZZX00`1EEED0oooo0:ZZZP020000000>0?ooo`000000EEEE0:ZZZP3oool0
00000?ooo`1EEED0000005EEE@2ZZZX0EEEE0000003oool2000000040:ZZZP1EEED0EEEE0:ZZZQP0
oooo2P3AcJTG0?ooo`030:ZZZP1EEED0oooo00@0ZZZZ00D0EEEE0:ZZZP000000ZZZZ05EEE@020:ZZ
ZP050?ooo`2ZZZX0EEEE0:ZZZP0000000P1EEED01P2ZZZX0EEEE0:ZZZP2ZZZX0oooo05EEEAP0oooo
303AcJT000/0dLfY603oool2000000060?ooo`000000ZZZZ0:ZZZP000000EEEE0P0000001@1EEED0
oooo05EEE@1EEED0oooo00D000000P2ZZZX010000000oooo00000000000H0?ooo`X0dLfY603oool2
000000070?ooo`000000ZZZZ0:ZZZP1EEED0oooo05EEE@040:ZZZP0405EEE@2ZZZX000000:ZZZP<0
EEEE00<0ZZZZ0000000000000`00000H0?ooo`X0dLfY603oool40000000:0:ZZZP3oool0EEEE0:ZZ
ZP000000oooo0:ZZZP3oool0000005EEE@<0oooo0P0000001@1EEED0oooo0?ooo`000000oooo0080
0000603oool:0=7=ZAP0oooo00H0EEEE0?ooo`1EEED0ZZZZ0000002ZZZX400000080oooo00@0EEEE
0:ZZZP3oool0oooo0P000000102ZZZX000000:ZZZP0000020:ZZZP030?ooo`1EEED0oooo01L0oooo
2P3AcJTH0?ooo`0305EEE@2ZZZX0oooo0080ZZZZ00@0oooo0:ZZZP3oool0oooo0`2ZZZX00`3oool0
00000:ZZZP020:ZZZP040?ooo`1EEED0ZZZZ0?ooo`@0ZZZZ00<0EEEE0?ooo`3oool05P3oool<0=7=
Z@002`3AcJTJ0?ooo`@0ZZZZ0P3oool0102ZZZX0oooo0:ZZZP0000020:ZZZP030000002ZZZX0oooo
0080ZZZZ00D0oooo0:ZZZP2ZZZX0ZZZZ0000000J0?ooo`X0dLfY6P3oool0101EEED000000?ooo`3o
ool205EEE@80ZZZZ00@000000:ZZZP1EEED0oooo102ZZZX0103oool0EEEE0?ooo`3oool2000001X0
oooo2P3AcJTJ0?ooo`040:ZZZP000000ZZZZ00000080EEEE00h0oooo0:ZZZP000000ZZZZ0?ooo`00
0000ZZZZ0000002ZZZX0oooo0000001EEED000000:ZZZP8000006P3oool:0=7=ZAX0oooo0`2ZZZX0
1@1EEED0ZZZZ0?ooo`000000ZZZZ0080oooo00<0EEEE0?ooo`3oool00P2ZZZX2000000030:ZZZP1E
EED000000080ZZZZ6P3oool:0=7=ZAX0oooo00/0EEEE0:ZZZP3oool0oooo0:ZZZP3oool0ZZZZ05EE
E@000000ZZZZ05EEE@020:ZZZP80EEEE0`2ZZZX20?ooo`80ZZZZ6P3oool<0=7=Z@002`3AcJTJ0?oo
o`@0ZZZZ00P0oooo0000001EEED0ZZZZ0?ooo`2ZZZX0EEEE0?ooo`<0ZZZZ00<0EEEE0000003oool0
0`2ZZZXK0?ooo`X0dLfY6P3oool01@2ZZZX000000000003oool0EEEE00<0ZZZZ0P3oool00`000000
EEEE0?ooo`030:ZZZP80EEEE00<0oooo05EEE@0000006`3oool:0=7=ZAX0oooo00@0ZZZZ05EEE@3o
ool0ZZZZ0P0000020:ZZZP0405EEE@2ZZZX0oooo0?ooo`@0ZZZZ00D0EEEE0000002ZZZX0ZZZZ05EE
E@0K0?ooo`X0dLfY6P3oool00`1EEED0oooo0:ZZZP020:ZZZP80oooo00<0ZZZZ0?ooo`0000000P2Z
ZZX00`000000ZZZZ0:ZZZP020?ooo`80ZZZZ7@3oool:0=7=ZAX0oooo00X0EEEE0:ZZZP3oool0ZZZZ
0000001EEED0ZZZZ05EEE@2ZZZX0oooo0P2ZZZX20?ooo`0705EEE@2ZZZX0ZZZZ0000002ZZZX00000
0:ZZZP0K0?ooo``0dLfY000;0=7=ZA/0oooo00D000000?ooo`3oool000000:ZZZP0200000080oooo
00@0ZZZZ0000003oool0oooo0P0000000`2ZZZX000000?ooo`02000001/0oooo2P3AcJTK0?ooo`03
0000002ZZZX0EEEE0080EEEE00@0oooo0:ZZZP3oool000000P1EEED00`000000EEEE0:ZZZP020?oo
o`80EEEE0P00000K0?ooo`X0dLfY6`3oool010000000ZZZZ0:ZZZP2ZZZX2000000030:ZZZP000000
oooo00<0oooo00@000000:ZZZP000000EEEE0P2ZZZX2000001/0oooo2P3AcJTK0?ooo`050000003o
ool0ZZZZ0:ZZZP0000000`2ZZZX01@000000oooo000000000000oooo0080ZZZZ00D0oooo0:ZZZP2Z
ZZX0ZZZZ0000000K0?ooo`X0dLfY6`3oool010000000EEEE0?ooo`3oool20:ZZZP040?ooo`1EEED0
ZZZZ0?ooo`80ZZZZ00@0EEEE0?ooo`2ZZZX0ZZZZ0P3oool00`1EEED000000?ooo`0J0?ooo``0dLfY
000;0=7=ZA`0oooo00<000000:ZZZP2ZZZX00P2ZZZX00`3oool000000:ZZZP030:ZZZP80oooo102Z
ZZXM0?ooo`X0dLfY703oool010000000EEEE05EEE@0000030?ooo`050:ZZZP3oool000000:ZZZP00
00000P3oool00`000000EEEE05EEE@0M0?ooo`X0dLfY703oool00`000000ZZZZ0?ooo`0205EEE@04
0?ooo`2ZZZX0EEEE0:ZZZP<0EEEE00D0oooo05EEE@1EEED0oooo0:ZZZP0M0?ooo`X0dLfY703oool0
1@1EEED0oooo0:ZZZP2ZZZX000000080oooo0P2ZZZX01`3oool0ZZZZ0?ooo`3oool000000?ooo`2Z
ZZX07P3oool:0=7=ZA`0oooo00<0EEEE0:ZZZP2ZZZX00`2ZZZX01P1EEED0ZZZZ000000000000ZZZZ
000000D0ZZZZ7@3oool<0=7=Z@002`3AcJTM0?ooo`@0ZZZZ00<0oooo0:ZZZP2ZZZX00`2ZZZX00`00
0000oooo0:ZZZP030:ZZZQd0oooo2P3AcJTM0?ooo`050:ZZZP00000000000000001EEED00P2ZZZX2
0?ooo`070:ZZZP000000EEEE0000003oool000000:ZZZP0M0?ooo`X0dLfY7@3oool00`2ZZZX0EEEE
05EEE@0205EEE@<0000000<0oooo0000002ZZZX0101EEED00`2ZZZX0oooo0?ooo`0K0?ooo`X0dLfY
7@3oool00`000000ZZZZ0:ZZZP02000000040?ooo`1EEED0EEEE0?ooo`80EEEE0P0000000`1EEED0
ZZZZ0000000M0?ooo`X0dLfY7@3oool020000000EEEE0?ooo`1EEED0oooo0:ZZZP1EEED000000P1E
EED20?ooo`0405EEE@3oool0EEEE000001d0oooo303AcJT000/0dLfY803oool00`000000ZZZZ0:ZZ
ZP060:ZZZP030000002ZZZX0oooo01h0oooo2P3AcJTR0?ooo`030:ZZZP1EEED0ZZZZ0080EEEE00@0
ZZZZ0?ooo`3oool0ZZZZ7`3oool:0=7=ZAl0oooo00<000000:ZZZP3oool00P2ZZZX00`3oool00000
0:ZZZP020?ooo`80ZZZZ7`3oool:0=7=ZB80oooo00D0EEEE0:ZZZP2ZZZX000000:ZZZP030?ooo`03
05EEE@3oool0oooo01d0oooo2P3AcJTO0?ooo`050:ZZZP000000ZZZZ0:ZZZP3oool00P1EEED01@3o
ool0ZZZZ0:ZZZP000000EEEE01l0oooo303AcJT000/0dLfY7`3oool00`000000ZZZZ0:ZZZP080:ZZ
ZR00oooo2P3AcJTO0?ooo`0;0000001EEED000000?ooo`000000oooo0:ZZZP000000oooo0000001E
EED0803oool:0=7=ZAl0oooo00<000000:ZZZP0000000P2ZZZX20?ooo`80ZZZZ00<000000:ZZZP3o
ool07`3oool:0=7=ZAl0oooo00@000000:ZZZP2ZZZX0ZZZZ0P3oool00`2ZZZX0oooo05EEE@020:ZZ
ZR00oooo2P3AcJTO0?ooo`040000001EEED0EEEE05EEE@@0ZZZZ0`1EEEDP0?ooo``0dLfY000;0=7=
ZB00oooo102ZZZX00`1EEED0oooo0:ZZZP030:ZZZR00oooo2P3AcJTP0?ooo`040:ZZZP0000000000
00000080oooo00@0000005EEE@000000ZZZZ803oool:0=7=ZB00oooo00D0ZZZZ05EEE@3oool0ZZZZ
000000030:ZZZP0305EEE@2ZZZX0oooo01l0oooo2P3AcJTP0?ooo`80ZZZZ00@0EEEE0?ooo`3oool0
EEEE0P3oool20:ZZZR00oooo2P3AcJTP0?ooo`050:ZZZP1EEED0ZZZZ05EEE@2ZZZX00P1EEED00`3o
ool0EEEE0:ZZZP0P0?ooo``0dLfY000;0=7=ZB<0oooo00D000000:ZZZP2ZZZX000000:ZZZP0R0?oo
o`X0dLfY8`3oool405EEE@030:ZZZP3oool0oooo0200oooo2P3AcJTR0?ooo`8000000P2ZZZX00`00
0000ZZZZ0?ooo`0Q0?ooo`X0dLfY8P3oool205EEE@040?ooo`2ZZZX0EEEE00000280oooo2P3AcJTR
0?ooo`0605EEE@3oool0ZZZZ05EEE@3oool000008P3oool<0=7=Z@002`3AcJTR0?ooo`030000002Z
ZZX0ZZZZ0080ZZZZ8`3oool:0=7=ZB80oooo00<0000005EEE@0000000P1EEEDS0?ooo`X0dLfY8P3o
ool01@000000ZZZZ05EEE@3oool0ZZZZ02<0oooo2P3AcJTR0?ooo`050:ZZZP1EEED0oooo0?ooo`1E
EED08`3oool:0=7=ZB80oooo00D0ZZZZ05EEE@3oool0ZZZZ05EEE@0S0?ooo``0dLfY000;0=7=ZB<0
oooo00@0ZZZZ0?ooo`2ZZZX0ZZZZ8`3oool:0=7=ZB<0oooo00@0ZZZZ0?ooo`000000ZZZZ8`3oool:
0=7=ZB<0oooo00@0ZZZZ05EEE@1EEED0ZZZZ8`3oool:0=7=ZB<0oooo0P1EEED00`2ZZZX0EEEE0?oo
o`0R0?ooo`X0dLfY8`3oool205EEE@030:ZZZP1EEED0oooo0280oooo303AcJT000/0dLfY903oool0
0`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool0
0`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool0
0`2ZZZX0oooo0?ooo`0S0?ooo``0dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY
003o0=7=ZK80dLfY003o0=7=ZK80dLfY000;0=7=Z@060?ooo`00000000000?ooo`2ZZZX000000P3o
ool01P2ZZZX0EEEE0000002ZZZX0EEEE0:ZZZP8000000P1EEED20:ZZZP@000000P3oool010000000
oooo05EEE@1EEED5000000050:ZZZP3oool0ZZZZ0:ZZZP3oool010000000101EEED0oooo0?ooo`2Z
ZZX20?ooo`@000000P2ZZZX010000000EEEE0?ooo`0000030:ZZZP030000002ZZZX0ZZZZ0080oooo
0P000000103oool000000000003oool:0=7=Z@040?ooo`2ZZZX0oooo0?ooo`8000000`1EEED20:ZZ
ZP040000001EEED0oooo05EEE@80oooo00<0EEEE0?ooo`0000000P2ZZZX00`3oool0EEEE05EEE@02
05EEE@<0ZZZZ00@0EEEE0?ooo`1EEED000001@1EEED00`3oool0000005EEE@0205EEE@@0ZZZZ0P1E
EED20?ooo`80ZZZZ00/000000?ooo`000000oooo0000001EEED0oooo0:ZZZP000000ZZZZ0?ooo`02
05EEE@030?ooo`00000000000080oooo00<000000?ooo`3AcJT02@3AcJT<0?ooo`<000000P3oool0
0`000000oooo0?ooo`040?ooo`030000001EEED0oooo00L0oooo0P2ZZZX20?ooo`030:ZZZP000000
oooo00H0oooo0P1EEED01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P00
000=0?ooo`X0dLfY703oool200000080EEEE00@0000005EEE@000000EEEE0P3oool00`1EEED0oooo
05EEE@020000000305EEE@000000oooo01`0oooo2P3AcJTF0?ooo`H0ZZZZ101EEED01`2ZZZX00000
0:ZZZP1EEED0ZZZZ0?ooo`1EEED00P000000102ZZZX0EEEE05EEE@1EEED20:ZZZP0505EEE@2ZZZX0
ZZZZ0000002ZZZX05P3oool<0=7=Z@002`3AcJT01@3oool0000005EEE@3oool0ZZZZ00D000000`2Z
ZZX02P000000oooo0?ooo`000000ZZZZ05EEE@2ZZZX000000:ZZZP0000020:ZZZP080?ooo`000000
00000000003oool0000005EEE@2ZZZX20?ooo`040000003oool0ZZZZ00000080oooo00@0ZZZZ05EE
E@000000oooo0P0000001@2ZZZX0oooo0:ZZZP2ZZZX0000000<0ZZZZ00<0EEEE0000000000000P3o
ool01@000000EEEE0:ZZZP2ZZZX0EEEE00@000000P3oool00`1EEED0oooo0?ooo`0:0=7=Z@050?oo
o`000000EEEE05EEE@0000000P1EEED02`2ZZZX0000005EEE@2ZZZX0EEEE0000002ZZZX000000?oo
o`1EEED0ZZZZ0080000000D0oooo0000001EEED000000:ZZZP0205EEE@070000001EEED000000?oo
o`2ZZZX000000?ooo`0505EEE@80oooo0P0000001`3oool000000?ooo`000000ZZZZ05EEE@2ZZZX0
0P1EEED04P000000EEEE000000000000oooo05EEE@3oool000000:ZZZP3oool0EEEE0:ZZZP1EEED0
00000:ZZZP000000EEEE00000080EEEE0P3oool:0=7=Z@d0oooo00@0ZZZZ0?ooo`3oool0oooo0P1E
EED20?ooo`80EEEE00<0ZZZZ0000000000001`3oool010000000EEEE0?ooo`0000030?ooo`030000
003oool0000000@0oooo0`0000001`3oool0EEEE05EEE@2ZZZX0oooo05EEE@0000000`3oool00`2Z
ZZX0oooo0?ooo`0;0?ooo`X0dLfY703oool200000080oooo0P0000000`1EEED0ZZZZ0:ZZZP020:ZZ
ZP<0000000<0ZZZZ0?ooo`0000007@3oool:0=7=ZAL0oooo00D0EEEE0:ZZZP1EEED0EEEE0:ZZZP03
05EEE@050000002ZZZX0ZZZZ0:ZZZP1EEED00P00000205EEE@80ZZZZ101EEED01@2ZZZX0EEEE05EE
E@2ZZZX0EEEE01L0oooo303AcJT000/0dLfY0`3oool02@000000oooo000000000000EEEE0:ZZZP00
0000EEEE000000050?ooo`80EEEE00<0oooo0:ZZZP1EEED00P000000102ZZZX0oooo0000002ZZZX2
05EEE@80ZZZZ10000000103oool0ZZZZ0000002ZZZX20000000305EEE@2ZZZX0EEEE00<0ZZZZ00L0
oooo0:ZZZP000000000005EEE@2ZZZX0oooo0080EEEE103oool01P2ZZZX0000005EEE@000000ZZZZ
05EEE@80000000<0EEEE0000003oool00P3oool:0=7=Z@<0oooo00D0000005EEE@000000EEEE0000
000405EEE@80oooo00<0000005EEE@2ZZZX00`3oool200000080EEEE00D0oooo05EEE@0000000000
05EEE@020?ooo`0605EEE@2ZZZX0ZZZZ05EEE@2ZZZX0EEEE1@2ZZZX30?ooo`8000000P1EEED01@3o
ool0000005EEE@000000EEEE0080oooo00@000000:ZZZP00000000000P3oool205EEE@030:ZZZP1E
EED000000080000000<0EEEE0000003oool00P3oool:0=7=Z@h0oooo00<000000?ooo`2ZZZX00P00
0000102ZZZX000000000000000030?ooo`0905EEE@3oool0oooo0?ooo`000000oooo0:ZZZP3oool0
00000080EEEE00@0oooo05EEE@000000oooo0P2ZZZX01@000000oooo0000003oool0EEEE0080oooo
0`0000000`3oool0ZZZZ000000020:ZZZP8000003P3oool:0=7=ZAd0oooo00D0ZZZZ0?ooo`2ZZZX0
ZZZZ000000020?ooo`030000001EEED0oooo0080000000@0ZZZZ05EEE@3oool0ZZZZ7@3oool:0=7=
ZAD0oooo00<000000?ooo`1EEED00P2ZZZX0101EEED0oooo05EEE@2ZZZX20000000@05EEE@3oool0
00000:ZZZP1EEED000000:ZZZP1EEED0oooo05EEE@3oool000000:ZZZP1EEED0oooo05EEE@<0ZZZZ
00<0oooo0000003oool0503oool<0=7=Z@002`3AcJT40?ooo`80000000<0ZZZZ0000001EEED00`1E
EED5000000090?ooo`000000000005EEE@000000ZZZZ0000002ZZZX0oooo00<0000000<0ZZZZ05EE
E@0000000P3oool2000000040?ooo`2ZZZX000000:ZZZP80oooo00L0ZZZZ05EEE@2ZZZX0EEEE0000
002ZZZX0oooo00<0ZZZZ2P00000205EEE@040000001EEED000000:ZZZP800000103oool:0=7=Z@@0
oooo00<0ZZZZ0?ooo`0000000P00000305EEE@050?ooo`1EEED0oooo05EEE@2ZZZX00P3oool205EE
E@030:ZZZP3oool0oooo00<0ZZZZ00<0oooo0:ZZZP0000000P0000001P3oool0EEEE0?ooo`000000
oooo05EEE@80000000<0EEEE0?ooo`2ZZZX00P0000020?ooo`0:05EEE@2ZZZX0ZZZZ0000003oool0
ZZZZ0?ooo`1EEED0oooo05EEE@80ZZZZ00<0oooo05EEE@3oool00P1EEED00`3oool0000000000002
0?ooo`030000003oool0oooo0080oooo2P3AcJT@0?ooo`0605EEE@3oool0ZZZZ0?ooo`000000ZZZZ
0P0000020?ooo`040000003oool0ZZZZ00000080oooo00<0EEEE0?ooo`0000000P3oool010000000
oooo05EEE@3oool205EEE@050?ooo`000000oooo0?ooo`0000000P3oool02@2ZZZX000000:ZZZP2Z
ZZX0oooo0:ZZZP3oool0EEEE0:ZZZP0?0?ooo`X0dLfY7P3oool03P1EEED0ZZZZ0?ooo`2ZZZX0oooo
0000002ZZZX0oooo0000003oool0ZZZZ0?ooo`2ZZZX0EEEE7P3oool:0=7=ZAH0oooo00D0ZZZZ05EE
E@1EEED0ZZZZ0000000205EEE@030:ZZZP1EEED0oooo008000000P2ZZZX0103oool000000:ZZZP1E
EED2000000040:ZZZP1EEED0ZZZZ00000080EEEE00@0ZZZZ05EEE@1EEED0ZZZZ5P3oool<0=7=Z@00
2`3AcJT50?ooo`80000000@0oooo000000000000oooo0`00000205EEE@030000002ZZZX000000080
000000<0oooo0000000000000P3oool00`1EEED0ZZZZ0:ZZZP020?ooo`030000002ZZZX0oooo0080
000000H0oooo0:ZZZP000000ZZZZ0?ooo`2ZZZX30?ooo`030000002ZZZX000000080oooo0P000000
0`3oool0EEEE000000040000000805EEE@000000EEEE0000003oool0ZZZZ0000003oool2000000D0
oooo2P3AcJT50?ooo`030000003oool0oooo0080000000@0oooo05EEE@2ZZZX0EEEE0P3oool205EE
E@040000001EEED0ZZZZ0:ZZZP<0000000@0oooo05EEE@2ZZZX0EEEE0P3oool30000000405EEE@3o
ool0000000000080oooo0P0000030?ooo`80ZZZZ0P3oool00`000000ZZZZ000000020:ZZZP0:05EE
E@000000EEEE05EEE@000000oooo05EEE@2ZZZX0EEEE0?ooo`80000000<0oooo0:ZZZP0000001@3o
ool:0=7=Z@l0oooo0P0000020?ooo`0505EEE@3oool000000?ooo`1EEED00P3oool01P1EEED0ZZZZ
0?ooo`000000ZZZZ0?ooo`80EEEE00H000000?ooo`2ZZZX000000?ooo`00000205EEE@060000002Z
ZZX000000000002ZZZX000000P3oool01P000000oooo0000003oool0EEEE0?ooo`800000403oool:
0=7=ZAl0oooo00<0ZZZZ0?ooo`1EEED00P1EEED20?ooo`<0EEEE00<0oooo0:ZZZP3oool07P3oool:
0=7=ZAH0oooo0P00000205EEE@80ZZZZ101EEED01@2ZZZX0oooo05EEE@1EEED0ZZZZ0080EEEE00<0
00000?ooo`2ZZZX00`1EEED20:ZZZP<0EEEE00<0ZZZZ0000003oool05@3oool<0=7=Z@002`3AcJT6
0?ooo`0305EEE@3oool0oooo00<000000P1EEED20:ZZZP0405EEE@2ZZZX0ZZZZ00000080oooo00@0
EEEE0?ooo`3oool0oooo0P000000101EEED0oooo0?ooo`1EEED200000080EEEE0P000000101EEED0
00000000000000030?ooo`0305EEE@000000oooo0080oooo00<0000005EEE@3oool00P0000001`2Z
ZZX0EEEE05EEE@000000ZZZZ05EEE@2ZZZX00P000000102ZZZX0oooo0?ooo`0000060?ooo`X0dLfY
1P3oool205EEE@030000001EEED0000000@0EEEE00<000000:ZZZP2ZZZX00P2ZZZX0101EEED0ZZZZ
05EEE@0000020?ooo`<0EEEE00<0000005EEE@0000000P00000205EEE@8000000P1EEED200000080
EEEE00<000000:ZZZP1EEED0103oool00`1EEED0ZZZZ05EEE@020:ZZZP0305EEE@2ZZZX000000080
EEEE00<0ZZZZ05EEE@0000000P0000000`1EEED000000?ooo`050?ooo`X0dLfY403oool00`2ZZZX0
oooo000000030?ooo`040:ZZZP000000oooo0:ZZZP80000000@0oooo0:ZZZP3oool0oooo0P000000
102ZZZX0000005EEE@3oool4000000040:ZZZP3oool0ZZZZ05EEE@80000000X0ZZZZ0?ooo`000000
ZZZZ0?ooo`000000oooo0000003oool0ZZZZ403oool:0=7=ZA`0oooo00@000000?ooo`3oool0EEEE
100000000`1EEED000000000000300000200oooo2P3AcJTE0?ooo`070000003oool0ZZZZ05EEE@00
0000EEEE0:ZZZP0505EEE@080:ZZZP00000000000000002ZZZX000000?ooo`2ZZZX505EEE@070:ZZ
ZP1EEED0000005EEE@2ZZZX0oooo0000000E0?ooo``0dLfY000;0=7=Z@H0oooo0`0000001@1EEED0
oooo0:ZZZP2ZZZX000000080EEEE00@0000005EEE@2ZZZX0ZZZZ0`0000030?ooo`0305EEE@000000
000000<000000P3oool01P1EEED0ZZZZ0:ZZZP000000ZZZZ00000080oooo0`0000000`3oool00000
0?ooo`030?ooo`<000000`2ZZZX20000000505EEE@000000EEEE0:ZZZP3oool00`0000070?ooo`X0
dLfY1P3oool00`000000ZZZZ0?ooo`03000000<0EEEE00@0ZZZZ05EEE@1EEED0ZZZZ0`1EEED0102Z
ZZX0oooo0?ooo`3oool205EEE@<0ZZZZ0P0000000`1EEED0ZZZZ05EEE@020000000505EEE@000000
EEEE0000001EEED00P2ZZZX205EEE@<0oooo0P2ZZZX305EEE@040:ZZZP1EEED0EEEE0?ooo`80EEEE
00<0oooo0000000000000P3oool00`2ZZZX0oooo0?ooo`050?ooo`X0dLfY4@3oool00`1EEED0oooo
0000000205EEE@050?ooo`2ZZZX0oooo05EEE@0000000P1EEED20?ooo`80EEEE00D0000005EEE@3o
ool0oooo000000020?ooo`030000001EEED0oooo0080oooo0P1EEED00`3oool0EEEE0?ooo`020?oo
o`0505EEE@3oool000000?ooo`1EEED04@3oool:0=7=ZA`0oooo0P0000001P1EEED000000000002Z
ZZX000000?ooo`80000000<0oooo0000002ZZZX00P0000000`1EEED000000?ooo`0L0?ooo`X0dLfY
5P3oool00`2ZZZX0EEEE0:ZZZP03000000030?ooo`0000000000008000000P2ZZZX205EEE@060:ZZ
ZP1EEED0ZZZZ0:ZZZP000000oooo100000001@3oool000000:ZZZP1EEED0ZZZZ01H0oooo303AcJT0
00/0dLfY203oool200000080ZZZZ00@0EEEE000000000000EEEE10000000101EEED0ZZZZ0:ZZZP00
00020:ZZZP@0000000<0ZZZZ0000000000000P0000020?ooo`030000003oool0EEEE0080000000<0
EEEE0:ZZZP0000000P0000030:ZZZP040000002ZZZX0ZZZZ05EEE@80000000<0ZZZZ0000002ZZZX0
0`0000020:ZZZP800000203oool:0=7=Z@P0oooo00<000000?ooo`3oool00P000000103oool0EEEE
0:ZZZP1EEED20:ZZZP050000001EEED0ZZZZ0000001EEED00P0000000`2ZZZX0EEEE05EEE@020:ZZ
ZP0405EEE@2ZZZX0EEEE05EEE@@000000P1EEED0102ZZZX0EEEE0:ZZZP2ZZZX205EEE@090?ooo`00
000000000:ZZZP000000ZZZZ0?ooo`000000ZZZZ0080EEEE00<0ZZZZ05EEE@3oool00P0000000`3o
ool0ZZZZ000000080?ooo`X0dLfY4@3oool0102ZZZX0oooo05EEE@2ZZZX30?ooo`<0000000@0ZZZZ
0000002ZZZX0oooo0P2ZZZX3000000080:ZZZP3oool000000?ooo`000000ZZZZ0000003oool30:ZZ
ZP030?ooo`000000000000@0oooo00<0EEEE0?ooo`3oool04@3oool:0=7=ZAd0oooo00<0000005EE
E@2ZZZX00P1EEED00`2ZZZX0000000000002000000<0EEEE00<0000005EEE@0000007@3oool:0=7=
ZAH0oooo0`0000000`2ZZZX000000:ZZZP020:ZZZP050000003oool0ZZZZ0?ooo`2ZZZX0101EEED0
1`2ZZZX0oooo0:ZZZP1EEED000000:ZZZP0000000`2ZZZX00`000000ZZZZ0000000F0?ooo``0dLfY
000;0=7=Z@T0oooo00T0EEEE0?ooo`1EEED0ZZZZ0000002ZZZX0oooo0000002ZZZX00P1EEED00`2Z
ZZX0EEEE0:ZZZP020000000505EEE@000000ZZZZ0000002ZZZX00P00000205EEE@80ZZZZ0P3oool0
302ZZZX0000005EEE@1EEED0oooo0000002ZZZX000000:ZZZP000000EEEE00000080ZZZZ00D0EEEE
0000001EEED0EEEE0?ooo`02000000060:ZZZP000000EEEE05EEE@3oool000002@3oool:0=7=Z@T0
oooo0P1EEED00`000000EEEE0000000305EEE@060?ooo`000000EEEE05EEE@2ZZZX0EEEE0`000000
101EEED0ZZZZ05EEE@2ZZZX305EEE@030:ZZZP1EEED0000000<000000P2ZZZX305EEE@<0ZZZZ00T0
EEEE000000000000oooo05EEE@2ZZZX0000005EEE@0000000P1EEED00`2ZZZX0EEEE000000020000
000305EEE@000000oooo00P0oooo2P3AcJTB0?ooo`80EEEE1@3oool0102ZZZX0EEEE0000001EEED2
0?ooo`80ZZZZ0P3oool0102ZZZX0EEEE0?ooo`2ZZZX20?ooo`040:ZZZP3oool0oooo0?ooo`800000
00<0oooo0:ZZZP3oool00`3oool305EEEA80oooo2P3AcJTM0?ooo`80000000D0oooo05EEE@1EEED0
EEEE0000000205EEE@040000003oool0EEEE05EEE@<000007@3oool:0=7=ZAH0oooo00H000000:ZZ
ZP1EEED0ZZZZ05EEE@3oool20:ZZZP80000000<0oooo05EEE@1EEED0101EEED03@2ZZZX0EEEE0?oo
o`3oool000000:ZZZP000000oooo05EEE@2ZZZX0EEEE0:ZZZP0000005P3oool<0=7=Z@002`3AcJT:
0?ooo`040000001EEED0oooo0:ZZZP<0000000/0EEEE0000002ZZZX0EEEE0:ZZZP000000ZZZZ05EE
E@000000ZZZZ0?ooo`020000000705EEE@2ZZZX0oooo0000002ZZZX0EEEE0000000205EEE@800000
00<0oooo05EEE@1EEED00P000000103oool000000000001EEED2000000<0ZZZZ1@000000102ZZZX0
oooo05EEE@00000:0?ooo`X0dLfY2P3oool010000000EEEE00000000000205EEE@030:ZZZP1EEED0
EEEE00<0000000D0ZZZZ00000000000000000?ooo`0705EEE@D0000000<0oooo05EEE@1EEED00`1E
EED00`2ZZZX0EEEE000000020000000305EEE@2ZZZX000000080000000H0EEEE0000002ZZZX00000
05EEE@00000205EEE@030000003oool0oooo00P0oooo2P3AcJTC0?ooo`030:ZZZP3oool0000000<0
oooo0`0000000`2ZZZX0oooo0?ooo`0205EEE@80oooo101EEED0102ZZZX0oooo05EEE@1EEED20?oo
o`80000000<0oooo0000003oool00P3oool00`000000oooo0:ZZZP0C0?ooo`X0dLfY7P3oool30000
0080ZZZZ00@0EEEE0:ZZZP2ZZZX0EEEE0P2ZZZX00`000000EEEE0000000N0?ooo`X0dLfY5`3oool0
2@1EEED0oooo05EEE@3oool0ZZZZ05EEE@3oool000000:ZZZP0205EEE@050?ooo`2ZZZX0oooo0?oo
o`2ZZZX00`1EEED01@3oool000000?ooo`3oool0ZZZZ0080EEEE6@3oool<0=7=Z@002`3AcJT;0?oo
o`<0000000@0EEEE0:ZZZP1EEED000000`2ZZZX01@000000oooo0000002ZZZX0EEEE0080000000<0
ZZZZ0000002ZZZX00`0000001P2ZZZX0EEEE0:ZZZP000000EEEE0:ZZZP80000000<0EEEE0:ZZZP00
00000P00000205EEE@050:ZZZP3oool0oooo0000001EEED00P2ZZZX205EEE@030?ooo`1EEED00000
008000002`3oool:0=7=Z@/0oooo00<000000?ooo`3oool00P0000002@3oool0ZZZZ0:ZZZP1EEED0
ZZZZ05EEE@3oool0000005EEE@02000000050:ZZZP1EEED0EEEE05EEE@3oool00P1EEED5000000L0
EEEE00`0ZZZZ000000000000EEEE0000003oool0EEEE0?ooo`1EEED0ZZZZ05EEE@3oool200000003
0?ooo`2ZZZX0000000/0oooo2P3AcJTD0?ooo`0805EEE@3oool000000?ooo`000000oooo05EEE@00
00030?ooo`80000000<0oooo05EEE@1EEED00`1EEED20?ooo`8000000P3oool02@1EEED0000005EE
E@3oool000000?ooo`000000oooo05EEE@0D0?ooo`X0dLfY7P3oool20000000:0:ZZZP000000ZZZZ
0000001EEED0oooo0000002ZZZX000000:ZZZP8000007P3oool:0=7=ZAL0oooo0P0000001`1EEED0
00000000001EEED0ZZZZ0?ooo`0000000P1EEED20000000305EEE@000000000000<0EEEE0P3oool0
0`2ZZZX000000000000205EEE@030000003oool0oooo01H0oooo303AcJT000/0dLfY303oool01@1E
EED0oooo000000000000EEEE0080000000D0EEEE0:ZZZP3oool0oooo05EEE@03000000050?ooo`2Z
ZZX000000000002ZZZX00P1EEED01P000000EEEE05EEE@2ZZZX0EEEE000000<0EEEE0P0000030?oo
o`8000000`3oool01@000000EEEE0000002ZZZX0EEEE0080000000<0oooo0000003oool02`3oool:
0=7=Z@`0oooo0P1EEED010000000EEEE0000002ZZZX205EEE@030000003oool0ZZZZ0080ZZZZ00D0
EEEE0:ZZZP1EEED0EEEE0?ooo`0205EEE@030000002ZZZX0000000@0000000<0EEEE0:ZZZP000000
0P1EEED01@3oool0EEEE05EEE@3oool0EEEE00<0ZZZZ00<0oooo05EEE@1EEED00P1EEED300000003
05EEE@000000oooo00/0oooo2P3AcJTD0?ooo`050000003oool0ZZZZ0000002ZZZX00`0000001P1E
EED0oooo0:ZZZP2ZZZX000000:ZZZPD0000000l0oooo0:ZZZP00000000000:ZZZP3oool0ZZZZ0000
003oool000000:ZZZP3oool0ZZZZ0?ooo`000000503oool:0=7=ZAh0oooo00H000000?ooo`000000
EEEE0:ZZZP1EEED2000000<0EEEE0`00000N0?ooo`X0dLfY603oool0102ZZZX0000005EEE@3oool2
05EEE@030:ZZZP1EEED0EEEE0080EEEE00@0oooo05EEE@1EEED0oooo0`1EEED0203oool0ZZZZ05EE
E@1EEED0oooo05EEE@000000ZZZZ603oool<0=7=Z@002`3AcJT=0?ooo`070000001EEED0EEEE05EE
E@000000ZZZZ05EEE@030:ZZZP<0000000X0EEEE000000000000EEEE0?ooo`000000EEEE0000002Z
ZZX000000P3oool01`000000EEEE0000001EEED0ZZZZ0?ooo`1EEED01@0000030:ZZZP080000001E
EED0ZZZZ0:ZZZP1EEED0oooo05EEE@00000=0?ooo`X0dLfY3@3oool00`000000EEEE000000020000
000:05EEE@2ZZZX0EEEE05EEE@2ZZZX0oooo0000001EEED0ZZZZ05EEE@<0ZZZZ00<0EEEE0:ZZZP00
00001`000000102ZZZX0EEEE0:ZZZP2ZZZX205EEE@080000001EEED0000005EEE@2ZZZX0EEEE0000
002ZZZX205EEE@040000001EEED0EEEE000000d0oooo2P3AcJTE0?ooo`80EEEE0`3oool0102ZZZX0
00000?ooo`1EEED20?ooo`0305EEE@3oool0oooo0080000000@0EEEE0000001EEED0oooo0P1EEED0
1@3oool0EEEE000000000000EEEE0080oooo0`1EEEDE0?ooo`X0dLfY803oool00`1EEED0ZZZZ0000
00040000000405EEE@2ZZZX0EEEE0:ZZZQl0oooo2P3AcJTI0?ooo`040000002ZZZX0EEEE0:ZZZP80
oooo00P0000005EEE@1EEED000000:ZZZP000000oooo0:ZZZP<0EEEE00D0ZZZZ0?ooo`3oool0ZZZZ
05EEE@02000001T0oooo303AcJT000/0dLfY3P3oool2000000050?ooo`2ZZZX000000?ooo`1EEED0
0`00000305EEE@040000003oool00000000000<0EEEE00<0ZZZZ0?ooo`3oool00P3oool00`000000
EEEE05EEE@03000000030?ooo`000000ZZZZ00<0EEEE0`000000103oool000000000003oool20000
00h0oooo2P3AcJT>0?ooo`030000003oool0oooo0080000000@0oooo0:ZZZP2ZZZX0EEEE0P3oool0
2P000000EEEE0?ooo`1EEED0ZZZZ05EEE@3oool0EEEE0000001EEED6000000<0EEEE00<0ZZZZ05EE
E@3oool00P0000001P3oool0EEEE05EEE@2ZZZX0EEEE0?ooo`80000000<0oooo0:ZZZP0000003P3o
ool:0=7=ZAD0oooo0P0000030?ooo`040000001EEED000000?ooo`80000000H0oooo0000001EEED0
ZZZZ0000001EEED20:ZZZP040000003oool0oooo00000080oooo00@0EEEE0000003oool0oooo0`00
000E0?ooo`X0dLfY7`3oool01P1EEED0ZZZZ0:ZZZP3oool000000:ZZZP<000000P2ZZZXP0?ooo`X0
dLfY6P3oool00`000000ZZZZ0:ZZZP020:ZZZP080000003oool000000:ZZZP3oool0EEEE0:ZZZP3o
ool2000000050?ooo`2ZZZX0ZZZZ0:ZZZP0000000P2ZZZXJ0?ooo``0dLfY000;0=7=Z@l0oooo00<0
EEEE0?ooo`2ZZZX00P0000001`2ZZZX0EEEE05EEE@000000ZZZZ05EEE@0000000`3oool010000000
EEEE05EEE@1EEED5000000@0EEEE00H000000?ooo`3oool0oooo0000001EEED20:ZZZP80EEEE0`00
00020?ooo`030000003oool0oooo00d0oooo2P3AcJT?0?ooo`80EEEE00@0000005EEE@000000ZZZZ
0P1EEED40?ooo`040:ZZZP1EEED000000?ooo`80000000<0oooo0000000000000`0000020?ooo`04
0000002ZZZX0oooo00000080ZZZZ00<000000?ooo`3oool0101EEED01@000000EEEE0000001EEED0
000000l0oooo2P3AcJTF0?ooo`040:ZZZP3oool0oooo0?ooo`80EEEE00@0oooo0000002ZZZX0oooo
0P1EEED2000000040:ZZZP1EEED0000000000080EEEE00<000000:ZZZP0000000P1EEED01@000000
oooo0?ooo`3oool0ZZZZ01H0oooo2P3AcJTP0?ooo`80ZZZZ0`3oool00`2ZZZX0oooo0?ooo`020:ZZ
ZP030000003oool0oooo01d0oooo2P3AcJTJ0?ooo`80EEEE00@0ZZZZ0000002ZZZX000000`3oool0
0`2ZZZX0EEEE05EEE@020:ZZZP80oooo0P2ZZZX00`000000ZZZZ05EEE@0K0?ooo``0dLfY000;0=7=
ZA00oooo00D000000?ooo`000000000005EEE@020:ZZZP<0EEEE010000000:ZZZP000000ZZZZ0000
001EEED0ZZZZ0?ooo`000000ZZZZ0000001EEED0ZZZZ0000003oool0ZZZZ0P0000030:ZZZP040000
001EEED0EEEE00000080ZZZZ0`0000000`1EEED000000?ooo`0?0?ooo`X0dLfY403oool00`000000
EEEE000000020000000405EEE@2ZZZX0EEEE05EEE@8000000P2ZZZX200000080oooo00H000000?oo
o`3oool0EEEE0:ZZZP3oool2000000040?ooo`2ZZZX00000000000<0ZZZZ00@0000005EEE@000000
ZZZZ0P1EEED20000000305EEE@000000oooo00l0oooo2P3AcJTG0?ooo`030000003oool0ZZZZ00<0
00000`3oool010000000oooo00000000000205EEE@050000001EEED0oooo0000001EEED00P3oool0
1P2ZZZX000000:ZZZP2ZZZX0oooo000001L0oooo2P3AcJTO0?ooo`030:ZZZP3oool000000080oooo
0P0000020?ooo`030000003oool0oooo01l0oooo2P3AcJTK0?ooo`@0ZZZZ0P0000020:ZZZP040000
003oool0000000000080ZZZZ00H0000005EEE@2ZZZX0ZZZZ0?ooo`2ZZZXK0?ooo``0dLfY000;0=7=
ZA40oooo0P0000001P2ZZZX0000005EEE@000000ZZZZ05EEE@@0000000X0EEEE0000001EEED0EEEE
0?ooo`2ZZZX0EEEE0000002ZZZX0EEEE0P3oool205EEE@070000001EEED0EEEE0000002ZZZX00000
05EEE@020000000305EEE@2ZZZX0ZZZZ008000004@3oool:0=7=ZA40oooo00<0ZZZZ0?ooo`3oool0
0P0000001`3oool0ZZZZ0:ZZZP1EEED000000?ooo`0000000P3oool205EEE@060000001EEED0EEEE
0?ooo`000000EEEE0P0000001@1EEED000000?ooo`3oool0EEEE0080oooo00@0EEEE0:ZZZP1EEED0
oooo0P0000020?ooo`030000003oool0oooo00l0oooo2P3AcJTG0?ooo`040:ZZZP3oool0EEEE0?oo
o`80ZZZZ00@0oooo0000001EEED0oooo0P00000405EEE@050?ooo`000000oooo0:ZZZP0000000P3o
ool00`2ZZZX0oooo05EEE@0I0?ooo`X0dLfY7`3oool00`000000EEEE0000000200000080EEEE00@0
000005EEE@000000EEEE803oool:0=7=ZA`0oooo00X0ZZZZ05EEE@1EEED000000?ooo`2ZZZX00000
0:ZZZP000000oooo0`2ZZZX00`3oool0ZZZZ05EEE@0205EEEA`0oooo303AcJT000/0dLfY4P3oool2
000000030?ooo`000000ZZZZ00<0oooo00/0ZZZZ05EEE@2ZZZX0EEEE0:ZZZP3oool0EEEE0000003o
ool0000005EEE@02000000090?ooo`000000EEEE0?ooo`2ZZZX0EEEE0000001EEED0ZZZZ0080oooo
00<000000:ZZZP0000000`00000B0?ooo`X0dLfY4P3oool00`000000ZZZZ0?ooo`02000000050?oo
o`1EEED0EEEE0?ooo`2ZZZX00P1EEED01`000000ZZZZ05EEE@1EEED000000?ooo`1EEED00P3oool4
05EEE@040000001EEED0EEEE0:ZZZP<0EEEE0`0000000`3oool0ZZZZ0000000B0?ooo`X0dLfY603o
ool2000000@0oooo00L000000:ZZZP000000oooo0:ZZZP000000ZZZZ0080000000<0ZZZZ0?ooo`00
00000P0000000`3oool0EEEE0?ooo`03000001P0oooo2P3AcJTO0?ooo`060000001EEED0EEEE0:ZZ
ZP000000ZZZZ0P000000102ZZZX0EEEE05EEE@00000O0?ooo`X0dLfY703oool00`1EEED0ZZZZ0000
00020:ZZZP030000003oool0ZZZZ0080EEEE0P2ZZZX010000000ZZZZ0000000000020:ZZZQ`0oooo
303AcJT000/0dLfY4`3oool010000000oooo0?ooo`2ZZZX30000000405EEE@000000ZZZZ05EEE@<0
00000P3oool0101EEED0oooo0000001EEED20?ooo`<0000000<0EEEE0:ZZZP00000010000000102Z
ZZX0oooo05EEE@00000C0?ooo`X0dLfY4`3oool00`000000EEEE000000020000000<05EEE@2ZZZX0
EEEE05EEE@2ZZZX0EEEE0:ZZZP000000EEEE0:ZZZP1EEED000000P1EEED2000000090:ZZZP1EEED0
oooo0:ZZZP1EEED0ZZZZ05EEE@000000ZZZZ0080EEEE0P0000000`1EEED000000?ooo`0B0?ooo`X0
dLfY6@3oool0102ZZZX0oooo0000000000030?ooo`030:ZZZP3oool0oooo0080oooo00@0ZZZZ0?oo
o`1EEED0oooo0P2ZZZX30?ooo`030000003oool0ZZZZ01T0oooo2P3AcJTO0?ooo`0:0:ZZZP3oool0
00000:ZZZP000000ZZZZ05EEE@000000ZZZZ00000240oooo2P3AcJTL0?ooo`0505EEE@2ZZZX0EEEE
0:ZZZP3oool00P2ZZZX405EEE@070?ooo`2ZZZX0oooo0:ZZZP1EEED0ZZZZ0000000L0?ooo``0dLfY
000;0=7=ZA@0oooo0`0000002@3oool0ZZZZ05EEE@000000ZZZZ05EEE@2ZZZX000000:ZZZP040000
0080oooo1P0000030:ZZZP80EEEE00<0ZZZZ05EEE@0000000P00000D0?ooo`X0dLfY503oool00`2Z
ZZX0oooo0?ooo`02000000040?ooo`2ZZZX0ZZZZ05EEE@80ZZZZ0P000000103oool0ZZZZ0:ZZZP1E
EED20:ZZZP0405EEE@3oool0000000000080ZZZZ00@0EEEE0:ZZZP1EEED0oooo0P0000020?ooo`03
0000003oool0oooo0180oooo2P3AcJTJ0?ooo`0305EEE@3oool0oooo0080EEEE0P3oool205EEE@04
0?ooo`2ZZZX0ZZZZ0?ooo`80EEEE0P3oool205EEE@030000003oool0EEEE01X0oooo2P3AcJTO0?oo
o`030000001EEED000000080oooo00H000000:ZZZP3oool0EEEE0000001EEEDP0?ooo`X0dLfY703o
ool01P2ZZZX000000:ZZZP1EEED0ZZZZ0?ooo`D0EEEE00D0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP020000
01`0oooo303AcJT000/0dLfY5@3oool200000080ZZZZ0P00000205EEE@8000000P3oool00`2ZZZX0
000005EEE@020000000405EEE@000000ZZZZ0?ooo`<000000`1EEED00`000000ZZZZ000000020000
01D0oooo2P3AcJTE0?ooo`030000002ZZZX0oooo0080000000<0oooo05EEE@1EEED00P3oool20000
000305EEE@2ZZZX0EEEE00<0EEEE00@0ZZZZ05EEE@00000000000P3oool205EEE@<0000000<0oooo
0:ZZZP0000005@3oool:0=7=ZAX0oooo00@0ZZZZ0?ooo`3oool0ZZZZ1`3oool00`000000oooo0:ZZ
ZP040?ooo`030:ZZZP1EEED0oooo01/0oooo2P3AcJTP0?ooo`040000001EEED000000:ZZZP80oooo
00@0ZZZZ05EEE@1EEED00000803oool:0=7=ZA`0oooo0P2ZZZX01`000000ZZZZ0?ooo`2ZZZX0oooo
0000002ZZZX00P0000020:ZZZP040?ooo`00000000000:ZZZQd0oooo303AcJT000/0dLfY5P3oool0
1`000000oooo05EEE@1EEED000000:ZZZP0000000P2ZZZX30000000605EEE@00000000000:ZZZP00
0000EEEE0`0000020:ZZZP0305EEE@2ZZZX0ZZZZ00<0EEEE00<000000?ooo`3oool0503oool:0=7=
ZAH0oooo00<0000005EEE@0000000P000000101EEED0000005EEE@1EEED2000000H0EEEE00@0ZZZZ
05EEE@00000000000P1EEED00`2ZZZX0EEEE05EEE@020000000305EEE@000000oooo01D0oooo2P3A
cJTK0?ooo`80EEEE1@3oool205EEE@030000003oool0EEEE00H0oooo0P1EEEDK0?ooo`X0dLfY803o
ool3000000@0ZZZZ0`00000P0?ooo`X0dLfY7@3oool01@1EEED0oooo05EEE@2ZZZX0oooo00<0ZZZZ
00P0EEEE0:ZZZP2ZZZX0oooo0:ZZZP1EEED0oooo05EEEAd0oooo303AcJT000/0dLfY5`3oool01000
0000EEEE0?ooo`2ZZZX2000000030:ZZZP1EEED0ZZZZ0080ZZZZ00D0EEEE0000002ZZZX0EEEE0000
00030:ZZZP80EEEE00<0ZZZZ0000000000000P3oool00`1EEED0oooo0?ooo`0F0?ooo`X0dLfY5`3o
ool010000000EEEE05EEE@00000205EEE@070:ZZZP1EEED0EEEE0000003oool0EEEE0:ZZZP0205EE
E@040:ZZZP000000oooo00000080EEEE00@0ZZZZ0000001EEED000000P1EEEDH0?ooo`X0dLfY7P3o
ool00`000000oooo0?ooo`020?ooo`040:ZZZP1EEED0oooo0:ZZZP@0oooo00<000000?ooo`2ZZZX0
703oool:0=7=ZB80oooo00H0ZZZZ0?ooo`2ZZZX0ZZZZ0?ooo`1EEEDR0?ooo`X0dLfY7P3oool01`2Z
ZZX0EEEE05EEE@1EEED0oooo0:ZZZP1EEED00`2ZZZX205EEE@030000002ZZZX0oooo01d0oooo303A
cJT000/0dLfY603oool30000000505EEE@2ZZZX0EEEE0:ZZZP1EEED00`0000001@2ZZZX0EEEE0000
002ZZZX0EEEE00<0000000@0ZZZZ05EEE@3oool0EEEE0`00000H0?ooo`X0dLfY603oool00`000000
ZZZZ0?ooo`02000000040?ooo`1EEED0EEEE0?ooo`80ZZZZ101EEED20:ZZZP040?ooo`1EEED0EEEE
0?ooo`80000000<0oooo0:ZZZP000000603oool:0=7=ZA`0oooo0P1EEED30?ooo`030000003oool0
oooo0080EEEE0P3oool01@000000oooo0000003oool0EEEE01d0oooo2P3AcJTR0?ooo`80ZZZZ00@0
oooo0:ZZZP2ZZZX000008P3oool:0=7=ZAl0oooo0P1EEED01@000000ZZZZ0:ZZZP2ZZZX000000080
ZZZZ00<0000005EEE@1EEED07`3oool<0=7=Z@002`3AcJTI0?ooo`070000003oool000000000001E
EED0ZZZZ0000000205EEE@80ZZZZ0P1EEED0102ZZZX0000005EEE@1EEED20:ZZZP0505EEE@000000
000005EEE@0000006@3oool:0=7=ZAT0oooo00L0000005EEE@000000EEEE0000001EEED0000000L0
EEEE00D0ZZZZ05EEE@1EEED0ZZZZ05EEE@030000000305EEE@000000oooo01P0oooo2P3AcJTL0?oo
o`8000000P3oool010000000ZZZZ0?ooo`3oool2000000070?ooo`000000ZZZZ0000002ZZZX0oooo
0000000M0?ooo`X0dLfY8@3oool20000000605EEE@3oool0oooo05EEE@3oool000008@3oool:0=7=
ZAl0oooo00@000000?ooo`000000ZZZZ0P3oool01P2ZZZX0oooo0:ZZZP000000oooo000001l0oooo
303AcJT000/0dLfY6P3oool010000000EEEE05EEE@1EEED20:ZZZP040000003oool0oooo00000080
oooo0P0000001`3oool000000000002ZZZX0EEEE0?ooo`1EEED06`3oool:0=7=ZAX0oooo00@00000
05EEE@00000000000P1EEED00`2ZZZX0EEEE05EEE@0605EEE@040:ZZZP000000EEEE00000080EEEE
6`3oool:0=7=ZAh0oooo0P1EEED20?ooo`0505EEE@2ZZZX0EEEE0000002ZZZX00`3oool205EEEAh0
oooo2P3AcJTQ0?ooo`040000003oool0ZZZZ0?ooo`80ZZZZ0P00000Q0?ooo`X0dLfY803oool0101E
EED0ZZZZ0000000000020?ooo`80000000<0ZZZZ05EEE@0000007`3oool<0=7=Z@002`3AcJTK0?oo
o`80000000<0oooo0000000000000P3oool20:ZZZP030?ooo`2ZZZX0ZZZZ00<0oooo00<0ZZZZ0000
003oool00P00000K0?ooo`X0dLfY6`3oool00`000000oooo0?ooo`02000000040?ooo`1EEED0EEEE
0?ooo`80EEEE00@0oooo05EEE@1EEED0oooo0P0000000`3oool0ZZZZ0000000K0?ooo`X0dLfY7P3o
ool200000080oooo0P00000205EEE@040000003oool0oooo0?ooo`8000007P3oool:0=7=ZB<0oooo
00D0EEEE0?ooo`3oool0EEEE0:ZZZP0R0?ooo`X0dLfY7`3oool01@2ZZZX0EEEE0000002ZZZX00000
0080oooo00@000000?ooo`000000EEEE803oool<0=7=Z@002`3AcJTL0?ooo`<0000000D0EEEE0?oo
o`2ZZZX0EEEE000000020:ZZZP040000001EEED0ZZZZ0?ooo`<000007@3oool:0=7=ZA`0oooo00<0
00000:ZZZP3oool00`0000000`1EEED0ZZZZ05EEE@020:ZZZP030?ooo`00000000000080oooo00<0
ZZZZ0?ooo`3oool06`3oool:0=7=ZAl0oooo0P1EEED00`3oool0000000000003000000030:ZZZP3o
ool0EEEE0200oooo2P3AcJTS0?ooo`050:ZZZP3oool0ZZZZ0:ZZZP0000008P3oool:0=7=ZAl0oooo
00D000000:ZZZP000000ZZZZ000000020?ooo`040000002ZZZX000000:ZZZR00oooo303AcJT000/0
dLfY7@3oool00`000000EEEE00000002000000030:ZZZP000000EEEE0080000000H0EEEE00000000
0000oooo05EEE@00000M0?ooo`X0dLfY7@3oool010000000EEEE00000000000205EEE@070:ZZZP1E
EED0EEEE0:ZZZP000000EEEE0000000205EEE@030000003oool0oooo01/0oooo2P3AcJTO0?ooo`80
000000@0oooo0:ZZZP000000ZZZZ0P0000000`2ZZZX0oooo0000000P0?ooo`X0dLfY8P3oool01P00
0000EEEE0000003oool0EEEE00000280oooo2P3AcJTO0?ooo`040000002ZZZX0ZZZZ05EEE@@0ZZZZ
00<0EEEE0:ZZZP2ZZZX0803oool<0=7=Z@002`3AcJTN0?ooo`8000000P2ZZZX0101EEED0000005EE
E@1EEED200000080ZZZZ0P00000N0?ooo`X0dLfY7P3oool00`000000oooo05EEE@020:ZZZP@0EEEE
0P2ZZZX00`1EEED0ZZZZ0000000N0?ooo`X0dLfY803oool00`2ZZZX0oooo0?ooo`020?ooo`050:ZZ
ZP3oool0EEEE0?ooo`2ZZZX0803oool:0=7=ZB80oooo00@0ZZZZ0?ooo`3oool00000903oool:0=7=
ZB00oooo0P2ZZZX00`000000ZZZZ000000020:ZZZP030000002ZZZX0ZZZZ0200oooo303AcJT000/0
dLfY7`3oool4000000050:ZZZP00000000000:ZZZP3oool00P00000P0?ooo`X0dLfY7`3oool01P00
0000ZZZZ05EEE@1EEED0ZZZZ05EEE@<0ZZZZ00<0EEEE0:ZZZP3oool07`3oool:0=7=ZB40oooo0P00
0000103oool0EEEE0?ooo`3oool200000240oooo2P3AcJTS0?ooo`040:ZZZP00000000000:ZZZR<0
oooo2P3AcJTQ0?ooo`060000001EEED0EEEE0?ooo`000000EEEE0P00000Q0?ooo``0dLfY000;0=7=
ZB00oooo00<0000005EEE@3oool00P2ZZZX01@000000ZZZZ0?ooo`1EEED000000200oooo2P3AcJTP
0?ooo`040000001EEED0EEEE0:ZZZP80EEEE0P2ZZZX00`1EEED000000?ooo`0O0?ooo`X0dLfY9@3o
ool00`000000oooo0:ZZZP0R0?ooo`X0dLfY8`3oool010000000EEEE05EEE@00000S0?ooo`X0dLfY
8P3oool01P000000EEEE0:ZZZP2ZZZX0EEEE0:ZZZR80oooo303AcJT000/0dLfY8@3oool300000003
0?ooo`1EEED00000008000008@3oool:0=7=ZB40oooo00<000000:ZZZP1EEED00`1EEED00`2ZZZX0
00000?ooo`0P0?ooo`X0dLfY8P3oool205EEE@030000003oool0EEEE02<0oooo2P3AcJTS0?ooo`@0
00008`3oool:0=7=ZB80oooo0P1EEED00`2ZZZX0EEEE05EEE@0S0?ooo``0dLfY000;0=7=ZB80oooo
0P0000000`2ZZZX000000000000S0?ooo`X0dLfY8P3oool01@000000ZZZZ0?ooo`000000ZZZZ02<0
oooo2P3AcJTS0?ooo`040:ZZZP1EEED0oooo0:ZZZR<0oooo2P3AcJTU0?ooo`030:ZZZP3oool0oooo
0280oooo2P3AcJTS0?ooo`80ZZZZ00<0oooo0:ZZZP3oool08P3oool<0=7=Z@002`3AcJTS0?ooo`04
0000003oool0EEEE000002<0oooo2P3AcJTS0?ooo`80000000<0EEEE0000003oool08P3oool:0=7=
ZB@0oooo0P1EEEDT0?ooo`X0dLfY903oool00`1EEED000000?ooo`0S0?ooo`X0dLfY903oool00`2Z
ZZX0EEEE0?ooo`0S0?ooo``0dLfY000;0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool:0=7=ZB@0
oooo00<0ZZZZ0?ooo`3oool08`3oool:0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool:0=7=ZB@0
oooo00<0ZZZZ0?ooo`3oool08`3oool:0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool<0=7=Z@00
o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00
2`3AcJT20?ooo`030000002ZZZX0ZZZZ00<0ZZZZ0P0000020:ZZZP030?ooo`000000oooo00D0ZZZZ
00<000000:ZZZP2ZZZX00P3oool01`000000oooo0?ooo`2ZZZX0oooo05EEE@2ZZZX00P1EEED01@3o
ool000000:ZZZP2ZZZX0000000<0EEEE00@0ZZZZ05EEE@3oool0ZZZZ0P3oool00`000000oooo0000
00020:ZZZP040000002ZZZX0ZZZZ00000080ZZZZ00<0oooo0000003oool00P2ZZZX2000000<0ZZZZ
00D0oooo0:ZZZP00000000000?ooo`0:0=7=Z@`0oooo00<000000?ooo`1EEED00P1EEED40:ZZZP04
05EEE@2ZZZX0ZZZZ0:ZZZP<0000000<0ZZZZ05EEE@1EEED00P0000000`2ZZZX0EEEE0?ooo`030?oo
o`80ZZZZ00@000000:ZZZP1EEED0EEEE0P0000000`2ZZZX000000:ZZZP020:ZZZP80EEEE0`2ZZZX3
05EEE@h0oooo2P3AcJTF0?ooo`070:ZZZP000000ZZZZ05EEE@000000ZZZZ000000020?ooo`050000
001EEED0oooo05EEE@2ZZZX00P000000102ZZZX0oooo0?ooo`1EEED30?ooo`070000002ZZZX0ZZZZ
05EEE@2ZZZX0oooo0:ZZZP0F0?ooo`X0dLfY00<0oooo0000002ZZZX00`00000205EEE@070:ZZZP3o
ool0oooo0:ZZZP3oool000000:ZZZP0505EEE@050:ZZZP1EEED0oooo05EEE@0000000P1EEED01P2Z
ZZX0oooo0?ooo`3oool000000:ZZZPP0EEEE00H0ZZZZ0?ooo`3oool0oooo0000002ZZZX205EEE@03
0000001EEED0oooo00H0EEEE0P2ZZZX2000000040:ZZZP3oool0ZZZZ0:ZZZP80EEEE0`0000000`2Z
ZZX000000?ooo`0:0=7=Z@040?ooo`000000oooo0?ooo`<0000000D0oooo05EEE@1EEED0ZZZZ0000
00030?ooo`0405EEE@2ZZZX0EEEE05EEE@80ZZZZ0P000000103oool000000000003oool20:ZZZP80
oooo00/0ZZZZ05EEE@3oool0ZZZZ0?ooo`1EEED0ZZZZ0?ooo`1EEED0oooo05EEE@040?ooo`050:ZZ
ZP3oool000000000003oool00`0000001@2ZZZX0EEEE0:ZZZP2ZZZX0EEEE0080oooo00<0ZZZZ0000
002ZZZX00P1EEED20?ooo`060000002ZZZX0oooo0?ooo`000000oooo303AcJT000/0dLfY00H0oooo
0:ZZZP2ZZZX0EEEE0000003oool2000000040?ooo`000000oooo00000080EEEE00D0oooo0000003o
ool0ZZZZ05EEE@020?ooo`8000000P2ZZZX30?ooo`8000000`2ZZZX00`000000ZZZZ0?ooo`020000
00030?ooo`2ZZZX0000000<0ZZZZ00<000000?ooo`3oool00P3oool01`2ZZZX0oooo000000000000
ZZZZ0?ooo`1EEED0103oool01P1EEED000000000003oool0ZZZZ0?ooo`80000000@0oooo0000001E
EED0ZZZZ0P3oool:0=7=Z@d0oooo102ZZZX01P1EEED0ZZZZ0:ZZZP3oool0EEEE0:ZZZP80EEEE00<0
ZZZZ0?ooo`0000000`2ZZZX2000000030:ZZZP1EEED0oooo00<0oooo0P2ZZZX010000000ZZZZ0:ZZ
ZP2ZZZX3000000040:ZZZP1EEED0ZZZZ0:ZZZP80EEEE1`2ZZZX=0?ooo`X0dLfY5P3oool0101EEED0
00000:ZZZP2ZZZX205EEE@@000000`3oool010000000EEEE05EEE@0000030?ooo`<0000000<0ZZZZ
05EEE@1EEED00P2ZZZX00`000000EEEE0?ooo`0E0?ooo`X0dLfY00@0oooo0000003oool0EEEE0P3o
ool02@000000ZZZZ0000002ZZZX0EEEE0:ZZZP3oool0EEEE0:ZZZP0605EEE@030:ZZZP0000000000
0080000000<0EEEE0000003oool00P1EEED00`3oool0000005EEE@0705EEE@070000003oool0EEEE
05EEE@3oool0000005EEE@02000000030?ooo`000000ZZZZ00H0EEEE00`0ZZZZ05EEE@1EEED0ZZZZ
05EEE@2ZZZX000000:ZZZP000000oooo0:ZZZP1EEED30?ooo`X0dLfY00<0oooo0000003oool00P1E
EED20:ZZZP@0EEEE00H0oooo0000002ZZZX0ZZZZ0000002ZZZX200000080oooo00H000000?ooo`3o
ool0oooo0000001EEED20?ooo`0305EEE@3oool0EEEE0080EEEE00H000000?ooo`1EEED0EEEE0?oo
o`2ZZZX205EEE@80oooo0P1EEED20?ooo`0;0000003oool0oooo0?ooo`000000ZZZZ0?ooo`000000
oooo0:ZZZP0000000`2ZZZX00`3oool0EEEE05EEE@0205EEE@040?ooo`2ZZZX0oooo05EEE@<0oooo
303AcJT000/0dLfY0`3oool00`2ZZZX000000:ZZZP020000000805EEE@3oool000000000003oool0
EEEE0:ZZZP1EEED3000000030?ooo`000000oooo00<0oooo102ZZZX0103oool0ZZZZ0000002ZZZX2
0000000@05EEE@000000000005EEE@3oool000000:ZZZP3oool0ZZZZ0?ooo`1EEED0ZZZZ0000002Z
ZZX0oooo05EEE@80oooo00<0ZZZZ0?ooo`0000000P0000020:ZZZP0305EEE@2ZZZX0000000800000
00<0EEEE0000000000000`2ZZZX30?ooo`X0dLfY3P3oool00`000000EEEE05EEE@020:ZZZP@00000
00<0ZZZZ05EEE@1EEED00P0000030:ZZZP@0EEEE103oool0102ZZZX0EEEE05EEE@1EEED30:ZZZP05
0000002ZZZX0EEEE05EEE@2ZZZX0100000001@2ZZZX0EEEE05EEE@3oool0000000h0oooo2P3AcJTF
0?ooo`0305EEE@2ZZZX0EEEE0080ZZZZ00@0EEEE0?ooo`2ZZZX0oooo1P1EEED00`3oool0EEEE0000
000205EEE@030000003oool0ZZZZ00<0EEEE00@0ZZZZ05EEE@2ZZZX0EEEE5P3oool:0=7=Z@<0oooo
00H0000005EEE@1EEED0oooo0000002ZZZX305EEE@<0oooo00<0000005EEE@1EEED01@1EEED20:ZZ
ZP0405EEE@3oool0oooo05EEE@80000000H0EEEE0?ooo`3oool0oooo0000003oool300000080oooo
00L0EEEE000000000000EEEE0?ooo`2ZZZX0EEEE0080ZZZZ1`1EEED010000000oooo0?ooo`000003
05EEE@030:ZZZP000000oooo0080EEEE00@000000?ooo`3oool0oooo2P3AcJT30?ooo`030000003o
ool0ZZZZ00H0EEEE00H0oooo05EEE@1EEED0oooo0000003oool20:ZZZP050000002ZZZX0oooo0000
003oool00`1EEED01P3oool0ZZZZ0000003oool0ZZZZ0?ooo`D0EEEE0P3oool0102ZZZX000000000
002ZZZX405EEE@050?ooo`2ZZZX0oooo0:ZZZP0000000P2ZZZX2000000X0EEEE00<0ZZZZ00000000
00000`3oool<0=7=Z@002`3AcJT50?ooo`<0ZZZZ00X0EEEE0?ooo`3oool0ZZZZ05EEE@3oool00000
0?ooo`1EEED0oooo0P1EEED00`2ZZZX0oooo0:ZZZP020000000505EEE@2ZZZX0ZZZZ0000001EEED0
0P0000020?ooo`030:ZZZP1EEED0oooo0080EEEE00H0ZZZZ0?ooo`3oool0ZZZZ0000001EEED30:ZZ
ZP0605EEE@000000ZZZZ0:ZZZP3oool00000101EEED200000080oooo00P0ZZZZ0?ooo`1EEED0EEEE
0:ZZZP1EEED0ZZZZ000000@0oooo2P3AcJT?0?ooo`<0ZZZZ1@1EEED30:ZZZP80000000<0ZZZZ05EE
E@2ZZZX00`2ZZZX00`1EEED0oooo0?ooo`020?ooo`D0ZZZZ00<0EEEE0:ZZZP0000000`2ZZZX605EE
E@<0ZZZZ3`3oool:0=7=ZAH0oooo00/0EEEE0:ZZZP1EEED0ZZZZ0?ooo`000000oooo05EEE@000000
ZZZZ0?ooo`02000000030?ooo`2ZZZX0ZZZZ0080oooo00T000000?ooo`000000000005EEE@3oool0
000005EEE@2ZZZX00`1EEEDF0?ooo`X0dLfY103oool010000000ZZZZ0?ooo`2ZZZX205EEE@800000
0P3oool00`1EEED0ZZZZ05EEE@0605EEE@030:ZZZP1EEED0EEEE0080ZZZZ0`000000101EEED0ZZZZ
0:ZZZP1EEED20?ooo`030:ZZZP3oool0oooo0080ZZZZ0`0000000`1EEED0ZZZZ05EEE@0805EEE@04
0000001EEED0oooo05EEE@80oooo0P00000205EEE@040:ZZZP000000ZZZZ000000@0oooo2P3AcJT5
0?ooo`P0EEEE00d0ZZZZ0000003oool0EEEE0?ooo`2ZZZX000000?ooo`2ZZZX000000?ooo`1EEED0
000000<0EEEE0`2ZZZX010000000oooo00000000000205EEE@040000001EEED0oooo000000<0ZZZZ
0P1EEED20000000605EEE@2ZZZX000000:ZZZP3oool000000P2ZZZX0101EEED000000000002ZZZX8
05EEE@030000003oool0oooo0080oooo303AcJT000/0dLfY103oool20:ZZZP040000001EEED0ZZZZ
05EEE@8000000P2ZZZX02`3oool0ZZZZ0:ZZZP2ZZZX000000:ZZZP1EEED0000005EEE@3oool00000
00@0ZZZZ0P1EEED00`2ZZZX0oooo0:ZZZP030:ZZZP040000002ZZZX0ZZZZ0:ZZZP80oooo0P1EEED4
0:ZZZP040000002ZZZX0EEEE00000080ZZZZ0P000000102ZZZX0oooo0?ooo`2ZZZX30000000305EE
E@2ZZZX0EEEE0080ZZZZ1@3oool:0=7=Z@l0oooo00<0EEEE0:ZZZP2ZZZX01P2ZZZX0101EEED0ZZZZ
0000001EEED30:ZZZP0405EEE@2ZZZX0EEEE05EEE@@0oooo00@0ZZZZ05EEE@2ZZZX0EEEE0P2ZZZX2
05EEE@80ZZZZ00<0EEEE0:ZZZP2ZZZX0102ZZZX00`1EEED0ZZZZ05EEE@0?0?ooo`X0dLfY603oool2
05EEE@050:ZZZP3oool0oooo0?ooo`0000000P2ZZZX20?ooo`040:ZZZP000000ZZZZ0:ZZZP80oooo
00<0ZZZZ0000000000000`3oool0102ZZZX0EEEE05EEE@00000G0?ooo`X0dLfY103oool01`000000
oooo0:ZZZP2ZZZX000000?ooo`0000000P3oool205EEE@050?ooo`000000000005EEE@0000000P1E
EED2000000040:ZZZP000000oooo05EEE@@0000000<0EEEE0?ooo`2ZZZX00P1EEED01@2ZZZX0EEEE
0000003oool0EEEE00@0000000<0EEEE0000000000000P2ZZZX01@000000EEEE000000000000EEEE
008000000`1EEED20?ooo`<0000000<0ZZZZ05EEE@3oool01@3oool:0=7=Z@@0oooo00D0000005EE
E@00000000000:ZZZP020000000=05EEE@000000ZZZZ0?ooo`000000EEEE0:ZZZP3oool0000005EE
E@3oool0EEEE0:ZZZP03000000070?ooo`000000ZZZZ0?ooo`2ZZZX0oooo05EEE@020000000;0?oo
o`00000000000000001EEED0oooo0000003oool0ZZZZ0000003oool00`000000202ZZZX0EEEE0?oo
o`3oool000000?ooo`2ZZZX0EEEE0P3oool01`2ZZZX0EEEE05EEE@000000EEEE0:ZZZP0000000P1E
EED50?ooo``0dLfY000;0=7=Z@H0oooo00H0ZZZZ05EEE@000000EEEE0:ZZZP3oool20:ZZZP060000
002ZZZX0ZZZZ0?ooo`2ZZZX000000P3oool0102ZZZX000000:ZZZP0000020:ZZZP050000002ZZZX0
00000?ooo`0000000P2ZZZX405EEE@80ZZZZ00h000000:ZZZP000000ZZZZ0?ooo`2ZZZX0oooo0000
002ZZZX0EEEE0:ZZZP3oool0EEEE000000<0ZZZZ0P0000020:ZZZP060?ooo`2ZZZX0ZZZZ0000001E
EED0ZZZZ1P3oool:0=7=ZA00oooo0P2ZZZX205EEE@040:ZZZP1EEED0oooo0?ooo`80EEEE00<00000
0?ooo`1EEED00P1EEED0103oool000000:ZZZP1EEED40?ooo`80ZZZZ00@000000?ooo`1EEED0EEEE
0P3oool01@2ZZZX0EEEE05EEE@000000oooo00@0EEEE0P2ZZZX@0?ooo`X0dLfY5`3oool01`1EEED0
00000?ooo`3oool0ZZZZ0000003oool00P0000040?ooo`800000103oool2000000030?ooo`000000
ZZZZ0080oooo00<000000?ooo`3oool05P3oool:0=7=Z@H0oooo0`1EEED01P2ZZZX0oooo0:ZZZP1E
EED0oooo0:ZZZP80EEEE00<0ZZZZ05EEE@3oool00`3oool02`2ZZZX0EEEE05EEE@3oool000000?oo
o`000000oooo0:ZZZP1EEED0oooo008000000P3oool010000000EEEE0?ooo`1EEED20?ooo`030000
003oool0000000<0EEEE00L000000?ooo`3oool0ZZZZ0?ooo`1EEED0ZZZZ0080EEEE00H0ZZZZ0?oo
o`1EEED0ZZZZ0?ooo`2ZZZX205EEE@030000003oool0oooo00@0oooo2P3AcJT70?ooo`0305EEE@3o
ool0ZZZZ0080oooo00<0ZZZZ05EEE@1EEED00P3oool00`000000ZZZZ0:ZZZP0200000080oooo00@0
ZZZZ000000000000oooo0P1EEED20:ZZZP050?ooo`1EEED0EEEE0:ZZZP3oool00P2ZZZX205EEE@03
0?ooo`000000ZZZZ0080EEEE00<0oooo0:ZZZP0000000P2ZZZX00`3oool0000005EEE@020:ZZZP80
oooo00@0000005EEE@1EEED000000P3oool0101EEED0oooo05EEE@0000060?ooo``0dLfY000;0=7=
Z@H0oooo00/000000?ooo`1EEED0EEEE0:ZZZP3oool0EEEE0?ooo`2ZZZX0oooo000000020?ooo`09
0000002ZZZX0oooo0:ZZZP1EEED0oooo0:ZZZP000000oooo00<0EEEE0P2ZZZX0101EEED0ZZZZ05EE
E@2ZZZX205EEE@040000001EEED0ZZZZ0?ooo`80EEEE0P3oool020000000ZZZZ0?ooo`1EEED0ZZZZ
0?ooo`2ZZZX000000P3oool01`000000oooo0:ZZZP3oool0ZZZZ0?ooo`2ZZZX00P1EEED80?ooo`X0
dLfY403oool00`1EEED0ZZZZ0:ZZZP020:ZZZP0305EEE@3oool0ZZZZ0080ZZZZ0`0000001P1EEED0
0000000000000000ZZZZ05EEE@@0oooo0P2ZZZX30000000305EEE@000000000000<0ZZZZ0P3oool0
101EEED0ZZZZ0:ZZZP2ZZZX205EEEA00oooo2P3AcJTH0?ooo`80000000@0EEEE0000000000000000
0P1EEED4000000030:ZZZP000000000000<000000P1EEED00`000000oooo00000003000001P0oooo
2P3AcJT60?ooo`8000000`2ZZZX305EEE@060?ooo`000000ZZZZ05EEE@2ZZZX000000P1EEED00`3o
ool0000005EEE@0205EEE@060?ooo`000000oooo0?ooo`1EEED0ZZZZ0P0000050?ooo`030000002Z
ZZX0EEEE0080oooo00<0ZZZZ0?ooo`1EEED00P1EEED20?ooo`0805EEE@3oool000000:ZZZP1EEED0
ZZZZ0000003oool305EEE@040:ZZZP000000ZZZZ000000L0oooo2P3AcJT60?ooo`070000001EEED0
EEEE0000003oool0EEEE0:ZZZP02000000040?ooo`1EEED0oooo0:ZZZP8000000P3oool02P1EEED0
ZZZZ0:ZZZP1EEED0oooo0000002ZZZX0EEEE0?ooo`00000405EEE@0:0?ooo`1EEED0EEEE05EEE@00
0000ZZZZ05EEE@2ZZZX000000?ooo`<0ZZZZ00T0EEEE0?ooo`3oool0oooo0000002ZZZX0oooo05EE
E@3oool00P000000103oool0EEEE0?ooo`2ZZZX205EEE@L0oooo303AcJT000/0dLfY1`3oool50:ZZ
ZP0305EEE@00000000000080EEEE0P3oool305EEE@060000002ZZZX000000000002ZZZX000000P2Z
ZZX20000000405EEE@2ZZZX0ZZZZ00000080ZZZZ00L0000005EEE@2ZZZX0EEEE0:ZZZP000000ZZZZ
0080000000D0oooo000000000000ZZZZ0000000305EEE@80oooo00D0EEEE00000000000000000?oo
o`020:ZZZP030000002ZZZX0ZZZZ00L0oooo2P3AcJTB0?ooo`80EEEE00H0ZZZZ05EEE@3oool0EEEE
0000003oool305EEE@@0000000<0ZZZZ05EEE@3oool00`3oool20:ZZZP040000002ZZZX000000000
00<0EEEE00H0oooo0000003oool0oooo05EEE@2ZZZX205EEE@030000003oool0oooo00l0oooo2P3A
cJTI0?ooo`070:ZZZP3oool000000000003oool000000?ooo`05000000030:ZZZP000000ZZZZ0080
000000<0oooo0000003oool00P0000000`3oool0ZZZZ0?ooo`0H0?ooo`X0dLfY1`3oool00`000000
oooo0:ZZZP0505EEE@050:ZZZP1EEED0EEEE05EEE@2ZZZX00P0000001@2ZZZX000000?ooo`000000
ZZZZ0080EEEE00@0oooo05EEE@1EEED000000P3oool0102ZZZX0oooo0:ZZZP2ZZZX20?ooo`060000
001EEED0EEEE0?ooo`2ZZZX0EEEE0P0000020?ooo`040:ZZZP000000oooo0:ZZZP<0EEEE00<0oooo
05EEE@1EEED0101EEED00`3oool000000?ooo`060?ooo`X0dLfY1`3oool2000000030:ZZZP1EEED0
EEEE00<0ZZZZ00<000000:ZZZP1EEED00P2ZZZX20?ooo`<0EEEE00@0oooo05EEE@1EEED0oooo0P1E
EED01@3oool000000?ooo`000000ZZZZ0080EEEE00@0ZZZZ0000003oool000000`1EEED0202ZZZX0
EEEE05EEE@3oool0EEEE0000001EEED0oooo0`2ZZZX00`1EEED0ZZZZ0:ZZZP020:ZZZP<0EEEE00<0
oooo0000000000001`3oool<0=7=Z@002`3AcJT90?ooo`80ZZZZ00<000000?ooo`3oool00P2ZZZX0
1P1EEED0ZZZZ0:ZZZP2ZZZX0EEEE0?ooo`80ZZZZ0P0000000`2ZZZX00000000000040:ZZZP050000
002ZZZX0ZZZZ0:ZZZP3oool00P2ZZZX00`000000ZZZZ0:ZZZP020:ZZZP80000000H0oooo00000000
0000oooo0:ZZZP3oool30:ZZZP050?ooo`1EEED0ZZZZ0:ZZZP3oool00P0000020:ZZZPT0oooo2P3A
cJTA0?ooo`80EEEE00<0ZZZZ0000000000000`0000000`2ZZZX0000005EEE@02000000@0ZZZZ00<0
EEEE0?ooo`3oool00P3oool50:ZZZP050000001EEED0EEEE0000002ZZZX0100000020:ZZZP0305EE
E@3oool0oooo0100oooo2P3AcJTI0?ooo`<0EEEE00H0ZZZZ0000003oool0ZZZZ05EEE@0000020?oo
o`80000000L0oooo000000000000EEEE0000003oool0000000@0EEEE6@3oool:0=7=Z@T0oooo0`1E
EED200000080EEEE00D0oooo05EEE@000000EEEE0:ZZZP0205EEE@030?ooo`2ZZZX0ZZZZ00<0EEEE
00D0ZZZZ0?ooo`3oool0EEEE0?ooo`0205EEE@090?ooo`000000EEEE05EEE@3oool0EEEE0:ZZZP3o
ool0ZZZZ00<0EEEE0`2ZZZX405EEE@030000002ZZZX0oooo0080EEEE00D0000005EEE@1EEED0EEEE
000000090?ooo`X0dLfY2@3oool205EEE@0?0000002ZZZX0EEEE05EEE@000000oooo05EEE@3oool0
EEEE0:ZZZP000000oooo0:ZZZP1EEED0ZZZZ0080000000H0oooo0000003oool000000?ooo`2ZZZX2
05EEE@80000000P0EEEE0:ZZZP2ZZZX0oooo0000003oool000000:ZZZP80000000X0ZZZZ05EEE@3o
ool0oooo0000003oool0EEEE0?ooo`2ZZZX0oooo0`1EEED20000000305EEE@000000oooo00P0oooo
303AcJT000/0dLfY2@3oool010000000oooo0000003oool40:ZZZP@000000P1EEED01@000000ZZZZ
0?ooo`3oool000000080oooo00H000000?ooo`000000oooo05EEE@3oool20:ZZZP090?ooo`2ZZZX0
oooo0000003oool000000?ooo`2ZZZX000000080oooo00D0ZZZZ05EEE@1EEED0EEEE0?ooo`030000
00D0ZZZZ00<000000?ooo`3oool02@3oool:0=7=ZA80oooo00<000000?ooo`1EEED01@1EEED01P00
0000EEEE0000002ZZZX000000:ZZZP<0EEEE103oool02@2ZZZX0EEEE05EEE@2ZZZX000000:ZZZP00
0000EEEE0:ZZZP0605EEE@030?ooo`000000oooo0140oooo2P3AcJTI0?ooo`0405EEE@2ZZZX0ZZZZ
0?ooo`80000000H0oooo05EEE@1EEED0EEEE0000003oool300000080EEEE0`000000101EEED0ZZZZ
0:ZZZP1EEEDI0?ooo`X0dLfY2@3oool2000000040:ZZZP000000000000000080EEEE0`00000305EE
E@80ZZZZ0P00000305EEE@030:ZZZP000000oooo00<000000P3oool010000000ZZZZ0000003oool2
0:ZZZP<0EEEE00<0ZZZZ0000002ZZZX00`1EEED0102ZZZX000000000003oool205EEE@<0000000<0
ZZZZ0000003oool02@3oool:0=7=Z@T0oooo0P0000000`3oool0ZZZZ00000002000000030?ooo`1E
EED0EEEE0080ZZZZ0P3oool305EEE@040:ZZZP3oool0EEEE0:ZZZP80oooo00<0EEEE0?ooo`1EEED0
100000001`1EEED0oooo05EEE@2ZZZX0oooo0:ZZZP1EEED00P3oool205EEE@<0oooo00@000000:ZZ
ZP1EEED0EEEE0P3oool200000080oooo00<000000?ooo`3oool0203oool<0=7=Z@002`3AcJT;0?oo
o`070000001EEED0EEEE0?ooo`2ZZZX0oooo05EEE@020:ZZZP0605EEE@2ZZZX0EEEE05EEE@2ZZZX0
oooo0P2ZZZX5000000030:ZZZP3oool0ZZZZ0080oooo00D0ZZZZ05EEE@2ZZZX000000:ZZZP030000
00040:ZZZP000000oooo0:ZZZP80EEEE00@0ZZZZ0?ooo`2ZZZX0ZZZZ103oool00`1EEED0oooo0000
000;0?ooo`X0dLfY4`3oool01@1EEED0ZZZZ05EEE@2ZZZX0EEEE0080ZZZZ00<0EEEE0000002ZZZX0
0`2ZZZX305EEE@@0oooo00<0ZZZZ05EEE@1EEED00`2ZZZX20000000505EEE@2ZZZX0ZZZZ05EEE@2Z
ZZX00`1EEEDC0?ooo`X0dLfY6`3oool0101EEED0oooo0?ooo`1EEED3000000030:ZZZP1EEED0EEEE
0080EEEE00H0ZZZZ000000000000000005EEE@3oool205EEE@030000003oool0oooo01P0oooo2P3A
cJT;0?ooo`060000001EEED0EEEE0?ooo`000000oooo0P2ZZZX0101EEED0000000000000000205EE
E@050:ZZZP3oool0oooo0000003oool00`1EEED00`2ZZZX0oooo0?ooo`030?ooo`050000002ZZZX0
EEEE0:ZZZP1EEED00`3oool010000000ZZZZ05EEE@1EEED200000080EEEE00<0ZZZZ05EEE@3oool0
0P3oool00`1EEED0ZZZZ0000000;0?ooo`X0dLfY2`3oool010000000EEEE0:ZZZP00000505EEE@@0
ZZZZ00D0oooo05EEE@1EEED000000?ooo`030:ZZZP80000000<0ZZZZ0?ooo`0000000`3oool20000
000505EEE@2ZZZX0ZZZZ0?ooo`0000000P1EEED0103oool0EEEE0:ZZZP2ZZZX505EEE@050?ooo`00
0000ZZZZ05EEE@0000002`3oool<0=7=Z@002`3AcJT<0?ooo`030:ZZZP000000ZZZZ00<0000000<0
oooo0000002ZZZX01@2ZZZX00`000000oooo0:ZZZP020?ooo`0305EEE@2ZZZX0ZZZZ0080000000<0
ZZZZ000000000000102ZZZX50?ooo`80ZZZZ00<000000:ZZZP2ZZZX00P0000001`3oool0EEEE0000
00000000ZZZZ0000002ZZZX0303oool:0=7=ZAD0oooo00L0EEEE0:ZZZP2ZZZX0ZZZZ0000003oool0
00000080ZZZZ00D0EEEE0:ZZZP2ZZZX0ZZZZ05EEE@040?ooo`<0ZZZZ0P1EEED01@2ZZZX000000000
003oool0000000<0ZZZZ00<0EEEE0000003oool04`3oool:0=7=ZAX0oooo0P2ZZZX20?ooo`0705EE
E@00000000000:ZZZP1EEED0ZZZZ05EEE@020:ZZZP0805EEE@2ZZZX000000:ZZZP1EEED0oooo05EE
E@2ZZZXK0?ooo`X0dLfY303oool305EEE@050?ooo`000000EEEE05EEE@2ZZZX00`00000205EEE@06
0000003oool0oooo0?ooo`000000ZZZZ0`1EEED01P3oool000000?ooo`2ZZZX000000:ZZZP<0EEEE
00<0ZZZZ0000003oool00P3oool00`000000EEEE00000003000000050:ZZZP1EEED0ZZZZ0000003o
ool00P1EEED00`000000oooo0?ooo`0:0?ooo`X0dLfY303oool00`000000oooo0:ZZZP0605EEE@09
0?ooo`1EEED0EEEE0?ooo`000000oooo0000001EEED0oooo0080EEEE00@0oooo0:ZZZP2ZZZX00000
0P2ZZZX010000000oooo0:ZZZP3oool205EEE@80oooo0`000000103oool0EEEE05EEE@3oool605EE
E@030:ZZZP3oool0000000`0oooo303AcJT000/0dLfY303oool00`000000oooo0:ZZZP020:ZZZP09
05EEE@3oool0oooo0?ooo`1EEED0ZZZZ0?ooo`000000oooo0080EEEE0P0000000`1EEED0ZZZZ0:ZZ
ZP020:ZZZP0405EEE@2ZZZX0ZZZZ05EEE@<0ZZZZ00D0000005EEE@000000000005EEE@020?ooo`05
0000003oool0ZZZZ05EEE@2ZZZX00P3oool0101EEED0ZZZZ05EEE@2ZZZX>0?ooo`X0dLfY503oool5
0:ZZZP@000000`2ZZZX00`000000ZZZZ05EEE@040?ooo`80ZZZZ00<000000:ZZZP2ZZZX00P2ZZZX3
000000040:ZZZP1EEED0ZZZZ0:ZZZQD0oooo2P3AcJTJ0?ooo`0305EEE@000000oooo0080oooo0P1E
EED02P000000oooo0000003oool0EEEE0000003oool0000005EEE@0000030?ooo`030000003oool0
oooo01T0oooo2P3AcJT<0?ooo`80000000<0ZZZZ0?ooo`2ZZZX00P1EEED010000000oooo0:ZZZP3o
ool2000000D0oooo00D0000005EEE@1EEED000000?ooo`0205EEE@040:ZZZP1EEED0EEEE00000080
EEEE00<000000?ooo`3oool00`3oool01P000000oooo0?ooo`2ZZZX0oooo00000080EEEE00@0ZZZZ
0000002ZZZX000003@3oool:0=7=Z@`0oooo00<000000?ooo`1EEED01`1EEED01P2ZZZX000000?oo
o`1EEED0oooo0:ZZZP80EEEE00@0ZZZZ0000003oool0EEEE0P2ZZZX00`1EEED0ZZZZ0:ZZZP0205EE
E@030?ooo`000000ZZZZ0080EEEE0P2ZZZX0101EEED0oooo0000002ZZZX805EEE@h0oooo303AcJT0
00/0dLfY3P3oool200000080ZZZZ00D000000:ZZZP3oool0ZZZZ05EEE@030:ZZZP0605EEE@2ZZZX0
ZZZZ0?ooo`000000oooo0P1EEED50:ZZZP<0EEEE0P000000103oool0ZZZZ0:ZZZP3oool20:ZZZP06
0?ooo`1EEED0ZZZZ0?ooo`2ZZZX000000P2ZZZX00`3oool000000?ooo`0=0?ooo`X0dLfY5@3oool0
10000000oooo05EEE@2ZZZX300000080oooo00D000000:ZZZP2ZZZX0ZZZZ05EEE@040?ooo`@0ZZZZ
00X000000?ooo`00000000000?ooo`000000ZZZZ05EEE@3oool000005@3oool:0=7=ZAh0oooo00D0
00000:ZZZP2ZZZX0oooo0:ZZZP060?ooo`050:ZZZP00000000000?ooo`2ZZZX0703oool:0=7=Z@h0
oooo00<0000005EEE@1EEED00`3oool30:ZZZPD0oooo0P1EEED00`3oool000000?ooo`020:ZZZP@0
EEEE00<0oooo0:ZZZP3oool00P3oool00`1EEED0oooo0?ooo`030?ooo`040000002ZZZX0ZZZZ0000
0080oooo00@0ZZZZ05EEE@2ZZZX000003P3oool:0=7=Z@h0oooo00<000000?ooo`3oool00`000000
1`2ZZZX0EEEE0?ooo`3oool000000?ooo`2ZZZX00P3oool205EEE@040?ooo`00000000000:ZZZP@0
EEEE0`00000305EEE@080:ZZZP3oool000000?ooo`000000EEEE0?ooo`1EEED3000000040:ZZZP3o
ool00000000000h0oooo303AcJT000/0dLfY3`3oool0102ZZZX0EEEE0:ZZZP1EEED40:ZZZP<00000
102ZZZX0103oool0ZZZZ0:ZZZP0000060:ZZZP040000002ZZZX0oooo0?ooo`<0ZZZZ100000020:ZZ
ZP060?ooo`2ZZZX0EEEE0000001EEED0ZZZZ3`3oool:0=7=ZAH0oooo0`2ZZZX2000000050:ZZZP00
000000000000002ZZZX00`1EEED40?ooo`040:ZZZP1EEED0EEEE0:ZZZP<0000000<0ZZZZ00000000
00000`2ZZZXF0?ooo`X0dLfY703oool40000000305EEE@3oool0EEEE00@000000P3oool01@1EEED0
oooo000000000000EEEE01`0oooo2P3AcJT?0?ooo`80EEEE0P2ZZZX01P3oool0EEEE05EEE@2ZZZX0
oooo05EEE@<0oooo0`1EEED00`3oool000000:ZZZP0505EEE@80ZZZZ00<000000?ooo`1EEED00P1E
EED30?ooo`80EEEE00D0ZZZZ05EEE@2ZZZX0oooo0:ZZZP0205EEE@030000003oool0oooo00d0oooo
2P3AcJT@0?ooo`80EEEE00H0ZZZZ0?ooo`000000ZZZZ05EEE@0000020?ooo`080000002ZZZX0EEEE
05EEE@000000EEEE0?ooo`2ZZZX505EEE@030?ooo`2ZZZX0oooo0080000000<0EEEE0:ZZZP2ZZZX0
0`3oool205EEE@070:ZZZP3oool0oooo0:ZZZP3oool0EEEE0000000?0?ooo``0dLfY000;0=7=Z@l0
oooo00@000000?ooo`1EEED0EEEE0P2ZZZX01@1EEED0oooo0000003oool0ZZZZ0080000000D0oooo
000000000000000005EEE@080:ZZZP0305EEE@2ZZZX0000000<0000000P0oooo0:ZZZP3oool0ZZZZ
0?ooo`1EEED0oooo0:ZZZP80EEEE4@3oool:0=7=ZAH0oooo00D0EEEE0:ZZZP2ZZZX000000:ZZZP03
000000050?ooo`2ZZZX0ZZZZ0:ZZZP1EEED0103oool30:ZZZP040000003oool000000:ZZZP<00000
00<0ZZZZ05EEE@1EEED05P3oool:0=7=ZA`0oooo0`1EEED01P000000oooo0?ooo`3oool000000:ZZ
ZP8000000`3oool010000000EEEE05EEE@1EEEDL0?ooo`X0dLfY3`3oool300000080ZZZZ0`1EEED0
1@000000oooo0000003oool0ZZZZ00<0EEEE00<0oooo05EEE@2ZZZX01P1EEED00`2ZZZX0EEEE05EE
E@0205EEE@060000002ZZZX0ZZZZ0000003oool0ZZZZ0`1EEED30:ZZZP030000003oool0oooo00h0
oooo2P3AcJT?0?ooo`040000001EEED0ZZZZ00000080oooo00P0ZZZZ0000003oool0oooo05EEE@3o
ool0ZZZZ0?ooo`<000000P2ZZZX605EEE@80ZZZZ10000000102ZZZX0oooo05EEE@3oool200000004
0:ZZZP1EEED0oooo00000080EEEE403oool<0=7=Z@002`3AcJTB0?ooo`050:ZZZP1EEED0ZZZZ0:ZZ
ZP000000102ZZZX01P3oool0000005EEE@2ZZZX0oooo000000@0oooo00D000000?ooo`000000oooo
000000020:ZZZP0305EEE@000000oooo00<0ZZZZ00L0oooo0000002ZZZX0oooo05EEE@2ZZZX00000
0140oooo2P3AcJTG0?ooo`D0ZZZZ0P000000102ZZZX000000000001EEED50?ooo`050000001EEED0
00000000002ZZZX00P0000040:ZZZQP0oooo2P3AcJTL0?ooo`030:ZZZP3oool0ZZZZ0080EEEE00D0
000005EEE@1EEED0oooo0000000205EEE@060000001EEED0EEEE0:ZZZP3oool0EEEE703oool:0=7=
ZA40oooo00<0ZZZZ05EEE@1EEED0101EEED20:ZZZP040000002ZZZX0EEEE0?ooo`80ZZZZ2P1EEED0
1P3oool0ZZZZ0?ooo`3oool0ZZZZ00000080ZZZZ1P1EEED00`000000oooo0?ooo`0?0?ooo`X0dLfY
4P3oool405EEE@070?ooo`1EEED0oooo0:ZZZP000000ZZZZ000000020:ZZZP030?ooo`000000EEEE
0080EEEE00<0000005EEE@1EEED00P1EEED200000080ZZZZ00L0oooo0:ZZZP000000ZZZZ0?ooo`1E
EED0oooo00@0EEEE00<000000?ooo`3oool03`3oool<0=7=Z@002`3AcJTA0?ooo`<0ZZZZ00<00000
0?ooo`3oool01@2ZZZX010000000ZZZZ0:ZZZP2ZZZX20?ooo`80ZZZZ0P3oool0102ZZZX0oooo0?oo
o`3oool30:ZZZP030?ooo`2ZZZX0ZZZZ00<0ZZZZ0P3oool00`000000ZZZZ0:ZZZP0B0?ooo`X0dLfY
5`3oool205EEE@<0ZZZZ00H000000:ZZZP1EEED0000005EEE@2ZZZX60?ooo`0:0:ZZZP1EEED0ZZZZ
05EEE@2ZZZX000000:ZZZP1EEED0ZZZZ05EEEAP0oooo2P3AcJTL0?ooo`050000001EEED000000?oo
o`0000000`3oool2000000070?ooo`000000oooo0000003oool0000005EEE@0M0?ooo`X0dLfY4@3o
ool010000000EEEE05EEE@1EEED2000000030:ZZZP000000ZZZZ0080ZZZZ00<0oooo0000002ZZZX0
2`1EEED20:ZZZP8000000`2ZZZX010000000EEEE00000000000305EEEA80oooo2P3AcJTA0?ooo`05
0000001EEED0EEEE0000002ZZZX00P1EEED00`000000oooo05EEE@020?ooo`050:ZZZP000000oooo
0?ooo`0000000P1EEED20000000305EEE@00000000000080oooo00L000000:ZZZP1EEED0oooo0:ZZ
ZP3oool000000080EEEE00@0ZZZZ0000001EEED0EEEE4P3oool<0=7=Z@002`3AcJTB0?ooo`040000
003oool0ZZZZ0?ooo`H0ZZZZ0P3oool3000000040:ZZZP00000000000:ZZZP<0000000D0ZZZZ0000
003oool000000?ooo`070:ZZZP040?ooo`000000oooo00000180oooo2P3AcJTH0?ooo`050000003o
ool0ZZZZ0:ZZZP0000000P2ZZZX20000000305EEE@3oool0oooo00@0oooo00<0EEEE0000002ZZZX0
0P2ZZZX01@000000ZZZZ05EEE@3oool0000001P0oooo2P3AcJTM0?ooo`040:ZZZP000000EEEE0000
0080EEEE00<000000?ooo`0000000P0000001@1EEED00000000000000000ZZZZ01d0oooo2P3AcJTB
0?ooo`D0000000P0oooo05EEE@2ZZZX0EEEE0:ZZZP3oool0EEEE0:ZZZP`0EEEE00L0ZZZZ05EEE@1E
EED0ZZZZ05EEE@2ZZZX0EEEE00<0000000<0ZZZZ0000000000004P3oool:0=7=ZA80oooo0P000000
1P3oool0ZZZZ0000003oool000000?ooo`80EEEE00<000000:ZZZP3oool0103oool5000000@0oooo
0P2ZZZX205EEE@060?ooo`00000000000000002ZZZX0oooo0P00000B0?ooo``0dLfY000;0=7=ZAD0
oooo0P1EEED00`3oool0ZZZZ0?ooo`020?ooo`030:ZZZP3oool0ZZZZ0080ZZZZ00P0000005EEE@00
0000oooo0:ZZZP000000EEEE000000<0ZZZZ00<0oooo0:ZZZP3oool00P3oool01@2ZZZX0oooo05EE
E@1EEED0000001@0oooo2P3AcJTI0?ooo`0305EEE@2ZZZX0ZZZZ00@0ZZZZ2`0000040:ZZZP80EEEE
6@3oool:0=7=ZAd0oooo0P1EEED20:ZZZP80000000<0EEEE0:ZZZP0000000P1EEED00`000000ZZZZ
05EEE@0205EEEAd0oooo2P3AcJTD0?ooo`050:ZZZP1EEED0EEEE0?ooo`0000000P1EEED20:ZZZQ00
EEEE00H0oooo0:ZZZP000000EEEE0000003oool205EEE@030000003oool0oooo0180oooo2P3AcJTD
0?ooo`80EEEE00<0ZZZZ0?ooo`1EEED0101EEED20:ZZZP0505EEE@2ZZZX0oooo0:ZZZP3oool00P2Z
ZZX00`3oool000000?ooo`040:ZZZPD0EEEE00@000000:ZZZP1EEED00000503oool<0=7=Z@002`3A
cJTD0?ooo`80ZZZZ1P000000201EEED00000000000000000oooo0000002ZZZX000000P3oool00`00
0000ZZZZ000000020?ooo`80000000<0ZZZZ0000001EEED00P0000000`2ZZZX000000:ZZZP0E0?oo
o`X0dLfY6`3oool00`1EEED0ZZZZ0:ZZZP02000000050:ZZZP000000oooo0000002ZZZX010000002
0:ZZZP050000002ZZZX0EEEE05EEE@0000006P3oool:0=7=ZAd0oooo0`1EEED02`000000oooo0:ZZ
ZP1EEED000000:ZZZP1EEED000000?ooo`000000oooo0080EEEE7@3oool:0=7=ZA@0oooo00<00000
05EEE@1EEED00P3oool2000000030:ZZZP1EEED0EEEE00l0EEEE0P2ZZZX2000000040?ooo`1EEED0
EEEE05EEEAD0oooo2P3AcJTD0?ooo`80000000<0oooo05EEE@1EEED01@1EEED01`3oool0EEEE05EE
E@3oool000000:ZZZP1EEED00P2ZZZX20?ooo`80EEEE00<0oooo05EEE@1EEED0101EEED00`2ZZZX0
oooo0000000E0?ooo``0dLfY000;0=7=ZAD0oooo00<000000?ooo`1EEED00P2ZZZX01@1EEED0oooo
0:ZZZP1EEED0ZZZZ0080oooo0`1EEED20?ooo`<0EEEE00<0oooo0:ZZZP2ZZZX00P1EEED00`3oool0
EEEE0:ZZZP020:ZZZP030?ooo`000000oooo01@0oooo2P3AcJTJ0?ooo`<0ZZZZ00D000000?ooo`2Z
ZZX0EEEE0:ZZZP03000000080:ZZZP00000000000:ZZZP1EEED000000?ooo`0000020:ZZZQ/0oooo
2P3AcJTM0?ooo`0505EEE@2ZZZX0ZZZZ0000001EEED00P2ZZZX205EEE@070:ZZZP000000EEEE0000
003oool0ZZZZ05EEE@0M0?ooo`X0dLfY5@3oool3000000040?ooo`2ZZZX0EEEE0:ZZZQ80EEEE00D0
ZZZZ0?ooo`2ZZZX0oooo0:ZZZP02000001D0oooo2P3AcJTE0?ooo`030000003oool0EEEE00L0EEEE
0P0000020?ooo`080:ZZZP3oool000000:ZZZP1EEED0oooo0000002ZZZX805EEE@030?ooo`000000
oooo01@0oooo303AcJT000/0dLfY603oool020000000ZZZZ0:ZZZP000000oooo0:ZZZP000000EEEE
0`2ZZZX0101EEED0ZZZZ0000001EEED40:ZZZP040000002ZZZX0ZZZZ00000080ZZZZ0P00000G0?oo
o`X0dLfY6`3oool00`000000EEEE05EEE@0205EEE@80ZZZZ00H000000:ZZZP3oool0oooo0:ZZZP00
00020:ZZZP<0EEEE00<0oooo0000003oool06P3oool:0=7=ZAl0oooo0`0000020:ZZZP040000002Z
ZZX0ZZZZ0:ZZZP80000000<0ZZZZ0?ooo`3oool07@3oool:0=7=ZAL0oooo00H0ZZZZ05EEE@1EEED0
oooo0:ZZZP00000205EEE@<0000000<0EEEE0000003oool00P0000000`1EEED000000000000405EE
E@80ZZZZ0P1EEED00`000000oooo0?ooo`0E0?ooo`X0dLfY5`3oool00`000000oooo0?ooo`030000
00040:ZZZP1EEED0EEEE0?ooo`8000000P2ZZZX0101EEED0ZZZZ0?ooo`0000020?ooo`0505EEE@2Z
ZZX000000000002ZZZX00P3oool00`000000oooo0?ooo`0E0?ooo``0dLfY000;0=7=ZAL0oooo0P2Z
ZZX00`1EEED0ZZZZ05EEE@02000000030?ooo`1EEED0EEEE00<0EEEE0P2ZZZX405EEE@080:ZZZP3o
ool000000:ZZZP1EEED0000005EEE@2ZZZXH0?ooo`X0dLfY703oool50:ZZZP80000000H0EEEE0?oo
o`3oool0EEEE0:ZZZP0000050:ZZZQ`0oooo2P3AcJTO0?ooo`0<0000002ZZZX0EEEE0?ooo`1EEED0
oooo0000001EEED0000005EEE@2ZZZX0EEEE7`3oool:0=7=ZAL0oooo00<0000005EEE@1EEED00P2Z
ZZX2000000060?ooo`00000000000000003oool000000P3oool5000000040?ooo`00000000000:ZZ
ZP<0EEEE603oool:0=7=ZAL0oooo00X000000?ooo`1EEED0EEEE0:ZZZP3oool000000:ZZZP1EEED0
00000P3oool010000000EEEE0:ZZZP0000020?ooo`080000001EEED0ZZZZ0000003oool0ZZZZ0?oo
o`1EEEDI0?ooo``0dLfY000;0=7=ZAP0oooo00@000000?ooo`1EEED0EEEE0P3oool20:ZZZP030000
002ZZZX0000000H0ZZZZ00D000000:ZZZP2ZZZX0oooo0:ZZZP0205EEE@030?ooo`000000oooo01L0
oooo2P3AcJTL0?ooo`0705EEE@2ZZZX0EEEE0:ZZZP000000ZZZZ05EEE@040000000705EEE@2ZZZX0
00000:ZZZP1EEED0ZZZZ05EEE@0L0?ooo`X0dLfY7`3oool205EEE@030:ZZZP3oool0oooo00800000
0P3oool00`2ZZZX0EEEE05EEE@0O0?ooo`X0dLfY603oool3000000@0ZZZZ00<0oooo0:ZZZP3oool0
0P2ZZZX01`3oool0ZZZZ0:ZZZP1EEED0oooo0:ZZZP1EEED01@2ZZZX2000001P0oooo2P3AcJTH0?oo
o`080000001EEED0ZZZZ0000001EEED0oooo0:ZZZP0000040?ooo`030:ZZZP000000oooo00<0oooo
00D000000:ZZZP3oool0oooo0000000205EEE@030000003oool0oooo01H0oooo303AcJT000/0dLfY
6`3oool0102ZZZX0oooo0:ZZZP2ZZZX3000000H0ZZZZ0P0000030:ZZZP0305EEE@2ZZZX0000001X0
oooo2P3AcJTM0?ooo`80ZZZZ00<0oooo0:ZZZP0000000P0000000`1EEED0ZZZZ0000000200000004
0:ZZZP1EEED0ZZZZ0:ZZZQd0oooo2P3AcJTO0?ooo`050:ZZZP3oool0ZZZZ0000003oool00P000000
1@3oool000000:ZZZP3oool0EEEE01l0oooo2P3AcJTJ0?ooo`080:ZZZP1EEED0EEEE05EEE@2ZZZX0
00000?ooo`2ZZZX205EEE@080?ooo`000000EEEE05EEE@2ZZZX0oooo0000002ZZZX305EEE@030000
003oool0oooo01P0oooo2P3AcJTK0?ooo`H0EEEE00<0oooo0000003oool00P1EEED01@3oool0ZZZZ
0?ooo`1EEED0oooo00@0EEEE00<000000?ooo`3oool0603oool<0=7=Z@002`3AcJTJ0?ooo`80ZZZZ
0`0000000`3oool0ZZZZ0?ooo`030?ooo`050000003oool000000?ooo`2ZZZX00`0000020:ZZZQ/0
oooo2P3AcJTM0?ooo`80EEEE00D0oooo0:ZZZP000000EEEE000000020:ZZZP030000001EEED00000
0080ZZZZ0P1EEEDM0?ooo`X0dLfY7`3oool00`000000EEEE0000000200000080EEEE00@000000?oo
o`000000EEEE803oool:0=7=ZAX0oooo00<0000005EEE@1EEED00P1EEED00`3oool0EEEE05EEE@02
00000080oooo00D000000:ZZZP1EEED0EEEE0:ZZZP0405EEEA/0oooo2P3AcJTJ0?ooo`050000001E
EED000000000002ZZZX00P1EEED00`000000ZZZZ05EEE@0305EEE@060?ooo`000000EEEE05EEE@2Z
ZZX000000P1EEEDK0?ooo``0dLfY000;0=7=ZA/0oooo0P0000000`2ZZZX0oooo0:ZZZP020:ZZZP06
0?ooo`1EEED0EEEE0?ooo`1EEED0oooo0P2ZZZX20?ooo`030:ZZZP3oool0000001/0oooo2P3AcJTN
0?ooo`080000002ZZZX0ZZZZ0000001EEED000000?ooo`1EEED3000000030:ZZZP3oool0000001h0
oooo2P3AcJTP0?ooo`070:ZZZP00000000000:ZZZP3oool0EEEE0:ZZZP02000000030:ZZZP3oool0
oooo01h0oooo2P3AcJTK0?ooo`040000002ZZZX00000000000<0EEEE00<0ZZZZ0?ooo`3oool00P3o
ool305EEE@030?ooo`0000000000008000006`3oool:0=7=ZA/0oooo00L000000?ooo`3oool0ZZZZ
0000003oool0000000D0EEEE00H0oooo0000003oool000000:ZZZP3oool2000001/0oooo303AcJT0
00/0dLfY703oool00`000000oooo05EEE@020?ooo`080:ZZZP3oool0oooo05EEE@2ZZZX0oooo0000
002ZZZX20?ooo`0305EEE@3oool0oooo01`0oooo2P3AcJTO0?ooo`0405EEE@2ZZZX0oooo0:ZZZP@0
000000@0EEEE0?ooo`2ZZZX0EEEE7`3oool:0=7=ZB00oooo0P1EEED00`2ZZZX0oooo0?ooo`020?oo
o`<0EEEE803oool:0=7=ZA`0oooo00D000000:ZZZP1EEED0oooo0:ZZZP0405EEE@050:ZZZP1EEED0
000005EEE@2ZZZX00P1EEED00`2ZZZX0oooo0?ooo`0K0?ooo`X0dLfY703oool01@000000EEEE05EE
E@000000oooo00P0EEEE00@0oooo0:ZZZP1EEED0EEEE7@3oool<0=7=Z@002`3AcJTM0?ooo`80ZZZZ
00<0000005EEE@1EEED00P3oool00`2ZZZX0EEEE0?ooo`0305EEE@030000002ZZZX0ZZZZ01d0oooo
2P3AcJTO0?ooo`060000003oool0ZZZZ0:ZZZP000000oooo0P0000020:ZZZR40oooo2P3AcJTP0?oo
o`<0EEEE100000000`3oool0EEEE05EEE@0P0?ooo`X0dLfY7@3oool010000000EEEE05EEE@3oool2
000000040:ZZZP1EEED0EEEE0:ZZZP80000000@0oooo05EEE@1EEED000007@3oool:0=7=ZAd0oooo
0P0000000`2ZZZX0EEEE05EEE@0805EEE@030?ooo`000000000001d0oooo303AcJT000/0dLfY7`3o
ool20:ZZZP0805EEE@2ZZZX000000000003oool000000?ooo`1EEED20:ZZZQl0oooo2P3AcJTP0?oo
o`80EEEE00<0oooo05EEE@1EEED00P1EEED00`2ZZZX0EEEE05EEE@0P0?ooo`X0dLfY8@3oool20000
00060?ooo`00000000000?ooo`1EEED000008@3oool:0=7=ZB00oooo00<0EEEE0:ZZZP1EEED0101E
EED20:ZZZP0305EEE@000000oooo01h0oooo2P3AcJTO0?ooo`80EEEE0P0000020?ooo`060000003o
ool000000000001EEED000007`3oool<0=7=Z@002`3AcJTO0?ooo`040000003oool0000000000080
ZZZZ00@0oooo0:ZZZP1EEED000008@3oool:0=7=ZB40oooo00<000000:ZZZP2ZZZX00`2ZZZX00`3o
ool000000?ooo`0P0?ooo`X0dLfY8P3oool200000080EEEE00<000000:ZZZP3oool08@3oool:0=7=
ZAl0oooo00H000000:ZZZP1EEED0ZZZZ0000003oool200000080EEEE00<0ZZZZ0?ooo`3oool07P3o
ool:0=7=ZAl0oooo0P0000001@3oool0ZZZZ0?ooo`3oool0ZZZZ00<0oooo00<000000?ooo`3oool0
7P3oool<0=7=Z@002`3AcJTP0?ooo`80ZZZZ00H0EEEE0?ooo`2ZZZX0ZZZZ0?ooo`1EEED20:ZZZR00
oooo2P3AcJTR0?ooo`030:ZZZP1EEED0oooo0080EEEE00<0ZZZZ0?ooo`3oool0803oool:0=7=ZB80
oooo00<0000005EEE@3oool00`1EEEDR0?ooo`X0dLfY803oool010000000EEEE05EEE@2ZZZX20?oo
o`040:ZZZP1EEED0EEEE00000200oooo2P3AcJTP0?ooo`030000003oool0oooo0080EEEE00D0oooo
05EEE@1EEED0oooo0000000P0?ooo``0dLfY000;0=7=ZB80oooo00H0ZZZZ0000002ZZZX0oooo0000
002ZZZXR0?ooo`X0dLfY8P3oool010000000oooo0:ZZZP2ZZZXT0?ooo`X0dLfY8P3oool010000000
oooo0:ZZZP2ZZZXT0?ooo`X0dLfY8`3oool205EEE@030:ZZZP1EEED000000280oooo2P3AcJTR0?oo
o`060000003oool0EEEE0:ZZZP3oool000008P3oool<0=7=Z@002`3AcJTR0?ooo`040000003oool0
ZZZZ0:ZZZR@0oooo2P3AcJTS0?ooo`040:ZZZP000000ZZZZ0:ZZZR<0oooo2P3AcJTS0?ooo`040:ZZ
ZP000000ZZZZ0:ZZZR<0oooo2P3AcJTR0?ooo`050000002ZZZX0EEEE05EEE@2ZZZX08`3oool:0=7=
ZB80oooo00@000000?ooo`1EEED0EEEE903oool<0=7=Z@002`3AcJTS0?ooo`@0ZZZZ8`3oool:0=7=
ZB<0oooo00@0EEEE0?ooo`000000EEEE8`3oool:0=7=ZB<0oooo00@0EEEE0?ooo`000000EEEE8`3o
ool:0=7=ZB<0oooo0P0000000`1EEED000000?ooo`0R0?ooo`X0dLfY8`3oool20000000305EEE@00
0000oooo0280oooo303AcJT000/0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool0
0`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool0
0`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo``0dLfY003o0=7=
ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY000;0=7=
Z@050?ooo`2ZZZX000000?ooo`2ZZZX00`3oool2000000090:ZZZP3oool0ZZZZ0000002ZZZX0EEEE
0:ZZZP000000ZZZZ00<000001@2ZZZX3000000030:ZZZP3oool0oooo0080oooo00D0EEEE0000001E
EED0EEEE000000020?ooo`80ZZZZ0`0000030:ZZZP070000002ZZZX0000005EEE@000000ZZZZ05EE
E@030:ZZZP80000000@0oooo0:ZZZP1EEED000000`3oool01@000000oooo000000000000oooo00X0
dLfY103oool00`000000ZZZZ0:ZZZP040?ooo`0305EEE@3oool0oooo0080oooo00X0EEEE0:ZZZP3o
ool000000?ooo`2ZZZX000000:ZZZP000000oooo0P000000102ZZZX000000?ooo`2ZZZX<0?ooo`<0
00000P3oool3000000030:ZZZP3oool000000080oooo00<0EEEE0?ooo`3oool00P3oool00`1EEED0
oooo0?ooo`020?ooo`80ZZZZ00D000000?ooo`3oool000000?ooo`0:0=7=Z@030?ooo`000000ZZZZ
0080ZZZZ0P3oool40:ZZZP050000002ZZZX0oooo0:ZZZP1EEED010000000103oool0000000000000
00020?ooo`<0EEEE0P2ZZZX2000000030?ooo`000000oooo00D0oooo0P0000020:ZZZP80EEEE00@0
ZZZZ0?ooo`3oool0ZZZZ0P0000000`2ZZZX0000000000003000000040:ZZZP3oool00000000000@0
ZZZZ0P3oool01@000000ZZZZ0:ZZZP000000oooo00X0dLfY0P3oool30:ZZZP80oooo0P2ZZZX00`1E
EED000000:ZZZP02000000040:ZZZP000000EEEE05EEE@<0000000<0ZZZZ0000001EEED00`1EEED2
000000<0EEEE00<000000:ZZZP2ZZZX01P2ZZZX200000080EEEE0P00000405EEE@030000002ZZZX0
0000008000000P1EEED20:ZZZP040000001EEED0ZZZZ000000<0ZZZZ0P3oool01@1EEED0ZZZZ0:ZZ
ZP000000oooo00X0dLfY00@0oooo05EEE@1EEED000000P3oool00`000000EEEE0000000400000080
oooo00<0EEEE0000002ZZZX00P1EEED00`3oool00000000000020000000405EEE@3oool0ZZZZ0?oo
o`80000000D0oooo05EEE@000000EEEE000000020?ooo`030000001EEED000000080EEEE0`000000
0`2ZZZX0oooo05EEE@0500000080EEEE0P0000000`1EEED0oooo0?ooo`050000000805EEE@3oool0
oooo05EEE@000000EEEE0000003oool<0=7=Z@002`3AcJT0103oool0000005EEE@1EEED300000003
0?ooo`000000ZZZZ0080EEEE0P0000001P2ZZZX000000?ooo`1EEED000000?ooo`<0ZZZZ00P00000
05EEE@000000EEEE0000001EEED0000005EEE@8000000P3oool00`000000oooo0:ZZZP020000000;
0?ooo`000000oooo05EEE@000000EEEE0000003oool0000005EEE@0000000P2ZZZX20?ooo`030000
001EEED0oooo0080ZZZZ00L0000005EEE@1EEED0EEEE0?ooo`000000oooo008000000`1EEED20?oo
o`X0dLfY00d0oooo0:ZZZP2ZZZX0oooo0000003oool000000?ooo`2ZZZX0oooo0000002ZZZX0oooo
00<0ZZZZ00@000000?ooo`1EEED0EEEE0P3oool01P000000oooo0?ooo`2ZZZX0oooo00000080oooo
00<0ZZZZ0?ooo`3oool00P3oool0101EEED0oooo0?ooo`1EEED30?ooo`030000002ZZZX0oooo00<0
000000D0ZZZZ0?ooo`00000000000?ooo`0305EEE@030:ZZZP000000oooo00@0ZZZZ00<000000:ZZ
ZP2ZZZX00`3oool00`000000oooo0:ZZZP020?ooo`X0dLfY00@0oooo0:ZZZP3oool0EEEE2@2ZZZX0
1P3oool0ZZZZ0:ZZZP000000ZZZZ00000080ZZZZ0P3oool00`000000ZZZZ05EEE@02000000040:ZZ
ZP000000oooo0:ZZZP<0oooo00@0ZZZZ0?ooo`2ZZZX0ZZZZ1@3oool40000000305EEE@2ZZZX0ZZZZ
0080oooo0P2ZZZX01`000000ZZZZ000000000000ZZZZ0?ooo`0000001@2ZZZX0103oool0ZZZZ05EE
E@1EEED30?ooo`X0dLfY00D0oooo0:ZZZP2ZZZX0ZZZZ05EEE@020?ooo`0905EEE@2ZZZX0EEEE0000
002ZZZX0EEEE0000002ZZZX0000000H0EEEE00P0ZZZZ0000001EEED0000005EEE@000000EEEE0000
0080EEEE00<000000:ZZZP2ZZZX01P2ZZZX01@000000EEEE05EEE@000000ZZZZ00<0000000<0EEEE
0000002ZZZX0101EEED01@000000EEEE0:ZZZP2ZZZX000000080ZZZZ00@0000005EEE@2ZZZX0EEEE
0P3oool30:ZZZP80oooo2P3AcJT01P3oool0ZZZZ0000003oool0ZZZZ00000080ZZZZ00<0EEEE0?oo
o`0000000`1EEED4000000030?ooo`2ZZZX0EEEE00D0EEEE0P3oool01`1EEED000000?ooo`2ZZZX0
00000?ooo`2ZZZX0103oool01@000000oooo000000000000oooo008000000P3oool505EEE@040000
002ZZZX0oooo0?ooo`<0000000<0EEEE0:ZZZP1EEED00P0000000`1EEED0ZZZZ0000000200000004
0?ooo`000000oooo0?ooo``0dLfY000;0=7=Z@<0oooo00<000000:ZZZP0000000P0000020:ZZZP80
oooo00<0ZZZZ0?ooo`2ZZZX00`00000405EEE@030?ooo`2ZZZX0000000<0000000<0oooo05EEE@00
00000P000000101EEED0oooo05EEE@00000405EEE@030000002ZZZX000000080EEEE10000000102Z
ZZX0oooo05EEE@00000205EEE@<0000000<0ZZZZ0?ooo`3oool00P3oool00`000000ZZZZ00000002
0000000305EEE@000000oooo0080oooo2P3AcJT30?ooo`80ZZZZ00<0oooo0000003oool0103oool3
0:ZZZP030000002ZZZX00000008000000P3oool0101EEED0ZZZZ05EEE@1EEED20:ZZZP060?ooo`2Z
ZZX000000?ooo`000000oooo0P0000020?ooo`80000000@0oooo00000000000000000`2ZZZX01P3o
ool0EEEE05EEE@2ZZZX0EEEE0?ooo`<0000000<0EEEE0:ZZZP0000000P2ZZZX30?ooo`050000003o
ool0oooo0:ZZZP3oool00P2ZZZX30?ooo`X0dLfY0`3oool01P2ZZZX0EEEE0000003oool000000:ZZ
ZP80oooo00D000000?ooo`3oool0oooo000000020?ooo`80ZZZZ0`1EEED01`2ZZZX000000:ZZZP2Z
ZZX0EEEE0?ooo`2ZZZX00P0000020?ooo`060:ZZZP3oool0oooo0:ZZZP3oool0EEEE0P3oool00`2Z
ZZX000000:ZZZP0205EEE@80ZZZZ0P00000305EEE@<0ZZZZ00h0oooo0:ZZZP3oool0oooo0:ZZZP00
0000oooo0000002ZZZX000000:ZZZP000000oooo0:ZZZP<0oooo2P3AcJT30?ooo`030:ZZZP1EEED0
oooo00@0ZZZZ0P000000101EEED000000:ZZZP00000405EEE@060:ZZZP1EEED0ZZZZ0000001EEED0
00000P1EEED00`2ZZZX0EEEE0:ZZZP0505EEE@040:ZZZP1EEED0EEEE0:ZZZP80EEEE00<000000:ZZ
ZP1EEED00P1EEED20000000505EEE@2ZZZX0ZZZZ05EEE@0000000P1EEED010000000EEEE0:ZZZP2Z
ZZX40000000505EEE@2ZZZX0ZZZZ0:ZZZP3oool00P2ZZZX30?ooo`X0dLfY0`3oool02@2ZZZX0oooo
0?ooo`3oool000000:ZZZP3oool000000:ZZZP020?ooo`040000002ZZZX0oooo0:ZZZP80000000<0
oooo0000000000000P0000000`3oool00000000000040?ooo`030000002ZZZX0oooo00D0oooo00<0
ZZZZ0000003oool00P3oool3000000030?ooo`000000oooo0080000000<0EEEE0000000000000P3o
ool01@2ZZZX000000?ooo`000000ZZZZ0080000000H0ZZZZ0000003oool0oooo0000002ZZZX30?oo
o``0dLfY000;0=7=Z@@0oooo0P2ZZZX00`3oool0ZZZZ05EEE@040000000305EEE@2ZZZX0oooo0080
ZZZZ0P3oool00`2ZZZX0EEEE0:ZZZP020:ZZZP030?ooo`2ZZZX0ZZZZ0080oooo00@0ZZZZ00000000
0000ZZZZ0`3oool01@2ZZZX0oooo0?ooo`2ZZZX000000080ZZZZ0P3oool20:ZZZP060?ooo`2ZZZX0
00000:ZZZP1EEED0ZZZZ0P3oool20:ZZZP0305EEE@2ZZZX0EEEE00<000000P1EEED30:ZZZP030000
003oool0oooo0080oooo2P3AcJT60?ooo`80000000<0ZZZZ0?ooo`3oool00P3oool010000000oooo
0:ZZZP3oool20000000305EEE@000000000000<0ZZZZ00L000000?ooo`1EEED0oooo0:ZZZP1EEED0
ZZZZ0080oooo00<0ZZZZ0?ooo`3oool01@3oool01`000000EEEE0:ZZZP2ZZZX0EEEE0:ZZZP000000
0`2ZZZX01@000000ZZZZ05EEE@000000EEEE00<0oooo00<000000?ooo`3oool00P3oool01@2ZZZX0
00000?ooo`3oool0000000@0oooo2P3AcJT40?ooo`040000002ZZZX0EEEE00000080oooo0P2ZZZX0
103oool000000000003oool20:ZZZP030?ooo`0000000000008000000P2ZZZX010000000ZZZZ0000
000000020?ooo`<0EEEE0P0000020?ooo`050000001EEED0EEEE05EEE@2ZZZX00P3oool200000004
0?ooo`000000ZZZZ0:ZZZP80000000<0ZZZZ0000003oool00P2ZZZX0103oool00000000000000003
0:ZZZP050?ooo`000000ZZZZ0:ZZZP000000103oool:0=7=Z@D0oooo102ZZZX405EEE@030000002Z
ZZX000000080EEEE00<0000005EEE@1EEED00P2ZZZX01@000000EEEE05EEE@1EEED000000080ZZZZ
0P1EEED00`000000EEEE0:ZZZP020:ZZZP0505EEE@2ZZZX0EEEE05EEE@0000000P1EEED00`2ZZZX0
00000000000305EEE@<0ZZZZ0P1EEED00`000000EEEE05EEE@020:ZZZP040000001EEED0EEEE05EE
E@D0ZZZZ00<000000?ooo`3oool00P3oool:0=7=Z@@0oooo101EEED0102ZZZX0oooo0?ooo`2ZZZX2
0000000705EEE@3oool0EEEE0?ooo`000000EEEE0:ZZZP020?ooo`060:ZZZP000000EEEE0:ZZZP1E
EED0ZZZZ100000080?ooo`030000001EEED00000008000000`1EEED03P000000ZZZZ0?ooo`3oool0
ZZZZ05EEE@000000oooo05EEE@2ZZZX0EEEE0000001EEED0ZZZZ0P3oool01@2ZZZX0EEEE0000001E
EED0000000@0oooo303AcJT000/0dLfY1@3oool3000000030?ooo`000000EEEE008000000P2ZZZX0
0`000000oooo0:ZZZP020:ZZZP<0oooo00<0EEEE0:ZZZP3oool01@2ZZZX30?ooo`060:ZZZP000000
oooo0?ooo`000000ZZZZ0`3oool40:ZZZP0405EEE@3oool0ZZZZ0:ZZZP80oooo0`2ZZZX20?ooo`0;
0000002ZZZX0ZZZZ0?ooo`000000EEEE0:ZZZP3oool000000:ZZZP0000001@3oool:0=7=Z@D0oooo
00<000000:ZZZP3oool00P3oool00`1EEED0oooo0?ooo`030?ooo`0305EEE@00000000000080oooo
0P2ZZZX70?ooo`0405EEE@000000EEEE0:ZZZPH0oooo00P0ZZZZ05EEE@000000EEEE0?ooo`000000
oooo0:ZZZP<0oooo0P2ZZZX01P1EEED0oooo0000003oool0EEEE000000@0oooo00<0EEEE0?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`X0dLfY1@3oool010000000ZZZZ0000002ZZZX205EE
E@<0ZZZZ00H0oooo0000001EEED000000:ZZZP3oool200000080oooo0P2ZZZX010000000oooo0?oo
o`0000020:ZZZP80EEEE00H0ZZZZ0000003oool0oooo0000002ZZZX305EEE@030:ZZZP000000ZZZZ
0080oooo0P2ZZZX20?ooo`0;0000003oool0oooo0:ZZZP000000EEEE0000003oool0ZZZZ0?ooo`2Z
ZZX00P1EEED0102ZZZX000000000000000050?ooo`X0dLfY1@3oool02@000000EEEE0:ZZZP1EEED0
ZZZZ0000001EEED0ZZZZ05EEE@030:ZZZP040000002ZZZX0ZZZZ05EEE@80ZZZZ00<0EEEE0000002Z
ZZX0101EEED30:ZZZP<0EEEE0P2ZZZX00`1EEED0000005EEE@030:ZZZP0705EEE@000000EEEE0000
002ZZZX0000005EEE@020:ZZZP0;05EEE@2ZZZX0ZZZZ05EEE@2ZZZX0EEEE0:ZZZP1EEED0000005EE
E@0000000P1EEED00`2ZZZX0oooo000000050?ooo`X0dLfY1@3oool010000000EEEE0:ZZZP3oool2
0000000305EEE@3oool0oooo00@0000000<0oooo05EEE@2ZZZX00`00000205EEE@030?ooo`2ZZZX0
oooo0080oooo1@000000101EEED000000000001EEED2000000<0oooo00<000000:ZZZP2ZZZX00P1E
EED01P2ZZZX000000000003oool0EEEE0?ooo`80000000/0EEEE0000003oool0000005EEE@000000
ZZZZ0?ooo`2ZZZX0EEEE000000050?ooo``0dLfY000;0=7=Z@H0oooo0P1EEED01@000000ZZZZ0?oo
o`3oool000000080ZZZZ00D000000:ZZZP000000000005EEE@0300000080EEEE00D0ZZZZ0?ooo`1E
EED0000005EEE@040000000305EEE@3oool0oooo0080oooo1@0000001`1EEED0000005EEE@000000
ZZZZ05EEE@3oool00P0000001P3oool0EEEE0000001EEED0ZZZZ00000080ZZZZ00L000000?ooo`3o
ool0ZZZZ0000001EEED0000000H0oooo2P3AcJT60?ooo`80ZZZZ00@0oooo0000003oool0EEEE0`3o
ool0102ZZZX000000?ooo`3oool20:ZZZP040?ooo`1EEED0ZZZZ0?ooo`80ZZZZ00H0oooo0000002Z
ZZX0000005EEE@0000080?ooo`060000002ZZZX000000:ZZZP000000oooo0P2ZZZX02@3oool0ZZZZ
05EEE@3oool000000:ZZZP3oool0ZZZZ000000030?ooo`80EEEE00<0oooo0:ZZZP3oool00P2ZZZX6
0?ooo`X0dLfY1`3oool0101EEED000000000002ZZZX2000000030?ooo`2ZZZX0000000D0ZZZZ103o
ool00`000000EEEE05EEE@020?ooo`060:ZZZP000000EEEE05EEE@000000EEEE0P3oool01`1EEED0
000005EEE@1EEED000000:ZZZP3oool00P1EEED00`2ZZZX000000?ooo`040?ooo`80ZZZZ00@00000
0:ZZZP2ZZZX0ZZZZ0P3oool01P000000ZZZZ000000000000EEEE0:ZZZPH0oooo2P3AcJT60?ooo`05
0:ZZZP1EEED0oooo05EEE@2ZZZX00P0000001@3oool0ZZZZ0:ZZZP1EEED000000080ZZZZ00L0EEEE
0:ZZZP1EEED0000005EEE@2ZZZX000000080EEEE1@0000000`1EEED0ZZZZ0:ZZZP030:ZZZPD00000
0`1EEED0102ZZZX0EEEE05EEE@1EEED40:ZZZP<0EEEE00T0ZZZZ0?ooo`3oool000000:ZZZP1EEED0
oooo05EEE@2ZZZX01P3oool:0=7=Z@H0oooo00H000000?ooo`3oool0000005EEE@2ZZZX200000004
0:ZZZP1EEED0000000000080EEEE00H0oooo000000000000oooo0:ZZZP0000020?ooo`050000001E
EED0EEEE0000003oool00P000000103oool000000000003oool2000000050?ooo`000000EEEE05EE
E@0000000P3oool00`000000ZZZZ0?ooo`02000000050?ooo`1EEED0EEEE0?ooo`0000000P2ZZZX0
10000000ZZZZ0:ZZZP1EEED30?ooo`030:ZZZP3oool0oooo00@0oooo303AcJT000/0dLfY1P3oool0
0`000000ZZZZ0?ooo`03000000030:ZZZP000000ZZZZ0080ZZZZ0P3oool205EEE@040000001EEED0
EEEE0?ooo`80EEEE00<0ZZZZ0?ooo`2ZZZX00P3oool20:ZZZPD0oooo0`2ZZZX00`1EEED0oooo0:ZZ
ZP020:ZZZP030000001EEED0oooo0080EEEE00D0000005EEE@1EEED0oooo000000030:ZZZP@00000
00<0EEEE0?ooo`2ZZZX01`3oool:0=7=Z@H0oooo00<000000?ooo`3oool00P000000102ZZZX00000
0000002ZZZX2000000<0oooo0P0000030:ZZZP040?ooo`2ZZZX0oooo00000080oooo0`1EEED60?oo
o`80EEEE00L0ZZZZ0?ooo`3oool000000?ooo`1EEED0oooo00<0ZZZZ0P0000030?ooo`80000000D0
ZZZZ0000002ZZZX0ZZZZ0000000:0?ooo`X0dLfY1P3oool2000000030:ZZZP000000ZZZZ0080oooo
0`2ZZZX00`000000EEEE05EEE@020?ooo`0605EEE@3oool0oooo05EEE@3oool0ZZZZ0P0000000`3o
ool000000:ZZZP02000000030:ZZZP000000oooo0080000000H0ZZZZ000000000000ZZZZ0000003o
ool3000000040?ooo`1EEED0oooo0?ooo`80EEEE00@0oooo05EEE@3oool000000`2ZZZX20?ooo`<0
ZZZZ00<000000?ooo`3oool01@3oool:0=7=Z@H0oooo00D000000?ooo`2ZZZX0EEEE0:ZZZP020?oo
o`80ZZZZ0`1EEED01`2ZZZX0EEEE0:ZZZP2ZZZX000000:ZZZP1EEED00P2ZZZX00`000000EEEE05EE
E@0405EEE@D0ZZZZ1P1EEED20000000305EEE@2ZZZX0EEEE0080000000H0ZZZZ05EEE@1EEED0ZZZZ
0000001EEED30:ZZZP80oooo0`2ZZZX80?ooo`X0dLfY1P3oool01P000000EEEE05EEE@1EEED0oooo
05EEE@80oooo00H0ZZZZ0?ooo`1EEED0EEEE0?ooo`1EEED2000000<0oooo00@0000005EEE@000000
oooo0P1EEED2000000060:ZZZP000000EEEE0?ooo`000000EEEE0P2ZZZX010000000oooo05EEE@1E
EED4000000040?ooo`1EEED0oooo00000080EEEE00X0oooo0000001EEED0EEEE0:ZZZP3oool0ZZZZ
05EEE@3oool000000P1EEED70?ooo``0dLfY000;0=7=Z@P0oooo00L000000:ZZZP000000ZZZZ05EE
E@3oool0EEEE0080oooo0`00000305EEE@040:ZZZP000000EEEE05EEE@<0ZZZZ00L0EEEE0000002Z
ZZX000000?ooo`000000ZZZZ0080000000<0oooo0000002ZZZX00P1EEED01P2ZZZX0EEEE0:ZZZP2Z
ZZX0EEEE000000<0EEEE100000002@3oool0ZZZZ05EEE@3oool0EEEE0:ZZZP000000ZZZZ00000008
0?ooo`X0dLfY203oool00`000000ZZZZ0?ooo`020?ooo`030:ZZZP3oool0ZZZZ0080ZZZZ00<00000
0:ZZZP3oool00P3oool01@2ZZZX000000000003oool0000000<0ZZZZ0P0000000`1EEED0oooo0?oo
o`040?ooo`0305EEE@000000ZZZZ0080ZZZZ00<0oooo0000003oool00P0000030?ooo`040000002Z
ZZX000000?ooo`80ZZZZ00<0oooo0:ZZZP3oool00`3oool00`000000oooo0?ooo`060?ooo`X0dLfY
203oool010000000ZZZZ0000003oool20:ZZZP0305EEE@2ZZZX0ZZZZ008000000P2ZZZX4000000<0
ZZZZ00D000000?ooo`3oool0oooo0:ZZZP0205EEE@070000003oool0ZZZZ0000002ZZZX0EEEE0:ZZ
ZP030?ooo`@0ZZZZ100000020:ZZZP050000002ZZZX0ZZZZ0:ZZZP1EEED00P2ZZZX0103oool00000
0000000000080?ooo`X0dLfY203oool00`000000EEEE0:ZZZP030:ZZZP0305EEE@000000EEEE00<0
ZZZZ0P1EEED020000000EEEE05EEE@2ZZZX0EEEE0000001EEED000000P2ZZZX00`000000EEEE05EE
E@0605EEE@030000001EEED0ZZZZ00<0000000<0EEEE0:ZZZP1EEED00P0000000`1EEED0ZZZZ0:ZZ
ZP020:ZZZP<0EEEE00H0ZZZZ0?ooo`2ZZZX0ZZZZ0?ooo`0000080?ooo`X0dLfY203oool00`000000
EEEE0:ZZZP040?ooo`030:ZZZP1EEED000000080oooo0P2ZZZX00`3oool000000?ooo`0200000004
0?ooo`00000000000?ooo`80000000<0EEEE0?ooo`3oool00P0000020?ooo`0505EEE@0000000000
0?ooo`0000000P3oool01@1EEED000000?ooo`2ZZZX0oooo0080ZZZZ0P3oool205EEE@D0oooo00<0
ZZZZ05EEE@000000203oool<0=7=Z@002`3AcJT90?ooo`0305EEE@000000EEEE00<0EEEE0P000000
1P3oool000000?ooo`000000ZZZZ0?ooo`<0ZZZZ00D0EEEE0?ooo`2ZZZX0ZZZZ000000020:ZZZP@0
000000/0ZZZZ00000000000000000:ZZZP3oool000000:ZZZP000000oooo05EEE@020:ZZZP030000
003oool0ZZZZ0080oooo00@000000?ooo`000000oooo0P1EEED0103oool0EEEE0000000000090?oo
o`X0dLfY2@3oool20:ZZZP050?ooo`000000oooo0?ooo`0000000P3oool2000000070?ooo`2ZZZX0
ZZZZ0000003oool000000:ZZZP020?ooo`040000003oool00000000000H0oooo00<0EEEE0?ooo`00
00000P3oool00`000000oooo0?ooo`0200000080oooo0P2ZZZX3000000D0oooo00@0ZZZZ0?ooo`2Z
ZZX0ZZZZ2@3oool:0=7=Z@X0oooo00D0EEEE0000003oool000000:ZZZP020?ooo`80ZZZZ00D00000
0:ZZZP000000ZZZZ000000030:ZZZP0705EEE@2ZZZX0oooo0:ZZZP3oool0ZZZZ0000000205EEE@03
0?ooo`2ZZZX0EEEE008000000`2ZZZX20?ooo`0305EEE@2ZZZX0ZZZZ00<0ZZZZ00d000000?ooo`00
0000ZZZZ0000003oool000000:ZZZP000000ZZZZ0000001EEED0ZZZZ00T0oooo2P3AcJT90?ooo`03
0:ZZZP1EEED0oooo00@0ZZZZ1@00000305EEE@8000000`1EEED00`000000ZZZZ05EEE@0505EEE@03
0000001EEED000000080EEEE0P2ZZZX00`000000EEEE05EEE@03000000<0EEEE1@0000001`1EEED0
ZZZZ0:ZZZP2ZZZX0oooo05EEE@2ZZZX02@3oool:0=7=Z@T0oooo00<000000?ooo`3oool0103oool0
1@000000oooo0?ooo`3oool000000080oooo0P0000001`2ZZZX0EEEE05EEE@1EEED0ZZZZ0000003o
ool00P0000000`1EEED000000?ooo`07000000030:ZZZP000000EEEE0080ZZZZ00<000000?ooo`3o
ool0103oool00`2ZZZX000000?ooo`050?ooo`030:ZZZP3oool0oooo00L0oooo303AcJT000/0dLfY
2P3oool00`000000EEEE05EEE@02000000030?ooo`000000ZZZZ0080oooo00@000000?ooo`3oool0
ZZZZ0P1EEED300000080ZZZZ00@0oooo0:ZZZP3oool0EEEE0P3oool0102ZZZX0oooo05EEE@3oool5
0:ZZZP8000000`1EEED20?ooo`040:ZZZP3oool0oooo0:ZZZP@000000P1EEED00`000000oooo0?oo
o`080?ooo`X0dLfY2P3oool20:ZZZP8000000P3oool0102ZZZX0EEEE0?ooo`2ZZZX20?ooo`040000
003oool0oooo0?ooo`80ZZZZ00D0oooo0:ZZZP2ZZZX0ZZZZ0?ooo`02000000030?ooo`0000000000
0080oooo00<000000?ooo`2ZZZX00P2ZZZX00`000000ZZZZ05EEE@030?ooo`040000003oool00000
0:ZZZP80oooo00D0ZZZZ0?ooo`3oool000000?ooo`020:ZZZPX0oooo2P3AcJT:0?ooo`040:ZZZP3o
ool0EEEE00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`80ZZZZ0P3oool01@000000
oooo0?ooo`3oool0000000<0ZZZZ00@000000?ooo`2ZZZX000000`2ZZZX01@1EEED0oooo0?ooo`1E
EED000000080oooo0P2ZZZX50?ooo`080:ZZZP00000000000?ooo`000000EEEE0?ooo`2ZZZX:0?oo
o`X0dLfY2P3oool50:ZZZP@0000000<0EEEE0000001EEED00P1EEED00`000000EEEE05EEE@0205EE
E@030000001EEED0ZZZZ0080ZZZZ00D0EEEE0000002ZZZX0EEEE000000030:ZZZP80EEEE00H00000
05EEE@1EEED0000005EEE@00000305EEE@050000001EEED0000005EEE@0000001P2ZZZX:0?ooo`X0
dLfY2P3oool01P2ZZZX000000000002ZZZX0oooo0:ZZZP<0000000<0EEEE0000000000000P3oool0
1`000000oooo0000003oool0EEEE0:ZZZP3oool00`2ZZZX20?ooo`80000000<0oooo0000002ZZZX0
0P2ZZZX00`3oool0ZZZZ0:ZZZP030?ooo`80000000L0oooo000000000000EEEE0000001EEED00000
0080oooo00@0ZZZZ0?ooo`000000ZZZZ2P3oool<0=7=Z@002`3AcJT;0?ooo`040000003oool0oooo
00000080oooo0`00000305EEE@030?ooo`000000ZZZZ0080ZZZZ0P0000002`1EEED0oooo0000001E
EED0ZZZZ05EEE@3oool0000005EEE@2ZZZX0EEEE0080000000L0EEEE0000002ZZZX0ZZZZ0?ooo`2Z
ZZX0000000<0EEEE0`0000001`1EEED0oooo0?ooo`000000oooo0:ZZZP0000002`3oool:0=7=Z@/0
oooo00<000000:ZZZP3oool00P3oool0101EEED0ZZZZ0000003oool20:ZZZP060?ooo`1EEED0oooo
05EEE@000000oooo1@2ZZZX20?ooo`040:ZZZP1EEED000000:ZZZP80oooo102ZZZX30?ooo`0505EE
E@3oool0oooo0?ooo`2ZZZX00P3oool00`000000ZZZZ05EEE@040?ooo`030000003oool0oooo00T0
oooo2P3AcJT;0?ooo`040000002ZZZX000000:ZZZP80EEEE00D0oooo0:ZZZP2ZZZX0ZZZZ0?ooo`06
0:ZZZP030000003oool0000000D0ZZZZ00<0oooo0000002ZZZX00`2ZZZX2000000040?ooo`000000
ZZZZ0?ooo`@0ZZZZ0P3oool30:ZZZP80EEEE00@0ZZZZ00000000000000002`3oool:0=7=Z@/0oooo
00D0000005EEE@2ZZZX0EEEE0:ZZZP02000000030:ZZZP1EEED0000000<0EEEE00L000000:ZZZP1E
EED0000005EEE@000000ZZZZ00@000000P2ZZZX00`1EEED0ZZZZ00000003000000030:ZZZP000000
EEEE0080000000<0ZZZZ0000000000000P1EEED01@2ZZZX0EEEE0:ZZZP1EEED000000080EEEE00<0
ZZZZ0?ooo`0000002`3oool:0=7=Z@/0oooo00@0000005EEE@2ZZZX0oooo0P2ZZZX0103oool00000
0000003oool2000000040:ZZZP3oool0oooo0?ooo`80ZZZZ00<0EEEE0?ooo`0000000P3oool01P00
0000EEEE0?ooo`000000EEEE000000@0oooo00<0EEEE0:ZZZP2ZZZX00`3oool00`2ZZZX000000000
000400000080ZZZZ00@0oooo0:ZZZP1EEED000002`3oool<0=7=Z@002`3AcJT<0?ooo`0305EEE@2Z
ZZX00000008000000`2ZZZX205EEE@030?ooo`1EEED0EEEE0080000000@0EEEE0000002ZZZX00000
0P3oool00`000000ZZZZ000000020?ooo`030000002ZZZX000000080oooo00H000000:ZZZP000000
EEEE0?ooo`00000205EEE@030?ooo`1EEED0oooo0080ZZZZ00H0oooo00000000000000000:ZZZP00
000<0?ooo`X0dLfY303oool20:ZZZP040?ooo`000000oooo0:ZZZP<0oooo00D000000?ooo`000000
ZZZZ000000030?ooo`030000003oool0000000<0oooo00@0EEEE0000002ZZZX0EEEE1@3oool01@00
0000oooo0?ooo`2ZZZX000000080ZZZZ00<0oooo0000003oool00P3oool0101EEED0oooo0:ZZZP3o
ool20:ZZZP`0oooo2P3AcJT=0?ooo`0705EEE@00000000000:ZZZP3oool000000?ooo`020:ZZZP03
0?ooo`2ZZZX0oooo0080EEEE1@3oool0101EEED0ZZZZ0000002ZZZX20?ooo`050:ZZZP3oool0ZZZZ
05EEE@2ZZZX00P3oool01`2ZZZX0oooo05EEE@1EEED0oooo0000003oool00P2ZZZX0103oool00000
0000002ZZZX20000000305EEE@2ZZZX0oooo00/0oooo2P3AcJT<0?ooo`090:ZZZP1EEED0oooo05EE
E@2ZZZX0oooo0000003oool0EEEE0080000000L0EEEE0:ZZZP000000EEEE0:ZZZP000000ZZZZ00H0
EEEE0P2ZZZX605EEE@050:ZZZP000000ZZZZ0:ZZZP0000000P2ZZZX2000000090:ZZZP3oool00000
0000002ZZZX0EEEE0?ooo`1EEED0ZZZZ00`0oooo2P3AcJT<0?ooo`050000003oool0oooo0000003o
ool00P2ZZZX01@000000ZZZZ0?ooo`3oool0EEEE00<0oooo00<0EEEE0?ooo`1EEED00P1EEED20?oo
o`060000002ZZZX0oooo0?ooo`2ZZZX0EEEE0P3oool01@000000EEEE05EEE@2ZZZX0EEEE00<0oooo
00H0ZZZZ0?ooo`3oool0ZZZZ0000002ZZZX50?ooo`030:ZZZP3oool0oooo00X0oooo303AcJT000/0
dLfY3@3oool04@000000EEEE0000003oool0EEEE0000002ZZZX0EEEE0000002ZZZX000000?ooo`00
0000ZZZZ0000001EEED0ZZZZ0080000000@0ZZZZ0000001EEED000000P1EEED3000000030:ZZZP00
000000000080ZZZZ0`000000303oool0EEEE0:ZZZP000000oooo0:ZZZP000000EEEE0?ooo`000000
EEEE000000d0oooo2P3AcJT=0?ooo`80ZZZZ0P000000103oool000000?ooo`1EEED30?ooo`050:ZZ
ZP3oool0oooo0?ooo`1EEED00`3oool0102ZZZX000000000002ZZZX20?ooo`80ZZZZ00<000000:ZZ
ZP0000001P3oool02P2ZZZX0oooo0?ooo`3oool0ZZZZ0?ooo`000000oooo0000003oool20:ZZZPd0
oooo2P3AcJT=0?ooo`050:ZZZP3oool0EEEE0:ZZZP3oool01@2ZZZX0103oool0ZZZZ0?ooo`2ZZZX2
0?ooo`040000003oool0ZZZZ00000080ZZZZ0P3oool010000000oooo0000002ZZZX2000000030?oo
o`000000oooo00<0oooo2@2ZZZX00`1EEED0oooo0:ZZZP0=0?ooo`X0dLfY3@3oool30:ZZZP0305EE
E@3oool0oooo00<0EEEE00@000000:ZZZP2ZZZX0EEEE0P2ZZZX205EEE@<0ZZZZ00<0EEEE0:ZZZP2Z
ZZX00`2ZZZX205EEE@<0ZZZZ00D0EEEE0000002ZZZX0ZZZZ05EEE@020:ZZZP040000001EEED0ZZZZ
05EEE@80oooo00@0EEEE0:ZZZP2ZZZX0ZZZZ3@3oool:0=7=Z@d0oooo00D0ZZZZ000000000000ZZZZ
000000020:ZZZP@0oooo00<0ZZZZ05EEE@2ZZZX00P3oool205EEE@050?ooo`2ZZZX0EEEE0?ooo`1E
EED00P3oool01@1EEED0000005EEE@2ZZZX0oooo0080EEEE0P3oool205EEE@030:ZZZP3oool0oooo
0080oooo0P2ZZZX01@000000ZZZZ0?ooo`000000ZZZZ00d0oooo303AcJT000/0dLfY3P3oool30000
00030:ZZZP000000000000<0ZZZZ0`3oool00`2ZZZX0EEEE000000020:ZZZP060?ooo`1EEED00000
05EEE@3oool0ZZZZ0P3oool00`1EEED0000005EEE@030:ZZZP030?ooo`1EEED0EEEE0080oooo00@0
00000:ZZZP2ZZZX0EEEE0P000000103oool000000:ZZZP00000>0?ooo`X0dLfY3P3oool00`000000
ZZZZ0?ooo`020?ooo`80ZZZZ0`0000030?ooo`0405EEE@3oool000000:ZZZP80oooo0P0000040?oo
o`8000000P3oool0102ZZZX0000005EEE@1EEED30?ooo`030:ZZZP00000000000080ZZZZ103oool0
0`000000oooo0?ooo`0<0?ooo`X0dLfY3P3oool00`000000ZZZZ000000070:ZZZP030?ooo`000000
oooo00<0oooo00D0ZZZZ0000003oool0EEEE0:ZZZP020?ooo`050:ZZZP3oool0EEEE05EEE@3oool0
0P2ZZZX30?ooo`80000000D0oooo0:ZZZP2ZZZX0ZZZZ05EEE@020:ZZZP040?ooo`00000000000000
00h0oooo2P3AcJT>0?ooo`040000001EEED0ZZZZ0?ooo`80ZZZZ00<0EEEE0000001EEED00P1EEED2
0:ZZZP030000001EEED0ZZZZ00D0ZZZZ00<0EEEE0:ZZZP1EEED00P1EEED60:ZZZP080000002ZZZX0
ZZZZ05EEE@2ZZZX0EEEE0000001EEED40:ZZZP030?ooo`000000oooo00d0oooo2P3AcJT>0?ooo`06
0000001EEED0ZZZZ0?ooo`2ZZZX0EEEE1@3oool010000000oooo05EEE@3oool205EEE@030?ooo`1E
EED0ZZZZ0080000000<0ZZZZ0000000000000P2ZZZX0201EEED0oooo05EEE@1EEED0oooo05EEE@2Z
ZZX000001@3oool01P1EEED0ZZZZ0?ooo`2ZZZX0EEEE000000h0oooo303AcJT000/0dLfY3`3oool2
05EEE@80ZZZZ00@0oooo0000002ZZZX0ZZZZ0P0000001`3oool0ZZZZ0:ZZZP000000EEEE0000001E
EED00P2ZZZX0101EEED0ZZZZ05EEE@0000040:ZZZP8000000P1EEED00`2ZZZX000000?ooo`020000
00<0ZZZZ00D0oooo0:ZZZP000000EEEE0000000?0?ooo`X0dLfY3`3oool30:ZZZP040000003oool0
00000?ooo`80000000@0oooo0:ZZZP000000ZZZZ0P0000000`3oool0EEEE0?ooo`060?ooo`030:ZZ
ZP3oool0oooo0080oooo00H000000:ZZZP2ZZZX000000:ZZZP3oool2000000<0oooo00@000000?oo
o`2ZZZX0ZZZZ3`3oool:0=7=ZA00oooo00<0EEEE0:ZZZP3oool00P0000020?ooo`050:ZZZP3oool0
ZZZZ0?ooo`1EEED00P3oool00`1EEED0oooo0000000200000080oooo00<000000?ooo`2ZZZX00P00
000205EEE@80oooo00D0EEEE0?ooo`2ZZZX0oooo000000020?ooo`060:ZZZP000000oooo0000001E
EED0ZZZZ3`3oool:0=7=Z@l0oooo00<0ZZZZ05EEE@2ZZZX00P2ZZZX0101EEED0ZZZZ000000000004
05EEE@H0ZZZZ0P1EEED20000000305EEE@2ZZZX0ZZZZ00@0ZZZZ0P1EEED00`2ZZZX0EEEE05EEE@02
000000@0ZZZZ00<0oooo05EEE@2ZZZX03`3oool:0=7=Z@l0oooo00@000000?ooo`3oool0oooo0`00
00001P2ZZZX0000005EEE@000000oooo05EEE@<000000P1EEED02@3oool0EEEE000000000000oooo
0000002ZZZX0oooo05EEE@0300000080EEEE00P0oooo0000001EEED000000:ZZZP000000ZZZZ0000
00<0oooo00<0ZZZZ0?ooo`3oool03@3oool<0=7=Z@002`3AcJT@0?ooo`030000002ZZZX0ZZZZ0080
ZZZZ00<000000?ooo`1EEED00`1EEED01`000000ZZZZ05EEE@000000EEEE0?ooo`1EEED00P2ZZZX0
0`3oool000000:ZZZP0205EEE@040?ooo`000000000005EEE@<000000`1EEED00`3oool000000?oo
o`020:ZZZP0305EEE@000000oooo00l0oooo2P3AcJT@0?ooo`040:ZZZP3oool00000000000<0oooo
0P2ZZZX40?ooo`040:ZZZP3oool0oooo00000080oooo00H000000?ooo`3oool000000:ZZZP3oool2
000000080?ooo`2ZZZX0oooo0?ooo`2ZZZX0oooo0:ZZZP1EEED30?ooo`8000000P2ZZZX@0?ooo`X0
dLfY403oool00`2ZZZX0EEEE05EEE@02000000030?ooo`000000oooo0080oooo00<0ZZZZ0000002Z
ZZX00P3oool205EEE@040000002ZZZX0ZZZZ0?ooo`<0ZZZZ00<0000005EEE@2ZZZX00P3oool00`2Z
ZZX000000:ZZZP020?ooo`080:ZZZP000000oooo0?ooo`000000EEEE0?ooo`2ZZZX@0?ooo`X0dLfY
403oool50:ZZZP@0000000<0EEEE0000001EEED02@1EEED00`000000EEEE05EEE@0705EEE@040:ZZ
ZP1EEED0000005EEE@8000001@2ZZZX@0?ooo`X0dLfY403oool01@2ZZZX0oooo0000002ZZZX0EEEE
0080oooo102ZZZX600000080ZZZZ00H0EEEE0?ooo`1EEED0EEEE0?ooo`2ZZZX6000000040?ooo`2Z
ZZX0ZZZZ000000<0oooo00@0ZZZZ000000000000ZZZZ403oool<0=7=Z@002`3AcJTA0?ooo`80ZZZZ
00@0000005EEE@1EEED000000P3oool20:ZZZP040?ooo`2ZZZX000000?ooo`@0EEEE00D000000?oo
o`3oool000000?ooo`0205EEE@80oooo00d000000:ZZZP3oool0oooo0:ZZZP3oool0ZZZZ0000001E
EED0ZZZZ0000002ZZZX000000140oooo2P3AcJTB0?ooo`030:ZZZP3oool0oooo0080EEEE00<00000
0?ooo`3oool01@2ZZZX20?ooo`80ZZZZ103oool20:ZZZP80oooo0P2ZZZX00`3oool0ZZZZ05EEE@03
0?ooo`80EEEE0P3oool00`2ZZZX000000?ooo`0@0?ooo`X0dLfY4@3oool00`000000ZZZZ00000003
05EEE@050?ooo`2ZZZX0ZZZZ0000003oool00P2ZZZX00`3oool00000000000020:ZZZP0405EEE@3o
ool0ZZZZ05EEE@80ZZZZ00D000000:ZZZP3oool0ZZZZ05EEE@020?ooo`<0ZZZZ0P1EEED0102ZZZX0
00000:ZZZP00000A0?ooo`X0dLfY4P3oool0101EEED0ZZZZ05EEE@2ZZZX2000000060:ZZZP1EEED0
EEEE0000001EEED000000P1EEED02@000000EEEE05EEE@1EEED0ZZZZ0000001EEED0000005EEE@02
0000000>05EEE@00000000000000002ZZZX0EEEE0:ZZZP1EEED000000:ZZZP1EEED0ZZZZ05EEE@00
000A0?ooo`X0dLfY4@3oool205EEE@80ZZZZ0P0000001P3oool0ZZZZ05EEE@3oool000000:ZZZP<0
EEEE00L000000?ooo`3oool000000?ooo`2ZZZX000000080oooo00<000000:ZZZP1EEED00P1EEED0
1@000000oooo05EEE@2ZZZX0EEEE0080000000@0oooo0:ZZZP1EEED000004@3oool<0=7=Z@002`3A
cJTB0?ooo`040000002ZZZX0oooo000000<0ZZZZ00@0oooo05EEE@2ZZZX0ZZZZ0P3oool01P000000
oooo0000003oool000000?ooo`80000000@0ZZZZ0000003oool0ZZZZ0P3oool20:ZZZP0505EEE@3o
ool0ZZZZ0?ooo`2ZZZX00P0000000`2ZZZX000000?ooo`0A0?ooo`X0dLfY4P3oool00`000000oooo
0?ooo`03000000030:ZZZP000000oooo00<0oooo00@0ZZZZ0?ooo`2ZZZX0ZZZZ1P3oool40:ZZZP<0
oooo00<0ZZZZ0000002ZZZX00`0000020?ooo`030000003oool0oooo0100oooo2P3AcJTB0?ooo`80
000000<0ZZZZ0000002ZZZX00P3oool30:ZZZP80000000D0oooo0000002ZZZX0ZZZZ000000020?oo
o`030:ZZZP3oool0EEEE0080ZZZZ0P3oool2000000<0ZZZZ0P3oool00`2ZZZX000000:ZZZP020000
0180oooo2P3AcJTB0?ooo`050000003oool0ZZZZ05EEE@2ZZZX00P3oool20:ZZZP80EEEE0P000003
05EEE@060000001EEED0ZZZZ0:ZZZP1EEED000000P1EEED00`2ZZZX000000000000205EEE@80ZZZZ
0P3oool01@2ZZZX0EEEE0:ZZZP3oool000000180oooo2P3AcJTB0?ooo`090000001EEED0000005EE
E@3oool0ZZZZ0?ooo`2ZZZX0oooo008000000P3oool0102ZZZX000000?ooo`2ZZZX40?ooo`040000
003oool0000000000080oooo00L0ZZZZ000000000000ZZZZ0?ooo`1EEED0oooo00<0EEEE00<00000
0?ooo`3oool0403oool<0=7=Z@002`3AcJTC0?ooo`030000001EEED0EEEE0080000000<0EEEE0000
003oool01000000305EEE@040?ooo`000000oooo0?ooo`8000000P1EEED30000000505EEE@000000
ZZZZ0000001EEED00P00000205EEE@030000003oool0oooo0140oooo2P3AcJTC0?ooo`030:ZZZP3o
ool0000000@000000P3oool01@1EEED0oooo05EEE@3oool0000000P0oooo00<000000:ZZZP1EEED0
103oool2000000030?ooo`00000000000080ZZZZ4`3oool:0=7=ZA<0oooo00D0ZZZZ05EEE@1EEED0
ZZZZ0?ooo`040:ZZZP070000002ZZZX0ZZZZ0:ZZZP3oool0EEEE000000020?ooo`040000003oool0
EEEE05EEE@80oooo2@2ZZZX00`1EEED0oooo0:ZZZP0C0?ooo`X0dLfY4`3oool30:ZZZP0305EEE@3o
ool0oooo00H0EEEE0P2ZZZX0101EEED0000005EEE@2ZZZX205EEE@030:ZZZP1EEED0ZZZZ00<0EEEE
00@0000005EEE@2ZZZX0EEEE0P3oool0101EEED0ZZZZ0:ZZZP2ZZZXC0?ooo`X0dLfY4`3oool0102Z
ZZX0oooo0000002ZZZX30?ooo`80EEEE0`3oool00`2ZZZX0EEEE05EEE@050?ooo`030000001EEED0
EEEE00<0oooo00<0ZZZZ05EEE@0000000P3oool01@000000ZZZZ000000000000ZZZZ01<0oooo303A
cJT000/0dLfY503oool00`2ZZZX0oooo0?ooo`020?ooo`040:ZZZP000000EEEE0?ooo`80ZZZZ0P3o
ool00`2ZZZX000000?ooo`030?ooo`030000002ZZZX0oooo00<0ZZZZ0P1EEED20:ZZZP050?ooo`00
0000oooo0?ooo`000000503oool:0=7=ZAD0oooo00@0ZZZZ0?ooo`3oool0ZZZZ0P3oool00`1EEED0
oooo000000020:ZZZPX0oooo0P2ZZZX00`000000EEEE05EEE@020?ooo`050:ZZZP3oool0oooo0:ZZ
ZP000000503oool:0=7=ZA@0oooo00<000000:ZZZP0000001P2ZZZX00`000000oooo0?ooo`020000
0080ZZZZ0P3oool0102ZZZX000000000000000020?ooo`040000002ZZZX0ZZZZ05EEE@80ZZZZ00@0
oooo0000002ZZZX00000503oool:0=7=ZAD0oooo00<0EEEE0:ZZZP3oool00P2ZZZX01@1EEED00000
0:ZZZP2ZZZX0EEEE00<0ZZZZ0P1EEED200000080EEEE0`2ZZZX01@1EEED0ZZZZ05EEE@000000EEEE
00@0ZZZZ00<0EEEE0000003oool04`3oool:0=7=ZA@0oooo0P1EEED01P2ZZZX0oooo0?ooo`3oool0
ZZZZ000000@0oooo00<000000:ZZZP3oool01@3oool00`2ZZZX000000?ooo`030?ooo`030000003o
ool0oooo0080oooo00<0ZZZZ05EEE@000000503oool<0=7=Z@002`3AcJTE0?ooo`040000002ZZZX0
ZZZZ0?ooo`80ZZZZ00<000000?ooo`3oool00P2ZZZX205EEE@060000002ZZZX000000000002ZZZX0
00000P1EEED20:ZZZP060?ooo`1EEED0000005EEE@2ZZZX0oooo0P2ZZZX00`000000oooo0?ooo`0C
0?ooo`X0dLfY5@3oool010000000oooo0?ooo`0000020?ooo`<0000000<0ZZZZ0?ooo`3oool02P3o
ool0102ZZZX000000000000000020?ooo`040000003oool0oooo000001D0oooo2P3AcJTE0?ooo`80
000000P0ZZZZ05EEE@000000ZZZZ0?ooo`2ZZZX000000?ooo`<0ZZZZ00H0oooo0:ZZZP3oool00000
0:ZZZP0000030:ZZZP030?ooo`000000ZZZZ0080oooo00<0000005EEE@2ZZZX00P00000E0?ooo`X0
dLfY5@3oool00`000000oooo0:ZZZP030:ZZZP@0EEEE00@0ZZZZ05EEE@1EEED000000P1EEED00`00
0000EEEE0:ZZZP0705EEE@@0ZZZZ00<0oooo0000003oool0503oool:0=7=ZAD0oooo00<0000005EE
E@0000000P1EEED00`000000EEEE000000020:ZZZP030?ooo`000000EEEE0080EEEE0P3oool00`1E
EED0000005EEE@0200000080ZZZZ00<0oooo05EEE@000000101EEED00`000000oooo0?ooo`0C0?oo
o``0dLfY000;0=7=ZAH0oooo0`0000000`3oool0EEEE0:ZZZP04000000030?ooo`2ZZZX0000000@0
ZZZZ00@000000:ZZZP3oool0EEEE0P0000001`3oool0ZZZZ05EEE@3oool0000005EEE@0000005P3o
ool:0=7=ZAH0oooo00<0ZZZZ0?ooo`0000001@0000040?ooo`0305EEE@3oool0oooo00L0oooo00@0
00000?ooo`000000ZZZZ0P0000020:ZZZQH0oooo2P3AcJTF0?ooo`030:ZZZP1EEED0EEEE00800000
00T0oooo0:ZZZP3oool0oooo0000002ZZZX0oooo0000002ZZZX00P3oool0102ZZZX0EEEE0?ooo`2Z
ZZX30?ooo`070000003oool0oooo0000001EEED0oooo0:ZZZP0F0?ooo`X0dLfY5P3oool50:ZZZP05
0000001EEED0EEEE0000001EEED00P2ZZZX205EEE@040:ZZZP000000EEEE05EEE@80ZZZZ00<0EEEE
0000001EEED00P0000050:ZZZQH0oooo2P3AcJTF0?ooo`070:ZZZP3oool000000:ZZZP3oool0ZZZZ
000000020?ooo`060000002ZZZX0EEEE05EEE@2ZZZX0oooo0`2ZZZX00`1EEED0ZZZZ000000020?oo
o`040000002ZZZX0oooo0:ZZZP80000000<0ZZZZ0?ooo`3oool0503oool<0=7=Z@002`3AcJTG0?oo
o`030000001EEED0EEEE0080ZZZZ00<000000?ooo`0000000`2ZZZX01P000000oooo0000002ZZZX0
oooo05EEE@80ZZZZ0P000000103oool0ZZZZ0:ZZZP00000205EEEAP0oooo2P3AcJTG0?ooo`@0ZZZZ
0P3oool00`000000ZZZZ000000020:ZZZP0305EEE@3oool0oooo0080oooo00H000000:ZZZP2ZZZX0
00000:ZZZP0000030?ooo`80ZZZZ603oool:0=7=ZAL0oooo00<0ZZZZ0?ooo`1EEED00`0000000`3o
ool000000?ooo`030?ooo`050000003oool0oooo0000002ZZZX00`3oool00`000000oooo0:ZZZP02
0000000305EEE@3oool0oooo01L0oooo2P3AcJTG0?ooo`80ZZZZ0`1EEED010000000oooo0000002Z
ZZX200000080ZZZZ0P1EEED20:ZZZP80000000P0ZZZZ0000003oool0ZZZZ05EEE@3oool0EEEE0:ZZ
ZQP0oooo2P3AcJTG0?ooo`070:ZZZP000000oooo0?ooo`000000oooo0:ZZZP0200000080oooo00@0
ZZZZ0000003oool0oooo0P0000030?ooo`040000002ZZZX0oooo00000080oooo00<000000?ooo`3o
ool05P3oool<0=7=Z@002`3AcJTH0?ooo`040000002ZZZX0EEEE000000@0EEEE00@000000?ooo`1E
EED000000P2ZZZX00`000000EEEE0?ooo`0200000080EEEE0P0000000`3oool0ZZZZ0000000H0?oo
o`X0dLfY603oool00`000000oooo0?ooo`02000000030?ooo`00000000000080000000<0oooo05EE
E@3oool00P1EEED3000000050?ooo`000000oooo0:ZZZP0000000P3oool00`000000oooo0?ooo`0F
0?ooo`X0dLfY603oool2000000030:ZZZP000000oooo0080oooo00@0ZZZZ0?ooo`2ZZZX0ZZZZ103o
ool20:ZZZP070?ooo`2ZZZX0oooo0?ooo`2ZZZX000000:ZZZP02000001P0oooo2P3AcJTH0?ooo`04
0000003oool0ZZZZ05EEE@<0oooo0`1EEED00`2ZZZX0EEEE0000000505EEE@080:ZZZP3oool0oooo
0:ZZZP1EEED0ZZZZ0?ooo`00000H0?ooo`X0dLfY603oool010000000EEEE0000001EEED20?ooo`05
0000001EEED0EEEE0000002ZZZX0103oool01@1EEED0000005EEE@1EEED000000080oooo0`1EEED0
0`000000oooo0?ooo`0F0?ooo``0dLfY000;0=7=ZAT0oooo00<000000:ZZZP2ZZZX00P3oool0102Z
ZZX0EEEE05EEE@0000020?ooo`0905EEE@000000oooo0:ZZZP000000EEEE0?ooo`2ZZZX0oooo0080
ZZZZ00<0EEEE0000003oool0603oool:0=7=ZAT0oooo00D0ZZZZ0?ooo`00000000000?ooo`020:ZZ
ZP<0oooo00D000000?ooo`1EEED000000:ZZZP030?ooo`040:ZZZP3oool0000000000080ZZZZ6@3o
ool:0=7=ZAT0oooo00D0ZZZZ05EEE@1EEED0ZZZZ0?ooo`030:ZZZP80oooo00H0ZZZZ0?ooo`2ZZZX0
ZZZZ0000003oool30:ZZZP050?ooo`2ZZZX0EEEE0?ooo`2ZZZX06@3oool:0=7=ZAT0oooo0`2ZZZX3
0?ooo`030000001EEED0EEEE008000000P1EEED2000000<0EEEE0P3oool0101EEED0ZZZZ0:ZZZP2Z
ZZXI0?ooo`X0dLfY6@3oool00`2ZZZX0oooo00000002000000040:ZZZP1EEED0ZZZZ0:ZZZPD0oooo
00<000000:ZZZP2ZZZX00P2ZZZX01@000000ZZZZ000000000000ZZZZ01T0oooo303AcJT000/0dLfY
6P3oool01@000000EEEE05EEE@3oool0EEEE0080000000D0EEEE0:ZZZP2ZZZX0oooo000000020:ZZ
ZP0705EEE@000000ZZZZ05EEE@3oool0000005EEE@0K0?ooo`X0dLfY6P3oool20:ZZZP040?ooo`00
0000oooo00000080ZZZZ0P000000103oool0EEEE0000000000020:ZZZP80oooo00<000000:ZZZP2Z
ZZX06`3oool:0=7=ZAX0oooo00T0ZZZZ0?ooo`000000ZZZZ0?ooo`2ZZZX000000?ooo`2ZZZX00P3o
ool0102ZZZX0oooo0:ZZZP3oool2000000030?ooo`2ZZZX0EEEE01`0oooo2P3AcJTJ0?ooo`80ZZZZ
00P0oooo0:ZZZP2ZZZX0ZZZZ05EEE@000000EEEE00000080EEEE00@0000005EEE@000000EEEE0`2Z
ZZX00`1EEED0ZZZZ0?ooo`0J0?ooo`X0dLfY6P3oool00`2ZZZX000000?ooo`020?ooo`030:ZZZP00
0000oooo00L0oooo0P0000030?ooo`030000003oool0oooo01T0oooo303AcJT000/0dLfY6`3oool2
000000070?ooo`000000ZZZZ0:ZZZP3oool0EEEE000000020?ooo`80000000L0oooo0:ZZZP2ZZZX0
00000?ooo`2ZZZX0000001/0oooo2P3AcJTK0?ooo`040000003oool0oooo0:ZZZP80oooo0`000000
1P3oool0EEEE0000003oool000000?ooo`80ZZZZ0P3oool00`000000oooo0?ooo`0I0?ooo`X0dLfY
6`3oool020000000ZZZZ0:ZZZP1EEED0oooo0:ZZZP3oool000000P3oool020000000oooo0:ZZZP3o
ool0ZZZZ0000001EEED0ZZZZ0P00000K0?ooo`X0dLfY6`3oool00`000000ZZZZ0:ZZZP030:ZZZP<0
EEEE00D0000005EEE@1EEED0000005EEE@040:ZZZP030?ooo`000000oooo01X0oooo2P3AcJTK0?oo
o`050000001EEED0000005EEE@2ZZZX02P3oool205EEE@030000001EEED0000001/0oooo303AcJT0
00/0dLfY703oool01P000000ZZZZ0?ooo`000000oooo0:ZZZPD000000P2ZZZX30?ooo`030:ZZZP3o
ool0oooo01/0oooo2P3AcJTL0?ooo`050000003oool0ZZZZ0000002ZZZX00P000000103oool0ZZZZ
05EEE@3oool2000000030:ZZZP3oool0ZZZZ01h0oooo2P3AcJTL0?ooo`8000000P2ZZZX205EEE@80
ZZZZ00<0oooo0:ZZZP2ZZZX00`1EEED00`000000ZZZZ0000000M0?ooo`X0dLfY703oool00`000000
oooo05EEE@0205EEE@80ZZZZ0P0000001`1EEED0000005EEE@2ZZZX0EEEE0:ZZZP1EEED07P3oool:
0=7=ZA`0oooo00L0000005EEE@1EEED0oooo0:ZZZP000000EEEE0080000000@0EEEE000000000000
00000P2ZZZX205EEEAd0oooo303AcJT000/0dLfY7@3oool00`000000EEEE00000002000000030?oo
o`2ZZZX0oooo0080ZZZZ00H0EEEE000000000000ZZZZ05EEE@00000M0?ooo`X0dLfY7@3oool20:ZZ
ZP80oooo00<000000?ooo`0000000P2ZZZX3000000040?ooo`2ZZZX0ZZZZ0:ZZZQd0oooo2P3AcJTM
0?ooo`030:ZZZP3oool000000080000000D0ZZZZ0?ooo`3oool000000?ooo`030000000305EEE@3o
ool0ZZZZ01d0oooo2P3AcJTM0?ooo`80ZZZZ00D0oooo05EEE@1EEED0ZZZZ0000000205EEE@030000
002ZZZX0EEEE0080EEEE0P2ZZZXM0?ooo`X0dLfY7@3oool01@2ZZZX000000?ooo`3oool000000080
ZZZZ00D0oooo0000002ZZZX0EEEE000000020?ooo`030000002ZZZX0oooo01`0oooo303AcJT000/0
dLfY7P3oool02`000000ZZZZ0:ZZZP3oool0000005EEE@3oool0000005EEE@2ZZZX0oooo0080ZZZZ
00<000000?ooo`3oool0703oool:0=7=ZAh0oooo00<000000?ooo`3oool00P3oool4000000050:ZZ
ZP3oool0oooo0?ooo`0000007P3oool:0=7=ZAh0oooo00@000000:ZZZP2ZZZX000000P2ZZZX20?oo
o`80ZZZZ00@000000:ZZZP00000000007P3oool:0=7=ZAh0oooo00<000000:ZZZP2ZZZX00`1EEED0
20000000EEEE05EEE@2ZZZX0EEEE0:ZZZP3oool000007P3oool:0=7=ZAh0oooo00<0000005EEE@00
00000P1EEED02@2ZZZX0oooo0?ooo`2ZZZX0oooo05EEE@000000EEEE0000000N0?ooo``0dLfY000;
0=7=ZAl0oooo00@000000:ZZZP000000ZZZZ103oool2000000030:ZZZP3oool0oooo01h0oooo2P3A
cJTO0?ooo`050000003oool0ZZZZ0?ooo`2ZZZX00P0000000`2ZZZX0EEEE0:ZZZP0Q0?ooo`X0dLfY
7`3oool2000000090:ZZZP3oool0ZZZZ0?ooo`000000ZZZZ0000002ZZZX000000200oooo2P3AcJTO
0?ooo`040000003oool0EEEE0:ZZZP80EEEE00@0000005EEE@2ZZZX0EEEE8@3oool:0=7=ZAl0oooo
00<0000005EEE@1EEED01@3oool00`2ZZZX0EEEE05EEE@0P0?ooo``0dLfY000;0=7=ZB00oooo00<0
000005EEE@0000001000000205EEE@030000003oool0oooo01h0oooo2P3AcJTP0?ooo`80ZZZZ0P00
00000`3oool00000000000030:ZZZR00oooo2P3AcJTP0?ooo`040:ZZZP3oool000000:ZZZP80oooo
00@0ZZZZ05EEE@3oool0ZZZZ803oool:0=7=ZB00oooo0P2ZZZX01P3oool0ZZZZ05EEE@000000ZZZZ
05EEE@80ZZZZ803oool:0=7=ZB00oooo00<0ZZZZ0000003oool01@3oool00`000000ZZZZ0?ooo`0O
0?ooo``0dLfY000;0=7=ZB40oooo00@000000?ooo`2ZZZX0oooo0`2ZZZX00`000000oooo0?ooo`0O
0?ooo`X0dLfY8@3oool00`000000oooo0:ZZZP020?ooo`030:ZZZP3oool000000240oooo2P3AcJTQ
0?ooo`040000002ZZZX0ZZZZ0?ooo`80ZZZZ0P00000Q0?ooo`X0dLfY8@3oool020000000ZZZZ0:ZZ
ZP1EEED000000:ZZZP3oool000008@3oool:0=7=ZB40oooo00@0000005EEE@000000EEEE0P000000
0`1EEED000000?ooo`0P0?ooo``0dLfY000;0=7=ZB80oooo00<000000:ZZZP1EEED00P2ZZZXS0?oo
o`X0dLfY8P3oool010000000oooo0?ooo`1EEEDT0?ooo`X0dLfY8P3oool2000000030?ooo`2ZZZX0
000002<0oooo2P3AcJTR0?ooo`050000001EEED0EEEE0:ZZZP1EEED08`3oool:0=7=ZB80oooo00D0
000005EEE@3oool0000005EEE@0S0?ooo``0dLfY000;0=7=ZB<0oooo00@000000?ooo`1EEED00000
8`3oool:0=7=ZB<0oooo0P2ZZZX00`000000ZZZZ0?ooo`0R0?ooo`X0dLfY8`3oool0102ZZZX0EEEE
0?ooo`2ZZZXS0?ooo`X0dLfY8`3oool20:ZZZP030000002ZZZX0oooo0280oooo2P3AcJTS0?ooo`04
0:ZZZP1EEED000000:ZZZR<0oooo303AcJT000/0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0
dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0
dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo``0
dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80
dLfY003o0=7=ZK80dLfY000;0=7=Z@80oooo00<0ZZZZ0000001EEED00P3oool00`1EEED0ZZZZ0?oo
o`02000000050:ZZZP3oool0oooo0?ooo`1EEED00P3oool0101EEED000000000001EEED2000000<0
oooo0P2ZZZX20?ooo`80000000<0oooo05EEE@0000000P1EEED00`3oool00000000000020?ooo`80
ZZZZ0`3oool20000000505EEE@000000oooo05EEE@3oool00`1EEED20?ooo`<0000000<0EEEE0:ZZ
ZP1EEED00P3oool2000000030:ZZZP1EEED0oooo00X0dLfY00D0oooo0000003oool000000:ZZZP02
0?ooo`030000001EEED0000000@0oooo00<0ZZZZ0000001EEED01@0000000`3oool0000000000004
0?ooo`80ZZZZ00@0oooo00000000000000000P3oool00`000000oooo00000002000000040?ooo`2Z
ZZX0ZZZZ000000<0oooo0P0000000`3oool000000000000200000080EEEE00<0oooo0:ZZZP3oool0
0`3oool00`000000EEEE000000030?ooo`040000003oool000000?ooo`X0dLfY00<0oooo0:ZZZP2Z
ZZX00`2ZZZX305EEE@80000000<0EEEE0?ooo`0000000`3oool00`1EEED0ZZZZ05EEE@03000000@0
ZZZZ00L0oooo05EEE@2ZZZX0ZZZZ0?ooo`000000oooo00<0ZZZZ00D0EEEE0:ZZZP000000oooo0000
00030:ZZZP80oooo0`2ZZZX00`1EEED000000000000205EEE@80ZZZZ00<0oooo0000003oool00P00
00000`1EEED000000000000205EEE@80ZZZZ00D0EEEE0:ZZZP2ZZZX000000?ooo`0:0=7=Z@030?oo
o`2ZZZX0EEEE00<0ZZZZ10000000202ZZZX0000005EEE@000000ZZZZ05EEE@3oool0EEEE0P2ZZZX0
103oool000000000001EEED20:ZZZP0405EEE@2ZZZX000000:ZZZP<0EEEE00H000000:ZZZP3oool0
00000:ZZZP3oool20000000505EEE@2ZZZX0EEEE0:ZZZP0000001@2ZZZX300000080ZZZZ0P3oool2
0:ZZZP030000002ZZZX000000080ZZZZ0`0000001P2ZZZX0oooo0:ZZZP1EEED000000?ooo`X0dLfY
00@0oooo0:ZZZP1EEED0ZZZZ0P3oool20000000305EEE@3oool0oooo00<0oooo00H0EEEE0?ooo`3o
ool0oooo0000001EEED20?ooo`0405EEE@000000EEEE0?ooo`80000000@0EEEE0000002ZZZX0EEEE
0P0000060?ooo`<0000000T0ZZZZ0000002ZZZX0000005EEE@3oool0EEEE0000001EEED00P3oool0
1P1EEED000000?ooo`3oool0000005EEE@@0oooo00X0000005EEE@000000ZZZZ0?ooo`000000ZZZZ
05EEE@000000oooo303AcJT000/0dLfY00@0oooo0000001EEED0ZZZZ103oool010000000EEEE0?oo
o`3oool205EEE@080000003oool0oooo0?ooo`1EEED000000:ZZZP3oool30:ZZZP0305EEE@000000
EEEE00@0EEEE0P3oool010000000EEEE00000000000205EEE@80oooo00<0000005EEE@1EEED0101E
EED0102ZZZX0oooo0:ZZZP3oool20000000505EEE@000000oooo0?ooo`0000000P1EEED20?ooo`80
00000`3oool20:ZZZP0305EEE@3oool0oooo00X0dLfY00@0oooo0000003oool0ZZZZ0`1EEED20?oo
o`040:ZZZP3oool000000?ooo`8000000`3oool00`1EEED0ZZZZ05EEE@020?ooo`030000003oool0
oooo0080oooo0`000000103oool0ZZZZ0:ZZZP2ZZZX20?ooo`030000003oool0ZZZZ0080ZZZZ0`00
00090?ooo`040:ZZZP1EEED0ZZZZ0?ooo`D0000000@0oooo0:ZZZP3oool0oooo0P1EEED20:ZZZP<0
oooo2P3AcJT02`3oool000000000001EEED0oooo0000003oool0EEEE0000003oool0EEEE0080oooo
0P2ZZZX00`3oool0EEEE05EEE@02000000<0ZZZZ00D0000005EEE@000000EEEE0:ZZZP0405EEE@80
oooo0P00000205EEE@040000003oool0oooo0?ooo`<0EEEE0P2ZZZX20000000305EEE@2ZZZX0ZZZZ
0080ZZZZ0P00000305EEE@80ZZZZ00H000000?ooo`1EEED0oooo0000001EEED30000000405EEE@00
0000oooo0?ooo`X0dLfY00<0oooo0000002ZZZX00P1EEED40:ZZZP040000003oool0ZZZZ05EEE@<0
000000<0oooo0000002ZZZX00P3oool00`1EEED0ZZZZ00000003000000070?ooo`2ZZZX0oooo0000
002ZZZX0EEEE0000000205EEE@80ZZZZ00@0EEEE000000000000EEEE0P0000000`3oool0ZZZZ0?oo
o`03000000080?ooo`2ZZZX0EEEE0000003oool0ZZZZ05EEE@3oool300000080ZZZZ0P3oool50:ZZ
ZP0405EEE@2ZZZX0oooo0?ooo`X0dLfY00@0oooo0000002ZZZX0ZZZZ0P0000001P3oool0ZZZZ05EE
E@1EEED0000005EEE@80000000<0EEEE0?ooo`3oool00P3oool30000000405EEE@3oool0EEEE0000
0080oooo00D0EEEE0:ZZZP3oool0oooo05EEE@080?ooo`0>05EEE@000000oooo0:ZZZP1EEED0oooo
05EEE@000000EEEE0?ooo`1EEED0000005EEE@0000040?ooo`0505EEE@000000EEEE05EEE@000000
0P1EEED20:ZZZP040000001EEED0ZZZZ0:ZZZP80oooo303AcJT000/0dLfY0`3oool20000000505EE
E@3oool000000?ooo`0000000P2ZZZX01@000000oooo05EEE@1EEED0ZZZZ0080oooo00D0EEEE0:ZZ
ZP3oool0EEEE0?ooo`02000000H0EEEE00L0ZZZZ05EEE@000000ZZZZ0000001EEED0ZZZZ0080EEEE
00<0ZZZZ05EEE@1EEED0101EEED2000000050:ZZZP1EEED0oooo0000001EEED00P3oool20:ZZZP03
05EEE@3oool000000080ZZZZ00D000000?ooo`000000oooo05EEE@02000000<0oooo2P3AcJT30?oo
o`030000003oool0000000<0000000@0oooo0:ZZZP00000000000`3oool010000000ZZZZ0?ooo`3o
ool2000000070?ooo`00000000000?ooo`2ZZZX0oooo000000030?ooo`0305EEE@3oool0EEEE00@0
oooo00<0ZZZZ0?ooo`1EEED00`3oool01@000000oooo0000003oool000000080oooo0P0000030?oo
o`040000003oool0oooo0?ooo`80000000P0ZZZZ0?ooo`000000000005EEE@000000oooo000000<0
oooo2P3AcJT30?ooo`040000002ZZZX0EEEE0?ooo`<0EEEE0P0000000`3oool0ZZZZ0:ZZZP020?oo
o`80EEEE103oool20:ZZZP0405EEE@3oool0ZZZZ0:ZZZP80000000<0EEEE0000000000000P1EEED0
10000000oooo05EEE@1EEED20000000305EEE@00000000000080ZZZZ00@0000005EEE@2ZZZX0EEEE
0P3oool0101EEED0oooo05EEE@2ZZZX20?ooo`80ZZZZ0`00000505EEE@030:ZZZP000000oooo0080
oooo2P3AcJT30?ooo`030000001EEED0ZZZZ00<0ZZZZ00<0EEEE0:ZZZP2ZZZX00P2ZZZX02@000000
EEEE05EEE@1EEED0ZZZZ0000003oool0EEEE0?ooo`02000000030:ZZZP000000ZZZZ0080ZZZZ00D0
EEEE0:ZZZP1EEED0000005EEE@040:ZZZP80000000`0EEEE0:ZZZP1EEED0ZZZZ0?ooo`2ZZZX00000
0:ZZZP000000ZZZZ0?ooo`1EEED200000080ZZZZ00<0EEEE0:ZZZP0000001`2ZZZX0103oool0ZZZZ
0:ZZZP0000030?ooo`X0dLfY0`3oool3000000030?ooo`1EEED0EEEE0080000000L0EEEE0?ooo`3o
ool0oooo0:ZZZP3oool0EEEE0080ZZZZ0`3oool01@000000oooo0?ooo`000000EEEE0080oooo00X0
ZZZZ05EEE@1EEED0EEEE0?ooo`1EEED0oooo0000001EEED0oooo0P1EEED01@3oool0ZZZZ0?ooo`3o
ool0EEEE00<0oooo00@0EEEE0?ooo`3oool0oooo0P2ZZZX20?ooo`050:ZZZP3oool0oooo0?ooo`1E
EED00P00000205EEE@040?ooo`000000ZZZZ000000<0oooo303AcJT000/0dLfY1P3oool00`1EEED0
oooo0?ooo`0305EEE@<0oooo00@0000005EEE@1EEED0EEEE0P0000000`3oool0EEEE000000020000
000305EEE@000000EEEE00@0000000H0oooo0000002ZZZX0oooo05EEE@2ZZZX20?ooo`030000001E
EED0000000H0000000<0ZZZZ05EEE@3oool00P000000101EEED0ZZZZ05EEE@0000020?ooo`<0EEEE
0`3oool00`000000oooo05EEE@040?ooo`X0dLfY103oool020000000oooo0:ZZZP1EEED0oooo0000
001EEED0oooo0P2ZZZX01P1EEED0ZZZZ05EEE@1EEED000000:ZZZP80oooo00`000000?ooo`3oool0
000005EEE@3oool0ZZZZ0?ooo`000000oooo0:ZZZP3oool205EEE@060?ooo`1EEED0EEEE0000003o
ool0ZZZZ0P0000000`3oool0EEEE0?ooo`020000000;0?ooo`00000000000?ooo`1EEED0ZZZZ0000
003oool0EEEE0:ZZZP1EEED00P2ZZZX01@3oool0EEEE0:ZZZP3oool0EEEE0080oooo00<000000?oo
o`3oool00P3oool:0=7=Z@@0oooo00D0000005EEE@2ZZZX0ZZZZ000000030:ZZZP<0EEEE00@0oooo
05EEE@1EEED0ZZZZ0P1EEED20:ZZZP<0EEEE00L0oooo0000003oool000000?ooo`2ZZZX0oooo00<0
EEEE0P2ZZZX00`1EEED0ZZZZ05EEE@030?ooo`<0000000@0ZZZZ05EEE@1EEED0EEEE0`2ZZZX00`1E
EED0ZZZZ05EEE@0405EEE@030?ooo`2ZZZX0ZZZZ0080000000@0ZZZZ05EEE@1EEED00000103oool:
0=7=Z@@0oooo00<0ZZZZ05EEE@1EEED00`2ZZZX500000080EEEE00<000000:ZZZP3oool00`1EEED3
0:ZZZP040?ooo`2ZZZX0ZZZZ0?ooo`<0000000@0oooo000000000000ZZZZ0P0000020?ooo`<00000
00@0oooo0000002ZZZX0EEEE0`2ZZZX205EEE@030:ZZZP3oool0ZZZZ00<0EEEE1@0000001P1EEED0
ZZZZ0:ZZZP2ZZZX0EEEE000000@0oooo2P3AcJT40?ooo`050:ZZZP1EEED0EEEE05EEE@2ZZZX00P3o
ool00`1EEED000000:ZZZP04000000030?ooo`2ZZZX000000080EEEE103oool02@000000EEEE0000
00000000EEEE0?ooo`000000EEEE000000020?ooo`040000001EEED000000?ooo`<0000000<0EEEE
0000003oool00P3oool01`000000EEEE05EEE@000000ZZZZ0?ooo`1EEED00`0000002P2ZZZX00000
05EEE@3oool0EEEE0:ZZZP1EEED0000005EEE@0000040?ooo``0dLfY000;0=7=Z@D0oooo0`1EEED0
1@3oool0EEEE0:ZZZP2ZZZX0oooo00@0000000@0EEEE0:ZZZP1EEED000000P3oool00`1EEED00000
0:ZZZP0205EEE@040:ZZZP1EEED000000?ooo`80EEEE00<0oooo05EEE@0000001@1EEED200000007
05EEE@000000EEEE05EEE@2ZZZX0000005EEE@030?ooo`0305EEE@2ZZZX0000000@00000102ZZZX0
103oool0EEEE0:ZZZP1EEED50?ooo`X0dLfY1@3oool20000000305EEE@3oool0oooo0080000000D0
EEEE0?ooo`000000oooo05EEE@02000000030?ooo`2ZZZX0oooo0080oooo00<0000005EEE@1EEED0
0`3oool00`000000oooo0?ooo`03000000060?ooo`00000000000?ooo`000000oooo0P0000000`3o
ool000000?ooo`0205EEE@030000003oool0oooo00<0oooo00H000000?ooo`1EEED0oooo0000003o
ool3000000030:ZZZP3oool0EEEE008000001@3oool:0=7=Z@D0oooo00<000000:ZZZP2ZZZX00P2Z
ZZX00`3oool0EEEE000000020?ooo`030000001EEED000000080ZZZZ00d0EEEE0?ooo`000000oooo
05EEE@3oool0ZZZZ05EEE@000000EEEE0?ooo`000000EEEE00<0oooo00D0ZZZZ05EEE@3oool0EEEE
0?ooo`0205EEE@0:0?ooo`1EEED0000005EEE@2ZZZX0oooo05EEE@3oool000000?ooo`<0ZZZZ0P1E
EED01`000000oooo0?ooo`000000EEEE0?ooo`1EEED00`2ZZZX00`000000oooo0?ooo`030?ooo`X0
dLfY1@3oool01@000000EEEE0:ZZZP3oool0ZZZZ00<0000000@0ZZZZ000000000000ZZZZ0P1EEED2
0000000405EEE@2ZZZX0ZZZZ0?ooo`80ZZZZ0`0000000`2ZZZX0oooo05EEE@0205EEE@040000002Z
ZZX0oooo000000<0EEEE00P000000:ZZZP000000EEEE0000001EEED0ZZZZ0?ooo`80ZZZZ00@0EEEE
000000000000EEEE0`2ZZZX00`000000ZZZZ00000002000000050:ZZZP3oool0ZZZZ0:ZZZP000000
1@3oool:0=7=Z@D0oooo00D000000?ooo`00000000000:ZZZP02000000<0oooo0`000000103oool0
EEEE0000001EEED60?ooo`0405EEE@000000000000000080EEEE1@3oool00`000000EEEE05EEE@03
000000L0oooo00@0EEEE0000001EEED0oooo0P000000102ZZZX0oooo0?ooo`2ZZZX5000000030:ZZ
ZP000000oooo00@0oooo303AcJT000/0dLfY1P3oool01`000000EEEE000000000000oooo0000003o
ool00P1EEED00`3oool0EEEE0?ooo`02000000<0oooo00@0ZZZZ0?ooo`000000EEEE0P0000020?oo
o`0505EEE@2ZZZX0oooo0000001EEED00P0000001@1EEED0oooo0?ooo`2ZZZX0EEEE0080oooo1000
00040?ooo`0605EEE@00000000000?ooo`1EEED0oooo0P1EEED200000080oooo00<0000005EEE@00
00001P3oool:0=7=Z@P0oooo0P2ZZZX00`3oool0ZZZZ0?ooo`020?ooo`050:ZZZP3oool0oooo0000
003oool00P0000000`3oool000000?ooo`030?ooo`80EEEE00<0oooo0000000000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo05EEE@80oooo00D0ZZZZ0?ooo`3oool00000
0?ooo`02000000050?ooo`000000oooo0?ooo`0000000P3oool20:ZZZP050?ooo`000000ZZZZ0?oo
o`0000001P3oool:0=7=Z@H0oooo00L0000005EEE@00000000000?ooo`2ZZZX0EEEE0080ZZZZ00<0
oooo0:ZZZP3oool00`000000203oool0ZZZZ05EEE@2ZZZX0EEEE0000001EEED0ZZZZ0P1EEED00`00
0000oooo05EEE@020:ZZZP80EEEE00<0ZZZZ05EEE@1EEED00P3oool205EEE@040?ooo`1EEED0ZZZZ
05EEE@<0ZZZZ00L0oooo05EEE@00000000000?ooo`2ZZZX0EEEE0080ZZZZ00<0oooo0:ZZZP3oool0
0P0000000`1EEED000000?ooo`050?ooo`X0dLfY1P3oool00`2ZZZX0EEEE0:ZZZP040:ZZZP030?oo
o`000000ZZZZ0080ZZZZ00X0000005EEE@000000EEEE0:ZZZP1EEED0ZZZZ05EEE@000000oooo0`2Z
ZZX00`3oool0000000000002000000040?ooo`1EEED000000?ooo`80000000<0EEEE0:ZZZP2ZZZX0
0P3oool00`2ZZZX0EEEE0:ZZZP020:ZZZP0905EEE@000000EEEE0000001EEED0ZZZZ0?ooo`000000
oooo00<0ZZZZ00@0EEEE0:ZZZP1EEED000001P3oool:0=7=Z@H0oooo00D0ZZZZ0000001EEED00000
0?ooo`02000000040:ZZZP00000000000?ooo`8000000P2ZZZX80?ooo`80ZZZZ00<0oooo05EEE@00
00001P3oool00`000000EEEE0:ZZZP020:ZZZPP0oooo0P2ZZZX00`000000oooo0?ooo`0200000006
0:ZZZP00000000000?ooo`2ZZZX0EEEE0P0000060?ooo``0dLfY000;0=7=Z@H0oooo00<0EEEE0?oo
o`2ZZZX00P000000102ZZZX0000005EEE@0000020:ZZZP<000000P1EEED01@000000EEEE05EEE@2Z
ZZX0EEEE0080oooo00<0EEEE0000003oool00P0000001P2ZZZX0oooo0?ooo`1EEED0oooo0:ZZZP80
000000D0oooo0000001EEED0EEEE0?ooo`020:ZZZP80EEEE00<0000005EEE@0000000P0000020:ZZ
ZP80000000<0EEEE0?ooo`2ZZZX00P0000000`2ZZZX0oooo0?ooo`060?ooo`X0dLfY1P3oool20000
0080oooo0`0000001@3oool0000005EEE@3oool0EEEE0080oooo00D000000?ooo`3oool000000?oo
o`020:ZZZP040?ooo`2ZZZX0000000000080ZZZZ00<0oooo0000003oool00`3oool010000000oooo
0:ZZZP3oool3000000030?ooo`000000ZZZZ00L0oooo00D0EEEE0?ooo`00000000000?ooo`030000
000305EEE@3oool0000000L0oooo2P3AcJT60?ooo`040000003oool0EEEE0?ooo`80EEEE00<0oooo
0000000000000P1EEED01@3oool0EEEE0?ooo`3oool0ZZZZ0080000000@0EEEE000000000000oooo
0P1EEED010000000ZZZZ05EEE@2ZZZX205EEE@080:ZZZP1EEED0EEEE05EEE@2ZZZX0EEEE0?ooo`00
000205EEE@80oooo00@0000005EEE@1EEED000000P2ZZZX01@3oool0EEEE05EEE@1EEED0oooo0080
00000`1EEED00`3oool0EEEE0?ooo`070?ooo`X0dLfY1P3oool00`000000ZZZZ05EEE@0400000080
ZZZZ0P0000002@3oool0ZZZZ05EEE@000000EEEE0:ZZZP1EEED0000005EEE@030:ZZZP80000000P0
oooo05EEE@3oool0oooo05EEE@000000ZZZZ05EEE@80oooo00<0EEEE0000000000000P0000020:ZZ
ZP0805EEE@000000ZZZZ0:ZZZP1EEED0000005EEE@2ZZZX2000000<0ZZZZ0`0000000`2ZZZX0EEEE
0:ZZZP070?ooo`X0dLfY1P3oool00`000000ZZZZ05EEE@040?ooo`030000002ZZZX0oooo0080oooo
100000001P1EEED000000000001EEED0000005EEE@@0000000<0EEEE0?ooo`3oool01P3oool0101E
EED0000000000000000405EEE@030000001EEED0EEEE00@000000P3oool0101EEED0ZZZZ00000000
00020?ooo`80EEEE00<0ZZZZ0?ooo`3oool01@3oool<0=7=Z@002`3AcJT80?ooo`0405EEE@000000
EEEE0?ooo`80EEEE1@0000020:ZZZP030000001EEED0EEEE0080000000@0ZZZZ0?ooo`1EEED0oooo
0`000000203oool0EEEE0?ooo`3oool000000?ooo`1EEED0oooo0`000000103oool000000?ooo`3o
ool200000080EEEE00P000000:ZZZP2ZZZX0000005EEE@000000EEEE00000080EEEE00@0oooo05EE
E@2ZZZX0EEEE203oool:0=7=Z@P0oooo0P0000030?ooo`040000002ZZZX000000?ooo`80000000P0
oooo000000000000oooo0:ZZZP1EEED0oooo05EEE@80oooo0P1EEED00`2ZZZX0EEEE0?ooo`030?oo
o`060000003oool0oooo0?ooo`1EEED0oooo0P1EEED0202ZZZX0oooo0000003oool0EEEE0000003o
ool000000P3oool2000000040?ooo`2ZZZX0ZZZZ000000<0oooo0P0000080?ooo`X0dLfY203oool0
1@000000EEEE05EEE@1EEED0oooo00<000000P1EEED2000000<0oooo00@0EEEE0:ZZZP2ZZZX0EEEE
0P00000205EEE@80oooo0`1EEED01P2ZZZX0EEEE05EEE@2ZZZX0EEEE0?ooo`<0EEEE00<0oooo0000
002ZZZX00P2ZZZX00`1EEED0oooo0?ooo`03000000<0EEEE0`00000205EEE@800000203oool:0=7=
Z@P0oooo00L0000005EEE@2ZZZX0EEEE0:ZZZP1EEED0ZZZZ00@0000000<0EEEE0?ooo`1EEED00P2Z
ZZX205EEE@80ZZZZ0P0000001P3oool0EEEE000000000000EEEE0:ZZZP80000000H0ZZZZ0?ooo`00
0000000005EEE@3oool200000080ZZZZ0P1EEED01@3oool0ZZZZ05EEE@000000EEEE00@0000000@0
ZZZZ05EEE@2ZZZX0EEEE0P2ZZZX00`000000oooo0?ooo`060?ooo`X0dLfY203oool00`000000oooo
05EEE@020?ooo`80000000<0EEEE0000001EEED00P0000030?ooo`80000000<0EEEE0?ooo`3oool0
1`0000001@1EEED0ZZZZ0?ooo`1EEED0oooo00D0000000H0EEEE0?ooo`3oool0EEEE0000001EEED3
0?ooo`80000000<0EEEE0000000000000P0000001@1EEED0oooo05EEE@2ZZZX0000000P0oooo303A
cJT000/0dLfY2@3oool20000000705EEE@2ZZZX0oooo05EEE@2ZZZX000000?ooo`0405EEE@050?oo
o`1EEED0oooo05EEE@2ZZZX00P00000305EEE@040?ooo`1EEED0000005EEE@80oooo00<0EEEE0000
001EEED00P3oool205EEE@8000000P1EEED00`3oool0ZZZZ0?ooo`0405EEE@040?ooo`000000oooo
05EEE@80oooo00<0EEEE0000000000002@3oool:0=7=Z@h0oooo00@0EEEE0?ooo`3oool000000`3o
ool00`000000oooo0:ZZZP02000000030?ooo`2ZZZX0ZZZZ0080oooo00<000000:ZZZP0000000P00
00020?ooo`030000003oool000000080ZZZZ0P3oool00`000000ZZZZ0?ooo`02000000030:ZZZP3o
ool0000000D0oooo00<0000005EEE@3oool00`3oool00`000000oooo0?ooo`070?ooo`X0dLfY2P3o
ool02`1EEED000000?ooo`3oool0000005EEE@2ZZZX0EEEE0:ZZZP3oool0EEEE0080ZZZZ00@0EEEE
00000000000000000P3oool010000000EEEE0:ZZZP2ZZZX205EEE@040:ZZZP1EEED0EEEE0:ZZZP80
EEEE00@0ZZZZ05EEE@1EEED000000P3oool0101EEED000000000001EEED30:ZZZP060?ooo`2ZZZX0
EEEE0:ZZZP3oool000000P3oool00`000000EEEE000000090?ooo`X0dLfY2@3oool00`2ZZZX0EEEE
0:ZZZP02000000080?ooo`2ZZZX0ZZZZ0:ZZZP3oool0ZZZZ05EEE@0000020:ZZZP080000001EEED0
ZZZZ05EEE@3oool0EEEE0?ooo`0000020?ooo`0305EEE@2ZZZX0ZZZZ0080ZZZZ00X000000?ooo`3o
ool000000?ooo`1EEED0ZZZZ05EEE@2ZZZX0EEEE0P0000001@2ZZZX000000?ooo`2ZZZX0oooo00<0
ZZZZ00H0oooo000000000000ZZZZ05EEE@0000090?ooo`X0dLfY2@3oool01P2ZZZX000000:ZZZP2Z
ZZX0000005EEE@80oooo00@000000?ooo`000000ZZZZ0P0000020?ooo`80000000@0EEEE0?ooo`00
0000oooo0P0000020?ooo`0405EEE@000000000005EEE@80oooo00<000000?ooo`3oool00P000002
05EEE@030000003oool0EEEE00@0000000D0oooo05EEE@3oool0ZZZZ05EEE@02000000030:ZZZP00
0000000000T0oooo303AcJT000/0dLfY2P3oool00`000000EEEE0?ooo`020000000305EEE@3oool0
EEEE00D0EEEE01P0oooo0:ZZZP000000ZZZZ0?ooo`2ZZZX0oooo0:ZZZP000000EEEE0?ooo`000000
oooo0000001EEED0oooo0000003oool0EEEE0?ooo`2ZZZX0oooo0000003oool2000000030:ZZZP1E
EED0EEEE00D0EEEE00L0oooo05EEE@00000000000?ooo`1EEED0000000X0oooo2P3AcJT:0?ooo`04
0000003oool0ZZZZ0:ZZZP80EEEE00@0ZZZZ0000003oool000000P3oool01@000000EEEE05EEE@1E
EED0oooo008000000P3oool0102ZZZX000000?ooo`3oool405EEE@80oooo0P0000020?ooo`030:ZZ
ZP000000oooo0080EEEE0P0000020?ooo`040000003oool0oooo0:ZZZP80EEEE0P2ZZZX00`3oool0
00000?ooo`090?ooo`X0dLfY2P3oool3000000040?ooo`000000oooo05EEE@<0oooo10000000101E
EED0oooo05EEE@1EEED2000000@0oooo00<0EEEE0?ooo`0000000P3oool01P000000oooo0?ooo`00
0000oooo000000<0EEEE00<0oooo05EEE@0000000`0000020?ooo`060000001EEED000000000003o
ool0EEEE0P00000:0?ooo`X0dLfY2P3oool010000000ZZZZ0:ZZZP1EEED30:ZZZP050?ooo`000000
oooo0:ZZZP1EEED00P000000101EEED0ZZZZ0:ZZZP3oool2000000<0oooo00<0ZZZZ05EEE@2ZZZX0
0`2ZZZX00`1EEED0ZZZZ0?ooo`020?ooo`80000000X0oooo0:ZZZP2ZZZX0EEEE0?ooo`000000EEEE
0:ZZZP3oool00000102ZZZX205EEE@030:ZZZP000000oooo00T0oooo2P3AcJT:0?ooo`030000002Z
ZZX0EEEE0080000000<0oooo0:ZZZP1EEED00P0000001`1EEED0oooo0?ooo`1EEED000000?ooo`2Z
ZZX00P3oool0201EEED00000000000000000ZZZZ0000001EEED0oooo0P1EEED02`000000ZZZZ0000
003oool0000005EEE@000000oooo0000003oool0000000<0oooo00@0ZZZZ000000000000EEEE0P2Z
ZZX200000080ZZZZ00<000000?ooo`3oool0203oool<0=7=Z@002`3AcJT;0?ooo`<0EEEE00@0oooo
0000003oool0ZZZZ103oool00`2ZZZX0oooo00000002000000040?ooo`1EEED0EEEE0:ZZZP800000
0`1EEED01@3oool0ZZZZ05EEE@3oool0EEEE0080000000@0ZZZZ05EEE@1EEED0oooo0`000000101E
EED0ZZZZ0?ooo`0000020?ooo`0705EEE@3oool0oooo0?ooo`1EEED0ZZZZ05EEE@0;0?ooo`X0dLfY
2`3oool6000000<0oooo00D000000?ooo`000000oooo0:ZZZP030?ooo`0905EEE@000000ZZZZ0?oo
o`000000oooo0:ZZZP3oool0ZZZZ0080oooo00D000000?ooo`000000EEEE0:ZZZP02000000<0oooo
00D0ZZZZ0?ooo`000000oooo000000020?ooo`80000000<0ZZZZ0000000000000P00000;0?ooo`X0
dLfY2`3oool010000000EEEE0?ooo`1EEED20?ooo`030:ZZZP1EEED0ZZZZ00<0ZZZZ00<0EEEE0:ZZ
ZP1EEED00`1EEED20?ooo`80EEEE00<0oooo0:ZZZP1EEED00P2ZZZX205EEE@030?ooo`1EEED0oooo
0080oooo00H0ZZZZ05EEE@2ZZZX0EEEE0:ZZZP3oool40:ZZZP0505EEE@2ZZZX0oooo0?ooo`1EEED0
0P3oool00`000000oooo0?ooo`090?ooo`X0dLfY2`3oool00`000000EEEE0:ZZZP03000000<0ZZZZ
0P0000020?ooo`<000001P2ZZZX6000000040?ooo`000000ZZZZ000000@0ZZZZ0`0000020?ooo`80
00000P2ZZZX400000080ZZZZ00<000000?ooo`3oool02@3oool:0=7=Z@/0oooo00<000000?ooo`3o
ool00P0000001P2ZZZX0oooo0:ZZZP2ZZZX0000005EEE@8000000P3oool010000000ZZZZ05EEE@00
00020?ooo`0405EEE@2ZZZX0oooo0:ZZZP80oooo0`2ZZZX00`1EEED0oooo0?ooo`02000000080:ZZ
ZP3oool0oooo0?ooo`1EEED0000005EEE@3oool20:ZZZP070?ooo`2ZZZX000000000003oool0ZZZZ
0000000;0?ooo``0dLfY000;0=7=Z@`0oooo00@0000005EEE@000000EEEE0P3oool010000000EEEE
05EEE@0000020?ooo`@0EEEE0P3oool4000000060?ooo`2ZZZX0000005EEE@2ZZZX0EEEE10000000
103oool0ZZZZ05EEE@3oool205EEE@050000003oool000000?ooo`1EEED00P0000020?ooo`030000
001EEED0000000`0oooo2P3AcJT>0?ooo`030000001EEED0oooo0080000000<0oooo0:ZZZP3oool0
1P000000103oool0ZZZZ0:ZZZP0000020?ooo`050000001EEED000000:ZZZP1EEED00`3oool01P00
0000ZZZZ0:ZZZP3oool000000?ooo`80000000H0oooo0000003oool0ZZZZ0?ooo`0000030?ooo`03
0000003oool0000000`0oooo2P3AcJT<0?ooo`80ZZZZ00<0EEEE0?ooo`1EEED00P1EEED00`000000
EEEE000000020:ZZZP0305EEE@00000000000080EEEE0`2ZZZX205EEE@80000000@0oooo00000000
0000oooo0`1EEED20:ZZZP80EEEE00D0oooo0000001EEED0EEEE0:ZZZP03000000D0EEEE00<0ZZZZ
0000003oool02`3oool:0=7=Z@`0oooo00<0ZZZZ05EEE@2ZZZX00`2ZZZX00`1EEED0ZZZZ0:ZZZP05
0:ZZZP030?ooo`2ZZZX00000008000000P1EEED20?ooo`0405EEE@3oool0ZZZZ05EEE@80oooo00<0
EEEE0000000000000P0000040:ZZZP030000002ZZZX0ZZZZ0080ZZZZ00L0EEEE0:ZZZP2ZZZX0oooo
0:ZZZP1EEED0000000`0oooo2P3AcJT<0?ooo`050:ZZZP00000000000?ooo`1EEED00`0000000`1E
EED0ZZZZ05EEE@040?ooo`80EEEE00D0ZZZZ0000001EEED000000?ooo`020000000505EEE@000000
00000:ZZZP3oool00`0000000`2ZZZX0EEEE05EEE@030?ooo`030000001EEED0ZZZZ00<000000P1E
EED0103oool0000000000000000<0?ooo``0dLfY000;0=7=Z@d0oooo00<0000005EEE@2ZZZX0103o
ool010000000EEEE05EEE@1EEED20?ooo`060:ZZZP1EEED000000000001EEED0ZZZZ0P1EEED00`00
0000oooo05EEE@020?ooo`050000001EEED0EEEE0?ooo`1EEED00P00000205EEE@80oooo00@0ZZZZ
05EEE@1EEED00000103oool00`2ZZZX0EEEE0000000=0?ooo`X0dLfY3@3oool010000000oooo0000
001EEED30?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000`2ZZZX20?ooo`80EEEE
1@0000000`1EEED0oooo0:ZZZP020:ZZZP040?ooo`0000000000000000@0oooo00P0EEEE0?ooo`3o
ool0oooo05EEE@2ZZZX0oooo000000d0oooo2P3AcJT=0?ooo`050000003oool000000000003oool0
0P0000020:ZZZP0305EEE@2ZZZX0EEEE0080ZZZZ0P1EEED20?ooo`0405EEE@3oool000000:ZZZP80
EEEE00H0ZZZZ05EEE@00000000000?ooo`0000020?ooo`090000001EEED0EEEE0:ZZZP1EEED0oooo
05EEE@2ZZZX0EEEE0080000000D0oooo0000001EEED0oooo0000000=0?ooo`X0dLfY3@3oool00`00
0000ZZZZ0:ZZZP02000000030?ooo`2ZZZX0ZZZZ00<0ZZZZ0P3oool00`000000oooo000000020000
00030:ZZZP1EEED0EEEE0080EEEE0P2ZZZX01@1EEED0ZZZZ05EEE@1EEED0ZZZZ0080000000<0ZZZZ
0?ooo`0000000`3oool40:ZZZP060?ooo`000000000005EEE@2ZZZX000003@3oool:0=7=Z@d0oooo
00@000000:ZZZP2ZZZX000000`3oool0102ZZZX000000:ZZZP3oool2000000040?ooo`000000oooo
0:ZZZP<0000000P0oooo000000000000oooo05EEE@000000EEEE0?ooo`<000000P2ZZZX400000003
0?ooo`2ZZZX0000000<0oooo00D0ZZZZ0000002ZZZX0ZZZZ0000000=0?ooo``0dLfY000;0=7=Z@h0
oooo00@0EEEE0000001EEED000000P1EEED0102ZZZX0oooo0?ooo`00000205EEE@030000003oool0
EEEE0080oooo00@0EEEE0:ZZZP3oool0oooo0P1EEED01P000000EEEE05EEE@3oool0ZZZZ000000@0
oooo00@0000005EEE@1EEED000000P3oool01`2ZZZX0EEEE05EEE@3oool0EEEE0:ZZZP1EEED03P3o
ool:0=7=Z@h0oooo0P00000405EEE@80000000@0oooo0000003oool000000P3oool4000000040?oo
o`2ZZZX0ZZZZ0?ooo`80ZZZZ0P3oool00`2ZZZX0oooo0000000300000080oooo00D000000?ooo`00
0000oooo0000000505EEE@8000003P3oool:0=7=Z@h0oooo00H000000:ZZZP2ZZZX0EEEE0:ZZZP3o
ool2000000090?ooo`1EEED0EEEE0:ZZZP000000oooo0:ZZZP1EEED0ZZZZ00@0oooo0P0000000`1E
EED00000000000020?ooo`80ZZZZ0P1EEED00`3oool000000:ZZZP0205EEE@040?ooo`000000EEEE
0?ooo`@0ZZZZ00<000000?ooo`3oool0303oool:0=7=Z@h0oooo00<0000005EEE@2ZZZX00P2ZZZX3
00000080ZZZZ00H000000:ZZZP2ZZZX0ZZZZ0000001EEED2000000040:ZZZP1EEED0EEEE0:ZZZP80
000000@0ZZZZ0000001EEED0ZZZZ0P0000000`1EEED000000:ZZZP020:ZZZP80000000H0ZZZZ0000
0000000000000:ZZZP3oool20:ZZZP030000003oool0oooo00`0oooo2P3AcJT>0?ooo`0<0000003o
ool000000000002ZZZX000000:ZZZP3oool0ZZZZ0000002ZZZX0EEEE0P3oool0102ZZZX000000?oo
o`0000020?ooo`80ZZZZ0P3oool01P2ZZZX0oooo0?ooo`3oool000000?ooo`8000000P3oool01@1E
EED0ZZZZ0000002ZZZX0oooo0080000000D0ZZZZ000000000000ZZZZ0000000>0?ooo``0dLfY000;
0=7=Z@l0oooo0P0000020?ooo`<0000000<0ZZZZ0?ooo`2ZZZX00`1EEED30?ooo`0505EEE@2ZZZX0
000005EEE@3oool00P2ZZZX0103oool000000000002ZZZX30?ooo`0<0000001EEED0oooo05EEE@2Z
ZZX000000:ZZZP000000oooo0000003oool0EEEE0P00000?0?ooo`X0dLfY4`3oool00`2ZZZX0oooo
000000040?ooo`030000003oool0ZZZZ00@0ZZZZ00<0EEEE0?ooo`0000000`00000205EEE@D0ZZZZ
00d0oooo0000003oool0oooo0000003oool000000?ooo`2ZZZX0oooo0:ZZZP3oool0000000l0oooo
2P3AcJT?0?ooo`040000001EEED0000000000080oooo00<0EEEE0:ZZZP0000000P0000000`3oool0
EEEE0000000200000080ZZZZ00X0EEEE0?ooo`000000EEEE0?ooo`000000ZZZZ05EEE@2ZZZX0EEEE
0P00000205EEE@030?ooo`00000000000080ZZZZ00<0EEEE0:ZZZP3oool00P0000000`1EEED00000
0?ooo`0>0?ooo`X0dLfY3`3oool00`2ZZZX0EEEE05EEE@040:ZZZP80oooo102ZZZX20?ooo`<0ZZZZ
00<0EEEE0000003oool00P2ZZZX00`3oool0000005EEE@030:ZZZP040?ooo`1EEED0ZZZZ05EEE@80
ZZZZ00<000000?ooo`2ZZZX0102ZZZX00`1EEED000000?ooo`0>0?ooo`X0dLfY3`3oool01@2ZZZX0
00000:ZZZP000000oooo0080000000D0ZZZZ05EEE@2ZZZX0ZZZZ0000000205EEE@80oooo0P000000
102ZZZX000000000002ZZZX3000000030:ZZZP000000oooo0080oooo0P1EEED01@000000ZZZZ0:ZZ
ZP3oool0ZZZZ0080000000<0oooo0000001EEED00P00000?0?ooo``0dLfY000;0=7=ZA00oooo00D0
00000?ooo`3oool0000005EEE@03000000060?ooo`2ZZZX0ZZZZ0000001EEED0oooo0P2ZZZX01`3o
ool000000:ZZZP1EEED0ZZZZ0?ooo`1EEED00P0000020?ooo`040:ZZZP3oool0EEEE00000080ZZZZ
00T0oooo05EEE@000000000005EEE@000000oooo05EEE@000000403oool:0=7=ZA00oooo00H00000
0:ZZZP3oool0oooo05EEE@3oool205EEE@060000001EEED0oooo05EEE@3oool0EEEE0`2ZZZX03@3o
ool00000000000000000oooo0000001EEED0oooo0:ZZZP3oool0ZZZZ05EEE@3oool00`1EEED00`00
0000EEEE05EEE@050?ooo`030000003oool0oooo00h0oooo2P3AcJT@0?ooo`050000002ZZZX0EEEE
0:ZZZP1EEED00`2ZZZX00`1EEED0ZZZZ0:ZZZP0205EEE@80ZZZZ00D0oooo0000003oool000000:ZZ
ZP0205EEE@050:ZZZP3oool0oooo0000001EEED00P2ZZZX305EEE@030:ZZZP1EEED0ZZZZ0080ZZZZ
00D0EEEE0:ZZZP1EEED0ZZZZ0000000@0?ooo`X0dLfY403oool010000000EEEE0:ZZZP3oool70:ZZ
ZP030000001EEED0ZZZZ0080EEEE00H0ZZZZ05EEE@1EEED0ZZZZ05EEE@0000020:ZZZP0505EEE@2Z
ZZX0oooo05EEE@2ZZZX00P0000030:ZZZP0505EEE@2ZZZX0ZZZZ0:ZZZP3oool00P2ZZZX00`000000
oooo0?ooo`0>0?ooo`X0dLfY403oool00`000000ZZZZ000000020000000305EEE@000000oooo0080
EEEE00<0ZZZZ0000000000000P1EEED00`000000ZZZZ05EEE@020?ooo`0705EEE@3oool0oooo0?oo
o`1EEED0ZZZZ0000000205EEE@<000000P1EEED0102ZZZX0000005EEE@2ZZZX2000000030:ZZZP00
0000oooo00l0oooo303AcJT000/0dLfY4@3oool01@2ZZZX0EEEE05EEE@2ZZZX0EEEE0080ZZZZ101E
EED01P2ZZZX0EEEE05EEE@2ZZZX000000:ZZZP8000000P1EEED010000000oooo0:ZZZP00000305EE
E@030?ooo`1EEED0EEEE0080EEEE0P2ZZZX00`1EEED0oooo05EEE@0205EEEA40oooo2P3AcJTA0?oo
o`80000000L0oooo0000002ZZZX0oooo0:ZZZP3oool0ZZZZ0080oooo00P0000005EEE@1EEED0ZZZZ
0000002ZZZX0oooo05EEE@80ZZZZ00D0EEEE0?ooo`2ZZZX000000:ZZZP0205EEE@040:ZZZP3oool0
oooo0:ZZZP<0oooo00<0ZZZZ0000003oool00P00000A0?ooo`X0dLfY4@3oool030000000EEEE05EE
E@000000oooo0000001EEED000000?ooo`1EEED0000005EEE@80000000H0EEEE0?ooo`3oool0oooo
0000002ZZZX2000000<0oooo00@0EEEE000000000000oooo0P0000001@3oool00000000000000000
oooo00<0EEEE00<000000?ooo`3oool03`3oool:0=7=ZA40oooo00<0ZZZZ05EEE@2ZZZX00P2ZZZX0
0`1EEED0000000000004000000050:ZZZP3oool0oooo0:ZZZP0000000P1EEED01P2ZZZX0oooo05EE
E@1EEED000000:ZZZP80oooo00<0ZZZZ05EEE@0000000`0000001`2ZZZX0EEEE0:ZZZP1EEED0ZZZZ
05EEE@0000004@3oool:0=7=ZA40oooo00D0ZZZZ0?ooo`1EEED0EEEE0?ooo`020000000705EEE@3o
ool000000000003oool0000005EEE@020:ZZZP0605EEE@00000000000000002ZZZX000000P1EEED0
1@2ZZZX0oooo05EEE@000000oooo0080000000@0oooo05EEE@00000000000P3oool00`1EEED0oooo
0000000A0?ooo``0dLfY000;0=7=ZA80oooo00<0EEEE0?ooo`0000000P0000002P3oool0000005EE
E@1EEED000000:ZZZP1EEED000000?ooo`1EEED20?ooo`040000001EEED0EEEE00000080oooo0P1E
EED020000000EEEE0?ooo`000000oooo05EEE@000000ZZZZ0P0000000`2ZZZX0oooo05EEE@0B0?oo
o`X0dLfY4P3oool3000000050?ooo`2ZZZX0oooo0?ooo`000000103oool20:ZZZP8000001@2ZZZX3
000000040?ooo`2ZZZX0oooo00000080oooo00@000000?ooo`3oool0ZZZZ0P3oool200000180oooo
2P3AcJTB0?ooo`040000002ZZZX0ZZZZ05EEE@80ZZZZ0`1EEED01@3oool000000?ooo`000000EEEE
00@0ZZZZ00@0oooo05EEE@2ZZZX0EEEE0`2ZZZX010000000oooo05EEE@3oool305EEE@80ZZZZ00@0
EEEE0:ZZZP2ZZZX000004P3oool:0=7=ZA80oooo00D000000:ZZZP2ZZZX0oooo0:ZZZP0300000006
0:ZZZP00000000000:ZZZP3oool0EEEE0P3oool2000000040:ZZZP1EEED0000000000080oooo00@0
EEEE0?ooo`2ZZZX0ZZZZ100000020:ZZZP040?ooo`1EEED0ZZZZ00000180oooo2P3AcJTB0?ooo`06
0000002ZZZX0ZZZZ0000003oool0ZZZZ0P00000305EEE@80000000<0EEEE0000001EEED00P3oool0
1`2ZZZX0oooo0?ooo`3oool0EEEE0000003oool00`00000205EEE@8000000P3oool010000000EEEE
0:ZZZP00000B0?ooo``0dLfY000;0=7=ZA<0oooo00L000000:ZZZP2ZZZX0oooo0000002ZZZX0oooo
0080000000T0ZZZZ05EEE@3oool0ZZZZ05EEE@3oool0EEEE0?ooo`2ZZZX00P3oool01P000000oooo
05EEE@1EEED0oooo05EEE@80000000P0EEEE0?ooo`2ZZZX000000?ooo`2ZZZX0EEEE000001<0oooo
2P3AcJTC0?ooo`030000002ZZZX0ZZZZ00<0EEEE0`3oool205EEE@040?ooo`000000000005EEE@H0
000000D0EEEE000000000000oooo05EEE@040?ooo`<0EEEE00<0ZZZZ0?ooo`0000004`3oool:0=7=
ZA<0oooo00H0000005EEE@000000oooo0000003oool305EEE@050000003oool0ZZZZ0000001EEED0
0P00000205EEE@040:ZZZP1EEED0000000000080EEEE00T0ZZZZ0?ooo`3oool0EEEE0000001EEED0
oooo0000003oool00`00000C0?ooo`X0dLfY4`3oool010000000EEEE0:ZZZP1EEED30:ZZZP040?oo
o`000000ZZZZ0:ZZZP<0EEEE00<0ZZZZ0?ooo`3oool00P0000000`3oool0EEEE0:ZZZP0305EEE@03
0:ZZZP3oool0000000@0ZZZZ00@0EEEE0:ZZZP2ZZZX000004`3oool:0=7=ZA<0oooo00T000000:ZZ
ZP1EEED000000:ZZZP3oool0ZZZZ0000002ZZZX00P3oool01P000000ZZZZ0:ZZZP2ZZZX0000005EE
E@80000000@0EEEE0000002ZZZX0ZZZZ0P0000000`3oool0ZZZZ0:ZZZP020:ZZZP060?ooo`000000
000005EEE@2ZZZX000004`3oool<0=7=Z@002`3AcJTD0?ooo`030:ZZZP000000EEEE00<0EEEE0`00
00020?ooo`80000000<0EEEE0?ooo`0000000P1EEED010000000oooo05EEE@0000030?ooo`<00000
0P1EEED0103oool0EEEE0000001EEEDD0?ooo`X0dLfY503oool5000000040:ZZZP00000000000:ZZ
ZP80oooo00D0EEEE0?ooo`3oool0ZZZZ0?ooo`020:ZZZP030?ooo`2ZZZX0oooo00D0oooo00D00000
0?ooo`2ZZZX000000:ZZZP03000001@0oooo2P3AcJTE0?ooo`0305EEE@3oool0oooo0080oooo0P1E
EED20:ZZZP0905EEE@3oool0oooo0:ZZZP3oool0EEEE0:ZZZP000000EEEE0080ZZZZ00<0oooo0000
001EEED00P2ZZZX0201EEED0ZZZZ0?ooo`3oool0EEEE0?ooo`1EEED00000503oool:0=7=ZA@0oooo
00<0ZZZZ05EEE@2ZZZX00`0000020:ZZZP80000000D0ZZZZ0000002ZZZX0EEEE000000050:ZZZP05
05EEE@2ZZZX0EEEE0:ZZZP0000000P2ZZZX4000000030:ZZZP1EEED0000001@0oooo2P3AcJTD0?oo
o`030:ZZZP3oool0oooo0080000000L0ZZZZ000000000000000005EEE@000000EEEE0080ZZZZ0P3o
ool20:ZZZP030?ooo`1EEED0ZZZZ0080ZZZZ00H0000005EEE@00000000000?ooo`2ZZZX200000080
oooo00<000000?ooo`3oool04P3oool<0=7=Z@002`3AcJTE0?ooo`0805EEE@3oool0000005EEE@2Z
ZZX0oooo0000001EEED20000000505EEE@000000EEEE0?ooo`0000000P1EEED00`000000oooo05EE
E@04000000050?ooo`000000EEEE0:ZZZP1EEED00P3oool00`1EEED0oooo0?ooo`0C0?ooo`X0dLfY
5@3oool2000000080?ooo`2ZZZX0EEEE0:ZZZP000000oooo0000003oool20:ZZZP80000000@0ZZZZ
000000000000ZZZZ0P0000020:ZZZP080?ooo`000000oooo0000003oool0EEEE0:ZZZP3oool20000
01D0oooo2P3AcJTE0?ooo`80000000<0EEEE0:ZZZP2ZZZX00P0000002`3oool0ZZZZ05EEE@1EEED0
ZZZZ05EEE@000000oooo05EEE@2ZZZX0oooo0080EEEE0P2ZZZX00`1EEED0ZZZZ05EEE@0200000080
ZZZZ00<0EEEE0000000000005@3oool:0=7=ZAD0oooo00L000000:ZZZP2ZZZX0EEEE0:ZZZP1EEED0
ZZZZ008000000P2ZZZX30?ooo`D0ZZZZ0P3oool20:ZZZP8000000`2ZZZX205EEE@030:ZZZP000000
oooo01@0oooo2P3AcJTE0?ooo`030000002ZZZX0000000<0EEEE00P0oooo00000000000000000?oo
o`000000ZZZZ0?ooo`@0ZZZZ00@0oooo0:ZZZP000000EEEE0P0000000`1EEED0oooo0:ZZZP0305EE
E@030:ZZZP000000oooo01@0oooo303AcJT000/0dLfY5P3oool010000000oooo0?ooo`00000205EE
E@050000003oool0ZZZZ05EEE@3oool00`1EEED01P2ZZZX0oooo05EEE@2ZZZX0EEEE0?ooo`80ZZZZ
0P3oool01P1EEED000000000003oool0EEEE000001H0oooo2P3AcJTF0?ooo`050000002ZZZX00000
0:ZZZP1EEED00`3oool60000000405EEE@000000000005EEE@@000000`3oool01@000000ZZZZ0000
003oool0000001H0oooo2P3AcJTF0?ooo`060000001EEED000000000003oool000000`1EEED20000
000305EEE@2ZZZX0oooo0080000000<0oooo05EEE@1EEED00P00000205EEE@030?ooo`000000oooo
0080000000<0oooo0000003oool05@3oool:0=7=ZAH0oooo00<0000005EEE@2ZZZX00P0000000`3o
ool0ZZZZ0:ZZZP030:ZZZP80000000<0ZZZZ0000000000000P2ZZZX00`000000ZZZZ05EEE@030:ZZ
ZP030?ooo`00000000000080ZZZZ00<000000?ooo`3oool0503oool:0=7=ZAH0oooo00@000000:ZZ
ZP2ZZZX000000P3oool30:ZZZP80oooo1P000000102ZZZX000000?ooo`3oool20:ZZZP80oooo00D0
ZZZZ0000002ZZZX0ZZZZ0000000F0?ooo``0dLfY000;0=7=ZAL0oooo0P000000201EEED0oooo05EE
E@000000oooo05EEE@3oool000000P1EEED00`3oool000000:ZZZP020?ooo`0405EEE@000000EEEE
05EEE@80oooo00@0EEEE0000001EEED00000603oool:0=7=ZAL0oooo00@000000?ooo`3oool00000
0`2ZZZX305EEE@0=0000001EEED0EEEE0000002ZZZX0EEEE0:ZZZP000000EEEE0?ooo`1EEED0ZZZZ
0?ooo`020:ZZZQX0oooo2P3AcJTG0?ooo`80000000@0EEEE000000000000ZZZZ0P1EEED30?ooo`D0
EEEE00@0ZZZZ0?ooo`3oool0oooo0P1EEED01@3oool000000000001EEED0000001P0oooo2P3AcJTG
0?ooo`040000002ZZZX0EEEE05EEE@@0ZZZZ0`0000020:ZZZP8000000P2ZZZX2000000030?ooo`2Z
ZZX0ZZZZ00<0ZZZZ00<0EEEE0:ZZZP3oool05`3oool:0=7=ZAL0oooo00H000000:ZZZP000000ZZZZ
0000003oool30000000305EEE@2ZZZX0000000D0000000<0ZZZZ05EEE@3oool00P0000001@3oool0
000005EEE@000000ZZZZ01P0oooo303AcJT000/0dLfY603oool02@1EEED0oooo000000000000oooo
05EEE@000000EEEE0?ooo`0205EEE@070?ooo`00000000000?ooo`2ZZZX0EEEE0?ooo`0200000080
EEEE00@000000:ZZZP3oool0EEEE603oool:0=7=ZAP0oooo0P0000000`1EEED0oooo000000020000
0080oooo00<0ZZZZ0000000000000P2ZZZX01@000000ZZZZ0:ZZZP3oool0ZZZZ00<000000P3oool2
000001P0oooo2P3AcJTH0?ooo`040000003oool0oooo0?ooo`80EEEE0`2ZZZX00`1EEED000000000
0003000000050:ZZZP1EEED0ZZZZ05EEE@2ZZZX00P1EEED0103oool0EEEE0?ooo`00000H0?ooo`X0
dLfY603oool00`000000ZZZZ0:ZZZP04000000<0ZZZZ00<0EEEE0:ZZZP2ZZZX01P2ZZZX400000003
05EEE@2ZZZX0000001P0oooo2P3AcJTH0?ooo`030000002ZZZX0EEEE00<0oooo00@000000:ZZZP1E
EED0EEEE1@2ZZZX00`3oool0EEEE05EEE@02000000<0oooo00<0EEEE0:ZZZP000000603oool<0=7=
Z@002`3AcJTI0?ooo`030000002ZZZX0ZZZZ0080oooo00L0ZZZZ0?ooo`3oool0oooo0000001EEED0
oooo0080EEEE00D000000?ooo`3oool000000:ZZZP020?ooo`030:ZZZP1EEED0000001T0oooo2P3A
cJTI0?ooo`030000002ZZZX0oooo0080oooo00D0000005EEE@1EEED0oooo05EEE@05000000060?oo
o`1EEED0oooo0000003oool000000P3oool00`000000oooo0?ooo`0G0?ooo`X0dLfY6@3oool00`00
0000ZZZZ05EEE@0205EEE@80000000D0EEEE000000000000oooo05EEE@030?ooo`090000001EEED0
00000000001EEED0ZZZZ05EEE@2ZZZX0000001T0oooo2P3AcJTI0?ooo`030000001EEED0ZZZZ00<0
ZZZZ00@0EEEE0:ZZZP2ZZZX0ZZZZ100000000`1EEED0ZZZZ0:ZZZP030:ZZZP040?ooo`2ZZZX0ZZZZ
000001T0oooo2P3AcJTI0?ooo`040000002ZZZX000000:ZZZP<000000P2ZZZX600000080ZZZZ00<0
oooo0000000000000P0000000`2ZZZX000000?ooo`0H0?ooo``0dLfY000;0=7=ZAX0oooo0P000000
1P1EEED0oooo0?ooo`000000oooo0:ZZZP80EEEE00L0000005EEE@1EEED000000:ZZZP3oool00000
0080oooo0P00000K0?ooo`X0dLfY6P3oool00`000000oooo0?ooo`020?ooo`0305EEE@3oool00000
00D0000000<0oooo0000003oool0803oool:0=7=ZAX0oooo00<000000?ooo`0000000`3oool205EE
E@060000001EEED0EEEE0000001EEED000000P1EEED30?ooo`0305EEE@3oool0oooo01X0oooo2P3A
cJTJ0?ooo`030000002ZZZX0ZZZZ0080000000H0oooo0:ZZZP2ZZZX0ZZZZ0000002ZZZX2000000<0
ZZZZ0`0000000`1EEED0ZZZZ0?ooo`0J0?ooo`X0dLfY6P3oool01P000000ZZZZ0:ZZZP000000ZZZZ
00000080ZZZZ1P0000020:ZZZP050000002ZZZX000000000002ZZZX06`3oool<0=7=Z@002`3AcJTK
0?ooo`0305EEE@3oool000000080EEEE00@0oooo000000000000EEEE0P0000000`1EEED000000000
00020?ooo`0405EEE@000000oooo05EEEA/0oooo2P3AcJTK0?ooo`060000003oool000000000002Z
ZZX0oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo00@000006`3oool:0=7=
ZA/0oooo00D000000:ZZZP2ZZZX0EEEE0:ZZZP0205EEE@040?ooo`2ZZZX0ZZZZ0?ooo`80ZZZZ0P1E
EED01@2ZZZX0EEEE0:ZZZP2ZZZX0000001/0oooo2P3AcJTK0?ooo`050000001EEED0ZZZZ0?ooo`2Z
ZZX01@0000000`1EEED0000000000002000000050:ZZZP3oool0ZZZZ0:ZZZP0000006`3oool:0=7=
ZA/0oooo00D0000005EEE@2ZZZX000000?ooo`0205EEE@D0ZZZZ00D0oooo05EEE@1EEED0oooo0000
00020:ZZZP030000003oool0oooo01T0oooo303AcJT000/0dLfY703oool0201EEED0ZZZZ05EEE@3o
ool0ZZZZ0000001EEED000000P3oool010000000ZZZZ0000002ZZZX205EEE@030:ZZZP3oool0oooo
01/0oooo2P3AcJTL0?ooo`@0000000X0ZZZZ00000000000000000?ooo`1EEED000000?ooo`000000
ZZZZ0`00000M0?ooo`X0dLfY703oool010000000oooo05EEE@1EEED20?ooo`8000000P3oool20000
00<0oooo00<0EEEE0?ooo`3oool0703oool:0=7=ZA`0oooo00<000000:ZZZP1EEED00`000000102Z
ZZX000000000002ZZZX4000000030:ZZZP1EEED0ZZZZ01d0oooo2P3AcJTL0?ooo`030000002ZZZX0
oooo00<000000`3oool00`000000oooo0000000200000080oooo00<0ZZZZ0?ooo`3oool06`3oool<
0=7=Z@002`3AcJTM0?ooo`<0000000<0oooo0000001EEED0103oool0102ZZZX000000?ooo`1EEED2
000001d0oooo2P3AcJTM0?ooo`040000003oool000000?ooo`80EEEE00H0ZZZZ0?ooo`3oool0ZZZZ
0?ooo`1EEED30?ooo`030000003oool0oooo01/0oooo2P3AcJTM0?ooo`040000002ZZZX0EEEE05EE
E@80oooo00L0ZZZZ05EEE@2ZZZX0ZZZZ05EEE@3oool0EEEE0080ZZZZ00<000000?ooo`3oool06`3o
ool:0=7=ZAd0oooo00@000000:ZZZP2ZZZX0oooo0P2ZZZX205EEE@080?ooo`1EEED0ZZZZ0:ZZZP3o
ool0EEEE0:ZZZP00000M0?ooo`X0dLfY7@3oool00`000000ZZZZ000000020?ooo`060000002ZZZX0
EEEE0000002ZZZX000000P3oool00`000000ZZZZ0000000M0?ooo``0dLfY000;0=7=ZAh0oooo00@0
EEEE0:ZZZP00000000001@3oool3000000030?ooo`1EEED0oooo01d0oooo2P3AcJTN0?ooo`040000
003oool0oooo0?ooo`80000000@0oooo000000000000ZZZZ0P3oool2000001h0oooo2P3AcJTN0?oo
o`060000001EEED0EEEE0:ZZZP000000oooo0P000000103oool0ZZZZ0:ZZZP1EEED2000001h0oooo
2P3AcJTN0?ooo`0;0000001EEED0ZZZZ05EEE@2ZZZX0EEEE0?ooo`000000EEEE0:ZZZP1EEED00P2Z
ZZX00`000000oooo0?ooo`0L0?ooo`X0dLfY7P3oool00`000000EEEE0000000305EEE@030:ZZZP3o
ool0EEEE0080EEEE00<000000:ZZZP0000007P3oool<0=7=Z@002`3AcJTO0?ooo`0;05EEE@2ZZZX0
000005EEE@3oool0EEEE0:ZZZP3oool0EEEE0000002ZZZX0803oool:0=7=ZAl0oooo0`00000205EE
E@80oooo0P1EEED200000200oooo2P3AcJTO0?ooo`050000002ZZZX0ZZZZ0:ZZZP1EEED00P2ZZZX0
101EEED0ZZZZ0:ZZZP2ZZZXP0?ooo`X0dLfY7`3oool01P000000ZZZZ05EEE@3oool0ZZZZ000000<0
ZZZZ00<0EEEE0:ZZZP3oool07`3oool:0=7=ZAl0oooo00<000000:ZZZP3oool00P0000001P3oool0
0000000000000000oooo0:ZZZR00oooo303AcJT000/0dLfY803oool20000000405EEE@0000000000
0?ooo`@00000803oool:0=7=ZB00oooo00<000000?ooo`2ZZZX01P3oool00`000000oooo0?ooo`0N
0?ooo`X0dLfY803oool4000000040?ooo`000000000005EEE@800000803oool:0=7=ZB00oooo00@0
00000:ZZZP2ZZZX0EEEE0P2ZZZX205EEE@030:ZZZP000000oooo01l0oooo2P3AcJTP0?ooo`0:0000
002ZZZX0EEEE0:ZZZP1EEED000000:ZZZP000000ZZZZ00000200oooo303AcJT000/0dLfY8@3oool0
0`1EEED0oooo0:ZZZP02000000030:ZZZP3oool0EEEE0240oooo2P3AcJTQ0?ooo`040000003oool0
EEEE0?ooo`80EEEE0P00000Q0?ooo`X0dLfY8@3oool01@000000EEEE0?ooo`1EEED0ZZZZ0080oooo
00<000000?ooo`3oool07`3oool:0=7=ZB40oooo00<0000005EEE@2ZZZX00P0000020:ZZZP030000
003oool0oooo01l0oooo2P3AcJTQ0?ooo`080000001EEED0EEEE0:ZZZP3oool0EEEE0:ZZZP00000Q
0?ooo``0dLfY000;0=7=ZB80oooo00D0EEEE0:ZZZP3oool0oooo0:ZZZP0S0?ooo`X0dLfY8P3oool2
000000030?ooo`000000000002<0oooo2P3AcJTR0?ooo`80000000<0EEEE0?ooo`0000008`3oool:
0=7=ZB80oooo00D000000:ZZZP2ZZZX0EEEE0:ZZZP0S0?ooo`X0dLfY8P3oool01@000000ZZZZ05EE
E@3oool0ZZZZ02<0oooo303AcJT000/0dLfY8`3oool010000000ZZZZ00000000000S0?ooo`X0dLfY
8`3oool010000000oooo0?ooo`00000S0?ooo`X0dLfY8`3oool010000000ZZZZ0?ooo`00000S0?oo
o`X0dLfY8`3oool010000000EEEE0:ZZZP00000S0?ooo`X0dLfY8`3oool2000000030:ZZZP000000
oooo0280oooo303AcJT000/0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2Z
ZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2Z
ZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo``0dLfY003o0=7=ZK80
dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY000;0=7=Z@07
0?ooo`00000000000000001EEED0ZZZZ0?ooo`02000000030:ZZZP3oool0oooo00D0000000L0oooo
05EEE@3oool000000:ZZZP000000ZZZZ008000000`3oool2000000050?ooo`1EEED0EEEE0000001E
EED00P3oool01@1EEED0ZZZZ05EEE@1EEED0oooo00<000000P3oool400000080ZZZZ00D0oooo05EE
E@00000000000?ooo`02000000040:ZZZP3oool0oooo0?ooo`8000000P2ZZZX30000000305EEE@3o
ool0dLfY00T0dLfY00<0oooo05EEE@0000000P0000000`1EEED000000?ooo`020?ooo`80000000H0
oooo000000000000EEEE0?ooo`1EEED2000000030?ooo`000000oooo0080000000H0ZZZZ0000003o
ool0oooo0000001EEED40?ooo`0405EEE@3oool0000005EEE@@0oooo00L0EEEE000000000000oooo
0000002ZZZX000000080oooo00@000000?ooo`00000000000P3oool00`1EEED00000000000030000
00<0oooo0P1EEED01@3oool000000000001EEED0oooo00X0dLfY0`3oool00`000000ZZZZ00000003
05EEE@040?ooo`1EEED0000005EEE@@0ZZZZ00T0oooo0:ZZZP1EEED0EEEE0000001EEED0ZZZZ0?oo
o`2ZZZX00P00000205EEE@030000001EEED0000000<000000P1EEED04`000000ZZZZ000000000000
oooo0000001EEED0ZZZZ0000003oool0ZZZZ0?ooo`000000EEEE0000002ZZZX0EEEE0:ZZZP1EEED0
102ZZZX0101EEED0000005EEE@2ZZZX305EEE@060000001EEED000000?ooo`1EEED0oooo2P3AcJT0
1`3oool0EEEE0000002ZZZX0oooo0000002ZZZX00P1EEED00`000000ZZZZ000000020:ZZZP060000
002ZZZX000000?ooo`2ZZZX0EEEE0P3oool00`1EEED000000:ZZZP020?ooo`070:ZZZP3oool00000
0:ZZZP3oool000000:ZZZP020?ooo`060000003oool0oooo0000002ZZZX000000P2ZZZX200000003
0:ZZZP000000oooo0080ZZZZ00H0EEEE0?ooo`3oool0EEEE0:ZZZP3oool3000000050:ZZZP000000
00000:ZZZP0000000P1EEED2000000050?ooo`2ZZZX0000005EEE@3oool02P3AcJT30?ooo`<0ZZZZ
0P1EEED00`2ZZZX0000005EEE@030:ZZZP0;05EEE@2ZZZX0ZZZZ0:ZZZP1EEED0oooo05EEE@3oool0
00000?ooo`2ZZZX00P1EEED01@3oool0EEEE0:ZZZP3oool0EEEE008000000`1EEED00`2ZZZX0EEEE
0000000200000080oooo00<0ZZZZ0000003oool00P1EEED03`2ZZZX0EEEE0000003oool000000?oo
o`1EEED0oooo0:ZZZP000000EEEE0:ZZZP3oool0ZZZZ05EEE@020:ZZZP0305EEE@2ZZZX0ZZZZ0080
ZZZZ00<0oooo05EEE@3oool0303AcJT000/0dLfY00T0oooo0:ZZZP2ZZZX0oooo0000001EEED00000
0?ooo`2ZZZX00`0000001@2ZZZX0oooo000000000000oooo0080000000<0EEEE0:ZZZP0000000P00
00001@3oool00000000000000000oooo0080EEEE00@0000005EEE@000000ZZZZ103oool200000004
05EEE@3oool0EEEE05EEE@@000000P3oool2000000050?ooo`1EEED000000000003oool00P000000
103oool000000000000000020:ZZZP060?ooo`1EEED0EEEE0000003oool0ZZZZ0P3oool:0=7=Z@03
0?ooo`000000oooo0080000000<0oooo0000000000000`0000000`3oool00000000000040?ooo`80
000000<0oooo0000000000000P1EEED300000080ZZZZ1P3oool2000000H0oooo00H0ZZZZ05EEE@00
0000oooo0000001EEED3000000030:ZZZP00000000000080oooo00D000000?ooo`00000000000?oo
o`0400000080oooo0P0000030?ooo`X0dLfY00D0oooo0000001EEED0oooo0:ZZZP030000000805EE
E@2ZZZX0ZZZZ0:ZZZP3oool0ZZZZ0000002ZZZX2000000040?ooo`2ZZZX0ZZZZ0?ooo`80ZZZZ00D0
00000:ZZZP1EEED000000:ZZZP020?ooo`80000000<0ZZZZ05EEE@1EEED00P0000001@1EEED00000
0:ZZZP000000EEEE0080oooo0140EEEE0000001EEED0ZZZZ0000003oool0ZZZZ0?ooo`1EEED0ZZZZ
0?ooo`1EEED000000?ooo`000000ZZZZ0?ooo`020:ZZZP030000001EEED00000008000000P3oool0
0`1EEED0oooo0?ooo`0:0=7=Z@070?ooo`000000oooo0000002ZZZX000000:ZZZP020?ooo`060000
003oool0ZZZZ0?ooo`000000ZZZZ0P0000000`2ZZZX000000?ooo`030?ooo`040:ZZZP000000oooo
0?ooo`80000000<0ZZZZ05EEE@2ZZZX00P0000030:ZZZP030000002ZZZX000000080000000L0ZZZZ
05EEE@2ZZZX0ZZZZ0000001EEED0oooo00800000103oool01P000000ZZZZ000000000000ZZZZ0000
0080ZZZZ00@0oooo0000003oool0oooo0P0000000`2ZZZX000000?ooo`020?ooo`X0dLfY00<0oooo
0000000000001000000305EEE@030?ooo`2ZZZX0EEEE0080000000<0ZZZZ05EEE@0000000P3oool0
201EEED0ZZZZ000000000000EEEE0000001EEED000000P2ZZZX0101EEED0ZZZZ0000002ZZZX20?oo
o`030:ZZZP000000oooo0080ZZZZ0P0000002P1EEED0ZZZZ0:ZZZP000000EEEE0000001EEED0ZZZZ
0000002ZZZX30?ooo`030:ZZZP1EEED0ZZZZ00<0000000<0ZZZZ0?ooo`3oool00`1EEED010000000
EEEE0000000000020?ooo``0dLfY000;0=7=Z@<0oooo00<0EEEE0000000000000P2ZZZX0303oool0
ZZZZ000000000000ZZZZ0?ooo`000000ZZZZ0?ooo`000000ZZZZ05EEE@80000000D0ZZZZ0?ooo`3o
ool0oooo0:ZZZP020?ooo`80ZZZZ0`3oool6000000<0oooo0P2ZZZX60?ooo`040:ZZZP0000000000
05EEE@80ZZZZ00@0oooo0:ZZZP000000oooo0`0000020?ooo`050:ZZZP00000000000000001EEED0
0`3oool:0=7=Z@<0oooo0P0000020?ooo`030:ZZZP000000oooo00<0oooo00<000000?ooo`3oool0
103oool00`2ZZZX000000:ZZZP05000000040?ooo`2ZZZX0EEEE0:ZZZP<0000000<0oooo00000000
00000P3oool30000000505EEE@2ZZZX000000000003oool00`0000000`2ZZZX00000000000060?oo
o`8000000`3oool00`000000ZZZZ0?ooo`020?ooo`040000003oool0oooo0?ooo`X0dLfY0`3oool2
0000000505EEE@000000oooo05EEE@2ZZZX00P3oool01@1EEED0oooo0?ooo`3oool0ZZZZ0080oooo
00@000000?ooo`2ZZZX0oooo0P0000020?ooo`80000000L0ZZZZ0000002ZZZX0ZZZZ0000001EEED0
00000080EEEE00`0000005EEE@000000ZZZZ05EEE@000000ZZZZ05EEE@000000EEEE0?ooo`000002
0?ooo`040:ZZZP00000000000?ooo`80ZZZZ00@000000?ooo`3oool0EEEE0P3oool01@000000EEEE
0?ooo`3oool0EEEE008000000`3oool:0=7=Z@<0oooo00@000000?ooo`00000000000P2ZZZX0103o
ool000000?ooo`3oool200000080EEEE00`0ZZZZ00000000000000000?ooo`2ZZZX000000:ZZZP00
0000ZZZZ0000002ZZZX205EEE@<0000000@0EEEE0:ZZZP000000EEEE0P2ZZZX2000000030?ooo`1E
EED0EEEE0080000000H0oooo0000002ZZZX000000:ZZZP3oool40000000405EEE@2ZZZX000000000
0080oooo00@000000:ZZZP2ZZZX0ZZZZ100000030?ooo`X0dLfY0`3oool20000000505EEE@2ZZZX0
00000:ZZZP0000000P2ZZZX40000000605EEE@2ZZZX0ZZZZ0:ZZZP1EEED000000P1EEED20:ZZZP03
0000001EEED0EEEE008000000P1EEED00`3oool0ZZZZ0:ZZZP020?ooo`050:ZZZP1EEED0oooo05EE
E@2ZZZX00`00000205EEE@<0ZZZZ00<0EEEE0000001EEED00P2ZZZX00`000000EEEE05EEE@020000
000505EEE@2ZZZX0ZZZZ0000002ZZZX00P0000000`1EEED00000000000030?ooo``0dLfY000;0=7=
Z@@0oooo00D0ZZZZ0?ooo`000000ZZZZ000000020:ZZZP060?ooo`00000000000000003oool00000
0P1EEED00`000000oooo0:ZZZP05000000030:ZZZP000000ZZZZ00@0000000@0oooo0000003oool0
ZZZZ1P0000030:ZZZPD0000000<0ZZZZ0000000000000P1EEED01P000000oooo000000000000ZZZZ
0?ooo`80ZZZZ00D000000:ZZZP000000oooo0:ZZZP040?ooo`X0dLfY103oool0101EEED000000000
001EEED40?ooo`80EEEE0P0000002P1EEED0000005EEE@000000oooo05EEE@3oool000000:ZZZP00
000305EEE@030?ooo`00000000000080EEEE0P3oool00`1EEED0oooo0?ooo`0305EEE@030?ooo`00
0000oooo0080EEEE0P000000102ZZZX000000?ooo`1EEED20000000305EEE@000000EEEE00800000
00<0EEEE0?ooo`3oool00`3oool0101EEED000000000001EEED40?ooo`X0dLfY1P3oool205EEE@80
ZZZZ00@000000:ZZZP2ZZZX0ZZZZ0P0000001`2ZZZX0000005EEE@3oool0EEEE0000002ZZZX00P00
00020:ZZZP80000000<0ZZZZ0?ooo`1EEED00P2ZZZX00`3oool0ZZZZ0:ZZZP020:ZZZP060?ooo`2Z
ZZX0ZZZZ0:ZZZP3oool0ZZZZ0P0000020:ZZZP040000002ZZZX0ZZZZ00000080oooo00D0EEEE0?oo
o`2ZZZX0ZZZZ000000030:ZZZP070000003oool0ZZZZ05EEE@000000oooo05EEE@040?ooo`X0dLfY
1@3oool02P000000ZZZZ0000003oool000000:ZZZP1EEED0ZZZZ05EEE@0000020?ooo`80000000@0
oooo0000002ZZZX0ZZZZ0`00000305EEE@030?ooo`2ZZZX0EEEE0080000000@0ZZZZ0?ooo`3oool0
00000P3oool20000000305EEE@2ZZZX0oooo0080EEEE00@0oooo000000000000EEEE0P2ZZZX01`00
0000oooo000000000000oooo0:ZZZP0000000`1EEED20:ZZZP050?ooo`00000000000000001EEED0
103oool:0=7=Z@H0oooo00H0ZZZZ05EEE@1EEED0000005EEE@0000020:ZZZP80oooo0P2ZZZX01000
0000oooo0?ooo`1EEED20000000805EEE@000000ZZZZ0:ZZZP3oool0EEEE0?ooo`2ZZZX200000005
0:ZZZP3oool000000000003oool010000000103oool0EEEE0:ZZZP2ZZZX200000080EEEE00H00000
05EEE@2ZZZX0oooo0000003oool20:ZZZP060?ooo`2ZZZX000000000001EEED0oooo0P1EEED00`2Z
ZZX0oooo05EEE@040?ooo``0dLfY000;0=7=Z@@0oooo00H000000?ooo`3oool0oooo0000002ZZZX2
000000030:ZZZP3oool0ZZZZ0080ZZZZ00<0oooo0:ZZZP3oool00P0000020:ZZZP040000003oool0
ZZZZ05EEE@@0ZZZZ00@000000?ooo`00000000000P3oool2000000030?ooo`000000oooo0080ZZZZ
00L0oooo05EEE@000000oooo0000003oool0ZZZZ0080000000L0oooo0:ZZZP3oool0ZZZZ0000002Z
ZZX0oooo00D0000000<0oooo05EEE@3oool01@3oool:0=7=Z@@0oooo00<000000?ooo`0000001P3o
ool00`2ZZZX0oooo0:ZZZP030?ooo`0D0000003oool0ZZZZ0?ooo`000000oooo05EEE@3oool00000
0?ooo`000000ZZZZ0?ooo`000000oooo0000002ZZZX000000?ooo`2ZZZX20?ooo`80000000X0ZZZZ
0000003oool000000?ooo`1EEED0oooo0000003oool0ZZZZ0P0000001P3oool0EEEE0?ooo`2ZZZX0
oooo0:ZZZPH0oooo00<000000?ooo`3oool0103oool:0=7=Z@@0oooo00H0000005EEE@3oool0ZZZZ
05EEE@3oool30:ZZZP050000001EEED0EEEE0000002ZZZX00`3oool20:ZZZP030000001EEED0EEEE
00D0EEEE0P2ZZZX605EEE@040:ZZZP1EEED0ZZZZ0:ZZZP80EEEE00<0000005EEE@1EEED00`1EEED2
0:ZZZP<0oooo00H0ZZZZ0000001EEED0EEEE0000001EEED20:ZZZP050000001EEED0ZZZZ0?ooo`1E
EED01@3oool:0=7=Z@@0oooo00D0000005EEE@00000000000?ooo`0205EEE@80oooo00T000000?oo
o`2ZZZX0ZZZZ0000002ZZZX0EEEE0000002ZZZX00P3oool2000000@0ZZZZ00@000000?ooo`000000
00000P1EEED010000000ZZZZ05EEE@3oool2000000030?ooo`000000ZZZZ00<0ZZZZ0`000000303o
ool0ZZZZ05EEE@1EEED0ZZZZ0000002ZZZX000000?ooo`000000ZZZZ0?ooo`80EEEE00@0oooo0000
00000000EEEE1@3oool:0=7=Z@@0oooo0P0000003P1EEED0000005EEE@1EEED0ZZZZ0?ooo`2ZZZX0
EEEE0:ZZZP3oool0000005EEE@2ZZZX0EEEE0P0000020:ZZZP80oooo0`0000001@2ZZZX000000?oo
o`1EEED000000080EEEE00D0ZZZZ05EEE@1EEED0oooo0000000205EEE@050000002ZZZX0EEEE0000
001EEED00P3oool20:ZZZP80000000<0EEEE0:ZZZP2ZZZX00P0000001@2ZZZX0EEEE0:ZZZP3oool0
ZZZZ0080EEEE0`0000050?ooo``0dLfY000;0=7=Z@H0oooo00H0ZZZZ0?ooo`00000000000?ooo`1E
EED30?ooo`0505EEE@2ZZZX0oooo0000002ZZZX00P0000020:ZZZP@00000102ZZZX70000000405EE
E@00000000000?ooo`80ZZZZ00<0oooo0000001EEED00P0000001@3oool0ZZZZ000000000000ZZZZ
0080000000<0ZZZZ0?ooo`3oool00P3oool01P1EEED0oooo000000000000oooo0:ZZZPH0oooo2P3A
cJT70?ooo`0:0000003oool000000:ZZZP000000ZZZZ05EEE@3oool0ZZZZ00000080EEEE0P000000
1@3oool000000:ZZZP000000oooo00<0ZZZZ00<0EEEE0000001EEED0101EEED00`2ZZZX0oooo05EE
E@0305EEE@0:0?ooo`000000EEEE0?ooo`2ZZZX000000?ooo`000000ZZZZ00000080oooo00L00000
05EEE@3oool0000005EEE@3oool0EEEE0080000000<0ZZZZ0000003oool00P0000060?ooo`X0dLfY
1P3oool2000000<0EEEE00<000000:ZZZP3oool01P2ZZZX01`3oool0ZZZZ000000000000oooo05EE
E@0000000P1EEED01@000000oooo05EEE@000000oooo00<0EEEE0140ZZZZ05EEE@000000oooo0000
001EEED0oooo0000002ZZZX0EEEE0?ooo`1EEED0oooo05EEE@000000ZZZZ05EEE@040:ZZZP080?oo
o`2ZZZX0oooo0?ooo`000000EEEE0?ooo`1EEED2000000H0oooo2P3AcJT60?ooo`030:ZZZP000000
000000<000000`2ZZZX03`000000oooo000000000000ZZZZ0000003oool0ZZZZ0?ooo`000000ZZZZ
0000002ZZZX000000?ooo`03000000030?ooo`000000ZZZZ00<0ZZZZ0P3oool3000000090?ooo`00
0000ZZZZ0000002ZZZX000000?ooo`2ZZZX0oooo0080ZZZZ0P000000103oool000000:ZZZP2ZZZX7
000000H0oooo2P3AcJT60?ooo`80000000@0EEEE0000001EEED000000P3oool30000000<0:ZZZP00
0000ZZZZ05EEE@2ZZZX0EEEE0000002ZZZX0oooo05EEE@2ZZZX0EEEE0`0000002@2ZZZX0oooo0000
00000000ZZZZ0?ooo`000000ZZZZ0?ooo`020:ZZZP<0000000<0ZZZZ0?ooo`3oool00P2ZZZX0101E
EED0ZZZZ0:ZZZP2ZZZX3000000080?ooo`000000oooo05EEE@000000EEEE0000001EEED2000000H0
oooo303AcJT000/0dLfY1P3oool01@000000oooo05EEE@3oool0EEEE00D0000000H0EEEE0?ooo`00
0000ZZZZ0?ooo`2ZZZX2000000030:ZZZP3oool0oooo0080000000@0ZZZZ000000000000ZZZZ0P3o
ool01`000000oooo0:ZZZP000000ZZZZ0?ooo`2ZZZX00P0000001P2ZZZX000000000002ZZZX0oooo
0:ZZZP80000000@0ZZZZ0000002ZZZX000000P1EEED50000000305EEE@3oool0EEEE00P0oooo2P3A
cJT60?ooo`80EEEE00D000000?ooo`000000EEEE000000020?ooo`050000001EEED0oooo0:ZZZP3o
ool00`0000001@1EEED0000005EEE@1EEED0oooo00<0ZZZZ00<000000?ooo`3oool00P3oool01000
0000ZZZZ0?ooo`0000030?ooo`80ZZZZ00H000000?ooo`000000EEEE0000003oool2000000030:ZZ
ZP3oool0ZZZZ0080EEEE0`3oool205EEE@<0000000<0EEEE0?ooo`3oool01@3oool:0=7=Z@H0oooo
00@0EEEE0?ooo`3oool0EEEE0P0000000`2ZZZX0EEEE05EEE@030:ZZZP030000003oool0EEEE0080
EEEE00<000000:ZZZP2ZZZX00P0000020?ooo`0405EEE@00000000000:ZZZP80oooo0P0000000`3o
ool0ZZZZ0:ZZZP020000000405EEE@3oool00000000000<0ZZZZ00P0000005EEE@1EEED0ZZZZ0?oo
o`000000EEEE0:ZZZP<0EEEE00@0ZZZZ00000000000000002@3oool:0=7=Z@H0oooo0P1EEED30000
00070:ZZZP00000000000000002ZZZX0000005EEE@0300000080ZZZZ00<0EEEE0:ZZZP0000000P00
00001P3oool0000005EEE@1EEED000000:ZZZPD000000P2ZZZX20000000805EEE@00000000000000
003oool000000:ZZZP1EEED20:ZZZP<0000000<0ZZZZ0000000000000`0000001@2ZZZX000000:ZZ
ZP000000EEEE00L0oooo2P3AcJT60?ooo`0505EEE@3oool0oooo0:ZZZP3oool00P1EEED00`2ZZZX0
000005EEE@0205EEE@040:ZZZP1EEED0ZZZZ0:ZZZP80EEEE0`0000020:ZZZP80EEEE00<0ZZZZ0000
003oool00P2ZZZX01`1EEED000000:ZZZP000000oooo0000002ZZZX00P1EEED00`3oool0ZZZZ0000
0002000000050?ooo`1EEED0ZZZZ0:ZZZP1EEED00P2ZZZX0201EEED0ZZZZ0000002ZZZX0000005EE
E@3oool0ZZZZ2@3oool<0=7=Z@002`3AcJT70?ooo`0:05EEE@00000000000000001EEED0ZZZZ0?oo
o`000000oooo0:ZZZP80oooo00<0EEEE0000002ZZZX00`0000020:ZZZP040000002ZZZX0ZZZZ0:ZZ
ZP8000000P2ZZZX010000000oooo0?ooo`0000020:ZZZP060000003oool0ZZZZ0:ZZZP3oool00000
0P2ZZZX00`000000oooo000000020:ZZZP0405EEE@3oool0oooo0:ZZZP80000000<0oooo0:ZZZP1E
EED00`0000000`1EEED0oooo0?ooo`050?ooo`X0dLfY1`3oool01@000000oooo000000000000oooo
00@0000000@0oooo0000002ZZZX0ZZZZ0`1EEED05P3oool0ZZZZ0:ZZZP3oool0EEEE0000003oool0
EEEE0000002ZZZX0oooo0000001EEED0oooo0000001EEED000000?ooo`2ZZZX0000005EEE@3oool2
05EEE@<0ZZZZ101EEED20:ZZZP80oooo0`0000020?ooo`80000000<0oooo0000003oool01P3oool:
0=7=Z@L0oooo00<0000005EEE@3oool00P2ZZZX40000000:0:ZZZP3oool0EEEE0?ooo`000000EEEE
0000002ZZZX000000?ooo`<000000P2ZZZX01P3oool0ZZZZ0:ZZZP2ZZZX0EEEE000000<0EEEE1P2Z
ZZX00`000000ZZZZ0?ooo`030000000305EEE@000000oooo0080EEEE00D0ZZZZ05EEE@0000000000
0?ooo`020:ZZZP030?ooo`1EEED0000000L0oooo2P3AcJT70?ooo`030000003oool0ZZZZ00800000
00<0ZZZZ0000000000000P2ZZZX01@000000oooo0000002ZZZX000000080oooo0P1EEED01@2ZZZX0
00000?ooo`1EEED0oooo0080ZZZZ00@0oooo0:ZZZP000000ZZZZ0`0000001@3oool0ZZZZ0:ZZZP3o
ool0EEEE008000000`1EEED00`2ZZZX0oooo0000000200000080oooo00<0ZZZZ05EEE@0000001@00
00000`3oool000000?ooo`060?ooo`X0dLfY1`3oool20000000705EEE@000000ZZZZ0:ZZZP000000
oooo05EEE@020000000405EEE@000000000000000080EEEE00P000000?ooo`3oool0000005EEE@2Z
ZZX0oooo05EEE@80oooo0P1EEED00`000000oooo05EEE@030?ooo`0805EEE@3oool0ZZZZ0:ZZZP00
0000EEEE0?ooo`00000205EEE@030000001EEED000000080EEEE00<0000005EEE@3oool00P000000
0`2ZZZX0000000000002000000L0oooo303AcJT000/0dLfY2P3oool02@1EEED0oooo0:ZZZP3oool0
000005EEE@000000oooo0:ZZZP040000000405EEE@3oool000000:ZZZP<0000000X0ZZZZ00000000
0000000005EEE@000000oooo0:ZZZP000000oooo0P0000002@3oool0ZZZZ0000003oool000000:ZZ
ZP000000oooo0:ZZZP020000000705EEE@000000ZZZZ0:ZZZP000000EEEE000000030?ooo`0305EE
E@000000oooo00P0oooo2P3AcJT:0?ooo`050000003oool0oooo0:ZZZP000000103oool01`000000
EEEE0000002ZZZX0000005EEE@2ZZZX00`1EEED01@000000oooo0?ooo`3oool000000080ZZZZ00<0
EEEE0:ZZZP2ZZZX00P0000030?ooo`080000003oool0EEEE05EEE@2ZZZX0EEEE0?ooo`2ZZZX30000
00@0oooo00@000000:ZZZP3oool0oooo0P0000090?ooo`X0dLfY2@3oool20000000505EEE@2ZZZX0
ZZZZ0:ZZZP3oool00`2ZZZX00`000000EEEE0000000205EEE@8000000P2ZZZX205EEE@090000002Z
ZZX0ZZZZ05EEE@000000oooo05EEE@000000oooo0080EEEE00L0ZZZZ0?ooo`000000EEEE0000002Z
ZZX0EEEE008000000P1EEED3000000030:ZZZP000000ZZZZ00<0ZZZZ00@0oooo05EEE@0000000000
2@3oool:0=7=Z@T0oooo00@000000?ooo`00000000000P1EEED00`000000ZZZZ0:ZZZP0200000008
0:ZZZP1EEED000000?ooo`000000ZZZZ0000003oool3000000080?ooo`1EEED0EEEE0?ooo`2ZZZX0
EEEE0000002ZZZX305EEE@@0000000L0oooo0:ZZZP2ZZZX000000?ooo`000000EEEE00<0000000<0
oooo0:ZZZP2ZZZX00P1EEED0102ZZZX000000?ooo`0000090?ooo`X0dLfY2@3oool2000000D0EEEE
0P2ZZZX01P1EEED0ZZZZ0:ZZZP1EEED0ZZZZ05EEE@80ZZZZ00`0EEEE0:ZZZP000000ZZZZ0?ooo`1E
EED0ZZZZ0?ooo`2ZZZX0oooo05EEE@2ZZZX30?ooo`070:ZZZP3oool0oooo0:ZZZP3oool0ZZZZ0?oo
o`040:ZZZP80EEEE00<0ZZZZ05EEE@1EEED00P2ZZZX205EEE@040000001EEED00000000000T0oooo
303AcJT000/0dLfY2@3oool0101EEED000000000000000020:ZZZP060?ooo`2ZZZX000000000002Z
ZZX0oooo0P1EEED3000000050?ooo`00000000000?ooo`2ZZZX00P1EEED20?ooo`040:ZZZP000000
00000:ZZZP80oooo0P1EEED01@2ZZZX0oooo000000000000oooo008000000`1EEED01P3oool0ZZZZ
000000000000ZZZZ0?ooo`80ZZZZ0`00000:0?ooo`X0dLfY2@3oool205EEE@80000000<0EEEE0?oo
o`3oool01@3oool20:ZZZP040?ooo`000000oooo0:ZZZP80oooo1P0000001@1EEED000000?ooo`1E
EED0oooo00D000000P3oool0101EEED0oooo0000000000020:ZZZP0305EEE@3oool0oooo00@0oooo
00@0EEEE000000000000EEEE2P3oool:0=7=Z@T0oooo00L0EEEE0?ooo`3oool0EEEE0:ZZZP000000
ZZZZ0080EEEE0`2ZZZX00`3oool0ZZZZ0?ooo`020:ZZZP80EEEE0P000000101EEED0ZZZZ0000003o
ool20:ZZZP80000000@0ZZZZ0?ooo`3oool000000P1EEED010000000EEEE05EEE@3oool20:ZZZP04
0?ooo`2ZZZX0oooo0?ooo`80ZZZZ00H0000005EEE@1EEED000000:ZZZP00000<0?ooo`X0dLfY2@3o
ool0101EEED0oooo0000000000020?ooo`030:ZZZP000000EEEE00<0EEEE00D0oooo0:ZZZP000000
ZZZZ000000020:ZZZP030000003oool0000000@0ZZZZ0P0000000`3oool000000:ZZZP020:ZZZP80
000000D0oooo0000002ZZZX0oooo000000030:ZZZP050?ooo`1EEED0EEEE05EEE@3oool00P000002
0?ooo`8000002`3oool:0=7=Z@T0oooo00<0EEEE0?ooo`3oool00`2ZZZX00`1EEED0oooo0:ZZZP02
0:ZZZP050?ooo`1EEED0ZZZZ05EEE@3oool00P1EEED00`000000oooo05EEE@0205EEE@<0000000@0
EEEE0:ZZZP2ZZZX0EEEE0`00000305EEE@8000000P1EEED00`3oool0ZZZZ0:ZZZP0205EEE@80ZZZZ
00<0EEEE0?ooo`2ZZZX00`2ZZZX<0?ooo``0dLfY000;0=7=Z@/0oooo00H0000005EEE@3oool0oooo
0000002ZZZX2000000<0ZZZZ00h0oooo05EEE@1EEED0ZZZZ0000002ZZZX0oooo0000003oool00000
05EEE@2ZZZX0oooo0:ZZZP80000000`0ZZZZ0000002ZZZX0EEEE0000003oool000000?ooo`2ZZZX0
00000:ZZZP1EEED20?ooo`030:ZZZP3oool0ZZZZ0080000000<0ZZZZ0000003oool00P3oool00`00
0000oooo0?ooo`090?ooo`X0dLfY2`3oool00`1EEED0000005EEE@050000000405EEE@000000ZZZZ
0:ZZZP<0EEEE00@000000?ooo`3oool000000`3oool0301EEED0oooo000000000000ZZZZ0000002Z
ZZX0EEEE0?ooo`000000oooo000000<0oooo0P1EEED01@000000ZZZZ0:ZZZP000000EEEE00D00000
0`1EEED;0?ooo`X0dLfY2`3oool305EEE@050?ooo`1EEED0ZZZZ0000001EEED00P000000201EEED0
000005EEE@2ZZZX0oooo0000001EEED0ZZZZ0P1EEED00`2ZZZX0oooo0?ooo`030000000305EEE@00
0000EEEE0080oooo0`1EEED01@2ZZZX0EEEE0:ZZZP3oool0ZZZZ0080000000@0EEEE0:ZZZP000000
EEEE0P2ZZZX20?ooo`0305EEE@2ZZZX0EEEE00/0oooo2P3AcJT;0?ooo`0505EEE@00000000000000
003oool01`00000205EEE@070?ooo`2ZZZX000000000003oool000000:ZZZP0400000080ZZZZ00H0
00000?ooo`000000000005EEE@0000020?ooo`050000002ZZZX0oooo05EEE@3oool02P0000000`2Z
ZZX0EEEE0?ooo`0:0?ooo`X0dLfY2`3oool01@1EEED0oooo0:ZZZP2ZZZX0EEEE008000000P2ZZZX0
1@000000ZZZZ05EEE@1EEED000000080ZZZZ1000000205EEE@080?ooo`00000000000000001EEED0
000005EEE@3oool205EEE@@0000000L0EEEE0:ZZZP000000ZZZZ05EEE@2ZZZX0EEEE0080ZZZZ00<0
EEEE0000003oool00P2ZZZX00`3oool0EEEE0?ooo`0:0?ooo``0dLfY000;0=7=Z@`0oooo0`000000
103oool000000000000000020?ooo`040000003oool00000000000<0EEEE00@0oooo05EEE@1EEED0
ZZZZ0P3oool2000000040?ooo`2ZZZX0000000000080oooo00@0ZZZZ05EEE@1EEED000000`1EEED0
10000000EEEE0?ooo`0000020?ooo`030000003oool0000000<0000000<0EEEE0?ooo`3oool02P3o
ool:0=7=Z@d0oooo00T000000?ooo`000000ZZZZ0000002ZZZX0EEEE0?ooo`1EEED00P0000020?oo
o`030:ZZZP000000ZZZZ0080000000<0ZZZZ0?ooo`0000000P1EEED01P3oool0000005EEE@3oool0
00000?ooo`<0000000<0oooo0000000000000`3oool02@000000EEEE0?ooo`1EEED0ZZZZ0000002Z
ZZX000000?ooo`02000000`0oooo2P3AcJT<0?ooo`80000000<0EEEE0000003oool00`0000000`3o
ool0ZZZZ0?ooo`020:ZZZP80EEEE00H000000?ooo`2ZZZX0EEEE0:ZZZP0000020:ZZZP80oooo00P0
ZZZZ0?ooo`2ZZZX0ZZZZ0000003oool0EEEE0:ZZZP8000000P1EEED20:ZZZP030?ooo`2ZZZX0ZZZZ
0080000000@0ZZZZ0?ooo`3oool0EEEE0P00000<0?ooo`X0dLfY303oool00`2ZZZX0000000000002
05EEE@040:ZZZP000000EEEE05EEE@8000000`2ZZZX02@3oool0ZZZZ0000001EEED0oooo0:ZZZP00
0000EEEE0:ZZZP0400000080EEEE00@000000?ooo`3oool0EEEE0P2ZZZX010000000ZZZZ0:ZZZP2Z
ZZX200000080EEEE0P0000000`1EEED0ZZZZ00000002000000`0oooo2P3AcJT<0?ooo`80000000D0
EEEE0:ZZZP00000000000:ZZZP020?ooo`80EEEE00T000000:ZZZP2ZZZX0oooo05EEE@3oool0EEEE
0?ooo`2ZZZX00P3oool20:ZZZP0305EEE@3oool0ZZZZ00D0oooo00@0EEEE0?ooo`1EEED0EEEE0P2Z
ZZX01@000000EEEE05EEE@000000oooo0080ZZZZ0P0000000`1EEED000000000000<0?ooo``0dLfY
000;0=7=Z@`0oooo0P2ZZZX0103oool000000000001EEED40?ooo`0>05EEE@000000oooo0:ZZZP3o
ool0ZZZZ0000001EEED000000:ZZZP000000ZZZZ0?ooo`2ZZZX2000000<0ZZZZ0`000000201EEED0
oooo0:ZZZP3oool0ZZZZ0?ooo`000000EEEE1@3oool2000000030?ooo`2ZZZX0oooo00`0oooo2P3A
cJT<0?ooo`80EEEE00D000000?ooo`000000EEEE000000030?ooo`030000001EEED0EEEE0080oooo
00<0000005EEE@3oool00P3oool010000000ZZZZ0?ooo`3oool2000000050?ooo`000000ZZZZ0000
001EEED00P3oool20000000305EEE@3oool0EEEE008000000`3oool00`000000EEEE000000020000
000305EEE@3oool0oooo00/0oooo2P3AcJT<0?ooo`0305EEE@3oool0oooo0080EEEE0P0000002P2Z
ZZX0oooo05EEE@1EEED0ZZZZ05EEE@000000EEEE0000001EEED20:ZZZP030000001EEED0EEEE0080
EEEE00@000000:ZZZP1EEED0oooo0P1EEED30:ZZZP0605EEE@00000000000000001EEED0ZZZZ0P1E
EED01P000000ZZZZ0000002ZZZX0EEEE000000l0oooo2P3AcJT<0?ooo`80EEEE00<000000?ooo`3o
ool00P0000000`3oool000000?ooo`04000000070?ooo`1EEED0oooo0?ooo`000000oooo05EEE@02
0?ooo`060000002ZZZX000000000002ZZZX0oooo0P1EEED010000000oooo05EEE@1EEED5000000<0
oooo0P000000103oool0ZZZZ0000001EEED=0?ooo`X0dLfY303oool0201EEED0oooo0?ooo`2ZZZX0
EEEE0?ooo`000000ZZZZ0P1EEED010000000oooo0000002ZZZX20?ooo`80000000h0ZZZZ00000000
0000oooo0000001EEED0ZZZZ0000001EEED000000?ooo`000000EEEE0:ZZZP8000000P3oool0102Z
ZZX0000005EEE@00000205EEE@050:ZZZP000000EEEE05EEE@2ZZZX03`3oool<0=7=Z@002`3AcJT>
0?ooo`0405EEE@000000000005EEE@80ZZZZ0P0000020?ooo`0305EEE@2ZZZX0oooo00@0000000@0
EEEE0000002ZZZX0oooo0P000000102ZZZX000000000002ZZZX4000000090:ZZZP00000000000:ZZ
ZP1EEED0ZZZZ0?ooo`000000oooo0080ZZZZ0`0000000`1EEED0oooo0?ooo`0<0?ooo`X0dLfY3P3o
ool01`1EEED0000005EEE@3oool0EEEE0?ooo`1EEED00P3oool01@1EEED000000000001EEED0oooo
0080EEEE00@0oooo05EEE@000000oooo0`000000202ZZZX000000?ooo`3oool0000005EEE@3oool0
EEEE0P3oool30000000305EEE@3oool0oooo0080oooo1@1EEED>0?ooo`X0dLfY3P3oool305EEE@<0
ZZZZ00@000000:ZZZP2ZZZX0oooo0P1EEED00`2ZZZX000000?ooo`020?ooo`0705EEE@3oool0oooo
0:ZZZP1EEED0oooo0:ZZZP0205EEE@80oooo00D0ZZZZ0?ooo`3oool0ZZZZ0000000405EEE@D0ZZZZ
00@0oooo05EEE@2ZZZX0EEEE3P3oool:0=7=Z@h0oooo00L0EEEE000000000000ZZZZ0000003oool0
ZZZZ0080000000<0ZZZZ05EEE@2ZZZX0100000001@3oool0EEEE05EEE@1EEED0oooo00@0EEEE00D0
ZZZZ05EEE@1EEED0ZZZZ0?ooo`04000000030:ZZZP1EEED00000008000000P3oool40000000305EE
E@3oool0oooo00`0oooo2P3AcJT>0?ooo`0305EEE@3oool0ZZZZ00D0ZZZZ1`1EEED010000000EEEE
05EEE@3oool205EEE@80ZZZZ00D000000:ZZZP000000EEEE0?ooo`0205EEE@80000000P0EEEE0000
001EEED0EEEE0:ZZZP1EEED0ZZZZ05EEE@@0ZZZZ00<0oooo05EEE@3oool03@3oool<0=7=Z@002`3A
cJT?0?ooo`030:ZZZP3oool000000080EEEE00<0oooo0:ZZZP2ZZZX00P00000205EEE@040:ZZZP00
0000oooo0:ZZZP80oooo00D0EEEE0000002ZZZX0oooo05EEE@020:ZZZP0705EEE@3oool0ZZZZ0:ZZ
ZP3oool000000:ZZZP0205EEE@8000000P2ZZZX01P000000EEEE05EEE@000000oooo0:ZZZPl0oooo
2P3AcJT@0?ooo`040000003oool0oooo0:ZZZP<0oooo00<000000?ooo`0000000`3oool01@000000
oooo0?ooo`1EEED0oooo0080EEEE00T0oooo0000001EEED0EEEE0?ooo`1EEED0ZZZZ0?ooo`000000
0P3oool2000000@0oooo00@000000:ZZZP3oool0oooo0P00000?0?ooo`X0dLfY3`3oool200000006
0?ooo`1EEED0EEEE05EEE@000000ZZZZ0P3oool00`2ZZZX0EEEE05EEE@020:ZZZP040000003oool0
oooo0?ooo`80000000<0ZZZZ05EEE@0000000`3oool01`2ZZZX000000:ZZZP000000EEEE0?ooo`2Z
ZZX00P3oool00`2ZZZX0000005EEE@0305EEE@8000003`3oool:0=7=Z@l0oooo00`000000?ooo`00
000000000:ZZZP000000oooo0000003oool0ZZZZ0?ooo`00000305EEE@040000002ZZZX0oooo0?oo
o`D0ZZZZ00D000000?ooo`3oool0oooo0000000305EEE@030000003oool0ZZZZ0080000000<0oooo
0:ZZZP2ZZZX00P0000000`3oool000000?ooo`0>0?ooo`X0dLfY3`3oool400000080EEEE0P000002
0?ooo`80ZZZZ00H0EEEE0?ooo`000000EEEE0000001EEED20:ZZZP030?ooo`1EEED000000080oooo
00/0ZZZZ05EEE@1EEED0EEEE0000003oool0EEEE0?ooo`2ZZZX0oooo0:ZZZP030000000305EEE@00
0000EEEE008000003`3oool<0=7=Z@002`3AcJT?0?ooo`060000003oool0oooo0?ooo`2ZZZX00000
0P1EEED0102ZZZX0oooo0:ZZZP3oool20:ZZZP030000002ZZZX00000008000000P1EEED200000080
EEEE0`000000202ZZZX0000005EEE@2ZZZX0oooo0:ZZZP3oool000000P1EEED0103oool0ZZZZ0?oo
o`1EEEDA0?ooo`X0dLfY3`3oool205EEE@80000000<0EEEE0?ooo`3oool00P3oool205EEE@800000
00D0EEEE0000001EEED0oooo0:ZZZP030?ooo`80000000H0oooo0000003oool0ZZZZ0000001EEED3
000000<0EEEE103oool0101EEED000000000001EEED@0?ooo`X0dLfY3`3oool0101EEED0oooo0000
001EEED200000080EEEE00D0ZZZZ05EEE@1EEED0ZZZZ0?ooo`0305EEE@80ZZZZ00X000000:ZZZP3o
ool0EEEE0:ZZZP3oool0ZZZZ0000002ZZZX000000P1EEED20?ooo`H0EEEE0P0000000`1EEED0oooo
0?ooo`0@0?ooo`X0dLfY3`3oool01@1EEED0oooo0000002ZZZX000000080ZZZZ00X0000005EEE@2Z
ZZX0ZZZZ0000003oool0ZZZZ0?ooo`1EEED000000P2ZZZX600000080ZZZZ00<0oooo05EEE@3oool0
0P3oool02P000000ZZZZ0:ZZZP1EEED000000:ZZZP3oool000000:ZZZP00000A0?ooo`X0dLfY3`3o
ool02P1EEED0oooo0:ZZZP2ZZZX0oooo0000001EEED0oooo0:ZZZP1EEED2000000<0EEEE00H0ZZZZ
05EEE@3oool0ZZZZ05EEE@0000020:ZZZP80000000@0ZZZZ0?ooo`3oool0ZZZZ0`1EEED200000003
05EEE@000000oooo0080EEEE00<0oooo0:ZZZP3oool04@3oool<0=7=Z@002`3AcJTA0?ooo`050:ZZ
ZP3oool000000:ZZZP0000000P2ZZZX00`3oool0ZZZZ0:ZZZP020:ZZZP80oooo0`000000102ZZZX0
oooo0000000000020?ooo`80000000@0ZZZZ0?ooo`3oool0oooo0`2ZZZX00`3oool0ZZZZ0:ZZZP03
000000030?ooo`2ZZZX0oooo0100oooo2P3AcJTA0?ooo`0305EEE@000000EEEE00H0000000L0oooo
0000002ZZZX000000:ZZZP000000oooo0080000000<0oooo0000000000000P3oool020000000oooo
0:ZZZP2ZZZX000000?ooo`000000ZZZZ1P0000000`1EEED0000005EEE@0A0?ooo`X0dLfY4@3oool0
1@2ZZZX0EEEE05EEE@1EEED000000080ZZZZ00H0EEEE0:ZZZP1EEED0000005EEE@2ZZZX205EEE@03
0?ooo`2ZZZX0ZZZZ0080EEEE00D0000005EEE@2ZZZX0ZZZZ0?ooo`0205EEE@030:ZZZP0000000000
0080ZZZZ00D0EEEE0:ZZZP2ZZZX000000?ooo`0305EEEA40oooo2P3AcJTA0?ooo`030:ZZZP000000
000000@0ZZZZ00@000000:ZZZP2ZZZX0ZZZZ100000000`2ZZZX000000?ooo`020?ooo`050000003o
ool000000000002ZZZX00`0000020:ZZZP040?ooo`2ZZZX00000000000<0ZZZZ0P0000000`1EEED0
oooo0?ooo`0?0?ooo`X0dLfY4`3oool00`2ZZZX0EEEE05EEE@020?ooo`030000003oool0oooo00<0
EEEE00@0oooo0000002ZZZX0ZZZZ0`0000000`1EEED00000000000030:ZZZP060?ooo`1EEED0EEEE
05EEE@2ZZZX0oooo0P0000001P3oool0EEEE0:ZZZP2ZZZX0oooo05EEEA40oooo303AcJT000/0dLfY
4@3oool010000000oooo05EEE@3oool700000080ZZZZ0P0000001@3oool000000000002ZZZX0oooo
0080ZZZZ0P0000000`3oool0ZZZZ000000020:ZZZP050000002ZZZX000000000002ZZZX00P000000
0`3oool0EEEE0?ooo`0B0?ooo`X0dLfY4@3oool00`000000oooo00000002000000050:ZZZP000000
ZZZZ0000003oool00P1EEED01@000000EEEE000000000000EEEE0080oooo00<0EEEE0?ooo`3oool0
0P1EEED01@000000oooo05EEE@000000oooo0080EEEE00L000000:ZZZP000000ZZZZ0000003oool0
000001<0oooo2P3AcJTA0?ooo`<0000000<0oooo0:ZZZP2ZZZX0102ZZZX01@3oool0ZZZZ0:ZZZP1E
EED0ZZZZ00<0EEEE00@0oooo0:ZZZP2ZZZX0oooo0`1EEED01P3oool0EEEE0:ZZZP2ZZZX0oooo05EE
E@80ZZZZ00@0EEEE0:ZZZP2ZZZX0EEEE0P00000B0?ooo`X0dLfY4@3oool00`000000ZZZZ00000003
000000080:ZZZP3oool0ZZZZ0:ZZZP3oool0ZZZZ0000001EEED300000080EEEE00@000000:ZZZP1E
EED0ZZZZ0P00000205EEE@80000000@0oooo0000002ZZZX0oooo1@0000000`2ZZZX0oooo0?ooo`0@
0?ooo`X0dLfY4@3oool400000080EEEE00H0ZZZZ0000002ZZZX0ZZZZ0000002ZZZX200000080ZZZZ
0`1EEED01`3oool0ZZZZ05EEE@2ZZZX0EEEE0:ZZZP3oool0100000000`1EEED0ZZZZ0000000405EE
E@8000004P3oool<0=7=Z@002`3AcJTB0?ooo`0405EEE@000000000000000080oooo0P0000000`3o
ool0EEEE0000000205EEE@030000002ZZZX0ZZZZ00<0000000<0ZZZZ0000003oool00P2ZZZX505EE
E@050?ooo`00000000000000003oool00`0000000`1EEED0oooo0?ooo`0@0?ooo`X0dLfY4P3oool2
05EEE@050000003oool0000005EEE@0000000P3oool0102ZZZX000000?ooo`0000020:ZZZP060?oo
o`000000ZZZZ0000003oool0ZZZZ0P3oool00`2ZZZX0oooo000000020?ooo`080:ZZZP000000oooo
0000001EEED000000?ooo`00000205EEEA80oooo2P3AcJTB0?ooo`0405EEE@3oool0000005EEE@80
ZZZZ00<0EEEE0:ZZZP2ZZZX00P1EEED01P3oool0EEEE05EEE@2ZZZX0oooo0:ZZZP@0EEEE0P3oool2
0:ZZZP0405EEE@3oool0EEEE05EEE@80ZZZZ00@0EEEE0:ZZZP2ZZZX0EEEE0P3oool00`1EEED0oooo
0?ooo`0@0?ooo`X0dLfY4P3oool205EEE@050:ZZZP00000000000000003oool00P1EEED0103oool0
00000000003oool2000000090:ZZZP3oool0oooo0:ZZZP000000oooo0000002ZZZX000000080oooo
0P0000001@3oool0EEEE05EEE@3oool0ZZZZ00<000000P1EEEDB0?ooo`X0dLfY4P3oool00`1EEED0
oooo0:ZZZP030:ZZZP80EEEE00<0ZZZZ0000002ZZZX00P1EEED01@000000oooo0:ZZZP2ZZZX0oooo
0080EEEE00D0oooo05EEE@2ZZZX0oooo0:ZZZP0205EEE@030:ZZZP000000oooo0080EEEE0`2ZZZX2
0?ooo`0305EEE@3oool0oooo0100oooo303AcJT000/0dLfY5@3oool00`1EEED0oooo05EEE@040000
00@0ZZZZ0`0000001@1EEED0oooo0?ooo`1EEED0ZZZZ00<000000P2ZZZX500000080oooo00<0EEEE
0000003oool04`3oool:0=7=ZA@0oooo00T0EEEE0000001EEED0oooo05EEE@3oool000000?ooo`2Z
ZZX00P0000020:ZZZP030000001EEED0oooo0080000000@0oooo000000000000ZZZZ0`000000102Z
ZZX0oooo0?ooo`3oool305EEE@030000001EEED0oooo01<0oooo2P3AcJTD0?ooo`050:ZZZP1EEED0
EEEE0?ooo`2ZZZX00P0000001`3oool0000005EEE@3oool0000005EEE@2ZZZX01@1EEED01@3oool0
ZZZZ05EEE@2ZZZX0oooo0080EEEE00D0oooo0:ZZZP000000ZZZZ0?ooo`0305EEEA@0oooo2P3AcJTD
0?ooo`P0000000H0ZZZZ0000003oool000000:ZZZP0000020:ZZZP030?ooo`2ZZZX0ZZZZ00800000
00<0ZZZZ0?ooo`3oool01P000000102ZZZX000000000001EEEDD0?ooo`X0dLfY5P3oool00`2ZZZX0
oooo05EEE@030?ooo`<0EEEE00L0oooo0000002ZZZX0oooo0000003oool0EEEE0080000000<0ZZZZ
0000001EEED00P1EEED20?ooo`030:ZZZP3oool0EEEE0080ZZZZ00<0oooo05EEE@3oool04`3oool<
0=7=Z@002`3AcJTD0?ooo`0805EEE@00000000000000001EEED0ZZZZ0?ooo`0000020?ooo`030000
002ZZZX0EEEE0080ZZZZ103oool20:ZZZP0405EEE@3oool000000?ooo`8000000P2ZZZX0101EEED0
000000000000000E0?ooo`X0dLfY503oool00`000000oooo000000020?ooo`040:ZZZP3oool00000
0:ZZZP<0000000D0EEEE0?ooo`1EEED0ZZZZ0?ooo`020:ZZZP80oooo00D0EEEE0?ooo`0000000000
0:ZZZP02000000040:ZZZP3oool0oooo000001H0oooo2P3AcJTD0?ooo`<0000000<0oooo0000002Z
ZZX00P1EEED00`3oool0ZZZZ05EEE@020?ooo`030000002ZZZX0ZZZZ00@0ZZZZ00@000000?ooo`1E
EED0EEEE0P2ZZZX01@1EEED000000:ZZZP000000EEEE008000005@3oool:0=7=ZA@0oooo0P000000
1P3oool0ZZZZ0000001EEED000000:ZZZP80000000<0ZZZZ0000000000000P0000001@3oool00000
0:ZZZP3oool0ZZZZ008000000P2ZZZX2000000030:ZZZP1EEED0EEEE0080000000<0oooo0000003o
ool0503oool:0=7=ZA@0oooo100000001@2ZZZX000000000002ZZZX0000000<0EEEE00@0ZZZZ05EE
E@1EEED000000P3oool01@000000ZZZZ05EEE@2ZZZX0000000<0EEEE00D0ZZZZ05EEE@000000ZZZZ
05EEE@02000001D0oooo303AcJT000/0dLfY5@3oool20:ZZZP80000000@0EEEE0000003oool00000
0P2ZZZX00`1EEED0000000000005000000040:ZZZP000000000005EEE@<0ZZZZ00D0oooo05EEE@1E
EED000000?ooo`020:ZZZQD0oooo2P3AcJTE0?ooo`80EEEE0P0000001@1EEED0oooo0?ooo`000000
oooo008000000`3oool010000000oooo05EEE@0000030?ooo`80000000D0oooo05EEE@3oool0oooo
05EEE@0200000080EEEE5@3oool:0=7=ZAD0oooo00<0EEEE0?ooo`0000000P1EEED01@3oool00000
0000001EEED0ZZZZ00<0oooo1P1EEED30?ooo`050:ZZZP1EEED0oooo0000003oool00P1EEED20?oo
o`0305EEE@3oool0oooo01<0oooo2P3AcJTE0?ooo`0505EEE@3oool000000000003oool00P000000
1@2ZZZX00000000000000000ZZZZ0080000000@0oooo05EEE@1EEED0oooo0P0000000`2ZZZX00000
0000000300000080oooo0P0000000`3oool0EEEE0?ooo`0D0?ooo`X0dLfY5@3oool01P1EEED0oooo
0:ZZZP2ZZZX0EEEE00000080oooo00<0ZZZZ0?ooo`1EEED00P2ZZZX01@1EEED0oooo000000000000
oooo00<0ZZZZ0P3oool20:ZZZP040?ooo`1EEED0EEEE0:ZZZP80oooo00<0EEEE0?ooo`3oool04`3o
ool<0=7=Z@002`3AcJTG0?ooo`<000000P2ZZZX0103oool0ZZZZ0?ooo`3oool2000000050?ooo`1E
EED000000:ZZZP1EEED00`0000001@2ZZZX0oooo0:ZZZP3oool0ZZZZ00<0000000<0EEEE0?ooo`3o
ool05@3oool:0=7=ZAL0oooo00<0EEEE0000001EEED00`0000000`3oool0000005EEE@0205EEE@03
0000001EEED0oooo00D0EEEE0P0000001`3oool00000000000000000EEEE0000001EEED05`3oool:
0=7=ZAL0oooo00<0ZZZZ05EEE@1EEED00P3oool02@2ZZZX0EEEE05EEE@2ZZZX0oooo0:ZZZP1EEED0
ZZZZ05EEE@020:ZZZP040000002ZZZX0oooo000000<0EEEE00<0oooo0000001EEED00P1EEEDG0?oo
o`X0dLfY5`3oool01@2ZZZX00000000000000000oooo0080EEEE00@0ZZZZ05EEE@1EEED0oooo1@00
00020?ooo`0405EEE@2ZZZX0ZZZZ05EEE@80oooo0`0000000`1EEED0oooo0?ooo`0E0?ooo`X0dLfY
6@3oool30:ZZZP80EEEE0P2ZZZX30?ooo`050:ZZZP3oool0EEEE0:ZZZP1EEED00P3oool20:ZZZP80
EEEE0`2ZZZX00`3oool0EEEE0?ooo`0F0?ooo``0dLfY000;0=7=ZAL0oooo0P2ZZZX00`3oool00000
0:ZZZP030:ZZZP80000000<0oooo0000000000000P1EEED2000000030?ooo`00000000000080ZZZZ
00D000000:ZZZP000000oooo0:ZZZP0H0?ooo`X0dLfY5`3oool00`000000oooo00000006000000<0
oooo00<000000?ooo`3oool00P0000030?ooo`80000000@0ZZZZ0000003oool000006@3oool:0=7=
ZAL0oooo0`000000101EEED0ZZZZ0?ooo`1EEED20:ZZZP040000002ZZZX0ZZZZ05EEE@80ZZZZ00H0
EEEE0?ooo`2ZZZX000000?ooo`2ZZZX205EEE@040:ZZZP1EEED00000000001P0oooo2P3AcJTG0?oo
o`0>0000002ZZZX000000:ZZZP1EEED0ZZZZ0?ooo`1EEED0oooo0:ZZZP1EEED0ZZZZ0000002ZZZX2
00000080EEEE00@0ZZZZ05EEE@1EEED0oooo0P1EEED2000000030:ZZZP3oool0oooo01H0oooo2P3A
cJTG0?ooo`D0000000H0EEEE0000001EEED0000005EEE@2ZZZX200000080EEEE0P000000202ZZZX0
EEEE0000001EEED0000005EEE@000000EEEE0P00000H0?ooo``0dLfY000;0=7=ZAP0oooo00P00000
0?ooo`3oool0oooo0000002ZZZX000000?ooo`80000000<0oooo0000001EEED01`0000001P2ZZZX0
00000?ooo`1EEED0oooo000001P0oooo2P3AcJTH0?ooo`80EEEE00<000000?ooo`1EEED00P1EEED3
0?ooo`80EEEE00<0oooo05EEE@1EEED00`3oool305EEE@030000003oool000000080EEEE603oool:
0=7=ZAP0oooo00<0EEEE0?ooo`0000000P3oool00`1EEED0ZZZZ0000000205EEE@80000000@0oooo
000000000000oooo0P1EEED20:ZZZP0305EEE@000000oooo0080oooo00<0EEEE0?ooo`3oool05P3o
ool:0=7=ZAP0oooo0P1EEED00`2ZZZX0oooo000000030:ZZZP040000003oool000000:ZZZP800000
00@0ZZZZ0?ooo`3oool000000`2ZZZX20?ooo`030000001EEED0EEEE01P0oooo2P3AcJTH0?ooo`0;
05EEE@3oool0ZZZZ0:ZZZP1EEED0ZZZZ05EEE@3oool0EEEE0:ZZZP0000001P2ZZZX01P1EEED0oooo
05EEE@2ZZZX0oooo0:ZZZP80oooo00<0EEEE0?ooo`3oool05P3oool<0=7=Z@002`3AcJTJ0?ooo`06
0:ZZZP3oool000000000003oool0ZZZZ0P0000001@2ZZZX0EEEE0000003oool0EEEE00<0000000H0
EEEE0?ooo`00000000000?ooo`2ZZZXJ0?ooo`X0dLfY6P3oool01@1EEED0000005EEE@3oool0EEEE
00@0000000@0EEEE0?ooo`1EEED0EEEE100000001@1EEED0oooo05EEE@000000EEEE01X0oooo2P3A
cJTJ0?ooo`080:ZZZP1EEED0ZZZZ0?ooo`2ZZZX0000005EEE@2ZZZX205EEE@060:ZZZP000000EEEE
0000002ZZZX0EEEE0P2ZZZX0103oool0EEEE05EEE@1EEEDJ0?ooo`X0dLfY6P3oool3000000030:ZZ
ZP000000ZZZZ00<0000000@0oooo000000000000oooo1@000000102ZZZX000000000001EEEDJ0?oo
o`X0dLfY703oool00`2ZZZX0EEEE05EEE@0305EEE@<0oooo00<000000?ooo`3oool01@1EEED00`2Z
ZZX0oooo05EEE@0J0?ooo``0dLfY000;0=7=ZAX0oooo00P000000?ooo`3oool0oooo05EEE@000000
ZZZZ0?ooo`80000000X0oooo05EEE@000000ZZZZ0?ooo`2ZZZX0000005EEE@3oool0EEEE703oool:
0=7=ZAX0oooo00<000000?ooo`3oool00P3oool01@000000ZZZZ0000003oool000000080oooo0`00
00001@2ZZZX000000?ooo`3oool0000001`0oooo2P3AcJTJ0?ooo`<0000000D0oooo05EEE@3oool0
oooo0:ZZZP0200000080EEEE0P0000001@2ZZZX0oooo05EEE@1EEED0oooo008000006`3oool:0=7=
ZAX0oooo1P000000103oool000000?ooo`00000205EEE@<0000000H0oooo0:ZZZP00000000000?oo
o`00000K0?ooo`X0dLfY6P3oool20000000405EEE@000000EEEE00000080EEEE00H0ZZZZ05EEE@3o
ool0000005EEE@00000405EEE@<000006`3oool<0=7=Z@002`3AcJTK0?ooo`0505EEE@0000000000
0000002ZZZX00P0000001@2ZZZX0EEEE000000000000EEEE00<0000000D0EEEE0000000000000000
05EEE@0K0?ooo`X0dLfY6`3oool02P1EEED00000000000000000EEEE0000003oool0000005EEE@3o
ool205EEE@040000003oool0000005EEE@8000000P1EEEDK0?ooo`X0dLfY6`3oool02P1EEED0oooo
05EEE@000000EEEE0?ooo`000000ZZZZ0000001EEED4000000060?ooo`000000000005EEE@3oool0
EEEE6`3oool:0=7=ZA/0oooo00H0EEEE000000000000ZZZZ0?ooo`00000205EEE@060?ooo`000000
oooo0?ooo`000000EEEE0P000000102ZZZX000000?ooo`1EEEDK0?ooo`X0dLfY6`3oool00`1EEED0
oooo0:ZZZP020:ZZZP80000000H0ZZZZ05EEE@3oool0oooo05EEE@2ZZZX2000000<0ZZZZ00<0oooo
05EEE@3oool06P3oool<0=7=Z@002`3AcJTL0?ooo`080000003oool0EEEE0?ooo`2ZZZX0oooo0:ZZ
ZP3oool2000000<0oooo00<0ZZZZ0?ooo`1EEED07P3oool:0=7=ZA`0oooo0P1EEED3000000040?oo
o`000000EEEE0?ooo`80EEEE00H000000?ooo`000000EEEE0000001EEEDM0?ooo`X0dLfY703oool0
0`1EEED0ZZZZ05EEE@030:ZZZP060?ooo`2ZZZX0ZZZZ0?ooo`2ZZZX0oooo0P2ZZZX00`000000EEEE
0:ZZZP0M0?ooo`X0dLfY703oool00`1EEED0ZZZZ000000030:ZZZP060?ooo`2ZZZX000000000002Z
ZZX000000P2ZZZX2000000030:ZZZP3oool0oooo01/0oooo2P3AcJTL0?ooo`0405EEE@3oool0oooo
0:ZZZP80oooo1@1EEED30?ooo`030:ZZZP3oool0oooo01d0oooo303AcJT000/0dLfY7@3oool01@1E
EED00000000000000000ZZZZ0080000000<0oooo0000000000000P2ZZZX30000000305EEE@3oool0
oooo01/0oooo2P3AcJTM0?ooo`030000003oool0oooo0080000000@0oooo0000003oool0oooo1@00
00000`3oool000000?ooo`0L0?ooo`X0dLfY7@3oool2000000<0EEEE00@0ZZZZ05EEE@1EEED0ZZZZ
1@1EEED2000001d0oooo2P3AcJTM0?ooo`030000002ZZZX000000080000000<0oooo05EEE@1EEED0
0P1EEED4000000030:ZZZP000000oooo01`0oooo2P3AcJTM0?ooo`80000000H0EEEE0000002ZZZX0
000005EEE@00000305EEE@030:ZZZP0000000000008000007@3oool<0=7=Z@002`3AcJTP0?ooo`05
05EEE@3oool000000000003oool00P0000020?ooo`0305EEE@000000oooo01h0oooo2P3AcJTP0?oo
o`80000000@0oooo0000003oool0oooo1@00000O0?ooo`X0dLfY7`3oool0101EEED0ZZZZ05EEE@3o
ool20:ZZZP060000002ZZZX0EEEE05EEE@2ZZZX000007`3oool:0=7=ZB00oooo00<000000:ZZZP00
00001@0000000`2ZZZX000000000000O0?ooo`X0dLfY7`3oool200000080EEEE00H0ZZZZ0?ooo`00
0000ZZZZ0000001EEED2000001l0oooo303AcJT000/0dLfY7`3oool01@1EEED00000000000000000
oooo0080000000@0oooo0000000000000000803oool:0=7=ZAl0oooo0P1EEED00`000000EEEE0?oo
o`030?ooo`0305EEE@000000EEEE0200oooo2P3AcJTO0?ooo`0505EEE@2ZZZX0ZZZZ0:ZZZP000000
0P1EEED010000000ZZZZ0:ZZZP2ZZZXP0?ooo`X0dLfY7`3oool01P1EEED000000000002ZZZX00000
0:ZZZPD00000803oool:0=7=ZAl0oooo00<0EEEE0?ooo`3oool00P2ZZZX205EEE@80ZZZZ8P3oool<
0=7=Z@002`3AcJTP0?ooo`<0ZZZZ00D000000?ooo`2ZZZX000000?ooo`020:ZZZR00oooo2P3AcJTP
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000803oool:0=7=ZB00oooo0P000000
0`2ZZZX0000005EEE@02000000030?ooo`00000000000200oooo2P3AcJTP0?ooo`<0000000D0ZZZZ
000000000000ZZZZ0?ooo`0200000200oooo2P3AcJTP0?ooo`80000000<0EEEE0000002ZZZX01@00
000P0?ooo``0dLfY000;0=7=ZB80oooo0P000000103oool0ZZZZ0000001EEEDR0?ooo`X0dLfY8`3o
ool00`000000oooo0000000200000280oooo2P3AcJTR0?ooo`80EEEE00@0000005EEE@1EEED00000
8P3oool:0=7=ZB80oooo00@0EEEE000000000000ZZZZ0P00000R0?ooo`X0dLfY8P3oool01P1EEED0
ZZZZ000000000000ZZZZ00000280oooo303AcJT000/0dLfY8P3oool01@2ZZZX000000?ooo`3oool0
000002<0oooo2P3AcJTR0?ooo`<0EEEE00<0000005EEE@3oool08P3oool:0=7=ZB80oooo00D0EEEE
0:ZZZP1EEED0oooo0:ZZZP0S0?ooo`X0dLfY8P3oool01@1EEED0ZZZZ0?ooo`000000ZZZZ02<0oooo
2P3AcJTR0?ooo`0305EEE@2ZZZX000000080ZZZZ8`3oool<0=7=Z@002`3AcJTS0?ooo`@000008`3o
ool:0=7=ZB<0oooo0P0000000`3oool000000?ooo`0R0?ooo`X0dLfY8`3oool010000000ZZZZ0:ZZ
ZP00000S0?ooo`X0dLfY8`3oool2000000030:ZZZP000000oooo0280oooo2P3AcJTS0?ooo`040000
003oool0ZZZZ000002<0oooo303AcJT000/0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY
903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY
903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo``0dLfY
003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY
000;0=7=Z@050?ooo`00000000000:ZZZP0000000P3oool00`000000EEEE0?ooo`030:ZZZP@0oooo
00<0ZZZZ0?ooo`1EEED00P2ZZZX0103oool0ZZZZ0:ZZZP2ZZZX20?ooo`<0ZZZZ00D000000?ooo`3o
ool0ZZZZ000000020:ZZZP050000002ZZZX0oooo0?ooo`1EEED00`2ZZZX20?ooo`80ZZZZ00<0EEEE
0?ooo`2ZZZX00P1EEED0103oool0ZZZZ0?ooo`0000020?ooo`<0ZZZZ00<0000005EEE@0000000P3o
ool20:ZZZP030000001EEED0oooo00X0dLfY00X0oooo05EEE@1EEED0ZZZZ0?ooo`2ZZZX0EEEE0:ZZ
ZP3oool0ZZZZ0P1EEED20?ooo`050:ZZZP1EEED0ZZZZ0?ooo`1EEED00P3oool00`2ZZZX000000?oo
o`020?ooo`050:ZZZP1EEED0oooo0:ZZZP0000000P3oool01P1EEED0ZZZZ0?ooo`3oool0EEEE0?oo
o`80EEEE00H0oooo05EEE@000000ZZZZ0?ooo`1EEED30?ooo`030:ZZZP000000ZZZZ0080oooo00L0
EEEE0?ooo`2ZZZX0EEEE0:ZZZP3oool0ZZZZ0080EEEE0P3oool01@2ZZZX0EEEE0:ZZZP3oool0ZZZZ
0080EEEE00<0oooo0=7=Z@3AcJT0203AcJT0203oool0EEEE000000000000ZZZZ05EEE@3oool0ZZZZ
0`0000020:ZZZP050?ooo`2ZZZX0EEEE05EEE@2ZZZX00P3oool0101EEED000000?ooo`3oool205EE
E@040?ooo`2ZZZX0000005EEE@80ZZZZ00<000000:ZZZP3oool00P1EEED020000000EEEE0?ooo`2Z
ZZX000000?ooo`2ZZZX0EEEE0`2ZZZX205EEE@040000003oool000000:ZZZP80oooo00D0000005EE
E@2ZZZX0ZZZZ0?ooo`020:ZZZP040000003oool000000:ZZZP80EEEE00D0ZZZZ000000000000EEEE
0?ooo`0:0=7=Z@030?ooo`2ZZZX0ZZZZ0080EEEE00<0ZZZZ0?ooo`3oool00P3oool30:ZZZP050?oo
o`1EEED0oooo0:ZZZP1EEED0102ZZZX00`1EEED0000005EEE@020:ZZZP040000002ZZZX0oooo0000
00<0ZZZZ0P1EEED20:ZZZP0705EEE@2ZZZX0ZZZZ0:ZZZP1EEED000000?ooo`0200000080ZZZZ00D0
EEEE0000001EEED0ZZZZ05EEE@050:ZZZP0305EEE@3oool0ZZZZ0080ZZZZ0`3oool01`1EEED0ZZZZ
0:ZZZP1EEED0ZZZZ05EEE@3oool02P3AcJT00`3oool0EEEE000000060000000305EEE@2ZZZX0ZZZZ
0080ZZZZ00<0EEEE0000002ZZZX00P2ZZZX020000000oooo0:ZZZP3oool0ZZZZ0000002ZZZX0oooo
102ZZZX00`1EEED000000:ZZZP06000000030:ZZZP000000ZZZZ00@0ZZZZ00D0oooo0:ZZZP000000
00000?ooo`020:ZZZP040000002ZZZX0ZZZZ0:ZZZP80EEEE102ZZZX00`1EEED00000000000050000
000305EEE@3oool0dLfY00/0dLfY000;0=7=Z@070?ooo`2ZZZX0ZZZZ0?ooo`2ZZZX000000:ZZZP02
000000D0ZZZZ0P000000102ZZZX0EEEE0?ooo`0000020?ooo`080000002ZZZX0ZZZZ0:ZZZP000000
ZZZZ05EEE@3oool205EEE@0:0000003oool0ZZZZ0:ZZZP000000oooo0:ZZZP1EEED0oooo00000080
EEEE00<0oooo0:ZZZP2ZZZX00`2ZZZX00`1EEED000000?ooo`02000000050?ooo`2ZZZX0ZZZZ0:ZZ
ZP000000102ZZZX3000000050:ZZZP00000000000?ooo`2ZZZX00P3oool:0=7=Z@0:0?ooo`2ZZZX0
oooo0?ooo`1EEED0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP80oooo0P1EEED0102ZZZX0oooo0:ZZZP1EEED5
0:ZZZP0605EEE@000000000005EEE@3oool000000P3oool405EEE@050:ZZZP3oool000000:ZZZP3o
ool00`1EEED20?ooo`0305EEE@3oool0ZZZZ0080000000@0oooo0:ZZZP2ZZZX000000P2ZZZX01P1E
EED0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP80oooo0P1EEED0102ZZZX0oooo0:ZZZP0000040?ooo`X0dLfY
00<0oooo0:ZZZP3oool0102ZZZX02@1EEED0oooo0?ooo`1EEED0oooo05EEE@000000oooo00000002
05EEE@030:ZZZP1EEED0EEEE0080oooo00T0EEEE000000000000oooo05EEE@3oool0ZZZZ0000003o
ool00P2ZZZX010000000ZZZZ0:ZZZP3oool40:ZZZP0505EEE@000000ZZZZ0:ZZZP1EEED00`000003
0?ooo`80EEEE00T0ZZZZ0000001EEED000000?ooo`000000ZZZZ0?ooo`1EEED00P3oool205EEE@<0
ZZZZ0`3oool:0=7=Z@040?ooo`2ZZZX0EEEE0?ooo`80ZZZZ00@0oooo00000000000000000P2ZZZX0
1`000000ZZZZ05EEE@1EEED000000?ooo`2ZZZX00P1EEED0102ZZZX0oooo05EEE@3oool205EEE@04
0?ooo`1EEED00000000000<0ZZZZ0P0000020:ZZZP040000002ZZZX0ZZZZ0:ZZZP<000000P3oool0
0`2ZZZX0EEEE0?ooo`020?ooo`080:ZZZP3oool0EEEE0:ZZZP3oool000000:ZZZP1EEED40:ZZZP08
05EEE@00000000000000002ZZZX0EEEE0?ooo`1EEED20?ooo`X0dLfY00L0oooo0:ZZZP000000ZZZZ
0000002ZZZX000000080ZZZZ00H000000:ZZZP1EEED0000005EEE@2ZZZX505EEE@<000000P2ZZZX0
0`000000EEEE000000020?ooo`070000003oool0ZZZZ0:ZZZP3oool0ZZZZ0?ooo`050:ZZZP800000
00D0oooo000000000000EEEE000000020:ZZZP80000000<0ZZZZ05EEE@1EEED00P1EEED20:ZZZP05
05EEE@000000EEEE0:ZZZP3oool01P2ZZZX00`000000oooo0?ooo`0<0=7=Z@002`3AcJT30?ooo`03
05EEE@2ZZZX0ZZZZ0080ZZZZ00<0EEEE0?ooo`2ZZZX00P3oool01@2ZZZX0EEEE05EEE@000000oooo
0080ZZZZ00D0oooo0:ZZZP3oool0oooo000000030?ooo`0805EEE@2ZZZX000000:ZZZP000000EEEE
0000003oool20:ZZZP070?ooo`1EEED0EEEE0000001EEED000000:ZZZP020?ooo`050000003oool0
00000:ZZZP3oool0102ZZZX2000000060:ZZZP1EEED0ZZZZ0000003oool0ZZZZ0P1EEED30:ZZZP03
0000001EEED0oooo0080oooo2P3AcJT30?ooo`80EEEE00D0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP020?oo
o`80EEEE00D0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP030?ooo`0305EEE@3oool000000080oooo00@0ZZZZ
0?ooo`00000000000`3oool00`2ZZZX0oooo0?ooo`020?ooo`0305EEE@3oool0oooo00@0000000<0
ZZZZ0?ooo`3oool00P0000002`1EEED0oooo0?ooo`3oool0ZZZZ05EEE@2ZZZX0oooo0:ZZZP1EEED0
ZZZZ0080oooo0P1EEED00`2ZZZX0oooo0:ZZZP0205EEE@<0oooo2P3AcJT30?ooo`80EEEE00D00000
0?ooo`3oool000000?ooo`0205EEE@80oooo00<0EEEE0000002ZZZX00P1EEED00`2ZZZX0EEEE05EE
E@020?ooo`050:ZZZP000000EEEE0000001EEED00P3oool00`000000ZZZZ00000002000000050:ZZ
ZP3oool000000:ZZZP0000000P2ZZZX20?ooo`050:ZZZP00000000000000002ZZZX00P3oool00`1E
EED0ZZZZ0:ZZZP0205EEE@80ZZZZ00<0EEEE0?ooo`1EEED00P1EEED00`2ZZZX000000?ooo`020000
0080EEEE0`3oool:0=7=Z@<0oooo00<0EEEE0:ZZZP2ZZZX00P00000205EEE@80000000H0EEEE0:ZZ
ZP2ZZZX0ZZZZ0?ooo`2ZZZX405EEE@030:ZZZP3oool0ZZZZ0080EEEE00<0000005EEE@2ZZZX00P1E
EED20:ZZZP80EEEE00@0oooo0:ZZZP1EEED0EEEE0P2ZZZX205EEE@050:ZZZP00000000000:ZZZP1E
EED00`2ZZZX405EEE@030:ZZZP3oool0ZZZZ0080ZZZZ0`00000205EEE@050000001EEED0ZZZZ0:ZZ
ZP1EEED00`3oool:0=7=Z@<0oooo0P1EEED0102ZZZX0oooo0?ooo`3oool20000000505EEE@2ZZZX0
EEEE0000001EEED00`2ZZZX00`1EEED0000005EEE@0405EEE@030000001EEED0oooo00<0ZZZZ00<0
oooo0:ZZZP3oool00P2ZZZX01@1EEED0ZZZZ0:ZZZP2ZZZX0oooo00@0ZZZZ1`1EEED00`000000EEEE
0:ZZZP020:ZZZP80000000D0EEEE0:ZZZP1EEED0000005EEE@030?ooo`030:ZZZP1EEED0EEEE00<0
oooo303AcJT000/0dLfY103oool40:ZZZP0505EEE@2ZZZX0ZZZZ05EEE@0000000P3oool00`1EEED0
000005EEE@020:ZZZP040?ooo`000000ZZZZ0:ZZZP80000000H0EEEE0:ZZZP1EEED0EEEE0?ooo`2Z
ZZX3000000@0ZZZZ0`0000020?ooo`80EEEE00@0ZZZZ05EEE@00000000000P2ZZZX01`000000EEEE
0:ZZZP2ZZZX0EEEE0000002ZZZX00P3oool205EEE@030:ZZZP000000EEEE00@0ZZZZ103oool:0=7=
Z@H0oooo00@0EEEE0:ZZZP3oool0ZZZZ0P1EEED20?ooo`070:ZZZP1EEED0ZZZZ0?ooo`2ZZZX0EEEE
0000000205EEE@80oooo00<0EEEE0:ZZZP1EEED00P3oool01@1EEED0oooo0?ooo`3oool0ZZZZ0080
EEEE00<0000005EEE@3oool00`3oool01P1EEED0oooo0?ooo`1EEED0000005EEE@80oooo0P1EEED0
2@000000EEEE0:ZZZP3oool0ZZZZ05EEE@2ZZZX0oooo0:ZZZP0205EEE@80oooo00@0ZZZZ0000003o
ool0ZZZZ103oool:0=7=Z@L0oooo00<0000005EEE@1EEED00`2ZZZX205EEE@80ZZZZ00d0EEEE0:ZZ
ZP2ZZZX0ZZZZ05EEE@2ZZZX0EEEE0:ZZZP000000ZZZZ0?ooo`1EEED0ZZZZ0080EEEE00X000000:ZZ
ZP1EEED0EEEE0?ooo`000000EEEE0000002ZZZX000000P1EEED20:ZZZP070?ooo`00000000000:ZZ
ZP1EEED0ZZZZ05EEE@050:ZZZP040?ooo`1EEED0EEEE05EEE@80ZZZZ0P1EEED010000000EEEE0?oo
o`2ZZZX40?ooo`X0dLfY103oool00`1EEED0oooo0?ooo`040:ZZZP030?ooo`2ZZZX0EEEE00<0EEEE
00@0ZZZZ05EEE@2ZZZX0EEEE0P2ZZZX00`000000EEEE0?ooo`030:ZZZP040?ooo`1EEED0oooo05EE
E@<0ZZZZ0P1EEED00`2ZZZX0EEEE0:ZZZP0305EEE@80oooo00@0ZZZZ05EEE@3oool0EEEE1@2ZZZX3
05EEE@070:ZZZP1EEED0EEEE0:ZZZP3oool0ZZZZ05EEE@030:ZZZP030?ooo`2ZZZX0oooo00<0oooo
2P3AcJT40?ooo`030000003oool0oooo0080oooo0P2ZZZX01@3oool000000?ooo`2ZZZX0oooo0080
00000P3oool00`2ZZZX0oooo0?ooo`020?ooo`040:ZZZP3oool0EEEE05EEE@@0000000<0ZZZZ0000
001EEED00P2ZZZX205EEE@030:ZZZP000000EEEE008000000P1EEED0103oool0ZZZZ0?ooo`2ZZZX2
0?ooo`030:ZZZP3oool0oooo008000000P2ZZZX0103oool000000?ooo`2ZZZX50?ooo`030:ZZZP3o
ool0oooo0080oooo303AcJT000/0dLfY1@3oool0101EEED000000:ZZZP2ZZZX20?ooo`060:ZZZP00
000000000?ooo`2ZZZX000000P2ZZZX01`3oool0EEEE000000000000ZZZZ05EEE@3oool00P2ZZZX0
0`000000ZZZZ0:ZZZP020?ooo`030000001EEED0ZZZZ00<0ZZZZ00@0oooo0000003oool0oooo0P2Z
ZZX01P000000ZZZZ0000003oool0EEEE0?ooo`<0000000@0oooo0:ZZZP00000000000P3oool20000
00030:ZZZP3oool000000080ZZZZ00<0000005EEE@3oool0103oool:0=7=Z@D0oooo0P1EEED00`2Z
ZZX0oooo0:ZZZP0205EEE@80oooo00H0ZZZZ05EEE@2ZZZX0oooo0:ZZZP1EEED20:ZZZP030000002Z
ZZX0oooo0080oooo00D0EEEE0?ooo`3oool0oooo000000020?ooo`80ZZZZ00@0oooo0000002ZZZX0
EEEE0P3oool00`2ZZZX0oooo0?ooo`0205EEE@060000003oool0oooo0?ooo`000000ZZZZ0P1EEED0
1`2ZZZX0oooo0:ZZZP1EEED0ZZZZ0?ooo`2ZZZX00P1EEED20?ooo`030:ZZZP1EEED0EEEE00D0oooo
2P3AcJT50?ooo`0505EEE@2ZZZX0ZZZZ0?ooo`1EEED00P3oool01P1EEED0ZZZZ0:ZZZP2ZZZX0oooo
00000080EEEE00D0oooo05EEE@3oool0oooo05EEE@020:ZZZP0705EEE@2ZZZX0EEEE05EEE@2ZZZX0
EEEE0?ooo`0205EEE@050:ZZZP000000EEEE0:ZZZP3oool0101EEED02@2ZZZX0EEEE0000002ZZZX0
EEEE0:ZZZP3oool0EEEE0000000205EEE@80oooo0`2ZZZX50?ooo`030:ZZZP1EEED0EEEE00D0oooo
2P3AcJT50?ooo`0305EEE@2ZZZX0EEEE0080ZZZZ00@0EEEE0:ZZZP1EEED0oooo0P1EEED01P3oool0
00000?ooo`1EEED000000?ooo`D0EEEE00@0ZZZZ05EEE@2ZZZX0oooo0P2ZZZX205EEE@060000001E
EED0EEEE0000003oool0EEEE0P2ZZZX0103oool0ZZZZ0:ZZZP2ZZZX305EEE@030:ZZZP1EEED0oooo
0080EEEE00H0oooo05EEE@3oool0ZZZZ05EEE@3oool20:ZZZP80EEEE00@0ZZZZ05EEE@2ZZZX0EEEE
1@3oool:0=7=Z@D0oooo00<0EEEE0?ooo`3oool00P2ZZZX02P3oool0ZZZZ0:ZZZP2ZZZX0oooo0:ZZ
ZP1EEED000000?ooo`2ZZZX405EEE@<0ZZZZ00<0EEEE0000002ZZZX00P2ZZZX01P1EEED0ZZZZ0:ZZ
ZP000000ZZZZ0?ooo`80000000<0ZZZZ05EEE@2ZZZX00P2ZZZX205EEE@040000002ZZZX0ZZZZ0:ZZ
ZP80EEEE0P2ZZZX01@3oool0ZZZZ05EEE@2ZZZX0oooo00<0ZZZZ00@0oooo0000002ZZZX0oooo0P1E
EED50?ooo``0dLfY000;0=7=Z@H0oooo00@0ZZZZ0?ooo`00000000000P2ZZZX01@3oool0ZZZZ0:ZZ
ZP2ZZZX0oooo00<0ZZZZ0P0000020:ZZZP80oooo00L0EEEE0:ZZZP2ZZZX0ZZZZ05EEE@000000EEEE
0080oooo00@0ZZZZ0?ooo`1EEED0ZZZZ0P3oool01P1EEED0oooo05EEE@2ZZZX0oooo0:ZZZP<0oooo
00@000000:ZZZP00000000000`2ZZZX00`3oool000000:ZZZP050:ZZZP030000003oool0ZZZZ00H0
oooo2P3AcJT80?ooo`040000002ZZZX0oooo0?ooo`80EEEE00P0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP3o
ool0ZZZZ05EEE@80oooo00@0000005EEE@3oool0oooo0P0000001P2ZZZX0oooo0?ooo`3oool0ZZZZ
05EEE@80oooo00P0EEEE0?ooo`3oool0oooo05EEE@2ZZZX000000:ZZZP80oooo00D0EEEE0000003o
ool0oooo05EEE@020?ooo`070:ZZZP1EEED0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP020?ooo`0405EEE@00
0000oooo0:ZZZPH0oooo2P3AcJT70?ooo`0;05EEE@2ZZZX0EEEE0?ooo`000000oooo05EEE@2ZZZX0
EEEE0:ZZZP1EEED00P0000020:ZZZP80EEEE0P2ZZZX01@3oool0EEEE05EEE@1EEED0oooo0080EEEE
00<0oooo0000000000000P1EEED2000000040?ooo`1EEED0EEEE0?ooo`<0EEEE0`2ZZZX205EEE@08
0:ZZZP00000000000000001EEED0ZZZZ0?ooo`2ZZZX205EEE@060000003oool0EEEE0:ZZZP1EEED0
ZZZZ1P3oool:0=7=Z@H0oooo00P0EEEE0?ooo`1EEED0ZZZZ0000003oool000000:ZZZP80EEEE00@0
ZZZZ000000000000EEEE0`3oool00`1EEED0ZZZZ0:ZZZP030:ZZZP80EEEE00H0ZZZZ0?ooo`1EEED0
EEEE0?ooo`2ZZZX20?ooo`80EEEE00@0oooo05EEE@1EEED0EEEE0P2ZZZX0101EEED0ZZZZ0:ZZZP2Z
ZZX20?ooo`80EEEE0P0000020:ZZZP0905EEE@2ZZZX0oooo0?ooo`000000ZZZZ05EEE@3oool0ZZZZ
00H0oooo2P3AcJT60?ooo`80000000<0ZZZZ05EEE@1EEED00P0000001@1EEED000000:ZZZP3oool0
000000<0EEEE00D0oooo05EEE@1EEED0oooo0:ZZZP0305EEE@80000000@0EEEE0:ZZZP2ZZZX0oooo
0P1EEED00`000000EEEE0:ZZZP020:ZZZP<0000000D0oooo05EEE@1EEED0ZZZZ0?ooo`0205EEE@04
0?ooo`1EEED0EEEE05EEE@80oooo00<0EEEE0000001EEED00P00000205EEE@030:ZZZP000000ZZZZ
00H0oooo303AcJT000/0dLfY1P3oool00`000000oooo05EEE@040:ZZZP040000003oool0EEEE05EE
E@<0ZZZZ00L0oooo0:ZZZP2ZZZX0oooo0000001EEED000000080oooo00L000000:ZZZP1EEED00000
0:ZZZP000000ZZZZ0080oooo0`2ZZZX010000000EEEE0:ZZZP0000020?ooo`030000001EEED00000
00L0ZZZZ00@0EEEE0?ooo`3oool000000`2ZZZX00`3oool0EEEE0?ooo`070?ooo`X0dLfY1P3oool0
10000000EEEE0?ooo`2ZZZX205EEE@80oooo00L0ZZZZ05EEE@2ZZZX0oooo0:ZZZP1EEED0ZZZZ00@0
oooo00<0EEEE0000001EEED00P2ZZZX01@3oool0EEEE0000001EEED0ZZZZ00@0oooo0P1EEED01@00
0000EEEE0?ooo`2ZZZX0oooo00<0EEEE103oool205EEE@070:ZZZP3oool0ZZZZ05EEE@2ZZZX0oooo
0:ZZZP0205EEE@80oooo00<0EEEE0?ooo`3oool01@3oool:0=7=Z@H0oooo00<0000005EEE@000000
0`3oool01P1EEED0ZZZZ0:ZZZP000000oooo0:ZZZP<0000000T0EEEE0:ZZZP1EEED0ZZZZ0000002Z
ZZX0EEEE0:ZZZP1EEED00`2ZZZX0101EEED0000005EEE@3oool405EEE@050:ZZZP1EEED0ZZZZ05EE
E@2ZZZX00P1EEED01P000000ZZZZ0:ZZZP2ZZZX0EEEE0:ZZZP8000000P3oool30:ZZZP0605EEE@3o
ool0oooo0:ZZZP000000EEEE1`3oool:0=7=Z@H0oooo00@000000:ZZZP1EEED0EEEE0`3oool01`1E
EED0ZZZZ0:ZZZP1EEED0oooo05EEE@3oool00`1EEED30:ZZZP@0EEEE00P0000005EEE@2ZZZX00000
0:ZZZP000000ZZZZ05EEE@<0000000H0ZZZZ05EEE@000000EEEE0:ZZZP1EEED30:ZZZP@0EEEE00@0
oooo05EEE@3oool0EEEE0P2ZZZX01`1EEED0oooo0?ooo`3oool0ZZZZ05EEE@2ZZZX01`3oool:0=7=
Z@H0oooo0180000005EEE@3oool0oooo0000002ZZZX000000:ZZZP3oool0000005EEE@000000oooo
0:ZZZP000000ZZZZ0000002ZZZX2000000030:ZZZP3oool0oooo00<0ZZZZ00<0000005EEE@000000
0P2ZZZX01P3oool0ZZZZ0000001EEED000000?ooo`80ZZZZ0`3oool2000000060?ooo`000000ZZZZ
0?ooo`2ZZZX0oooo0P1EEED00`2ZZZX0oooo0:ZZZP020:ZZZP040000002ZZZX0oooo05EEE@L0oooo
303AcJT000/0dLfY203oool40:ZZZP0705EEE@00000000000?ooo`000000EEEE0?ooo`0200000004
0:ZZZP1EEED0oooo0?ooo`80ZZZZ0P3oool20:ZZZP030000002ZZZX0oooo0080ZZZZ0P0000000`2Z
ZZX0EEEE0?ooo`050:ZZZP060?ooo`2ZZZX0ZZZZ0?ooo`2ZZZX0EEEE0P2ZZZX01@000000oooo0?oo
o`000000EEEE008000001@2ZZZX80?ooo`X0dLfY203oool0102ZZZX0oooo0000001EEED20?ooo`07
0:ZZZP1EEED0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP030?ooo`0505EEE@2ZZZX0ZZZZ0:ZZZP1EEED00P3o
ool00`1EEED0ZZZZ05EEE@060?ooo`0305EEE@2ZZZX0oooo0080oooo00@000000:ZZZP2ZZZX0ZZZZ
0P1EEED20?ooo`80EEEE00/0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP3oool0ZZZZ05EEE@000000oooo0:ZZ
ZP080?ooo`X0dLfY203oool20:ZZZP0305EEE@3oool000000080EEEE00T0oooo05EEE@000000oooo
05EEE@2ZZZX0oooo05EEE@0000000P2ZZZX0101EEED0oooo05EEE@0000030:ZZZP040000001EEED0
EEEE0:ZZZP80EEEE00T0ZZZZ0000002ZZZX0oooo0:ZZZP000000ZZZZ0?ooo`1EEED00P2ZZZX205EE
E@040?ooo`1EEED0EEEE0?ooo`80EEEE00<0000005EEE@1EEED00P3oool00`1EEED0oooo0:ZZZP08
0?ooo`X0dLfY203oool01@2ZZZX0oooo0:ZZZP3oool0ZZZZ00<0EEEE0P3oool20:ZZZP80EEEE1P2Z
ZZX405EEE@040:ZZZP1EEED0oooo0?ooo`80000000<0oooo0000001EEED00P2ZZZX305EEE@H0ZZZZ
00<0EEEE0:ZZZP2ZZZX00P2ZZZX02@3oool0ZZZZ05EEE@1EEED0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP08
0?ooo`X0dLfY203oool60:ZZZP030?ooo`2ZZZX000000080ZZZZ0P1EEED00`2ZZZX0oooo0:ZZZP02
0:ZZZP040?ooo`2ZZZX0ZZZZ00000080ZZZZ00H000000:ZZZP1EEED000000:ZZZP3oool200000005
0:ZZZP000000oooo0:ZZZP0000001@2ZZZX20?ooo`060:ZZZP1EEED0EEEE0:ZZZP1EEED000000P3o
ool40:ZZZP030000002ZZZX0oooo00L0oooo303AcJT000/0dLfY2`3oool010000000oooo0:ZZZP2Z
ZZX20?ooo`0;0000002ZZZX0ZZZZ05EEE@3oool0ZZZZ05EEE@000000oooo05EEE@3oool0102ZZZX0
1@3oool000000:ZZZP2ZZZX0oooo0080ZZZZ00<0EEEE0000003oool00`2ZZZX01`000000oooo0:ZZ
ZP3oool000000?ooo`2ZZZX00P3oool20:ZZZP0305EEE@3oool0oooo0080ZZZZ00@0oooo0000003o
ool000002@3oool:0=7=Z@T0oooo00<0EEEE0?ooo`3oool00P1EEED01`2ZZZX0oooo0:ZZZP1EEED0
ZZZZ0?ooo`2ZZZX00P1EEED01@2ZZZX000000?ooo`000000oooo0080EEEE00H000000?ooo`1EEED0
ZZZZ0000001EEED20000000305EEE@2ZZZX0ZZZZ0080EEEE00<0000005EEE@3oool00`3oool01000
0000ZZZZ05EEE@1EEED20?ooo`070:ZZZP1EEED0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP020?ooo`030000
003oool0oooo00L0oooo2P3AcJT90?ooo`0805EEE@2ZZZX0ZZZZ0:ZZZP000000oooo0:ZZZP000002
0:ZZZP030000002ZZZX0EEEE0080EEEE00H0oooo0:ZZZP2ZZZX0ZZZZ05EEE@00000205EEE@040?oo
o`2ZZZX0ZZZZ05EEE@80ZZZZ00H0EEEE0:ZZZP2ZZZX0oooo0:ZZZP1EEED2000000030:ZZZP1EEED0
ZZZZ0080oooo0P1EEED01`3oool000000:ZZZP3oool000000:ZZZP3oool00P0000020:ZZZP030000
003oool0oooo00L0oooo2P3AcJT90?ooo`0;0:ZZZP1EEED0EEEE0:ZZZP1EEED0ZZZZ0000003oool0
EEEE0:ZZZP1EEED00P2ZZZX00`1EEED0ZZZZ05EEE@0305EEE@040:ZZZP1EEED0ZZZZ0:ZZZP80EEEE
0P3oool0101EEED0oooo0?ooo`3oool205EEE@80ZZZZ00@0EEEE0:ZZZP1EEED0ZZZZ101EEED01P2Z
ZZX0EEEE05EEE@2ZZZX000000?ooo`80ZZZZ101EEED00`000000oooo0?ooo`070?ooo`X0dLfY2@3o
ool00`1EEED0ZZZZ0000000400000080EEEE00D0ZZZZ0000002ZZZX0000005EEE@040000000505EE
E@3oool0EEEE0000002ZZZX00P1EEED20:ZZZP80000000@0ZZZZ05EEE@1EEED0EEEE0P000000101E
EED0ZZZZ05EEE@1EEED200000080EEEE00L000000?ooo`000000ZZZZ0?ooo`1EEED0ZZZZ00800000
00@0EEEE0000002ZZZX000002@3oool<0=7=Z@002`3AcJT:0?ooo`80ZZZZ00D000000:ZZZP000000
ZZZZ000000040:ZZZP80oooo0`2ZZZX01P000000EEEE0?ooo`000000ZZZZ000000<0oooo00D00000
05EEE@2ZZZX0000005EEE@030?ooo`050:ZZZP000000000005EEE@3oool00P2ZZZX30?ooo`@0ZZZZ
00D000000:ZZZP000000ZZZZ0?ooo`020:ZZZPX0oooo2P3AcJT:0?ooo`0;0:ZZZP3oool0000005EE
E@2ZZZX0oooo0:ZZZP1EEED0ZZZZ0?ooo`2ZZZX00P1EEED50?ooo`80ZZZZ00h000000?ooo`3oool0
00000?ooo`000000oooo05EEE@000000oooo0000003oool0ZZZZ00000080ZZZZ103oool00`2ZZZX0
EEEE05EEE@020?ooo`060:ZZZP1EEED0ZZZZ0?ooo`2ZZZX0EEEE0P3oool00`2ZZZX0oooo0?ooo`08
0?ooo`X0dLfY2P3oool00`2ZZZX0oooo0:ZZZP020:ZZZP@0EEEE00<000000:ZZZP3oool00P1EEED0
0`3oool0ZZZZ0:ZZZP030?ooo`80EEEE0P2ZZZX30?ooo`030000003oool0ZZZZ00<0ZZZZ00L0EEEE
0?ooo`1EEED0oooo0000002ZZZX0oooo0080EEEE00L0oooo05EEE@000000EEEE0:ZZZP1EEED0oooo
0080ZZZZ0P3oool00`2ZZZX0oooo0?ooo`080?ooo`X0dLfY2P3oool00`2ZZZX0EEEE05EEE@020:ZZ
ZP060?ooo`000000EEEE05EEE@3oool0EEEE0`2ZZZX00`000000EEEE0?ooo`070:ZZZP80oooo0P2Z
ZZX00`3oool0EEEE0:ZZZP040:ZZZP0405EEE@2ZZZX0EEEE05EEE@8000000`2ZZZX00`3oool0EEEE
0000000200000080ZZZZ00<0oooo05EEE@2ZZZX02P3oool:0=7=Z@X0oooo00X0ZZZZ0000003oool0
000005EEE@000000EEEE0000001EEED0ZZZZ0`1EEED00`3oool0ZZZZ0?ooo`02000000030:ZZZP00
0000EEEE00<0EEEE00H0ZZZZ05EEE@2ZZZX0000005EEE@3oool405EEE@060000002ZZZX000000000
003oool0ZZZZ0`1EEED20:ZZZP<0EEEE00H0000005EEE@000000oooo0000002ZZZX:0?ooo``0dLfY
000;0=7=Z@/0oooo00<0000005EEE@3oool00`2ZZZX00`1EEED0ZZZZ0:ZZZP020:ZZZP040000002Z
ZZX0ZZZZ0:ZZZP8000000P2ZZZX02@3oool0000005EEE@000000oooo05EEE@2ZZZX0oooo05EEE@02
00000080EEEE00@0oooo0:ZZZP0000000000102ZZZX00`000000ZZZZ0:ZZZP020:ZZZP040?ooo`2Z
ZZX0ZZZZ0:ZZZP80oooo00<000000?ooo`3oool02@3oool:0=7=Z@/0oooo00X000000?ooo`3oool0
ZZZZ05EEE@2ZZZX0oooo0:ZZZP1EEED0ZZZZ0P3oool02P1EEED00000000000000000EEEE0:ZZZP1E
EED0oooo0000001EEED30?ooo`80EEEE0`3oool01P1EEED0oooo0?ooo`1EEED0oooo05EEE@<00000
00<0ZZZZ0?ooo`3oool00P1EEED0202ZZZX0oooo0:ZZZP1EEED0ZZZZ0?ooo`1EEED000002`3oool:
0=7=Z@/0oooo00H000000?ooo`2ZZZX0EEEE0000002ZZZX205EEE@030?ooo`2ZZZX0EEEE00<0EEEE
00/0ZZZZ0000003oool0EEEE0:ZZZP1EEED0oooo0000003oool0000005EEE@020?ooo`0=05EEE@3o
ool0oooo0000002ZZZX0EEEE0:ZZZP1EEED0oooo0000002ZZZX0EEEE0?ooo`0205EEE@80oooo00P0
EEEE0?ooo`2ZZZX0oooo05EEE@2ZZZX0EEEE000000/0oooo2P3AcJT;0?ooo`040000001EEED0ZZZZ
05EEE@<0oooo0P1EEED30:ZZZP030?ooo`1EEED0oooo0080EEEE1P2ZZZX01@1EEED000000:ZZZP2Z
ZZX0000000L0ZZZZ0P1EEED00`3oool0EEEE0:ZZZP020:ZZZP@0EEEE0P3oool0101EEED0ZZZZ0:ZZ
ZP00000;0?ooo`X0dLfY2`3oool01P000000EEEE0000003oool0ZZZZ0?ooo`80ZZZZ00@0EEEE0:ZZ
ZP3oool0oooo0`000000102ZZZX0000005EEE@0000030?ooo`030:ZZZP000000oooo0080ZZZZ00X0
oooo0000002ZZZX0oooo0:ZZZP3oool000000:ZZZP000000ZZZZ0P0000003@2ZZZX0oooo0?ooo`00
0000EEEE0:ZZZP000000oooo0:ZZZP3oool0000005EEE@0000002`3oool<0=7=Z@002`3AcJT<0?oo
o`030000002ZZZX0ZZZZ0080ZZZZ0P1EEED01@3oool000000?ooo`2ZZZX0EEEE00<0ZZZZ00@0oooo
0:ZZZP2ZZZX0ZZZZ101EEED00`000000ZZZZ0:ZZZP0200000080EEEE00D000000:ZZZP2ZZZX0ZZZZ
0?ooo`050:ZZZP030?ooo`2ZZZX0oooo0080EEEE102ZZZX00`1EEED0oooo0?ooo`0:0?ooo`X0dLfY
303oool205EEE@070:ZZZP3oool0ZZZZ05EEE@2ZZZX0oooo0:ZZZP0205EEE@80oooo00@0EEEE0?oo
o`1EEED0ZZZZ0`3oool405EEE@030?ooo`1EEED0EEEE00<0EEEE0`3oool205EEE@040?ooo`1EEED0
oooo0:ZZZP80EEEE0P3oool01@2ZZZX0EEEE0:ZZZP3oool0ZZZZ0080EEEE303oool:0=7=Z@`0oooo
00<0EEEE0:ZZZP3oool00P1EEED20:ZZZP0605EEE@2ZZZX0oooo0000002ZZZX0EEEE0`2ZZZX01`3o
ool0ZZZZ05EEE@000000ZZZZ0000002ZZZX0103oool03P2ZZZX000000:ZZZP2ZZZX0EEEE0:ZZZP00
0000ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP000000oooo0P1EEED01`2ZZZX0EEEE05EEE@000000oooo0:ZZ
ZP1EEED0303oool:0=7=Z@`0oooo0`2ZZZX200000080EEEE00D0000005EEE@2ZZZX0oooo0:ZZZP02
0000000305EEE@3oool0ZZZZ00<0EEEE00H0oooo0000003oool0EEEE0000003oool205EEE@030000
003oool0ZZZZ00<0EEEE00T0oooo05EEE@000000000005EEE@3oool0ZZZZ05EEE@0000000P1EEED0
1@000000EEEE0:ZZZP2ZZZX0EEEE00`0oooo2P3AcJT<0?ooo`0305EEE@3oool0oooo008000000`2Z
ZZX205EEE@80000000L0oooo05EEE@000000EEEE0:ZZZP000000ZZZZ0080EEEE00@000000:ZZZP00
0000oooo0P0000003@2ZZZX0000005EEE@000000ZZZZ0000003oool0EEEE0000001EEED0oooo05EE
E@0000000P1EEED30:ZZZP050000003oool0oooo0?ooo`1EEED0303oool<0=7=Z@002`3AcJT=0?oo
o`040000003oool000000?ooo`80ZZZZ00<0EEEE0:ZZZP2ZZZX00P0000000`2ZZZX000000:ZZZP02
0?ooo`030000003oool000000080ZZZZ00H0EEEE0?ooo`3oool000000?ooo`1EEED30:ZZZP060?oo
o`00000000000?ooo`2ZZZX000000P2ZZZX01@000000ZZZZ0000001EEED0ZZZZ00@0oooo00<00000
0?ooo`3oool02`3oool:0=7=Z@d0oooo00P0000005EEE@3oool0ZZZZ05EEE@2ZZZX0oooo0:ZZZP80
EEEE0P3oool0102ZZZX0oooo0?ooo`1EEED50?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool0EEEE0P3oool01P000000oooo05EEE@2ZZZX0oooo0:ZZZP80EEEE0P3oool01P2ZZZX0EEEE
0:ZZZP3oool0EEEE000000d0oooo2P3AcJT=0?ooo`0@0000001EEED0EEEE0000001EEED0oooo0:ZZ
ZP000000EEEE0000002ZZZX0EEEE0:ZZZP000000oooo0:ZZZP80EEEE0`0000001@2ZZZX0EEEE0:ZZ
ZP2ZZZX0EEEE00<000000`1EEED01@2ZZZX0oooo0000002ZZZX0EEEE0080000000D0EEEE0:ZZZP2Z
ZZX0oooo05EEE@020000000305EEE@000000oooo00`0oooo2P3AcJT=0?ooo`030000002ZZZX0EEEE
0080EEEE00D0ZZZZ05EEE@1EEED0EEEE0:ZZZP030?ooo`040:ZZZP3oool0ZZZZ00000080ZZZZ00D0
EEEE0000002ZZZX0oooo05EEE@020?ooo`80000000D0EEEE0000002ZZZX000000:ZZZP040?ooo`80
ZZZZ0`1EEED20:ZZZP80EEEE00<0ZZZZ0000003oool0303oool:0=7=Z@d0oooo00<0000005EEE@2Z
ZZX01@2ZZZX0101EEED000000000002ZZZX30?ooo`040000002ZZZX0EEEE0:ZZZP80000000@0EEEE
0000002ZZZX0ZZZZ1@0000000`1EEED0ZZZZ0:ZZZP030?ooo`80ZZZZ00<0000005EEE@2ZZZX0102Z
ZZX00`3oool0EEEE0000000=0?ooo``0dLfY000;0=7=Z@h0oooo00@0EEEE0000002ZZZX000000P3o
ool30:ZZZP0505EEE@3oool0ZZZZ0:ZZZP1EEED00P0000020:ZZZP040?ooo`1EEED0000005EEE@80
oooo00@0EEEE0:ZZZP1EEED0oooo0P2ZZZX00`000000EEEE05EEE@020:ZZZP80oooo0`2ZZZX20?oo
o`80ZZZZ00<0000005EEE@3oool03@3oool:0=7=Z@h0oooo0P1EEED01@2ZZZX0oooo0:ZZZP1EEED0
ZZZZ0080oooo0P1EEED00`2ZZZX0oooo0?ooo`0205EEE@060:ZZZP3oool0000005EEE@3oool0EEEE
0P0000000`1EEED0oooo05EEE@02000000030:ZZZP1EEED0oooo0080oooo00<0ZZZZ05EEE@2ZZZX0
0P3oool205EEE@030:ZZZP3oool0ZZZZ0080EEEE3P3oool:0=7=Z@h0oooo00d0EEEE000000000000
oooo0000001EEED0oooo0:ZZZP000000ZZZZ05EEE@2ZZZX0000000<0ZZZZ00D0EEEE0:ZZZP3oool0
ZZZZ0?ooo`0405EEE@80ZZZZ00<0oooo0:ZZZP1EEED00`2ZZZX00`000000ZZZZ05EEE@0200000080
ZZZZ00@0EEEE0000002ZZZX000000P1EEED>0?ooo`X0dLfY3P3oool02@1EEED0ZZZZ05EEE@1EEED0
ZZZZ05EEE@2ZZZX0EEEE0:ZZZP0405EEE@<0ZZZZ0P3oool00`2ZZZX0oooo0:ZZZP020000000:05EE
E@000000ZZZZ0?ooo`2ZZZX0EEEE0?ooo`2ZZZX000000:ZZZP@0EEEE00@0ZZZZ05EEE@2ZZZX0EEEE
0P2ZZZX00`1EEED0ZZZZ05EEE@0>0?ooo`X0dLfY3P3oool00`1EEED000000000000300000080oooo
0P2ZZZX00`000000EEEE0000000205EEE@050:ZZZP3oool0EEEE0:ZZZP1EEED00P2ZZZX00`1EEED0
00000:ZZZP0205EEE@040:ZZZP000000oooo0:ZZZP@0EEEE00@000000:ZZZP2ZZZX0oooo1@000002
05EEE@h0oooo303AcJT000/0dLfY3`3oool0102ZZZX0oooo0:ZZZP0000040:ZZZP050000001EEED0
oooo0:ZZZP3oool00P2ZZZX40?ooo`80000000@0EEEE000000000000ZZZZ0P3oool00`000000oooo
0:ZZZP020?ooo`0305EEE@3oool0EEEE00D0ZZZZ0P0000000`3oool0ZZZZ0?ooo`0>0?ooo`X0dLfY
4@3oool0101EEED0ZZZZ0?ooo`2ZZZX205EEE@80oooo00<0ZZZZ0000000000000P2ZZZX00`1EEED0
oooo0?ooo`0205EEE@040:ZZZP3oool0ZZZZ0:ZZZP80EEEE0P3oool0201EEED0ZZZZ05EEE@000000
EEEE0:ZZZP3oool0ZZZZ0P1EEED20?ooo`040:ZZZP000000oooo0:ZZZPl0oooo2P3AcJT@0?ooo`80
ZZZZ0P0000000`2ZZZX0EEEE0000000205EEE@070?ooo`2ZZZX0oooo0:ZZZP000000EEEE0:ZZZP03
05EEE@040:ZZZP1EEED0ZZZZ0:ZZZP<0EEEE00L0000005EEE@000000EEEE0?ooo`2ZZZX0oooo0080
EEEE00<0000005EEE@1EEED00P0000030:ZZZPl0oooo2P3AcJT?0?ooo`0905EEE@3oool0ZZZZ0:ZZ
ZP000000oooo0000002ZZZX0EEEE00@0ZZZZ00@0oooo05EEE@000000ZZZZ0P1EEED01@2ZZZX0oooo
0?ooo`2ZZZX0oooo00<0EEEE0P000000101EEED0ZZZZ0:ZZZP1EEED40:ZZZP070000003oool00000
0:ZZZP1EEED0oooo0:ZZZP0?0?ooo`X0dLfY3`3oool00`000000ZZZZ000000030:ZZZP80000000P0
EEEE0:ZZZP1EEED0ZZZZ0?ooo`2ZZZX0000005EEE@@0ZZZZ00D000000?ooo`1EEED0000005EEE@02
0:ZZZP80EEEE00H000000?ooo`3oool0ZZZZ05EEE@2ZZZX4000000D0ZZZZ3`3oool<0=7=Z@002`3A
cJT@0?ooo`0305EEE@2ZZZX0ZZZZ00H0ZZZZ00H000000:ZZZP2ZZZX0EEEE0:ZZZP3oool20:ZZZP80
oooo00@000000:ZZZP2ZZZX000000P3oool01@2ZZZX0oooo0?ooo`2ZZZX0oooo0080ZZZZ00<00000
0:ZZZP2ZZZX01@2ZZZX00`000000EEEE0?ooo`0?0?ooo`X0dLfY403oool205EEE@030:ZZZP3oool0
ZZZZ0080EEEE0P3oool0102ZZZX0EEEE0:ZZZP0000050?ooo`050000001EEED0oooo0?ooo`1EEED0
1P3oool20:ZZZP0405EEE@2ZZZX0oooo0:ZZZP80EEEE0P3oool00`2ZZZX0EEEE05EEE@0@0?ooo`X0
dLfY403oool205EEE@80000000D0EEEE0000003oool000000:ZZZP0205EEE@050000003oool0EEEE
0?ooo`1EEED00`2ZZZX205EEE@030000001EEED0ZZZZ0080ZZZZ0P3oool01P1EEED0ZZZZ00000000
0000EEEE0:ZZZP80oooo00@0000005EEE@00000000000P1EEED@0?ooo`X0dLfY403oool01P1EEED0
ZZZZ0:ZZZP1EEED0000005EEE@80ZZZZ0`1EEED30:ZZZP0405EEE@000000ZZZZ0:ZZZP80EEEE0P3o
ool02P1EEED0ZZZZ0:ZZZP2ZZZX0000005EEE@2ZZZX0EEEE0:ZZZP00000205EEE@80ZZZZ00<0EEEE
0000001EEED00P2ZZZX00`1EEED0oooo0?ooo`0>0?ooo`X0dLfY403oool205EEE@070:ZZZP3oool0
oooo0?ooo`1EEED0000005EEE@020:ZZZP0:0?ooo`2ZZZX0ZZZZ0:ZZZP1EEED000000?ooo`1EEED0
00000:ZZZP80000000<0ZZZZ0?ooo`0000000`2ZZZX010000000oooo0:ZZZP2ZZZX305EEE@<0oooo
00<0ZZZZ05EEE@1EEED0403oool<0=7=Z@002`3AcJTA0?ooo`@0ZZZZ00<0EEEE0:ZZZP2ZZZX00P2Z
ZZX01@000000oooo0?ooo`2ZZZX0000000D0ZZZZ00@000000?ooo`2ZZZX000000`2ZZZX00`000000
ZZZZ0?ooo`020?ooo`@0ZZZZ00<0EEEE0:ZZZP2ZZZX00P2ZZZXA0?ooo`X0dLfY4`3oool010000000
ZZZZ0?ooo`3oool205EEE@030:ZZZP3oool0ZZZZ00L0oooo00@0EEEE0000001EEED0EEEE1P3oool0
1P1EEED0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP80oooo00@0EEEE0000003oool0ZZZZ4@3oool:0=7=ZA<0
oooo0`1EEED01@000000EEEE0?ooo`2ZZZX000000080EEEE0`2ZZZX00`3oool0EEEE0000000205EE
E@060000001EEED0ZZZZ05EEE@3oool000000P2ZZZX205EEE@0:0000002ZZZX0oooo0?ooo`000000
EEEE0?ooo`1EEED0oooo0:ZZZQ40oooo2P3AcJTA0?ooo`0305EEE@3oool0ZZZZ0080ZZZZ00L0EEEE
0:ZZZP1EEED0ZZZZ0?ooo`000000ZZZZ0080EEEE00@0oooo05EEE@2ZZZX0oooo1@1EEED00`2ZZZX0
EEEE0?ooo`0205EEE@040?ooo`000000ZZZZ0:ZZZP<0EEEE00D0ZZZZ0?ooo`2ZZZX0oooo0:ZZZP0A
0?ooo`X0dLfY4@3oool00`000000oooo0?ooo`040?ooo`040:ZZZP0000000000000000@0ZZZZ0P1E
EED01P2ZZZX0oooo0:ZZZP2ZZZX0oooo00000080EEEE102ZZZX00`000000EEEE000000020:ZZZPD0
oooo00<0ZZZZ0?ooo`3oool03`3oool<0=7=Z@002`3AcJTB0?ooo`0405EEE@000000ZZZZ0:ZZZP80
00000P3oool30000000505EEE@3oool0EEEE05EEE@3oool00P1EEED20000000305EEE@2ZZZX0oooo
0080EEEE00<0oooo05EEE@2ZZZX00P0000030?ooo`050000002ZZZX000000000001EEED04P3oool:
0=7=ZA80oooo0P1EEED00`2ZZZX0oooo0?ooo`0205EEE@030:ZZZP3oool0ZZZZ0080EEEE0P000000
101EEED0oooo0000000000020?ooo`80000000@0oooo05EEE@00000000000P1EEED01@2ZZZX0oooo
0:ZZZP1EEED0ZZZZ0080oooo0`1EEEDB0?ooo`X0dLfY4P3oool205EEE@030:ZZZP3oool0ZZZZ0080
ZZZZ00@0EEEE0:ZZZP3oool0EEEE0`3oool0102ZZZX0EEEE0000002ZZZX205EEE@80ZZZZ00<0EEEE
0:ZZZP3oool0103oool00`2ZZZX0EEEE0:ZZZP020:ZZZP040?ooo`2ZZZX0EEEE05EEEA80oooo2P3A
cJTB0?ooo`0405EEE@2ZZZX0EEEE0:ZZZP80EEEE0`3oool00`1EEED0oooo0?ooo`020:ZZZP0405EE
E@2ZZZX0ZZZZ0?ooo`80ZZZZ00H0oooo05EEE@2ZZZX0EEEE0?ooo`2ZZZX20?ooo`0605EEE@3oool0
oooo0?ooo`2ZZZX0EEEE0`2ZZZX00`1EEED0oooo0?ooo`0@0?ooo`X0dLfY4P3oool205EEE@050?oo
o`2ZZZX000000?ooo`2ZZZX00P00000205EEE@030:ZZZP1EEED0ZZZZ0080ZZZZ00<0EEEE0:ZZZP3o
ool01@2ZZZX205EEE@80ZZZZ00<0EEEE0:ZZZP0000000P2ZZZX00`000000ZZZZ0?ooo`0205EEEA80
oooo303AcJT000/0dLfY4`3oool00`2ZZZX0oooo000000020:ZZZP030000002ZZZX0oooo0080ZZZZ
0P3oool00`2ZZZX0oooo0?ooo`02000000030:ZZZP000000000000H0oooo102ZZZX2000000040:ZZ
ZP000000ZZZZ0:ZZZQ<0oooo2P3AcJTC0?ooo`040:ZZZP3oool0000005EEE@80oooo00L0ZZZZ05EE
E@2ZZZX0oooo0:ZZZP3oool0ZZZZ0080oooo00<0EEEE0?ooo`3oool01@3oool03@2ZZZX0oooo0:ZZ
ZP3oool0ZZZZ05EEE@2ZZZX0oooo0:ZZZP1EEED000000?ooo`2ZZZX04`3oool:0=7=ZA<0oooo00X0
ZZZZ05EEE@2ZZZX0EEEE0:ZZZP1EEED0oooo0:ZZZP000000ZZZZ1@1EEED20:ZZZP0405EEE@2ZZZX0
ZZZZ0?ooo`80EEEE00d0ZZZZ05EEE@1EEED0ZZZZ0000001EEED0oooo05EEE@000000EEEE0:ZZZP3o
ool0ZZZZ01<0oooo2P3AcJTC0?ooo`080:ZZZP3oool0EEEE0:ZZZP000000oooo0000001EEED20000
00030:ZZZP1EEED0EEEE0080ZZZZ0P1EEED00`2ZZZX0EEEE05EEE@030:ZZZP80EEEE00<0ZZZZ05EE
E@0000000P0000000`3oool0ZZZZ0:ZZZP0205EEE@030:ZZZP3oool0oooo0140oooo2P3AcJTC0?oo
o`030:ZZZP000000ZZZZ0080EEEE00L000000:ZZZP2ZZZX000000?ooo`2ZZZX0EEEE00@0ZZZZ00@0
EEEE0:ZZZP000000EEEE102ZZZX0101EEED0ZZZZ0?ooo`0000020:ZZZP060000001EEED0EEEE0:ZZ
ZP000000ZZZZ4`3oool<0=7=Z@002`3AcJTE0?ooo`0605EEE@3oool0ZZZZ0:ZZZP3oool0EEEE0`2Z
ZZX01P000000ZZZZ0:ZZZP000000ZZZZ0?ooo`80ZZZZ00<0oooo0:ZZZP0000000P2ZZZX01P000000
ZZZZ0:ZZZP2ZZZX0EEEE0?ooo`80ZZZZ00<0oooo05EEE@000000503oool:0=7=ZA@0oooo00<0EEEE
0?ooo`3oool00P1EEED0102ZZZX0oooo0:ZZZP0000020?ooo`070000003oool000000?ooo`1EEED0
oooo0000000205EEE@030000003oool0oooo0080oooo00H0EEEE0:ZZZP3oool0ZZZZ05EEE@2ZZZX2
0?ooo`030000003oool0oooo0180oooo2P3AcJTD0?ooo`0505EEE@000000ZZZZ0:ZZZP1EEED00P2Z
ZZX0103oool0EEEE0000000000020:ZZZP80EEEE00P0oooo05EEE@2ZZZX0oooo0:ZZZP1EEED0ZZZZ
05EEE@80000000L0ZZZZ0?ooo`1EEED0ZZZZ05EEE@3oool0ZZZZ00800000503oool:0=7=ZA@0oooo
00<0ZZZZ05EEE@2ZZZX0103oool205EEE@050?ooo`2ZZZX0oooo0:ZZZP1EEED00`2ZZZX01`1EEED0
ZZZZ05EEE@1EEED0ZZZZ0?ooo`2ZZZX00P3oool205EEE@80oooo00@0EEEE0:ZZZP1EEED00000503o
ool:0=7=ZA@0oooo00@0EEEE0?ooo`2ZZZX00000102ZZZX01@000000ZZZZ05EEE@000000EEEE0080
000000@0oooo0:ZZZP2ZZZX0oooo0P0000001@1EEED0ZZZZ05EEE@2ZZZX0000000@0ZZZZ00@0oooo
0:ZZZP3oool00000503oool<0=7=Z@002`3AcJTE0?ooo`D0ZZZZ0P3oool205EEE@060:ZZZP1EEED0
00000000001EEED0ZZZZ0P3oool0102ZZZX000000000000000020:ZZZP0305EEE@000000oooo00H0
ZZZZ5@3oool:0=7=ZAD0oooo00P0ZZZZ0?ooo`000000EEEE0:ZZZP3oool0ZZZZ05EEE@80ZZZZ0`3o
ool00`2ZZZX0oooo0?ooo`060?ooo`80ZZZZ00D0EEEE0:ZZZP3oool0ZZZZ05EEE@020?ooo`030:ZZ
ZP3oool0oooo01<0oooo2P3AcJTE0?ooo`040:ZZZP3oool0EEEE0?ooo`80ZZZZ00<0oooo05EEE@2Z
ZZX00P2ZZZX00`1EEED0ZZZZ0:ZZZP020?ooo`0605EEE@3oool0EEEE0:ZZZP1EEED000000P2ZZZX0
201EEED0oooo0000002ZZZX0oooo0:ZZZP3oool0ZZZZ5@3oool:0=7=ZAD0oooo01L0ZZZZ05EEE@2Z
ZZX0oooo0:ZZZP1EEED0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP1EEED0ZZZZ05EEE@3oool0ZZZZ05EEE@3o
ool0EEEE0:ZZZP1EEED0ZZZZ05EEE@050:ZZZP80oooo00<0EEEE0:ZZZP3oool0503oool:0=7=ZAD0
oooo00<0ZZZZ0000002ZZZX01@2ZZZX0103oool0EEEE05EEE@0000040:ZZZP050000002ZZZX0ZZZZ
0:ZZZP0000000P1EEED00`3oool0ZZZZ0:ZZZP040:ZZZP030000002ZZZX0oooo01@0oooo303AcJT0
00/0dLfY5P3oool01@000000oooo0000003oool000000080EEEE00<0ZZZZ0000003oool00`2ZZZX0
0`3oool0EEEE000000020?ooo`80ZZZZ00D0oooo0000002ZZZX0000005EEE@020?ooo`030000003o
ool0000001H0oooo2P3AcJTF0?ooo`0:0000003oool0oooo0:ZZZP1EEED0ZZZZ0?ooo`2ZZZX0EEEE
00000080EEEE1@3oool03@000000EEEE05EEE@3oool0EEEE0:ZZZP3oool0ZZZZ05EEE@2ZZZX0oooo
05EEE@0000005P3oool:0=7=ZAH0oooo00@000000:ZZZP2ZZZX000000P1EEED00`2ZZZX0EEEE0?oo
o`020:ZZZP80EEEE0P2ZZZX0101EEED0ZZZZ0?ooo`1EEED20:ZZZP030?ooo`1EEED0ZZZZ0080EEEE
00@000000:ZZZP1EEED000005P3oool:0=7=ZAH0oooo00<0000005EEE@1EEED00P1EEED00`2ZZZX0
EEEE05EEE@030:ZZZP0305EEE@000000EEEE0080ZZZZ0`1EEED30:ZZZP80EEEE0P2ZZZX205EEE@03
0:ZZZP000000oooo01D0oooo2P3AcJTF0?ooo`040000002ZZZX0000005EEE@800000103oool02`00
0000EEEE0000001EEED0oooo0000001EEED0000005EEE@000000ZZZZ0080oooo0`000000101EEED0
000005EEE@00000F0?ooo``0dLfY000;0=7=ZAL0oooo0P2ZZZX0103oool0ZZZZ0000002ZZZX50?oo
o`80ZZZZ00@0oooo0:ZZZP2ZZZX0EEEE1@3oool3000000030?ooo`2ZZZX0oooo01L0oooo2P3AcJTG
0?ooo`070:ZZZP3oool0oooo05EEE@2ZZZX0oooo0:ZZZP0305EEE@030?ooo`000000ZZZZ00800000
00<0ZZZZ05EEE@3oool00`1EEED0102ZZZX0oooo0:ZZZP00000J0?ooo`X0dLfY5`3oool01P2ZZZX0
oooo0?ooo`2ZZZX0oooo05EEE@80ZZZZ0`1EEED0102ZZZX0oooo0000001EEED20?ooo`80EEEE0`2Z
ZZX20?ooo`030:ZZZP3oool0oooo01P0oooo2P3AcJTG0?ooo`030:ZZZP1EEED0oooo0080ZZZZ00@0
oooo05EEE@000000EEEE0P2ZZZX010000000EEEE0:ZZZP2ZZZX205EEE@80ZZZZ00P0EEEE0000001E
EED000000:ZZZP1EEED0oooo05EEEAP0oooo2P3AcJTG0?ooo`050:ZZZP000000oooo0000001EEED0
0P2ZZZX00`000000oooo05EEE@0205EEE@040000002ZZZX0ZZZZ000000@0EEEE00@000000:ZZZP00
0000EEEE0P3oool00`000000oooo0?ooo`0F0?ooo``0dLfY000;0=7=ZAP0oooo00X000000?ooo`3o
ool0ZZZZ0?ooo`1EEED0000005EEE@3oool000000`2ZZZX01@1EEED0ZZZZ05EEE@000000oooo0080
000000H0EEEE0:ZZZP2ZZZX0EEEE0?ooo`00000H0?ooo`X0dLfY603oool020000000EEEE0?ooo`2Z
ZZX0EEEE0:ZZZP3oool0ZZZZ0P3oool20:ZZZP030?ooo`2ZZZX0ZZZZ00D0oooo00H0ZZZZ05EEE@2Z
ZZX0oooo05EEE@00000H0?ooo`X0dLfY603oool010000000EEEE0:ZZZP1EEED40:ZZZP0305EEE@2Z
ZZX000000080EEEE00D0oooo05EEE@2ZZZX0ZZZZ05EEE@030:ZZZP80EEEE00<0oooo05EEE@000000
603oool:0=7=ZAP0oooo00@000000:ZZZP2ZZZX0EEEE0P3oool00`2ZZZX0EEEE0:ZZZP0205EEE@03
0?ooo`2ZZZX0EEEE0080oooo00@0EEEE0:ZZZP2ZZZX0ZZZZ0P3oool205EEE@030:ZZZP000000oooo
01L0oooo2P3AcJTH0?ooo`040000001EEED000000?ooo`<0ZZZZ0P3oool00`2ZZZX000000:ZZZP03
0:ZZZP040?ooo`2ZZZX0oooo0?ooo`<0ZZZZ00@0oooo05EEE@1EEED00000603oool<0=7=Z@002`3A
cJTI0?ooo`0705EEE@2ZZZX0ZZZZ0:ZZZP000000EEEE000000020:ZZZP060?ooo`00000000000?oo
o`000000oooo0P2ZZZX205EEE@050000002ZZZX0ZZZZ0000001EEED06@3oool:0=7=ZAT0oooo0P1E
EED0102ZZZX0oooo0:ZZZP1EEED40?ooo`040000003oool0oooo000000<0oooo00D0000005EEE@2Z
ZZX0oooo0:ZZZP0205EEEAT0oooo2P3AcJTI0?ooo`0905EEE@2ZZZX0oooo0:ZZZP1EEED0000005EE
E@3oool0EEEE0080000000/0oooo05EEE@000000ZZZZ05EEE@3oool0ZZZZ0000001EEED000000?oo
o`0205EEEAT0oooo2P3AcJTI0?ooo`0605EEE@2ZZZX0ZZZZ0000002ZZZX0EEEE0`2ZZZX010000000
EEEE0:ZZZP2ZZZX205EEE@80ZZZZ0P1EEED01@2ZZZX0EEEE0:ZZZP2ZZZX0EEEE01T0oooo2P3AcJTI
0?ooo`0705EEE@3oool0oooo0000003oool000000:ZZZP02000000D0ZZZZ1@0000030?ooo`80EEEE
6@3oool<0=7=Z@002`3AcJTJ0?ooo`030000003oool0000000<0oooo00@000000:ZZZP1EEED0oooo
0P2ZZZX20?ooo`030:ZZZP000000oooo01l0oooo2P3AcJTJ0?ooo`050000001EEED0oooo0:ZZZP1E
EED00P2ZZZX0103oool0ZZZZ05EEE@00000205EEE@030:ZZZP3oool0ZZZZ0080EEEE00<0ZZZZ0?oo
o`1EEED06`3oool:0=7=ZAX0oooo0180000005EEE@1EEED000000:ZZZP1EEED0oooo05EEE@3oool0
EEEE0:ZZZP000000EEEE0:ZZZP1EEED0oooo05EEE@2ZZZX20000000305EEE@3oool0oooo01T0oooo
2P3AcJTJ0?ooo`040000002ZZZX0EEEE05EEE@@0ZZZZ00<0oooo0:ZZZP2ZZZX01`2ZZZX205EEE@03
0:ZZZP3oool0oooo01T0oooo2P3AcJTJ0?ooo`030000001EEED0ZZZZ0080ZZZZ00<0EEEE0000002Z
ZZX01`2ZZZX200000080ZZZZ00<0oooo05EEE@3oool06P3oool<0=7=Z@002`3AcJTK0?ooo`0305EE
E@000000ZZZZ00<0ZZZZ00<0oooo0000002ZZZX00`2ZZZX0101EEED0oooo0:ZZZP0000020:ZZZP03
0000001EEED0oooo01X0oooo2P3AcJTK0?ooo`80EEEE00@0ZZZZ0?ooo`2ZZZX0EEEE103oool01@2Z
ZZX0oooo0000003oool0EEEE0080oooo00<0ZZZZ05EEE@1EEED06`3oool:0=7=ZA/0oooo00<0EEEE
0000000000000`2ZZZX00`000000oooo0?ooo`020:ZZZP80oooo00D000000:ZZZP1EEED0ZZZZ0000
000205EEEA/0oooo2P3AcJTK0?ooo`0905EEE@2ZZZX0EEEE0:ZZZP1EEED0ZZZZ0?ooo`2ZZZX00000
0080ZZZZ00T0000005EEE@3oool0ZZZZ05EEE@2ZZZX0EEEE0:ZZZP1EEED06`3oool:0=7=ZA/0oooo
00H0EEEE00000000000000000?ooo`1EEED800000080EEEE0P00000205EEEA/0oooo303AcJT000/0
dLfY703oool00`000000oooo05EEE@020:ZZZP030000002ZZZX0ZZZZ00@0ZZZZ00@000000:ZZZP3o
ool0EEEE7P3oool:0=7=ZA`0oooo00L0000005EEE@3oool0ZZZZ05EEE@000000EEEE00@0oooo00<0
EEEE0000001EEED00P3oool00`1EEED0oooo0?ooo`0K0?ooo`X0dLfY703oool00`000000EEEE0:ZZ
ZP0205EEE@030:ZZZP1EEED0EEEE00<0EEEE00H000000:ZZZP1EEED0oooo0:ZZZP1EEEDM0?ooo`X0
dLfY703oool00`000000ZZZZ05EEE@0205EEE@050?ooo`1EEED0EEEE0?ooo`2ZZZX00P1EEED01@3o
ool0EEEE0:ZZZP1EEED0ZZZZ01d0oooo2P3AcJTL0?ooo`050000001EEED0ZZZZ0000002ZZZX00P00
00000`1EEED0ZZZZ0000000205EEE@050000002ZZZX000000:ZZZP1EEED07@3oool<0=7=Z@002`3A
cJTM0?ooo`0305EEE@000000ZZZZ0080ZZZZ00@000000?ooo`1EEED0ZZZZ0P3oool30:ZZZP030000
001EEED0oooo01`0oooo2P3AcJTM0?ooo`80EEEE00D0ZZZZ0?ooo`3oool0EEEE0?ooo`0200000004
0?ooo`1EEED0oooo0?ooo`<0EEEE7@3oool:0=7=ZAd0oooo0P1EEED20:ZZZP80EEEE1@0000000`1E
EED0ZZZZ05EEE@0205EEEAd0oooo2P3AcJTM0?ooo`0405EEE@2ZZZX00000000000<0ZZZZ0P1EEED0
102ZZZX0EEEE0:ZZZP0000020:ZZZP0305EEE@3oool0oooo01/0oooo2P3AcJTM0?ooo`80EEEE00<0
ZZZZ05EEE@3oool00P2ZZZX205EEE@030:ZZZP3oool0oooo00@0EEEE7@3oool<0=7=Z@002`3AcJTN
0?ooo`@0ZZZZ00H0EEEE0000002ZZZX0oooo0000001EEED40:ZZZQh0oooo2P3AcJTN0?ooo`040:ZZ
ZP3oool0000000000080oooo00@0EEEE0?ooo`3oool0ZZZZ0P0000000`3oool0ZZZZ0?ooo`0M0?oo
o`X0dLfY7P3oool01`2ZZZX0oooo000000000000EEEE0?ooo`1EEED00P3oool01@1EEED000000000
003oool0ZZZZ01h0oooo2P3AcJTN0?ooo`040:ZZZP3oool0oooo05EEE@80ZZZZ00P0EEEE0:ZZZP2Z
ZZX0ZZZZ05EEE@3oool0EEEE0:ZZZQh0oooo2P3AcJTN0?ooo`040:ZZZP3oool000000:ZZZP800000
00D0ZZZZ0?ooo`00000000000:ZZZP02000000030:ZZZP3oool0oooo01`0oooo303AcJT000/0dLfY
7`3oool02@1EEED000000000002ZZZX0oooo05EEE@2ZZZX0oooo0:ZZZP0200000200oooo2P3AcJTO
0?ooo`<0EEEE0P2ZZZX20?ooo`80ZZZZ0P1EEEDP0?ooo`X0dLfY7`3oool205EEE@<0ZZZZ0P000000
102ZZZX0EEEE0:ZZZP1EEEDP0?ooo`X0dLfY7`3oool00`1EEED0ZZZZ0:ZZZP020?ooo`80EEEE0P3o
ool20:ZZZR00oooo2P3AcJTO0?ooo`80EEEE00@0oooo0:ZZZP2ZZZX0oooo0`2ZZZX00`3oool0EEEE
0?ooo`0O0?ooo``0dLfY000;0=7=ZB00oooo0P2ZZZX010000000oooo05EEE@1EEED20?ooo`80ZZZZ
803oool:0=7=ZB00oooo00<0ZZZZ0?ooo`0000001P3oool00`2ZZZX0oooo0?ooo`0N0?ooo`X0dLfY
803oool01@2ZZZX0oooo05EEE@1EEED0000000<0EEEE00<0oooo0:ZZZP3oool07`3oool:0=7=ZB00
oooo00D0ZZZZ05EEE@1EEED0EEEE0000000405EEE@030:ZZZP3oool0oooo01h0oooo2P3AcJTP0?oo
o`070:ZZZP000000000005EEE@2ZZZX0000005EEE@02000000030:ZZZP3oool0oooo01h0oooo303A
cJT000/0dLfY8@3oool00`000000EEEE0?ooo`0200000080oooo00<000000?ooo`3oool07`3oool:
0=7=ZB40oooo00<000000?ooo`3oool00`3oool00`1EEED000000?ooo`0P0?ooo`X0dLfY8@3oool4
0000000405EEE@000000EEEE00000240oooo2P3AcJTQ0?ooo`080000003oool0oooo0?ooo`2ZZZX0
oooo0:ZZZP00000Q0?ooo`X0dLfY8@3oool00`000000oooo000000020:ZZZP030000001EEED00000
0240oooo303AcJT000/0dLfY8P3oool30:ZZZP0305EEE@2ZZZX0oooo0280oooo2P3AcJTR0?ooo`03
0:ZZZP3oool0EEEE02D0oooo2P3AcJTR0?ooo`040:ZZZP3oool0oooo0:ZZZR@0oooo2P3AcJTR0?oo
o`80ZZZZ00<0EEEE0:ZZZP2ZZZX08`3oool:0=7=ZB80oooo00D0ZZZZ000000000000ZZZZ0000000S
0?ooo``0dLfY000;0=7=ZB<0oooo00@0000005EEE@2ZZZX000008`3oool:0=7=ZB<0oooo00@00000
0?ooo`1EEED000008`3oool:0=7=ZB<0oooo00@000000:ZZZP1EEED000008`3oool:0=7=ZB<0oooo
00@000000?ooo`1EEED000008`3oool:0=7=ZB<0oooo00@000000:ZZZP1EEED000008`3oool<0=7=
Z@002`3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0
oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0
oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo303AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3A
cJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT000/0dLfY00D0oooo0000002ZZZX0
oooo000000020?ooo`P000000P2ZZZX00`3oool0000005EEE@020?ooo`040000003oool0oooo0?oo
o`8000000P1EEED00`000000EEEE05EEE@0905EEE@8000000P1EEED200000080oooo0P0000020?oo
o`0505EEE@000000ZZZZ0:ZZZP3oool02@0000030?ooo`030:ZZZP1EEED0oooo00X0dLfY00<0oooo
0000002ZZZX00P0000040?ooo`030:ZZZP3oool0oooo00<0oooo102ZZZX02@3oool0ZZZZ0:ZZZP3o
ool0EEEE0?ooo`000000EEEE000000020:ZZZP030?ooo`2ZZZX0oooo0080oooo00@0EEEE0?ooo`3o
ool0EEEE1@3oool02@2ZZZX000000000001EEED000000?ooo`1EEED0oooo0:ZZZP020?ooo`040:ZZ
ZP000000ZZZZ05EEE@D0oooo00X0ZZZZ0?ooo`3oool0EEEE0?ooo`1EEED000000:ZZZP1EEED0oooo
2P3AcJT01@3oool00000000000000000EEEE0080ZZZZ00<0000005EEE@2ZZZX00P1EEED20:ZZZP03
05EEE@2ZZZX0oooo0080ZZZZ00@0EEEE0:ZZZP2ZZZX0ZZZZ0`1EEED00`3oool000000?ooo`020?oo
o`050:ZZZP000000000005EEE@0000000P2ZZZX00`000000EEEE00000002000000<0oooo00@00000
0:ZZZP1EEED0EEEE0`2ZZZX00`000000EEEE0:ZZZP020?ooo`80EEEE0P2ZZZX205EEE@040:ZZZP1E
EED000000?ooo`80ZZZZ0P0000000`1EEED0oooo0=7=Z@090=7=Z@030?ooo`00000000000080oooo
00T0EEEE0:ZZZP2ZZZX0ZZZZ0000003oool0000005EEE@2ZZZX00P1EEED00`000000ZZZZ00000002
000000H0ZZZZ00@0EEEE0:ZZZP3oool0oooo0P2ZZZX00`000000oooo0:ZZZP030:ZZZP030?ooo`00
0000ZZZZ00<0oooo00<0ZZZZ05EEE@1EEED01@2ZZZX0203oool000000000001EEED000000:ZZZP1E
EED0ZZZZ0P0000001P3oool000000:ZZZP2ZZZX0oooo05EEE@80oooo00<0000005EEE@3oool02P3A
cJT0103oool000000?ooo`2ZZZX505EEE@030?ooo`1EEED0EEEE00X0EEEE1P00000205EEE@h00000
0P1EEED6000000`0EEEE00X0ZZZZ05EEE@1EEED0oooo05EEE@000000ZZZZ0?ooo`1EEED0oooo303A
cJT000/0dLfY00D0oooo0:ZZZP2ZZZX0ZZZZ05EEE@02000000L0EEEE00L000000:ZZZP2ZZZX0ZZZZ
0000001EEED0oooo00<0EEEE00@0oooo0000001EEED0EEEE0P0000000`1EEED00000000000090000
0080EEEE0P00000205EEE@030000003oool0EEEE0080EEEE00<0000005EEE@0000000`2ZZZX00`00
0000EEEE05EEE@0505EEE@030?ooo`000000EEEE0080ZZZZ0P3oool:0=7=Z@070?ooo`2ZZZX0ZZZZ
0:ZZZP3oool0EEEE0:ZZZP02000000070?ooo`000000000005EEE@000000EEEE0:ZZZP020?ooo`03
0:ZZZP1EEED0ZZZZ0080ZZZZ00P0EEEE0:ZZZP2ZZZX0oooo0:ZZZP3oool0EEEE0:ZZZP80000000<0
oooo0:ZZZP3oool00`3oool01P000000oooo000000000000ZZZZ05EEE@80ZZZZ00@0oooo0:ZZZP2Z
ZZX0EEEE0`2ZZZX0101EEED0ZZZZ05EEE@3oool205EEE@050000002ZZZX000000000003oool00P00
000205EEE@030?ooo`2ZZZX0ZZZZ0080oooo2P3AcJT0103oool0ZZZZ0:ZZZP3oool205EEE@050?oo
o`2ZZZX0ZZZZ05EEE@2ZZZX01@1EEED00`2ZZZX0EEEE0?ooo`020:ZZZP0605EEE@3oool0EEEE05EE
E@2ZZZX0oooo0`1EEED20?ooo`80ZZZZ00<0oooo0:ZZZP2ZZZX00P2ZZZX01`3oool0ZZZZ0:ZZZP1E
EED0oooo05EEE@3oool00P1EEED0202ZZZX0EEEE0:ZZZP3oool0EEEE0?ooo`2ZZZX0oooo0P2ZZZX0
0`000000EEEE05EEE@0205EEE@040:ZZZP000000ZZZZ0:ZZZP80EEEE00<0ZZZZ0?ooo`2ZZZX00P3o
ool:0=7=Z@050?ooo`2ZZZX0ZZZZ0?ooo`2ZZZX00P3oool030000000oooo05EEE@3oool0EEEE0?oo
o`2ZZZX0EEEE0000003oool0EEEE00000080ZZZZ1@0000000`3oool0ZZZZ05EEE@030:ZZZP030?oo
o`1EEED0EEEE0080EEEE00H0000005EEE@3oool0EEEE0?ooo`1EEED20:ZZZP030?ooo`2ZZZX0EEEE
0080000000D0EEEE000000000000EEEE0:ZZZP02000000060?ooo`1EEED0EEEE0:ZZZP3oool0EEEE
0`3oool01P000000oooo0?ooo`000000oooo0:ZZZP80oooo2P3AcJT0103oool0ZZZZ0:ZZZP1EEED2
00000080oooo00<0ZZZZ05EEE@1EEED02`1EEED600000080EEEE3P00000205EEE@H00000301EEED0
203oool0ZZZZ0?ooo`2ZZZX000000?ooo`1EEED0ZZZZ0P3oool<0=7=Z@002`3AcJT30?ooo`0305EE
E@3oool0oooo0080000000H0ZZZZ05EEE@2ZZZX0000005EEE@0000030:ZZZP040000001EEED0EEEE
000000<0oooo00@0000005EEE@1EEED0EEEE0P0000000`1EEED000000000000900000080EEEE0P00
000305EEE@040000003oool0oooo0?ooo`<0EEEE00/0oooo0:ZZZP000000ZZZZ0000001EEED00000
0:ZZZP000000ZZZZ000000020?ooo`030000001EEED0oooo0080oooo2P3AcJT30?ooo`80EEEE00@0
oooo0:ZZZP2ZZZX000000P1EEED00`3oool00000000000030?ooo`030:ZZZP3oool0oooo0080EEEE
0P3oool20:ZZZP0:0?ooo`2ZZZX0oooo0?ooo`000000EEEE0?ooo`000000ZZZZ05EEE@80oooo00L0
EEEE0:ZZZP000000oooo05EEE@000000oooo0080ZZZZ00<0oooo0:ZZZP2ZZZX00P3oool01@1EEED0
oooo0?ooo`3oool0EEEE00<0oooo0P0000001`3oool0EEEE05EEE@000000ZZZZ05EEE@3oool00P1E
EED30?ooo`X0dLfY0`3oool205EEE@040000002ZZZX0EEEE0?ooo`80ZZZZ00<0EEEE0?ooo`000000
0P2ZZZX00`3oool0EEEE0:ZZZP0205EEE@030?ooo`1EEED0EEEE0080EEEE0P0000020:ZZZP800000
00D0EEEE0:ZZZP2ZZZX0EEEE0:ZZZP0305EEE@060:ZZZP1EEED000000000002ZZZX0oooo0P000002
05EEE@0>0000001EEED0oooo0?ooo`1EEED0ZZZZ0000003oool0EEEE0:ZZZP000000ZZZZ05EEE@2Z
ZZX20?ooo`80EEEE00<0000005EEE@1EEED00`3oool:0=7=Z@<0oooo00<0EEEE0000000000000`2Z
ZZX00`000000EEEE0000000205EEE@080:ZZZP3oool0ZZZZ0000002ZZZX0000005EEE@2ZZZX20000
000805EEE@000000ZZZZ05EEE@000000EEEE0:ZZZP00000305EEE@80ZZZZ00<000000:ZZZP2ZZZX0
0P1EEED00`000000ZZZZ05EEE@0205EEE@060:ZZZP000000EEEE0?ooo`000000ZZZZ0P000000202Z
ZZX0oooo0:ZZZP3oool0ZZZZ05EEE@3oool000000P1EEED30:ZZZP030000001EEED0EEEE00<0oooo
2P3AcJT30?ooo`0805EEE@2ZZZX0oooo05EEE@000000ZZZZ05EEE@00000205EEE@030000001EEED0
EEEE00H0EEEE1P00000205EEE@h000000P1EEED6000000P0EEEE00T0000005EEE@1EEED000000?oo
o`2ZZZX0000005EEE@3oool00P1EEED30?ooo``0dLfY000;0=7=Z@@0oooo00<0ZZZZ0000003oool0
0P2ZZZX20?ooo`<0000000<0oooo05EEE@2ZZZX0100000000`3oool0EEEE0?ooo`0400000080EEEE
00<0000005EEE@1EEED02@1EEED200000080EEEE1000000205EEE@060?ooo`00000000000000003o
ool0ZZZZ0P3oool3000000030?ooo`2ZZZX0ZZZZ0080ZZZZ00<000000:ZZZP3oool00`3oool:0=7=
Z@H0oooo00@0ZZZZ05EEE@3oool0ZZZZ0P3oool00`1EEED0oooo0?ooo`020?ooo`030:ZZZP1EEED0
00000080oooo00P0ZZZZ0000003oool0oooo0000003oool000000:ZZZP@0oooo00<0ZZZZ0?ooo`3o
ool00P3oool01P1EEED0oooo0?ooo`2ZZZX0oooo0:ZZZP80oooo00T000000?ooo`3oool000000:ZZ
ZP3oool0ZZZZ0000001EEED02P3oool0101EEED0oooo0?ooo`2ZZZX40?ooo`X0dLfY1P3oool02@00
0000ZZZZ0:ZZZP2ZZZX0oooo05EEE@2ZZZX0oooo0:ZZZP0205EEE@060?ooo`2ZZZX0EEEE0?ooo`00
0000ZZZZ0P3oool30:ZZZP030000003oool0oooo0080oooo00D0ZZZZ05EEE@1EEED0oooo00000002
05EEE@030:ZZZP3oool0EEEE00<0oooo00@0ZZZZ0?ooo`2ZZZX0oooo0P2ZZZX01@000000EEEE05EE
E@2ZZZX0oooo0080EEEE00H0ZZZZ0?ooo`000000EEEE0?ooo`1EEED20:ZZZP0305EEE@3oool0ZZZZ
00@0oooo2P3AcJT50?ooo`@0ZZZZ00T0000005EEE@3oool0oooo0:ZZZP3oool0EEEE0?ooo`000000
0`1EEED0202ZZZX0oooo0000001EEED0oooo0000003oool000000P2ZZZX0203oool0ZZZZ0?ooo`00
0000EEEE0:ZZZP000000EEEE0P3oool40:ZZZP0805EEE@3oool0oooo0?ooo`1EEED0ZZZZ0?ooo`2Z
ZZX305EEE@050:ZZZP3oool0EEEE0?ooo`2ZZZX00P3oool00`1EEED0ZZZZ0:ZZZP040:ZZZP@0oooo
2P3AcJT50?ooo`0405EEE@000000EEEE0?ooo`80000000<0EEEE000000000000201EEED600000080
EEEE3P00000205EEE@H00000201EEED01P000000ZZZZ05EEE@000000ZZZZ0?ooo`<0EEEE00<0ZZZZ
0?ooo`3oool00P3oool<0=7=Z@002`3AcJT40?ooo`0;0000003oool0oooo05EEE@2ZZZX0EEEE0000
003oool000000:ZZZP0000000P3oool0202ZZZX0000005EEE@000000ZZZZ0?ooo`2ZZZX000000`1E
EED20000000305EEE@000000000000T000000P1EEED2000000<0EEEE00@000000?ooo`3oool0ZZZZ
0P1EEED20000000;0?ooo`2ZZZX000000:ZZZP000000oooo0000003oool0ZZZZ05EEE@0000001P3o
ool:0=7=Z@@0oooo00<000000:ZZZP2ZZZX00`3oool30000000505EEE@2ZZZX0EEEE0000002ZZZX0
0P3oool20:ZZZP0605EEE@3oool0EEEE05EEE@3oool0EEEE0P3oool010000000EEEE05EEE@1EEED5
0?ooo`030000001EEED0EEEE0080000000@0oooo05EEE@1EEED0oooo0P1EEED0103oool0EEEE0:ZZ
ZP1EEED20?ooo`0605EEE@000000ZZZZ0:ZZZP1EEED0oooo0P0000030?ooo`0305EEE@2ZZZX0oooo
00@0oooo2P3AcJT40?ooo`090000002ZZZX0oooo05EEE@2ZZZX0oooo0000002ZZZX0oooo0080EEEE
00H0ZZZZ05EEE@3oool0EEEE0:ZZZP1EEED20?ooo`<0000000D0ZZZZ05EEE@1EEED0oooo05EEE@02
0:ZZZP<0EEEE0P000000101EEED0000005EEE@2ZZZX205EEE@80oooo00<0EEEE0?ooo`0000000P00
00020?ooo`0305EEE@2ZZZX0EEEE00D0EEEE0P2ZZZX01P000000oooo0:ZZZP1EEED0oooo0:ZZZPD0
oooo2P3AcJT40?ooo`040000002ZZZX0000005EEE@8000001@2ZZZX00`1EEED0ZZZZ0:ZZZP040?oo
o`80000000@0EEEE0?ooo`1EEED0EEEE0`0000000`2ZZZX0oooo05EEE@020?ooo`80ZZZZ00@0oooo
05EEE@1EEED0oooo0`0000002@3oool0EEEE05EEE@3oool0EEEE0:ZZZP000000oooo0:ZZZP020?oo
o`80ZZZZ00@0EEEE0:ZZZP2ZZZX0EEEE0P2ZZZX01@1EEED0000005EEE@000000ZZZZ00D0oooo2P3A
cJT40?ooo`030000002ZZZX000000080EEEE0P2ZZZX0103oool0000005EEE@00000705EEE@H00000
0P1EEED>00000080EEEE1P00000705EEE@060000001EEED0oooo0?ooo`2ZZZX0oooo0P1EEED00`00
0000ZZZZ0?ooo`040?ooo``0dLfY000;0=7=Z@H0oooo0P2ZZZX00`1EEED00000000000020?ooo`05
0000003oool0oooo0:ZZZP0000000P1EEED0102ZZZX0EEEE05EEE@00000405EEE@80000000<0EEEE
0000000000002@00000205EEE@800000101EEED0103oool0EEEE05EEE@00000205EEE@050?ooo`2Z
ZZX0oooo0?ooo`0000000P3oool00`000000EEEE05EEE@020:ZZZPH0oooo2P3AcJT60?ooo`80EEEE
00T0000005EEE@1EEED0ZZZZ0000003oool0EEEE0?ooo`2ZZZX00P3oool40:ZZZP070?ooo`2ZZZX0
EEEE0?ooo`2ZZZX0EEEE0:ZZZP020000000405EEE@000000EEEE0:ZZZP80EEEE00/0ZZZZ05EEE@00
0000EEEE0:ZZZP000000ZZZZ05EEE@2ZZZX0oooo05EEE@060:ZZZP0=0?ooo`000000ZZZZ0?ooo`1E
EED0oooo0000002ZZZX0EEEE0?ooo`000000EEEE0:ZZZP060?ooo`X0dLfY1P3oool00`1EEED00000
05EEE@020:ZZZP0=0000003oool0ZZZZ05EEE@2ZZZX0oooo05EEE@000000EEEE0000003oool0EEEE
0?ooo`0200000080ZZZZ00<0EEEE0:ZZZP3oool00`3oool30000000305EEE@000000oooo0080oooo
00H0EEEE0?ooo`2ZZZX0EEEE0:ZZZP3oool2000000080:ZZZP1EEED0oooo0?ooo`1EEED000000:ZZ
ZP3oool205EEE@040:ZZZP3oool000000:ZZZP80EEEE00<000000:ZZZP3oool01@3oool:0=7=Z@H0
oooo00<0EEEE0000003oool00`0000000`2ZZZX0EEEE000000030000000305EEE@3oool000000080
EEEE00@000000:ZZZP00000000000`2ZZZX00`1EEED0ZZZZ000000020:ZZZP@000000P2ZZZX00`00
0000oooo05EEE@040:ZZZP030000002ZZZX0ZZZZ00<0EEEE00L0oooo05EEE@3oool000000:ZZZP00
0000EEEE00<0000000@0ZZZZ0?ooo`000000ZZZZ1P3oool:0=7=Z@H0oooo00@0EEEE0000001EEED0
00000P3oool00`1EEED0oooo0000000705EEE@H000000P1EEED>00000080EEEE1P0000000`1EEED0
000005EEE@0405EEE@030000003oool0ZZZZ0080oooo00@0ZZZZ05EEE@000000ZZZZ1P3oool<0=7=
Z@002`3AcJT60?ooo`040000003oool0oooo0?ooo`80ZZZZ00<0oooo05EEE@3oool00P2ZZZX00`00
0000EEEE000000020?ooo`030:ZZZP000000000000<000000P1EEED00`000000EEEE05EEE@0905EE
E@8000000P1EEED4000000030?ooo`2ZZZX0oooo0080000000L0EEEE0:ZZZP2ZZZX000000?ooo`1E
EED0000000<0ZZZZ2@3oool:0=7=Z@H0oooo00D0000005EEE@3oool0oooo0:ZZZP040?ooo`060000
003oool0EEEE05EEE@000000EEEE0P0000000`1EEED0ZZZZ0?ooo`020?ooo`0405EEE@3oool0ZZZZ
0:ZZZP80oooo00<000000?ooo`2ZZZX00P3oool00`1EEED0oooo0?ooo`020:ZZZP030?ooo`000000
oooo0080oooo00<0ZZZZ0000000000000`000000101EEED0oooo0?ooo`2ZZZX20?ooo`0305EEE@3o
ool0ZZZZ0080oooo00<0EEEE0?ooo`3oool01@3oool:0=7=Z@H0oooo00L0000005EEE@000000EEEE
0:ZZZP3oool0000000<0oooo0P1EEED2000000040?ooo`2ZZZX000000?ooo`80ZZZZ00D000000?oo
o`2ZZZX0oooo05EEE@020:ZZZP0905EEE@2ZZZX0oooo0?ooo`2ZZZX0oooo0:ZZZP1EEED0ZZZZ0080
EEEE103oool20:ZZZP8000000P2ZZZX200000080EEEE00T0ZZZZ0?ooo`3oool0ZZZZ0?ooo`2ZZZX0
oooo0000001EEED01`3oool:0=7=Z@H0oooo00P0000005EEE@2ZZZX0ZZZZ0?ooo`2ZZZX0oooo05EE
E@80000000@0EEEE0:ZZZP3oool0oooo0P2ZZZX20000000=05EEE@000000000005EEE@000000ZZZZ
0000003oool0EEEE0?ooo`1EEED0oooo05EEE@020?ooo`0>0:ZZZP3oool0EEEE0:ZZZP000000ZZZZ
0000001EEED0ZZZZ0000001EEED0ZZZZ0000002ZZZX30?ooo`050:ZZZP1EEED0ZZZZ0000001EEED0
0P2ZZZX0103oool0ZZZZ0:ZZZP1EEED70?ooo`X0dLfY1P3oool3000000080?ooo`1EEED0EEEE0:ZZ
ZP3oool0000005EEE@00000305EEE@030?ooo`000000000000D000000P1EEED>00000080EEEE2000
000305EEE@030000001EEED000000080oooo0P1EEED00`3oool00000000000070?ooo``0dLfY000;
0=7=Z@L0oooo00@0EEEE0000003oool0oooo0P000000101EEED000000000003oool4000000030:ZZ
ZP3oool0EEEE00@0EEEE0P0000000`1EEED00000000000020000000405EEE@000000000005EEE@<0
00000P1EEED2000000D0EEEE00<0oooo0:ZZZP3oool00P0000030?ooo`040000001EEED0oooo0000
0080oooo00<0000005EEE@3oool01P3oool:0=7=Z@L0oooo00H0EEEE000000000000EEEE0000003o
ool205EEE@80ZZZZ00@000000?ooo`1EEED0oooo0`2ZZZX00`3oool0EEEE05EEE@020?ooo`@00000
0P3oool00`2ZZZX00000000000020:ZZZP030?ooo`00000000000080000000@0EEEE0?ooo`1EEED0
EEEE0P3oool20:ZZZP060?ooo`1EEED0oooo05EEE@2ZZZX0oooo0`1EEED01@000000EEEE0:ZZZP00
0000EEEE00L0oooo2P3AcJT70?ooo`0805EEE@00000000000:ZZZP1EEED0oooo0:ZZZP0000040?oo
o`0405EEE@2ZZZX0000005EEE@8000000P3oool01P1EEED0oooo0:ZZZP000000ZZZZ05EEE@800000
00<0oooo05EEE@2ZZZX00P3oool01@000000EEEE000000000000ZZZZ0080EEEE0P3oool200000006
05EEE@000000oooo05EEE@3oool0ZZZZ0P3oool01@000000ZZZZ0:ZZZP1EEED0ZZZZ0080000000<0
EEEE0?ooo`3oool01@3oool:0=7=Z@L0oooo00D0EEEE000000000000ZZZZ0?ooo`020:ZZZP800000
0`2ZZZX0201EEED0ZZZZ0:ZZZP2ZZZX0EEEE0?ooo`000000ZZZZ0`1EEED2000000070?ooo`1EEED0
00000?ooo`000000ZZZZ0?ooo`0205EEE@030?ooo`2ZZZX0000000<0EEEE0P0000020?ooo`<0ZZZZ
00X0EEEE0:ZZZP2ZZZX0ZZZZ05EEE@000000ZZZZ05EEE@3oool0ZZZZ0P0000000`1EEED0oooo0?oo
o`050?ooo`X0dLfY1`3oool01`1EEED000000:ZZZP000000EEEE0?ooo`2ZZZX00`00000205EEE@03
0000003oool0EEEE00H000000P1EEED>00000080EEEE1P00000205EEE@070000001EEED0EEEE0000
002ZZZX000000:ZZZP0205EEE@040000003oool0000005EEE@L0oooo303AcJT000/0dLfY2P3oool0
0`000000oooo0:ZZZP02000000030:ZZZP3oool000000080000000<0EEEE0?ooo`0000000P1EEED0
0`000000oooo000000020000000305EEE@000000000000@0000000<0oooo0000001EEED00P000002
05EEE@D0000000@0EEEE000000000000oooo100000020?ooo`80000000@0EEEE0?ooo`0000000000
2@3oool:0=7=Z@`0oooo0`2ZZZX0103oool0ZZZZ0000001EEED20:ZZZP050?ooo`2ZZZX0ZZZZ0?oo
o`2ZZZX00P3oool03@000000ZZZZ05EEE@3oool0EEEE0000003oool0ZZZZ0?ooo`1EEED0ZZZZ05EE
E@0000000`1EEED01@2ZZZX000000?ooo`1EEED0ZZZZ0080oooo00D0ZZZZ0?ooo`2ZZZX0ZZZZ05EE
E@050:ZZZP<0oooo00<000000?ooo`3oool01`3oool:0=7=Z@X0oooo0100ZZZZ05EEE@2ZZZX0EEEE
0:ZZZP1EEED0oooo05EEE@3oool000000:ZZZP1EEED0ZZZZ0?ooo`000000oooo0`2ZZZX01`3oool0
ZZZZ0:ZZZP2ZZZX0EEEE0?ooo`0000000P2ZZZX020000000EEEE05EEE@2ZZZX0oooo0:ZZZP3oool0
EEEE0P2ZZZX01@3oool000000000002ZZZX0EEEE0080000000D0oooo0:ZZZP3oool000000:ZZZP03
05EEE@030:ZZZP000000oooo00P0oooo2P3AcJT:0?ooo`050:ZZZP1EEED000000?ooo`2ZZZX00P3o
ool01`2ZZZX0oooo0:ZZZP3oool0ZZZZ05EEE@2ZZZX00`3oool01@2ZZZX0EEEE0:ZZZP3oool0EEEE
008000000P3oool00`1EEED0ZZZZ0?ooo`0300000080oooo00<0ZZZZ05EEE@2ZZZX0103oool02P1E
EED0ZZZZ05EEE@2ZZZX0oooo0:ZZZP3oool0EEEE0:ZZZP3oool205EEE@030:ZZZP000000oooo00P0
oooo2P3AcJT:0?ooo`030000002ZZZX0oooo0080EEEE00<0oooo0:ZZZP2ZZZX00P2ZZZX00`3oool0
EEEE0000000500000080EEEE3P00000205EEE@H000000P1EEED20:ZZZP0305EEE@2ZZZX0EEEE0080
EEEE0P2ZZZX2000000T0oooo303AcJT000/0dLfY2@3oool0101EEED000000:ZZZP3oool200000008
0:ZZZP1EEED000000000002ZZZX0EEEE0000003oool4000000<0EEEE00X0000005EEE@1EEED0EEEE
0000003oool0ZZZZ0000003oool000000P1EEED2000000<0EEEE00D0oooo00000000000000000?oo
o`02000000050:ZZZP000000ZZZZ05EEE@3oool00P0000000`3oool0ZZZZ0000000:0?ooo`X0dLfY
2@3oool405EEE@030:ZZZP3oool0ZZZZ0080ZZZZ1@3oool00`000000EEEE0:ZZZP020?ooo`0305EE
E@3oool0ZZZZ0080oooo00H0ZZZZ000000000000oooo05EEE@0000020:ZZZP80oooo00<0ZZZZ0?oo
o`3oool00P3oool00`2ZZZX0EEEE000000020?ooo`030000003oool0oooo0080ZZZZ00@0EEEE0?oo
o`2ZZZX0oooo0P1EEED:0?ooo`X0dLfY2@3oool405EEE@040:ZZZP1EEED0oooo0:ZZZP80EEEE00@0
oooo05EEE@2ZZZX0EEEE0P3oool305EEE@030000002ZZZX0oooo00<0EEEE00<0oooo0:ZZZP2ZZZX0
0P2ZZZX01P000000EEEE05EEE@1EEED0oooo0:ZZZP@0EEEE0P3oool02`1EEED0ZZZZ0?ooo`3oool0
EEEE0000002ZZZX0oooo05EEE@2ZZZX000000080EEEE2P3oool:0=7=Z@T0oooo0P1EEED00`000000
EEEE0?ooo`0205EEE@<0ZZZZ00D0EEEE0000002ZZZX000000?ooo`0405EEE@030?ooo`1EEED0ZZZZ
00@0EEEE00@0oooo0:ZZZP1EEED0oooo0`1EEED20:ZZZP0405EEE@000000EEEE0?ooo`80EEEE00D0
ZZZZ0000002ZZZX0oooo05EEE@040:ZZZP0505EEE@3oool0oooo0000001EEED02P3oool:0=7=Z@T0
oooo0P1EEED02P2ZZZX0EEEE05EEE@000000EEEE0:ZZZP3oool000000?ooo`2ZZZX700000080EEEE
3P00000205EEE@L000000P3oool02@000000oooo0:ZZZP2ZZZX0000005EEE@3oool0ZZZZ05EEE@0:
0?ooo``0dLfY000;0=7=Z@/0oooo00<000000?ooo`2ZZZX00P3oool01`000000ZZZZ0?ooo`000000
EEEE0000002ZZZX00`3oool010000000EEEE05EEE@1EEED2000000060?ooo`00000000000000001E
EED0oooo0`0000000`3oool000000000000305EEE@080:ZZZP3oool0oooo0?ooo`2ZZZX0000005EE
E@0000020?ooo`060000002ZZZX0oooo0:ZZZP3oool000002`3oool:0=7=Z@/0oooo00@0000005EE
E@2ZZZX0oooo0P1EEED40?ooo`060:ZZZP3oool0oooo0?ooo`2ZZZX0oooo0P1EEED00`3oool00000
0:ZZZP020:ZZZP8000000P1EEED200000080ZZZZ00D0oooo0000003oool0oooo05EEE@020:ZZZP<0
oooo00<0ZZZZ0?ooo`3oool00P3oool00`1EEED0oooo0?ooo`020:ZZZP030000003oool0oooo00T0
oooo2P3AcJT;0?ooo`040000003oool0oooo05EEE@80oooo00L0ZZZZ05EEE@2ZZZX0EEEE0:ZZZP00
0000ZZZZ0080EEEE00@000000:ZZZP2ZZZX0oooo1@2ZZZX00`1EEED0ZZZZ05EEE@0205EEE@80ZZZZ
00H0EEEE0:ZZZP3oool0oooo0:ZZZP00000205EEE@030:ZZZP000000ZZZZ0080ZZZZ00P0EEEE0000
003oool0ZZZZ05EEE@3oool0ZZZZ000000/0oooo2P3AcJT;0?ooo`8000000`1EEED00`3oool00000
0?ooo`0305EEE@090?ooo`2ZZZX0000005EEE@000000oooo0:ZZZP000000oooo0080ZZZZ0`1EEED0
2`2ZZZX0000005EEE@3oool0EEEE0:ZZZP1EEED0oooo0000001EEED0oooo0080EEEE0P0000001P3o
ool0EEEE0000001EEED0oooo00000080oooo0P1EEED00`2ZZZX000000?ooo`0:0?ooo`X0dLfY2`3o
ool30000000505EEE@3oool0ZZZZ0000003oool00P2ZZZX00`1EEED000000000000400000080EEEE
3P00000205EEE@H0000000H0EEEE0:ZZZP2ZZZX0oooo0000002ZZZX205EEE@030000002ZZZX00000
00/0oooo303AcJT000/0dLfY303oool01`000000oooo0?ooo`000000EEEE0?ooo`2ZZZX00`000004
0?ooo`@000000P1EEED02P000000oooo0000003oool0EEEE0000003oool000000?ooo`00000205EE
E@<000001@3oool010000000EEEE0000002ZZZX205EEE@<0oooo00<0EEEE0?ooo`3oool02P3oool:
0=7=Z@`0oooo00@0ZZZZ05EEE@3oool0EEEE0`2ZZZX02@1EEED000000000001EEED000000:ZZZP3o
ool0ZZZZ0000000205EEE@80oooo00D000000?ooo`1EEED0oooo0:ZZZP040?ooo`090000003oool0
oooo05EEE@2ZZZX0000005EEE@3oool0ZZZZ0080EEEE00P000000:ZZZP1EEED0ZZZZ05EEE@2ZZZX0
EEEE0?ooo`80EEEE303oool:0=7=Z@`0oooo0P2ZZZX205EEE@80oooo00D0ZZZZ0?ooo`2ZZZX0EEEE
0?ooo`02000000080:ZZZP3oool0ZZZZ0:ZZZP3oool000000:ZZZP1EEED20?ooo`0705EEE@3oool0
000005EEE@2ZZZX0oooo05EEE@02000000030?ooo`1EEED0ZZZZ0080ZZZZ00<000000?ooo`3oool0
0P1EEED0103oool0ZZZZ05EEE@3oool205EEE@030:ZZZP1EEED0oooo00/0oooo2P3AcJT<0?ooo`03
0:ZZZP000000ZZZZ0080EEEE00@0oooo05EEE@1EEED000000P2ZZZX00`000000EEEE0:ZZZP0205EE
E@030000003oool0000000<0ZZZZ00H0oooo05EEE@2ZZZX0000005EEE@0000030:ZZZP030000003o
ool0oooo0080EEEE00<0ZZZZ05EEE@1EEED00`2ZZZX205EEE@060?ooo`1EEED0ZZZZ0:ZZZP000000
EEEE303oool:0=7=Z@`0oooo00T0ZZZZ05EEE@1EEED0EEEE0?ooo`2ZZZX0oooo0000003oool01`00
000205EEE@h000000P1EEED40000000805EEE@00000000000?ooo`000000oooo0:ZZZP3oool405EE
E@`0oooo303AcJT000/0dLfY303oool20:ZZZP030000003oool0ZZZZ0080oooo00@0000005EEE@1E
EED000000P1EEED00`3oool0EEEE05EEE@0205EEE@<0000000<0oooo0:ZZZP3oool00P0000000`3o
ool0ZZZZ0?ooo`03000000<0EEEE00H000000?ooo`1EEED0oooo0000001EEED200000080oooo0P2Z
ZZX00`000000ZZZZ0?ooo`0<0?ooo`X0dLfY303oool0102ZZZX0EEEE05EEE@3oool205EEE@030?oo
o`2ZZZX0EEEE00<0oooo00D0ZZZZ05EEE@3oool0oooo0:ZZZP0205EEE@050?ooo`1EEED0oooo05EE
E@2ZZZX00P0000000`2ZZZX0EEEE0?ooo`0505EEE@030?ooo`000000EEEE0080ZZZZ0`3oool01@2Z
ZZX0oooo0:ZZZP1EEED000000080EEEE3@3oool:0=7=Z@`0oooo00H0ZZZZ05EEE@000000EEEE0:ZZ
ZP0000020?ooo`040:ZZZP1EEED0EEEE05EEE@<0oooo00P0ZZZZ05EEE@1EEED0oooo05EEE@2ZZZX0
EEEE00000080oooo00D0EEEE0?ooo`2ZZZX0EEEE0:ZZZP020?ooo`80EEEE00<0ZZZZ0000003oool0
0P3oool205EEE@<0oooo0P2ZZZX00`1EEED0000005EEE@0=0?ooo`X0dLfY303oool01P2ZZZX0EEEE
0000001EEED0oooo0:ZZZP80oooo00@0EEEE000000000000ZZZZ0P3oool01@1EEED0oooo0:ZZZP1E
EED0ZZZZ00<000000P2ZZZX0101EEED000000:ZZZP1EEED3000000050:ZZZP1EEED000000?ooo`00
00000P3oool0102ZZZX000000000002ZZZX20?ooo`050000003oool000000000001EEED03@3oool:
0=7=Z@`0oooo00/0ZZZZ05EEE@000000ZZZZ0000003oool000000:ZZZP1EEED0ZZZZ05EEE@050000
0080EEEE3P00000205EEE@@000000P1EEED30:ZZZP060000003oool0000005EEE@000000EEEE3@3o
ool<0=7=Z@002`3AcJT>0?ooo`0505EEE@2ZZZX0oooo0000003oool0100000030?ooo`040000001E
EED0EEEE05EEE@@0000000<0oooo0000000000000P0000000`2ZZZX0000000000002000000<0EEEE
00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`020?ooo`030000001EEED0oooo00d0
oooo2P3AcJT>0?ooo`0605EEE@2ZZZX000000000003oool0EEEE0P3oool30:ZZZP0305EEE@000000
EEEE00<0oooo00D000000:ZZZP1EEED0oooo000000020?ooo`050000003oool0EEEE0:ZZZP000000
0`3oool01P1EEED0000005EEE@2ZZZX0oooo0:ZZZP80oooo00<0EEEE0?ooo`1EEED00P0000000`1E
EED0oooo0?ooo`0<0?ooo`X0dLfY3P3oool01`1EEED000000000001EEED0ZZZZ0?ooo`0000000P1E
EED01@3oool0EEEE0?ooo`2ZZZX000000080EEEE00@0ZZZZ05EEE@3oool000000P2ZZZX02@3oool0
ZZZZ0:ZZZP1EEED000000?ooo`000000ZZZZ05EEE@020000000405EEE@3oool0EEEE0:ZZZP80EEEE
00@0ZZZZ0?ooo`2ZZZX0ZZZZ0P0000000`1EEED0oooo0?ooo`0<0?ooo`X0dLfY3P3oool01@1EEED0
00000?ooo`3oool0000000@0EEEE00<0oooo0000001EEED00P1EEED20:ZZZP030?ooo`2ZZZX0ZZZZ
0080EEEE010000000:ZZZP2ZZZX000000:ZZZP1EEED0ZZZZ0000003oool0ZZZZ0000001EEED0oooo
05EEE@000000ZZZZ0P1EEED00`000000EEEE000000020?ooo`030000001EEED0oooo00d0oooo2P3A
cJT>0?ooo`0305EEE@3oool0ZZZZ0080EEEE0P3oool00`1EEED0oooo0000000400000080EEEE3P00
000205EEE@@0000000X0EEEE0?ooo`1EEED0EEEE0?ooo`1EEED000000:ZZZP000000EEEE3P3oool<
0=7=Z@002`3AcJT?0?ooo`80ZZZZ00<0EEEE0000003oool00`1EEED00`3oool0EEEE000000030000
000405EEE@000000000000000080oooo00X0ZZZZ0?ooo`2ZZZX0ZZZZ0000003oool000000:ZZZP00
0000EEEE0P000000103oool0000005EEE@00000205EEE@040000003oool0000005EEE@80ZZZZ3`3o
ool:0=7=Z@l0oooo0P2ZZZX00`3oool0EEEE05EEE@0200000080oooo00T000000?ooo`3oool0oooo
0000001EEED0ZZZZ0?ooo`2ZZZX00P1EEED40?ooo`80EEEE0`2ZZZX01P1EEED0ZZZZ0?ooo`1EEED0
oooo00000080oooo00D000000:ZZZP1EEED0EEEE0?ooo`020:ZZZPl0oooo2P3AcJT?0?ooo`030:ZZ
ZP3oool0EEEE0080EEEE0P2ZZZX00`000000EEEE0:ZZZP0205EEE@070000001EEED0oooo0000001E
EED0oooo05EEE@0200000080oooo00@000000?ooo`1EEED0oooo0P0000001@3oool000000000002Z
ZZX0EEEE0080ZZZZ00<000000:ZZZP3oool00P1EEED00`2ZZZX0oooo0:ZZZP0?0?ooo`X0dLfY3`3o
ool0102ZZZX0oooo0:ZZZP3oool20:ZZZP80oooo00<0EEEE0:ZZZP0000000P3oool30:ZZZP040000
001EEED000000?ooo`@0ZZZZ00@0oooo0000001EEED0EEEE0`2ZZZX00`3oool0ZZZZ000000020:ZZ
ZP<0oooo00D0ZZZZ0?ooo`000000oooo0:ZZZP0?0?ooo`X0dLfY3`3oool01@2ZZZX0EEEE00000000
0000ZZZZ0080oooo00<0ZZZZ05EEE@0000000`00000205EEE@h000000P1EEED5000000080:ZZZP3o
ool0oooo0:ZZZP000000oooo05EEE@2ZZZX?0?ooo``0dLfY000;0=7=Z@l0oooo00D000000?ooo`2Z
ZZX0oooo0:ZZZP03000000050?ooo`2ZZZX0oooo0000001EEED00`0000001@3oool0EEEE0?ooo`3o
ool000000080oooo00D0000005EEE@3oool0EEEE0?ooo`02000000050:ZZZP1EEED0ZZZZ0?ooo`2Z
ZZX0100000000`2ZZZX0oooo0?ooo`0A0?ooo`X0dLfY3`3oool01P000000oooo0?ooo`3oool0ZZZZ
05EEE@@0oooo00D0EEEE0:ZZZP000000oooo05EEE@02000000L0oooo00<0ZZZZ0?ooo`3oool00P00
00000`1EEED0oooo0000000205EEE@D0oooo00<0ZZZZ0?ooo`3oool04@3oool:0=7=Z@l0oooo00@0
00000?ooo`1EEED0EEEE0P2ZZZX010000000EEEE0:ZZZP00000205EEE@0:0000001EEED0oooo05EE
E@3oool0ZZZZ0000003oool0ZZZZ05EEE@<0ZZZZ00D000000:ZZZP3oool0EEEE0?ooo`0200000080
EEEE0P0000001P1EEED0000005EEE@2ZZZX0EEEE0:ZZZQ40oooo2P3AcJT?0?ooo`040000003oool0
ZZZZ0:ZZZP80EEEE0P2ZZZX01@3oool000000?ooo`3oool0ZZZZ0080000000<0EEEE0:ZZZP000000
1P2ZZZX00`1EEED0ZZZZ0000000205EEE@80000000D0ZZZZ0000003oool0000005EEE@020:ZZZP04
0?ooo`1EEED0ZZZZ0:ZZZQ40oooo2P3AcJT?0?ooo`070000003oool0ZZZZ0:ZZZP3oool0EEEE0?oo
o`0205EEE@@000000P1EEED>00000080EEEE100000001`2ZZZX0EEEE0?ooo`1EEED0oooo0:ZZZP00
00004@3oool<0=7=Z@002`3AcJTA0?ooo`030:ZZZP000000ZZZZ00<0ZZZZ00H0oooo0000003oool0
ZZZZ0000003oool20:ZZZP030?ooo`1EEED0EEEE0080ZZZZ0P3oool20:ZZZP80EEEE0`2ZZZX01P3o
ool000000?ooo`3oool000000?ooo`80ZZZZ00@0oooo0:ZZZP000000ZZZZ4@3oool:0=7=ZA@0oooo
00L0EEEE0?ooo`3oool0oooo0:ZZZP3oool0000000<0EEEE00<0000005EEE@2ZZZX00P3oool00`2Z
ZZX0oooo0?ooo`020:ZZZP040?ooo`2ZZZX00000000000<0EEEE0P3oool20:ZZZP80oooo00@0ZZZZ
0?ooo`3oool0ZZZZ4@3oool:0=7=ZA<0oooo00/0EEEE0:ZZZP2ZZZX0EEEE0?ooo`1EEED0ZZZZ05EE
E@3oool0ZZZZ0?ooo`020:ZZZP040000003oool0oooo0?ooo`80ZZZZ00<0oooo0000003oool00P00
0000102ZZZX0oooo05EEE@3oool20:ZZZP0805EEE@2ZZZX0EEEE0:ZZZP000000EEEE0?ooo`2ZZZXA
0?ooo`X0dLfY4P3oool30:ZZZP080000002ZZZX0EEEE0?ooo`000000ZZZZ05EEE@0000020:ZZZP06
0000002ZZZX0EEEE0?ooo`000000oooo0P0000000`3oool0EEEE0:ZZZP030:ZZZP80EEEE00H0ZZZZ
0000003oool0EEEE0:ZZZP0000040:ZZZQ40oooo2P3AcJTB0?ooo`<0EEEE00@0oooo0:ZZZP3oool0
EEEE0`00000205EEE@h000000P1EEED30000000505EEE@000000ZZZZ0?ooo`0000000P1EEED00`2Z
ZZX0oooo0?ooo`0?0?ooo``0dLfY000;0=7=ZA40oooo00`000000?ooo`000000EEEE0:ZZZP3oool0
00000?ooo`000000oooo0:ZZZP0000030?ooo`030:ZZZP3oool0000000H0oooo00@0ZZZZ0000003o
ool0oooo0P2ZZZX0201EEED000000?ooo`1EEED0oooo0:ZZZP3oool000004`3oool:0=7=ZA40oooo
00<000000:ZZZP1EEED00`3oool20000000305EEE@3oool0oooo0080oooo00<0ZZZZ0?ooo`3oool0
0P0000040?ooo`80000000H0oooo0:ZZZP2ZZZX0oooo0:ZZZP3oool205EEE@070000003oool0oooo
0?ooo`2ZZZX0EEEE0:ZZZP0B0?ooo`X0dLfY4@3oool01`000000ZZZZ0?ooo`1EEED0ZZZZ0?ooo`00
00000`2ZZZX01P000000EEEE0:ZZZP2ZZZX0oooo05EEE@80oooo1@1EEED00`3oool0EEEE0:ZZZP02
0:ZZZP030?ooo`000000ZZZZ0080ZZZZ0P3oool0102ZZZX0oooo0?ooo`2ZZZXB0?ooo`X0dLfY4@3o
ool01@000000ZZZZ0000001EEED0000000<0ZZZZ101EEED20000000305EEE@2ZZZX0oooo00<0oooo
00D0EEEE0?ooo`3oool0oooo0:ZZZP03000000070:ZZZP1EEED0000005EEE@2ZZZX000000:ZZZP03
000000030:ZZZP3oool0oooo0100oooo2P3AcJTA0?ooo`030000002ZZZX000000080EEEE00<0oooo
0:ZZZP1EEED00`00000205EEE@h000000P1EEED30000000405EEE@2ZZZX0oooo05EEE@80000000<0
ZZZZ0?ooo`3oool0403oool<0=7=Z@002`3AcJTB0?ooo`0405EEE@000000oooo0?ooo`80000000D0
ZZZZ0?ooo`3oool000000?ooo`0205EEE@80oooo00<000000?ooo`3oool00`3oool0101EEED00000
0?ooo`3oool205EEE@0;0?ooo`000000ZZZZ0?ooo`2ZZZX0EEEE0000003oool0ZZZZ0000001EEED0
4P3oool:0=7=ZA80oooo00<0EEEE0:ZZZP3oool00`1EEED30?ooo`80000000<0oooo0000003oool0
1`3oool01P1EEED0oooo0?ooo`3oool000000?ooo`80000000@0ZZZZ0?ooo`3oool0oooo0`1EEED0
0`2ZZZX0EEEE0?ooo`0A0?ooo`X0dLfY4P3oool00`1EEED0ZZZZ05EEE@0305EEE@040?ooo`2ZZZX0
oooo0:ZZZP@0EEEE00D0oooo0000002ZZZX0EEEE0:ZZZP0205EEE@030:ZZZP000000oooo00<0EEEE
0P2ZZZX0101EEED0ZZZZ0?ooo`3oool205EEE@80ZZZZ00<0EEEE0?ooo`3oool0403oool:0=7=ZA80
oooo00<0EEEE0:ZZZP1EEED00P3oool00`000000ZZZZ0000000205EEE@80oooo00D0EEEE0?ooo`2Z
ZZX0EEEE0:ZZZP0205EEE@0>0:ZZZP1EEED0ZZZZ05EEE@2ZZZX0oooo05EEE@3oool0ZZZZ05EEE@2Z
ZZX000000:ZZZP0000020?ooo`030000002ZZZX0EEEE0180oooo2P3AcJTB0?ooo`0305EEE@2ZZZX0
EEEE0080EEEE00<0ZZZZ05EEE@0000000P0000000`2ZZZX000000000000B0000000305EEE@3oool0
EEEE0080EEEE00<0ZZZZ05EEE@3oool04@3oool<0=7=Z@002`3AcJTF0?ooo`<0ZZZZ00<0000005EE
E@3oool00P2ZZZX01`000000oooo05EEE@2ZZZX000000:ZZZP0000000P2ZZZX01@3oool0ZZZZ05EE
E@3oool000000080ZZZZ0P3oool01P000000ZZZZ0?ooo`2ZZZX0oooo000001@0oooo2P3AcJTD0?oo
o`0505EEE@3oool0oooo0:ZZZP3oool00`1EEED01P000000ZZZZ0000003oool0000005EEE@<0oooo
00`0EEEE0?ooo`3oool0EEEE0000001EEED000000:ZZZP3oool0EEEE0?ooo`1EEED40?ooo`030000
003oool0oooo0180oooo2P3AcJTD0?ooo`0605EEE@000000oooo0:ZZZP3oool0ZZZZ0P3oool01`00
0000ZZZZ0000001EEED0oooo0000003oool01@2ZZZX030000000oooo000000000000ZZZZ05EEE@3o
ool000000:ZZZP3oool0EEEE0?ooo`800000503oool:0=7=ZA@0oooo00<0EEEE0:ZZZP2ZZZX00P3o
ool200000080ZZZZ00L0EEEE0000001EEED0oooo0:ZZZP3oool000000080ZZZZ0P0000001@2ZZZX0
oooo000000000000EEEE00<0ZZZZ00<000000?ooo`2ZZZX00P2ZZZX00`000000oooo0?ooo`0B0?oo
o`X0dLfY503oool2000000060?ooo`1EEED0EEEE0?ooo`1EEED0ZZZZ0P1EEED>0000000605EEE@3o
ool0ZZZZ0:ZZZP3oool0EEEE0P3oool2000001@0oooo303AcJT000/0dLfY503oool0301EEED00000
0?ooo`3oool000000?ooo`1EEED000000?ooo`000000oooo0:ZZZP80oooo00H0EEEE0:ZZZP1EEED0
oooo0:ZZZP0000020?ooo`040000003oool000000?ooo`80000000D0oooo0000003oool0oooo0000
000E0?ooo`X0dLfY503oool01@1EEED000000:ZZZP1EEED000000080EEEE00@000000:ZZZP2ZZZX0
ZZZZ0P3oool01@1EEED0ZZZZ0000003oool0EEEE0080000000<0EEEE0?ooo`3oool00P2ZZZX0103o
ool000000?ooo`1EEED2000000030:ZZZP000000oooo01@0oooo2P3AcJTD0?ooo`0505EEE@000000
00000:ZZZP1EEED00P2ZZZX010000000EEEE0?ooo`2ZZZX30?ooo`D0ZZZZ00<0EEEE0?ooo`3oool0
0P2ZZZX20?ooo`040000003oool0ZZZZ05EEE@<000005@3oool:0=7=ZA@0oooo00T0EEEE00000000
0000ZZZZ0?ooo`000000ZZZZ05EEE@2ZZZX00`1EEED20:ZZZP030?ooo`0000000000008000000`2Z
ZZX305EEE@050?ooo`1EEED000000000003oool00`00000E0?ooo`X0dLfY503oool0101EEED00000
0?ooo`00000205EEE@040:ZZZP3oool0EEEE05EEE@h000000P1EEED20?ooo`80EEEE00<0ZZZZ0?oo
o`0000005@3oool<0=7=Z@002`3AcJTE0?ooo`<0ZZZZ00H0oooo0:ZZZP000000000005EEE@000002
0:ZZZP0705EEE@2ZZZX0oooo0?ooo`1EEED000000?ooo`020:ZZZP0505EEE@3oool0ZZZZ0000003o
ool00P0000000`2ZZZX0oooo000000020:ZZZQD0oooo2P3AcJTE0?ooo`80ZZZZ0P3oool205EEE@80
oooo00<000000?ooo`3oool00P3oool20:ZZZP80oooo0P2ZZZX40?ooo`060000003oool0oooo0000
001EEED0oooo0`2ZZZXE0?ooo`X0dLfY5@3oool30:ZZZP80EEEE00H0oooo0:ZZZP1EEED0EEEE0?oo
o`1EEED20:ZZZPH0EEEE0`2ZZZX0103oool0EEEE0:ZZZP2ZZZX305EEE@030?ooo`2ZZZX0ZZZZ01D0
oooo2P3AcJTE0?ooo`<0ZZZZ00@0EEEE0:ZZZP1EEED0EEEE0P2ZZZX01`000000ZZZZ000000000000
EEEE0?ooo`1EEED00P3oool01@1EEED000000000002ZZZX000000080ZZZZ00D0EEEE0000002ZZZX0
EEEE0?ooo`020:ZZZQD0oooo2P3AcJTE0?ooo`80ZZZZ00@0oooo000000000000oooo0`1EEED>0000
00<0EEEE00@0ZZZZ000000000000EEEE0P2ZZZXE0?ooo``0dLfY000;0=7=ZAL0oooo00<000000:ZZ
ZP3oool00P0000001P2ZZZX0EEEE0:ZZZP3oool0000005EEE@80oooo0P0000020?ooo`0705EEE@00
0000oooo0:ZZZP1EEED0oooo000000020?ooo`030:ZZZP1EEED0oooo01H0oooo2P3AcJTG0?ooo`80
EEEE00<0oooo0:ZZZP3oool01`3oool0101EEED0000005EEE@1EEED60?ooo`040:ZZZP3oool0EEEE
0?ooo`80EEEE5`3oool:0=7=ZAL0oooo0P1EEED01P000000ZZZZ05EEE@000000ZZZZ0?ooo`80EEEE
00<0000005EEE@2ZZZX00P1EEED0202ZZZX0oooo0000001EEED0ZZZZ0?ooo`2ZZZX000000P1EEED0
0`000000EEEE05EEE@0G0?ooo`X0dLfY5`3oool0201EEED000000?ooo`3oool0ZZZZ0000002ZZZX0
00000P3oool00`2ZZZX00000000000020:ZZZP0=0000001EEED0ZZZZ0?ooo`1EEED000000:ZZZP1E
EED0ZZZZ05EEE@3oool0000005EEE@0G0?ooo`X0dLfY5`3oool00`1EEED0ZZZZ0?ooo`0405EEE@h0
0000101EEED00`3oool0ZZZZ05EEE@0G0?ooo``0dLfY000;0=7=ZAL0oooo0`2ZZZX205EEE@80oooo
0`2ZZZX30?ooo`0305EEE@3oool0oooo0080oooo00D0ZZZZ05EEE@2ZZZX0oooo0000000205EEE@80
ZZZZ603oool:0=7=ZAL0oooo00T0ZZZZ0?ooo`3oool0ZZZZ05EEE@000000oooo0000003oool00P00
00001P1EEED0000005EEE@3oool000000:ZZZP@0000000<0oooo0000001EEED06`3oool:0=7=ZAL0
oooo00P0ZZZZ0?ooo`3oool000000:ZZZP3oool0ZZZZ05EEE@80oooo00@0ZZZZ05EEE@1EEED0ZZZZ
0P1EEED20:ZZZP030?ooo`2ZZZX0EEEE00<0ZZZZ00<0EEEE0?ooo`3oool0603oool:0=7=ZAL0oooo
00T0ZZZZ0?ooo`2ZZZX0ZZZZ0?ooo`000000ZZZZ0000003oool00P1EEED00`3oool0000005EEE@03
000000<0EEEE00H000000:ZZZP1EEED0oooo0000002ZZZXI0?ooo`X0dLfY5`3oool0102ZZZX0oooo
05EEE@00000305EEE@h000001@1EEEDI0?ooo``0dLfY000;0=7=ZAP0oooo00@000000?ooo`2ZZZX0
oooo0P1EEED03`2ZZZX0oooo0000003oool0EEEE0?ooo`1EEED000000?ooo`1EEED0oooo0000003o
ool0ZZZZ05EEE@040?ooo`030000003oool0oooo01H0oooo2P3AcJTH0?ooo`070000002ZZZX0ZZZZ
0?ooo`1EEED0oooo05EEE@020?ooo`0505EEE@2ZZZX0oooo0000002ZZZX00P3oool0101EEED0oooo
0?ooo`1EEED30?ooo`0305EEE@2ZZZX0000001P0oooo2P3AcJTH0?ooo`050000002ZZZX0oooo05EE
E@3oool00P0000001@1EEED0ZZZZ0:ZZZP2ZZZX000000080ZZZZ00<000000:ZZZP2ZZZX00P2ZZZX2
000000050:ZZZP1EEED0oooo0:ZZZP000000603oool:0=7=ZAP0oooo00@000000:ZZZP1EEED0EEEE
0P000000102ZZZX0EEEE0?ooo`0000030:ZZZP0=0?ooo`2ZZZX0EEEE0000003oool0EEEE0:ZZZP00
0000oooo05EEE@000000ZZZZ0000000H0?ooo`X0dLfY603oool00`000000ZZZZ0000000305EEE@h0
00000`1EEED00`000000ZZZZ0000000H0?ooo``0dLfY000;0=7=ZAX0oooo00@0ZZZZ0000003oool0
00001@3oool010000000EEEE05EEE@0000030?ooo`060:ZZZP3oool000000:ZZZP000000ZZZZ6P3o
ool:0=7=ZAX0oooo0P1EEED0103oool0EEEE0:ZZZP2ZZZX20?ooo`0405EEE@3oool0oooo000000D0
oooo00D0ZZZZ05EEE@000000EEEE0:ZZZP0J0?ooo`X0dLfY6P3oool00`1EEED0000005EEE@020:ZZ
ZP80EEEE00<000000?ooo`1EEED00P3oool00`1EEED000000000000205EEE@80ZZZZ00<0EEEE0000
002ZZZX06P3oool:0=7=ZAX0oooo00<0EEEE0000001EEED00P3oool01@000000EEEE05EEE@000000
oooo0080ZZZZ00D0oooo0:ZZZP1EEED0EEEE000000020?ooo`80000000<0ZZZZ0?ooo`3oool0603o
ool:0=7=ZAX0oooo00<0EEEE0000002ZZZX0400000000`1EEED000000:ZZZP0J0?ooo``0dLfY000;
0=7=ZAX0oooo00D000000?ooo`3oool0EEEE0?ooo`020:ZZZP040000002ZZZX0000005EEE@800000
00L0ZZZZ0000002ZZZX0EEEE0?ooo`1EEED0000001`0oooo2P3AcJTJ0?ooo`040000001EEED0oooo
0?ooo`80ZZZZ00@0oooo0000001EEED0EEEE0P3oool01P1EEED0ZZZZ0000003oool0EEEE0:ZZZP80
oooo00<0EEEE0?ooo`3oool06@3oool:0=7=ZAX0oooo00/0000005EEE@3oool0EEEE0:ZZZP3oool0
ZZZZ0?ooo`2ZZZX0EEEE0?ooo`0205EEE@080:ZZZP3oool0ZZZZ0?ooo`2ZZZX0EEEE0000001EEEDK
0?ooo`X0dLfY6P3oool01`000000EEEE0000002ZZZX0oooo0000003oool00P1EEED40:ZZZP050000
001EEED0oooo0000003oool00P2ZZZX00`1EEED0oooo0?ooo`0I0?ooo`X0dLfY6P3oool200000080
oooo00<0EEEE0000000000002P000000101EEED0oooo00000000000K0?ooo``0dLfY000;0=7=ZA/0
oooo00T0EEEE0:ZZZP3oool0oooo0:ZZZP1EEED0oooo0000003oool00P0000030?ooo`0605EEE@3o
ool0oooo0?ooo`000000EEEE6`3oool:0=7=ZA/0oooo00@0EEEE0:ZZZP000000EEEE0`3oool00`2Z
ZZX0EEEE0?ooo`0305EEE@80oooo00D0000005EEE@000000000005EEE@0K0?ooo`X0dLfY6`3oool0
0`1EEED00000000000040:ZZZP060?ooo`2ZZZX0oooo0?ooo`2ZZZX0EEEE0P2ZZZX01@1EEED0ZZZZ
000000000000EEEE01/0oooo2P3AcJTK0?ooo`0705EEE@000000oooo0?ooo`1EEED0oooo05EEE@05
0:ZZZP030000001EEED0oooo00<0oooo00<0000005EEE@3oool06P3oool:0=7=ZA/0oooo00<0EEEE
0?ooo`2ZZZX0300000001@1EEED000000:ZZZP000000EEEE01/0oooo303AcJT000/0dLfY703oool0
10000000oooo0?ooo`3oool205EEE@060000001EEED000000000001EEED0oooo0P1EEED00`2ZZZX0
oooo0?ooo`0M0?ooo`X0dLfY703oool020000000oooo0?ooo`3oool0ZZZZ0?ooo`1EEED0oooo0P2Z
ZZX0103oool0ZZZZ0?ooo`2ZZZXP0?ooo`X0dLfY703oool02`000000oooo0:ZZZP1EEED0ZZZZ05EE
E@2ZZZX0oooo0:ZZZP1EEED0oooo0080EEEE00<0ZZZZ05EEE@2ZZZX07P3oool:0=7=ZA`0oooo00D0
00000?ooo`2ZZZX0ZZZZ05EEE@080:ZZZP0305EEE@2ZZZX0ZZZZ01h0oooo2P3AcJTL0?ooo`040000
003oool000000:ZZZPX0000000<0ZZZZ0000003oool07@3oool<0=7=Z@002`3AcJTM0?ooo`0505EE
E@000000oooo0?ooo`2ZZZX00P0000001@2ZZZX000000000003oool0ZZZZ0080oooo00<0000005EE
E@3oool0703oool:0=7=ZAd0oooo0P1EEED0103oool0EEEE0:ZZZP2ZZZX400000080ZZZZ101EEEDM
0?ooo`X0dLfY7@3oool205EEE@030000001EEED0ZZZZ0080EEEE00D000000?ooo`1EEED0EEEE0:ZZ
ZP0405EEEAd0oooo2P3AcJTM0?ooo`80EEEE00<000000:ZZZP2ZZZX0202ZZZX00`000000EEEE05EE
E@0M0?ooo`X0dLfY7@3oool205EEE@030?ooo`1EEED0000000L0000000@0EEEE0:ZZZP1EEED0EEEE
7@3oool<0=7=Z@002`3AcJTP0?ooo`070000003oool000000000001EEED0oooo000000020?ooo`80
00007`3oool:0=7=ZAl0oooo00<0ZZZZ05EEE@2ZZZX00`3oool01P000000oooo0?ooo`2ZZZX0EEEE
000001l0oooo2P3AcJTO0?ooo`090:ZZZP3oool0oooo0:ZZZP3oool0EEEE0:ZZZP3oool0EEEE0080
oooo00<000000?ooo`3oool07@3oool:0=7=ZAl0oooo00<0ZZZZ0000000000000P0000000`1EEED0
000000000004000001l0oooo2P3AcJTO0?ooo`030:ZZZP000000EEEE00H0000000<0EEEE00000000
00007`3oool<0=7=Z@002`3AcJTO0?ooo`0305EEE@000000ZZZZ0080000000H0ZZZZ0?ooo`000000
oooo0:ZZZP00000P0?ooo`X0dLfY7`3oool00`1EEED0ZZZZ05EEE@0205EEE@80oooo00@0EEEE0?oo
o`1EEED0ZZZZ803oool:0=7=ZAl0oooo00<0EEEE0:ZZZP2ZZZX00P1EEED0102ZZZX0oooo05EEE@1E
EED20:ZZZR00oooo2P3AcJTO0?ooo`0;05EEE@2ZZZX000000:ZZZP000000ZZZZ05EEE@000000EEEE
0000002ZZZX0803oool:0=7=ZAl0oooo00<0EEEE0:ZZZP1EEED01P0000000`1EEED0ZZZZ0?ooo`0O
0?ooo``0dLfY000;0=7=ZB00oooo0P2ZZZX01@1EEED000000:ZZZP2ZZZX0000000<0ZZZZ803oool:
0=7=ZB00oooo00@0ZZZZ05EEE@000000oooo0P1EEED0103oool0EEEE05EEE@2ZZZXP0?ooo`X0dLfY
803oool0102ZZZX0EEEE05EEE@1EEED20:ZZZP0405EEE@000000EEEE0:ZZZR00oooo2P3AcJTP0?oo
o`0:0:ZZZP1EEED0oooo0?ooo`000000EEEE0?ooo`000000EEEE0:ZZZR00oooo2P3AcJTP0?ooo`03
0:ZZZP1EEED0000000D0000000<0EEEE0:ZZZP3oool07`3oool<0=7=Z@002`3AcJTR0?ooo`030000
003oool000000080oooo00<0EEEE0?ooo`3oool0803oool:0=7=ZB80oooo00H000000:ZZZP000000
00000:ZZZP1EEEDR0?ooo`X0dLfY8P3oool3000000030:ZZZP000000EEEE0280oooo2P3AcJTR0?oo
o`030000001EEED0ZZZZ00<0EEEE8P3oool:0=7=ZB80oooo0`0000000`1EEED0000005EEE@0R0?oo
o``0dLfY000;0=7=ZB80oooo0`2ZZZX00`000000ZZZZ0?ooo`0R0?ooo`X0dLfY8P3oool20:ZZZP03
0?ooo`2ZZZX0ZZZZ02<0oooo2P3AcJTR0?ooo`80ZZZZ00<0EEEE0?ooo`2ZZZX08`3oool:0=7=ZB80
oooo0`2ZZZX00`000000ZZZZ0?ooo`0R0?ooo`X0dLfY8P3oool20:ZZZP80000000<0ZZZZ0?ooo`3o
ool08@3oool<0=7=Z@002`3AcJTS0?ooo`80000000<0oooo0000003oool08P3oool:0=7=ZB<0oooo
00@000000?ooo`3oool000008`3oool:0=7=ZB<0oooo00@000000:ZZZP3oool000008`3oool:0=7=
ZB<0oooo0P0000000`3oool000000?ooo`0R0?ooo`X0dLfY8`3oool010000000EEEE0?ooo`00000S
0?ooo``0dLfY000;0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool:0=7=ZB@0oooo00<0ZZZZ0?oo
o`3oool08`3oool:0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool:0=7=ZB@0oooo00<0ZZZZ0?oo
o`3oool08`3oool:0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool<0=7=Z@00o`3AcJVb0=7=Z@00
o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@002`3AcJTD0?ooo`80
00000P1EEED00`3oool0EEEE000000020:ZZZP030000003oool0oooo00@0oooo0P1EEED60?ooo`05
0000002ZZZX0ZZZZ0000001EEED00P3oool00`1EEED000000?ooo`0D0?ooo`X0dLfY5`3oool00`00
0000oooo000000020?ooo`<0EEEE0`2ZZZX00`1EEED0ZZZZ000000050:ZZZP<0EEEE00H000000?oo
o`3oool000000?ooo`00000G0?ooo`X0dLfY5@3oool01P1EEED000000000001EEED0oooo0:ZZZP80
00000P2ZZZX00`000000oooo05EEE@020:ZZZP060?ooo`2ZZZX0ZZZZ0000001EEED0oooo102ZZZX0
1`000000oooo0?ooo`1EEED0oooo0000001EEED05@3oool:0=7=Z@040?ooo`000000ZZZZ0?ooo`@0
0000103oool3000000030?ooo`000000oooo0080oooo00L0ZZZZ0?ooo`1EEED0ZZZZ0000003oool0
EEEE0080oooo00<0ZZZZ0?ooo`2ZZZX00P1EEED2000000030?ooo`1EEED0000000<0EEEE0P3oool0
0`2ZZZX000000?ooo`020?ooo`050000001EEED0EEEE0?ooo`2ZZZX00`3oool010000000oooo0000
000000030?ooo`030:ZZZP3oool000000080000000D0EEEE0?ooo`2ZZZX0EEEE0?ooo`0:0=7=Z@06
0?ooo`00000000000000001EEED0ZZZZ0P3oool00`2ZZZX000000:ZZZP020?ooo`80ZZZZ00D0oooo
05EEE@2ZZZX0ZZZZ05EEE@04000000030:ZZZP3oool0ZZZZ0080oooo00<0EEEE0:ZZZP1EEED0103o
ool205EEE@030?ooo`000000oooo0080oooo00P0ZZZZ05EEE@3oool0oooo0:ZZZP3oool0ZZZZ05EE
E@80000000H0oooo05EEE@2ZZZX0ZZZZ05EEE@0000020:ZZZP80oooo00<0ZZZZ0?ooo`2ZZZX00P3o
ool01P2ZZZX0EEEE000000000000EEEE0?ooo``0dLfY000;0=7=ZAD0oooo00D0EEEE0?ooo`3oool0
EEEE0:ZZZP04000000H0oooo00@0ZZZZ0?ooo`3oool00000103oool30000000605EEE@2ZZZX0EEEE
0000003oool0EEEE5@3oool:0=7=ZAL0oooo00<0EEEE0?ooo`2ZZZX00P2ZZZX20?ooo`040:ZZZP00
000000000?ooo`80000000T0EEEE0?ooo`00000000000?ooo`000000oooo0:ZZZP3oool0102ZZZXI
0?ooo`X0dLfY5P3oool20:ZZZP<0oooo00T0000005EEE@2ZZZX0000005EEE@2ZZZX0oooo05EEE@00
00000P2ZZZX00`000000oooo0?ooo`020:ZZZP030000002ZZZX0ZZZZ008000000P3oool20:ZZZQH0
oooo2P3AcJT0103oool0ZZZZ0:ZZZP2ZZZX5000000@0oooo00@0EEEE0?ooo`3oool0oooo0P1EEED5
0?ooo`0405EEE@3oool0EEEE05EEE@80oooo00@000000?ooo`2ZZZX0oooo0P2ZZZX20?ooo`060:ZZ
ZP3oool0oooo0:ZZZP1EEED000000P3oool01@1EEED000000?ooo`1EEED0ZZZZ0080oooo00@00000
0?ooo`1EEED0EEEE0`3oool00`1EEED0oooo0?ooo`020?ooo`D000000P2ZZZX20?ooo`X0dLfY00<0
oooo0:ZZZP2ZZZX00`3oool01P1EEED0oooo05EEE@2ZZZX0oooo05EEE@<0ZZZZ00<0oooo0000001E
EED00P0000020:ZZZP80oooo00L0ZZZZ05EEE@3oool0EEEE0?ooo`2ZZZX0oooo0080EEEE0P3oool5
05EEE@090?ooo`1EEED0EEEE0?ooo`2ZZZX0000005EEE@2ZZZX0EEEE0080ZZZZ00<0oooo0:ZZZP3o
ool0100000030:ZZZP80EEEE00T0oooo0:ZZZP1EEED0oooo0000003oool0ZZZZ0?ooo`2ZZZX00P3o
ool<0=7=Z@002`3AcJTF0?ooo`050000002ZZZX0oooo0?ooo`1EEED00P0000001@1EEED0ZZZZ05EE
E@3oool0ZZZZ0080000000D0oooo000000000000EEEE0:ZZZP020?ooo`030:ZZZP1EEED0ZZZZ0080
00000P3oool00`2ZZZX000000?ooo`0E0?ooo`X0dLfY5`3oool01@1EEED0ZZZZ05EEE@2ZZZX0EEEE
0080oooo0`2ZZZX0201EEED000000000003oool0EEEE0000003oool0EEEE0`2ZZZX01P3oool0EEEE
05EEE@2ZZZX0EEEE0:ZZZQP0oooo2P3AcJTF0?ooo`040000003oool0oooo00000080ZZZZ00l0oooo
000000000000ZZZZ0?ooo`000000oooo0000003oool0EEEE0000003oool000000?ooo`2ZZZX00P00
00020:ZZZP80000000<0oooo0:ZZZP0000005P3oool:0=7=Z@<0oooo00<0EEEE0:ZZZP0000000`3o
ool00`2ZZZX0oooo0?ooo`020?ooo`<0ZZZZ00@0EEEE0?ooo`3oool0oooo0P2ZZZX3000000050?oo
o`000000EEEE0?ooo`2ZZZX00P1EEED0103oool0ZZZZ05EEE@00000205EEE@80oooo0P1EEED01@2Z
ZZX0oooo0?ooo`000000ZZZZ008000000`2ZZZX010000000oooo0?ooo`3oool30:ZZZP030?ooo`2Z
ZZX0oooo00@0oooo00@0ZZZZ000000000000EEEE0`3oool:0=7=Z@<0oooo00H0EEEE000000000000
EEEE0:ZZZP1EEED50?ooo`070:ZZZP3oool0EEEE05EEE@3oool0EEEE0?ooo`040:ZZZP040?ooo`00
0000oooo0:ZZZP80oooo00H0EEEE0?ooo`1EEED0ZZZZ0?ooo`2ZZZX30?ooo`0305EEE@3oool0oooo
0080oooo00@0EEEE0?ooo`2ZZZX0oooo1@2ZZZX0101EEED0oooo0:ZZZP1EEED20:ZZZP080?ooo`1E
EED0oooo0?ooo`2ZZZX0EEEE0:ZZZP1EEED20000000405EEE@3oool0oooo0?ooo``0dLfY000;0=7=
ZAL0oooo00H0EEEE0?ooo`2ZZZX000000?ooo`2ZZZX205EEE@040:ZZZP3oool0EEEE0:ZZZP800000
00@0EEEE0000001EEED0EEEE0P3oool205EEE@060000003oool0EEEE0:ZZZP3oool0EEEE5`3oool:
0=7=ZAL0oooo00@000000:ZZZP2ZZZX000000P3oool00`1EEED0ZZZZ05EEE@0205EEE@80ZZZZ0P3o
ool00`2ZZZX0oooo05EEE@0205EEE@050:ZZZP1EEED0ZZZZ0?ooo`1EEED00P2ZZZXH0?ooo`X0dLfY
5P3oool00`000000ZZZZ0:ZZZP020:ZZZP060000002ZZZX0ZZZZ0?ooo`1EEED0oooo0`2ZZZX20?oo
o`<0ZZZZ00<0oooo0000003oool00P2ZZZX00`000000EEEE0:ZZZP020:ZZZP030000003oool0oooo
01@0oooo2P3AcJT40?ooo`80ZZZZ0`1EEED20:ZZZP030000003oool0oooo00<0oooo00<0ZZZZ0000
001EEED00P3oool010000000oooo05EEE@3oool200000080EEEE0`3oool0302ZZZX0oooo0?ooo`3o
ool0ZZZZ0?ooo`000000ZZZZ0?ooo`2ZZZX0oooo05EEE@8000000P3oool00`1EEED0oooo00000002
0?ooo`0505EEE@00000000000?ooo`0000000`3oool00`000000ZZZZ0:ZZZP0205EEE@030?ooo`2Z
ZZX0ZZZZ00@0oooo2P3AcJT40?ooo`050:ZZZP3oool0oooo0?ooo`0000000P2ZZZX010000000EEEE
05EEE@2ZZZX205EEE@040000002ZZZX0oooo00000080EEEE00D0000005EEE@1EEED0oooo0:ZZZP02
05EEE@030?ooo`000000ZZZZ0080oooo00@000000:ZZZP2ZZZX000000P3oool01@2ZZZX0EEEE0?oo
o`1EEED000000080ZZZZ0P1EEED00`000000EEEE05EEE@020?ooo`090:ZZZP1EEED0EEEE0?ooo`2Z
ZZX0EEEE0:ZZZP000000ZZZZ0080000000@0oooo0:ZZZP3oool0ZZZZ103oool<0=7=Z@002`3AcJTG
0?ooo`070000002ZZZX000000:ZZZP1EEED0ZZZZ000000020?ooo`80EEEE00@0oooo05EEE@2ZZZX0
0000101EEED20?ooo`80000000@0EEEE0:ZZZP000000ZZZZ603oool:0=7=ZAT0oooo00<0ZZZZ0000
000000000P2ZZZX00`3oool0EEEE0000000205EEE@@0oooo0P1EEED01P000000ZZZZ0?ooo`2ZZZX0
oooo00000080ZZZZ6@3oool:0=7=ZAL0oooo0`2ZZZX01@000000EEEE0:ZZZP2ZZZX0000000<0ZZZZ
00H0oooo05EEE@3oool0000005EEE@3oool30:ZZZP050000002ZZZX0EEEE05EEE@3oool00P2ZZZXH
0?ooo`X0dLfY1@3oool0101EEED0ZZZZ0?ooo`1EEED2000000H0oooo00<000000?ooo`3oool00`3o
ool30:ZZZP030000003oool0oooo0080000000H0EEEE0?ooo`3oool0oooo0:ZZZP0000020:ZZZP@0
oooo0P0000030?ooo`80ZZZZ203oool01@1EEED0oooo0?ooo`2ZZZX0oooo0080000000@0EEEE0?oo
o`000000EEEE1@3oool:0=7=Z@D0oooo00D0EEEE000000000000EEEE0:ZZZP030?ooo`0305EEE@3o
ool000000080ZZZZ0P0000001@2ZZZX000000?ooo`1EEED0oooo0080000000<0EEEE0?ooo`3oool0
0P3oool00`000000oooo05EEE@0205EEE@050000001EEED0oooo0?ooo`0000000`3oool01`000000
EEEE0:ZZZP000000oooo0:ZZZP3oool0100000020:ZZZP80oooo00@0EEEE0?ooo`3oool0oooo0P1E
EED20000000305EEE@3oool0oooo00<0oooo303AcJT000/0dLfY603oool205EEE@040?ooo`1EEED0
000000000080oooo00<0000005EEE@0000000P3oool01@1EEED0oooo0?ooo`1EEED000000080oooo
0P00000405EEEAP0oooo2P3AcJTI0?ooo`040000003oool0oooo0:ZZZP80EEEE00<0oooo0:ZZZP2Z
ZZX01@2ZZZX0101EEED0ZZZZ0:ZZZP00000305EEE@030?ooo`1EEED0000001T0oooo2P3AcJTG0?oo
o`80000000<0EEEE0:ZZZP0000000P2ZZZX3000000<0oooo0P2ZZZX01`3oool000000?ooo`000000
oooo0000002ZZZX00P0000000`3oool0EEEE0000000H0?ooo`X0dLfY1P3oool20:ZZZP@000000`3o
ool00`2ZZZX000000?ooo`060?ooo`060000003oool0oooo05EEE@3oool0EEEE0P3oool01P2ZZZX0
00000?ooo`1EEED0oooo0:ZZZP80EEEE00@000000:ZZZP3oool0oooo0`1EEED20?ooo`030000003o
ool0oooo00@0oooo00<0EEEE0000003oool00`3oool400000080ZZZZ1P3oool:0=7=Z@H0oooo00D0
ZZZZ0?ooo`2ZZZX0oooo0000000505EEE@030?ooo`1EEED0oooo0080oooo0P2ZZZX01@000000oooo
0:ZZZP2ZZZX0oooo0080EEEE00<0oooo05EEE@3oool00P3oool20:ZZZP030?ooo`2ZZZX0oooo0080
oooo00<0EEEE0?ooo`1EEED00P3oool20:ZZZP050?ooo`000000ZZZZ0:ZZZP1EEED00P3oool00`2Z
ZZX0oooo0?ooo`0205EEE@070?ooo`1EEED000000?ooo`2ZZZX0oooo0:ZZZP060?ooo``0dLfY000;
0=7=ZAT0oooo00<0ZZZZ0?ooo`0000000P0000030?ooo`80EEEE00H0ZZZZ0?ooo`3oool0ZZZZ0000
001EEED30?ooo`050000001EEED000000?ooo`2ZZZX06@3oool:0=7=ZAX0oooo00@0EEEE00000000
0000oooo0P2ZZZX205EEE@050?ooo`000000ZZZZ05EEE@0000000`1EEED00`3oool0ZZZZ0?ooo`02
0000000305EEE@3oool0oooo01P0oooo2P3AcJTG0?ooo`030000002ZZZX0oooo00<0000000D0EEEE
0?ooo`3oool0EEEE0?ooo`020:ZZZP060000002ZZZX0ZZZZ0:ZZZP3oool0EEEE0P3oool00`1EEED0
0000000000020?ooo`030:ZZZP3oool0oooo01H0oooo2P3AcJT60?ooo`030000003oool0oooo0080
oooo101EEED20:ZZZPP0oooo00<0EEEE0?ooo`2ZZZX00P3oool40:ZZZP80oooo00@0EEEE0:ZZZP3o
ool0oooo0P2ZZZX01`000000ZZZZ0?ooo`3oool0ZZZZ0000001EEED0203oool20:ZZZP80EEEE00@0
oooo05EEE@3oool0EEEE2@3oool:0=7=Z@H0oooo00<000000?ooo`2ZZZX00P2ZZZX20?ooo`060:ZZ
ZP3oool0oooo0:ZZZP000000oooo0P1EEED00`2ZZZX0oooo0?ooo`050?ooo`070:ZZZP3oool00000
0?ooo`1EEED0oooo05EEE@020:ZZZP<0EEEE00@0oooo0000003oool0ZZZZ0P3oool01P000000oooo
0?ooo`1EEED0oooo0:ZZZP80EEEE00<0oooo0000002ZZZX00P3oool01P2ZZZX0oooo0?ooo`2ZZZX0
EEEE0:ZZZPP0oooo303AcJT000/0dLfY6P3oool205EEE@050000003oool0oooo0000002ZZZX00`00
00020?ooo`<0000000@0ZZZZ0000003oool0oooo0`1EEEDJ0?ooo`X0dLfY6P3oool02`1EEED00000
0?ooo`1EEED0ZZZZ0?ooo`2ZZZX0EEEE0000001EEED0oooo00@0EEEE0`2ZZZX00`1EEED000000000
000K0?ooo`X0dLfY603oool0101EEED0000005EEE@1EEED60:ZZZP060000002ZZZX0ZZZZ0000002Z
ZZX000001@2ZZZX01@000000EEEE0:ZZZP000000EEEE01P0oooo2P3AcJT80?ooo`80ZZZZ00D0oooo
05EEE@1EEED0ZZZZ0?ooo`02000000040:ZZZP000000ZZZZ05EEE@@0000000D0oooo0:ZZZP3oool0
oooo0:ZZZP030?ooo`0<0000003oool0ZZZZ0000003oool0ZZZZ0?ooo`000000oooo0000003oool0
ZZZZ0P3oool0101EEED0oooo0000003oool200000080ZZZZ00H000000?ooo`00000000000?ooo`2Z
ZZX205EEE@030?ooo`2ZZZX0ZZZZ00P0oooo2P3AcJT80?ooo`040:ZZZP3oool0ZZZZ0?ooo`800000
00L0ZZZZ0?ooo`3oool000000?ooo`1EEED0oooo00<0EEEE0P3oool00`2ZZZX000000:ZZZP020?oo
o`030:ZZZP000000oooo00<0ZZZZ00D0oooo0:ZZZP1EEED0oooo000000030?ooo`0305EEE@000000
oooo0080oooo00D0ZZZZ05EEE@1EEED0oooo05EEE@030?ooo`80ZZZZ00<000000?ooo`3oool00`2Z
ZZX80?ooo``0dLfY000;0=7=ZAX0oooo00<0ZZZZ0?ooo`2ZZZX00P2ZZZX00`3oool0ZZZZ00000002
00000080oooo00<0000005EEE@000000102ZZZXM0?ooo`X0dLfY6`3oool00`2ZZZX0oooo05EEE@02
05EEE@040000003oool0oooo0:ZZZP80oooo0P2ZZZX00`3oool0000005EEE@0205EEE@80ZZZZ6`3o
ool:0=7=ZAT0oooo0P2ZZZX2000000090?ooo`000000EEEE0000002ZZZX0EEEE0:ZZZP3oool00000
00<0ZZZZ0`0000001@3oool00000000000000000ZZZZ01T0oooo2P3AcJT>0?ooo`<000000P3oool0
0`1EEED0oooo0?ooo`0205EEE@80oooo00<0ZZZZ05EEE@0000000P3oool205EEE@<0oooo0P000003
0?ooo`0605EEE@3oool0oooo0?ooo`2ZZZX0EEEE103oool01@1EEED0oooo0:ZZZP1EEED0oooo00@0
000000D0oooo0:ZZZP3oool0oooo000000090?ooo`X0dLfY2P3oool01`2ZZZX0EEEE0:ZZZP3oool0
ZZZZ0?ooo`1EEED00`3oool030000000oooo0000002ZZZX0EEEE0:ZZZP1EEED0oooo0:ZZZP1EEED0
ZZZZ05EEE@80oooo00D0ZZZZ05EEE@000000oooo05EEE@030?ooo`80ZZZZ00<0EEEE0?ooo`3oool0
0P2ZZZX01@1EEED000000000003oool0ZZZZ0080oooo0`1EEED01P2ZZZX0oooo0:ZZZP1EEED0ZZZZ
000000T0oooo303AcJT000/0dLfY6`3oool605EEE@030?ooo`000000000000<0000000<0ZZZZ0?oo
o`1EEED01@1EEEDK0?ooo`X0dLfY703oool01@1EEED000000?ooo`1EEED000000080EEEE1@3oool0
1P1EEED000000?ooo`3oool0000005EEEA`0oooo2P3AcJTI0?ooo`050000003oool0ZZZZ05EEE@2Z
ZZX00P3oool2000000030:ZZZP3oool0oooo0080oooo0`0000020?ooo`050:ZZZP1EEED0ZZZZ0:ZZ
ZP0000006@3oool:0=7=Z@X0oooo0P2ZZZX700000080oooo0P2ZZZX20?ooo`0=0:ZZZP3oool0oooo
0000002ZZZX0oooo0:ZZZP3oool0ZZZZ05EEE@3oool0EEEE0:ZZZP020?ooo`060:ZZZP3oool0oooo
0?ooo`2ZZZX000000P3oool00`2ZZZX0oooo0:ZZZP020:ZZZP80oooo1P0000030:ZZZPX0oooo2P3A
cJT:0?ooo`<0ZZZZ0P3oool01@1EEED0oooo0:ZZZP2ZZZX0oooo0080EEEE00@0ZZZZ0?ooo`1EEED0
oooo0`2ZZZX00`3oool0ZZZZ0:ZZZP020?ooo`040:ZZZP3oool0EEEE0:ZZZP@0oooo0P2ZZZX00`3o
ool0ZZZZ0:ZZZP020?ooo`0305EEE@000000ZZZZ0080EEEE00D0oooo0:ZZZP1EEED0oooo00000003
0?ooo`80ZZZZ2P3oool<0=7=Z@002`3AcJTN0?ooo`040:ZZZP3oool0ZZZZ0?ooo`H0EEEE00H0oooo
0:ZZZP3oool0ZZZZ0?ooo`2ZZZXL0?ooo`X0dLfY703oool01P2ZZZX0oooo0:ZZZP3oool0EEEE0?oo
o`D0ZZZZ00D0EEEE0?ooo`1EEED0EEEE0:ZZZP0N0?ooo`X0dLfY6@3oool010000000ZZZZ0:ZZZP00
00040:ZZZP030?ooo`2ZZZX0ZZZZ00<0ZZZZ00<000000?ooo`2ZZZX00`2ZZZX010000000ZZZZ0:ZZ
ZP00000I0?ooo`X0dLfY2`3oool01`000000oooo05EEE@3oool0EEEE0?ooo`1EEED0103oool01@00
0000oooo0?ooo`3oool0EEEE00<0oooo00@000000?ooo`3oool0oooo0P1EEED0102ZZZX0oooo05EE
E@0000020?ooo`80000000@0oooo05EEE@3oool000000`3oool00`000000oooo0?ooo`060?ooo`03
05EEE@3oool0000000/0oooo2P3AcJT;0?ooo`040000002ZZZX0EEEE0:ZZZP80oooo00<0ZZZZ05EE
E@3oool00P0000000`3oool0EEEE05EEE@0205EEE@030:ZZZP1EEED0ZZZZ00<0ZZZZ00H0EEEE0:ZZ
ZP3oool0oooo0000003oool205EEE@@0ZZZZ00<0oooo0:ZZZP3oool00P1EEED20?ooo`80000000@0
oooo05EEE@3oool0oooo0P2ZZZX00`1EEED0oooo0000000;0?ooo``0dLfY000;0=7=ZA`0oooo00T0
ZZZZ000000000000ZZZZ0000003oool0ZZZZ0?ooo`2ZZZX0103oool5000001`0oooo2P3AcJTL0?oo
o`080000001EEED0EEEE0?ooo`2ZZZX0oooo05EEE@2ZZZX205EEE@040:ZZZP1EEED0oooo0:ZZZP<0
EEEE7@3oool:0=7=ZAX0oooo00@000000:ZZZP2ZZZX0ZZZZ0P0000020:ZZZP80EEEE00<0ZZZZ05EE
E@1EEED00`2ZZZX01P1EEED000000:ZZZP1EEED0ZZZZ05EEEAX0oooo2P3AcJT<0?ooo`030000002Z
ZZX0000000<0oooo00@0ZZZZ000000000000oooo101EEED01@3oool0ZZZZ0000001EEED0oooo00<0
EEEE00H0oooo0:ZZZP000000oooo0:ZZZP3oool205EEE@80oooo00@0EEEE0000002ZZZX0oooo0P1E
EED01P3oool0EEEE0?ooo`1EEED000000:ZZZP80oooo00@0ZZZZ0000002ZZZX0EEEE303oool:0=7=
Z@`0oooo0`0000000`1EEED0ZZZZ0:ZZZP020?ooo`0505EEE@3oool0oooo0?ooo`2ZZZX00P3oool0
1@2ZZZX0EEEE05EEE@000000ZZZZ00<0000000@0EEEE0?ooo`3oool0EEEE1@00000205EEE@040:ZZ
ZP3oool0oooo0:ZZZPH0oooo00<0EEEE0:ZZZP1EEED00P0000000`1EEED0oooo0?ooo`0:0?ooo``0
dLfY000;0=7=ZA`0oooo00<0000005EEE@0000000P000000103oool000000000003oool200000080
oooo00D000000?ooo`000000EEEE0000000L0?ooo`X0dLfY7@3oool010000000ZZZZ05EEE@1EEED2
0:ZZZP0405EEE@2ZZZX0ZZZZ05EEE@80ZZZZ00@0EEEE0?ooo`2ZZZX000007@3oool:0=7=ZAX0oooo
00<0000005EEE@2ZZZX00P3oool3000000060:ZZZP3oool000000000003oool0ZZZZ0P0000030?oo
o`030:ZZZP1EEED0oooo01X0oooo2P3AcJT=0?ooo`060000003oool0oooo0:ZZZP3oool000000`3o
ool50:ZZZPH0oooo00<0000005EEE@0000001@0000040?ooo`030000003oool0oooo0080ZZZZ00<0
oooo0:ZZZP3oool00P3oool00`000000oooo0:ZZZP020?ooo`030000003oool0oooo00/0oooo2P3A
cJT=0?ooo`080000003oool0EEEE0:ZZZP3oool0ZZZZ05EEE@3oool20000000405EEE@000000ZZZZ
0?ooo`@0ZZZZ00H0000005EEE@1EEED0ZZZZ05EEE@2ZZZX205EEE@040?ooo`1EEED0EEEE00000080
ZZZZ00@0EEEE0:ZZZP3oool0ZZZZ100000000`3oool0EEEE0:ZZZP030:ZZZP030?ooo`000000oooo
00`0oooo303AcJT000/0dLfY703oool00`000000EEEE0?ooo`02000000060?ooo`00000000000000
001EEED000000P3oool01@000000oooo0?ooo`1EEED0000001`0oooo2P3AcJTN0?ooo`0305EEE@00
0000000000<0000000@0oooo000000000000oooo0`0000000`1EEED0oooo0?ooo`0L0?ooo`X0dLfY
6P3oool00`000000ZZZZ0:ZZZP030:ZZZP050?ooo`2ZZZX0ZZZZ0:ZZZP1EEED00P2ZZZX00`000000
ZZZZ0?ooo`030:ZZZP030000002ZZZX0oooo01X0oooo2P3AcJT>0?ooo`0305EEE@2ZZZX0oooo00<0
000000D0ZZZZ0000003oool0oooo000000020?ooo`80000000P0EEEE0?ooo`1EEED0oooo05EEE@3o
ool0ZZZZ0?ooo`80ZZZZ00H0oooo05EEE@3oool0EEEE0?ooo`1EEED200000080oooo00D000000?oo
o`3oool000000?ooo`020000000405EEE@3oool0000005EEE@h0oooo2P3AcJT>0?ooo`0505EEE@00
0000000005EEE@2ZZZX00`3oool02P1EEED0oooo0:ZZZP2ZZZX000000?ooo`2ZZZX0EEEE0?ooo`2Z
ZZX20?ooo`<0000000<0oooo0000002ZZZX00P3oool00`2ZZZX0oooo05EEE@020?ooo`<0ZZZZ00<0
oooo05EEE@3oool00P3oool01@2ZZZX0EEEE000000000000EEEE00h0oooo303AcJT000/0dLfY703o
ool050000000EEEE0?ooo`1EEED000000:ZZZP000000EEEE0?ooo`000000EEEE0000002ZZZX00000
0:ZZZP3oool0EEEE0000003oool000006P3oool:0=7=ZAd0oooo00@000000?ooo`2ZZZX0oooo0P2Z
ZZX0103oool0ZZZZ0:ZZZP3oool20:ZZZP040?ooo`2ZZZX0oooo000001d0oooo2P3AcJTJ0?ooo`04
0000002ZZZX0EEEE05EEE@@0ZZZZ00H0oooo05EEE@2ZZZX0000005EEE@0000020:ZZZP030000002Z
ZZX0EEEE0080ZZZZ6`3oool:0=7=Z@l0oooo0P2ZZZX300000080oooo0P1EEED60?ooo`030:ZZZP00
0000ZZZZ00@0oooo00T000000?ooo`3oool0oooo0:ZZZP000000ZZZZ0?ooo`1EEED0103oool205EE
E@030?ooo`0000000000008000000P2ZZZX?0?ooo`X0dLfY3`3oool01P2ZZZX0oooo0?ooo`3oool0
00000?ooo`80EEEE00L0oooo05EEE@2ZZZX0EEEE0?ooo`1EEED0000000<0ZZZZ00P000000?ooo`1E
EED0EEEE0?ooo`1EEED0oooo000000<0ZZZZ0P0000020?ooo`030:ZZZP1EEED0EEEE00<0EEEE00D0
00000?ooo`2ZZZX0oooo0:ZZZP0?0?ooo``0dLfY000;0=7=ZAX0oooo00@0EEEE0?ooo`3oool00000
0P2ZZZX010000000EEEE0000002ZZZX205EEE@040:ZZZP000000EEEE00000080ZZZZ00<0000005EE
E@3oool06`3oool:0=7=ZAh0oooo00<000000:ZZZP3oool00`3oool20:ZZZP060?ooo`2ZZZX0oooo
0?ooo`2ZZZX000007P3oool:0=7=ZA/0oooo00<0EEEE0?ooo`2ZZZX00P000000102ZZZX0oooo0?oo
o`3oool2000000<0oooo0P2ZZZX010000000ZZZZ0000001EEEDK0?ooo`X0dLfY403oool0101EEED0
ZZZZ0000002ZZZX20?ooo`80ZZZZ0P3oool20:ZZZP030?ooo`2ZZZX0oooo00<0oooo00<0ZZZZ0?oo
o`3oool00P3oool0202ZZZX0oooo0?ooo`000000oooo0:ZZZP3oool0ZZZZ103oool0102ZZZX0oooo
0?ooo`2ZZZX20000000305EEE@3oool0oooo00h0oooo2P3AcJT@0?ooo`0905EEE@000000000005EE
E@2ZZZX0EEEE0:ZZZP000000EEEE00<0oooo00H000000:ZZZP000000EEEE0000001EEED20?ooo`80
000000<0oooo05EEE@1EEED00`0000020:ZZZP060?ooo`2ZZZX0oooo05EEE@3oool0ZZZZ0`1EEED2
0000000305EEE@3oool0oooo00h0oooo303AcJT000/0dLfY6`3oool00`2ZZZX0EEEE000000030000
000405EEE@3oool0EEEE0:ZZZP80EEEE00<0oooo05EEE@0000000`0000000`1EEED0ZZZZ0?ooo`0J
0?ooo`X0dLfY7`3oool00`000000oooo0?ooo`0205EEE@040?ooo`000000EEEE00000080oooo00<0
EEEE0?ooo`3oool07@3oool:0=7=ZA`0oooo0P2ZZZX2000000@0ZZZZ00<0EEEE0:ZZZP2ZZZX00`2Z
ZZX0103oool000000:ZZZP2ZZZXL0?ooo`X0dLfY4@3oool20:ZZZP070?ooo`1EEED0EEEE0:ZZZP00
0000oooo0:ZZZP020?ooo`030000003oool0oooo00<0EEEE00<0oooo05EEE@3oool00P1EEED00`2Z
ZZX0EEEE05EEE@030?ooo`040000003oool000000:ZZZP80oooo00@0ZZZZ05EEE@1EEED0oooo0P2Z
ZZXA0?ooo`X0dLfY4@3oool0102ZZZX0oooo0:ZZZP3oool2000000050:ZZZP3oool0oooo0000001E
EED0102ZZZX01@3oool0ZZZZ0?ooo`3oool0EEEE00<0oooo00<0ZZZZ0?ooo`3oool00P2ZZZX00`3o
ool0EEEE0?ooo`020?ooo`070:ZZZP00000000000?ooo`2ZZZX0oooo0:ZZZP0A0?ooo``0dLfY000;
0=7=ZA`0oooo00D0EEEE0?ooo`3oool0000005EEE@030?ooo`030000001EEED0oooo0080oooo00D0
EEEE0:ZZZP3oool0oooo05EEE@0L0?ooo`X0dLfY7@3oool03@000000oooo0000001EEED0oooo0000
001EEED0oooo0000001EEED000000?ooo`1EEED00P3oool00`000000oooo0?ooo`0K0?ooo`X0dLfY
703oool00`2ZZZX0oooo0?ooo`020?ooo`080:ZZZP3oool0oooo0000002ZZZX0oooo0000002ZZZX4
0?ooo`030000003oool0oooo01X0oooo2P3AcJTB0?ooo`0405EEE@000000oooo05EEE@@0000000@0
ZZZZ0?ooo`3oool0oooo0P2ZZZX00`000000oooo0?ooo`020:ZZZP050?ooo`2ZZZX0oooo0?ooo`00
00000P2ZZZX40?ooo`@0000000@0EEEE0:ZZZP000000EEEE4P3oool:0=7=ZA80oooo00<0EEEE0000
000000000P1EEED30?ooo`050:ZZZP3oool0ZZZZ0:ZZZP3oool00P2ZZZX00`3oool0ZZZZ05EEE@02
0?ooo`0:05EEE@3oool0oooo0:ZZZP000000oooo0:ZZZP000000oooo05EEE@80oooo00<0ZZZZ05EE
E@1EEED00P0000000`1EEED0oooo0?ooo`0@0?ooo``0dLfY000;0=7=ZA`0oooo00@0ZZZZ0?ooo`1E
EED0ZZZZ0`3oool010000000EEEE0?ooo`0000030?ooo`030:ZZZP1EEED0oooo01d0oooo2P3AcJTN
0?ooo`0305EEE@3oool0ZZZZ00<0oooo0P2ZZZX00`3oool0EEEE0?ooo`020:ZZZP0305EEE@3oool0
oooo01`0oooo2P3AcJTL0?ooo`H0ZZZZ0P3oool2000000030?ooo`000000ZZZZ00@0ZZZZ00<00000
0?ooo`3oool06P3oool:0=7=ZA<0oooo0P2ZZZX5000000L0oooo0P1EEED0102ZZZX000000?ooo`2Z
ZZX205EEE@030?ooo`000000oooo00<0oooo1P0000020:ZZZQ<0oooo2P3AcJTC0?ooo`0>0:ZZZP3o
ool0ZZZZ0?ooo`000000EEEE0?ooo`000000ZZZZ0?ooo`1EEED0ZZZZ0?ooo`1EEED20:ZZZP@0oooo
00<0EEEE0:ZZZP1EEED00P2ZZZX01P1EEED0ZZZZ0:ZZZP000000oooo05EEE@80oooo0`2ZZZXC0?oo
o``0dLfY000;0=7=ZA`0oooo00D000000:ZZZP000000oooo000000030?ooo`030:ZZZP1EEED0oooo
0080oooo00@000000:ZZZP000000ZZZZ7@3oool:0=7=ZAh0oooo00<000000:ZZZP2ZZZX00P000000
101EEED0ZZZZ05EEE@1EEED200000080ZZZZ00<000000?ooo`3oool0703oool:0=7=ZA`0oooo00<0
EEEE0000002ZZZX00P000000101EEED0ZZZZ0:ZZZP3oool30:ZZZP0505EEE@000000EEEE0:ZZZP00
00007@3oool:0=7=ZAH0oooo00T0EEEE0?ooo`1EEED0oooo05EEE@000000ZZZZ0000001EEED01@3o
ool2000000030?ooo`2ZZZX0oooo0080oooo00@0EEEE0000002ZZZX000000P3oool01@1EEED0oooo
05EEE@3oool0000001@0oooo2P3AcJTE0?ooo`030:ZZZP1EEED0ZZZZ0080oooo00H0EEEE0?ooo`1E
EED0ZZZZ0000002ZZZX20?ooo`030000002ZZZX000000080ZZZZ00<000000?ooo`3oool00P000002
0:ZZZP@0oooo00@0ZZZZ05EEE@2ZZZX00000503oool<0=7=Z@002`3AcJTL0?ooo`80000000l0EEEE
0?ooo`000000EEEE0?ooo`1EEED000000?ooo`1EEED0000005EEE@000000ZZZZ05EEE@0000007@3o
ool:0=7=ZAl0oooo0P2ZZZX2000000070?ooo`1EEED0EEEE0?ooo`1EEED000000:ZZZP0P0?ooo`X0
dLfY7@3oool01@000000EEEE0:ZZZP3oool0ZZZZ0080000000<0oooo0000000000000P2ZZZX0103o
ool0ZZZZ05EEE@00000M0?ooo`X0dLfY5@3oool20:ZZZP030?ooo`1EEED0EEEE00D0ZZZZ00<0oooo
05EEE@1EEED00`3oool00`000000oooo05EEE@0205EEE@030000002ZZZX0ZZZZ0080ZZZZ0`1EEED3
0:ZZZQD0oooo2P3AcJTE0?ooo`<0ZZZZ0P3oool2000000030:ZZZP1EEED0EEEE0080ZZZZ0`3oool0
0`1EEED0ZZZZ0?ooo`020?ooo`050:ZZZP1EEED0EEEE05EEE@3oool00P0000030?ooo`80ZZZZ5@3o
ool<0=7=Z@002`3AcJTL0?ooo`8000000P1EEED00`2ZZZX0000005EEE@020?ooo`080000003oool0
ZZZZ0000002ZZZX0oooo05EEE@00000M0?ooo`X0dLfY7`3oool00`000000EEEE0?ooo`020:ZZZP03
05EEE@2ZZZX0ZZZZ0080oooo00<0EEEE0?ooo`3oool07P3oool:0=7=ZAd0oooo00<000000:ZZZP2Z
ZZX00`2ZZZX01@3oool0ZZZZ0:ZZZP3oool000000080ZZZZ00<000000:ZZZP0000007@3oool:0=7=
ZAH0oooo00T000000?ooo`3oool0ZZZZ0?ooo`000000oooo0000003oool00P1EEED00`000000EEEE
05EEE@020?ooo`80EEEE00T0000005EEE@3oool0oooo0000003oool000000?ooo`2ZZZX00P3oool0
0`000000oooo0?ooo`0D0?ooo`X0dLfY5P3oool01P000000ZZZZ05EEE@2ZZZX0oooo0:ZZZP@00000
00X0EEEE0000001EEED0EEEE0:ZZZP3oool0EEEE0?ooo`000000EEEE0`0000040:ZZZP0305EEE@3o
ool0000001H0oooo303AcJT000/0dLfY7@3oool02@000000EEEE05EEE@000000oooo0000001EEED0
oooo0:ZZZP0205EEE@050?ooo`000000EEEE05EEE@0000007@3oool:0=7=ZB00oooo00D000000:ZZ
ZP2ZZZX0ZZZZ0?ooo`020:ZZZP030?ooo`2ZZZX000000200oooo2P3AcJTN0?ooo`0905EEE@2ZZZX0
00000?ooo`1EEED0000005EEE@2ZZZX000000080oooo0P0000000`1EEED0oooo0?ooo`0L0?ooo`X0
dLfY5`3oool30:ZZZP<0000000<0ZZZZ05EEE@0000000P3oool01@000000ZZZZ05EEE@3oool0ZZZZ
00<0oooo00<0ZZZZ05EEE@2ZZZX00`0000020:ZZZQP0oooo2P3AcJTG0?ooo`80ZZZZ0`3oool01`1E
EED0ZZZZ05EEE@1EEED0oooo0000003oool0102ZZZX00`3oool000000?ooo`0205EEE@060:ZZZP00
0000oooo0:ZZZP3oool0ZZZZ603oool<0=7=Z@002`3AcJTN0?ooo`0305EEE@3oool0EEEE0080oooo
00<0ZZZZ0000003oool00P2ZZZX0103oool0EEEE0000001EEEDN0?ooo`X0dLfY8@3oool0201EEED0
00000?ooo`1EEED000000?ooo`000000EEEE8@3oool:0=7=ZAl0oooo00@0ZZZZ0000003oool0oooo
0P2ZZZX01P000000ZZZZ0?ooo`3oool000000:ZZZQl0oooo2P3AcJTH0?ooo`0A0000003oool0EEEE
0?ooo`1EEED0oooo0:ZZZP1EEED0oooo0000002ZZZX0oooo0000001EEED0oooo0:ZZZP0000000P3o
ool00`2ZZZX0oooo0?ooo`030?ooo`030000003oool0oooo01H0oooo2P3AcJTH0?ooo`040000003o
ool0EEEE0:ZZZP80oooo0P0000001@3oool0EEEE0000001EEED000000080EEEE00<0oooo05EEE@3o
ool00P0000001P3oool0ZZZZ0:ZZZP2ZZZX0oooo000001P0oooo303AcJT000/0dLfY7`3oool20:ZZ
ZP80000000@0ZZZZ05EEE@3oool0ZZZZ0P0000020:ZZZQl0oooo2P3AcJTR0?ooo`060:ZZZP3oool0
oooo05EEE@3oool0ZZZZ8P3oool:0=7=ZAl0oooo00<0EEEE0:ZZZP2ZZZX00P2ZZZX00`3oool00000
0:ZZZP030:ZZZP030000003oool0oooo01d0oooo2P3AcJTI0?ooo`0305EEE@2ZZZX0000000<0oooo
0P1EEED01@3oool000000?ooo`3oool0ZZZZ00<0oooo00D0EEEE0000003oool0oooo0:ZZZP020000
000305EEE@3oool0oooo01L0oooo2P3AcJTI0?ooo`0405EEE@000000000005EEE@@0ZZZZ00X00000
0?ooo`3oool0oooo0:ZZZP3oool0EEEE0000002ZZZX0oooo0P2ZZZX0101EEED000000000001EEEDI
0?ooo``0dLfY000;0=7=ZAl0oooo0P1EEED00`000000oooo0?ooo`0205EEE@040?ooo`0000000000
05EEEB00oooo2P3AcJTR0?ooo`80EEEE00<0oooo0:ZZZP1EEED08`3oool:0=7=ZAl0oooo0P2ZZZX0
0`1EEED0ZZZZ0?ooo`030?ooo`040000001EEED0ZZZZ000001l0oooo2P3AcJTJ0?ooo`040000003o
ool0oooo0:ZZZP<0oooo0`0000000`3oool0000000000002000000<0oooo00<0ZZZZ0?ooo`3oool0
6`3oool:0=7=ZAX0oooo00<000000?ooo`1EEED00P2ZZZX00`000000oooo000000020:ZZZP0505EE
E@3oool0ZZZZ0:ZZZP0000000P3oool30:ZZZQ`0oooo303AcJT000/0dLfY803oool01@2ZZZX0oooo
0:ZZZP2ZZZX0000000<0ZZZZ00<0oooo0:ZZZP3oool07`3oool:0=7=ZB<0oooo00@0ZZZZ05EEE@00
0000ZZZZ8`3oool:0=7=ZAl0oooo0P2ZZZX2000000@0oooo0P0000000`2ZZZX000000?ooo`0N0?oo
o`X0dLfY6`3oool00`1EEED0ZZZZ0?ooo`0205EEE@040?ooo`1EEED0oooo05EEE@80oooo00@0EEEE
0?ooo`1EEED0oooo0P1EEED00`3oool0000005EEE@0K0?ooo`X0dLfY6`3oool0101EEED000000000
001EEED30?ooo`060:ZZZP3oool0EEEE05EEE@3oool0EEEE0P3oool205EEE@80000000<0EEEE0?oo
o`3oool06@3oool<0=7=Z@002`3AcJTP0?ooo`8000000P1EEED20?ooo`0405EEE@00000000000000
0200oooo2P3AcJTP0?ooo`040000003oool0oooo05EEE@80ZZZZ00@0EEEE0?ooo`3oool00000803o
ool:0=7=ZB00oooo0P2ZZZX00`000000oooo0?ooo`020?ooo`<0ZZZZ803oool:0=7=ZA`0oooo00@0
00000?ooo`3oool0oooo0P2ZZZX00`3oool0EEEE0?ooo`0205EEE@<0ZZZZ00<0EEEE0?ooo`3oool0
7@3oool:0=7=ZA`0oooo00D000000?ooo`2ZZZX0ZZZZ05EEE@020:ZZZP060?ooo`2ZZZX0oooo0?oo
o`1EEED0ZZZZ0P1EEED00`2ZZZX0oooo0?ooo`0L0?ooo``0dLfY000;0=7=ZB00oooo0P0000000`2Z
ZZX0EEEE0000000305EEE@800000803oool:0=7=ZB40oooo00@0EEEE0?ooo`1EEED0ZZZZ0P1EEED0
0`2ZZZX0EEEE0?ooo`0P0?ooo`X0dLfY803oool2000000D0oooo00<0EEEE000000000000803oool:
0=7=ZAd0oooo00<0EEEE0000000000000`3oool01@2ZZZX0oooo0?ooo`2ZZZX000000080oooo00<0
ZZZZ0000001EEED07@3oool:0=7=ZAd0oooo00L0EEEE000000000000EEEE0:ZZZP3oool000000080
ZZZZ00@000000?ooo`2ZZZX0EEEE0P0000000`1EEED0oooo0?ooo`0K0?ooo``0dLfY000;0=7=ZB00
oooo0P000000103oool0EEEE0?ooo`00000205EEE@800000803oool:0=7=ZB40oooo00D000000:ZZ
ZP2ZZZX0ZZZZ05EEE@020:ZZZP030000003oool0oooo01l0oooo2P3AcJTP0?ooo`030000002ZZZX0
oooo00D0oooo00<0ZZZZ0000003oool07`3oool:0=7=ZAh0oooo0P2ZZZX00`3oool0000000000004
0?ooo`80000000<0oooo0:ZZZP2ZZZX07P3oool:0=7=ZAh0oooo00L0ZZZZ0?ooo`2ZZZX0oooo05EE
E@3oool000000080oooo00<0EEEE0?ooo`2ZZZX00P2ZZZXN0?ooo``0dLfY000;0=7=ZB40oooo00D0
EEEE0:ZZZP3oool0EEEE000000020?ooo`0305EEE@3oool0oooo01l0oooo2P3AcJTQ0?ooo`040000
002ZZZX0ZZZZ05EEE@80ZZZZ00<0oooo0000003oool0803oool:0=7=ZB40oooo00@0EEEE0?ooo`00
0000EEEE0`0000000`1EEED0oooo0?ooo`0O0?ooo`X0dLfY7`3oool00`1EEED000000:ZZZP060?oo
o`030:ZZZP000000oooo01l0oooo2P3AcJTO0?ooo`0305EEE@00000000000080000000<0ZZZZ0?oo
o`0000000`00000P0?ooo``0dLfY000;0=7=ZB80oooo00@0EEEE0:ZZZP2ZZZX0oooo0P2ZZZXR0?oo
o`X0dLfY8P3oool01P2ZZZX000000?ooo`1EEED0000005EEEB80oooo2P3AcJTR0?ooo`<0ZZZZ00<0
oooo0:ZZZP2ZZZX08P3oool:0=7=ZB00oooo0P2ZZZX01@000000oooo05EEE@1EEED0oooo00<0ZZZZ
803oool:0=7=ZB00oooo102ZZZX010000000oooo0:ZZZP3oool20:ZZZR00oooo303AcJT000/0dLfY
8P3oool20:ZZZP040?ooo`1EEED0ZZZZ00000280oooo2P3AcJTR0?ooo`80ZZZZ0P3oool00`2ZZZX0
00000?ooo`0Q0?ooo`X0dLfY8P3oool01P000000oooo0?ooo`000000oooo00000280oooo2P3AcJTQ
0?ooo`040000003oool0EEEE00000080EEEE00<0oooo0000003oool0803oool:0=7=ZB40oooo00P0
00000:ZZZP1EEED0EEEE0?ooo`1EEED0oooo00000240oooo303AcJT000/0dLfY8`3oool0102ZZZX0
EEEE0?ooo`2ZZZXS0?ooo`X0dLfY8`3oool40:ZZZR<0oooo2P3AcJTS0?ooo`040:ZZZP1EEED0EEEE
0:ZZZR<0oooo2P3AcJTR0?ooo`80ZZZZ00<0oooo0:ZZZP2ZZZX08`3oool:0=7=ZB80oooo0P2ZZZX0
0`000000oooo0:ZZZP0S0?ooo``0dLfY000;0=7=ZB<0oooo0P0000000`2ZZZX000000?ooo`0R0?oo
o`X0dLfY8`3oool010000000ZZZZ05EEE@00000S0?ooo`X0dLfY8`3oool010000000ZZZZ00000000
000S0?ooo`X0dLfY8`3oool010000000oooo0?ooo`00000S0?ooo`X0dLfY8`3oool010000000EEEE
0?ooo`00000S0?ooo``0dLfY000;0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool:0=7=ZB@0oooo
00<0ZZZZ0?ooo`3oool08`3oool:0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool:0=7=ZB@0oooo
00<0ZZZZ0?ooo`3oool08`3oool:0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool<0=7=Z@00o`3A
cJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@002`3A
cJT0103oool0EEEE0000001EEED20000000;0?ooo`00000000000:ZZZP3oool000000:ZZZP3oool0
ZZZZ0?ooo`0000000P1EEED02P3oool000000?ooo`2ZZZX000000:ZZZP1EEED000000:ZZZP1EEED2
00000080ZZZZ00D0EEEE0:ZZZP2ZZZX000000?ooo`020:ZZZP0305EEE@2ZZZX00000008000000`2Z
ZZX01`1EEED0ZZZZ0000002ZZZX0oooo0:ZZZP3oool00P1EEED01`000000ZZZZ0:ZZZP3oool0EEEE
0000003oool01P000000101EEED0000005EEE@3oool:0=7=Z@030?ooo`1EEED0EEEE008000000P3o
ool205EEE@030:ZZZP00000000000080000000T0ZZZZ0000003oool000000?ooo`000000EEEE0:ZZ
ZP3oool01000000405EEE@030:ZZZP000000000000H0EEEE0P0000001@2ZZZX0EEEE05EEE@000000
EEEE00<0000000D0ZZZZ0?ooo`2ZZZX0ZZZZ000000030?ooo`0405EEE@2ZZZX000000?ooo`800000
00<0oooo05EEE@1EEED00P3oool200000080EEEE00<0oooo0=7=Z@3AcJT0203AcJT0203oool0EEEE
05EEE@000000EEEE0000001EEED0oooo0P2ZZZX40?ooo`030000001EEED0000000<0ZZZZ00@0EEEE
0000001EEED0oooo0P0000000`2ZZZX000000?ooo`0200000080oooo00<000000?ooo`2ZZZX00P1E
EED00`2ZZZX00000000000020?ooo`80000000<0oooo0000001EEED00P00000205EEE@080000002Z
ZZX0ZZZZ0:ZZZP1EEED0000005EEE@0000040?ooo`80ZZZZ00D0oooo05EEE@000000EEEE00000002
05EEE@030?ooo`3AcJT0dLfY00P0dLfY4P3oool20000000505EEE@2ZZZX0oooo05EEE@0000000`3o
ool200000080oooo00@000000?ooo`3oool0EEEE0P3oool205EEE@060?ooo`00000000000?ooo`00
0000EEEE0`3oool010000000ZZZZ0?ooo`2ZZZX300000180oooo2P3AcJTI0?ooo`0805EEE@3oool0
EEEE0?ooo`000000oooo0:ZZZP0000080?ooo`030000002ZZZX0oooo0080000000D0EEEE0?ooo`1E
EED0oooo05EEE@0G0?ooo``0dLfY000;0=7=Z@030?ooo`1EEED0oooo00@0ZZZZ0`0000000`1EEED0
oooo0:ZZZP0305EEE@040:ZZZP3oool0ZZZZ0:ZZZP80EEEE00@0ZZZZ0000002ZZZX0oooo0P000004
0:ZZZP0405EEE@000000oooo00000080ZZZZ0`0000003@1EEED0ZZZZ0:ZZZP2ZZZX0oooo0000002Z
ZZX0oooo0:ZZZP000000ZZZZ05EEE@0000000P2ZZZX00`3oool0ZZZZ05EEE@0205EEE@040:ZZZP3o
ool0EEEE0:ZZZP800000102ZZZX30?ooo`X0dLfY00<0oooo05EEE@3oool01@3oool0101EEED00000
0:ZZZP1EEED3000000<0EEEE00D000000?ooo`2ZZZX000000?ooo`0505EEE@040:ZZZP0000000000
0?ooo`80000000<0ZZZZ0000002ZZZX01@000000102ZZZX0000000000000000505EEE@060?ooo`00
000000000?ooo`000000ZZZZ0P1EEED2000000050?ooo`1EEED0ZZZZ0?ooo`1EEED00`3oool00`00
0000oooo0?ooo`020?ooo`X0dLfY00H0oooo05EEE@1EEED0oooo0000003oool205EEE@050000001E
EED0000005EEE@0000000P1EEED20?ooo`80ZZZZ00H000000:ZZZP1EEED0oooo05EEE@0000020:ZZ
ZP@0EEEE00@0000005EEE@1EEED0EEEE1000000605EEE@0=0000001EEED0EEEE0:ZZZP000000EEEE
0?ooo`1EEED0ZZZZ0000002ZZZX000000?ooo`0505EEE@<0000000H0EEEE0?ooo`3oool0ZZZZ0?oo
o`1EEED20?ooo`X0dLfY4`3oool0101EEED0oooo0:ZZZP0000020?ooo`0305EEE@3oool0oooo0080
ZZZZ0P3oool20:ZZZP0405EEE@000000ZZZZ0:ZZZP8000000P2ZZZX00`1EEED0oooo0:ZZZP020?oo
o`080000001EEED0oooo0:ZZZP000000ZZZZ0?ooo`1EEEDC0?ooo`X0dLfY5`3oool00`2ZZZX0EEEE
0?ooo`020?ooo`80ZZZZ00<0oooo05EEE@3oool01P3oool01@000000oooo0?ooo`1EEED0oooo0080
ZZZZ00@0oooo0000003oool0EEEE603oool<0=7=Z@002`3AcJT30?ooo`0605EEE@000000ZZZZ0000
002ZZZX000000`3oool00`2ZZZX000000:ZZZP0205EEE@<0oooo0`2ZZZX00`000000EEEE00000003
000000<0ZZZZ00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000<0ZZZZ1000
00000`1EEED0oooo0:ZZZP020:ZZZP80oooo00H0ZZZZ05EEE@1EEED0ZZZZ0000001EEED30?ooo`03
0000002ZZZX000000080ZZZZ00@0EEEE0?ooo`3oool0oooo2P3AcJT30?ooo`80EEEE00<000000?oo
o`2ZZZX0102ZZZX2000000030:ZZZP1EEED0EEEE00<0ZZZZ00H0000005EEE@000000oooo0000002Z
ZZX4000000050:ZZZP1EEED0000005EEE@2ZZZX00P0000001`1EEED000000000001EEED000000?oo
o`2ZZZX00`0000000`1EEED0ZZZZ000000020000000305EEE@000000ZZZZ0080ZZZZ00D0EEEE0:ZZ
ZP2ZZZX0000005EEE@020:ZZZP070000002ZZZX0ZZZZ05EEE@000000ZZZZ05EEE@030?ooo`X0dLfY
0`3oool205EEE@050000001EEED000000?ooo`1EEED00P00000505EEE@<0oooo0P0000001@2ZZZX0
0000000000000000EEEE00@0000000H0ZZZZ0000001EEED0EEEE0000001EEED30000000305EEE@00
000000000080000000<0ZZZZ0000000000000`0000000`2ZZZX00000000000020?ooo`030:ZZZP1E
EED0EEEE00<0EEEE0P0000020?ooo`030000001EEED000000080EEEE0`3oool:0=7=ZA@0oooo00D0
ZZZZ05EEE@1EEED0ZZZZ000000020?ooo`030:ZZZP3oool0oooo0080ZZZZ0P3oool01P1EEED0oooo
05EEE@1EEED0oooo0:ZZZP80oooo00<0EEEE0:ZZZP3oool00P2ZZZX20?ooo`050000001EEED0EEEE
05EEE@000000503oool:0=7=ZAP0oooo0`1EEED30:ZZZP030000003oool0000000P0ZZZZ00L00000
0?ooo`000000ZZZZ05EEE@2ZZZX000000080EEEE603oool<0=7=Z@002`3AcJT40?ooo`0305EEE@00
000000000080000000D0ZZZZ0000002ZZZX0oooo000000020?ooo`070:ZZZP000000EEEE0?ooo`2Z
ZZX0oooo000000020:ZZZP050?ooo`2ZZZX0oooo0:ZZZP3oool00`0000040:ZZZP040000002ZZZX0
ZZZZ0:ZZZP<0000000D0oooo05EEE@3oool0EEEE0?ooo`020:ZZZP060000003oool000000?ooo`1E
EED0oooo0P2ZZZX01P3oool000000:ZZZP2ZZZX000000:ZZZP80000000<0ZZZZ0000001EEED0103o
ool:0=7=Z@@0oooo00/0EEEE000000000000ZZZZ0?ooo`000000EEEE0000002ZZZX0EEEE00000002
05EEE@030000001EEED000000080000000<0ZZZZ0000003oool00P000000101EEED0000005EEE@2Z
ZZX30000000405EEE@2ZZZX0000000000080ZZZZ0P0000020:ZZZP0805EEE@2ZZZX0EEEE0:ZZZP00
0000oooo05EEE@2ZZZX30000000305EEE@000000EEEE0080000000H0EEEE000000000000EEEE0000
003oool20:ZZZP030000001EEED0oooo00<0oooo2P3AcJT40?ooo`0305EEE@3oool0000000<0oooo
00<0EEEE0:ZZZP2ZZZX00P3oool00`1EEED0oooo0000000205EEE@030:ZZZP1EEED000000080oooo
00<000000?ooo`2ZZZX0101EEED01P2ZZZX0oooo05EEE@2ZZZX0EEEE0?ooo`80ZZZZ00<0oooo0:ZZ
ZP1EEED00`1EEED0102ZZZX000000000003oool20000000305EEE@000000EEEE0080EEEE00<0oooo
05EEE@3oool00P3oool00`2ZZZX0EEEE0?ooo`020?ooo`030:ZZZP3oool0EEEE00@0oooo2P3AcJTB
0?ooo`030000003oool0EEEE00<0EEEE0`3oool01@1EEED0oooo0:ZZZP1EEED000000080oooo00<0
ZZZZ05EEE@1EEED00P1EEED01P000000oooo0?ooo`2ZZZX0EEEE0:ZZZP80EEEE00<000000?ooo`3o
ool00`1EEED20?ooo`030000003oool0oooo0100oooo2P3AcJTI0?ooo`80ZZZZ00<0oooo05EEE@1E
EED00`3oool0101EEED0oooo05EEE@3oool405EEE@<0oooo00D0EEEE0000003oool0oooo0:ZZZP0I
0?ooo``0dLfY000;0=7=Z@@0oooo00P0EEEE0?ooo`00000000000:ZZZP3oool000000?ooo`<0ZZZZ
00<0oooo05EEE@2ZZZX00P3oool01`000000ZZZZ0:ZZZP1EEED000000:ZZZP3oool00P0000050:ZZ
ZP060000002ZZZX0oooo05EEE@2ZZZX0EEEE1@2ZZZX01@1EEED000000:ZZZP2ZZZX0000000<0ZZZZ
0`3oool205EEE@050000002ZZZX0ZZZZ0000003oool00P0000000`2ZZZX000000:ZZZP060?ooo`X0
dLfY103oool0101EEED0oooo0000001EEED3000000040:ZZZP00000000000:ZZZP80oooo00<0ZZZZ
0000000000000`00000205EEE@040:ZZZP3oool0oooo000000<0EEEE00<0ZZZZ0?ooo`1EEED01000
0000101EEED0oooo0:ZZZP3oool205EEE@040:ZZZP3oool000000:ZZZP80EEEE1@000000301EEED0
oooo05EEE@2ZZZX0000005EEE@2ZZZX000000?ooo`000000EEEE0:ZZZPH0oooo2P3AcJT40?ooo`80
EEEE1@3oool205EEE@050000001EEED0oooo0?ooo`1EEED00P2ZZZX0103oool000000:ZZZP000003
05EEE@H0000000<0EEEE0:ZZZP2ZZZX00P0000000`2ZZZX0EEEE05EEE@06000000@0EEEE00<0ZZZZ
0000001EEED00P2ZZZX20?ooo`80EEEE0P0000000`1EEED0oooo0?ooo`020?ooo`030000001EEED0
oooo00@0oooo2P3AcJTC0?ooo`0605EEE@00000000000000003oool000000P3oool010000000oooo
05EEE@1EEED30?ooo`D0EEEE0`3oool305EEE@80000000<0EEEE0?ooo`000000100000000`1EEED0
oooo0?ooo`0A0?ooo`X0dLfY603oool00`000000oooo05EEE@020:ZZZPH0oooo00D0EEEE0?ooo`00
0000EEEE0:ZZZP060?ooo`80ZZZZ00<0oooo0000003oool05`3oool<0=7=Z@002`3AcJT60?ooo`05
0:ZZZP00000000000000001EEED00`2ZZZX01P000000ZZZZ05EEE@3oool000000?ooo`8000000`2Z
ZZX20?ooo`P0ZZZZ103oool60:ZZZP040000002ZZZX0ZZZZ0?ooo`<0ZZZZ00<000000:ZZZP3oool0
0P0000000`1EEED00000000000030:ZZZP0505EEE@2ZZZX000000000001EEED01P3oool:0=7=Z@H0
oooo00<0ZZZZ0000001EEED00P1EEED02@000000oooo0000003oool0EEEE0?ooo`000000EEEE0?oo
o`04000000050:ZZZP1EEED0EEEE0000001EEED0102ZZZX00`1EEED00000000000040000000305EE
E@2ZZZX000000080ZZZZ00H0EEEE000000000000EEEE0:ZZZP3oool30000000>0?ooo`1EEED0ZZZZ
0?ooo`1EEED0oooo0000001EEED0000005EEE@000000EEEE0000001EEED60?ooo`X0dLfY1P3oool0
0`1EEED0oooo0:ZZZP020?ooo`0305EEE@000000000000D0EEEE00<0oooo05EEE@0000000P000002
0:ZZZP0;0000001EEED0000005EEE@3oool0EEEE0000003oool0EEEE0:ZZZP3oool00P2ZZZX02@1E
EED0oooo000000000000oooo05EEE@000000EEEE000000020:ZZZP<0000000P0ZZZZ0?ooo`1EEED0
000005EEE@000000EEEE00000080EEEE00D0oooo0000002ZZZX0oooo05EEE@060?ooo`X0dLfY4P3o
ool01@000000oooo05EEE@3oool0ZZZZ0080oooo0P2ZZZX30?ooo`0305EEE@3oool0oooo0080oooo
00@0EEEE0?ooo`3oool0EEEE103oool03@1EEED0oooo0?ooo`3oool0EEEE0:ZZZP3oool000000:ZZ
ZP3oool0EEEE0?ooo`0000004P3oool:0=7=ZAT0oooo00@0000005EEE@3oool0oooo0P1EEED20000
000305EEE@2ZZZX0oooo00<0oooo00@0ZZZZ05EEE@000000ZZZZ0P1EEED20?ooo`0305EEE@000000
oooo01P0oooo303AcJT000/0dLfY1P3oool205EEE@0:0000002ZZZX0oooo0:ZZZP1EEED0ZZZZ0000
002ZZZX0oooo00000080EEEE0P0000030:ZZZP80EEEE00<0ZZZZ0000003oool01@0000001@2ZZZX0
00000:ZZZP2ZZZX0oooo00@0000000<0oooo0000002ZZZX00P1EEED01@2ZZZX0EEEE0:ZZZP000000
ZZZZ0080EEEE0P3oool2000000070:ZZZP000000ZZZZ0?ooo`1EEED0000005EEE@070?ooo`X0dLfY
1P3oool305EEE@030:ZZZP000000000000<0ZZZZ00<000000:ZZZP1EEED00P3oool200000080oooo
00/000000:ZZZP1EEED0EEEE0000001EEED000000?ooo`2ZZZX000000?ooo`06000000030:ZZZP00
0000000000<0EEEE00<000000:ZZZP0000000P3oool010000000oooo0?ooo`3oool20:ZZZP030000
002ZZZX0ZZZZ00@000000P1EEED70?ooo`X0dLfY1P3oool205EEE@060000003oool0oooo0?ooo`00
0000EEEE0P2ZZZX0203oool00000000000000000ZZZZ05EEE@000000EEEE0P0000000`2ZZZX00000
000000020000000305EEE@2ZZZX0000000<0000000@0EEEE00000000000000000P2ZZZX200000003
0?ooo`000000EEEE0080000000@0ZZZZ0000001EEED0ZZZZ0`0000001@3oool0ZZZZ0:ZZZP1EEED0
ZZZZ00<0oooo00<0000005EEE@3oool01P3oool:0=7=ZA<0oooo00<0EEEE0:ZZZP1EEED00P3oool0
0`2ZZZX0EEEE000000040?ooo`0505EEE@3oool0000005EEE@0000000P2ZZZX01@000000oooo0000
003oool0ZZZZ00@0oooo00P0ZZZZ05EEE@2ZZZX0EEEE0?ooo`1EEED0000005EEEA<0oooo2P3AcJTJ
0?ooo`040000003oool0oooo00000080EEEE0P3oool200000080oooo00<000000:ZZZP3oool00P3o
ool01@1EEED000000000003oool0EEEE01X0oooo303AcJT000/0dLfY1`3oool00`1EEED0oooo0:ZZ
ZP0205EEE@80000000<0oooo0000002ZZZX00P0000001@1EEED0ZZZZ000000000000EEEE0080ZZZZ
00<0oooo0:ZZZP0000001@2ZZZX3000000030?ooo`000000ZZZZ00D0ZZZZ00<000000:ZZZP3oool0
0P2ZZZX40000000405EEE@000000ZZZZ0:ZZZP80oooo00L0000005EEE@1EEED0EEEE0:ZZZP3oool0
EEEE00L0oooo2P3AcJT70?ooo`0B05EEE@3oool000000:ZZZP1EEED0ZZZZ0000003oool0EEEE0?oo
o`1EEED000000?ooo`000000ZZZZ05EEE@2ZZZX0EEEE0P0000002@2ZZZX000000000002ZZZX00000
0?ooo`2ZZZX000000?ooo`02000000060?ooo`1EEED0ZZZZ0?ooo`1EEED0ZZZZ0P0000000`2ZZZX0
00000000000305EEE@0<0:ZZZP1EEED0oooo0000001EEED0oooo0:ZZZP3oool000000?ooo`1EEED0
ZZZZ0P3oool00`1EEED0oooo0?ooo`050?ooo`X0dLfY1`3oool205EEE@030000001EEED0EEEE0080
oooo00<0EEEE0000001EEED00`1EEED0202ZZZX0EEEE0:ZZZP2ZZZX0oooo05EEE@2ZZZX000000`1E
EED20:ZZZP030000002ZZZX0oooo0080EEEE00@0oooo05EEE@000000ZZZZ101EEED01P000000ZZZZ
05EEE@3oool000000:ZZZPH0EEEE00@0000005EEE@3oool000001@1EEED70?ooo`X0dLfY503oool0
102ZZZX0EEEE0000003oool205EEE@D0oooo00H0ZZZZ05EEE@3oool0oooo0:ZZZP1EEED20:ZZZP80
oooo00<0EEEE0000003oool00`3oool305EEE@80000000<0EEEE0:ZZZP3oool04`3oool:0=7=ZAP0
oooo0P000000101EEED0oooo0:ZZZP2ZZZX20?ooo`030:ZZZP1EEED0EEEE00D0oooo00@0EEEE0:ZZ
ZP3oool0oooo0P2ZZZX20?ooo`800000603oool<0=7=Z@002`3AcJT90?ooo`060:ZZZP000000ZZZZ
05EEE@2ZZZX000000P1EEED30?ooo`D0EEEE00<0ZZZZ0000002ZZZX0202ZZZX00`3oool0EEEE0:ZZ
ZP060:ZZZP040000002ZZZX0oooo0:ZZZP@0EEEE0`3oool010000000EEEE05EEE@0000030:ZZZP03
0000001EEED0oooo00P0oooo2P3AcJT90?ooo`090:ZZZP1EEED000000000001EEED0oooo0000003o
ool000000080ZZZZ00@0oooo0:ZZZP2ZZZX0ZZZZ0P00000505EEE@060:ZZZP00000000000?ooo`2Z
ZZX0oooo0P2ZZZX3000000030:ZZZP1EEED0EEEE0080EEEE100000060:ZZZP<0oooo00<0EEEE0000
000000000P1EEED90?ooo`X0dLfY2@3oool00`1EEED000000?ooo`030?ooo`0305EEE@0000000000
0080EEEE0P3oool02@000000oooo0000003oool000000:ZZZP1EEED0000005EEE@0300000080EEEE
0P3oool205EEE@<0000000@0EEEE0000001EEED0ZZZZ0P3oool00`000000EEEE000000020?ooo`<0
EEEE00<000000?ooo`3oool00`3oool00`000000EEEE0?ooo`080?ooo`X0dLfY503oool205EEE@04
0:ZZZP3oool0oooo05EEE@D0oooo0`0000000`2ZZZX0EEEE05EEE@0205EEE@<000001P3oool01@1E
EED0oooo0?ooo`2ZZZX0EEEE01D0oooo2P3AcJTJ0?ooo`0605EEE@2ZZZX0oooo0:ZZZP1EEED00000
0P2ZZZX50?ooo`030000002ZZZX0ZZZZ0080EEEE00@0ZZZZ0?ooo`2ZZZX0ZZZZ6P3oool<0=7=Z@00
2`3AcJT90?ooo`80EEEE00H000000?ooo`2ZZZX0000005EEE@0000020:ZZZP030000002ZZZX0oooo
0080ZZZZ00@0oooo0:ZZZP2ZZZX00000201EEED20?ooo`P0EEEE0P000000202ZZZX0oooo0?ooo`2Z
ZZX0oooo0:ZZZP000000ZZZZ100000020:ZZZP030000001EEED0oooo00T0oooo2P3AcJT90?ooo`80
EEEE00H0000005EEE@000000EEEE0000003oool205EEE@040?ooo`1EEED0ZZZZ0:ZZZP8000000100
oooo0000002ZZZX000000:ZZZP000000EEEE0000002ZZZX000000?ooo`000000ZZZZ0?ooo`1EEED0
ZZZZ0`0000001`2ZZZX000000:ZZZP000000oooo0000001EEED00P2ZZZX0101EEED0oooo05EEE@1E
EED20?ooo`0505EEE@000000ZZZZ0000001EEED02P3oool:0=7=Z@T0oooo1@1EEED00`000000EEEE
0?ooo`020:ZZZP@0oooo00L0ZZZZ0000001EEED000000:ZZZP1EEED0ZZZZ00<0oooo0`0000000`2Z
ZZX0000000000002000000030?ooo`000000oooo00<0ZZZZ0P1EEED2000000@0oooo0P2ZZZX01@3o
ool0EEEE0000001EEED000000080EEEE2P3oool:0=7=ZAD0oooo00<0ZZZZ0?ooo`1EEED00P000006
0?ooo`0305EEE@3oool0EEEE00@0EEEE0P3oool01@1EEED0oooo0?ooo`3oool000000080oooo0`00
00000`3oool0ZZZZ0?ooo`0D0?ooo`X0dLfY6@3oool01`000000ZZZZ0?ooo`000000oooo0:ZZZP3o
ool00P1EEED60?ooo`80EEEE00@0oooo0:ZZZP3oool000000P3oool00`000000oooo0?ooo`0G0?oo
o``0dLfY000;0=7=Z@/0oooo00L0EEEE0:ZZZP000000EEEE0?ooo`2ZZZX0oooo0080ZZZZ00<0oooo
0000003oool00P3oool0502ZZZX000000:ZZZP000000oooo0000002ZZZX000000:ZZZP000000oooo
0:ZZZP000000oooo05EEE@2ZZZX0000005EEE@000000oooo0P2ZZZX01P000000ZZZZ0?ooo`2ZZZX0
oooo000000<0ZZZZ00@000000:ZZZP000000EEEE0P0000000`1EEED0oooo0?ooo`090?ooo`X0dLfY
2`3oool0201EEED00000000000000000EEEE0000003oool000000P2ZZZX00`000000EEEE05EEE@02
000000D0EEEE0`0000000`2ZZZX0000005EEE@06000000@0EEEE0`00000205EEE@030000001EEED0
ZZZZ00L0000000<0EEEE0?ooo`3oool02@3oool:0=7=Z@/0oooo00<0EEEE0000003oool00P3oool0
1@2ZZZX0EEEE0:ZZZP2ZZZX0oooo00@0000000@0EEEE0:ZZZP3oool00000103oool00`000000ZZZZ
0:ZZZP0205EEE@80ZZZZ00<000000?ooo`2ZZZX0103oool205EEE@@000000`2ZZZX00`000000ZZZZ
0?ooo`020?ooo`80EEEE2`3oool:0=7=ZAH0oooo00<0EEEE0?ooo`0000000P3oool00`2ZZZX0EEEE
000000020?ooo`030000001EEED0EEEE00H0EEEE00T000000?ooo`3oool000000?ooo`2ZZZX00000
0?ooo`0000000P1EEEDF0?ooo`X0dLfY6P3oool305EEE@80ZZZZ00<000000?ooo`1EEED01@2ZZZX0
103oool0EEEE0?ooo`0000020:ZZZP030?ooo`1EEED0000001X0oooo303AcJT000/0dLfY303oool0
102ZZZX000000000001EEED20:ZZZP030000003oool0ZZZZ0080ZZZZ00<0oooo05EEE@0000000`00
00020:ZZZP030?ooo`000000oooo0080ZZZZ0P0000020:ZZZP030?ooo`000000ZZZZ0080ZZZZ0P00
0000102ZZZX0000005EEE@0000020:ZZZP030000003oool000000080ZZZZ00@0EEEE000000000000
EEEE303oool:0=7=Z@`0oooo00<0ZZZZ0000001EEED00P000000103oool0EEEE0:ZZZP3oool60000
00050:ZZZP000000ZZZZ0000003oool00`000000101EEED0oooo0:ZZZP1EEED5000000030:ZZZP00
0000ZZZZ00<0000000<0ZZZZ0000000000000P2ZZZX01`1EEED000000000002ZZZX0EEEE0000001E
EED0303oool:0=7=Z@`0oooo0P1EEED01P000000EEEE0000003oool0EEEE000000L0EEEE00<00000
05EEE@1EEED00P00000205EEE@030:ZZZP1EEED0oooo00H0EEEE00D0000005EEE@1EEED000000?oo
o`0505EEE@80000000D0EEEE0?ooo`000000EEEE0000000205EEE@`0oooo2P3AcJTF0?ooo`070000
003oool0EEEE0?ooo`2ZZZX000000?ooo`040:ZZZP040?ooo`2ZZZX0oooo0:ZZZP@0oooo102ZZZX0
1@3oool000000:ZZZP3oool0EEEE008000005P3oool:0=7=ZAX0oooo00<0EEEE0000003oool00P1E
EED01P3oool0EEEE0:ZZZP3oool0EEEE0?ooo`<0EEEE00<0ZZZZ05EEE@3oool00P1EEED2000001/0
oooo303AcJT000/0dLfY303oool205EEE@@000000P3oool300000080oooo00<0EEEE0:ZZZP2ZZZX0
0P2ZZZX01@1EEED0ZZZZ0:ZZZP2ZZZX0EEEE00@0ZZZZ00D000000:ZZZP2ZZZX0000005EEE@040:ZZ
ZP0305EEE@3oool0oooo008000000`3oool20000000305EEE@000000EEEE00d0oooo2P3AcJT<0?oo
o`<0EEEE0P0000020?ooo`0=05EEE@3oool000000000001EEED0ZZZZ0?ooo`2ZZZX000000?ooo`00
0000ZZZZ000000040?ooo`040000002ZZZX0oooo00000080oooo00P0EEEE0:ZZZP000000oooo0000
001EEED0oooo0:ZZZP<000000P1EEED20?ooo`8000000P1EEED=0?ooo`X0dLfY303oool205EEE@03
0?ooo`000000oooo0080oooo00@0EEEE0?ooo`2ZZZX0oooo0P1EEED20?ooo`0705EEE@2ZZZX0oooo
0?ooo`2ZZZX0EEEE0:ZZZP0205EEE@80oooo00D0EEEE0:ZZZP2ZZZX0EEEE000000020?ooo`050:ZZ
ZP1EEED0oooo0?ooo`1EEED00P3oool20:ZZZP0705EEE@3oool0oooo0?ooo`2ZZZX0oooo05EEE@0=
0?ooo`X0dLfY603oool01@2ZZZX0oooo05EEE@3oool0000000@0EEEE00X0000005EEE@1EEED0EEEE
0:ZZZP1EEED0oooo0000001EEED000000P1EEED20?ooo`0405EEE@3oool0ZZZZ05EEEAL0oooo2P3A
cJTK0?ooo`090:ZZZP3oool0EEEE0000003oool0000005EEE@2ZZZX000000080ZZZZ00L0000005EE
E@1EEED000000?ooo`000000EEEE0080ZZZZ6`3oool<0=7=Z@002`3AcJT>0?ooo`0305EEE@2ZZZX0
oooo00<0000000H0oooo0000002ZZZX0ZZZZ0?ooo`0000050:ZZZP030?ooo`2ZZZX0oooo00H0ZZZZ
00<0oooo0:ZZZP2ZZZX01@2ZZZX01P000000oooo05EEE@2ZZZX000000:ZZZP<0000000<0oooo0000
001EEED03P3oool:0=7=Z@h0oooo00H0EEEE0?ooo`000000oooo0000001EEED20?ooo`090000001E
EED000000000001EEED0ZZZZ05EEE@2ZZZX0EEEE008000000P2ZZZX400000080ZZZZ0P000000101E
EED0ZZZZ05EEE@2ZZZX3000000070?ooo`000000oooo0?ooo`1EEED0000005EEE@020000000305EE
E@3oool0oooo00`0oooo2P3AcJT>0?ooo`80EEEE00D0000005EEE@000000EEEE0?ooo`020:ZZZPD0
oooo00<0ZZZZ05EEE@3oool00P000000202ZZZX0EEEE0:ZZZP1EEED000000:ZZZP3oool0ZZZZ0P00
00000`3oool0EEEE0?ooo`040?ooo`<0ZZZZ0P1EEED00`000000EEEE0000000205EEE@h0oooo2P3A
cJTG0?ooo`040000002ZZZX0EEEE0?ooo`80EEEE00@0ZZZZ05EEE@1EEED0ZZZZ0P1EEED0103oool0
ZZZZ0?ooo`3oool205EEE@80ZZZZ00L0EEEE0:ZZZP1EEED0EEEE0:ZZZP1EEED0ZZZZ01P0oooo2P3A
cJTK0?ooo`0305EEE@2ZZZX0oooo00@0oooo0`2ZZZX00`1EEED0ZZZZ0:ZZZP020?ooo`050000003o
ool0oooo0:ZZZP1EEED06`3oool<0=7=Z@002`3AcJT?0?ooo`0:0:ZZZP00000000000000002ZZZX0
oooo05EEE@2ZZZX0oooo000000L0EEEE0P2ZZZX00`3oool000000000000300000080ZZZZ1`1EEED0
2P000000ZZZZ0:ZZZP1EEED000000:ZZZP000000ZZZZ0000001EEED?0?ooo`X0dLfY3`3oool01P2Z
ZZX0EEEE05EEE@3oool0ZZZZ00000080ZZZZ100000001@2ZZZX0oooo0:ZZZP000000oooo00@00000
00@0oooo000000000000EEEE100000000`2ZZZX0oooo0:ZZZP03000000D0ZZZZ00@0oooo0000001E
EED0EEEE3`3oool:0=7=Z@l0oooo00<0EEEE0?ooo`0000000P3oool0101EEED00000000000000005
05EEE@80oooo00D000000?ooo`000000EEEE0?ooo`02000000030?ooo`1EEED0000000@0oooo00<0
000005EEE@0000000`1EEED20000000605EEE@3oool0oooo0:ZZZP3oool0EEEE3`3oool:0=7=ZAP0
oooo0P1EEED20000000@0?ooo`000000ZZZZ0:ZZZP000000oooo0000003oool0000005EEE@3oool0
00000?ooo`000000EEEE0:ZZZP<000000`1EEEDH0?ooo`X0dLfY703oool01`000000oooo0?ooo`1E
EED0ZZZZ0?ooo`1EEED00P0000001@1EEED0000005EEE@3oool0ZZZZ00<0oooo00<0ZZZZ0?ooo`3o
ool06P3oool<0=7=Z@002`3AcJT?0?ooo`80EEEE00<0ZZZZ0000000000000P2ZZZX00`3oool0ZZZZ
0:ZZZP020:ZZZP030?ooo`2ZZZX0oooo0080ZZZZ00<0oooo0000002ZZZX0102ZZZX200000080oooo
00<0ZZZZ0?ooo`3oool00P3oool20:ZZZP030000003oool0ZZZZ00@0000000<0EEEE0?ooo`3oool0
3P3oool:0=7=Z@l0oooo0P1EEED00`2ZZZX000000:ZZZP020000000305EEE@000000oooo0080oooo
00L000000:ZZZP000000oooo0000001EEED0ZZZZ008000000P3oool2000000060:ZZZP1EEED0oooo
0?ooo`000000ZZZZ0P0000020?ooo`050000001EEED000000?ooo`2ZZZX00P0000000`1EEED0oooo
0?ooo`0>0?ooo`X0dLfY3`3oool205EEE@<0oooo00<0ZZZZ0000001EEED00P2ZZZX20?ooo`040:ZZ
ZP1EEED0EEEE00000080EEEE00@000000?ooo`3oool000000P3oool02P2ZZZX0000005EEE@1EEED0
000005EEE@3oool0ZZZZ0000003oool20:ZZZP0305EEE@000000oooo0080oooo00<0000005EEE@3o
ool03`3oool:0=7=ZAT0oooo00<0ZZZZ0?ooo`1EEED00P3oool205EEE@80oooo00@0EEEE0?ooo`3o
ool0ZZZZ103oool205EEE@80oooo00<0EEEE0?ooo`2ZZZX06@3oool:0=7=ZAX0oooo0P0000040:ZZ
ZP030000003oool0ZZZZ0080oooo00D0ZZZZ0?ooo`3oool0oooo000000030:ZZZP030?ooo`000000
oooo01X0oooo303AcJT000/0dLfY4@3oool010000000ZZZZ0000000000020:ZZZP80oooo00D0ZZZZ
0?ooo`000000ZZZZ0?ooo`020:ZZZP030000001EEED0000000@0ZZZZ0P1EEED010000000oooo0:ZZ
ZP3oool200000080ZZZZ00@0oooo0:ZZZP2ZZZX0ZZZZ0P0000000`2ZZZX0EEEE0?ooo`0@0?ooo`X0
dLfY4@3oool3000000<0EEEE0P3oool00`000000EEEE0?ooo`0200000080ZZZZ00D0oooo0:ZZZP00
0000ZZZZ000000020:ZZZP0605EEE@2ZZZX0oooo0?ooo`2ZZZX000000P3oool00`1EEED000000?oo
o`0305EEE@040:ZZZP000000000005EEEA40oooo2P3AcJTA0?ooo`0305EEE@3oool0ZZZZ00<0oooo
00<0EEEE0:ZZZP3oool00P3oool00`000000EEEE05EEE@02000000030:ZZZP3oool0000000<00000
0P2ZZZX02@000000EEEE05EEE@1EEED000000?ooo`2ZZZX0oooo0:ZZZP030?ooo`040000002ZZZX0
oooo05EEEA40oooo2P3AcJTJ0?ooo`0305EEE@3oool0ZZZZ0080ZZZZ103oool010000000EEEE0:ZZ
ZP0000030?ooo`030000002ZZZX0ZZZZ0080oooo00<0EEEE0?ooo`3oool0603oool:0=7=ZA/0oooo
00H000000:ZZZP2ZZZX0oooo0:ZZZP1EEED20000000<0:ZZZP1EEED0ZZZZ0:ZZZP1EEED0000005EE
E@2ZZZX0oooo0:ZZZP1EEED000006`3oool<0=7=Z@002`3AcJTA0?ooo`0<05EEE@2ZZZX000000:ZZ
ZP000000EEEE0:ZZZP000000ZZZZ0000001EEED000000P2ZZZX205EEE@030000001EEED0EEEE00<0
EEEE0P00000205EEE@80ZZZZ0P1EEED01@3oool0ZZZZ0000002ZZZX0EEEE00<0000000<0ZZZZ0?oo
o`3oool0403oool:0=7=ZA40oooo00@0EEEE0:ZZZP00000000000`1EEED0103oool000000:ZZZP00
00030:ZZZP0505EEE@3oool000000000001EEED00P0000001@1EEED0ZZZZ0000003oool0EEEE00<0
ZZZZ0`0000000`3oool0000005EEE@0205EEE@030000002ZZZX0oooo0140oooo2P3AcJTA0?ooo`80
EEEE00<000000?ooo`3oool00P3oool00`1EEED000000000000305EEE@040?ooo`2ZZZX0EEEE0000
00D0EEEE0P0000000`1EEED0oooo0?ooo`0405EEE@030000001EEED0oooo00<0oooo00<0000005EE
E@3oool04@3oool:0=7=ZAX0oooo00<000000?ooo`0000000P1EEED50?ooo`80EEEE1@3oool305EE
E@030?ooo`000000oooo01T0oooo2P3AcJTL0?ooo`060000001EEED0EEEE0000001EEED0oooo0`2Z
ZZX0101EEED0ZZZZ0?ooo`3oool505EEEA`0oooo303AcJT000/0dLfY4P3oool305EEE@030:ZZZP3o
ool000000080EEEE00H0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP3oool30:ZZZP80oooo00<0ZZZZ0?ooo`2Z
ZZX0102ZZZX00`1EEED0oooo0?ooo`0305EEE@040:ZZZP3oool0ZZZZ00000080EEEE4P3oool:0=7=
ZA80oooo0P1EEED010000000ZZZZ0000000000030:ZZZP0605EEE@000000EEEE0000002ZZZX00000
0P2ZZZX40000000305EEE@2ZZZX000000080000000<0EEEE0000001EEED00`2ZZZX2000000040:ZZ
ZP1EEED0EEEE05EEEA80oooo2P3AcJTB0?ooo`80EEEE00<0000005EEE@1EEED00P1EEED0103oool0
ZZZZ0:ZZZP3oool305EEE@80oooo1P0000020?ooo`040000001EEED0EEEE0?ooo`80ZZZZ00<0oooo
05EEE@0000001@1EEEDB0?ooo`X0dLfY6P3oool01P1EEED0oooo0?ooo`2ZZZX0oooo000000@0oooo
0P0000060?ooo`80ZZZZ703oool:0=7=ZA`0oooo0P2ZZZX01@000000ZZZZ0?ooo`3oool000000080
ZZZZ00<000000:ZZZP0000000P3oool00`2ZZZX000000:ZZZP0M0?ooo``0dLfY000;0=7=ZA@0oooo
00<000000:ZZZP3oool00`2ZZZX00`3oool0EEEE05EEE@02000000070?ooo`2ZZZX0oooo0?ooo`2Z
ZZX000000?ooo`020:ZZZP030?ooo`2ZZZX0ZZZZ008000000P1EEED30:ZZZP80oooo00<0ZZZZ05EE
E@3oool04`3oool:0=7=ZA@0oooo00H000000?ooo`00000000000:ZZZP3oool4000000030?ooo`2Z
ZZX000000080000000D0oooo000000000000oooo05EEE@02000000030:ZZZP3oool0000000800000
00L0EEEE0?ooo`2ZZZX0ZZZZ0000003oool0EEEE01@0oooo2P3AcJTD0?ooo`0305EEE@000000oooo
0080oooo00@0ZZZZ05EEE@2ZZZX0ZZZZ0`3oool010000000EEEE0000000000020?ooo`040000002Z
ZZX0EEEE000000<0oooo0P2ZZZX00`000000ZZZZ0?ooo`020?ooo`030000001EEED0oooo01<0oooo
2P3AcJTK0?ooo`040000001EEED0ZZZZ000000@0oooo00@0EEEE0?ooo`000000EEEE0`3oool20000
0080ZZZZ00<000000?ooo`3oool06@3oool:0=7=ZAd0oooo0P1EEED40?ooo`040:ZZZP1EEED0EEEE
0:ZZZP<0oooo0`1EEEDM0?ooo``0dLfY000;0=7=ZA@0oooo0100EEEE0:ZZZP000000ZZZZ05EEE@2Z
ZZX0EEEE0?ooo`2ZZZX0oooo05EEE@000000ZZZZ05EEE@3oool000000P2ZZZX00`000000EEEE05EE
E@020:ZZZP0:05EEE@3oool0oooo0?ooo`000000ZZZZ05EEE@2ZZZX000000:ZZZQD0oooo2P3AcJTD
0?ooo`0305EEE@2ZZZX0EEEE0080000000D0EEEE0?ooo`00000000000?ooo`04000000030:ZZZP1E
EED0EEEE0080EEEE0`0000001`1EEED000000?ooo`3oool000000?ooo`1EEED00P0000000`1EEED0
ZZZZ0?ooo`0D0?ooo`X0dLfY503oool505EEE@040000003oool0EEEE000000D0EEEE00<000000?oo
o`3oool00`3oool205EEE@090000001EEED0EEEE0000001EEED0oooo0000001EEED000000080EEEE
5@3oool:0=7=ZA`0oooo0P1EEED00`3oool0EEEE000000030?ooo`80ZZZZ0`3oool00`000000oooo
0?ooo`0205EEEA`0oooo2P3AcJTN0?ooo`030:ZZZP3oool0000000<0000000@0EEEE000000000000
oooo0P0000000`3oool0ZZZZ0?ooo`0M0?ooo``0dLfY000;0=7=ZAD0oooo0P1EEED01P2ZZZX0oooo
0:ZZZP000000EEEE00000080ZZZZ00<000000?ooo`2ZZZX00P3oool200000080oooo00<0ZZZZ0?oo
o`3oool00P2ZZZX01P3oool0EEEE0000002ZZZX0oooo00000080EEEE5@3oool:0=7=ZAD0oooo0P1E
EED01`2ZZZX0EEEE0000003oool0000005EEE@2ZZZX00P1EEED00`2ZZZX000000:ZZZP020:ZZZP0>
0?ooo`2ZZZX0EEEE0000002ZZZX0000005EEE@2ZZZX0oooo0000001EEED0000005EEE@00000205EE
EAD0oooo2P3AcJTE0?ooo`80EEEE00<0ZZZZ0000003oool00P3oool01@2ZZZX0oooo0:ZZZP2ZZZX0
oooo0080000000L0EEEE0000001EEED0EEEE0:ZZZP000000oooo0080ZZZZ00<0oooo05EEE@3oool0
0P3oool010000000oooo05EEE@1EEEDE0?ooo`X0dLfY6P3oool00`000000oooo0:ZZZP030?ooo`80
ZZZZ00<000000:ZZZP1EEED01@2ZZZXP0?ooo`X0dLfY7@3oool200000080oooo00T0EEEE0:ZZZP2Z
ZZX0ZZZZ0?ooo`2ZZZX0oooo05EEE@3oool00`00000M0?ooo``0dLfY000;0=7=ZAL0oooo00D00000
0:ZZZP00000000000?ooo`0200000080ZZZZ00<0oooo0:ZZZP1EEED0101EEED00`000000ZZZZ0?oo
o`020:ZZZP070000002ZZZX0oooo05EEE@000000ZZZZ05EEE@0G0?ooo`X0dLfY5`3oool400000003
05EEE@000000000000<0000000X0oooo0000001EEED0ZZZZ0?ooo`1EEED000000?ooo`000000ZZZZ
0`0000001@1EEED00000000000000000EEEE01L0oooo2P3AcJTG0?ooo`80EEEE00D0000005EEE@00
0000EEEE0?ooo`030:ZZZP0405EEE@2ZZZX0000005EEE@80000000<0ZZZZ05EEE@2ZZZX00P2ZZZX0
1@3oool0EEEE0000001EEED000000080EEEE5`3oool:0=7=ZA`0oooo00@0ZZZZ0000000000000000
0P2ZZZX010000000oooo0:ZZZP2ZZZX20?ooo`80ZZZZ0`0000000`2ZZZX0oooo0?ooo`0J0?ooo`X0
dLfY7`3oool00`1EEED0oooo0?ooo`0205EEE@040?ooo`000000EEEE00000080oooo00<0ZZZZ0?oo
o`3oool07@3oool<0=7=Z@002`3AcJTG0?ooo`0305EEE@2ZZZX000000080EEEE1@2ZZZX010000000
oooo0:ZZZP3oool20:ZZZP040?ooo`000000ZZZZ05EEE@<0ZZZZ00@0EEEE000000000000ZZZZ603o
ool:0=7=ZAL0oooo00@0EEEE0:ZZZP000000ZZZZ100000002`1EEED0ZZZZ0000001EEED000000?oo
o`1EEED000000:ZZZP000000ZZZZ00D0000000<0EEEE0000002ZZZX0603oool:0=7=ZAL0oooo0P1E
EED00`3oool000000?ooo`0205EEE@080000001EEED000000000001EEED0000005EEE@2ZZZX60000
000605EEE@3oool0oooo0:ZZZP3oool0EEEE603oool:0=7=ZA`0oooo00X0ZZZZ0?ooo`2ZZZX0oooo
0:ZZZP000000EEEE0?ooo`2ZZZX000000P3oool01P000000ZZZZ0:ZZZP2ZZZX0oooo000001`0oooo
2P3AcJTO0?ooo`<0ZZZZ0P3oool20:ZZZP050?ooo`2ZZZX0ZZZZ0:ZZZP0000007`3oool<0=7=Z@00
2`3AcJTH0?ooo`<0EEEE0`0000020?ooo`030000002ZZZX0ZZZZ0080ZZZZ00L0EEEE0:ZZZP000000
ZZZZ0000002ZZZX0oooo00@000000P1EEEDH0?ooo`X0dLfY603oool205EEE@80000000L0oooo0000
0000000000000:ZZZP3oool0EEEE0080000000D0ZZZZ0000001EEED0oooo0:ZZZP05000000<0EEEE
603oool:0=7=ZAP0oooo0P1EEED30?ooo`030:ZZZP000000ZZZZ00<0ZZZZ00@0EEEE000000000000
EEEE0`2ZZZX00`1EEED000000:ZZZP020?ooo`030000001EEED0EEEE01P0oooo2P3AcJTL0?ooo`80
EEEE00D0ZZZZ05EEE@3oool0EEEE0:ZZZP020?ooo`0505EEE@3oool0oooo05EEE@3oool00P2ZZZX0
0`1EEED0oooo0?ooo`0K0?ooo`X0dLfY7`3oool205EEE@040000001EEED0EEEE000000<0EEEE00<0
000005EEE@3oool07`3oool<0=7=Z@002`3AcJTJ0?ooo`030000002ZZZX00000008000000P3oool0
0`2ZZZX0oooo0:ZZZP030:ZZZP040000002ZZZX0oooo0?ooo`80000000<0oooo0:ZZZP1EEED06P3o
ool:0=7=ZAX0oooo00H000000?ooo`1EEED0oooo0000003oool2000000030:ZZZP000000EEEE0080
000000<0ZZZZ0000000000000P000000103oool000000?ooo`1EEEDJ0?ooo`X0dLfY6P3oool00`1E
EED0oooo000000030?ooo`0405EEE@2ZZZX0oooo00000080oooo00@000000?ooo`2ZZZX0EEEE0`3o
ool00`2ZZZX0oooo05EEE@0J0?ooo`X0dLfY7@3oool00`000000ZZZZ0?ooo`0300000080ZZZZ00<0
oooo0:ZZZP0000000P0000020:ZZZP030000003oool0oooo01/0oooo2P3AcJTO0?ooo`050000003o
ool0ZZZZ0:ZZZP3oool00P1EEED00`3oool0EEEE0:ZZZP0Q0?ooo``0dLfY000;0=7=ZAX0oooo00<0
EEEE0:ZZZP2ZZZX00P000000102ZZZX000000:ZZZP3oool40000000405EEE@2ZZZX000000:ZZZP<0
000000<0ZZZZ0?ooo`3oool06@3oool:0=7=ZAX0oooo00D0EEEE0:ZZZP000000EEEE0?ooo`0305EE
E@040?ooo`1EEED0oooo0:ZZZP@0EEEE00D0ZZZZ0?ooo`1EEED0EEEE0:ZZZP0K0?ooo`X0dLfY6P3o
ool205EEE@D0oooo0`1EEED01@000000EEEE05EEE@000000EEEE00@0oooo00<0000005EEE@3oool0
6P3oool:0=7=ZAh0oooo00<0EEEE0?ooo`2ZZZX00`2ZZZX0103oool0EEEE0:ZZZP3oool20:ZZZP80
EEEE7P3oool:0=7=ZB00oooo00D0EEEE0:ZZZP000000oooo0:ZZZP020?ooo`80ZZZZ00<0EEEE0?oo
o`3oool07P3oool<0=7=Z@002`3AcJTK0?ooo`0:05EEE@000000ZZZZ0000003oool000000?ooo`2Z
ZZX000000:ZZZP80000000<0ZZZZ0?ooo`0000000P0000000`2ZZZX0EEEE05EEE@0K0?ooo`X0dLfY
6`3oool01@1EEED000000:ZZZP000000oooo0080ZZZZ0P3oool010000000ZZZZ0?ooo`3oool30:ZZ
ZP040000002ZZZX0EEEE05EEEA/0oooo2P3AcJTK0?ooo`80EEEE00<0000005EEE@0000000P1EEED2
0:ZZZP040000003oool0ZZZZ0?ooo`@0EEEE00<0000005EEE@1EEED06`3oool:0=7=ZAh0oooo00H0
00000?ooo`1EEED0EEEE0000002ZZZX20?ooo`040:ZZZP3oool0EEEE05EEE@8000007P3oool:0=7=
ZB00oooo00@0000005EEE@3oool0oooo0P000000103oool0EEEE05EEE@00000P0?ooo``0dLfY000;
0=7=ZA`0oooo00<0EEEE0000002ZZZX00P0000000`3oool0EEEE05EEE@020?ooo`0305EEE@2ZZZX0
oooo0080000000<0ZZZZ0000003oool0703oool:0=7=ZA`0oooo00@0EEEE000000000000ZZZZ0P1E
EED01P2ZZZX000000?ooo`3oool000000?ooo`80EEEE0`00000M0?ooo`X0dLfY703oool205EEE@04
0000003oool0oooo0?ooo`80ZZZZ00@0EEEE0:ZZZP2ZZZX0ZZZZ0`3oool00`000000EEEE0?ooo`0L
0?ooo`X0dLfY7`3oool02`2ZZZX0EEEE0:ZZZP1EEED0000005EEE@2ZZZX000000?ooo`2ZZZX0EEEE
0200oooo2P3AcJTR0?ooo`060:ZZZP3oool0ZZZZ05EEE@3oool0ZZZZ8P3oool<0=7=Z@002`3AcJTM
0?ooo`0805EEE@2ZZZX000000:ZZZP000000oooo0:ZZZP0000030:ZZZP050000002ZZZX000000:ZZ
ZP1EEED07@3oool:0=7=ZAd0oooo00D0EEEE0:ZZZP1EEED0000005EEE@020:ZZZP030000002ZZZX0
ZZZZ0080EEEE0P0000000`2ZZZX0EEEE0?ooo`0L0?ooo`X0dLfY7@3oool205EEE@050000001EEED0
EEEE0000001EEED00P0000000`1EEED0000005EEE@0405EEEAd0oooo2P3AcJTO0?ooo`030000002Z
ZZX0EEEE0080oooo0P1EEED0103oool0ZZZZ05EEE@2ZZZXP0?ooo`X0dLfY8@3oool020000000ZZZZ
0000003oool0EEEE0000003oool000008@3oool<0=7=Z@002`3AcJTP0?ooo`80ZZZZ00<0EEEE0000
000000000P000000101EEED0ZZZZ0:ZZZP1EEEDO0?ooo`X0dLfY8@3oool010000000EEEE0?ooo`00
00020?ooo`040:ZZZP000000oooo05EEEAl0oooo2P3AcJTO0?ooo`0505EEE@000000oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`000000EEEE01l0oooo2P3AcJTQ0?ooo`080:ZZZP3oool0EEEE
05EEE@2ZZZX0EEEE0?ooo`2ZZZXQ0?ooo`X0dLfY8P3oool01@2ZZZX000000?ooo`3oool0000002<0
oooo303AcJT000/0dLfY7`3oool00`1EEED000000:ZZZP050:ZZZP030?ooo`2ZZZX000000200oooo
2P3AcJTO0?ooo`0505EEE@000000oooo0:ZZZP0000000P2ZZZX2000000030?ooo`000000oooo01l0
oooo2P3AcJTO0?ooo`D0EEEE00@0000005EEE@1EEED000000P1EEEDP0?ooo`X0dLfY8@3oool00`00
0000ZZZZ0000000205EEE@030000002ZZZX000000240oooo2P3AcJTQ0?ooo`030000003oool0ZZZZ
00<0ZZZZ0P00000Q0?ooo``0dLfY000;0=7=ZB00oooo00@0EEEE0:ZZZP2ZZZX0oooo0P000000103o
ool000000:ZZZP1EEEDP0?ooo`X0dLfY803oool01@1EEED0ZZZZ000000000000EEEE0080000000<0
EEEE0:ZZZP1EEED0803oool:0=7=ZB00oooo0P1EEED20:ZZZP040000003oool0ZZZZ0?ooo`80EEEE
803oool:0=7=ZB80oooo00<0EEEE0?ooo`2ZZZX00P3oool00`1EEED0oooo0?ooo`0P0?ooo`X0dLfY
8`3oool01@2ZZZX000000000002ZZZX0EEEE0280oooo303AcJT000/0dLfY8`3oool01@2ZZZX0oooo
0000002ZZZX0EEEE0280oooo2P3AcJTS0?ooo`050:ZZZP00000000000:ZZZP1EEED08P3oool:0=7=
ZB80oooo0P1EEED0103oool0EEEE05EEE@1EEEDR0?ooo`X0dLfY8P3oool0101EEED0oooo0?ooo`2Z
ZZXT0?ooo`X0dLfY8P3oool01@1EEED0000005EEE@1EEED0000002<0oooo303AcJT000/0dLfY8P3o
ool01@1EEED000000000002ZZZX0000002<0oooo2P3AcJTR0?ooo`0305EEE@000000oooo00800000
8`3oool:0=7=ZB80oooo0P1EEED20?ooo`0305EEE@3oool0oooo0240oooo2P3AcJTS0?ooo`80ZZZZ
00<0EEEE0:ZZZP3oool08P3oool:0=7=ZB<0oooo00@0ZZZZ0000002ZZZX0ZZZZ8`3oool<0=7=Z@00
2`3AcJTS0?ooo`0405EEE@2ZZZX0ZZZZ05EEEB<0oooo2P3AcJTS0?ooo`0405EEE@000000ZZZZ05EE
EB<0oooo2P3AcJTS0?ooo`0405EEE@000000EEEE05EEEB<0oooo2P3AcJTS0?ooo`040000001EEED0
ZZZZ000002<0oooo2P3AcJTS0?ooo`040000003oool0ZZZZ000002<0oooo303AcJT000/0dLfY903o
ool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903o
ool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903o
ool00`2ZZZX0oooo0?ooo`0S0?ooo``0dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80
dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY000;0=7=Z@030?ooo`1EEED000000080EEEE0`000002
0:ZZZP030000003oool000000080000000<0ZZZZ0?ooo`1EEED00P0000001@1EEED000000000003o
ool0EEEE0080000000D0oooo000000000000EEEE0?ooo`0205EEE@030000002ZZZX0ZZZZ0080ZZZZ
0`1EEED00`3oool0EEEE000000020?ooo`80000000D0EEEE0?ooo`00000000000:ZZZP0200000003
05EEE@3oool0000000<0000000H0oooo0000003oool0ZZZZ0000002ZZZX20000000405EEE@000000
EEEE0?ooo`X0dLfY00@0oooo05EEE@1EEED0oooo0P000000103oool0000005EEE@1EEED200000003
0?ooo`00000000000080EEEE0`3oool0102ZZZX0000000000000000405EEE@030:ZZZP000000oooo
00<0EEEE1@00000405EEE@030?ooo`000000EEEE00@0EEEE00<0oooo000000000000103oool01@1E
EED0oooo000000000000ZZZZ008000000P1EEED300000080oooo0P1EEED00`3oool0dLfY0=7=Z@08
0=7=Z@040?ooo`1EEED0EEEE05EEE@80oooo00<0ZZZZ0?ooo`2ZZZX0101EEED00`000000ZZZZ05EE
E@020?ooo`0:05EEE@2ZZZX0000005EEE@2ZZZX000000?ooo`000000EEEE00000080ZZZZ00D0EEEE
000000000000oooo05EEE@040?ooo`030:ZZZP3oool000000080EEEE0P2ZZZX3000000070?ooo`00
0000ZZZZ05EEE@000000ZZZZ05EEE@020?ooo`80ZZZZ00@0000005EEE@1EEED0EEEE0P2ZZZX0103o
ool0EEEE0?ooo`3oool305EEE@030?ooo`3AcJT0dLfY00P0dLfY00L0oooo05EEE@1EEED0EEEE0:ZZ
ZP3oool0ZZZZ00<0EEEE0P3oool305EEE@80ZZZZ0P1EEED40:ZZZP@0oooo0P2ZZZX30?ooo`030:ZZ
ZP1EEED0ZZZZ00D0ZZZZ00<0EEEE0:ZZZP2ZZZX00P3oool20:ZZZP@0oooo0P2ZZZX0103oool0ZZZZ
05EEE@1EEED20:ZZZP<0EEEE0P3oool305EEE@80oooo101EEED00`3oool0dLfY0=7=Z@080=7=Z@07
0?ooo`1EEED0EEEE05EEE@2ZZZX0oooo05EEE@0600000080ZZZZ0P3oool00`1EEED0000000000002
0?ooo`030:ZZZP00000000000080ZZZZ00D0EEEE0:ZZZP1EEED0EEEE0:ZZZP020000000605EEE@00
0000000005EEE@000000ZZZZ0P0000000`2ZZZX0EEEE05EEE@0205EEE@80ZZZZ0P0000000`2ZZZX0
oooo05EEE@020000000305EEE@3oool0oooo00<0ZZZZ1@0000000`1EEED0oooo0:ZZZP0305EEE@03
0?ooo`3AcJT0dLfY00X0dLfY000;0=7=Z@030?ooo`1EEED0oooo0080EEEE00<0oooo0:ZZZP000000
0P3oool2000000060?ooo`00000000000?ooo`1EEED000000P1EEED00`2ZZZX0oooo000000020000
0080EEEE00<0000005EEE@1EEED00`000000101EEED000000?ooo`0000020?ooo`030000001EEED0
00000080000000<0EEEE0?ooo`0000000P1EEED300000080oooo0P1EEED00`000000EEEE0:ZZZP05
00000080oooo00D0000005EEE@3oool0oooo05EEE@030?ooo`X0dLfY00D0oooo05EEE@3oool0ZZZZ
0?ooo`02000000030:ZZZP1EEED0oooo008000000`1EEED20?ooo`0405EEE@3oool0EEEE0?ooo`80
000000<0ZZZZ05EEE@3oool00P3oool305EEE@030?ooo`1EEED0oooo00D000000P3oool02@1EEED0
oooo05EEE@1EEED0ZZZZ0?ooo`2ZZZX0oooo05EEE@0300000080EEEE00<0oooo05EEE@3oool00`1E
EED01P3oool000000000003oool0EEEE0:ZZZP<0000000@0ZZZZ0?ooo`3oool0oooo2P3AcJT00`3o
ool0EEEE0:ZZZP030?ooo`030000002ZZZX0EEEE00<0ZZZZ00<0EEEE0?ooo`000000103oool40:ZZ
ZP0305EEE@2ZZZX000000080ZZZZ00@000000:ZZZP3oool0ZZZZ0P1EEED50?ooo`@0EEEE00<0oooo
0:ZZZP0000000P2ZZZX00`000000ZZZZ05EEE@020:ZZZP030000002ZZZX0oooo0080oooo00@0ZZZZ
0000003oool0oooo0`2ZZZX00`1EEED0ZZZZ0?ooo`030?ooo`030:ZZZP3oool0oooo00X0dLfY00@0
oooo05EEE@2ZZZX0oooo0`1EEED00`2ZZZX0oooo0?ooo`020?ooo`070:ZZZP3oool0ZZZZ05EEE@00
0000oooo0:ZZZP0205EEE@030000001EEED0EEEE00L0EEEE00<000000:ZZZP2ZZZX00`0000000`1E
EED000000:ZZZP020:ZZZP<0EEEE00<0000005EEE@1EEED0101EEED020000000EEEE05EEE@2ZZZX0
oooo0000001EEED0ZZZZ103oool00`2ZZZX0oooo0:ZZZP0205EEE@030:ZZZP3oool0ZZZZ0080oooo
2P3AcJT02P3oool0EEEE0?ooo`000000ZZZZ0000001EEED0000005EEE@00000205EEE@040:ZZZP00
0000EEEE0:ZZZP<0EEEE00D000000?ooo`1EEED0EEEE0000000505EEE@80000000<0ZZZZ00000000
00000P1EEED20000000505EEE@2ZZZX000000000001EEED00P0000000`2ZZZX0EEEE05EEE@0605EE
E@060000001EEED0ZZZZ05EEE@2ZZZX0EEEE0P00000405EEE@050000003oool0000005EEE@000000
0`3oool<0=7=Z@002`3AcJT30?ooo`0405EEE@000000EEEE0?ooo`@0EEEE0`0000020?ooo`0:05EE
E@3oool000000?ooo`000000oooo0:ZZZP3oool000000?ooo`8000000P1EEED010000000EEEE0000
0000000205EEE@80oooo00<0EEEE0:ZZZP0000000`0000001P1EEED000000000001EEED0oooo0000
0080ZZZZ00@0oooo05EEE@3oool000000P1EEED20?ooo`050000003oool0000005EEE@3oool00P1E
EED010000000EEEE05EEE@1EEED30?ooo`X0dLfY0`3oool01@1EEED00000000000000000oooo0080
ZZZZ00@0oooo0:ZZZP1EEED0EEEE103oool01@1EEED000000:ZZZP3oool0EEEE0080ZZZZ00<00000
0?ooo`3oool00P1EEED01@3oool0ZZZZ0?ooo`000000ZZZZ00@0000000D0EEEE0000003oool0EEEE
0?ooo`0205EEE@060?ooo`00000000000:ZZZP3oool0EEEE0P3oool00`000000EEEE0?ooo`030?oo
o`0705EEE@3oool0ZZZZ0?ooo`1EEED0ZZZZ0?ooo`02000000030?ooo`1EEED0oooo0080oooo2P3A
cJT30?ooo`0505EEE@3oool0oooo05EEE@3oool00P1EEED20:ZZZP0305EEE@000000ZZZZ00<0ZZZZ
00<0oooo0:ZZZP0000000P0000000`2ZZZX000000000000205EEE@050:ZZZP1EEED0EEEE0:ZZZP00
0000203oool01@000000EEEE05EEE@1EEED0ZZZZ0080EEEE0P0000001P1EEED000000000001EEED0
ZZZZ0?ooo`@0ZZZZ0P0000020:ZZZP80EEEE00D0oooo0:ZZZP3oool0ZZZZ05EEE@030?ooo`X0dLfY
0`3oool00`1EEED0000000000002000000050:ZZZP3oool0ZZZZ05EEE@3oool00P1EEED01@000000
ZZZZ0?ooo`000000EEEE00<0ZZZZ0`1EEED02P000000ZZZZ0:ZZZP000000EEEE0000002ZZZX0oooo
0000001EEED20?ooo`0405EEE@3oool0oooo0:ZZZP80EEEE00<000000:ZZZP2ZZZX00`1EEED01P00
0000ZZZZ0:ZZZP000000EEEE00000080ZZZZ00/0000005EEE@1EEED0oooo05EEE@2ZZZX0oooo0:ZZ
ZP000000EEEE0000000205EEE@<0oooo2P3AcJT30?ooo`0705EEE@2ZZZX0EEEE0:ZZZP1EEED00000
05EEE@020:ZZZP<000001@1EEED00`2ZZZX0EEEE0:ZZZP0205EEE@<00000101EEED200000080EEEE
00@0000005EEE@1EEED0EEEE0P00000405EEE@<0000000D0EEEE0000002ZZZX0EEEE0:ZZZP0205EE
E@030:ZZZP1EEED0EEEE0080000000<0EEEE0:ZZZP2ZZZX00P0000001@1EEED0ZZZZ05EEE@3oool0
EEEE00<0oooo303AcJT000/0dLfY1@3oool205EEE@8000000P3oool00`1EEED0ZZZZ000000040000
00030?ooo`000000000000<0ZZZZ0P00000205EEE@80000000D0EEEE000000000000ZZZZ05EEE@05
0?ooo`050:ZZZP000000EEEE05EEE@0000000P1EEED3000000<0ZZZZ00@0EEEE0000003oool0EEEE
1000000205EEE@050?ooo`1EEED000000000003oool00P1EEED40?ooo`X0dLfY103oool405EEE@80
oooo0P1EEED00`2ZZZX0oooo0?ooo`040?ooo`030000002ZZZX0ZZZZ0080EEEE00H000000?ooo`00
0000ZZZZ0?ooo`1EEED20?ooo`030000002ZZZX0oooo00@0000000h0EEEE0:ZZZP000000EEEE0?oo
o`1EEED0oooo0:ZZZP000000oooo0000003oool0EEEE0:ZZZP8000001P3oool01@2ZZZX0EEEE05EE
E@000000oooo00@0EEEE103oool:0=7=Z@@0oooo0P1EEED30?ooo`030:ZZZP3oool000000080ZZZZ
1@0000000`3oool0ZZZZ000000020:ZZZP80EEEE0P3oool010000000oooo0?ooo`2ZZZX:05EEE@06
0:ZZZP3oool0oooo0:ZZZP3oool0ZZZZ0P1EEED20:ZZZP050000002ZZZX0oooo0000002ZZZX00`00
00020:ZZZP030000003oool0EEEE0080oooo0`1EEED40?ooo`X0dLfY103oool20:ZZZP050?ooo`1E
EED0EEEE0000001EEED00`3oool02P1EEED0ZZZZ05EEE@000000ZZZZ0?ooo`000000ZZZZ0000003o
ool30:ZZZP80000000<0ZZZZ0?ooo`2ZZZX00`1EEED40?ooo`<0EEEE00H0ZZZZ0?ooo`2ZZZX0ZZZZ
0000003oool30:ZZZP050000002ZZZX0ZZZZ0?ooo`2ZZZX00P1EEED00`2ZZZX0EEEE0?ooo`020?oo
o`0305EEE@2ZZZX0EEEE0080EEEE00<0ZZZZ05EEE@3oool00`3oool:0=7=Z@@0oooo0P1EEED01@00
0000EEEE0000001EEED0ZZZZ008000000P1EEED01`000000EEEE0:ZZZP2ZZZX0000005EEE@000000
0P3oool00`1EEED0000005EEE@030000000605EEE@000000EEEE05EEE@000000EEEE0P0000005@1E
EED0000005EEE@1EEED0000005EEE@000000EEEE0000001EEED0000005EEE@000000oooo0000002Z
ZZX000000:ZZZP000000EEEE0000000305EEE@060000002ZZZX0EEEE0000001EEED0ZZZZ0P1EEED4
0?ooo``0dLfY000;0=7=Z@D0oooo00<0EEEE0000001EEED0100000000`1EEED0oooo0:ZZZP020000
00060?ooo`2ZZZX0ZZZZ0:ZZZP000000EEEE0`0000030?ooo`80EEEE00<000000?ooo`3oool00P1E
EED00`3oool0EEEE05EEE@030?ooo`040000001EEED0EEEE00000080oooo0P0000000`3oool0EEEE
000000040:ZZZP80000000<0ZZZZ0?ooo`0000001000000305EEE@D0oooo2P3AcJT50?ooo`0705EE
E@2ZZZX0EEEE0:ZZZP3oool0ZZZZ000000040?ooo`0805EEE@3oool0oooo0:ZZZP1EEED0oooo0000
002ZZZX405EEE@060?ooo`1EEED0EEEE05EEE@3oool0ZZZZ1@0000020:ZZZP80oooo0P1EEED00`3o
ool0EEEE05EEE@0205EEE@050?ooo`000000oooo0?ooo`2ZZZX00P3oool205EEE@80oooo0P000000
0`2ZZZX0oooo0:ZZZP0305EEE@D0oooo2P3AcJT50?ooo`D0EEEE0P2ZZZX20?ooo`030000002ZZZX0
EEEE0080EEEE00@0ZZZZ0?ooo`000000ZZZZ0P0000030?ooo`@0EEEE00<0ZZZZ0000002ZZZX00P00
0000103oool000000000000000020:ZZZP80EEEE00D0ZZZZ0?ooo`000000oooo000000020:ZZZP08
0000002ZZZX0ZZZZ05EEE@3oool0EEEE0?ooo`0000020?ooo`80ZZZZ1@1EEED50?ooo`X0dLfY1@3o
ool405EEE@H0oooo00D0ZZZZ0000002ZZZX0oooo0:ZZZP02000000040?ooo`2ZZZX0000000000080
oooo0P0000030:ZZZP030000001EEED0EEEE00@0EEEE00@000000:ZZZP3oool0ZZZZ0P000000103o
ool0ZZZZ0000000000020?ooo`80000000@0ZZZZ0?ooo`1EEED000001P3oool00`2ZZZX0EEEE05EE
E@0205EEE@D0oooo2P3AcJT50?ooo`0305EEE@000000EEEE0080EEEE0P0000020:ZZZP<0000000<0
EEEE0?ooo`0000000`1EEED20:ZZZP040000001EEED0EEEE05EEE@<0000000<0ZZZZ05EEE@1EEED0
101EEED00`000000EEEE0:ZZZP040000000405EEE@00000000000:ZZZP@0EEEE00<000000?ooo`00
00000`0000020:ZZZP80000000<0ZZZZ05EEE@1EEED00P1EEED50?ooo``0dLfY000;0=7=Z@L0oooo
00D0EEEE0?ooo`1EEED0000005EEE@030?ooo`0:0000002ZZZX0oooo0000003oool000000?ooo`2Z
ZZX000000?ooo`<000000P2ZZZX00`3oool00000000000020000000405EEE@000000000005EEE@<0
000000<0ZZZZ0?ooo`2ZZZX0100000000`3oool0ZZZZ0:ZZZP030?ooo`040000001EEED0ZZZZ0000
0080oooo0P1EEED00`000000EEEE0?ooo`0205EEE@H0oooo2P3AcJT70?ooo`030000003oool0EEEE
00<0000000P0ZZZZ0?ooo`3oool0ZZZZ0000002ZZZX000000?ooo`80EEEE00@0oooo0000003oool0
EEEE0`3oool0102ZZZX0EEEE0?ooo`1EEED60000000405EEE@3oool0ZZZZ0:ZZZPD0oooo00`00000
05EEE@1EEED0EEEE0:ZZZP000000ZZZZ0?ooo`2ZZZX000000?ooo`2ZZZX30000000405EEE@3oool0
000005EEE@H0oooo2P3AcJT60?ooo`050:ZZZP3oool0oooo05EEE@3oool0101EEED01P000000oooo
0?ooo`2ZZZX0oooo0:ZZZP<0EEEE00@000000?ooo`1EEED0ZZZZ0P3oool010000000ZZZZ0:ZZZP1E
EED20:ZZZP0305EEE@000000ZZZZ0080EEEE00X0ZZZZ0?ooo`000000oooo0000002ZZZX000000?oo
o`000000oooo0P1EEED00`000000oooo0:ZZZP020?ooo`030:ZZZP1EEED0EEEE0080EEEE00D0oooo
0:ZZZP3oool0oooo05EEE@060?ooo`X0dLfY1P3oool00`2ZZZX0oooo0:ZZZP0705EEE@80ZZZZ00<0
000005EEE@3oool00`1EEED20:ZZZP80EEEE00<0oooo05EEE@1EEED00P0000020:ZZZP80oooo00H0
ZZZZ0?ooo`3oool0ZZZZ0000002ZZZX505EEE@80ZZZZ1@1EEED00`000000ZZZZ0:ZZZP0705EEE@03
0:ZZZP3oool0EEEE00H0oooo2P3AcJT70?ooo`80ZZZZ00<0EEEE0000001EEED01P1EEED01@3oool0
EEEE05EEE@1EEED0ZZZZ00@0EEEE0P00000505EEE@030?ooo`2ZZZX0000000<0ZZZZ0P1EEED00`00
0000EEEE05EEE@03000000<0EEEE00P0ZZZZ05EEE@2ZZZX0EEEE0?ooo`000000EEEE000000@0EEEE
0P0000020:ZZZP0305EEE@3oool0oooo00@0oooo303AcJT000/0dLfY1P3oool01P1EEED000000000
001EEED0000005EEE@<0000000<0ZZZZ0?ooo`3oool00`0000030:ZZZP80EEEE00<0ZZZZ00000000
00000P3oool00`000000ZZZZ05EEE@0200000080EEEE00@000000:ZZZP1EEED0ZZZZ103oool20000
0080EEEE0`2ZZZX30000000305EEE@3oool0000000<0000000<0EEEE0000000000000P0000070?oo
o`X0dLfY1P3oool305EEE@050?ooo`00000000000?ooo`0000000P1EEED010000000ZZZZ05EEE@1E
EED20:ZZZP030?ooo`1EEED0EEEE0080EEEE00@0oooo05EEE@3oool0EEEE0`3oool600000080oooo
00@0000005EEE@3oool0EEEE0P3oool205EEE@80oooo00@0ZZZZ05EEE@1EEED0EEEE0P00000205EE
E@@0000000<0oooo05EEE@1EEED01`3oool:0=7=Z@H0oooo0`1EEED30?ooo`030:ZZZP3oool0ZZZZ
00@0EEEE00<000000:ZZZP1EEED00P3oool0101EEED000000:ZZZP2ZZZX305EEE@050000003oool0
ZZZZ0?ooo`0000000P2ZZZX01@000000ZZZZ0:ZZZP3oool0ZZZZ00<0EEEE0P2ZZZX01`000000EEEE
0?ooo`3oool0EEEE0:ZZZP0000000`1EEED20:ZZZP040?ooo`1EEED0oooo0?ooo`<0EEEE1`3oool:
0=7=Z@H0oooo00<0EEEE0000002ZZZX00`2ZZZX0203oool0ZZZZ0?ooo`2ZZZX0EEEE0000003oool0
ZZZZ0P3oool20:ZZZP80EEEE00X0oooo0:ZZZP3oool0oooo0:ZZZP1EEED0oooo05EEE@2ZZZX00000
0P1EEED20000000405EEE@3oool0EEEE0:ZZZP80oooo0P2ZZZX205EEE@060?ooo`2ZZZX0oooo0?oo
o`2ZZZX0oooo0P1EEED20?ooo`H0ZZZZ00<000000?ooo`3oool01@3oool:0=7=Z@H0oooo0`1EEED2
000000030:ZZZP3oool0oooo0080EEEE00<000000:ZZZP2ZZZX00P1EEED0102ZZZX0EEEE0000001E
EED20000000305EEE@000000EEEE0080000000X0EEEE000000000000ZZZZ0000001EEED0ZZZZ0?oo
o`000000EEEE0P00000305EEE@80000000@0EEEE0000001EEED0ZZZZ0P1EEED01P2ZZZX000000000
00000000EEEE0?ooo`80ZZZZ00@0000005EEE@1EEED0EEEE1`3oool<0=7=Z@002`3AcJT80?ooo`80
EEEE00D0oooo05EEE@1EEED0ZZZZ000000020?ooo`80EEEE00@0oooo0000002ZZZX0ZZZZ0`000003
0?ooo`80000000`0oooo0000001EEED0oooo0000003oool0ZZZZ0000003oool0EEEE0000002ZZZX3
000000030?ooo`1EEED00000008000000P2ZZZX010000000oooo05EEE@1EEED20?ooo`040000002Z
ZZX0oooo05EEE@80oooo00<0EEEE0?ooo`3oool01P3oool:0=7=Z@P0oooo00<0EEEE0:ZZZP000000
0P0000000`3oool0EEEE05EEE@0205EEE@<0oooo0P00000205EEE@80oooo0P1EEED01@3oool0EEEE
05EEE@1EEED0ZZZZ00H0000000D0ZZZZ05EEE@1EEED0EEEE0?ooo`0205EEE@040000003oool0EEEE
0?ooo`8000000`3oool205EEE@030?ooo`1EEED0oooo00<000000P1EEED80?ooo`X0dLfY203oool5
05EEE@80ZZZZ00D000000:ZZZP3oool000000?ooo`0605EEE@80oooo0`0000001@3oool0ZZZZ0000
002ZZZX0EEEE0080oooo00D0EEEE0:ZZZP000000ZZZZ0?ooo`0200000080oooo00<0ZZZZ05EEE@1E
EED00`1EEED01P000000oooo000000000000ZZZZ0?ooo`80ZZZZ1@1EEED80?ooo`X0dLfY203oool0
201EEED0ZZZZ05EEE@3oool0EEEE0:ZZZP3oool0ZZZZ0P1EEED20:ZZZP80oooo00D0ZZZZ0000001E
EED0EEEE0?ooo`020:ZZZP030?ooo`2ZZZX0EEEE0080EEEE0P2ZZZX00`1EEED000000:ZZZP0405EE
E@050:ZZZP3oool0ZZZZ0:ZZZP0000000P1EEED00`3oool0ZZZZ0?ooo`030:ZZZP80EEEE0P3oool0
1P2ZZZX0EEEE0?ooo`1EEED0ZZZZ05EEE@P0oooo2P3AcJT80?ooo`0305EEE@00000000000080EEEE
00@0ZZZZ0000001EEED00000101EEED4000000030:ZZZP3oool0EEEE00H0EEEE00<0000005EEE@1E
EED00P1EEED00`3oool0EEEE05EEE@0305EEE@040000001EEED0ZZZZ0:ZZZP@0000000<0ZZZZ05EE
E@1EEED00P0000000`1EEED000000:ZZZP0205EEE@030000001EEED0EEEE00P0oooo303AcJT000/0
dLfY2@3oool300000080oooo0`0000002`1EEED000000000002ZZZX0EEEE0?ooo`000000oooo0000
001EEED0oooo0080000000<0oooo05EEE@1EEED00`0000020?ooo`<0000000<0EEEE0:ZZZP3oool0
0P0000001`3oool000000000003oool0ZZZZ0?ooo`1EEED01`0000001@3oool0EEEE000000000000
EEEE00T0oooo2P3AcJT:0?ooo`<0000000<0oooo0:ZZZP2ZZZX00P3oool505EEE@80oooo0P1EEED0
0`3oool0ZZZZ05EEE@020:ZZZP0305EEE@3oool0000000D0000000D0oooo05EEE@3oool0ZZZZ05EE
E@020?ooo`80EEEE00D0oooo05EEE@1EEED0EEEE0?ooo`0205EEE@050:ZZZP3oool0EEEE0:ZZZP3o
ool00`0000000`1EEED0oooo0?ooo`070?ooo`X0dLfY2@3oool01@2ZZZX0oooo0?ooo`1EEED0oooo
0080EEEE00@0ZZZZ0000001EEED00000102ZZZX20?ooo`<0EEEE00H0ZZZZ05EEE@1EEED0EEEE0?oo
o`2ZZZX40?ooo`030000003oool0EEEE0080EEEE00@0ZZZZ05EEE@1EEED0EEEE0P3oool40:ZZZP04
0000001EEED0ZZZZ0:ZZZP80EEEE00D0oooo0:ZZZP3oool0oooo05EEE@090?ooo`X0dLfY2@3oool0
10000000oooo0?ooo`2ZZZX305EEE@060:ZZZP3oool0000005EEE@000000ZZZZ0P1EEED02P3oool0
ZZZZ000000000000EEEE0000002ZZZX0oooo0:ZZZP3oool205EEE@80ZZZZ00<0EEEE0:ZZZP3oool0
0`2ZZZX01P000000EEEE0000003oool0ZZZZ0?ooo`80EEEE00H0ZZZZ05EEE@1EEED000000?ooo`2Z
ZZX305EEE@<0oooo00<0EEEE0?ooo`3oool01`3oool:0=7=Z@X0oooo00P0ZZZZ05EEE@2ZZZX0EEEE
0000003oool000000?ooo`80ZZZZ00@0EEEE0000001EEED000000`1EEED01@3oool0000005EEE@00
0000EEEE0080oooo00<0EEEE0000001EEED00P0000000`1EEED0oooo0?ooo`020000000305EEE@3o
ool0oooo00D0EEEE0P0000020:ZZZP040?ooo`000000EEEE000000<0EEEE00<0ZZZZ05EEE@3oool0
203oool<0=7=Z@002`3AcJT:0?ooo`0705EEE@3oool0oooo05EEE@000000EEEE0?ooo`0205EEE@80
oooo00<0EEEE0000001EEED00P1EEED20?ooo`80000000L0oooo0000003oool0EEEE0:ZZZP000000
oooo0080000000<0ZZZZ05EEE@3oool00P3oool20000000:0?ooo`000000EEEE05EEE@3oool00000
05EEE@2ZZZX0oooo05EEE@80oooo0P00000205EEE@030?ooo`1EEED0oooo00T0oooo2P3AcJT:0?oo
o`0405EEE@3oool0ZZZZ0?ooo`80EEEE00D0oooo0000001EEED0oooo05EEE@030?ooo`80ZZZZ00<0
EEEE0?ooo`1EEED00P1EEED20:ZZZPP0000000@0ZZZZ0?ooo`1EEED0EEEE0P3oool00`1EEED0ZZZZ
0:ZZZP030?ooo`0305EEE@3oool0EEEE0080oooo0P1EEED0103oool0ZZZZ0?ooo`1EEED:0?ooo`X0
dLfY2P3oool00`1EEED0ZZZZ0?ooo`020?ooo`060000002ZZZX0EEEE0?ooo`1EEED0ZZZZ0P1EEED0
0`2ZZZX000000:ZZZP0205EEE@<0oooo101EEED01@3oool0ZZZZ0:ZZZP3oool0ZZZZ00<0EEEE0P3o
ool305EEE@030:ZZZP000000ZZZZ00@0EEEE00<0oooo05EEE@2ZZZX0103oool00`2ZZZX0EEEE0?oo
o`090?ooo`X0dLfY2P3oool00`1EEED0ZZZZ0:ZZZP0305EEE@80ZZZZ0`3oool01@2ZZZX0EEEE05EE
E@2ZZZX0oooo008000000`1EEED00`2ZZZX0oooo0:ZZZP020:ZZZP80000000<0ZZZZ0000002ZZZX0
0P3oool205EEE@050:ZZZP00000000000?ooo`2ZZZX00P1EEED00`2ZZZX0oooo0?ooo`020?ooo`07
0:ZZZP1EEED0EEEE05EEE@3oool0ZZZZ05EEE@0:0?ooo`X0dLfY2P3oool00`1EEED0oooo00000002
05EEE@060:ZZZP1EEED0oooo0?ooo`2ZZZX0oooo0P1EEED01P3oool0000005EEE@000000oooo0:ZZ
ZP80000000/0ZZZZ05EEE@000000000005EEE@2ZZZX0oooo05EEE@3oool0000005EEE@0300000006
0:ZZZP3oool0EEEE05EEE@000000oooo0P1EEED20:ZZZP040?ooo`1EEED0EEEE00000080EEEE00<0
00000?ooo`1EEED02P3oool<0=7=Z@002`3AcJT;0?ooo`0405EEE@000000000005EEE@<0oooo00D0
EEEE0?ooo`3oool0EEEE0?ooo`020000000;05EEE@2ZZZX0ZZZZ0?ooo`000000ZZZZ0000001EEED0
oooo0000003oool00P0000030?ooo`0305EEE@2ZZZX0ZZZZ0080000000X0ZZZZ0000001EEED00000
05EEE@3oool0EEEE0000003oool0EEEE0P3oool205EEE@80000000<0EEEE0?ooo`3oool02@3oool:
0=7=Z@/0oooo00L0EEEE0:ZZZP1EEED0ZZZZ0?ooo`2ZZZX000000080oooo00P0EEEE0?ooo`1EEED0
oooo05EEE@000000oooo05EEE@80oooo0P1EEED:000000030?ooo`1EEED0oooo0080EEEE00<0oooo
0000001EEED00P1EEED40?ooo`040000002ZZZX0oooo0:ZZZP<0EEEE2`3oool:0=7=Z@/0oooo1@1E
EED00`2ZZZX0oooo0?ooo`020?ooo`040:ZZZP1EEED0EEEE05EEE@<0ZZZZ0`3oool30:ZZZP040000
003oool0ZZZZ00000080oooo0P2ZZZX40?ooo`<0ZZZZ00D0EEEE0?ooo`1EEED0ZZZZ000000020?oo
o`80ZZZZ1@1EEED;0?ooo`X0dLfY2`3oool00`1EEED0ZZZZ0:ZZZP030:ZZZPD0EEEE0P2ZZZX205EE
E@030?ooo`1EEED0ZZZZ0080oooo00H0000005EEE@2ZZZX0ZZZZ05EEE@3oool305EEE@030:ZZZP1E
EED000000080oooo1@1EEED00`3oool0ZZZZ05EEE@0305EEE@030000002ZZZX0ZZZZ0080ZZZZ00<0
000005EEE@3oool02P3oool:0=7=Z@/0oooo00<0EEEE0000001EEED00P3oool00`000000oooo05EE
E@0205EEE@80oooo00@0EEEE0?ooo`2ZZZX0oooo0`1EEED01P000000EEEE05EEE@2ZZZX000000?oo
o`80EEEE0P3oool0102ZZZX0EEEE05EEE@00000305EEE@80ZZZZ00@0oooo05EEE@3oool0oooo101E
EED2000000040?ooo`1EEED0EEEE05EEE@/0oooo303AcJT000/0dLfY303oool00`1EEED0000005EE
E@0400000080EEEE0P00000205EEE@030000003oool0oooo0080000000@0oooo000000000000EEEE
0P0000001P3oool000000000003oool0EEEE00000080oooo0P000000103oool000000000001EEED3
000000030?ooo`1EEED0000000<0000000<0EEEE0000001EEED0303oool:0=7=Z@d0oooo00<00000
0?ooo`1EEED00`000000102ZZZX000000?ooo`2ZZZX20?ooo`050000002ZZZX0oooo0:ZZZP000000
0P3oool:00000080oooo00<000000?ooo`3oool00P0000020?ooo`040:ZZZP3oool0oooo0:ZZZP<0
000000@0EEEE0?ooo`000000EEEE303oool:0=7=Z@`0oooo00D0ZZZZ0?ooo`3oool0EEEE0?ooo`03
05EEE@070:ZZZP000000oooo0?ooo`2ZZZX0oooo0:ZZZP03000000050?ooo`000000ZZZZ0?ooo`00
00000P1EEED02@2ZZZX0EEEE0000003oool0ZZZZ0000003oool000000?ooo`02000000050?ooo`2Z
ZZX0oooo0?ooo`000000101EEED01@3oool0ZZZZ0?ooo`3oool0EEEE00`0oooo2P3AcJT<0?ooo`03
05EEE@0000000000008000000P3oool0102ZZZX0oooo0?ooo`1EEED30:ZZZP80oooo0`1EEED01@3o
ool0EEEE0?ooo`3oool0EEEE0080oooo00<0EEEE0000003oool0101EEED00`2ZZZX0oooo0?ooo`02
0:ZZZP090000001EEED0oooo05EEE@2ZZZX0oooo0:ZZZP000000EEEE0080000000<0EEEE0?ooo`3o
ool02P3oool:0=7=Z@d0oooo0P2ZZZX02`3oool0EEEE05EEE@2ZZZX0EEEE0:ZZZP1EEED0ZZZZ0?oo
o`2ZZZX000000080ZZZZ00D0oooo05EEE@3oool0ZZZZ000000020:ZZZP0>0?ooo`1EEED000000?oo
o`1EEED0ZZZZ0000002ZZZX0oooo05EEE@3oool0ZZZZ05EEE@0000030:ZZZP<0EEEE0P2ZZZX205EE
E@80ZZZZ00<0EEEE0?ooo`3oool02P3oool<0=7=Z@002`3AcJT=0?ooo`0305EEE@00000000000080
EEEE100000001@1EEED000000:ZZZP3oool0ZZZZ00<0000000<0oooo0000002ZZZX00P2ZZZX0101E
EED0000005EEE@1EEED30:ZZZP80oooo00P0000005EEE@000000ZZZZ0?ooo`2ZZZX0000005EEE@D0
000000@0EEEE000000000000EEEE3@3oool:0=7=Z@d0oooo00@0EEEE0?ooo`000000oooo0P000000
1@2ZZZX0oooo0?ooo`000000oooo00<0EEEE00D0oooo05EEE@1EEED0EEEE0:ZZZP0:000000<0EEEE
0P3oool305EEE@80000000<0oooo05EEE@2ZZZX00P000000103oool0ZZZZ0?ooo`1EEED=0?ooo`X0
dLfY3@3oool00`1EEED0ZZZZ0?ooo`020?ooo`030000002ZZZX0ZZZZ0080ZZZZ00X0oooo05EEE@3o
ool0ZZZZ0?ooo`000000oooo0:ZZZP1EEED0ZZZZ0P3oool2000000070?ooo`000000ZZZZ0?ooo`2Z
ZZX0EEEE0:ZZZP030?ooo`030000003oool0EEEE00<0ZZZZ00<0EEEE0:ZZZP0000000`3oool00`2Z
ZZX0EEEE0?ooo`0<0?ooo`X0dLfY3@3oool0101EEED000000?ooo`3oool205EEE@@0oooo00L0EEEE
0:ZZZP2ZZZX0ZZZZ0?ooo`2ZZZX0000000T0EEEE00<0oooo05EEE@1EEED00P1EEED010000000ZZZZ
0?ooo`3oool20:ZZZPD0oooo00H0EEEE0:ZZZP3oool0oooo0000001EEED=0?ooo`X0dLfY3@3oool0
1@1EEED0oooo05EEE@2ZZZX0000000<0EEEE0P00000405EEE@80000000<0oooo0000001EEED00P1E
EED2000000040:ZZZP3oool0000000000080EEEE0P000000103oool0ZZZZ00000000000205EEE@03
0:ZZZP000000000000<0EEEE00D000000:ZZZP000000oooo05EEE@0=0?ooo``0dLfY000;0=7=Z@h0
oooo00X0EEEE0000001EEED0EEEE0000002ZZZX000000:ZZZP3oool000000P3oool01P000000oooo
0?ooo`000000ZZZZ000000D0oooo00<0EEEE0?ooo`0000000P3oool20:ZZZP030000002ZZZX0oooo
00<0oooo00D0ZZZZ0?ooo`2ZZZX000000:ZZZP02000000<0EEEE3P3oool:0=7=Z@h0oooo00<0EEEE
0:ZZZP0000000P0000020?ooo`<0EEEE1@3oool00`1EEED0oooo05EEE@0:05EEE@030:ZZZP3oool0
EEEE0080oooo00<0EEEE0?ooo`3oool0101EEED0103oool0000000000000000205EEE@h0oooo2P3A
cJT>0?ooo`D0EEEE00L0ZZZZ0?ooo`000000ZZZZ0?ooo`000000oooo00<0EEEE00D0ZZZZ0000003o
ool0ZZZZ0000000205EEE@090000002ZZZX0EEEE05EEE@000000ZZZZ0?ooo`000000ZZZZ0080EEEE
00H000000?ooo`00000000000:ZZZP0000020:ZZZPD0EEEE3P3oool:0=7=Z@h0oooo0`1EEED00`2Z
ZZX0oooo0?ooo`040?ooo`060000001EEED0EEEE0:ZZZP000000ZZZZ0P3oool00`2ZZZX0oooo0?oo
o`020:ZZZP040?ooo`2ZZZX0oooo0?ooo`80ZZZZ00@0oooo0:ZZZP000000ZZZZ0P1EEED00`000000
oooo0?ooo`040?ooo`@0EEEE3P3oool:0=7=Z@h0oooo00L0EEEE000000000000oooo0000001EEED0
00000080EEEE0P2ZZZX0203oool0EEEE05EEE@2ZZZX000000?ooo`000000EEEE0P000000102ZZZX0
oooo0000002ZZZX20000000305EEE@3oool0oooo0080000000D0EEEE0:ZZZP3oool0ZZZZ00000002
05EEE@050?ooo`1EEED000000?ooo`0000000P1EEED>0?ooo``0dLfY000;0=7=ZA00oooo0P1EEED0
0`3oool0EEEE000000020?ooo`@000000P2ZZZX00`000000oooo000000020:ZZZP060?ooo`1EEED0
00000000001EEED000000P2ZZZX20?ooo`030000002ZZZX0ZZZZ00<000000`3oool0102ZZZX0EEEE
0?ooo`3oool205EEE@l0oooo2P3AcJT@0?ooo`<0000000<0oooo05EEE@2ZZZX00P3oool205EEE@@0
oooo00<0EEEE0:ZZZP3oool0103oool00`2ZZZX0oooo0:ZZZP020?ooo`80EEEE103oool205EEE@05
0:ZZZP3oool0ZZZZ0:ZZZP3oool00`0000000`1EEED0oooo0?ooo`0=0?ooo`X0dLfY3`3oool01@2Z
ZZX0oooo0:ZZZP1EEED0oooo0080EEEE00@0ZZZZ0000001EEED00000102ZZZX305EEE@080000003o
ool0ZZZZ0:ZZZP1EEED0ZZZZ0?ooo`00000305EEE@@0ZZZZ00@0000005EEE@2ZZZX0ZZZZ0P1EEED0
1@3oool0EEEE0?ooo`3oool0EEEE00l0oooo2P3AcJT?0?ooo`030:ZZZP3oool0EEEE00L0EEEE00D0
oooo0:ZZZP1EEED0oooo05EEE@02000000@0EEEE00<0ZZZZ0000001EEED00`1EEED00`2ZZZX00000
05EEE@0205EEE@80oooo1`1EEED00`2ZZZX0oooo05EEE@0?0?ooo`X0dLfY403oool40:ZZZP050000
003oool0EEEE05EEE@2ZZZX00P00000205EEE@050:ZZZP3oool0ZZZZ0000002ZZZX00P0000020?oo
o`80000000`0ZZZZ000000000000oooo0:ZZZP000000EEEE0?ooo`000000ZZZZ0000001EEED20?oo
o`80ZZZZ00<0EEEE0:ZZZP1EEED03`3oool<0=7=Z@002`3AcJT@0?ooo`0405EEE@000000EEEE0000
0080EEEE00@0oooo05EEE@000000oooo0P0000000`2ZZZX000000?ooo`03000000030?ooo`000000
EEEE00D000000P3oool02`000000ZZZZ000000000000oooo0000001EEED0oooo05EEE@3oool00000
00<0EEEE403oool:0=7=ZA00oooo00@0EEEE0:ZZZP2ZZZX0oooo0P1EEED0203oool0000005EEE@3o
ool0EEEE0?ooo`1EEED0oooo0P1EEED20?ooo`80EEEE00@000000:ZZZP1EEED0EEEE0P3oool205EE
E@060?ooo`1EEED0oooo05EEE@3oool0EEEE0P3oool205EEE@040?ooo`2ZZZX0oooo05EEEA00oooo
2P3AcJT@0?ooo`0305EEE@3oool0oooo0080oooo014000000:ZZZP1EEED0oooo05EEE@2ZZZX0EEEE
0:ZZZP1EEED0ZZZZ0?ooo`000000oooo05EEE@000000oooo0:ZZZP02000000040?ooo`0000000000
0:ZZZPD0EEEE00@0oooo05EEE@2ZZZX000000`3oool00`2ZZZX0EEEE0?ooo`0?0?ooo`X0dLfY403o
ool01P1EEED000000000001EEED000000:ZZZP<0EEEE00<0ZZZZ0000001EEED00`1EEED0202ZZZX0
000005EEE@2ZZZX000000?ooo`1EEED000000P1EEED00`000000ZZZZ05EEE@0305EEE@030?ooo`2Z
ZZX0EEEE0080EEEE00@0ZZZZ0000001EEED000000P1EEED@0?ooo`X0dLfY403oool02P1EEED00000
000000000000ZZZZ0000001EEED000000:ZZZP3oool305EEE@050?ooo`1EEED000000000001EEED0
0P0000002P3oool0EEEE000000000000EEEE0000002ZZZX0EEEE0?ooo`2ZZZX205EEE@060?ooo`2Z
ZZX0000005EEE@000000EEEE0P0000000`3oool0EEEE0?ooo`0?0?ooo``0dLfY000;0=7=ZA80oooo
00H0EEEE0?ooo`000000000005EEE@3oool205EEE@80000000<0oooo0000002ZZZX00P0000001@2Z
ZZX000000000002ZZZX0oooo0080000000P0ZZZZ0000002ZZZX0ZZZZ0000003oool000000:ZZZP80
EEEE00D0oooo05EEE@000000EEEE0?ooo`0205EEEA40oooo2P3AcJTA0?ooo`0305EEE@2ZZZX0EEEE
0080oooo00D0ZZZZ0000003oool0oooo05EEE@050?ooo`80EEEE00H0oooo0:ZZZP1EEED0EEEE0:ZZ
ZP3oool205EEE@040:ZZZP3oool0oooo05EEE@@0oooo00L000000:ZZZP3oool0ZZZZ05EEE@2ZZZX0
EEEE0140oooo2P3AcJTA0?ooo`D0EEEE00<0ZZZZ0?ooo`3oool00P3oool01`2ZZZX0oooo05EEE@2Z
ZZX0000005EEE@0000000P2ZZZX01P3oool000000:ZZZP2ZZZX0000005EEE@80ZZZZ0P1EEED0102Z
ZZX000000?ooo`3oool20:ZZZPD0EEEE4@3oool:0=7=ZA40oooo0P2ZZZX305EEE@030:ZZZP3oool0
ZZZZ0080EEEE00L0oooo0:ZZZP2ZZZX0ZZZZ0000002ZZZX0oooo0080EEEE0P3oool00`1EEED0ZZZZ
0?ooo`050:ZZZP0;0?ooo`1EEED0EEEE0:ZZZP3oool0ZZZZ05EEE@3oool0EEEE0:ZZZP1EEED04@3o
ool:0=7=ZA40oooo00@0EEEE0000001EEED0ZZZZ0P0000000`1EEED000000:ZZZP020:ZZZP0405EE
E@3oool0EEEE0:ZZZP80000000H0EEEE0000003oool0EEEE0000001EEED30000000805EEE@3oool0
00000:ZZZP3oool0ZZZZ0000001EEED200000080EEEE00<0000005EEE@3oool0403oool<0=7=Z@00
2`3AcJTB0?ooo`<0EEEE1@0000001P3oool0ZZZZ0?ooo`000000ZZZZ00000080oooo0P000000103o
ool0EEEE0000001EEED20?ooo`80ZZZZ0P0000000`2ZZZX0EEEE0000000500000080EEEE4P3oool:
0=7=ZA80oooo0P1EEED20?ooo`80000000H0oooo0000001EEED0EEEE0000002ZZZX205EEE@80ZZZZ
0`0000000`1EEED00000000000020:ZZZP80EEEE00H0ZZZZ0000001EEED0EEEE0000003oool20000
00040?ooo`1EEED0EEEE05EEEA80oooo2P3AcJTB0?ooo`<0EEEE0P3oool0101EEED0ZZZZ0?ooo`2Z
ZZX405EEE@040?ooo`000000oooo05EEE@D0ZZZZ00<0oooo000000000000101EEED00`2ZZZX0oooo
0:ZZZP030?ooo`<0EEEE4P3oool:0=7=ZA80oooo101EEED00`2ZZZX0oooo0:ZZZP0405EEE@80ZZZZ
00<0EEEE0:ZZZP3oool01@1EEED0102ZZZX0oooo0:ZZZP1EEED20:ZZZP070?ooo`1EEED0EEEE05EE
E@2ZZZX0oooo0:ZZZP0405EEEA80oooo2P3AcJTB0?ooo`<0EEEE0P000000301EEED0oooo0000002Z
ZZX0oooo0:ZZZP000000EEEE0000003oool000000?ooo`80EEEE00@0ZZZZ05EEE@3oool000000P3o
ool0101EEED0000005EEE@3oool2000000040?ooo`1EEED00000000000<0EEEE4P3oool<0=7=Z@00
2`3AcJTC0?ooo`80EEEE00<0oooo05EEE@0000000P1EEED20?ooo`80000000@0oooo000000000000
00000P1EEED20000000405EEE@000000000000000080oooo0P0000020?ooo`@0EEEE0P3oool00`1E
EED0oooo0?ooo`0A0?ooo`X0dLfY4`3oool0101EEED0ZZZZ0000003oool2000000080:ZZZP3oool0
oooo0000003oool0EEEE0?ooo`1EEED200000080oooo00`000000?ooo`000000000005EEE@3oool0
EEEE0?ooo`000000oooo05EEE@2ZZZX2000000040?ooo`000000oooo05EEEA<0oooo2P3AcJTC0?oo
o`0305EEE@3oool0oooo0080oooo00<000000:ZZZP2ZZZX0102ZZZX01P000000EEEE0000003oool0
EEEE0?ooo`80EEEE00<0ZZZZ0000001EEED01@2ZZZX00`1EEED0ZZZZ000000030?ooo`030:ZZZP1E
EED0oooo0180oooo2P3AcJTC0?ooo`0305EEE@3oool0ZZZZ00<0EEEE0P2ZZZX20?ooo`050000001E
EED0oooo05EEE@0000001P2ZZZX01@000000EEEE0?ooo`1EEED0000000<0oooo00@0ZZZZ05EEE@1E
EED0EEEE0P2ZZZX00`1EEED0oooo0?ooo`0A0?ooo`X0dLfY4`3oool01@1EEED0000005EEE@1EEED0
oooo00<0EEEE00@0ZZZZ0000001EEED0EEEE0P2ZZZX305EEE@050000002ZZZX0EEEE0?ooo`1EEED0
0P2ZZZX205EEE@80ZZZZ00@0000005EEE@1EEED000000P1EEED00`3oool0EEEE0?ooo`0B0?ooo``0
dLfY000;0=7=ZA@0oooo100000001`1EEED00000000000000000ZZZZ05EEE@0000000`1EEED20?oo
o`80EEEE00L0oooo05EEE@1EEED0EEEE0?ooo`000000EEEE00@000000P1EEED20000000305EEE@3o
ool0oooo0180oooo2P3AcJTD0?ooo`0305EEE@2ZZZX00000008000000P3oool305EEE@<0oooo00D0
00000?ooo`000000EEEE0:ZZZP03000000<0oooo101EEED01P3oool00000000000000000ZZZZ05EE
EA@0oooo2P3AcJTD0?ooo`D0EEEE00<0ZZZZ0?ooo`0000000`0000030:ZZZP040?ooo`000000oooo
0?ooo`8000000P2ZZZX3000000040:ZZZP000000ZZZZ0:ZZZPD0EEEE503oool:0=7=ZA@0oooo00<0
00000:ZZZP2ZZZX00`2ZZZX405EEE@<0oooo00H0EEEE000000000000000005EEE@00000205EEE@<0
oooo0`1EEED00`000000ZZZZ0:ZZZP030:ZZZP0305EEE@3oool0oooo0180oooo2P3AcJTD0?ooo`04
05EEE@000000000005EEE@80oooo0`1EEED2000000050:ZZZP000000EEEE05EEE@3oool00P000002
0?ooo`0305EEE@000000EEEE008000000P1EEED0102ZZZX0oooo0?ooo`1EEED20000000305EEE@3o
ool0oooo0180oooo303AcJT000/0dLfY5@3oool01`1EEED0oooo0?ooo`1EEED0oooo0:ZZZP000000
0P3oool0101EEED000000?ooo`2ZZZX2000000080:ZZZP3oool000000?ooo`2ZZZX0oooo0000001E
EED20?ooo`030000001EEED0oooo0080EEEE00<0oooo05EEE@3oool0503oool:0=7=ZAD0oooo1@1E
EED00`000000oooo05EEE@020:ZZZP80oooo00@000000?ooo`000000EEEE0P000000103oool00000
0?ooo`3oool20:ZZZP0305EEE@3oool0oooo00D0EEEE5@3oool:0=7=ZAD0oooo0`1EEED20?ooo`03
05EEE@2ZZZX0000000<0ZZZZ0P1EEED00`3oool0ZZZZ0:ZZZP020:ZZZP040000001EEED0EEEE05EE
E@80ZZZZ00<0oooo0:ZZZP3oool00P3oool305EEEAD0oooo2P3AcJTE0?ooo`0705EEE@2ZZZX0EEEE
0?ooo`1EEED0ZZZZ000000060?ooo`0505EEE@000000oooo0?ooo`0000001P3oool01@1EEED00000
05EEE@1EEED0oooo0080ZZZZ00<0EEEE0?ooo`3oool04`3oool:0=7=ZAD0oooo0P1EEED00`2ZZZX0
EEEE000000020:ZZZP@0000000@0EEEE0:ZZZP1EEED0ZZZZ0P0000030:ZZZP0405EEE@0000000000
000000<0ZZZZ00<0000005EEE@1EEED00P1EEEDE0?ooo``0dLfY000;0=7=ZAH0oooo00D0EEEE0000
00000000EEEE0?ooo`040000000305EEE@3oool000000080EEEE00L000000?ooo`1EEED0oooo0000
003oool0EEEE00@0000000D0oooo05EEE@000000000005EEE@0F0?ooo`X0dLfY5P3oool0101EEED0
ZZZZ0:ZZZP3oool205EEE@030?ooo`000000EEEE0080EEEE100000002@3oool000000:ZZZP000000
EEEE0?ooo`1EEED000000?ooo`0205EEE@040?ooo`2ZZZX0oooo05EEEAH0oooo2P3AcJTF0?ooo`03
05EEE@3oool0oooo0080oooo00@0000005EEE@1EEED0oooo0`2ZZZX00`000000EEEE0?ooo`0205EE
E@<0ZZZZ00D0EEEE0?ooo`1EEED0ZZZZ000000030?ooo`030:ZZZP1EEED0oooo01D0oooo2P3AcJTF
0?ooo`0405EEE@3oool0oooo0?ooo`80EEEE1`3oool405EEE@L0oooo00H0EEEE0:ZZZP3oool0oooo
0000001EEEDF0?ooo`X0dLfY5P3oool00`1EEED000000000000405EEE@050000001EEED0000005EE
E@0000000P1EEED01@000000EEEE05EEE@2ZZZX0000000<0EEEE00<0000005EEE@1EEED00P1EEED0
0`000000oooo05EEE@0F0?ooo``0dLfY000;0=7=ZAL0oooo00H0EEEE0?ooo`1EEED0EEEE0000001E
EED20?ooo`0305EEE@00000000000080EEEE0P0000001@1EEED00000000000000000EEEE0080oooo
0P0000000`3oool0EEEE0?ooo`0H0?ooo`X0dLfY5`3oool00`1EEED0oooo0000000205EEE@<00000
00D0oooo000000000000EEEE0?ooo`02000000050?ooo`2ZZZX000000000002ZZZX00`0000000`1E
EED0oooo0000000I0?ooo`X0dLfY5`3oool0101EEED0ZZZZ0?ooo`2ZZZX505EEE@<0ZZZZ00<00000
0?ooo`0000000P0000020:ZZZP<0EEEE00D0oooo05EEE@3oool0oooo0:ZZZP0H0?ooo`X0dLfY5`3o
ool00`1EEED0ZZZZ0?ooo`0:05EEE@030000001EEED0EEEE00P0EEEE00<0ZZZZ0?ooo`2ZZZX0603o
ool:0=7=ZAL0oooo00D0EEEE0?ooo`2ZZZX0EEEE0:ZZZP0305EEE@060:ZZZP1EEED0000005EEE@3o
ool000000P3oool0101EEED0000005EEE@00000205EEE@040000002ZZZX0ZZZZ0:ZZZQT0oooo303A
cJT000/0dLfY603oool0101EEED000000000001EEED30?ooo`0305EEE@3oool0EEEE008000000P1E
EED00`000000EEEE05EEE@040?ooo`80EEEE0P0000000`1EEED0oooo0?ooo`0F0?ooo`X0dLfY603o
ool205EEE@80oooo0P0000001P3oool0EEEE05EEE@1EEED0ZZZZ0?ooo`80000000H0oooo05EEE@1E
EED0EEEE0000003oool2000000040?ooo`1EEED0EEEE05EEEAP0oooo2P3AcJTH0?ooo`<0EEEE0P3o
ool0101EEED0ZZZZ0:ZZZP2ZZZX205EEE@030:ZZZP1EEED0EEEE0080ZZZZ00D0EEEE0:ZZZP3oool0
ZZZZ05EEE@020?ooo`<0EEEE603oool:0=7=ZAP0oooo00<0EEEE0000002ZZZX00`2ZZZX30?ooo`0;
0:ZZZP3oool0ZZZZ0?ooo`1EEED0ZZZZ0?ooo`2ZZZX0oooo0:ZZZP3oool0102ZZZX00`000000EEEE
0?ooo`0G0?ooo`X0dLfY603oool305EEE@030:ZZZP000000EEEE0080oooo00@0000005EEE@2ZZZX0
EEEE0P2ZZZX305EEE@80000000@0oooo05EEE@000000ZZZZ0`1EEEDH0?ooo``0dLfY000;0=7=ZAT0
oooo00<0EEEE0000001EEED0100000001@1EEED0oooo0:ZZZP000000EEEE008000000P3oool00`1E
EED0000000000002000000<0EEEE6@3oool:0=7=ZAT0oooo00<0EEEE0:ZZZP0000000`000000101E
EED0oooo0?ooo`3oool405EEE@040000003oool0oooo0:ZZZP80000000@0oooo0000003oool0EEEE
6@3oool:0=7=ZAT0oooo00<0EEEE0?ooo`3oool00P3oool01P000000EEEE0:ZZZP2ZZZX000000?oo
o`80ZZZZ0P3oool30:ZZZP060000003oool0oooo0?ooo`2ZZZX0EEEE6@3oool:0=7=ZAT0oooo00<0
EEEE0000000000000P0000001P2ZZZX0EEEE05EEE@1EEED0000005EEE@80oooo00<0EEEE0:ZZZP1E
EED00P1EEED0102ZZZX0000005EEE@00000205EEEAT0oooo2P3AcJTI0?ooo`0605EEE@000000EEEE
0?ooo`1EEED0oooo102ZZZX405EEE@0:0000002ZZZX0ZZZZ05EEE@3oool0EEEE0:ZZZP1EEED0oooo
05EEEAT0oooo303AcJT000/0dLfY6P3oool0101EEED000000000001EEED600000080oooo10000000
0`1EEED0000005EEE@02000001/0oooo2P3AcJTJ0?ooo`0305EEE@3oool000000080000000D0ZZZZ
05EEE@2ZZZX0oooo0:ZZZP02000000050:ZZZP3oool0ZZZZ05EEE@3oool00`00000L0?ooo`X0dLfY
6P3oool0101EEED0ZZZZ0?ooo`2ZZZX405EEE@060:ZZZP3oool0ZZZZ05EEE@3oool0ZZZZ0P1EEED0
1@3oool0EEEE0:ZZZP3oool0ZZZZ01/0oooo2P3AcJTJ0?ooo`0505EEE@000000oooo0?ooo`2ZZZX0
0`1EEED50?ooo`050:ZZZP1EEED0EEEE05EEE@2ZZZX00P3oool00`000000oooo0?ooo`0I0?ooo`X0
dLfY6P3oool0101EEED0oooo05EEE@2ZZZX30000000;05EEE@000000ZZZZ0000001EEED0ZZZZ0000
001EEED0000005EEE@0000000P2ZZZXL0?ooo``0dLfY000;0=7=ZA/0oooo00<0EEEE0000001EEED0
0P0000000`2ZZZX000000?ooo`06000000030:ZZZP1EEED0000000<0EEEE6`3oool:0=7=ZA/0oooo
101EEED0103oool000000?ooo`1EEED40000000305EEE@3oool0000000D0EEEE6`3oool:0=7=ZA/0
oooo0`1EEED20?ooo`0:05EEE@2ZZZX000000:ZZZP3oool0EEEE0:ZZZP3oool0ZZZZ05EEE@80oooo
0`1EEEDK0?ooo`X0dLfY6`3oool405EEE@80oooo00<0ZZZZ05EEE@1EEED0101EEED00`2ZZZX0oooo
0:ZZZP0405EEEA/0oooo2P3AcJTK0?ooo`80EEEE00H0ZZZZ0000001EEED0EEEE0000002ZZZX20000
000505EEE@00000000000000001EEED00P0000000`2ZZZX0EEEE05EEE@0K0?ooo``0dLfY000;0=7=
ZA`0oooo00@0EEEE000000000000EEEE0P3oool30000000305EEE@00000000000080oooo0`00000M
0?ooo`X0dLfY703oool205EEE@80ZZZZ0P3oool5000000060:ZZZP3oool0oooo05EEE@2ZZZX0EEEE
7@3oool:0=7=ZA`0oooo1P1EEED00`2ZZZX0oooo0?ooo`020?ooo`030:ZZZP1EEED0EEEE00<0EEEE
7@3oool:0=7=ZA`0oooo00<0EEEE0000002ZZZX00`2ZZZX01@000000EEEE0:ZZZP000000EEEE00D0
ZZZZ00<000000?ooo`3oool06`3oool:0=7=ZA`0oooo0P1EEED01@000000EEEE000000000000EEEE
00L0000000<0EEEE0000001EEED07@3oool<0=7=Z@002`3AcJTM0?ooo`<0EEEE00<000000?ooo`1E
EED00P3oool0101EEED0oooo05EEE@3oool200000080EEEE7@3oool:0=7=ZAd0oooo00<0EEEE0?oo
o`3oool00P1EEED600000080EEEE00<000000?ooo`1EEED07@3oool:0=7=ZAd0oooo00@0EEEE0:ZZ
ZP3oool0ZZZZ1P1EEED01P3oool0EEEE0:ZZZP3oool0ZZZZ05EEEAd0oooo2P3AcJTM0?ooo`80EEEE
00P0000005EEE@000000ZZZZ0?ooo`000000ZZZZ0?ooo`80000000@0EEEE0000001EEED0EEEE7@3o
ool:0=7=ZAd0oooo00<0EEEE0?ooo`2ZZZX00P0000050:ZZZP<0000000<0ZZZZ0?ooo`1EEED07@3o
ool<0=7=Z@002`3AcJTN0?ooo`80EEEE00@0oooo05EEE@000000EEEE0P3oool00`1EEED0000005EE
E@020?ooo`0305EEE@3oool0oooo01`0oooo2P3AcJTN0?ooo`80EEEE0P3oool600000080oooo0P1E
EEDN0?ooo`X0dLfY7P3oool305EEE@80oooo00@0EEEE0:ZZZP3oool0EEEE0P3oool305EEEAh0oooo
2P3AcJTN0?ooo`0605EEE@2ZZZX0EEEE0?ooo`1EEED0ZZZZ0P0000001P2ZZZX0EEEE0?ooo`1EEED0
ZZZZ05EEEAh0oooo2P3AcJTN0?ooo`<0EEEE00<0000005EEE@1EEED0101EEED010000000EEEE05EE
E@1EEEDN0?ooo``0dLfY000;0=7=ZAl0oooo0P1EEED60000000305EEE@000000EEEE0200oooo2P3A
cJTO0?ooo`80EEEE00<0ZZZZ000000000000100000000`2ZZZX0EEEE0?ooo`0O0?ooo`X0dLfY7`3o
ool505EEE@030:ZZZP1EEED0EEEE00<0EEEE803oool:0=7=ZAl0oooo101EEED0102ZZZX0oooo0?oo
o`2ZZZX305EEEB00oooo2P3AcJTO0?ooo`80EEEE00<0000005EEE@2ZZZX00P1EEED0102ZZZX00000
0000001EEEDP0?ooo``0dLfY000;0=7=ZB00oooo00D0EEEE0?ooo`3oool0EEEE0000000305EEE@03
0?ooo`1EEED0oooo01l0oooo2P3AcJTP0?ooo`0305EEE@3oool0000000D0000000<0oooo05EEE@3o
ool07`3oool:0=7=ZB00oooo00X0EEEE0:ZZZP3oool0ZZZZ0?ooo`1EEED0ZZZZ0?ooo`2ZZZX0EEEE
803oool:0=7=ZB00oooo00<0EEEE0:ZZZP2ZZZX0101EEED00`3oool0ZZZZ05EEE@0P0?ooo`X0dLfY
803oool01@1EEED0oooo05EEE@1EEED0ZZZZ0080EEEE00<0ZZZZ0?ooo`1EEED0803oool<0=7=Z@00
2`3AcJTQ0?ooo`0505EEE@00000000000000001EEED00P0000000`1EEED0oooo0?ooo`0O0?ooo`X0
dLfY8@3oool805EEEB40oooo2P3AcJTQ0?ooo`<0EEEE0P3oool305EEEB40oooo2P3AcJTQ0?ooo`04
05EEE@2ZZZX0ZZZZ0?ooo`80ZZZZ00<0000005EEE@3oool0803oool:0=7=ZB40oooo0P1EEED0102Z
ZZX0EEEE05EEE@2ZZZX205EEEB40oooo303AcJT000/0dLfY8P3oool0101EEED0oooo0?ooo`1EEEDT
0?ooo`X0dLfY8P3oool305EEE@030:ZZZP1EEED0oooo0280oooo2P3AcJTR0?ooo`D0EEEE8`3oool:
0=7=ZB80oooo00<0EEEE0:ZZZP3oool00P2ZZZXS0?ooo`X0dLfY8P3oool305EEE@030000001EEED0
oooo0280oooo303AcJT000/0dLfY8`3oool0101EEED000000000001EEEDS0?ooo`X0dLfY8`3oool0
101EEED000000?ooo`1EEEDS0?ooo`X0dLfY8`3oool0101EEED0oooo0:ZZZP1EEEDS0?ooo`X0dLfY
8`3oool0101EEED0oooo0000001EEEDS0?ooo`X0dLfY8`3oool0101EEED0ZZZZ0?ooo`1EEEDS0?oo
o``0dLfY000;0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool:0=7=ZB@0oooo00<0ZZZZ0?ooo`3o
ool08`3oool:0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool:0=7=ZB@0oooo00<0ZZZZ0?ooo`3o
ool08`3oool:0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool<0=7=Z@00o`3AcJVb0=7=Z@00o`3A
cJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@002`3A
cJT01`3oool0EEEE05EEE@3oool0000005EEE@2ZZZX00`0000000`1EEED0oooo05EEE@0405EEE@03
0:ZZZP3oool0oooo0080000000P0EEEE0000003oool0oooo0:ZZZP1EEED0ZZZZ0?ooo`80ZZZZ00D0
EEEE0:ZZZP3oool0ZZZZ05EEE@040:ZZZP0705EEE@2ZZZX0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP020?oo
o`040:ZZZP1EEED0000005EEE@80oooo0P1EEED01@3oool0EEEE05EEE@1EEED0oooo0080EEEE0P00
000205EEE@80oooo0P1EEED00`3oool0dLfY0=7=Z@080=7=Z@090?ooo`1EEED0EEEE0?ooo`000000
ZZZZ05EEE@3oool0EEEE0080oooo00<0ZZZZ05EEE@1EEED00P1EEED0203oool0ZZZZ05EEE@1EEED0
oooo05EEE@000000oooo0`1EEED20?ooo`080:ZZZP3oool0EEEE0000001EEED0ZZZZ0?ooo`1EEED3
0?ooo`0505EEE@000000ZZZZ0?ooo`2ZZZX00P3oool00`000000EEEE05EEE@020000000305EEE@3o
ool0EEEE0080EEEE00<0oooo05EEE@1EEED00P1EEED01@2ZZZX0oooo0000001EEED0oooo0080ZZZZ
0P3oool205EEE@030?ooo`3AcJT0dLfY00P0dLfY00D0oooo0000002ZZZX0ZZZZ0000000305EEE@@0
oooo00H0EEEE0000001EEED000000:ZZZP1EEED20?ooo`<0000000<0EEEE0000000000000P2ZZZX0
1`1EEED0ZZZZ000000000000EEEE0000002ZZZX0103oool0202ZZZX0000005EEE@3oool000000:ZZ
ZP1EEED0ZZZZ0`000000101EEED000000000001EEED20?ooo`0605EEE@2ZZZX0EEEE05EEE@000000
ZZZZ103oool305EEE@050000002ZZZX0ZZZZ05EEE@3oool02P3AcJT0103oool0ZZZZ000000000005
0:ZZZP80000000H0EEEE0000001EEED000000?ooo`1EEED50:ZZZP040000002ZZZX0000000000080
ZZZZ00@000000?ooo`1EEED0ZZZZ0P1EEED00`000000ZZZZ0:ZZZP020:ZZZP030?ooo`1EEED0EEEE
0080EEEE00<0oooo0:ZZZP2ZZZX00`0000000`2ZZZX000000:ZZZP040:ZZZP0305EEE@2ZZZX00000
00<0EEEE00<000000:ZZZP2ZZZX00`2ZZZX30000000305EEE@3oool0dLfY00T0dLfY00<0oooo05EE
E@1EEED00`1EEED0102ZZZX0EEEE0:ZZZP3oool2000000040:ZZZP1EEED0ZZZZ000000@0EEEE00L0
ZZZZ05EEE@00000000000:ZZZP000000ZZZZ0080oooo0`1EEED0102ZZZX0EEEE0:ZZZP0000020:ZZ
ZP030000003oool0EEEE0080ZZZZ0P1EEED01@2ZZZX0oooo0?ooo`000000ZZZZ0080000000X0EEEE
0:ZZZP1EEED0EEEE0?ooo`1EEED0oooo0:ZZZP1EEED0oooo0P0000020:ZZZP0305EEE@2ZZZX0EEEE
00@0EEEE00<0oooo0=7=Z@3AcJT02P3AcJT000/0dLfY00H0oooo05EEE@1EEED0000005EEE@2ZZZX3
05EEE@050000002ZZZX0oooo0?ooo`1EEED00P3oool205EEE@8000000`1EEED20000000=05EEE@3o
ool0EEEE0000001EEED0000005EEE@000000EEEE0000003oool0000005EEE@020?ooo`0;05EEE@00
0000oooo0000001EEED0oooo05EEE@000000EEEE0000003oool00`1EEED2000000040?ooo`1EEED0
oooo0?ooo`80EEEE00<0oooo0:ZZZP1EEED00P1EEED20:ZZZP80000000<0EEEE0?ooo`3oool02P3A
cJT01`3oool0EEEE0?ooo`3oool000000:ZZZP0000000P1EEED00`3oool0ZZZZ05EEE@0505EEE@80
000000D0EEEE0?ooo`1EEED0oooo05EEE@02000000@0ZZZZ0P000000103oool0ZZZZ05EEE@000002
05EEE@040000003oool0ZZZZ0?ooo`8000000`2ZZZX0203oool000000000001EEED0oooo05EEE@2Z
ZZX0EEEE0P00000605EEE@040:ZZZP1EEED0EEEE05EEE@80ZZZZ1@3oool:0=7=Z@070?ooo`1EEED0
00000:ZZZP1EEED0oooo0:ZZZP050?ooo`040000001EEED0oooo05EEE@@0000000<0EEEE0?ooo`1E
EED00P1EEED00`3oool0EEEE05EEE@02000000030?ooo`1EEED0EEEE00H0000000H0oooo0000001E
EED0ZZZZ0?ooo`00000305EEE@050?ooo`1EEED0000005EEE@3oool00`0000001P2ZZZX000000?oo
o`3oool0EEEE000000L0oooo00<0EEEE0:ZZZP0000000P3oool:0=7=Z@060?ooo`1EEED0ZZZZ05EE
E@2ZZZX0oooo102ZZZX010000000ZZZZ0000003oool20000000605EEE@2ZZZX0ZZZZ05EEE@3oool0
EEEE0`2ZZZX010000000ZZZZ0:ZZZP2ZZZX3000000030?ooo`000000ZZZZ00@0ZZZZ0P0000020?oo
o`8000000`2ZZZX01`000000ZZZZ05EEE@2ZZZX0EEEE0:ZZZP1EEED00P2ZZZX205EEE@050000003o
ool0EEEE0:ZZZP0000000`2ZZZX01@1EEED0oooo05EEE@1EEED0ZZZZ0080oooo2P3AcJT00`3oool0
EEEE0?ooo`030?ooo`040:ZZZP3oool0oooo0?ooo`80EEEE0P0000001P2ZZZX0EEEE0?ooo`3oool0
EEEE0?ooo`80000000<0ZZZZ0000002ZZZX00P1EEED200000080EEEE00D0ZZZZ0000001EEED0ZZZZ
0?ooo`02000000030?ooo`1EEED0EEEE008000000P1EEED0203oool000000:ZZZP1EEED0ZZZZ0?oo
o`2ZZZX000000P3oool01`1EEED0oooo0?ooo`1EEED0ZZZZ0000003oool00P1EEED01P000000oooo
0?ooo`1EEED0oooo0:ZZZP@0oooo303AcJT000/0dLfY0`3oool02@1EEED0000005EEE@3oool0ZZZZ
0?ooo`1EEED0oooo05EEE@0200000080EEEE00@0ZZZZ0?ooo`1EEED0EEEE0P3oool405EEE@80ZZZZ
101EEED01@000000EEEE05EEE@1EEED0000000@0EEEE00@0000005EEE@1EEED0EEEE0P2ZZZX505EE
E@80oooo0`1EEED00`2ZZZX0oooo05EEE@020000000405EEE@3oool0EEEE0?ooo`80ZZZZ0`1EEED3
0?ooo`X0dLfY0`3oool205EEE@80000000<0oooo05EEE@1EEED00`3oool0101EEED0ZZZZ0?ooo`00
000205EEE@050000001EEED0EEEE0?ooo`1EEED00P3oool00`1EEED0000005EEE@020?ooo`0<05EE
E@000000ZZZZ05EEE@2ZZZX0EEEE0000002ZZZX0oooo0:ZZZP000000ZZZZ0P3oool2000000D0oooo
00T0EEEE0?ooo`000000EEEE0?ooo`000000oooo0:ZZZP1EEED00`3oool205EEE@050?ooo`000000
00000000001EEED00`3oool:0=7=Z@<0oooo00<0EEEE0:ZZZP2ZZZX01P2ZZZX50000000305EEE@00
0000ZZZZ00<000000P1EEED00`3oool000000:ZZZP03000000030:ZZZP1EEED0EEEE0080EEEE0P00
000505EEE@8000000P2ZZZX00`1EEED0oooo05EEE@04000000030:ZZZP000000EEEE00@000001P2Z
ZZX010000000ZZZZ0000001EEED30?ooo`X0dLfY0`3oool205EEE@8000000P3oool0102ZZZX0oooo
05EEE@1EEED20?ooo`0405EEE@2ZZZX0oooo05EEE@<0ZZZZ0`1EEED50:ZZZP0305EEE@3oool00000
00P0ZZZZ00<0000005EEE@1EEED01@2ZZZX01`1EEED0000005EEE@2ZZZX000000:ZZZP1EEED00P2Z
ZZX01`1EEED0oooo0?ooo`000000EEEE0?ooo`1EEED00`3oool00`000000ZZZZ05EEE@030?ooo`X0
dLfY0`3oool01@1EEED0ZZZZ05EEE@2ZZZX0oooo00<0ZZZZ00`0EEEE0000001EEED0EEEE0?ooo`1E
EED0oooo0000003oool0EEEE0000001EEED20:ZZZP040000001EEED0ZZZZ00000080ZZZZ00<00000
0:ZZZP0000000P2ZZZX20?ooo`80ZZZZ00<000000:ZZZP0000000P2ZZZX010000000ZZZZ00000000
00020:ZZZP0605EEE@000000ZZZZ0?ooo`000000ZZZZ101EEED00`2ZZZX0EEEE0:ZZZP020:ZZZP03
0?ooo`1EEED0EEEE0080EEEE0`3oool<0=7=Z@002`3AcJT40?ooo`80EEEE00D000000?ooo`1EEED0
ZZZZ0?ooo`0405EEE@060000002ZZZX0oooo05EEE@3oool000000P3oool01@1EEED0000005EEE@3o
ool000000080oooo101EEED01P3oool0ZZZZ000000000000ZZZZ0?ooo`80EEEE00D0oooo05EEE@3o
ool0EEEE0000000205EEE@030000001EEED0oooo00<0oooo00@0EEEE0:ZZZP2ZZZX00000101EEED0
0`3oool0ZZZZ05EEE@020?ooo`80EEEE103oool:0=7=Z@@0oooo101EEED020000000EEEE0000001E
EED0000005EEE@000000oooo0P0000001@1EEED0ZZZZ0:ZZZP3oool0ZZZZ00@0oooo00D0EEEE0?oo
o`3oool0oooo05EEE@020:ZZZP060000001EEED0EEEE0?ooo`1EEED000000P2ZZZX00`000000oooo
0?ooo`0205EEE@<0oooo00<0EEEE0:ZZZP3oool00P2ZZZX01@1EEED0ZZZZ0000003oool0000000<0
EEEE0`000000101EEED0oooo05EEE@1EEED40?ooo`X0dLfY103oool00`000000ZZZZ05EEE@0605EE
E@050:ZZZP1EEED0EEEE05EEE@3oool00P1EEED0103oool0EEEE0000001EEED20?ooo`<0EEEE00<0
oooo0000000000000`1EEED00`000000oooo05EEE@0200000080EEEE00<0ZZZZ0000003oool00P1E
EED40?ooo`030000001EEED0EEEE0080EEEE00D0oooo05EEE@2ZZZX0EEEE0:ZZZP0705EEE@030:ZZ
ZP1EEED0oooo00<0oooo2P3AcJT40?ooo`050:ZZZP00000000000:ZZZP0000000`3oool01@000000
ZZZZ0000003oool000000080oooo00<0EEEE0:ZZZP3oool00P000000203oool000000?ooo`000000
oooo0000003oool000002P2ZZZX020000000oooo0000003oool000000?ooo`000000oooo0P000000
0`3oool0EEEE05EEE@020?ooo`<0000000@0ZZZZ05EEE@3oool0oooo0P0000020:ZZZP030000001E
EED0oooo00<0oooo2P3AcJT50?ooo`80ZZZZ1@1EEED01P2ZZZX0oooo0?ooo`2ZZZX000000?ooo`80
EEEE00<0oooo0:ZZZP0000000P3oool00`000000oooo0:ZZZP030:ZZZP0605EEE@2ZZZX0oooo0?oo
o`000000EEEE0`0000000`3oool0ZZZZ0:ZZZP020:ZZZP0505EEE@2ZZZX0ZZZZ0000003oool00P00
00020:ZZZP80EEEE0P000000102ZZZX0oooo0?ooo`00000505EEE@030?ooo`2ZZZX0EEEE00@0oooo
303AcJT000/0dLfY1@3oool505EEE@80oooo101EEED01P3oool0000005EEE@000000EEEE0:ZZZP80
000000D0ZZZZ0000001EEED0EEEE0000000205EEE@060000002ZZZX0000005EEE@3oool0EEEE0P3o
ool2000000060:ZZZP1EEED0EEEE05EEE@2ZZZX0EEEE0P000000102ZZZX000000000002ZZZX20000
0080EEEE0P3oool205EEE@<0oooo00<0000005EEE@1EEED00P1EEED50?ooo`X0dLfY1@3oool01@1E
EED0oooo05EEE@3oool0ZZZZ00<0oooo0P2ZZZX0201EEED000000000001EEED0oooo0000003oool0
ZZZZ103oool01P000000oooo05EEE@2ZZZX0000005EEE@<0000000<0ZZZZ0?ooo`0000000P000000
1P1EEED0oooo0:ZZZP1EEED0ZZZZ000000<0oooo00H000000:ZZZP3oool0EEEE0?ooo`1EEED20000
00030?ooo`2ZZZX0ZZZZ00<0oooo00D0ZZZZ0?ooo`1EEED0ZZZZ05EEE@050?ooo`X0dLfY1@3oool0
1@1EEED0ZZZZ0:ZZZP000000EEEE0080oooo00H0000005EEE@1EEED0oooo0000003oool205EEE@80
ZZZZ0P0000000`3oool000000?ooo`070000000305EEE@3oool0oooo0080oooo0`000000102ZZZX0
00000000003oool3000000040?ooo`00000000000:ZZZP@0EEEE0P00000305EEE@80oooo0P000000
0`2ZZZX0000005EEE@050?ooo`X0dLfY1@3oool0101EEED0000000000000000305EEE@<0ZZZZ00H0
00000?ooo`1EEED0ZZZZ05EEE@0000030:ZZZP070000003oool0EEEE0:ZZZP1EEED0oooo0000000<
0:ZZZP070000003oool0EEEE0:ZZZP1EEED0oooo000000040:ZZZP0405EEE@2ZZZX0EEEE0?ooo`<0
ZZZZ0`1EEED01@2ZZZX000000000002ZZZX0EEEE00D0oooo2P3AcJT50?ooo`@0EEEE00H000000:ZZ
ZP2ZZZX0ZZZZ0?ooo`00000205EEE@@0ZZZZ00<0oooo0:ZZZP000000101EEED01@3oool0ZZZZ0?oo
o`2ZZZX0oooo008000000P2ZZZX02@000000ZZZZ000000000000oooo0:ZZZP3oool0ZZZZ0?ooo`05
05EEE@030:ZZZP3oool0000000<0ZZZZ0P1EEED00`000000oooo0:ZZZP030:ZZZP@0EEEE1@3oool<
0=7=Z@002`3AcJT60?ooo`0605EEE@000000EEEE05EEE@3oool0ZZZZ0P3oool20:ZZZP080?ooo`1E
EED0EEEE0000001EEED0ZZZZ05EEE@2ZZZX305EEE@050?ooo`000000ZZZZ0000002ZZZX00`1EEED0
103oool0EEEE0:ZZZP3oool305EEE@80000000<0ZZZZ05EEE@3oool00`1EEED01@000000EEEE0:ZZ
ZP2ZZZX000000080EEEE00L0oooo0:ZZZP2ZZZX0oooo05EEE@2ZZZX0oooo0080EEEE00<0000005EE
E@3oool01@3oool:0=7=Z@H0oooo00D0000005EEE@000000oooo000000020?ooo`050000001EEED0
ZZZZ0?ooo`2ZZZX00P3oool205EEE@0C0000002ZZZX0EEEE0?ooo`1EEED0oooo0000001EEED0ZZZZ
0?ooo`1EEED0oooo05EEE@3oool0ZZZZ05EEE@3oool0EEEE0?ooo`0205EEE@0:0:ZZZP1EEED0EEEE
0?ooo`2ZZZX0oooo05EEE@3oool0000005EEE@<0oooo00D000000?ooo`3oool0EEEE000000020?oo
o`030000001EEED000000080EEEE1P3oool:0=7=Z@H0oooo00<000000:ZZZP1EEED00`3oool01@1E
EED000000000003oool0EEEE0080000000T0ZZZZ0000003oool000000?ooo`1EEED0ZZZZ05EEE@3o
ool00P2ZZZX205EEE@030:ZZZP1EEED0oooo00@0oooo0P1EEED01P2ZZZX0EEEE05EEE@2ZZZX0EEEE
0?ooo`80ZZZZ0P1EEED010000000oooo0000002ZZZX20000000405EEE@2ZZZX00000000000<0oooo
0P1EEED00`2ZZZX0EEEE0?ooo`050?ooo`X0dLfY1P3oool01@2ZZZX0EEEE05EEE@3oool0ZZZZ0080
oooo00L0EEEE0:ZZZP2ZZZX000000?ooo`000000oooo00D0ZZZZ00<000000?ooo`0000000P000006
0:ZZZP030?ooo`1EEED0ZZZZ00D0ZZZZ00<000000?ooo`0000000P0000040:ZZZP030000003oool0
0000008000000P2ZZZX00`1EEED0ZZZZ0?ooo`020:ZZZP<0EEEE1P3oool:0=7=Z@P0oooo00<0ZZZZ
05EEE@1EEED00`1EEED00`2ZZZX0oooo0:ZZZP030:ZZZP0405EEE@00000000000:ZZZP<0oooo00<0
ZZZZ0000002ZZZX00`1EEED01@2ZZZX0EEEE0:ZZZP3oool0000000<0ZZZZ0`1EEED40:ZZZP80oooo
0`0000070:ZZZP@0EEEE00@0oooo0:ZZZP3oool0EEEE1P3oool<0=7=Z@002`3AcJT60?ooo`<0EEEE
00T0oooo0:ZZZP1EEED0oooo0:ZZZP1EEED0ZZZZ05EEE@3oool00P1EEED20:ZZZP070000003oool0
EEEE0?ooo`1EEED000000:ZZZP0305EEE@80ZZZZ00H0oooo05EEE@1EEED0ZZZZ05EEE@3oool20:ZZ
ZP<0EEEE0P0000000`1EEED0oooo05EEE@02000000050:ZZZP1EEED0EEEE05EEE@3oool00`1EEED0
1@2ZZZX0EEEE05EEE@2ZZZX0oooo0080EEEE1`3oool:0=7=Z@H0oooo0`1EEED02P3oool000000:ZZ
ZP000000ZZZZ0?ooo`000000EEEE0?ooo`0000020?ooo`0505EEE@3oool0ZZZZ05EEE@0000000P3o
ool305EEE@8000000`1EEED2000000<0EEEE00@000000:ZZZP1EEED0EEEE0P3oool01P1EEED00000
05EEE@1EEED0oooo05EEE@80oooo00<0000005EEE@1EEED00P3oool01@2ZZZX000000:ZZZP000000
oooo0080EEEE1`3oool:0=7=Z@H0oooo00<0EEEE0000002ZZZX0100000001@2ZZZX0oooo00000000
0000ZZZZ0080EEEE0`2ZZZX20000000905EEE@00000000000:ZZZP1EEED0000005EEE@000000ZZZZ
00H0000000D0ZZZZ0000001EEED0000005EEE@02000000040:ZZZP1EEED0000000000080ZZZZ0`1E
EED01@2ZZZX000000000003oool0ZZZZ00@0000000<0ZZZZ0000003oool01P3oool:0=7=Z@H0oooo
00D0EEEE0:ZZZP000000000005EEE@020000000405EEE@2ZZZX000000:ZZZP<000001`2ZZZX20000
00D0ZZZZ00@0EEEE0:ZZZP3oool0oooo202ZZZX2000000H0ZZZZ0P0000020:ZZZP050?ooo`2ZZZX0
EEEE05EEE@0000000P1EEED00`000000ZZZZ0?ooo`060?ooo`X0dLfY1P3oool01@1EEED000000?oo
o`3oool0ZZZZ00<0oooo00/0EEEE0000002ZZZX0oooo0:ZZZP1EEED0ZZZZ0?ooo`000000oooo05EE
E@020000000505EEE@000000oooo0?ooo`2ZZZX00P3oool01P000000ZZZZ0:ZZZP1EEED0ZZZZ0000
0080oooo00D0ZZZZ0?ooo`3oool0ZZZZ05EEE@020000000305EEE@2ZZZX000000080oooo00<0EEEE
0:ZZZP1EEED00P2ZZZX01@1EEED0oooo0:ZZZP3oool0ZZZZ0080oooo00<000000?ooo`3oool01@3o
ool<0=7=Z@002`3AcJT80?ooo`<0EEEE00T0000005EEE@1EEED0ZZZZ0000002ZZZX0oooo0:ZZZP1E
EED00P2ZZZX205EEE@030000002ZZZX0EEEE00<0EEEE00<0ZZZZ0?ooo`2ZZZX00`00000205EEE@0<
0000001EEED000000:ZZZP1EEED0ZZZZ05EEE@3oool0EEEE0000002ZZZX000000P1EEED01@2ZZZX0
EEEE05EEE@2ZZZX0EEEE00<0ZZZZ00<0EEEE0000000000000`1EEED80?ooo`X0dLfY203oool00`1E
EED0oooo05EEE@0205EEE@030000003oool0oooo0080EEEE00D0ZZZZ0?ooo`3oool0oooo00000003
0:ZZZP80EEEE00<0oooo0000002ZZZX00P3oool00`1EEED0oooo0:ZZZP020?ooo`030:ZZZP3oool0
EEEE0080oooo00<0ZZZZ0000000000000P1EEED20:ZZZP0605EEE@000000oooo0000003oool0ZZZZ
0P1EEED010000000oooo0000002ZZZX205EEE@030:ZZZP1EEED0oooo00L0oooo2P3AcJT80?ooo`03
05EEE@2ZZZX0EEEE0080EEEE00D0ZZZZ000000000000ZZZZ05EEE@020?ooo`0305EEE@000000ZZZZ
0080oooo00<0EEEE0000002ZZZX00P1EEED30?ooo`<0EEEE0P00000305EEE@<0oooo00<0EEEE0000
002ZZZX00P1EEED20?ooo`030:ZZZP000000EEEE0080oooo00D000000:ZZZP00000000000:ZZZP03
05EEE@030000001EEED0oooo00L0oooo2P3AcJT80?ooo`0705EEE@000000ZZZZ0000001EEED0ZZZZ
000000040:ZZZP030000002ZZZX0EEEE00<0ZZZZ00<0EEEE0000001EEED01`2ZZZX01@000000ZZZZ
0:ZZZP000000EEEE0080ZZZZ00<0EEEE0:ZZZP2ZZZX00P1EEED00`2ZZZX0EEEE0:ZZZP020:ZZZP03
05EEE@3oool0000000@0ZZZZ00@000000:ZZZP2ZZZX000000P2ZZZX00`1EEED0oooo0?ooo`060?oo
o`X0dLfY203oool00`1EEED0ZZZZ0?ooo`020:ZZZP0605EEE@000000ZZZZ0?ooo`2ZZZX0EEEE102Z
ZZX01P1EEED0ZZZZ05EEE@1EEED0000005EEE@80oooo0P2ZZZX0103oool0EEEE0:ZZZP3oool20:ZZ
ZP040000003oool0ZZZZ05EEE@80oooo00H0ZZZZ0000003oool0EEEE0:ZZZP1EEED40:ZZZP0605EE
E@2ZZZX0oooo0:ZZZP000000EEEE0P2ZZZX20?ooo`0305EEE@3oool0oooo00H0oooo303AcJT000/0
dLfY2@3oool00`1EEED0000005EEE@020000000;0:ZZZP000000EEEE05EEE@2ZZZX0EEEE0:ZZZP00
0000ZZZZ0000002ZZZX00P1EEED20?ooo`80EEEE0P2ZZZX010000000EEEE05EEE@00000305EEE@03
0000002ZZZX0ZZZZ0080EEEE0P3oool205EEE@090:ZZZP000000ZZZZ0000002ZZZX0EEEE0:ZZZP3o
ool0EEEE0080ZZZZ00D000000:ZZZP1EEED0000005EEE@090?ooo`X0dLfY2@3oool01@000000EEEE
000000000000oooo0080ZZZZ00H0oooo05EEE@3oool000000:ZZZP1EEED20?ooo`030000001EEED0
oooo0080EEEE0P2ZZZX01@000000ZZZZ0000001EEED000000080oooo00D0000005EEE@000000ZZZZ
000000020:ZZZP0:0?ooo`1EEED0oooo05EEE@000000EEEE0?ooo`1EEED0oooo000000<0oooo00<0
EEEE0:ZZZP3oool00P00000205EEE@T0oooo2P3AcJT90?ooo`030000002ZZZX0000000<0EEEE00<0
ZZZZ0000003oool00P3oool00`1EEED0oooo00000004000000030:ZZZP1EEED0000000@0000000H0
EEEE0000003oool0EEEE0000001EEED50000000305EEE@2ZZZX0ZZZZ00@00000103oool00`1EEED0
00000:ZZZP0205EEE@80000000<0ZZZZ05EEE@3oool0203oool:0=7=Z@T0oooo00D0ZZZZ05EEE@3o
ool0oooo000000060:ZZZP030000001EEED0ZZZZ0080ZZZZ00D0EEEE00000000000000000:ZZZP02
0?ooo`030:ZZZP000000000000@0ZZZZ00L0oooo0000002ZZZX0EEEE0?ooo`2ZZZX0oooo00800000
00H0EEEE0:ZZZP2ZZZX0ZZZZ05EEE@0000060:ZZZP80000000<0oooo05EEE@1EEED02@3oool:0=7=
Z@T0oooo00<000000:ZZZP2ZZZX00P2ZZZX0203oool000000?ooo`2ZZZX0oooo0:ZZZP000000ZZZZ
101EEED01@000000ZZZZ05EEE@3oool0000000<0EEEE00H0ZZZZ0?ooo`2ZZZX0EEEE0?ooo`2ZZZX3
05EEE@050000003oool0oooo0:ZZZP0000000P1EEED02P000000EEEE0:ZZZP1EEED0ZZZZ0?ooo`1E
EED0oooo0000003oool40:ZZZP0305EEE@3oool0oooo00L0oooo303AcJT000/0dLfY2P3oool205EE
E@<000000P1EEED02@3oool000000:ZZZP000000EEEE0?ooo`1EEED0oooo05EEE@020?ooo`040000
003oool0oooo05EEE@80ZZZZ0P3oool0102ZZZX0oooo0?ooo`3oool20:ZZZP0305EEE@3oool0oooo
0080oooo00H0000005EEE@3oool0EEEE0?ooo`1EEED20:ZZZP040000002ZZZX0EEEE05EEE@<00000
0P1EEED:0?ooo`X0dLfY2P3oool01@1EEED0oooo0?ooo`1EEED0oooo00<0ZZZZ00D000000?ooo`2Z
ZZX000000?ooo`0605EEE@80000000T0oooo000000000000EEEE0000001EEED0ZZZZ0000001EEED0
0P0000001P1EEED000000000003oool0EEEE000000<0EEEE00X0oooo0000001EEED0oooo0000003o
ool0ZZZZ05EEE@3oool0EEEE0P3oool00`1EEED0oooo0?ooo`080?ooo`X0dLfY2P3oool01P1EEED0
000005EEE@1EEED0oooo0:ZZZPD0oooo0P00000305EEE@030000001EEED0EEEE0080EEEE0`000000
0`2ZZZX0000000000002000000030:ZZZP000000000000<0EEEE00<0ZZZZ05EEE@0000000`1EEED2
000000L0oooo00@0EEEE0:ZZZP000000EEEE2P3oool:0=7=Z@X0oooo00D0EEEE0:ZZZP1EEED0ZZZZ
0?ooo`050:ZZZP80EEEE00@0oooo0000003oool000000P2ZZZX00`000000ZZZZ0:ZZZP020:ZZZP03
0000002ZZZX0ZZZZ00@0ZZZZ00<000000:ZZZP3oool01@2ZZZX01@000000oooo0?ooo`3oool0EEEE
00D0ZZZZ00H0EEEE0?ooo`2ZZZX0EEEE0:ZZZP1EEED:0?ooo`X0dLfY2P3oool00`1EEED0oooo0:ZZ
ZP020?ooo`050:ZZZP3oool0ZZZZ05EEE@3oool00P1EEED0103oool0ZZZZ05EEE@1EEED20:ZZZP03
0?ooo`2ZZZX0000000@0EEEE00<0ZZZZ0?ooo`2ZZZX00P2ZZZX205EEE@030:ZZZP000000ZZZZ0080
ZZZZ101EEED0203oool0EEEE0:ZZZP3oool0EEEE0:ZZZP3oool0EEEE103oool00`1EEED0oooo0?oo
o`080?ooo``0dLfY000;0=7=Z@/0oooo101EEED20?ooo`80000000D0oooo0000002ZZZX0oooo05EE
E@020000000305EEE@3oool0EEEE0080000000`0EEEE0000003oool0ZZZZ0?ooo`2ZZZX0EEEE0?oo
o`1EEED0oooo0000001EEED2000000030:ZZZP3oool0ZZZZ0080000000P0EEEE0?ooo`2ZZZX0EEEE
0?ooo`000000EEEE0?ooo`D0EEEE2`3oool:0=7=Z@/0oooo00D0EEEE0?ooo`1EEED0oooo0:ZZZP02
000000060:ZZZP3oool0oooo0000002ZZZX0EEEE0P0000000`2ZZZX0oooo0?ooo`0205EEE@030?oo
o`000000ZZZZ0080ZZZZ0P1EEED01@2ZZZX0oooo0:ZZZP000000oooo0080EEEE0`3oool300000004
0:ZZZP000000EEEE0?ooo`80ZZZZ00H000000:ZZZP3oool0EEEE0:ZZZP1EEED;0?ooo`X0dLfY2`3o
ool00`1EEED0ZZZZ00000002000000D0oooo00<0000005EEE@3oool00P2ZZZX02`000000EEEE05EE
E@000000EEEE0000003oool0EEEE0:ZZZP1EEED0oooo0080EEEE00<0000005EEE@3oool00P1EEED0
10000000EEEE05EEE@3oool20:ZZZP030?ooo`1EEED0000000D0oooo100000000`1EEED0oooo0?oo
o`090?ooo`X0dLfY2`3oool0101EEED0000005EEE@0000050:ZZZP0305EEE@000000ZZZZ00800000
102ZZZX010000000oooo0?ooo`0000080:ZZZP040000003oool0oooo000000@0ZZZZ0P0000000`2Z
ZZX000000:ZZZP020:ZZZP0705EEE@2ZZZX0EEEE0000001EEED0ZZZZ05EEE@0;0?ooo`X0dLfY2`3o
ool01@1EEED0oooo0?ooo`3oool0ZZZZ00<0EEEE00@000000?ooo`2ZZZX0ZZZZ0P0000001@2ZZZX0
00000000003oool0EEEE0080ZZZZ00L0oooo0:ZZZP2ZZZX0oooo0:ZZZP1EEED0oooo0080ZZZZ00@0
oooo0:ZZZP2ZZZX0EEEE0`0000000`2ZZZX00000000000020:ZZZP030?ooo`000000EEEE0080EEEE
0`3oool00`000000EEEE0?ooo`0:0?ooo``0dLfY000;0=7=Z@`0oooo00@0EEEE0000001EEED0oooo
0P2ZZZX010000000EEEE05EEE@2ZZZX405EEE@80ZZZZ0`0000002P2ZZZX0000005EEE@1EEED0oooo
0000002ZZZX0oooo0000001EEED400000080ZZZZ0`1EEED0203oool0EEEE0:ZZZP000000EEEE0000
001EEED0ZZZZ0P1EEED00`000000EEEE0?ooo`0;0?ooo`X0dLfY303oool01P000000EEEE0000003o
ool000000:ZZZP80EEEE00<0ZZZZ0000003oool00P1EEED02P3oool0ZZZZ05EEE@2ZZZX0EEEE0000
002ZZZX000000?ooo`2ZZZX505EEE@060?ooo`00000000000000001EEED0oooo0P1EEED0103oool0
EEEE05EEE@3oool200000080EEEE00@0ZZZZ0000001EEED000000P1EEED<0?ooo`X0dLfY303oool0
0`000000ZZZZ0:ZZZP070:ZZZP<000000P3oool00`1EEED0oooo05EEE@0200000080oooo00H00000
0:ZZZP00000000000:ZZZP1EEED20?ooo`0705EEE@000000EEEE0?ooo`1EEED000000?ooo`030000
00H0ZZZZ00@000000:ZZZP2ZZZX0EEEE303oool:0=7=Z@`0oooo00P0ZZZZ05EEE@00000000000?oo
o`1EEED0ZZZZ0?ooo`80EEEE00<0ZZZZ0000002ZZZX0102ZZZX405EEE@P0ZZZZ00@0EEEE0000001E
EED0EEEE1`2ZZZX205EEE@030?ooo`2ZZZX0oooo0080oooo00<0000005EEE@1EEED0303oool:0=7=
Z@`0oooo00L0EEEE0:ZZZP1EEED0ZZZZ0?ooo`2ZZZX0oooo00@0ZZZZ00D0EEEE0:ZZZP2ZZZX0EEEE
0:ZZZP0205EEE@060000001EEED0oooo0000003oool000000P1EEED01`000000oooo0000003oool0
ZZZZ0000001EEED0202ZZZX01@000000ZZZZ0?ooo`2ZZZX0oooo0080EEEE00<0ZZZZ05EEE@3oool0
2`3oool<0=7=Z@002`3AcJT=0?ooo`80EEEE00<0000005EEE@2ZZZX0101EEED01@2ZZZX0oooo05EE
E@1EEED0oooo00<0EEEE00D0oooo05EEE@000000oooo0000000205EEE@090?ooo`1EEED000000?oo
o`000000EEEE0?ooo`1EEED0000000D0EEEE00<0ZZZZ05EEE@1EEED00P1EEED00`2ZZZX0EEEE0000
000205EEE@d0oooo2P3AcJT=0?ooo`0:05EEE@3oool0oooo0000002ZZZX000000?ooo`1EEED0oooo
05EEE@@0oooo00T000000:ZZZP1EEED0EEEE0:ZZZP1EEED0ZZZZ05EEE@3oool00P1EEED20?ooo`03
0:ZZZP1EEED0EEEE0080EEEE00<0ZZZZ0000000000000P3oool0202ZZZX0EEEE0?ooo`000000oooo
0000002ZZZX000000P3oool00`1EEED0oooo0?ooo`0;0?ooo`X0dLfY3@3oool0201EEED000000000
00000000EEEE0000001EEED000000P1EEED00`2ZZZX0000005EEE@06000000<0oooo00@0ZZZZ0?oo
o`3oool0ZZZZ0`3oool00`1EEED0000000000002000000040:ZZZP1EEED00000000000@0EEEE00H0
000005EEE@000000ZZZZ0000001EEED=0?ooo`X0dLfY3@3oool02@1EEED0ZZZZ0?ooo`000000EEEE
0000001EEED000000:ZZZP02000000080:ZZZP1EEED0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP00000205EE
E@030?ooo`1EEED0oooo00H0EEEE00L0ZZZZ05EEE@000000oooo0:ZZZP1EEED0ZZZZ0080000000T0
ZZZZ05EEE@1EEED000000?ooo`000000EEEE0:ZZZP1EEED03@3oool:0=7=Z@d0oooo00<0EEEE0000
002ZZZX00P2ZZZX20?ooo`80ZZZZ101EEED01P3oool000000000003oool0EEEE0:ZZZP<0oooo00D0
ZZZZ05EEE@1EEED0ZZZZ000000020?ooo`040:ZZZP1EEED0oooo0?ooo`8000000P1EEED0102ZZZX0
EEEE0:ZZZP0000030?ooo`80ZZZZ00<0000005EEE@3oool0303oool<0=7=Z@002`3AcJT>0?ooo`<0
EEEE00D0oooo05EEE@1EEED0EEEE0?ooo`0205EEE@040000001EEED0oooo0:ZZZP80EEEE00/00000
0:ZZZP000000EEEE0:ZZZP1EEED0oooo0:ZZZP1EEED0000005EEE@030000000305EEE@000000ZZZZ
0080EEEE0P0000000`1EEED0oooo0?ooo`0205EEE@040000001EEED0EEEE05EEE@h0oooo2P3AcJT>
0?ooo`0605EEE@3oool0EEEE0:ZZZP1EEED0ZZZZ0P0000001@2ZZZX0EEEE0000001EEED0oooo00<0
ZZZZ00@0oooo0:ZZZP000000EEEE0P2ZZZX02`3oool0ZZZZ0:ZZZP3oool0EEEE0000002ZZZX0oooo
0:ZZZP000000ZZZZ0080EEEE00H0000005EEE@2ZZZX000000?ooo`2ZZZX305EEE@030:ZZZP1EEED0
oooo00d0oooo2P3AcJT>0?ooo`0@05EEE@2ZZZX0ZZZZ0000001EEED0oooo05EEE@000000EEEE0:ZZ
ZP000000ZZZZ05EEE@3oool0EEEE0?ooo`8000000`3oool4000000<0oooo00P0ZZZZ0000003oool0
EEEE0?ooo`000000ZZZZ00000080EEEE00P000000?ooo`3oool0EEEE0000002ZZZX0000005EEE@h0
oooo2P3AcJT>0?ooo`0405EEE@00000000000:ZZZP<0EEEE102ZZZX0101EEED0000005EEE@2ZZZX2
0?ooo`80000000P0oooo0000002ZZZX0000005EEE@2ZZZX000000?ooo`8000000P3oool205EEE@04
0000001EEED0ZZZZ00000080ZZZZ0`1EEED2000000030:ZZZP1EEED0oooo00d0oooo2P3AcJT>0?oo
o`<0EEEE00D0ZZZZ0000002ZZZX0EEEE0?ooo`020:ZZZP050?ooo`2ZZZX0EEEE05EEE@0000000P2Z
ZZX01P1EEED0ZZZZ05EEE@3oool000000:ZZZP8000000P1EEED01P2ZZZX0oooo0:ZZZP2ZZZX0oooo
05EEE@80ZZZZ00@0oooo0:ZZZP2ZZZX0oooo0P2ZZZX00`000000EEEE05EEE@0205EEE@h0oooo303A
cJT000/0dLfY3`3oool0201EEED000000:ZZZP3oool0ZZZZ05EEE@3oool0ZZZZ101EEED00`2ZZZX0
000005EEE@0205EEE@070:ZZZP000000oooo05EEE@000000oooo05EEE@02000000030:ZZZP1EEED0
EEEE0080EEEE00H0ZZZZ0?ooo`1EEED0EEEE0000002ZZZX20?ooo`050:ZZZP3oool0EEEE0000001E
EED03`3oool:0=7=Z@l0oooo00D0000005EEE@00000000000?ooo`020:ZZZP<0EEEE00@0oooo05EE
E@2ZZZX0ZZZZ0P1EEED0203oool0EEEE05EEE@000000oooo0000001EEED0oooo0`1EEED01@000000
EEEE05EEE@1EEED0ZZZZ0080oooo0`1EEED00`2ZZZX0EEEE0?ooo`0200000080EEEE3`3oool:0=7=
Z@l0oooo00<000000:ZZZP1EEED00`3oool00`1EEED000000:ZZZP0205EEE@80oooo0`2ZZZX02000
0000oooo0?ooo`3oool000000?ooo`1EEED000000`3oool00`1EEED0ZZZZ0:ZZZP020?ooo`<0EEEE
0P0000001`1EEED0oooo0?ooo`3oool0EEEE0:ZZZP1EEED03`3oool:0=7=Z@l0oooo00@0ZZZZ05EE
E@2ZZZX0oooo0P2ZZZX01`3oool0EEEE05EEE@3oool0ZZZZ0000002ZZZX00P0000030:ZZZP<00000
00<0ZZZZ05EEE@0000000P0000001@2ZZZX000000:ZZZP000000EEEE00<0ZZZZ00<0oooo0:ZZZP1E
EED00P3oool00`2ZZZX0oooo05EEE@0205EEE@l0oooo2P3AcJTB0?ooo`<0EEEE00X000000?ooo`00
0000000005EEE@3oool0ZZZZ0000003oool00000101EEED01@3oool0EEEE05EEE@3oool000000080
EEEE0P0000001P3oool0ZZZZ0:ZZZP2ZZZX0EEEE00000080oooo00L0000005EEE@1EEED0EEEE0:ZZ
ZP3oool0EEEE00l0oooo303AcJT000/0dLfY403oool01P1EEED00000000000000000EEEE0:ZZZP80
EEEE00@0000005EEE@1EEED0oooo0P0000001@3oool0ZZZZ05EEE@1EEED0oooo0080000000<0oooo
0000001EEED00`1EEED01`3oool000000000003oool0000005EEE@0000000P1EEED0102ZZZX0EEEE
00000000000205EEEA00oooo2P3AcJT@0?ooo`0305EEE@3oool0oooo00<0EEEE0P3oool305EEE@05
0?ooo`1EEED0EEEE0000003oool00P1EEED01@3oool000000000003oool0000000@0EEEE00@00000
05EEE@1EEED0oooo101EEED0103oool0EEEE0?ooo`1EEED20?ooo`0305EEE@3oool0oooo00h0oooo
2P3AcJT@0?ooo`0805EEE@2ZZZX0ZZZZ0000002ZZZX000000:ZZZP3oool205EEE@030?ooo`1EEED0
ZZZZ0080ZZZZ1@1EEED00`3oool0EEEE05EEE@0405EEE@80ZZZZ1P1EEED01`2ZZZX000000:ZZZP00
0000ZZZZ0000001EEED0403oool:0=7=ZA00oooo0P1EEED01`000000oooo05EEE@2ZZZX0EEEE0000
002ZZZX00P0000001P2ZZZX000000:ZZZP3oool0000005EEE@80000000@0EEEE0?ooo`000000EEEE
0P0000001P1EEED0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP80000000T0ZZZZ0000001EEED0ZZZZ0000003o
ool000000:ZZZP1EEED0403oool:0=7=ZA00oooo00L0EEEE0:ZZZP1EEED0EEEE0:ZZZP000000ZZZZ
0080oooo00<0ZZZZ0000003oool00P3oool0302ZZZX000000000001EEED0oooo0:ZZZP3oool00000
0:ZZZP3oool0EEEE00000080ZZZZ00D0oooo0000003oool0oooo0:ZZZP020?ooo`030:ZZZP000000
EEEE00@0EEEE403oool<0=7=Z@002`3AcJTA0?ooo`<0EEEE00D0000005EEE@3oool0ZZZZ00000002
05EEE@@0000000D0EEEE0:ZZZP2ZZZX0ZZZZ05EEE@020000000505EEE@3oool0ZZZZ0:ZZZP1EEED0
1000000205EEE@030000003oool0oooo00D0EEEE4@3oool:0=7=ZA40oooo00<0ZZZZ0?ooo`1EEED0
0P2ZZZX20?ooo`80ZZZZ00D0oooo0:ZZZP00000000000?ooo`020:ZZZP050?ooo`2ZZZX0ZZZZ0?oo
o`1EEED00P2ZZZX0203oool0ZZZZ0:ZZZP3oool0000005EEE@2ZZZX0oooo0P2ZZZX01`1EEED0oooo
0:ZZZP3oool0EEEE0?ooo`1EEED04@3oool:0=7=ZA40oooo00<000000:ZZZP1EEED00P1EEED0102Z
ZZX000000000002ZZZX2000000<0EEEE00<0000005EEE@1EEED00P1EEED20000000305EEE@000000
EEEE00D0EEEE0P000000102ZZZX000000000002ZZZX305EEE@030:ZZZP1EEED0oooo0100oooo2P3A
cJTA0?ooo`050:ZZZP000000ZZZZ0:ZZZP1EEED01P2ZZZX01`000000oooo0?ooo`000000EEEE0:ZZ
ZP1EEED00P2ZZZX01@000000ZZZZ05EEE@2ZZZX0EEEE00<0oooo00<0EEEE0:ZZZP0000000P2ZZZX0
1`000000ZZZZ05EEE@000000ZZZZ0000001EEED04@3oool:0=7=ZA80oooo0140ZZZZ0?ooo`2ZZZX0
ZZZZ05EEE@000000EEEE0000002ZZZX0EEEE0?ooo`000000EEEE0000003oool0ZZZZ000000020:ZZ
ZP0805EEE@2ZZZX0ZZZZ0:ZZZP3oool0ZZZZ05EEE@00000205EEE@050:ZZZP000000EEEE0000001E
EED00P2ZZZX00`3oool0ZZZZ05EEE@0A0?ooo``0dLfY000;0=7=ZA80oooo0P1EEED20?ooo`030:ZZ
ZP1EEED0oooo0080EEEE00@0oooo05EEE@1EEED0oooo0P1EEED20000000405EEE@3oool0EEEE05EE
E@8000000P1EEED0103oool0EEEE0?ooo`3oool205EEE@040?ooo`1EEED0ZZZZ0?ooo`<0EEEE4P3o
ool:0=7=ZA80oooo0P1EEED20?ooo`8000000P3oool205EEE@<0ZZZZ00@0EEEE0000003oool0oooo
102ZZZX010000000oooo0000000000020:ZZZP<0EEEE0P3oool00`2ZZZX000000?ooo`0305EEEA80
oooo2P3AcJTB0?ooo`0305EEE@000000ZZZZ008000000`1EEED30?ooo`030000001EEED0oooo0080
oooo0P1EEED20000000405EEE@3oool0oooo0?ooo`80EEEE00@0000005EEE@3oool0oooo0`1EEED2
000000030:ZZZP000000EEEE0180oooo2P3AcJTB0?ooo`0405EEE@2ZZZX00000000000D0ZZZZ00H0
000005EEE@000000oooo0:ZZZP1EEED30?ooo`80EEEE0`3oool205EEE@040?ooo`00000000000000
00D0ZZZZ0P0000000`2ZZZX0EEEE0?ooo`0A0?ooo`X0dLfY4P3oool505EEE@<0ZZZZ00<0EEEE0?oo
o`2ZZZX00P2ZZZX305EEE@060000003oool0oooo0:ZZZP3oool000000P1EEED01P000000ZZZZ0:ZZ
ZP1EEED0oooo05EEE@80ZZZZ1P1EEEDB0?ooo``0dLfY000;0=7=ZA<0oooo00L0EEEE000000000000
EEEE0?ooo`1EEED0ZZZZ0080oooo00@000000:ZZZP3oool0oooo101EEED20?ooo`D0EEEE00@0oooo
0:ZZZP3oool0oooo0P2ZZZX0101EEED0oooo05EEE@00000205EEEA<0oooo2P3AcJTC0?ooo`0<05EE
E@3oool0oooo0000002ZZZX0EEEE0?ooo`2ZZZX0oooo05EEE@000000oooo0P1EEED00`3oool00000
00000003000000060:ZZZP3oool0EEEE05EEE@3oool000000P3oool01@2ZZZX0oooo05EEE@2ZZZX0
00000080oooo00<0EEEE0?ooo`3oool04@3oool:0=7=ZA<0oooo00H0EEEE0:ZZZP1EEED0EEEE0?oo
o`2ZZZX30?ooo`030:ZZZP1EEED0EEEE00@0000000@0EEEE0?ooo`1EEED0EEEE1000000205EEE@@0
oooo00H0ZZZZ0?ooo`1EEED0EEEE0000001EEEDC0?ooo`X0dLfY4`3oool305EEE@030:ZZZP1EEED0
ZZZZ00@0ZZZZ0P1EEED00`2ZZZX0oooo0?ooo`020?ooo`030:ZZZP3oool0oooo00<0oooo00@00000
05EEE@1EEED00000102ZZZX01@3oool0ZZZZ05EEE@2ZZZX0EEEE01<0oooo2P3AcJTC0?ooo`0605EE
E@3oool0ZZZZ0?ooo`1EEED0ZZZZ0`3oool00`2ZZZX0EEEE000000020?ooo`<0EEEE00T000000:ZZ
ZP1EEED0oooo05EEE@3oool0ZZZZ0000001EEED00P3oool00`1EEED0oooo0:ZZZP020?ooo`030:ZZ
ZP3oool0EEEE01<0oooo303AcJT000/0dLfY503oool305EEE@090000001EEED0EEEE05EEE@3oool0
EEEE0000003oool0EEEE00<0ZZZZ1@3oool20:ZZZP80oooo00@000000:ZZZP3oool0ZZZZ0P1EEED0
10000000EEEE05EEE@1EEEDD0?ooo`X0dLfY503oool02@2ZZZX0oooo05EEE@2ZZZX0EEEE0000003o
ool000000?ooo`0205EEE@060000001EEED000000?ooo`1EEED0oooo0`1EEED00`000000EEEE0000
000205EEE@040?ooo`000000EEEE000000<0EEEE00<0oooo05EEE@3oool04`3oool:0=7=ZA@0oooo
00<000000:ZZZP0000000P0000030?ooo`80000000<0EEEE0?ooo`1EEED00`1EEED20000000305EE
E@2ZZZX0EEEE00<0EEEE00<000000?ooo`3oool00P3oool3000000030:ZZZP1EEED0oooo01<0oooo
2P3AcJTD0?ooo`040:ZZZP000000EEEE05EEE@@0ZZZZ00@000000?ooo`00000000001@1EEED00`00
0000EEEE0000000205EEE@80000000@0oooo0:ZZZP2ZZZX0EEEE0P2ZZZX010000000EEEE0000001E
EEDD0?ooo`X0dLfY503oool02P000000oooo0?ooo`3oool0ZZZZ05EEE@000000oooo0000002ZZZX2
0000000?05EEE@000000oooo0?ooo`1EEED0ZZZZ0?ooo`1EEED0000005EEE@3oool000000:ZZZP1E
EED0oooo0080EEEE00D0ZZZZ0?ooo`3oool0oooo05EEE@0D0?ooo``0dLfY000;0=7=ZAD0oooo0P1E
EED03P3oool000000000001EEED000000:ZZZP1EEED0ZZZZ0?ooo`1EEED0ZZZZ0000003oool00000
0P3oool01P000000ZZZZ05EEE@1EEED0ZZZZ05EEE@80000000<0oooo0000000000000`1EEEDE0?oo
o`X0dLfY5@3oool205EEE@070?ooo`1EEED0EEEE0?ooo`1EEED0ZZZZ000000020:ZZZP80EEEE0P2Z
ZZX00`3oool0EEEE0:ZZZP0305EEE@80ZZZZ0P0000000`1EEED0000005EEE@0405EEEAD0oooo2P3A
cJTE0?ooo`0305EEE@000000EEEE00H0EEEE00<000000?ooo`1EEED00P0000000`1EEED0oooo0?oo
o`0205EEE@040000001EEED0EEEE000000H0EEEE00<0ZZZZ0000001EEED05@3oool:0=7=ZAD0oooo
00H0EEEE0:ZZZP2ZZZX000000:ZZZP0000020?ooo`0405EEE@00000000000:ZZZP80EEEE0P2ZZZX0
10000000ZZZZ0:ZZZP1EEED20:ZZZP060000001EEED0oooo0?ooo`000000ZZZZ0P0000000`2ZZZX0
EEEE0?ooo`0D0?ooo`X0dLfY5@3oool0101EEED0oooo0?ooo`2ZZZX205EEE@050:ZZZP3oool0oooo
0?ooo`2ZZZX00P1EEED0103oool0EEEE0000003oool405EEE@030000003oool0oooo0080ZZZZ0P1E
EED20:ZZZP030?ooo`1EEED0oooo01@0oooo303AcJT000/0dLfY5P3oool0101EEED0000000000000
000305EEE@80ZZZZ00D0000005EEE@1EEED0000005EEE@020000000505EEE@2ZZZX0EEEE05EEE@00
00000P2ZZZX205EEE@<000000P1EEEDF0?ooo`X0dLfY5P3oool00`1EEED0oooo0?ooo`0205EEE@03
0:ZZZP3oool0EEEE00D0EEEE00@0ZZZZ0000001EEED0ZZZZ0`1EEED01`2ZZZX0EEEE05EEE@000000
ZZZZ0?ooo`1EEED00P3oool00`1EEED0oooo0?ooo`0D0?ooo`X0dLfY5P3oool02@1EEED0ZZZZ0000
00000000EEEE0000001EEED0000005EEE@020?ooo`80EEEE103oool02@000000EEEE0?ooo`3oool0
EEEE0000001EEED0000005EEE@030000000305EEE@3oool0oooo01@0oooo2P3AcJTF0?ooo`80EEEE
00H0oooo0000001EEED0000005EEE@0000020:ZZZP040000003oool0oooo00000080ZZZZ0P000000
303oool000000:ZZZP2ZZZX0000005EEE@000000oooo0000003oool0ZZZZ05EEEAH0oooo2P3AcJTF
0?ooo`0305EEE@2ZZZX0ZZZZ0080ZZZZ00@0oooo0:ZZZP1EEED0EEEE0P2ZZZX01P3oool0EEEE0000
003oool0EEEE00000080oooo0P2ZZZX305EEE@80oooo0P2ZZZX00`000000EEEE0?ooo`0E0?ooo``0
dLfY000;0=7=ZAL0oooo0P1EEED00`000000EEEE0?ooo`0205EEE@80ZZZZ00@0000005EEE@000000
oooo0P0000000`3oool0EEEE05EEE@02000000070:ZZZP1EEED0ZZZZ0?ooo`1EEED0000005EEE@0H
0?ooo`X0dLfY5`3oool01P1EEED0000005EEE@1EEED0oooo0:ZZZP80000000<0EEEE0?ooo`1EEED0
0P1EEED01`2ZZZX0000005EEE@3oool0EEEE0?ooo`1EEED00`000000103oool0000005EEE@00000H
0?ooo`X0dLfY5`3oool0101EEED000000:ZZZP1EEED30?ooo`0405EEE@3oool0EEEE05EEE@H0oooo
0P1EEED00`000000EEEE0?ooo`020?ooo`0305EEE@2ZZZX0000001P0oooo2P3AcJTG0?ooo`0405EE
E@2ZZZX0EEEE0:ZZZP80oooo00<0ZZZZ0?ooo`2ZZZX01`2ZZZX01@000000ZZZZ0:ZZZP1EEED0oooo
0080ZZZZ00@0oooo05EEE@1EEED0ZZZZ603oool:0=7=ZAL0oooo00@0EEEE0?ooo`3oool0oooo0P1E
EED20?ooo`80EEEE00<000000:ZZZP3oool0103oool00`000000EEEE05EEE@020?ooo`80EEEE00<0
ZZZZ0?ooo`3oool0603oool<0=7=Z@002`3AcJTH0?ooo`80EEEE0P3oool205EEE@80000000<0EEEE
0:ZZZP1EEED0100000020:ZZZP0605EEE@3oool0000005EEE@000000oooo0`1EEEDH0?ooo`X0dLfY
603oool205EEE@80oooo0P2ZZZX01@1EEED0000005EEE@1EEED000000080ZZZZ00<0EEEE0:ZZZP1E
EED00P1EEED01@2ZZZX0EEEE0:ZZZP000000oooo00<0EEEE603oool:0=7=ZAP0oooo00<0EEEE0000
00000000100000000`3oool0EEEE0?ooo`070?ooo`0305EEE@2ZZZX0000000<0000000<0ZZZZ0000
001EEED0603oool:0=7=ZAP0oooo00<0EEEE0:ZZZP1EEED00P0000001@1EEED000000:ZZZP3oool0
000000H0ZZZZ00@000000?ooo`1EEED000000P1EEED2000000030:ZZZP1EEED0oooo01L0oooo2P3A
cJTH0?ooo`0305EEE@000000oooo00@0oooo00H0ZZZZ0?ooo`2ZZZX0ZZZZ05EEE@2ZZZX205EEE@03
0000002ZZZX0oooo00<0oooo00D0ZZZZ0?ooo`3oool0000005EEE@0H0?ooo``0dLfY000;0=7=ZAT0
oooo00<0EEEE0000000000000P2ZZZX01P1EEED000000000002ZZZX000000?ooo`80000000<0oooo
0:ZZZP2ZZZX00P000000101EEED0ZZZZ05EEE@00000205EEEAT0oooo2P3AcJTI0?ooo`0305EEE@3o
ool0oooo0080ZZZZ00@000000?ooo`1EEED0oooo0P1EEED00`000000ZZZZ05EEE@020?ooo`80EEEE
00<000000:ZZZP0000000P3oool00`1EEED0oooo0?ooo`0G0?ooo`X0dLfY6@3oool00`1EEED0ZZZZ
0:ZZZP020:ZZZP030000001EEED0oooo00T0oooo00L0ZZZZ0000002ZZZX000000:ZZZP000000EEEE
01T0oooo2P3AcJTI0?ooo`80EEEE0P000000101EEED0ZZZZ0000000000080:ZZZP080000001EEED0
ZZZZ05EEE@3oool000000:ZZZP1EEEDI0?ooo`X0dLfY6@3oool0201EEED0ZZZZ05EEE@1EEED0ZZZZ
05EEE@2ZZZX000000P2ZZZX01`3oool0ZZZZ0:ZZZP3oool0EEEE0:ZZZP0000000P1EEED00`2ZZZX0
EEEE05EEE@0205EEEAT0oooo303AcJT000/0dLfY6P3oool305EEE@050:ZZZP3oool0ZZZZ05EEE@2Z
ZZX01@0000020:ZZZP0605EEE@2ZZZX0oooo0:ZZZP000000EEEE6`3oool:0=7=ZAX0oooo00<0EEEE
0000000000000P00000205EEE@030?ooo`1EEED0EEEE0080oooo00D0EEEE0?ooo`3oool0EEEE0?oo
o`020000000305EEE@000000oooo01X0oooo2P3AcJTJ0?ooo`0405EEE@000000000000000080EEEE
0P2ZZZX00`3oool0EEEE0?ooo`0205EEE@030000002ZZZX0ZZZZ0080EEEE00<000000:ZZZP000000
6`3oool:0=7=ZAX0oooo00D0EEEE0:ZZZP3oool000000?ooo`040:ZZZP0405EEE@2ZZZX0oooo05EE
E@<0ZZZZ00D000000?ooo`000000EEEE0:ZZZP0K0?ooo`X0dLfY6P3oool00`1EEED000000:ZZZP02
0:ZZZP040000001EEED0EEEE0:ZZZP80oooo00<0ZZZZ0?ooo`1EEED00P1EEED40:ZZZP030000003o
ool0oooo01T0oooo303AcJT000/0dLfY6`3oool205EEE@050?ooo`000000EEEE0000001EEED01@00
00001P3oool0EEEE0000003oool000000?ooo`80EEEE6`3oool:0=7=ZA/0oooo0P1EEED01P3oool0
EEEE0000002ZZZX0EEEE0:ZZZPD0oooo00D0EEEE0:ZZZP1EEED0EEEE0?ooo`0205EEEA/0oooo2P3A
cJTK0?ooo`0405EEE@2ZZZX0ZZZZ000000<0EEEE00D0oooo0:ZZZP3oool0oooo0:ZZZP0305EEE@80
000000<0ZZZZ0000001EEED06`3oool:0=7=ZA/0oooo00@0EEEE0000000000000000102ZZZX205EE
E@030000001EEED0ZZZZ00<0ZZZZ0P0000000`2ZZZX0EEEE0?ooo`0J0?ooo`X0dLfY6`3oool505EE
E@80oooo0P2ZZZX0101EEED000000:ZZZP2ZZZX20?ooo`D0EEEE6`3oool<0=7=Z@002`3AcJTL0?oo
o`@0EEEE00<0000005EEE@1EEED01P1EEED010000000EEEE05EEE@1EEEDM0?ooo`X0dLfY703oool0
101EEED0ZZZZ0?ooo`3oool30:ZZZP0305EEE@2ZZZX0EEEE0080EEEE0P2ZZZX00`1EEED0oooo0:ZZ
ZP0M0?ooo`X0dLfY703oool00`1EEED000000:ZZZP03000000060?ooo`000000oooo05EEE@000000
oooo0`0000000`2ZZZX000000?ooo`0L0?ooo`X0dLfY703oool01`1EEED0ZZZZ000000000000EEEE
0:ZZZP1EEED00P2ZZZX010000000ZZZZ0:ZZZP2ZZZX205EEE@030000002ZZZX0oooo01`0oooo2P3A
cJTL0?ooo`0305EEE@000000oooo0080oooo0`2ZZZX205EEE@030:ZZZP000000ZZZZ00<0oooo00<0
00000?ooo`3oool06`3oool<0=7=Z@002`3AcJTM0?ooo`D0EEEE00<0oooo05EEE@0000000P1EEED0
103oool0EEEE05EEE@00000205EEEAd0oooo2P3AcJTM0?ooo`0505EEE@000000000005EEE@3oool0
0P0000001@2ZZZX0EEEE000000000000oooo0080EEEE00<0000005EEE@3oool0703oool:0=7=ZAd0
oooo00@0EEEE0000002ZZZX000000`2ZZZX2000000<0ZZZZ00@000000:ZZZP000000EEEE7@3oool:
0=7=ZAd0oooo00H0EEEE0:ZZZP000000oooo0000003oool205EEE@080:ZZZP1EEED0oooo0000003o
ool0EEEE0:ZZZP1EEEDM0?ooo`X0dLfY7@3oool405EEE@040:ZZZP00000000000:ZZZP80000000@0
oooo0:ZZZP1EEED0ZZZZ0P1EEEDM0?ooo``0dLfY000;0=7=ZAh0oooo0P1EEED20?ooo`0605EEE@3o
ool0EEEE05EEE@3oool0ZZZZ0P3oool205EEEAh0oooo2P3AcJTN0?ooo`80EEEE0P3oool01P2ZZZX0
oooo000000000000oooo00000080oooo0P1EEEDN0?ooo`X0dLfY7P3oool00`1EEED0ZZZZ05EEE@03
05EEE@030?ooo`1EEED0EEEE00<0EEEE00<0000005EEE@3oool07@3oool:0=7=ZAh0oooo00<0EEEE
0000002ZZZX00`0000001@2ZZZX0oooo0000002ZZZX000000080ZZZZ00<0EEEE0?ooo`3oool0703o
ool:0=7=ZAh0oooo00H0EEEE0:ZZZP3oool0ZZZZ05EEE@3oool205EEE@030?ooo`1EEED0ZZZZ0080
oooo00<0EEEE0?ooo`3oool0703oool<0=7=Z@002`3AcJTO0?ooo`<0EEEE0`0000000`1EEED00000
05EEE@0205EEEB00oooo2P3AcJTO0?ooo`0505EEE@2ZZZX0oooo05EEE@2ZZZX00P1EEED0102ZZZX0
EEEE0?ooo`2ZZZXP0?ooo`X0dLfY7`3oool00`1EEED000000:ZZZP02000000030?ooo`1EEED00000
0080ZZZZ00<000000?ooo`3oool07P3oool:0=7=ZAl0oooo00D0EEEE0:ZZZP00000000000:ZZZP02
05EEE@040:ZZZP00000000000:ZZZR00oooo2P3AcJTO0?ooo`@0EEEE00@0ZZZZ05EEE@1EEED0ZZZZ
0`1EEEDP0?ooo``0dLfY000;0=7=ZB00oooo0`1EEED01@2ZZZX000000000002ZZZX000000080EEEE
803oool:0=7=ZB00oooo00D0EEEE000000000000000005EEE@020000000305EEE@000000EEEE0200
oooo2P3AcJTP0?ooo`0405EEE@000000EEEE05EEE@80oooo00@0EEEE0:ZZZP000000EEEE803oool:
0=7=ZB00oooo00<0EEEE0:ZZZP1EEED00P2ZZZX01@3oool0ZZZZ05EEE@2ZZZX0EEEE0200oooo2P3A
cJTP0?ooo`0505EEE@3oool0ZZZZ0:ZZZP3oool00P2ZZZX20?ooo`0305EEE@3oool0oooo01h0oooo
303AcJT000/0dLfY8@3oool205EEE@040?ooo`00000000000?ooo`80EEEE8@3oool:0=7=ZB40oooo
0P1EEED0103oool0EEEE05EEE@3oool205EEEB40oooo2P3AcJTQ0?ooo`0305EEE@2ZZZX0000000@0
000000<0EEEE0?ooo`3oool07`3oool:0=7=ZB40oooo00P0EEEE0000001EEED0EEEE0000001EEED0
ZZZZ05EEEB40oooo2P3AcJTQ0?ooo`0305EEE@3oool000000080oooo0P0000000`1EEED0oooo0?oo
o`0O0?ooo``0dLfY000;0=7=ZB80oooo1@1EEEDS0?ooo`X0dLfY8P3oool01@1EEED0ZZZZ05EEE@3o
ool0ZZZZ02<0oooo2P3AcJTR0?ooo`0505EEE@000000EEEE0:ZZZP0000008`3oool:0=7=ZB80oooo
00D0EEEE0:ZZZP2ZZZX000000:ZZZP0S0?ooo`X0dLfY8P3oool0101EEED0oooo05EEE@2ZZZXT0?oo
o``0dLfY000;0=7=ZB<0oooo00@0EEEE0000001EEED0EEEE8`3oool:0=7=ZB<0oooo0P1EEED00`00
0000EEEE0?ooo`0R0?ooo`X0dLfY8`3oool0101EEED0ZZZZ0000001EEEDS0?ooo`X0dLfY8`3oool2
05EEE@030:ZZZP1EEED0oooo0280oooo2P3AcJTS0?ooo`0405EEE@2ZZZX0000005EEEB<0oooo303A
cJT000/0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S
0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S
0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo``0dLfY003o0=7=ZK80dLfY003o0=7=ZK80
dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY000;0=7=Z@060?ooo`1EEED0ZZZZ
0:ZZZP1EEED0oooo0P2ZZZX0103oool000000000001EEED20000000305EEE@3oool0oooo00<0EEEE
00<0ZZZZ0?ooo`1EEED00`3oool0101EEED0oooo05EEE@1EEED20?ooo`80ZZZZ00<0000005EEE@3o
ool00P1EEED00`3oool0ZZZZ0:ZZZP020?ooo`80EEEE00P0oooo05EEE@3oool0oooo0:ZZZP1EEED0
oooo0:ZZZP80EEEE00D0ZZZZ0?ooo`1EEED0EEEE0000000205EEE@80000000@0oooo0:ZZZP2ZZZX0
oooo0`2ZZZX00`1EEED0oooo0=7=Z@090=7=Z@0B0?ooo`1EEED0EEEE0?ooo`1EEED0oooo05EEE@3o
ool0EEEE0000002ZZZX0oooo0:ZZZP1EEED0oooo05EEE@3oool0EEEE103oool405EEE@@0oooo00<0
EEEE0000003oool0201EEED01`3oool0000005EEE@3oool000000?ooo`2ZZZX0101EEED02@3oool0
EEEE0?ooo`3oool0EEEE0?ooo`1EEED0oooo05EEE@020?ooo`080:ZZZP000000EEEE0?ooo`000000
oooo0:ZZZP3oool205EEE@030?ooo`3AcJT0dLfY00P0dLfY00<0oooo05EEE@0000000P0000001@2Z
ZZX0oooo0?ooo`3oool0ZZZZ0080EEEE00@000000:ZZZP00000000000P1EEED00`000000EEEE0000
000205EEE@0;0:ZZZP1EEED0oooo0:ZZZP1EEED000000?ooo`000000ZZZZ0000002ZZZX00P1EEED0
3@000000oooo05EEE@1EEED0ZZZZ0000002ZZZX000000?ooo`2ZZZX0EEEE0000003oool0101EEED0
1@2ZZZX0EEEE000000000000EEEE0080000000D0ZZZZ0?ooo`1EEED0EEEE0:ZZZP020?ooo`80ZZZZ
0`0000000`1EEED0oooo0=7=Z@090=7=Z@040?ooo`1EEED0ZZZZ000000<0EEEE00<0oooo00000000
00000P0000000`1EEED0ZZZZ0:ZZZP040:ZZZP0305EEE@00000000000080000000<0EEEE0:ZZZP2Z
ZZX0102ZZZX;000000030?ooo`2ZZZX0ZZZZ00@0ZZZZ00@0EEEE00000000000000000P1EEED60:ZZ
ZPD0000000P0oooo05EEE@1EEED0oooo0000002ZZZX0EEEE0?ooo`X0dLfY00<0oooo05EEE@1EEED0
0`3oool305EEE@030:ZZZP1EEED0oooo0080EEEE00<0ZZZZ0?ooo`3oool0103oool205EEE@030000
002ZZZX0EEEE0080EEEE00P0ZZZZ05EEE@2ZZZX0EEEE0:ZZZP000000ZZZZ05EEE@80oooo00<0EEEE
0000000000000`2ZZZX00`1EEED0ZZZZ05EEE@0205EEE@80ZZZZ0P1EEED50?ooo`80ZZZZ0P1EEED0
0`3oool0EEEE0:ZZZP0205EEE@040:ZZZP3oool0oooo0?ooo`80EEEE00<0oooo0=7=Z@3AcJT02P3A
cJT000/0dLfY00D0oooo0:ZZZP3oool0ZZZZ0?ooo`0200000080EEEE00H0oooo05EEE@2ZZZX0EEEE
0?ooo`2ZZZX20?ooo`80EEEE103oool00`2ZZZX0000005EEE@0205EEE@040?ooo`1EEED0EEEE0:ZZ
ZP80000000H0EEEE0?ooo`1EEED0EEEE0?ooo`2ZZZX2000000D0EEEE00@0oooo05EEE@000000ZZZZ
0P3oool00`1EEED0oooo05EEE@030?ooo`060:ZZZP3oool0ZZZZ0:ZZZP1EEED0ZZZZ0`1EEED00`00
0000ZZZZ0:ZZZP030?ooo`X0dLfY00@0oooo0:ZZZP3oool0oooo0P1EEED30?ooo`0405EEE@3oool0
oooo0?ooo`80EEEE00@000000?ooo`1EEED0EEEE0P2ZZZX505EEE@80oooo00@0000005EEE@1EEED0
ZZZZ2P1EEED00`3oool0EEEE05EEE@030?ooo`H0EEEE00D0ZZZZ05EEE@1EEED0oooo0:ZZZP0205EE
E@<0oooo00D0ZZZZ0?ooo`3oool0ZZZZ05EEE@050?ooo`X0dLfY00H0oooo0:ZZZP000000EEEE0?oo
o`1EEED30?ooo`0405EEE@00000000000:ZZZP@0EEEE00<0ZZZZ0000001EEED00P3oool0102ZZZX0
oooo05EEE@1EEED20:ZZZP80EEEE00@000000:ZZZP3oool0EEEE0P00000205EEE@80000000@0EEEE
0?ooo`2ZZZX000000P1EEED02`2ZZZX0000005EEE@1EEED000000:ZZZP3oool0000005EEE@000000
oooo00@0EEEE0`0000040?ooo`0405EEE@2ZZZX0EEEE00000080oooo2P3AcJT0103oool0ZZZZ0?oo
o`2ZZZX405EEE@@0ZZZZ00<0EEEE0000000000000`0000000`2ZZZX000000:ZZZP030:ZZZP0305EE
E@000000000000<0000000<0EEEE0:ZZZP2ZZZX02@2ZZZX205EEE@D0000000L0EEEE0:ZZZP2ZZZX0
ZZZZ05EEE@000000ZZZZ00D000001@2ZZZX405EEE@040:ZZZP3oool0oooo0?ooo`X0dLfY0100oooo
05EEE@3oool000000?ooo`000000ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP1EEED0oooo05EEE@3oool0EEEE
0`00000205EEE@0;0000003oool0EEEE05EEE@3oool0EEEE0?ooo`2ZZZX0oooo0:ZZZP3oool00`1E
EED40?ooo`<0EEEE00@000000:ZZZP3oool000000`3oool205EEE@040?ooo`000000000005EEE@<0
000000D0EEEE0?ooo`1EEED0oooo05EEE@030:ZZZP80oooo00<000000?ooo`0000000`3oool<0=7=
Z@002`3AcJT30?ooo`0:0:ZZZP3oool0EEEE05EEE@3oool0EEEE0:ZZZP000000EEEE00000080oooo
00D000000?ooo`00000000000:ZZZP020?ooo`060000001EEED0EEEE0?ooo`1EEED0ZZZZ0P000000
1@2ZZZX0000005EEE@000000EEEE0080ZZZZ00@000000:ZZZP1EEED000000P1EEED0102ZZZX00000
0000002ZZZX20?ooo`0305EEE@2ZZZX000000080oooo00D0ZZZZ0000002ZZZX0oooo0:ZZZP020?oo
o`80EEEE00D0000005EEE@1EEED0oooo0000000205EEE@040:ZZZP3oool0oooo0?ooo`X0dLfY0`3o
ool00`2ZZZX0EEEE05EEE@020000000305EEE@000000oooo0080ZZZZ00<0EEEE0?ooo`3oool00P1E
EED00`3oool000000:ZZZP0605EEE@050:ZZZP3oool0oooo05EEE@3oool02P1EEED01P000000EEEE
0?ooo`3oool0ZZZZ0?ooo`80EEEE00H0oooo05EEE@1EEED0ZZZZ0000003oool205EEE@80oooo0P1E
EED01@2ZZZX0oooo0000001EEED0000000<0EEEE00@0ZZZZ0?ooo`3oool0oooo2P3AcJT30?ooo`06
0:ZZZP3oool0EEEE0:ZZZP1EEED0oooo101EEED50:ZZZP080000002ZZZX0EEEE0?ooo`1EEED0ZZZZ
0000001EEED200000080oooo00@000000:ZZZP1EEED0ZZZZ1@1EEED01P000000ZZZZ05EEE@2ZZZX0
00000?ooo`80000000<0ZZZZ05EEE@0000000P1EEED0103oool0ZZZZ0:ZZZP0000050:ZZZP080000
001EEED0EEEE05EEE@3oool0EEEE0:ZZZP1EEED20:ZZZP<0oooo2P3AcJT30?ooo`060:ZZZP3oool0
EEEE0?ooo`000000oooo0`2ZZZX00`1EEED000000000000300000080EEEE102ZZZX00`1EEED00000
00000004000000/0ZZZZ00<0oooo000000000000100000000`1EEED0ZZZZ0:ZZZP020:ZZZP80EEEE
1@0000040:ZZZP060?ooo`000000EEEE05EEE@000000ZZZZ0`3oool:0=7=Z@<0oooo0`1EEED20?oo
o`0405EEE@3oool0oooo0:ZZZP8000000P1EEED0103oool0EEEE0?ooo`3oool205EEE@<0oooo0P2Z
ZZX205EEE@070?ooo`2ZZZX000000:ZZZP1EEED0oooo000000020?ooo`030000003oool0EEEE00<0
ZZZZ00D0oooo05EEE@1EEED0EEEE0:ZZZP030?ooo`80EEEE1@3oool01@1EEED0000005EEE@2ZZZX0
oooo0080EEEE0P3oool305EEE@<0oooo303AcJT000/0dLfY103oool00`1EEED0ZZZZ0:ZZZP0305EE
E@030?ooo`2ZZZX0oooo0080oooo00<0EEEE0:ZZZP0000000P00000205EEE@80ZZZZ0`3oool40:ZZ
ZP030000003oool0ZZZZ0080ZZZZ00D0EEEE0?ooo`2ZZZX0EEEE0:ZZZP020?ooo`@0ZZZZ103oool0
0`2ZZZX0EEEE0:ZZZP03000000060:ZZZP3oool0oooo0?ooo`000000ZZZZ0P3oool205EEE@80ZZZZ
00<0EEEE0?ooo`3oool00P3oool:0=7=Z@@0oooo0`1EEED0102ZZZX0oooo0000003oool205EEE@04
0?ooo`1EEED0EEEE0?ooo`80EEEE0`2ZZZX205EEE@030:ZZZP000000EEEE00@0oooo2`1EEED00`2Z
ZZX0oooo0?ooo`020?ooo`0805EEE@000000ZZZZ0:ZZZP1EEED0ZZZZ0?ooo`2ZZZX205EEE@030?oo
o`000000EEEE0080oooo00H0EEEE0?ooo`3oool0oooo0:ZZZP3oool205EEE@@0oooo2P3AcJT40?oo
o`030000001EEED0oooo0080EEEE0`0000020:ZZZP090000002ZZZX000000:ZZZP000000EEEE0000
002ZZZX0000000<0ZZZZ0`1EEED01@000000EEEE05EEE@1EEED0oooo0080000000T0EEEE00000000
000000000?ooo`1EEED0ZZZZ05EEE@0000000`1EEED20:ZZZP0<0?ooo`000000ZZZZ0?ooo`1EEED0
00000:ZZZP000000ZZZZ0000002ZZZX0EEEE0`00000205EEE@030000001EEED0EEEE00@0oooo2P3A
cJT40?ooo`0905EEE@2ZZZX0EEEE0?ooo`1EEED000000:ZZZP000000EEEE00D0ZZZZ00<0EEEE0000
000000000`0000000`1EEED0ZZZZ0:ZZZP040:ZZZP0305EEE@000000000000P0000000<0EEEE0:ZZ
ZP2ZZZX0102ZZZX01`1EEED00000000000000000ZZZZ0000001EEED01@2ZZZX2000000070:ZZZP00
0000EEEE0?ooo`000000ZZZZ05EEE@040?ooo`X0dLfY1@3oool2000000<0EEEE00L0oooo0:ZZZP2Z
ZZX0EEEE0000003oool0EEEE00<0oooo00/0EEEE0?ooo`3oool0oooo0000003oool0ZZZZ05EEE@2Z
ZZX0EEEE0?ooo`0205EEE@80oooo100000020?ooo`80EEEE00L0oooo05EEE@1EEED0EEEE0:ZZZP3o
ool0000000H0oooo00T0ZZZZ05EEE@3oool0000005EEE@000000ZZZZ0?ooo`2ZZZX00`1EEED00`00
0000EEEE0?ooo`030?ooo``0dLfY000;0=7=Z@@0oooo00L0ZZZZ0?ooo`2ZZZX0oooo0000002ZZZX0
EEEE0080000000<0oooo05EEE@3oool0102ZZZX00`3oool000000:ZZZP0505EEE@030000002ZZZX0
000000<0oooo00H0EEEE0000003oool0EEEE0000001EEED20?ooo`80000000<0ZZZZ0000001EEED0
0`1EEED00`000000ZZZZ000000050:ZZZP030000001EEED0oooo0080000000D0EEEE0:ZZZP000000
oooo0:ZZZP060?ooo`X0dLfY103oool00`2ZZZX0oooo0?ooo`020:ZZZP80000000<0ZZZZ05EEE@1E
EED00P2ZZZX305EEE@80oooo00@0EEEE0?ooo`3oool0EEEE1P3oool;05EEE@D0oooo00H0ZZZZ0?oo
o`1EEED0EEEE0?ooo`1EEED20?ooo`<0EEEE0P2ZZZX205EEE@030:ZZZP00000000000080ZZZZ1`3o
ool:0=7=Z@@0oooo00<0ZZZZ05EEE@0000000P0000020?ooo`080000001EEED0oooo0?ooo`1EEED0
oooo0:ZZZP00000205EEE@030:ZZZP1EEED0EEEE0080oooo00@0EEEE0?ooo`1EEED0oooo0P2ZZZX2
0?ooo`040000003oool00000000000@0oooo00H000000:ZZZP3oool0EEEE0?ooo`1EEED20?ooo`09
0000001EEED0ZZZZ0000001EEED000000:ZZZP3oool000000080oooo0P0000001P3oool000000000
00000000ZZZZ05EEE@D0oooo2P3AcJT40?ooo`040:ZZZP3oool0EEEE00000080oooo0P2ZZZX00`1E
EED0000000000004000000030?ooo`2ZZZX0ZZZZ0080ZZZZ00<0EEEE0000000000000`0000000`2Z
ZZX0EEEE0:ZZZP090:ZZZP030000002ZZZX0000000@0000000<0EEEE0:ZZZP2ZZZX00P2ZZZX00`3o
ool0000000000004000000<0ZZZZ00@000000?ooo`000000ZZZZ1P3oool:0=7=Z@@0oooo00<0EEEE
0:ZZZP2ZZZX00P1EEED01P2ZZZX0oooo05EEE@1EEED0oooo00000080EEEE102ZZZX3000000030:ZZ
ZP1EEED0EEEE0080EEEE00D0ZZZZ05EEE@3oool0EEEE0000000505EEE@80000000<0EEEE0?ooo`1E
EED00P2ZZZX0101EEED0oooo05EEE@2ZZZX3000000@0ZZZZ00@0EEEE000000000000oooo0P1EEED0
1P3oool0ZZZZ05EEE@1EEED000000:ZZZPD0oooo303AcJT000/0dLfY1P3oool01@1EEED0oooo05EE
E@1EEED000000080ZZZZ00H0000005EEE@3oool0ZZZZ0?ooo`1EEED20:ZZZP0505EEE@000000EEEE
05EEE@3oool00P1EEED00`000000EEEE000000040:ZZZP050000003oool000000000003oool00P2Z
ZZX01@3oool0000005EEE@000000EEEE0080oooo00@0EEEE000000000000EEEE0P2ZZZX205EEE@04
0:ZZZP3oool0EEEE00000080ZZZZ0P0000000`1EEED0oooo0:ZZZP060?ooo`X0dLfY1P3oool305EE
E@80000000<0EEEE0?ooo`1EEED00P1EEED20:ZZZP030000002ZZZX0oooo0080EEEE00P0oooo0:ZZ
ZP1EEED0EEEE0:ZZZP000000oooo0:ZZZP`0EEEE00@0ZZZZ0?ooo`3oool0ZZZZ0P1EEED20:ZZZP<0
EEEE00D0ZZZZ0000001EEED0ZZZZ0000000405EEE@8000000P1EEED00`2ZZZX0oooo0?ooo`040?oo
o`X0dLfY1P3oool020000000ZZZZ05EEE@1EEED000000:ZZZP1EEED000000P2ZZZX00`1EEED00000
0:ZZZP0205EEE@<0oooo00T0000005EEE@3oool0000005EEE@2ZZZX000000:ZZZP3oool00P1EEED4
000000060:ZZZP1EEED0oooo0:ZZZP000000ZZZZ0P0000000`2ZZZX0EEEE000000040?ooo`0405EE
E@2ZZZX0000005EEE@80ZZZZ00H000000:ZZZP2ZZZX000000:ZZZP1EEED20:ZZZPH0oooo2P3AcJT6
0?ooo`090000003oool0EEEE0?ooo`2ZZZX0oooo05EEE@000000ZZZZ00<0000000<0ZZZZ0000002Z
ZZX00`2ZZZX00`1EEED00000000000030000000305EEE@2ZZZX0ZZZZ00T0ZZZZ0P1EEED500000007
05EEE@2ZZZX0ZZZZ0:ZZZP1EEED000000:ZZZP03000000090:ZZZP000000EEEE0?ooo`2ZZZX00000
05EEE@3oool0ZZZZ00H0oooo2P3AcJT70?ooo`0D0000003oool0EEEE0?ooo`2ZZZX0oooo0000002Z
ZZX0EEEE0?ooo`1EEED0ZZZZ05EEE@000000oooo05EEE@3oool0EEEE0?ooo`1EEED20?ooo`0405EE
E@2ZZZX000000?ooo`80EEEE00@0ZZZZ05EEE@3oool0ZZZZ0P1EEED0103oool0EEEE0:ZZZP1EEED2
0?ooo`060:ZZZP3oool0EEEE0?ooo`1EEED0oooo0P1EEED01@2ZZZX0oooo0?ooo`1EEED0ZZZZ0080
000000H0ZZZZ0?ooo`3oool0oooo0000001EEED60?ooo``0dLfY000;0=7=Z@H0oooo0P1EEED20:ZZ
ZP0405EEE@3oool0EEEE0?ooo`<0ZZZZ0P3oool0102ZZZX0oooo0:ZZZP3oool20:ZZZP0905EEE@2Z
ZZX0ZZZZ0?ooo`2ZZZX0oooo0000001EEED0000000<0oooo00@000000?ooo`1EEED000000P1EEED0
103oool0ZZZZ05EEE@2ZZZX205EEE@030:ZZZP1EEED0oooo00<0ZZZZ0P3oool00`2ZZZX000000:ZZ
ZP030?ooo`0405EEE@2ZZZX0ZZZZ05EEE@L0oooo2P3AcJT60?ooo`<0EEEE00L0ZZZZ05EEE@3oool0
EEEE0000002ZZZX0oooo0080EEEE00<0oooo0:ZZZP1EEED00P1EEED20?ooo`0505EEE@3oool0EEEE
0000003oool0301EEED0103oool0EEEE0?ooo`3oool305EEE@80oooo0P1EEED20:ZZZP80oooo0P1E
EED01P2ZZZX0000005EEE@3oool0EEEE0?ooo`80EEEE1`3oool:0=7=Z@H0oooo00d0EEEE0:ZZZP1E
EED0EEEE0:ZZZP3oool0ZZZZ05EEE@3oool0EEEE0000003oool000000080EEEE00D0000005EEE@00
0000EEEE0:ZZZP0300000080ZZZZ00<000000:ZZZP0000001@1EEED00`3oool000000:ZZZP030:ZZ
ZP040?ooo`000000ZZZZ0:ZZZP<0EEEE0P000000101EEED000000000000000020?ooo`0305EEE@2Z
ZZX0oooo0080ZZZZ00<0EEEE0:ZZZP3oool01P3oool:0=7=Z@H0oooo0P1EEED01P2ZZZX0oooo05EE
E@3oool000000?ooo`D0ZZZZ00<0oooo0000000000000P0000000`1EEED0ZZZZ0:ZZZP030:ZZZP03
05EEE@2ZZZX0000000X0000000<0EEEE0:ZZZP2ZZZX00`2ZZZX00`1EEED000000000000200000003
0?ooo`2ZZZX0ZZZZ00<0ZZZZ00L0oooo0000003oool0EEEE0000002ZZZX0EEEE00L0oooo2P3AcJT6
0?ooo`0305EEE@2ZZZX0000000<0ZZZZ0P0000001P3oool0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP80EEEE
00@000000?ooo`000000EEEE103oool20:ZZZP0605EEE@3oool0EEEE0?ooo`2ZZZX0EEEE0`3oool0
1P1EEED000000:ZZZP3oool000000?ooo`80EEEE00<000000?ooo`0000000P1EEED0202ZZZX0EEEE
05EEE@3oool0ZZZZ0?ooo`000000EEEE0P2ZZZX2000000030:ZZZP3oool0oooo00D0oooo303AcJT0
00/0dLfY1`3oool01@2ZZZX0oooo0:ZZZP3oool000000080ZZZZ0P0000000`1EEED0ZZZZ05EEE@02
05EEE@80oooo0P2ZZZX00`3oool0ZZZZ0:ZZZP020000000305EEE@2ZZZX0ZZZZ0080EEEE00H00000
0?ooo`3oool000000?ooo`1EEED20:ZZZP0405EEE@000000oooo0:ZZZP80oooo00D0ZZZZ0?ooo`3o
ool0oooo0000000205EEE@0;0000001EEED000000000002ZZZX0EEEE0000003oool0ZZZZ0?ooo`2Z
ZZX01`3oool:0=7=Z@L0oooo00<0ZZZZ0?ooo`3oool00P1EEED010000000oooo0?ooo`1EEED20000
000305EEE@3oool0EEEE0080EEEE00D0000005EEE@1EEED0EEEE0:ZZZP02000000030:ZZZP1EEED0
EEEE00X0EEEE00@0ZZZZ000000000000ZZZZ1P1EEED20?ooo`0405EEE@2ZZZX0000005EEE@80oooo
00<0ZZZZ05EEE@1EEED00P3oool00`2ZZZX0oooo0?ooo`050?ooo`X0dLfY1`3oool20:ZZZP0405EE
E@3oool0oooo05EEE@<0000000D0oooo0000002ZZZX0EEEE000000030?ooo`<0EEEE0P000000101E
EED0oooo05EEE@2ZZZX205EEE@030000001EEED000000080000000P0EEEE0:ZZZP000000oooo05EE
E@2ZZZX000000:ZZZP80EEEE00T0ZZZZ0?ooo`3oool0ZZZZ05EEE@2ZZZX000000?ooo`2ZZZX00P00
00030?ooo`0305EEE@2ZZZX0ZZZZ00L0oooo2P3AcJT70?ooo`030:ZZZP3oool0EEEE0080EEEE00@0
ZZZZ05EEE@1EEED0EEEE0`0000050:ZZZP0305EEE@000000000000@000002`2ZZZX00`3oool00000
000000040000000305EEE@2ZZZX0ZZZZ00<0ZZZZ1000000205EEE@060:ZZZP1EEED0EEEE0:ZZZP3o
ool0ZZZZ1`3oool:0=7=Z@L0oooo0`1EEED01P3oool0EEEE0:ZZZP000000EEEE0?ooo`80EEEE00`0
ZZZZ05EEE@1EEED0EEEE0:ZZZP000000EEEE0:ZZZP1EEED000000:ZZZP3oool205EEE@<0oooo0P1E
EED00`2ZZZX0EEEE0?ooo`020?ooo`80EEEE00/0oooo05EEE@000000EEEE0:ZZZP1EEED000000:ZZ
ZP1EEED0ZZZZ05EEE@020:ZZZP<0EEEE00@0000005EEE@1EEED0oooo0`1EEED70?ooo``0dLfY000;
0=7=Z@T0oooo00@0EEEE0?ooo`1EEED0EEEE103oool305EEE@060?ooo`2ZZZX0oooo0?ooo`000000
oooo0P2ZZZX02@3oool0000005EEE@1EEED0000005EEE@000000EEEE0?ooo`0205EEE@030?ooo`1E
EED000000080EEEE00X000000:ZZZP2ZZZX0ZZZZ0?ooo`000000ZZZZ0?ooo`2ZZZX000000`1EEED0
203oool0EEEE0?ooo`3oool0000005EEE@3oool0ZZZZ2@3oool:0=7=Z@T0oooo0`1EEED300000003
0?ooo`1EEED0000000<0oooo00<0ZZZZ0?ooo`2ZZZX00P1EEED0103oool0EEEE00000000000<05EE
E@040?ooo`1EEED00000000000@0EEEE00@0ZZZZ0?ooo`2ZZZX0EEEE0P3oool205EEE@030?ooo`00
0000000000<0EEEE00<0ZZZZ0?ooo`3oool01`3oool:0=7=Z@T0oooo00L0EEEE0?ooo`1EEED0EEEE
0?ooo`2ZZZX0EEEE0080ZZZZ00H0oooo000000000000EEEE0:ZZZP0000020?ooo`0405EEE@000000
ZZZZ05EEE@8000000P1EEED20:ZZZP0305EEE@000000ZZZZ00<0EEEE0P0000000`1EEED000000000
00030?ooo`0605EEE@2ZZZX0EEEE0:ZZZP000000oooo102ZZZX01@3oool0EEEE05EEE@3oool0ZZZZ
00T0oooo2P3AcJT90?ooo`030000003oool0EEEE0080oooo00H0000005EEE@3oool0oooo05EEE@3o
ool40:ZZZP0305EEE@000000000000<0000000<0ZZZZ05EEE@2ZZZX02@2ZZZX00`000000ZZZZ0000
00040000000905EEE@2ZZZX0ZZZZ0:ZZZP1EEED0oooo05EEE@000000oooo0080000000D0oooo05EE
E@1EEED0oooo0:ZZZP090?ooo`X0dLfY2@3oool00`2ZZZX000000:ZZZP020?ooo`80EEEE00X00000
0:ZZZP2ZZZX0EEEE0:ZZZP3oool0EEEE0?ooo`1EEED0oooo0P1EEED01`3oool0ZZZZ05EEE@3oool0
EEEE0?ooo`2ZZZX00P1EEED02@2ZZZX0EEEE05EEE@3oool0EEEE0:ZZZP1EEED0ZZZZ0?ooo`0205EE
E@050?ooo`1EEED0oooo05EEE@3oool00P1EEED02P2ZZZX0EEEE0000003oool0EEEE0?ooo`1EEED0
ZZZZ0000001EEED90?ooo``0dLfY000;0=7=Z@T0oooo0P1EEED20:ZZZP80EEEE00P0ZZZZ0000003o
ool0oooo0:ZZZP1EEED0000005EEE@80oooo00@0000005EEE@1EEED00000103oool00`000000EEEE
0?ooo`0205EEE@050?ooo`2ZZZX000000?ooo`2ZZZX00P3oool010000000EEEE0000000000020?oo
o`0805EEE@000000oooo0:ZZZP3oool0ZZZZ0000002ZZZX205EEE@80ZZZZ00<0EEEE0?ooo`3oool0
203oool:0=7=Z@T0oooo101EEED0102ZZZX0oooo0000003oool2000000060:ZZZP1EEED0oooo0?oo
o`1EEED0oooo0P1EEED40:ZZZP`0EEEE102ZZZX205EEE@@0oooo00T000000:ZZZP00000000000?oo
o`1EEED0oooo0:ZZZP3oool00P1EEED:0?ooo`X0dLfY2@3oool205EEE@<0000000<0ZZZZ0?ooo`00
00000`3oool00`1EEED0ZZZZ0:ZZZP02000000070:ZZZP00000000000000001EEED0000005EEE@02
0000000505EEE@3oool000000000003oool00`000000102ZZZX0000005EEE@3oool2000000030:ZZ
ZP000000oooo0080ZZZZ00D000000?ooo`3oool0EEEE000000020:ZZZP<0000000<0EEEE0?ooo`3o
ool0203oool:0=7=Z@T0oooo0P1EEED0102ZZZX0EEEE0?ooo`0000020?ooo`030000001EEED0ZZZZ
00@0000000<0EEEE0:ZZZP2ZZZX0102ZZZX;000000030?ooo`2ZZZX0ZZZZ00@0ZZZZ00L0EEEE0000
00000000000005EEE@2ZZZX0EEEE0080oooo00H0ZZZZ0000003oool000000:ZZZP1EEED:0?ooo`X0
dLfY2@3oool305EEE@<0oooo0P1EEED20:ZZZP0505EEE@2ZZZX0ZZZZ0:ZZZP0000000P2ZZZX01`00
0000ZZZZ0:ZZZP2ZZZX0EEEE0?ooo`2ZZZX00P3oool205EEE@050?ooo`1EEED0EEEE0?ooo`2ZZZX0
0P1EEED60:ZZZP030000002ZZZX0ZZZZ0080EEEE00@0ZZZZ05EEE@1EEED0ZZZZ0`3oool205EEE@X0
oooo303AcJT000/0dLfY2`3oool0101EEED0000005EEE@3oool30:ZZZP<0oooo00<0EEEE0?ooo`3o
ool00P2ZZZX00`1EEED000000?ooo`030?ooo`040:ZZZP1EEED0EEEE0?ooo`80EEEE00@0oooo05EE
E@1EEED0ZZZZ103oool020000000EEEE0:ZZZP2ZZZX0EEEE0?ooo`1EEED000000P3oool30:ZZZP04
0?ooo`1EEED0000005EEE@/0oooo2P3AcJT;0?ooo`0605EEE@3oool0EEEE0?ooo`000000EEEE0`3o
ool40:ZZZPD0EEEE00<0ZZZZ05EEE@1EEED0301EEED20:ZZZP@0EEEE00<0oooo0:ZZZP2ZZZX00`3o
ool01`000000EEEE0?ooo`3oool0EEEE0000001EEED02`3oool:0=7=Z@/0oooo00X0EEEE0:ZZZP00
0000000005EEE@000000ZZZZ05EEE@000000ZZZZ0`1EEED0102ZZZX0EEEE0:ZZZP1EEED20:ZZZP80
00000P3oool20000000305EEE@000000000000<0oooo0P0000020:ZZZP0505EEE@2ZZZX0EEEE0:ZZ
ZP3oool00P1EEED01P2ZZZX0000005EEE@1EEED0000005EEE@80000000<0ZZZZ05EEE@3oool02P3o
ool:0=7=Z@/0oooo00L0EEEE0000003oool0oooo05EEE@3oool0ZZZZ0080oooo100000000`1EEED0
ZZZZ0:ZZZP030:ZZZP0305EEE@2ZZZX0000000X0000000<0EEEE0:ZZZP2ZZZX00`2ZZZX00`1EEED0
00000000000200000080oooo00<0ZZZZ0?ooo`3oool00P3oool00`000000EEEE0?ooo`0:0?ooo`X0
dLfY2`3oool01`1EEED000000000002ZZZX0oooo05EEE@2ZZZX00P1EEED00`000000EEEE05EEE@02
05EEE@0:0:ZZZP3oool0ZZZZ0:ZZZP3oool0ZZZZ0?ooo`1EEED0oooo0:ZZZP80oooo00@0EEEE0?oo
o`1EEED0oooo0P1EEED0202ZZZX0oooo0:ZZZP2ZZZX0oooo0:ZZZP1EEED0ZZZZ0P1EEED0103oool0
EEEE05EEE@2ZZZX205EEE@040:ZZZP000000ZZZZ05EEE@/0oooo303AcJT000/0dLfY303oool03`1E
EED0oooo05EEE@1EEED000000:ZZZP000000ZZZZ0?ooo`000000ZZZZ05EEE@000000EEEE0?ooo`02
05EEE@030000003oool0EEEE00@0oooo00@0ZZZZ0?ooo`3oool0ZZZZ0P3oool010000000oooo0000
002ZZZX305EEE@060000002ZZZX0ZZZZ0000001EEED0ZZZZ100000000`1EEED0oooo0:ZZZP0<0?oo
o`X0dLfY303oool305EEE@800000103oool00`1EEED0oooo0?ooo`0305EEE@80oooo00<0EEEE0?oo
o`1EEED02`1EEED0103oool0EEEE05EEE@3oool305EEE@80oooo00<0EEEE0?ooo`3oool00P3oool2
00000080EEEE00<0ZZZZ0?ooo`3oool02P3oool:0=7=Z@`0oooo00@0ZZZZ0?ooo`1EEED0ZZZZ0P1E
EED20000000;05EEE@000000000005EEE@3oool000000:ZZZP000000EEEE0000003oool00P000000
0`2ZZZX000000?ooo`02000000040?ooo`000000ZZZZ00000080oooo00L000000?ooo`000000ZZZZ
0000003oool0EEEE0080000000T0oooo000000000000oooo05EEE@2ZZZX0EEEE0?ooo`2ZZZX0303o
ool:0=7=Z@`0oooo00P000000?ooo`1EEED0oooo0000001EEED000000?ooo`@0ZZZZ00<0EEEE0000
000000001000000;0:ZZZP030?ooo`000000000000@0000000P0EEEE0:ZZZP2ZZZX0ZZZZ05EEE@3o
ool0000005EEE@80000000<0EEEE0?ooo`2ZZZX0303oool:0=7=Z@`0oooo0`1EEED20?ooo`0C05EE
E@3oool0oooo05EEE@000000oooo05EEE@2ZZZX0EEEE0?ooo`1EEED0oooo05EEE@2ZZZX0oooo05EE
E@3oool0ZZZZ05EEE@020?ooo`0405EEE@2ZZZX0oooo05EEE@80ZZZZ0`1EEED01`2ZZZX0EEEE0:ZZ
ZP1EEED0oooo0000002ZZZX00P3oool00`1EEED0oooo0?ooo`0305EEE@`0oooo303AcJT000/0dLfY
303oool205EEE@80ZZZZ00@0EEEE0:ZZZP2ZZZX0ZZZZ0`000000101EEED0oooo0:ZZZP3oool20000
0080oooo00T000000:ZZZP2ZZZX000000?ooo`1EEED000000?ooo`0000000P2ZZZX30?ooo`060:ZZ
ZP00000000000:ZZZP3oool0EEEE0P0000001@3oool0ZZZZ0:ZZZP3oool0EEEE0080ZZZZ00<0EEEE
0?ooo`3oool02`3oool:0=7=Z@`0oooo0`1EEED01@2ZZZX0EEEE0000001EEED0oooo00<0EEEE00P0
oooo05EEE@1EEED0EEEE0?ooo`2ZZZX000000?ooo``0EEEE00@0oooo000000000000oooo0`1EEED0
2@000000EEEE05EEE@000000oooo05EEE@3oool0EEEE0?ooo`0205EEE@d0oooo2P3AcJT<0?ooo`05
05EEE@000000EEEE0?ooo`1EEED00P0000020?ooo`030:ZZZP1EEED000000080EEEE00/0ZZZZ05EE
E@1EEED000000:ZZZP000000oooo0000002ZZZX000000?ooo`020000000505EEE@000000oooo0000
002ZZZX00P00000405EEE@030000001EEED0ZZZZ0080oooo00H0000005EEE@1EEED0000005EEE@00
000=0?ooo`X0dLfY303oool205EEE@030:ZZZP3oool0EEEE0080EEEE00<0oooo0000000000000P00
00000`1EEED0ZZZZ0:ZZZP040:ZZZP0305EEE@000000000000P0000000<0EEEE0:ZZZP2ZZZX0102Z
ZZX00`1EEED0000000000002000000070?ooo`1EEED0EEEE05EEE@000000ZZZZ05EEE@0=0?ooo`X0
dLfY303oool0301EEED0oooo000000000000EEEE0:ZZZP1EEED0oooo0000002ZZZX0EEEE0?ooo`80
EEEE0P2ZZZX20?ooo`0505EEE@3oool0ZZZZ0?ooo`1EEED0103oool00`1EEED0oooo0:ZZZP0205EE
E@80oooo0P2ZZZX205EEE@050?ooo`1EEED0ZZZZ0:ZZZP3oool0101EEED00`000000oooo0?ooo`0<
0?ooo``0dLfY000;0=7=Z@h0oooo00H0EEEE0000001EEED0ZZZZ0?ooo`1EEED30?ooo`030:ZZZP3o
ool0oooo00<0oooo0P2ZZZX00`1EEED0000005EEE@020:ZZZP80oooo00@0ZZZZ05EEE@1EEED00000
0`2ZZZX20?ooo`040000003oool0oooo0:ZZZP80oooo0P1EEED20?ooo`0305EEE@000000EEEE00h0
oooo2P3AcJT>0?ooo`0305EEE@3oool0EEEE00@0oooo00<000000?ooo`3oool0101EEED20?ooo`h0
EEEE0P3oool505EEE@030?ooo`000000oooo0080oooo0P1EEED00`000000EEEE0?ooo`0=0?ooo`X0
dLfY3P3oool0101EEED0ZZZZ0000002ZZZX4000000070:ZZZP3oool0ZZZZ0000001EEED0000005EE
E@030000000605EEE@2ZZZX0ZZZZ05EEE@000000ZZZZ0P1EEED00`2ZZZX0EEEE0:ZZZP0200000009
0?ooo`00000000000000002ZZZX0oooo0:ZZZP000000ZZZZ0080000000@0EEEE0000001EEED0EEEE
3P3oool:0=7=Z@h0oooo00L0EEEE0000003oool000000?ooo`000000ZZZZ00<0000000<0EEEE0:ZZ
ZP2ZZZX0102ZZZX;000000030?ooo`2ZZZX0ZZZZ00@0ZZZZ00<0EEEE0000000000000`0000001@3o
ool000000?ooo`000000EEEE00h0oooo2P3AcJT>0?ooo`80EEEE00D0oooo05EEE@1EEED0oooo0:ZZ
ZP040?ooo`060000001EEED0ZZZZ0?ooo`1EEED0oooo0P1EEED00`3oool0EEEE0000000300000005
05EEE@3oool0EEEE0:ZZZP3oool00P1EEED01@2ZZZX0EEEE0000003oool000000080oooo00<0ZZZZ
0?ooo`1EEED00P3oool205EEE@h0oooo303AcJT000/0dLfY3`3oool03P1EEED0oooo0000001EEED0
oooo05EEE@2ZZZX0000005EEE@000000oooo0:ZZZP000000EEEE0`0000030?ooo`030:ZZZP000000
ZZZZ0080ZZZZ0P3oool03@2ZZZX000000000002ZZZX0000005EEE@3oool0000005EEE@000000ZZZZ
05EEE@3oool00P1EEED00`3oool0ZZZZ0?ooo`0>0?ooo`X0dLfY3`3oool305EEE@D000000P1EEED0
103oool0EEEE05EEE@00000@05EEE@060?ooo`1EEED0EEEE0?ooo`1EEED0ZZZZ0P0000000`1EEED0
00000000000205EEE@030:ZZZP3oool0oooo00d0oooo2P3AcJT?0?ooo`050000002ZZZX0ZZZZ05EE
E@0000000`2ZZZX010000000ZZZZ0:ZZZP2ZZZX205EEE@050000002ZZZX0EEEE05EEE@3oool00P2Z
ZZX205EEE@030:ZZZP000000oooo0080EEEE00@0ZZZZ000000000000EEEE0`2ZZZX01@000000ZZZZ
0:ZZZP2ZZZX000000080EEEE0P2ZZZX?0?ooo`X0dLfY3`3oool01@000000oooo05EEE@3oool00000
00@0ZZZZ00<0EEEE0000000000000`0000000`1EEED0ZZZZ0:ZZZP090:ZZZP80EEEE1@0000002P1E
EED0ZZZZ0:ZZZP2ZZZX0oooo0000003oool0EEEE0?ooo`2ZZZX?0?ooo`X0dLfY403oool01@000000
oooo05EEE@3oool000000080oooo0P00000305EEE@030?ooo`000000EEEE0080oooo1P1EEED00`2Z
ZZX0EEEE0?ooo`0205EEE@050000003oool0EEEE0:ZZZP1EEED00P0000020?ooo`060:ZZZP3oool0
EEEE0?ooo`000000EEEE3`3oool<0=7=Z@002`3AcJT?0?ooo`80EEEE0P2ZZZX01@1EEED0oooo05EE
E@3oool000000080oooo0P2ZZZX01@3oool000000?ooo`1EEED0ZZZZ0080000000L0ZZZZ00000000
0000ZZZZ05EEE@000000ZZZZ0080oooo00<000000:ZZZP2ZZZX00`3oool00`2ZZZX0oooo05EEE@02
05EEE@80ZZZZ00<0EEEE0?ooo`3oool03P3oool:0=7=Z@l0oooo0P1EEED01P3oool0EEEE0:ZZZP3o
ool000000?ooo`80EEEE00D0oooo0:ZZZP1EEED0EEEE0?ooo`0>05EEE@060?ooo`2ZZZX0EEEE0000
003oool0EEEE0P3oool00`000000oooo0:ZZZP0305EEEA00oooo2P3AcJT?0?ooo`0405EEE@2ZZZX0
ZZZZ05EEE@<0ZZZZ00<0000005EEE@0000000`3oool02@1EEED0ZZZZ0000003oool000000:ZZZP1E
EED0oooo0:ZZZP020?ooo`050000002ZZZX000000:ZZZP0000000P2ZZZX02@3oool0EEEE0?ooo`00
0000ZZZZ0000002ZZZX0oooo0:ZZZP0205EEE@030:ZZZP3oool0oooo00h0oooo2P3AcJT?0?ooo`80
EEEE00<0000005EEE@3oool00P0000000`2ZZZX0000005EEE@050:ZZZP0305EEE@2ZZZX0000000X0
000000<0EEEE0:ZZZP2ZZZX00`2ZZZX02@1EEED000000:ZZZP000000EEEE0?ooo`1EEED0ZZZZ05EE
E@0@0?ooo`X0dLfY3`3oool00`1EEED0ZZZZ000000020:ZZZP0305EEE@000000EEEE00<0EEEE00P0
ZZZZ0?ooo`000000oooo0000003oool0ZZZZ05EEE@<0oooo00L0ZZZZ0?ooo`1EEED0EEEE0:ZZZP1E
EED0000000<0oooo00<0ZZZZ05EEE@1EEED00P1EEED01P000000ZZZZ0:ZZZP2ZZZX000000:ZZZQ00
oooo303AcJT000/0dLfY4@3oool20000000505EEE@2ZZZX0ZZZZ0?ooo`0000000P3oool01@2ZZZX0
EEEE0?ooo`1EEED000000080EEEE00<0000005EEE@3oool00P0000002@3oool0EEEE0000001EEED0
ZZZZ0000001EEED0ZZZZ05EEE@050?ooo`050:ZZZP3oool0EEEE0000001EEED04@3oool:0=7=ZA40
oooo00L000000?ooo`1EEED0oooo0000003oool0EEEE0080ZZZZ0P3oool00`1EEED0oooo05EEE@0=
05EEE@@0oooo0P2ZZZX20?ooo`050000003oool0EEEE0?ooo`1EEED04@3oool:0=7=ZA40oooo0P00
00004@1EEED0000005EEE@000000ZZZZ0000003oool0ZZZZ05EEE@2ZZZX000000:ZZZP3oool00000
0:ZZZP1EEED000000080ZZZZ00<000000:ZZZP2ZZZX00P0000002@2ZZZX000000:ZZZP1EEED00000
0?ooo`000000ZZZZ0000000305EEE@030000001EEED0oooo0100oooo2P3AcJTA0?ooo`8000000P3o
ool01@000000EEEE0000002ZZZX0EEEE00D0ZZZZ00<0EEEE000000000000200000000`1EEED0ZZZZ
0:ZZZP030:ZZZP0505EEE@2ZZZX0000005EEE@0000000P3oool00`000000EEEE0?ooo`0@0?ooo`X0
dLfY4P3oool00`000000EEEE0?ooo`0205EEE@030?ooo`1EEED0ZZZZ0080ZZZZ0`1EEED00`2ZZZX0
oooo05EEE@020000000705EEE@2ZZZX000000000001EEED0oooo0:ZZZP0205EEE@80ZZZZ00<0oooo
0:ZZZP1EEED00`1EEED010000000EEEE0000001EEEDA0?ooo``0dLfY000;0=7=ZA40oooo00H0ZZZZ
05EEE@3oool0000005EEE@0000020:ZZZP060000003oool0oooo0:ZZZP000000oooo0P1EEED30?oo
o`060000003oool0oooo0:ZZZP3oool0EEEE0P3oool01@000000ZZZZ0?ooo`1EEED000000080ZZZZ
00D0000005EEE@1EEED0oooo05EEE@0B0?ooo`X0dLfY4@3oool00`2ZZZX0EEEE05EEE@0300000003
05EEE@3oool0oooo0080000000<0ZZZZ05EEE@1EEED03P1EEED00`2ZZZX0000005EEE@020?ooo`03
05EEE@000000000000<0EEEE4P3oool:0=7=ZA40oooo00<0ZZZZ05EEE@3oool00P1EEED00`3oool0
ZZZZ0000000205EEE@030:ZZZP000000ZZZZ0080EEEE00D000000:ZZZP000000oooo05EEE@020?oo
o`80ZZZZ00<0000005EEE@1EEED00`2ZZZX205EEE@030000002ZZZX0oooo0080EEEE00<0oooo05EE
E@3oool04@3oool:0=7=ZA40oooo00H0ZZZZ0000003oool000000?ooo`2ZZZX205EEE@D0000000<0
ZZZZ05EEE@2ZZZX02@2ZZZX00`000000ZZZZ00000002000000090:ZZZP000000EEEE0?ooo`2ZZZX0
oooo05EEE@3oool000000180oooo2P3AcJTA0?ooo`0405EEE@2ZZZX0000005EEE@<0oooo0P2ZZZX0
103oool0EEEE0?ooo`3oool305EEE@<0000000T0ZZZZ0?ooo`000000oooo0000001EEED0oooo05EE
E@3oool00`1EEED20:ZZZP0605EEE@3oool0oooo0:ZZZP000000ZZZZ4P3oool<0=7=Z@002`3AcJTB
0?ooo`80EEEE0P2ZZZX02@1EEED0oooo05EEE@3oool000000:ZZZP3oool0ZZZZ05EEE@020:ZZZP80
EEEE00L0oooo000000000000oooo0000001EEED0ZZZZ0080EEEE102ZZZX0103oool0EEEE0?ooo`1E
EED20:ZZZP80EEEE4P3oool:0=7=ZA80oooo0P1EEED00`3oool0ZZZZ05EEE@0205EEE@80000000D0
oooo05EEE@3oool0EEEE0?ooo`0<05EEE@@0oooo00D0000005EEE@3oool0EEEE0:ZZZP0305EEEA80
oooo2P3AcJTB0?ooo`80EEEE0`0000002`2ZZZX0oooo05EEE@3oool0EEEE0000003oool0EEEE0?oo
o`1EEED0ZZZZ00<0EEEE00@0000005EEE@1EEED0ZZZZ0`1EEED20?ooo`<0EEEE00<0oooo0:ZZZP00
00000P00000205EEEA80oooo2P3AcJTB0?ooo`80EEEE00<000000?ooo`1EEED00P0000000`3oool0
ZZZZ0:ZZZP030:ZZZP/0000000<0oooo0:ZZZP2ZZZX00`2ZZZX01P3oool000000?ooo`1EEED0oooo
0:ZZZP80EEEE4P3oool:0=7=ZA80oooo0P1EEED30?ooo`050:ZZZP1EEED0ZZZZ0?ooo`1EEED00`3o
ool0202ZZZX0EEEE05EEE@000000ZZZZ0?ooo`1EEED0ZZZZ101EEED30?ooo`0405EEE@2ZZZX0ZZZZ
05EEE@<0oooo0`1EEEDB0?ooo``0dLfY000;0=7=ZA@0oooo0P0000000`1EEED0ZZZZ0?ooo`030:ZZ
ZP0905EEE@3oool0oooo0000002ZZZX0000005EEE@3oool0EEEE0080oooo00@0ZZZZ0000002ZZZX0
00000P3oool40:ZZZP80oooo00<0EEEE0000001EEED0503oool:0=7=ZA@0oooo00<000000?ooo`1E
EED00P3oool2000000040?ooo`2ZZZX000000?ooo`/0EEEE0P3oool01P000000oooo0?ooo`1EEED0
00000?ooo`80EEEE00<0oooo05EEE@3oool04`3oool:0=7=ZA@0oooo0P2ZZZX01@000000EEEE05EE
E@000000oooo00<0ZZZZ00D0EEEE0:ZZZP3oool0oooo0000000405EEE@<0oooo00P0000005EEE@2Z
ZZX0EEEE0:ZZZP1EEED0000005EEE@80000000<0ZZZZ05EEE@3oool04`3oool:0=7=ZA@0oooo0P00
00002@3oool000000:ZZZP000000ZZZZ0?ooo`000000oooo0:ZZZP0<0000000;0:ZZZP3oool0oooo
0?ooo`1EEED000000:ZZZP000000oooo0000001EEED0503oool:0=7=ZA@0oooo00H0ZZZZ00000000
0000EEEE0?ooo`1EEED60:ZZZP030000002ZZZX0ZZZZ00D0oooo00<0ZZZZ0000002ZZZX0102ZZZX2
05EEE@050?ooo`2ZZZX000000000001EEED0503oool<0=7=Z@002`3AcJTD0?ooo`080:ZZZP1EEED0
oooo0000001EEED0oooo05EEE@3oool205EEE@090:ZZZP3oool0ZZZZ0:ZZZP3oool000000?ooo`1E
EED0000000<0ZZZZ00<0EEEE0:ZZZP1EEED0103oool205EEE@030?ooo`1EEED0oooo01@0oooo2P3A
cJTD0?ooo`040:ZZZP1EEED0EEEE05EEE@8000000`3oool00`1EEED0ZZZZ05EEE@0;05EEE@040:ZZ
ZP1EEED0oooo0?ooo`<000000`1EEEDE0?ooo`X0dLfY503oool20:ZZZP060?ooo`2ZZZX0ZZZZ05EE
E@000000ZZZZ0P1EEED20:ZZZP<0000000D0EEEE000000000000EEEE0:ZZZP0200000080ZZZZ00T0
EEEE0:ZZZP2ZZZX0000005EEE@2ZZZX0EEEE0?ooo`2ZZZX05@3oool:0=7=ZA@0oooo00@0ZZZZ0000
003oool0EEEE0P3oool010000000EEEE0000003oool205EEE@X0ZZZZ00H0oooo05EEE@3oool0oooo
05EEE@0000020?ooo`0305EEE@3oool0000001D0oooo2P3AcJTD0?ooo`<0EEEE103oool00`1EEED0
oooo05EEE@0405EEE@030:ZZZP00000000000080000000@0oooo05EEE@1EEED0oooo1@1EEED20?oo
o`<0EEEE5@3oool<0=7=Z@002`3AcJTE0?ooo`80EEEE0P2ZZZX0101EEED0ZZZZ0:ZZZP2ZZZX20?oo
o`80EEEE00<0000005EEE@2ZZZX00P3oool00`2ZZZX0EEEE0000000205EEE@80oooo00@000000:ZZ
ZP1EEED0EEEE0P2ZZZX205EEEAD0oooo2P3AcJTE0?ooo`80EEEE00L0oooo05EEE@2ZZZX0EEEE0000
001EEED0oooo00`0EEEE00<0oooo05EEE@3oool00P0000000`3oool0ZZZZ05EEE@0305EEEAD0oooo
2P3AcJTE0?ooo`0405EEE@00000000000?ooo`@0EEEE1@2ZZZX00`3oool0EEEE05EEE@0205EEE@<0
ZZZZ00@000000:ZZZP2ZZZX0ZZZZ0`1EEED0103oool0EEEE0000001EEEDE0?ooo`X0dLfY5@3oool2
05EEE@040000001EEED0oooo0:ZZZP80oooo00<0000005EEE@1EEED02P0000000`2ZZZX0EEEE0000
00020?ooo`040000003oool0EEEE0:ZZZP80EEEE5@3oool:0=7=ZAD0oooo00L0EEEE0?ooo`1EEED0
000005EEE@2ZZZX0oooo0080ZZZZ0P3oool20:ZZZPD0EEEE00<0oooo0:ZZZP2ZZZX00P3oool20:ZZ
ZP030?ooo`1EEED0EEEE0080000000<0oooo05EEE@3oool0503oool<0=7=Z@002`3AcJTG0?ooo`80
000000<0EEEE0:ZZZP2ZZZX00P2ZZZX03P3oool0EEEE0000001EEED0ZZZZ05EEE@3oool0000005EE
E@2ZZZX0EEEE0000002ZZZX0oooo0`2ZZZX0103oool0EEEE0000001EEEDG0?ooo`X0dLfY5`3oool0
1P000000oooo05EEE@3oool000000?ooo`80ZZZZ2`1EEED30:ZZZP0605EEE@000000oooo05EEE@3o
ool0EEEE5`3oool:0=7=ZAL0oooo00D0EEEE0:ZZZP000000ZZZZ000000020?ooo`0505EEE@2ZZZX0
00000000003oool0101EEED01@2ZZZX000000000003oool0EEEE0080oooo00D0000005EEE@000000
ZZZZ05EEE@0G0?ooo`X0dLfY5`3oool200000080oooo00@0EEEE0:ZZZP2ZZZX0oooo2`0000020?oo
o`030:ZZZP3oool0EEEE0080oooo00<0000005EEE@3oool05P3oool:0=7=ZAL0oooo0P1EEED01`3o
ool0EEEE05EEE@1EEED0oooo05EEE@3oool00P1EEED20:ZZZP040?ooo`1EEED0ZZZZ0:ZZZP@0EEEE
0P3oool00`1EEED0oooo0?ooo`0205EEEAL0oooo303AcJT000/0dLfY5`3oool01`2ZZZX0EEEE0?oo
o`000000EEEE0000002ZZZX00P0000020?ooo`060:ZZZP3oool0oooo0000003oool0ZZZZ0P3oool0
102ZZZX000000:ZZZP00000205EEE@030?ooo`1EEED0oooo01L0oooo2P3AcJTG0?ooo`030:ZZZP1E
EED0EEEE0080000000<0oooo05EEE@3oool02`1EEED20?ooo`0305EEE@000000000000<0EEEE603o
ool:0=7=ZAL0oooo00@0ZZZZ0000002ZZZX0ZZZZ0`1EEED010000000ZZZZ0:ZZZP2ZZZX200000003
05EEE@000000000000<0ZZZZ0P0000001P1EEED0000005EEE@1EEED0ZZZZ000001P0oooo2P3AcJTG
0?ooo`050:ZZZP000000oooo0000003oool00P1EEED00`000000EEEE0:ZZZP090:ZZZP080?ooo`00
0000EEEE0000003oool0EEEE0?ooo`00000H0?ooo`X0dLfY5`3oool01@1EEED0oooo0000003oool0
EEEE00<0ZZZZ0P3oool305EEE@80oooo00<0EEEE0?ooo`1EEED00P3oool20:ZZZP040?ooo`1EEED0
oooo000001T0oooo303AcJT000/0dLfY603oool205EEE@80ZZZZ00D0oooo0:ZZZP2ZZZX0oooo05EE
E@0300000080oooo00@000000:ZZZP000000EEEE0`2ZZZX00`1EEED0ZZZZ0:ZZZP0205EEEAP0oooo
2P3AcJTH0?ooo`80EEEE00<0oooo0:ZZZP3oool00P0000000`3oool0EEEE05EEE@0505EEE@040?oo
o`1EEED0EEEE05EEE@80000000<0EEEE0:ZZZP1EEED00P1EEEDH0?ooo`X0dLfY603oool02P1EEED0
ZZZZ0:ZZZP1EEED0oooo0000002ZZZX000000?ooo`1EEED20?ooo`80000000P0oooo0000001EEED0
oooo05EEE@2ZZZX000000:ZZZP80EEEE00<0ZZZZ05EEE@3oool05`3oool:0=7=ZAP0oooo0P1EEED0
0`000000oooo05EEE@0205EEE@/0000000H0oooo05EEE@1EEED0EEEE0?ooo`2ZZZX205EEEAP0oooo
2P3AcJTH0?ooo`0305EEE@2ZZZX000000080ZZZZ00<0EEEE0:ZZZP2ZZZX00P2ZZZX00`1EEED0oooo
0?ooo`030?ooo`@0ZZZZ00H0EEEE0:ZZZP2ZZZX000000:ZZZP1EEEDH0?ooo``0dLfY000;0=7=ZAX0
oooo0P0000001@3oool0ZZZZ0?ooo`1EEED0oooo00<0EEEE0P0000002P1EEED0000005EEE@3oool0
EEEE0?ooo`2ZZZX0EEEE0000001EEEDJ0?ooo`X0dLfY6P3oool00`000000oooo05EEE@020?ooo`03
0:ZZZP3oool0ZZZZ00H0EEEE00<0ZZZZ0?ooo`3oool00P3oool00`1EEED0oooo05EEE@0J0?ooo`X0
dLfY6P3oool20000000305EEE@000000EEEE0080ZZZZ00<0000005EEE@0000000P1EEED00`000000
EEEE000000020:ZZZP0505EEE@000000EEEE0000001EEED06P3oool:0=7=ZAX0oooo100000000`3o
ool000000:ZZZP08000000070:ZZZP000000oooo0000003oool0000005EEE@0J0?ooo`X0dLfY6`3o
ool2000000050?ooo`1EEED0oooo0000002ZZZX01P3oool0202ZZZX0000005EEE@1EEED0oooo05EE
E@000000EEEE6P3oool<0=7=Z@002`3AcJTJ0?ooo`040:ZZZP1EEED0EEEE000000@0EEEE00<0ZZZZ
0?ooo`0000000`3oool205EEE@050?ooo`1EEED000000?ooo`1EEED06`3oool:0=7=ZAX0oooo00D0
ZZZZ05EEE@1EEED0EEEE000000030?ooo`H0EEEE0P3oool00`1EEED0000005EEE@0205EEEA/0oooo
2P3AcJTJ0?ooo`030:ZZZP1EEED0EEEE0080EEEE00@0oooo05EEE@000000oooo10000000102ZZZX0
000005EEE@3oool205EEE@030?ooo`1EEED0oooo01X0oooo2P3AcJTJ0?ooo`040:ZZZP000000EEEE
05EEE@80oooo2P2ZZZX01@000000oooo05EEE@3oool0000001/0oooo2P3AcJTJ0?ooo`0:05EEE@2Z
ZZX0ZZZZ05EEE@3oool0EEEE0:ZZZP000000oooo00000080oooo00@000000?ooo`000000ZZZZ0P3o
ool00`1EEED000000:ZZZP0K0?ooo``0dLfY000;0=7=ZA/0oooo00H0EEEE0:ZZZP2ZZZX0ZZZZ05EE
E@3oool205EEE@040000002ZZZX0ZZZZ00000080EEEE00@0oooo05EEE@2ZZZX0ZZZZ0P1EEEDK0?oo
o`X0dLfY6`3oool205EEE@040?ooo`1EEED00000000000H0EEEE00H0oooo05EEE@000000ZZZZ05EE
E@3oool205EEEA/0oooo2P3AcJTK0?ooo`0705EEE@00000000000000002ZZZX000000?ooo`0505EE
E@030000003oool0000000<000000P1EEEDK0?ooo`X0dLfY6`3oool00`1EEED0ZZZZ0000000205EE
E@L0000000H0ZZZZ000000000000oooo05EEE@00000205EEEA/0oooo2P3AcJTK0?ooo`80EEEE0`3o
ool205EEE@8000000P3oool010000000EEEE05EEE@1EEED30?ooo`80EEEE6`3oool<0=7=Z@002`3A
cJTL0?ooo`0405EEE@00000000000?ooo`80ZZZZ00H0oooo05EEE@3oool0oooo05EEE@3oool20:ZZ
ZP0305EEE@000000000001d0oooo2P3AcJTL0?ooo`0305EEE@000000oooo0080oooo1P1EEED01P3o
ool0EEEE0?ooo`1EEED0oooo000001d0oooo2P3AcJTL0?ooo`0305EEE@2ZZZX0ZZZZ0080000000<0
oooo0:ZZZP2ZZZX00`2ZZZX0101EEED0oooo0000000000020:ZZZQd0oooo2P3AcJTL0?ooo`0305EE
E@00000000000080oooo1P000000101EEED000000?ooo`3oool2000001d0oooo2P3AcJTL0?ooo`06
05EEE@2ZZZX000000:ZZZP1EEED0oooo0P0000020?ooo`040000003oool0oooo05EEE@80000000<0
ZZZZ0?ooo`3oool06`3oool<0=7=Z@002`3AcJTM0?ooo`0@0:ZZZP1EEED0EEEE0000001EEED0ZZZZ
05EEE@000000ZZZZ05EEE@000000EEEE0000003oool0EEEE0:ZZZQd0oooo2P3AcJTM0?ooo`030:ZZ
ZP1EEED0EEEE008000001@1EEED00`3oool000000000000205EEE@030:ZZZP3oool0oooo01/0oooo
2P3AcJTM0?ooo`80ZZZZ00H0EEEE0:ZZZP000000EEEE0?ooo`1EEED20?ooo`80000000@0ZZZZ0?oo
o`2ZZZX0ZZZZ7@3oool:0=7=ZAd0oooo00@0ZZZZ0000001EEED000000P3oool02P1EEED0ZZZZ0:ZZ
ZP1EEED0ZZZZ0?ooo`000000oooo0000002ZZZXM0?ooo`X0dLfY7@3oool305EEE@80oooo0P000002
0?ooo`040000003oool0oooo0?ooo`<0EEEE7@3oool<0=7=Z@002`3AcJTP0?ooo`80ZZZZ0P3oool0
101EEED0oooo0?ooo`3oool30:ZZZQl0oooo2P3AcJTR0?ooo`H0EEEE0P3oool00`2ZZZX0oooo0?oo
o`0M0?ooo`X0dLfY7`3oool0101EEED0ZZZZ0000002ZZZX405EEE@8000000P2ZZZXO0?ooo`X0dLfY
803oool00`2ZZZX0EEEE05EEE@040:ZZZP80EEEE0P2ZZZXO0?ooo`X0dLfY7`3oool01@2ZZZX00000
0:ZZZP1EEED0ZZZZ0080EEEE00D0ZZZZ05EEE@2ZZZX0000005EEE@0O0?ooo``0dLfY000;0=7=ZAl0
oooo00T0EEEE000000000000ZZZZ0000003oool0EEEE0000001EEED00P00000P0?ooo`X0dLfY7`3o
ool00`1EEED000000?ooo`0605EEE@030?ooo`000000oooo01l0oooo2P3AcJTO0?ooo`80EEEE00<0
ZZZZ05EEE@0000000`0000000`3oool0ZZZZ05EEE@0P0?ooo`X0dLfY7`3oool00`1EEED000000000
0005000000030?ooo`00000000000200oooo2P3AcJTO0?ooo`<0EEEE00<0oooo05EEE@2ZZZX00P1E
EED00`3oool0EEEE05EEE@0P0?ooo``0dLfY000;0=7=ZB00oooo00H0ZZZZ05EEE@1EEED0oooo0000
002ZZZX20?ooo`0305EEE@2ZZZX0oooo01l0oooo2P3AcJTP0?ooo`030:ZZZP1EEED0EEEE00H0EEEE
00<0ZZZZ0?ooo`3oool07P3oool:0=7=ZB00oooo00D0ZZZZ000000000000oooo000000020?ooo`03
0:ZZZP000000ZZZZ0200oooo2P3AcJTP0?ooo`030:ZZZP000000EEEE00@0ZZZZ00<0oooo0000002Z
ZZX0803oool:0=7=ZB00oooo00<0EEEE0?ooo`3oool00P3oool01@1EEED0oooo0000003oool0EEEE
0200oooo303AcJT000/0dLfY8`3oool50:ZZZR80oooo2P3AcJTT0?ooo`040:ZZZP3oool0oooo0:ZZ
ZR80oooo2P3AcJTR0?ooo`060:ZZZP1EEED000000000001EEED0ZZZZ8P3oool:0=7=ZB<0oooo00<0
ZZZZ0?ooo`1EEED00P2ZZZXR0?ooo`X0dLfY8P3oool205EEE@040?ooo`1EEED0EEEE05EEEB80oooo
303AcJT000/0dLfY8P3oool00`1EEED0000005EEE@02000002<0oooo2P3AcJTR0?ooo`0505EEE@00
0000EEEE0?ooo`0000008`3oool:0=7=ZB80oooo00<0EEEE0000003oool00P00000S0?ooo`X0dLfY
8P3oool01@1EEED000000:ZZZP1EEED0000002<0oooo2P3AcJTR0?ooo`0405EEE@3oool0EEEE0000
02@0oooo303AcJT000/0dLfY8`3oool0102ZZZX0oooo05EEE@2ZZZXS0?ooo`X0dLfY8`3oool0102Z
ZZX0EEEE05EEE@2ZZZXS0?ooo`X0dLfY8`3oool0102ZZZX0000005EEE@2ZZZXS0?ooo`X0dLfY8`3o
ool0102ZZZX0EEEE0000002ZZZXS0?ooo`X0dLfY8`3oool0101EEED000000:ZZZP1EEEDS0?ooo``0
dLfY000;0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool:0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool0
8`3oool:0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool:0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool0
8`3oool:0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool<0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb
0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@002`3AcJT01`3oool0EEEE0000
003oool0ZZZZ0?ooo`1EEED00`0000020?ooo`0305EEE@2ZZZX0ZZZZ0080ZZZZ0`000000402ZZZX0
EEEE05EEE@3oool0EEEE0?ooo`2ZZZX0EEEE0:ZZZP3oool000000?ooo`000000ZZZZ0?ooo`000002
0?ooo`0;0000003oool0ZZZZ0000003oool000000?ooo`2ZZZX0EEEE0000003oool01@1EEED30000
00030:ZZZP3oool0ZZZZ0080ZZZZ0P3oool00`2ZZZX00000000000040?ooo`030000001EEED0oooo
00X0dLfY00@0oooo05EEE@1EEED000000P2ZZZX805EEE@80000000@0EEEE0000001EEED000000P1E
EED01P2ZZZX0oooo05EEE@2ZZZX0000005EEE@<0000000H0EEEE0:ZZZP000000ZZZZ0?ooo`1EEED2
0?ooo`80000000<0ZZZZ0000000000000P0000001P1EEED000000:ZZZP1EEED0oooo0:ZZZP80EEEE
00<0000005EEE@1EEED00P1EEED00`000000EEEE05EEE@0205EEE@050000001EEED0EEEE05EEE@2Z
ZZX00P00000205EEE@030?ooo`3AcJT0dLfY00P0dLfY00@0oooo05EEE@1EEED0oooo0P2ZZZX01`3o
ool0ZZZZ0?ooo`000000EEEE0?ooo`0000000P3oool0202ZZZX0000005EEE@1EEED0oooo0000003o
ool000000P1EEED00`000000EEEE0000000200000080EEEE00<0000005EEE@3oool00P0000004P3o
ool0000005EEE@1EEED000000?ooo`1EEED0000005EEE@000000EEEE0000001EEED0oooo0000003o
ool0EEEE0?ooo`80EEEE00<0000005EEE@3oool00`3oool01@1EEED000000?ooo`2ZZZX0oooo0080
ZZZZ00@0oooo05EEE@1EEED0oooo2P3AcJT0103oool0EEEE05EEE@3oool20000000>0?ooo`000000
00000000001EEED0ZZZZ0000002ZZZX0EEEE0:ZZZP1EEED0ZZZZ0?ooo`2ZZZX2000000@0EEEE00@0
00000?ooo`1EEED000000P1EEED01P000000EEEE0:ZZZP3oool0EEEE00000080oooo00P0EEEE0000
001EEED0EEEE0000001EEED0oooo00000080EEEE00L0ZZZZ05EEE@000000oooo0:ZZZP3oool00000
00<0EEEE00<0ZZZZ0000002ZZZX00P1EEED2000000040:ZZZP00000000000?ooo`80EEEE00<0oooo
0=7=Z@3AcJT0203AcJT01@3oool0ZZZZ0:ZZZP000000ZZZZ0080oooo00<0EEEE000000000000>000
0000201EEED0oooo0?ooo`1EEED000000:ZZZP1EEED0oooo303AcJT000/0dLfY00@0oooo0:ZZZP3o
ool0EEEE0`3oool01@2ZZZX0EEEE0?ooo`000000ZZZZ0080oooo0P1EEED0103oool000000?ooo`3o
ool2000000030?ooo`000000EEEE0080ZZZZ00H0oooo05EEE@3oool0EEEE0:ZZZP1EEED30?ooo`03
05EEE@000000oooo0080oooo00<0EEEE0:ZZZP1EEED00`3oool20:ZZZP0305EEE@000000oooo0080
00001@3oool0201EEED0oooo0:ZZZP2ZZZX000000?ooo`1EEED0ZZZZ0P3oool205EEE@<0oooo2P3A
cJT00`3oool0ZZZZ0?ooo`020?ooo`0305EEE@000000EEEE0080000000<0EEEE0000001EEED00P00
000305EEE@80000000D0EEEE0000002ZZZX0EEEE0:ZZZP030000000405EEE@000000EEEE000000<0
ZZZZ00@000000:ZZZP3oool000000`2ZZZX205EEE@050000001EEED000000:ZZZP0000000`2ZZZX0
10000000ZZZZ00000000000205EEE@D0000000L0EEEE000000000000EEEE0000001EEED0000000@0
oooo2P3AcJT01@3oool0ZZZZ0?ooo`3oool0EEEE00<0oooo00D0EEEE0000001EEED0oooo05EEE@02
00000080oooo00@000000?ooo`1EEED0EEEE0P000000101EEED0oooo00000000000205EEE@030000
001EEED0ZZZZ008000000P1EEED20000000705EEE@3oool000000000002ZZZX0EEEE0000000205EE
E@030?ooo`000000oooo00<000000P1EEED0103oool000000?ooo`1EEED20000000305EEE@3oool0
EEEE0080EEEE203oool:0=7=Z@060?ooo`2ZZZX0oooo0?ooo`000000oooo0P1EEED01@2ZZZX00000
000000000000ZZZZ00<0000000H0ZZZZ0?ooo`3oool0oooo05EEE@2ZZZX205EEE@050:ZZZP000000
oooo0000001EEED010000000201EEED0ZZZZ0?ooo`3oool000000?ooo`2ZZZX0EEEE100000002@2Z
ZZX0000005EEE@000000ZZZZ0000001EEED0ZZZZ05EEE@020?ooo`0305EEE@2ZZZX0000000800000
00H0ZZZZ000000000000EEEE0:ZZZP1EEED70?ooo`X0dLfY00L0oooo0:ZZZP000000oooo0:ZZZP00
0000ZZZZ03`0000000D0ZZZZ0000003oool0oooo000000020?ooo``0dLfY000;0=7=Z@<0oooo00T0
ZZZZ05EEE@3oool0oooo0000001EEED0oooo0000001EEED00`2ZZZX00`1EEED0oooo0:ZZZP020000
00030:ZZZP3oool0oooo0080ZZZZ00@0EEEE0000003oool0EEEE103oool00`000000EEEE00000002
0?ooo`050000001EEED000000?ooo`0000000P3oool01@1EEED0oooo05EEE@1EEED0ZZZZ00<0oooo
00@0ZZZZ000000000000ZZZZ0P3oool20:ZZZP050000001EEED000000?ooo`1EEED00P0000020?oo
o`040:ZZZP3oool0oooo0?ooo`X0dLfY0`3oool00`2ZZZX0000005EEE@0205EEE@040000001EEED0
000005EEE@D0000000H0EEEE000000000000EEEE0?ooo`2ZZZX205EEE@030:ZZZP1EEED000000080
EEEE00<000000:ZZZP2ZZZX00P2ZZZX20?ooo`030:ZZZP3oool000000080ZZZZ0P00000205EEE@08
0000001EEED0ZZZZ05EEE@000000ZZZZ0?ooo`1EEED20000000305EEE@000000000000<0000000@0
EEEE0000001EEED000000`1EEED00`3oool0ZZZZ0?ooo`020?ooo`X0dLfY0`3oool01P2ZZZX00000
05EEE@000000ZZZZ00000080EEEE00@0oooo05EEE@3oool000000`1EEED01@000000oooo0?ooo`00
0000EEEE00<0oooo00@0ZZZZ0?ooo`1EEED0EEEE0P3oool00`1EEED0oooo05EEE@02000000050?oo
o`000000oooo0?ooo`1EEED00P3oool0101EEED0ZZZZ0?ooo`2ZZZX20?ooo`030:ZZZP1EEED00000
0080oooo00T0000005EEE@1EEED0oooo0000003oool000000?ooo`1EEED00P0000001@2ZZZX0EEEE
05EEE@3oool0ZZZZ00<0oooo2P3AcJT30?ooo`050:ZZZP00000000000000001EEED00P0000030:ZZ
ZP050000003oool0oooo0:ZZZP0000000P1EEED400000080ZZZZ0P1EEED00`3oool0EEEE05EEE@02
0000000405EEE@000000ZZZZ05EEE@80ZZZZ00@0000005EEE@000000oooo0P1EEED00`000000EEEE
000000020:ZZZP<00000101EEED01@2ZZZX0oooo0?ooo`000000EEEE0080ZZZZ00L0EEEE0000001E
EED0ZZZZ0000003oool0ZZZZ00<0oooo2P3AcJT30?ooo`050:ZZZP000000ZZZZ0?ooo`1EEED00P00
00000`3oool0000005EEE@0b000000040?ooo`000000000005EEE@80ZZZZ00<000000:ZZZP3oool0
0P3oool<0=7=Z@002`3AcJT40?ooo`0905EEE@000000oooo0?ooo`000000EEEE0?ooo`2ZZZX0EEEE
0080oooo00<000000:ZZZP2ZZZX00P2ZZZX0103oool0ZZZZ0000001EEED30?ooo`0405EEE@000000
EEEE000000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0EEEE
00D0ZZZZ0?ooo`3oool0oooo000000040:ZZZP030?ooo`2ZZZX0EEEE00<0oooo00@0ZZZZ0?ooo`00
000000000P3oool00`000000EEEE0?ooo`030?ooo`X0dLfY103oool00`1EEED0000005EEE@020000
000305EEE@000000EEEE0080EEEE00<0000005EEE@0000000`0000001@1EEED0ZZZZ0:ZZZP000000
oooo00<0000000<0EEEE0000000000000P2ZZZX00`3oool0EEEE05EEE@020?ooo`0405EEE@2ZZZX0
oooo0:ZZZPD0000000@0EEEE0000003oool000000P2ZZZX30000000705EEE@000000EEEE0000001E
EED0000005EEE@04000000030:ZZZP000000EEEE00@0oooo2P3AcJT40?ooo`0305EEE@000000EEEE
00<0oooo00@0EEEE000000000000oooo0P2ZZZX305EEE@040000001EEED0000005EEE@<0oooo00P0
EEEE0?ooo`3oool0000005EEE@000000EEEE0?ooo`80EEEE0P00000205EEE@060?ooo`1EEED00000
05EEE@000000EEEE1@3oool0101EEED0000000000000000405EEE@060:ZZZP3oool000000000001E
EED000000P3oool00`2ZZZX0000005EEE@040?ooo`X0dLfY103oool0101EEED0ZZZZ0:ZZZP1EEED2
00000080EEEE00P0ZZZZ0000002ZZZX000000:ZZZP1EEED000000:ZZZP80000000@0EEEE0000001E
EED0EEEE0P00000305EEE@050?ooo`000000oooo05EEE@0000000P1EEED2000000030?ooo`000000
EEEE0080EEEE00<0oooo0000000000000P1EEED01@000000EEEE0000001EEED0ZZZZ0080000000<0
ZZZZ0?ooo`2ZZZX00P00000205EEE@80000000@0EEEE0?ooo`2ZZZX0EEEE103oool:0=7=Z@@0oooo
00<0ZZZZ0?ooo`2ZZZX00P0000000`3oool0000005EEE@0a000000030:ZZZP1EEED0000000<00000
00<0ZZZZ0?ooo`1EEED0103oool<0=7=Z@002`3AcJT50?ooo`0405EEE@000000ZZZZ0?ooo`80EEEE
00@0oooo0000003oool0oooo0P1EEED010000000oooo05EEE@2ZZZX20?ooo`0505EEE@2ZZZX00000
05EEE@2ZZZX00P1EEED00`3oool0ZZZZ0?ooo`020:ZZZP060000002ZZZX0EEEE0000003oool0ZZZZ
0`3oool01P1EEED0oooo0:ZZZP2ZZZX000000:ZZZP<0oooo00D0000005EEE@3oool0000005EEE@03
0?ooo`030000003oool0EEEE0080oooo00<0ZZZZ05EEE@1EEED01@3oool:0=7=Z@D0oooo0P1EEED0
1@000000EEEE0000001EEED000000080EEEE00<0000005EEE@00000010000000102ZZZX0EEEE0:ZZ
ZP2ZZZX205EEE@050000001EEED0EEEE0000003oool00P2ZZZX01P3oool0ZZZZ0?ooo`3oool0ZZZZ
0?ooo`80ZZZZ00<0EEEE0000001EEED00P00000205EEE@80ZZZZ00<0EEEE0:ZZZP0000001P000000
0`1EEED000000000000305EEE@030000001EEED0EEEE00D0oooo2P3AcJT50?ooo`80EEEE00<0oooo
0:ZZZP1EEED00P1EEED00`000000oooo05EEE@020?ooo`030:ZZZP000000oooo0080oooo1@1EEED0
1@3oool0000005EEE@1EEED000000080EEEE1@00000305EEE@060000001EEED0EEEE05EEE@3oool0
00000P1EEED00`000000EEEE0?ooo`020?ooo`030000001EEED0oooo0080EEEE00@0oooo05EEE@1E
EED0EEEE0P2ZZZX00`3oool0EEEE05EEE@050?ooo`X0dLfY1@3oool0101EEED000000000001EEED3
0:ZZZP030?ooo`000000ZZZZ0080000000<0EEEE0000000000000P000000102ZZZX0EEEE0:ZZZP00
000205EEE@040?ooo`2ZZZX0EEEE0:ZZZP80000000D0ZZZZ0?ooo`1EEED000000?ooo`0300000005
0?ooo`1EEED0ZZZZ0000001EEED00P0000000`2ZZZX0EEEE0:ZZZP07000000030:ZZZP0000000000
0080ZZZZ00<0000005EEE@0000000P1EEED50?ooo`X0dLfY1@3oool0101EEED0ZZZZ0000001EEED3
0?oooc40000000P0EEEE0?ooo`3oool0ZZZZ05EEE@000000ZZZZ05EEE@D0oooo303AcJT000/0dLfY
1`3oool00`1EEED0oooo05EEE@0205EEE@030?ooo`1EEED0EEEE0080000000<0oooo0000002ZZZX0
103oool20:ZZZP80oooo0P1EEED00`000000EEEE0?ooo`0205EEE@80oooo00@0ZZZZ0?ooo`3oool0
EEEE0P3oool010000000EEEE05EEE@3oool30:ZZZP<0oooo00H0EEEE0:ZZZP000000oooo0000003o
ool205EEE@070:ZZZP1EEED0EEEE0000003oool0EEEE0:ZZZP060?ooo`X0dLfY203oool00`000000
EEEE05EEE@0205EEE@<0000000<0EEEE0000001EEED00`1EEED30:ZZZP@0000000<0oooo00000000
00000P2ZZZX00`3oool0ZZZZ05EEE@020:ZZZP060000002ZZZX0ZZZZ0?ooo`000000oooo0P000000
1`1EEED000000:ZZZP000000ZZZZ05EEE@000000101EEED400000080EEEE0P0000000`3oool0ZZZZ
0?ooo`050?ooo`X0dLfY2P3oool3000000040?ooo`2ZZZX0oooo0?ooo`D0ZZZZ0P1EEED01P3oool0
000005EEE@1EEED000000?ooo`<0EEEE00@0ZZZZ0000001EEED000000`1EEED0102ZZZX0EEEE0000
001EEED20?ooo`80EEEE00H000000?ooo`000000EEEE0:ZZZP1EEED20:ZZZP<0oooo00<0ZZZZ0?oo
o`3oool00P000000101EEED0oooo0?ooo`2ZZZX60?ooo`X0dLfY1`3oool00`1EEED0ZZZZ0:ZZZP02
000000050:ZZZP1EEED0oooo0000001EEED00P0000001@1EEED0000005EEE@000000ZZZZ00<00000
00@0ZZZZ05EEE@3oool0oooo0P0000000`1EEED0ZZZZ0:ZZZP0205EEE@050:ZZZP3oool0EEEE0000
002ZZZX00P3oool00`1EEED0ZZZZ05EEE@020000000505EEE@000000EEEE0000001EEED00P000000
1@1EEED0oooo0?ooo`1EEED0ZZZZ00<0000000<0ZZZZ05EEE@2ZZZX01P3oool:0=7=Z@H0oooo00@0
00000?ooo`3oool000000P2ZZZXb000000<0ZZZZ0P3oool00`2ZZZX0oooo0?ooo`040?ooo``0dLfY
000;0=7=Z@H0oooo0P1EEED020000000oooo0:ZZZP3oool0EEEE0000001EEED0oooo102ZZZX50?oo
o`0405EEE@3oool0oooo0:ZZZP80oooo00@0EEEE0:ZZZP1EEED000000P3oool01P1EEED0oooo0000
001EEED0ZZZZ000000D0oooo00<0EEEE0?ooo`3oool00`3oool20:ZZZP0505EEE@2ZZZX0EEEE05EE
E@0000000P3oool0102ZZZX0oooo0000001EEED70?ooo`X0dLfY1P3oool205EEE@040?ooo`1EEED0
000000000080EEEE00<0000005EEE@0000000`1EEED2000000040?ooo`2ZZZX0EEEE05EEE@<00000
00D0ZZZZ0?ooo`1EEED000000?ooo`030:ZZZP080?ooo`2ZZZX0EEEE0?ooo`000000EEEE0?ooo`2Z
ZZX3000000<0EEEE00<0oooo0000001EEED00P1EEED20000000405EEE@000000EEEE05EEE@800000
00<0ZZZZ0?ooo`1EEED01`3oool:0=7=Z@H0oooo0P1EEED0103oool0000000000000000205EEE@@0
oooo00D0EEEE0?ooo`2ZZZX0ZZZZ0?ooo`02000000<0EEEE0P2ZZZX01P1EEED000000?ooo`1EEED0
00000?ooo`8000000P3oool0101EEED0oooo05EEE@1EEED20:ZZZP<0EEEE00@000000?ooo`3oool0
ZZZZ0P3oool00`1EEED0oooo0?ooo`020?ooo`0705EEE@00000000000000001EEED0oooo05EEE@07
0?ooo`X0dLfY1P3oool305EEE@0@0000002ZZZX0ZZZZ0000002ZZZX0EEEE0:ZZZP000000oooo0:ZZ
ZP1EEED0000005EEE@2ZZZX0000005EEE@8000000`1EEED20?ooo`030000003oool0ZZZZ00D00000
00@0oooo0000001EEED0oooo0`1EEED200000080EEEE00/0ZZZZ05EEE@000000EEEE0:ZZZP1EEED0
00000:ZZZP1EEED0ZZZZ000000020:ZZZP030000001EEED0EEEE00L0oooo2P3AcJT60?ooo`0505EE
E@2ZZZX0EEEE0?ooo`2ZZZX0<P0000000`3oool000000:ZZZP0205EEE@030:ZZZP3oool0oooo00D0
oooo303AcJT000/0dLfY203oool01@1EEED000000:ZZZP3oool0EEEE0080oooo00<0EEEE0000001E
EED00P3oool0101EEED0ZZZZ05EEE@2ZZZX30?ooo`030:ZZZP3oool0oooo0080oooo00@000000?oo
o`3oool0oooo0P0000030?ooo`030000003oool0oooo0080oooo0P2ZZZX20?ooo`030000001EEED0
ZZZZ00@0oooo00L000000:ZZZP3oool0oooo0000003oool0ZZZZ0080EEEE203oool:0=7=Z@P0oooo
00H0EEEE0000002ZZZX000000:ZZZP00000405EEE@050000001EEED0oooo05EEE@3oool00P000000
101EEED0000005EEE@2ZZZX205EEE@80000000D0ZZZZ05EEE@2ZZZX0oooo000000030:ZZZP050000
002ZZZX0EEEE05EEE@3oool00`1EEED01`000000ZZZZ0?ooo`1EEED0ZZZZ05EEE@0000000P1EEED0
1P000000EEEE0000001EEED000000:ZZZP80EEEE203oool:0=7=Z@P0oooo00/0EEEE0000002ZZZX0
EEEE0000001EEED0oooo0:ZZZP1EEED0oooo0000000205EEE@D0000000<0oooo0:ZZZP1EEED00P00
00001P3oool0EEEE0:ZZZP000000EEEE00000080EEEE0P2ZZZX00`1EEED0oooo0000000200000005
0:ZZZP1EEED000000000001EEED00P0000000`3oool0EEEE0000000205EEE@060000003oool0EEEE
0?ooo`1EEED0ZZZZ0P1EEED80?ooo`X0dLfY203oool01`1EEED0oooo000000000000EEEE0000002Z
ZZX00P00000205EEE@80oooo0`2ZZZX010000000EEEE05EEE@1EEED2000000040:ZZZP1EEED0EEEE
00000080ZZZZ0P1EEED0102ZZZX0EEEE0000001EEED20:ZZZP8000000`1EEED010000000ZZZZ0:ZZ
ZP2ZZZX20?ooo`0505EEE@000000000005EEE@2ZZZX01000000205EEE@P0oooo2P3AcJT80?ooo`04
05EEE@3oool0ZZZZ0:ZZZP80000000<0oooo05EEE@2ZZZX0:00000000`2ZZZX000000?ooo`020000
00<0ZZZZ00<0EEEE0?ooo`3oool01P3oool<0=7=Z@002`3AcJT:0?ooo`0705EEE@3oool0oooo0000
001EEED0oooo0:ZZZP0205EEE@050:ZZZP00000000000000003oool00P1EEED20?ooo`0405EEE@3o
ool00000000000@0oooo00<000000?ooo`3oool00`3oool0101EEED000000?ooo`1EEED20?ooo`80
EEEE00<0oooo0000000000000P2ZZZX205EEE@030:ZZZP3oool0EEEE0080000000<0oooo05EEE@2Z
ZZX02@3oool:0=7=Z@X0oooo00<0EEEE0000000000000P3oool0201EEED0000005EEE@000000EEEE
0?ooo`2ZZZX0oooo0P1EEED00`000000EEEE05EEE@020?ooo`80ZZZZ00@0EEEE0?ooo`1EEED00000
0P3oool2000000050?ooo`1EEED0oooo0:ZZZP3oool00P1EEED20000000605EEE@000000oooo0:ZZ
ZP000000EEEE0`0000001`2ZZZX0oooo0?ooo`1EEED0000005EEE@2ZZZX02@3oool:0=7=Z@X0oooo
00T0EEEE0?ooo`2ZZZX000000:ZZZP1EEED0oooo05EEE@0000000P1EEED010000000EEEE05EEE@00
000205EEE@0<0?ooo`000000EEEE05EEE@000000EEEE0?ooo`1EEED0ZZZZ0000001EEED0ZZZZ0P3o
ool0101EEED0000005EEE@1EEED20?ooo`80EEEE00H0000005EEE@1EEED000000?ooo`1EEED20000
0080oooo00H0ZZZZ000000000000oooo05EEE@2ZZZX90?ooo`X0dLfY2P3oool010000000EEEE0000
0000000205EEE@030:ZZZP1EEED0EEEE00<0EEEE00<0000005EEE@0000000`0000001`1EEED00000
000000000000EEEE0:ZZZP0000001@1EEED00`2ZZZX0EEEE0:ZZZP070000000405EEE@000000EEEE
0?ooo`<0EEEE00P0ZZZZ05EEE@1EEED000000?ooo`1EEED000000:ZZZPT0oooo2P3AcJT90?ooo`03
0000002ZZZX0oooo0080000000<0EEEE0:ZZZP3oool0:00000020?ooo`0405EEE@00000000000?oo
o`80ZZZZ2@3oool<0=7=Z@002`3AcJT:0?ooo`050:ZZZP3oool0EEEE0?ooo`1EEED00`3oool0101E
EED000000:ZZZP2ZZZX20?ooo`800000103oool00`000000oooo0?ooo`030:ZZZP0:0?ooo`2ZZZX0
ZZZZ0?ooo`2ZZZX0oooo05EEE@000000oooo0:ZZZP80oooo0P0000020?ooo`040:ZZZP0000000000
05EEE@80oooo00H0ZZZZ05EEE@3oool0EEEE0?ooo`2ZZZX:0?ooo`X0dLfY2P3oool01@2ZZZX0oooo
0000003oool0EEEE0080000000<0EEEE0000000000000P2ZZZX00`1EEED0ZZZZ0000000200000080
EEEE0100ZZZZ05EEE@2ZZZX0oooo0000001EEED0000005EEE@2ZZZX0000005EEE@000000oooo0000
001EEED0ZZZZ0`1EEED30000000305EEE@2ZZZX0ZZZZ00@000000P1EEED30?ooo`030:ZZZP3oool0
oooo00P0oooo2P3AcJT:0?ooo`040:ZZZP3oool0oooo05EEE@80oooo00<0000005EEE@1EEED00P3o
ool010000000oooo0?ooo`0000020?ooo`@0000000@0EEEE0?ooo`1EEED0ZZZZ0P0000001P1EEED0
00000?ooo`1EEED0oooo05EEE@@000000P3oool010000000oooo0?ooo`0000020?ooo`80EEEE00@0
00000?ooo`3oool0EEEE0P3oool00`2ZZZX0oooo0?ooo`080?ooo`X0dLfY2P3oool00`2ZZZX0oooo
05EEE@040:ZZZP8000000P1EEED2000000<0EEEE00<0ZZZZ0?ooo`2ZZZX00P0000020?ooo`030000
001EEED0EEEE00@0EEEE00<000000?ooo`0000000P0000000`1EEED0oooo0?ooo`0205EEE@<00000
0P1EEED2000000D0ZZZZ00<0oooo0:ZZZP3oool02@3oool:0=7=Z@X0oooo00H0ZZZZ0000003oool0
ZZZZ0000002ZZZXZ000000060:ZZZP000000ZZZZ0?ooo`000000ZZZZ2P3oool<0=7=Z@002`3AcJT;
0?ooo`0405EEE@000000ZZZZ0?ooo`80EEEE00@0000005EEE@2ZZZX0EEEE103oool00`000000EEEE
05EEE@030?ooo`050000001EEED0oooo0?ooo`1EEED00P3oool01@1EEED0oooo0?ooo`1EEED00000
00<0oooo00<0EEEE0?ooo`0000001@3oool0102ZZZX0EEEE0?ooo`1EEED20?ooo`030:ZZZP1EEED0
EEEE00/0oooo2P3AcJT;0?ooo`0305EEE@3oool0ZZZZ0080000000T0EEEE00000000000000000:ZZ
ZP3oool0ZZZZ05EEE@0000000P1EEED020000000oooo0000001EEED0oooo0:ZZZP000000EEEE0P2Z
ZZX0103oool0ZZZZ0000000000020:ZZZP0405EEE@000000000000000080EEEE00D000000?ooo`2Z
ZZX0oooo0:ZZZP02000000<0EEEE00@000000:ZZZP1EEED0EEEE2`3oool:0=7=Z@/0oooo00L0EEEE
0?ooo`1EEED0000005EEE@000000oooo00d0000000<0oooo05EEE@1EEED00P3oool2000000040?oo
o`1EEED0EEEE05EEE@D0000000@0EEEE000000000000EEEE0P000000101EEED000000000001EEED3
000000<0EEEE2`3oool:0=7=Z@/0oooo00L0EEEE0000002ZZZX000000:ZZZP000000EEEE00@00000
00@0EEEE00000000000000000P2ZZZX00`000000EEEE000000030?ooo`H000000`3oool01@000000
EEEE05EEE@2ZZZX0oooo00<0000000<0EEEE0000000000001P0000000`2ZZZX0EEEE05EEE@0;0?oo
o`X0dLfY2`3oool305EEE@030?ooo`000000oooo02P0000000H0oooo0:ZZZP3oool0EEEE0:ZZZP1E
EED;0?ooo``0dLfY000;0=7=Z@d0oooo00D0EEEE0?ooo`1EEED0EEEE0:ZZZP020?ooo`80EEEE00D0
ZZZZ05EEE@3oool000000:ZZZP040?ooo`060000003oool000000?ooo`000000EEEE0P0000000`2Z
ZZX000000?ooo`060?ooo`040000003oool0EEEE0:ZZZP80EEEE0P3oool205EEE@040000003oool0
EEEE0:ZZZP`0oooo2P3AcJT=0?ooo`040000001EEED0EEEE00000080EEEE00@000000?ooo`3oool0
oooo0P1EEED01@000000EEEE0000001EEED0oooo0080ZZZZ00<000000:ZZZP0000000P1EEED02@3o
ool0EEEE0000002ZZZX000000?ooo`2ZZZX0oooo05EEE@0300000080EEEE0P3oool00`1EEED00000
05EEE@0200000080EEEE00<000000:ZZZP3oool02`3oool:0=7=Z@d0oooo00H0000005EEE@000000
ZZZZ05EEE@00000205EEE@040000001EEED0EEEE00000080EEEE00@0000005EEE@000000EEEE0P00
00000`3oool0EEEE00000004000000070?ooo`000000EEEE05EEE@000000EEEE0000000205EEE@04
0000001EEED0EEEE00000080EEEE0P0000001@2ZZZX0EEEE05EEE@000000ZZZZ00`0oooo2P3AcJT=
0?ooo`0405EEE@3oool0EEEE05EEE@80oooo00L000000?ooo`2ZZZX0EEEE0000001EEED0oooo0080
00000`1EEED01P2ZZZX0EEEE0:ZZZP000000ZZZZ000000@0ZZZZ01D0EEEE0:ZZZP1EEED0EEEE0:ZZ
ZP000000ZZZZ0?ooo`1EEED0000005EEE@2ZZZX0EEEE0000003oool0ZZZZ05EEE@000000oooo05EE
E@2ZZZX0303oool:0=7=Z@`0oooo0P0000000`2ZZZX0oooo05EEE@02000000030?ooo`000000EEEE
01h0000000<0EEEE0000003oool00P0000001@1EEED0ZZZZ0:ZZZP000000ZZZZ00`0oooo303AcJT0
00/0dLfY3@3oool00`2ZZZX0oooo05EEE@030?ooo`070:ZZZP3oool0oooo0000003oool0EEEE0:ZZ
ZP0205EEE@030000003oool0oooo00<0000000H0EEEE0000003oool0oooo0000003oool200000003
0:ZZZP3oool0oooo0080EEEE0P2ZZZX01P1EEED0oooo0000003oool0EEEE0:ZZZP<0oooo00<0EEEE
0?ooo`2ZZZX03@3oool:0=7=Z@d0oooo00D0ZZZZ0?ooo`000000000005EEE@020000000405EEE@2Z
ZZX0ZZZZ000000L0EEEE0P2ZZZX3000000070?ooo`2ZZZX000000:ZZZP000000ZZZZ0?ooo`0405EE
E@030000001EEED0EEEE00<0ZZZZ00<0EEEE0000000000000P0000000`1EEED0oooo0:ZZZP0=0?oo
o`X0dLfY3@3oool01P2ZZZX0oooo0?ooo`000000oooo05EEE@<0000000@0oooo05EEE@000000EEEE
0`2ZZZX01`1EEED0oooo0:ZZZP000000EEEE0000001EEED00P00000305EEE@040000001EEED0oooo
05EEE@<0ZZZZ00d0EEEE0000003oool0oooo0000003oool0000005EEE@2ZZZX0000005EEE@3oool0
ZZZZ00d0oooo2P3AcJT=0?ooo`050:ZZZP3oool0oooo0000003oool00P1EEED0302ZZZX000000000
002ZZZX0oooo05EEE@000000EEEE0:ZZZP1EEED0ZZZZ05EEE@<000000P1EEED00`000000EEEE0000
00020000000305EEE@2ZZZX0EEEE00@0EEEE00D0oooo05EEE@00000000000:ZZZP0205EEE@050?oo
o`000000oooo0?ooo`2ZZZX03@3oool:0=7=Z@d0oooo00<0ZZZZ0000003oool00P0000000`1EEED0
oooo0?ooo`0P000000030:ZZZP3oool0EEEE0080000000<0ZZZZ0000002ZZZX03@3oool<0=7=Z@00
2`3AcJT>0?ooo`0805EEE@000000ZZZZ0000001EEED0oooo0:ZZZP0000030?ooo`040:ZZZP3oool0
oooo0?ooo`80EEEE00@0oooo0000003oool0oooo0P2ZZZX01P1EEED0ZZZZ0?ooo`3oool000000?oo
o`80EEEE00@0ZZZZ0?ooo`2ZZZX0ZZZZ0`3oool01P000000oooo0?ooo`1EEED0oooo0:ZZZP80EEEE
3P3oool:0=7=Z@h0oooo0P1EEED00`000000EEEE05EEE@02000000<0ZZZZ00P0EEEE000000000000
EEEE0000001EEED000000?ooo`80ZZZZ00D0oooo05EEE@1EEED0ZZZZ05EEE@040:ZZZP040000001E
EED0000005EEE@80000000H0EEEE0?ooo`2ZZZX0ZZZZ05EEE@00000205EEE@030000001EEED0EEEE
00h0oooo2P3AcJT>0?ooo`80EEEE00@0oooo0:ZZZP1EEED0EEEE100000020?ooo`030:ZZZP3oool0
ZZZZ0080oooo0`2ZZZX205EEE@040000001EEED0EEEE00000080ZZZZ0`3oool00`2ZZZX0oooo0:ZZ
ZP020?ooo`0405EEE@000000000000000080EEEE00@0ZZZZ0?ooo`1EEED0EEEE3P3oool:0=7=Z@h0
oooo00D0EEEE0?ooo`1EEED0ZZZZ05EEE@030000000605EEE@2ZZZX000000?ooo`000000EEEE0`00
0000101EEED000000?ooo`0000020?ooo`060000003oool0oooo0?ooo`000000ZZZZ0P000000102Z
ZZX0EEEE0000003oool20000000605EEE@000000ZZZZ0000001EEED0ZZZZ0`1EEED>0?ooo`X0dLfY
3P3oool0101EEED0ZZZZ0000002ZZZX20?ooo`0305EEE@000000000001h000000`3oool0101EEED0
00000:ZZZP1EEED>0?ooo``0dLfY000;0=7=ZA00oooo00@0EEEE0000003oool000000P3oool20000
000;0?ooo`1EEED0oooo0?ooo`1EEED0000005EEE@2ZZZX0EEEE0?ooo`2ZZZX00P3oool0202ZZZX0
oooo0000003oool0EEEE0:ZZZP1EEED000000`3oool01`1EEED0oooo05EEE@000000oooo05EEE@00
00000P3oool00`1EEED0ZZZZ0?ooo`0>0?ooo`X0dLfY4@3oool01P000000EEEE0000002ZZZX0oooo
0:ZZZPD0EEEE00/0000005EEE@2ZZZX0ZZZZ0000002ZZZX000000?ooo`1EEED000000?ooo`020:ZZ
ZP030000003oool0ZZZZ00<0EEEE00<0000005EEE@1EEED00P2ZZZX01`3oool0EEEE0000001EEED0
00000?ooo`2ZZZX03`3oool:0=7=ZA40oooo00<0EEEE0?ooo`0000000`0000030?ooo`0305EEE@3o
ool0oooo00<0oooo00<0EEEE0?ooo`0000000P0000001@3oool000000?ooo`3oool0EEEE00<0oooo
00<0EEEE0?ooo`3oool00P3oool5000000<0oooo00<0ZZZZ0?ooo`3oool03@3oool:0=7=ZA00oooo
00<000000:ZZZP0000000P1EEED200000080EEEE0P2ZZZX01@000000EEEE0:ZZZP1EEED0000000<0
ZZZZ0P1EEED00`2ZZZX0EEEE05EEE@020:ZZZP80EEEE00<0ZZZZ05EEE@0000000P2ZZZX00`1EEED0
0000000000020000000505EEE@00000000000000002ZZZX03`3oool:0=7=Z@l0oooo00D000000?oo
o`2ZZZX000000:ZZZP0800000080oooo00<000000?ooo`0000002@0000000`3oool000000?ooo`08
00000080ZZZZ00@000000?ooo`3oool0ZZZZ3`3oool<0=7=Z@002`3AcJT@0?ooo`050:ZZZP1EEED0
EEEE0?ooo`2ZZZX00P3oool405EEE@050?ooo`2ZZZX000000?ooo`0000000P3oool01P000000ZZZZ
0?ooo`3oool0ZZZZ05EEE@@0oooo00<000000:ZZZP3oool00`1EEED30?ooo`0505EEE@3oool0EEEE
0?ooo`2ZZZX0403oool:0=7=ZA00oooo00<0ZZZZ0000001EEED00P0000001@3oool000000000002Z
ZZX0EEEE008000000`1EEED00`000000ZZZZ05EEE@020?ooo`050000002ZZZX0oooo0:ZZZP1EEED0
0P2ZZZX205EEE@<0000000X0EEEE0:ZZZP1EEED000000?ooo`1EEED0000005EEE@3oool0ZZZZ403o
ool:0=7=ZA00oooo00<0ZZZZ0000001EEED00`1EEED01P000000EEEE0000003oool0000005EEE@80
oooo0`0000030?ooo`80000000<0oooo0:ZZZP3oool00`0000000`3oool0000005EEE@020?ooo`05
0000001EEED0000005EEE@0000000P1EEED00`3oool0ZZZZ0?ooo`0?0?ooo`X0dLfY403oool20:ZZ
ZP80000000@0EEEE0000003oool0EEEE0P000000201EEED0ZZZZ0000001EEED0000005EEE@000000
ZZZZ0P3oool2000000060?ooo`1EEED0ZZZZ0000003oool000000P1EEED00`2ZZZX0EEEE00000002
000000030?ooo`00000000000080000000<0oooo0:ZZZP3oool03`3oool:0=7=ZA00oooo00D0ZZZZ
0000002ZZZX0ZZZZ05EEE@02000000030?ooo`000000000000<000000P2ZZZX;000000<0ZZZZ0P00
00000`1EEED0000000000003000000050?ooo`2ZZZX0ZZZZ0000002ZZZX0403oool<0=7=Z@002`3A
cJTA0?ooo`0405EEE@000000ZZZZ0?ooo`80EEEE0P0000000`2ZZZX000000?ooo`020?ooo`050000
002ZZZX0ZZZZ0000001EEED0103oool0302ZZZX000000:ZZZP2ZZZX000000?ooo`1EEED0oooo0000
002ZZZX000000?ooo`80EEEE00@0oooo0:ZZZP000000EEEE4@3oool:0=7=ZA40oooo00<0EEEE0000
002ZZZX00P1EEED20?ooo`0305EEE@00000000000080000000`0EEEE0:ZZZP2ZZZX000000:ZZZP1E
EED0oooo0000001EEED0oooo05EEE@2ZZZX2000000030:ZZZP1EEED0ZZZZ00<0000000P0EEEE0:ZZ
ZP3oool0EEEE0000002ZZZX0000005EEEA40oooo2P3AcJTA0?ooo`0505EEE@000000ZZZZ0?ooo`00
00000`1EEED00`000000EEEE05EEE@020000000405EEE@000000EEEE05EEE@80oooo00@000000?oo
o`3oool0oooo101EEED00`000000EEEE05EEE@02000000<0EEEE00D0000005EEE@2ZZZX0000005EE
E@0A0?ooo`X0dLfY4@3oool0101EEED000000000000000020:ZZZP80EEEE00L0ZZZZ0000002ZZZX0
EEEE0000002ZZZX0EEEE0080000000<0EEEE0:ZZZP0000000`2ZZZX200000080ZZZZ0P0000000`2Z
ZZX0EEEE0:ZZZP0205EEE@80ZZZZ00@0EEEE000000000000EEEE4@3oool:0=7=ZA40oooo00<0ZZZZ
0?ooo`2ZZZX0100000000`1EEED0ZZZZ00000002000000040:ZZZP3oool0000005EEE@P0000000D0
EEEE0:ZZZP3oool0ZZZZ05EEE@02000000030:ZZZP1EEED0oooo008000000P2ZZZX00`3oool0EEEE
0?ooo`0@0?ooo``0dLfY000;0=7=ZA80oooo0P1EEED20?ooo`040:ZZZP3oool0EEEE000000@0oooo
00@0EEEE0?ooo`3oool0EEEE1P3oool03P1EEED0oooo0?ooo`1EEED0oooo0:ZZZP3oool0EEEE0000
001EEED0oooo0:ZZZP3oool000000P1EEEDB0?ooo`X0dLfY4P3oool205EEE@80000000@0ZZZZ05EE
E@1EEED000000`1EEED20:ZZZP050000003oool000000?ooo`2ZZZX00P0000020:ZZZP030000003o
ool0EEEE0080ZZZZ0P1EEED20000000405EEE@2ZZZX0ZZZZ000000<0EEEE4P3oool:0=7=ZA80oooo
0P1EEED00`3oool0ZZZZ0:ZZZP020?ooo`040:ZZZP1EEED000000:ZZZP80EEEE0P0000001P1EEED0
ZZZZ0?ooo`000000EEEE0?ooo`80EEEE0P00000205EEE@80000000<0oooo0:ZZZP3oool00`2ZZZX3
05EEEA80oooo2P3AcJTB0?ooo`80EEEE0P000000102ZZZX000000:ZZZP2ZZZX20000000405EEE@00
0000000000000080EEEE00H0000005EEE@1EEED0000005EEE@00000205EEE@H00000102ZZZX01000
0000EEEE05EEE@1EEEDB0?ooo`X0dLfY4P3oool01@1EEED0ZZZZ0000001EEED0ZZZZ0080oooo00D0
EEEE000000000000oooo0:ZZZP020?ooo`X0000000<0ZZZZ0?ooo`2ZZZX00`0000001@1EEED0oooo
0?ooo`2ZZZX0EEEE0080ZZZZ00<0EEEE0?ooo`3oool0403oool<0=7=Z@002`3AcJTC0?ooo`030:ZZ
ZP1EEED0EEEE00<0oooo00@0ZZZZ0000003oool0oooo0P1EEED20:ZZZP0405EEE@3oool0EEEE0:ZZ
ZP80EEEE00<0000005EEE@2ZZZX0101EEED00`3oool0EEEE0:ZZZP030?ooo`0305EEE@3oool0ZZZZ
01<0oooo2P3AcJTC0?ooo`040:ZZZP3oool000000?ooo`80000000@0EEEE00000000000000000P2Z
ZZX205EEE@040?ooo`2ZZZX0EEEE00000080EEEE00@0ZZZZ0?ooo`1EEED000000P2ZZZX02P1EEED0
000005EEE@1EEED0000005EEE@3oool000000?ooo`2ZZZXC0?ooo`X0dLfY4`3oool0102ZZZX0oooo
0?ooo`1EEED30?ooo`0405EEE@2ZZZX0EEEE0?ooo`@0000000@0EEEE0?ooo`000000EEEE0P3oool4
00000080oooo00<0ZZZZ05EEE@3oool00P3oool0101EEED0oooo0?ooo`2ZZZXC0?ooo`X0dLfY4`3o
ool0102ZZZX0oooo0000001EEED2000000@0ZZZZ1@1EEED0102ZZZX0EEEE0?ooo`00000405EEE@08
0:ZZZP1EEED0EEEE0000002ZZZX000000:ZZZP00000205EEE@030000003oool0ZZZZ01<0oooo2P3A
cJTC0?ooo`030:ZZZP3oool0oooo00<0ZZZZ0`000000101EEED0oooo0?ooo`1EEED:000000<0oooo
100000001P2ZZZX000000:ZZZP3oool000000:ZZZQ<0oooo303AcJT000/0dLfY503oool0201EEED0
00000:ZZZP000000EEEE0?ooo`2ZZZX0EEEE0P000000103oool000000000000000030?ooo`030:ZZ
ZP3oool0oooo00<0000000@0oooo0000001EEED0EEEE0P3oool01@1EEED0oooo0:ZZZP000000EEEE
01@0oooo2P3AcJTD0?ooo`0305EEE@3oool0ZZZZ0080EEEE00@0000005EEE@1EEED000000P2ZZZX0
10000000oooo0000002ZZZX20000000605EEE@000000ZZZZ0000003oool000000P2ZZZX02@000000
EEEE000000000000EEEE0000002ZZZX0oooo05EEE@0D0?ooo`X0dLfY503oool01`1EEED0oooo05EE
E@000000EEEE0000003oool00P1EEED50000000505EEE@3oool0000005EEE@3oool01P0000002@3o
ool0EEEE000000000000EEEE0000001EEED0oooo05EEE@0D0?ooo`X0dLfY503oool01P1EEED0oooo
000000000000EEEE00000080oooo00<0000005EEE@2ZZZX010000000102ZZZX0oooo05EEE@2ZZZX4
000000070:ZZZP1EEED0EEEE0?ooo`1EEED0000005EEE@02000000030?ooo`1EEED0oooo01<0oooo
2P3AcJTD0?ooo`0;0:ZZZP1EEED0EEEE0:ZZZP000000oooo0000001EEED0ZZZZ0000002ZZZX02`00
00020:ZZZP80000000D0EEEE0000003oool000000?ooo`0305EEEA@0oooo303AcJT000/0dLfY5@3o
ool205EEE@<0oooo00H0000005EEE@3oool0oooo0:ZZZP3oool30:ZZZPD0oooo102ZZZX20?ooo`05
05EEE@000000oooo0?ooo`0000000P1EEEDE0?ooo`X0dLfY5@3oool205EEE@090:ZZZP1EEED00000
0000001EEED0000005EEE@3oool0ZZZZ00<0EEEE00<0ZZZZ0000001EEED00P2ZZZX205EEE@030000
003oool0EEEE0080EEEE0P000000101EEED0000005EEE@1EEEDE0?ooo`X0dLfY5@3oool205EEE@05
0:ZZZP1EEED0oooo0000003oool00P1EEED2000000090?ooo`1EEED0EEEE0?ooo`000000EEEE0?oo
o`000000EEEE0080oooo00<0000005EEE@1EEED00`3oool0101EEED0000005EEE@1EEEDE0?ooo`X0
dLfY5@3oool205EEE@060000003oool0oooo0000002ZZZX0EEEE0P0000001P1EEED0000005EEE@00
0000EEEE0?ooo`@0EEEE00<0000005EEE@0000000P0000001@2ZZZX000000?ooo`3oool0ZZZZ0080
EEEE5@3oool:0=7=ZAD0oooo00@0EEEE0:ZZZP2ZZZX0ZZZZ0P0000001@1EEED0000005EEE@3oool0
EEEE00X0000000<0EEEE0?ooo`1EEED00P1EEED2000000040:ZZZP3oool0ZZZZ05EEEAD0oooo303A
cJT000/0dLfY5P3oool01@2ZZZX0EEEE05EEE@3oool0ZZZZ00D0oooo00D0EEEE0?ooo`3oool0EEEE
0:ZZZP0205EEE@80oooo0P1EEED40?ooo`0505EEE@3oool0EEEE0?ooo`2ZZZX05P3oool:0=7=ZAH0
oooo00<0ZZZZ05EEE@000000100000001P1EEED0ZZZZ0:ZZZP000000EEEE0?ooo`80000000D0EEEE
000000000000EEEE000000020:ZZZP80EEEE100000000`3oool0ZZZZ0?ooo`0E0?ooo`X0dLfY5P3o
ool01@2ZZZX0EEEE0?ooo`000000oooo00@0EEEE0P0000000`1EEED0ZZZZ0?ooo`0200000080oooo
00<0EEEE000000000000101EEED01@2ZZZX000000?ooo`3oool0ZZZZ01H0oooo2P3AcJTF0?ooo`80
ZZZZ00H0EEEE0:ZZZP2ZZZX0000005EEE@2ZZZX305EEE@050:ZZZP1EEED0000005EEE@2ZZZX00P00
00001@2ZZZX0EEEE05EEE@1EEED0ZZZZ008000000P2ZZZX00`1EEED0oooo0:ZZZP0F0?ooo`X0dLfY
5P3oool20:ZZZP060?ooo`000000000005EEE@000000ZZZZ300000000`2ZZZX000000:ZZZP0205EE
E@80000000<0oooo0000002ZZZX05P3oool<0=7=Z@002`3AcJTG0?ooo`040:ZZZP3oool0EEEE0000
0080EEEE00@0oooo0:ZZZP1EEED0oooo0P0000020?ooo`0405EEE@3oool0EEEE00000080oooo00H0
ZZZZ0?ooo`1EEED0EEEE0?ooo`1EEEDI0?ooo`X0dLfY5`3oool0102ZZZX0oooo0?ooo`00000205EE
E@060000002ZZZX0oooo0000002ZZZX0EEEE100000020:ZZZP80000000D0ZZZZ0000001EEED0EEEE
0000000J0?ooo`X0dLfY5`3oool02`2ZZZX0oooo0?ooo`1EEED0oooo0000003oool0EEEE0:ZZZP00
0000ZZZZ00<0000000@0EEEE0000001EEED0ZZZZ0P0000000`1EEED0oooo0000000L0?ooo`X0dLfY
5`3oool01@2ZZZX0oooo05EEE@000000EEEE00D000000`3oool2000000030?ooo`000000oooo00@0
00000P1EEED00`3oool0EEEE0?ooo`0H0?ooo`X0dLfY5`3oool01P2ZZZX000000?ooo`2ZZZX00000
0:ZZZP80oooo2`0000001@1EEED0oooo0?ooo`2ZZZX000000080oooo00<000000?ooo`3oool05P3o
ool<0=7=Z@002`3AcJTH0?ooo`80EEEE1@3oool205EEE@080:ZZZP3oool000000:ZZZP1EEED00000
0?ooo`2ZZZX205EEE@80oooo00<0ZZZZ0?ooo`0000000P1EEEDH0?ooo`X0dLfY603oool205EEE@03
0:ZZZP1EEED000000080EEEE00<0oooo0000003oool01@000000101EEED0oooo0000002ZZZX205EE
E@030000001EEED0oooo0080EEEE603oool:0=7=ZAP0oooo0`1EEED30000000505EEE@2ZZZX0ZZZZ
0:ZZZP3oool00P0000000`3oool000000?ooo`020:ZZZP030?ooo`1EEED000000080000000<0oooo
05EEE@1EEED0603oool:0=7=ZAP0oooo0P1EEED01`3oool000000?ooo`1EEED0000005EEE@2ZZZX0
0P1EEED50:ZZZP0505EEE@2ZZZX0oooo0000001EEED00P00000305EEEAP0oooo2P3AcJTH0?ooo`06
05EEE@2ZZZX0EEEE0?ooo`000000oooo0P1EEED;0000000705EEE@3oool0ZZZZ0?ooo`1EEED0ZZZZ
05EEE@0H0?ooo``0dLfY000;0=7=ZAT0oooo00<0ZZZZ05EEE@1EEED00`3oool0102ZZZX0oooo0?oo
o`1EEED20?ooo`030:ZZZP3oool0EEEE00H0oooo00<0EEEE0?ooo`2ZZZX06@3oool:0=7=ZAT0oooo
00<0ZZZZ0000001EEED00`1EEED30:ZZZP030000001EEED0000000<0EEEE0P2ZZZX305EEE@040000
001EEED0oooo0:ZZZQT0oooo2P3AcJTI0?ooo`040:ZZZP000000EEEE00000080EEEE0P3oool305EE
E@80000000@0EEEE0?ooo`1EEED0oooo1@1EEED00`3oool0ZZZZ0?ooo`0H0?ooo`X0dLfY6@3oool0
1P2ZZZX0oooo0?ooo`3oool0ZZZZ0?ooo`80EEEE0P0000001P1EEED0000005EEE@1EEED0ZZZZ0000
0080EEEE00<0oooo0:ZZZP0000000P3oool00`2ZZZX0oooo0?ooo`0G0?ooo`X0dLfY6@3oool01@2Z
ZZX000000:ZZZP3oool0EEEE0080000000D0EEEE000000000000000005EEE@0400000080EEEE00H0
000005EEE@2ZZZX0ZZZZ0000002ZZZXI0?ooo``0dLfY000;0=7=ZAX0oooo00L0ZZZZ0?ooo`3oool0
00000?ooo`1EEED0ZZZZ00<0EEEE00X0oooo05EEE@1EEED0000005EEE@2ZZZX000000?ooo`000000
EEEE703oool:0=7=ZAX0oooo00P0ZZZZ0?ooo`000000EEEE0000003oool0ZZZZ00000080EEEE00<0
000005EEE@1EEED00P0000000`2ZZZX0oooo0000000205EEEA`0oooo2P3AcJTJ0?ooo`0;0:ZZZP3o
ool0oooo0000002ZZZX0EEEE0000003oool0000005EEE@0000000P1EEED01`000000oooo00000000
0000ZZZZ0000001EEED0703oool:0=7=ZAX0oooo00L0ZZZZ0?ooo`000000ZZZZ0000001EEED0ZZZZ
00<0EEEE0P00000305EEE@050:ZZZP3oool000000:ZZZP000000703oool:0=7=ZAX0oooo00<0ZZZZ
0000003oool00P0000001@2ZZZX000000000001EEED0ZZZZ0080000000<0ZZZZ0000000000001000
00000`2ZZZX000000?ooo`0J0?ooo``0dLfY000;0=7=ZA/0oooo00@0EEEE0000003oool0oooo0`00
00001P3oool0ZZZZ0?ooo`3oool0ZZZZ0?ooo`8000000`3oool205EEEA/0oooo2P3AcJTK0?ooo`80
EEEE0P0000000`3oool0000005EEE@030000000605EEE@000000EEEE05EEE@000000ZZZZ0P000002
05EEEA/0oooo2P3AcJTK0?ooo`80EEEE00<0oooo0:ZZZP2ZZZX00P0000001P1EEED000000000003o
ool0000005EEE@8000000P2ZZZX00`3oool0EEEE05EEE@0K0?ooo`X0dLfY6`3oool00`1EEED0ZZZZ
0?ooo`020:ZZZP<0000000@0oooo05EEE@000000oooo0`0000000`1EEED0ZZZZ0?ooo`0205EEEA/0
oooo2P3AcJTK0?ooo`0905EEE@2ZZZX0000005EEE@3oool0ZZZZ05EEE@2ZZZX0oooo008000000P3o
ool01`1EEED0ZZZZ0:ZZZP1EEED000000:ZZZP1EEED06`3oool<0=7=Z@002`3AcJTL0?ooo`80EEEE
00P000000?ooo`1EEED0EEEE0:ZZZP3oool0EEEE00000080oooo0P1EEED00`2ZZZX0000005EEE@0M
0?ooo`X0dLfY703oool205EEE@040?ooo`000000EEEE00000080EEEE00T0000005EEE@1EEED0EEEE
0000001EEED0ZZZZ0?ooo`1EEED07@3oool:0=7=ZA`0oooo0P1EEED01@3oool000000000001EEED0
oooo0080000000P0oooo0000001EEED0EEEE0000001EEED0oooo05EEEAd0oooo2P3AcJTL0?ooo`80
EEEE00D0000005EEE@000000EEEE0000000605EEE@<0000000<0EEEE0?ooo`3oool06`3oool:0=7=
ZA`0oooo00L0EEEE0:ZZZP1EEED0oooo0:ZZZP000000ZZZZ00@0000000<0ZZZZ0000002ZZZX00P1E
EED00`2ZZZX0oooo0?ooo`0K0?ooo``0dLfY000;0=7=ZAd0oooo00<0ZZZZ0?ooo`3oool00P000000
101EEED0oooo0?ooo`0000020?ooo`80000000<0EEEE0?ooo`2ZZZX07@3oool:0=7=ZAd0oooo00<0
ZZZZ0?ooo`1EEED00P1EEED01P000000EEEE000000000000EEEE00000080EEEE00<000000?ooo`2Z
ZZX07@3oool:0=7=ZAd0oooo00D0ZZZZ0?ooo`1EEED0EEEE0000000205EEE@80000000L0EEEE0?oo
o`000000EEEE0000003oool0ZZZZ01d0oooo2P3AcJTM0?ooo`050:ZZZP3oool0ZZZZ0000002ZZZX0
1@0000001P1EEED0ZZZZ0000001EEED0oooo0:ZZZQd0oooo2P3AcJTM0?ooo`040:ZZZP000000ZZZZ
0:ZZZP<0oooo0P000000103oool0EEEE0?ooo`2ZZZX2000000030:ZZZP3oool0oooo01/0oooo303A
cJT000/0dLfY7P3oool01P1EEED000000?ooo`3oool0ZZZZ00000080oooo0P0000020?ooo`80EEEE
7P3oool:0=7=ZAh0oooo00<0EEEE0000002ZZZX00`1EEED01P000000EEEE05EEE@000000EEEE0:ZZ
ZP80EEEE7P3oool:0=7=ZAh0oooo00@0EEEE0000002ZZZX0ZZZZ0P1EEED00`000000EEEE05EEE@03
0:ZZZP80EEEE7P3oool:0=7=ZAh0oooo0P1EEED20000000605EEE@3oool0EEEE0000003oool0ZZZZ
0P00000205EEEAh0oooo2P3AcJTN0?ooo`0305EEE@3oool0ZZZZ008000001@2ZZZX010000000ZZZZ
0:ZZZP1EEEDN0?ooo``0dLfY000;0=7=ZAl0oooo0P1EEED00`000000ZZZZ0?ooo`020:ZZZP040?oo
o`2ZZZX0000005EEEB00oooo2P3AcJTO0?ooo`D0EEEE00@0000005EEE@1EEED000000P1EEEDP0?oo
o`X0dLfY7`3oool405EEE@80000000<0EEEE0000003oool00P1EEEDP0?ooo`X0dLfY7`3oool205EE
E@090?ooo`000000oooo0:ZZZP000000oooo0000003oool0EEEE0200oooo2P3AcJTO0?ooo`0405EE
E@2ZZZX0ZZZZ00000080ZZZZ00<000000:ZZZP0000000P2ZZZXP0?ooo``0dLfY000;0=7=ZB00oooo
00D0ZZZZ0?ooo`3oool0oooo05EEE@020?ooo`0305EEE@3oool0ZZZZ0200oooo2P3AcJTP0?ooo`03
0:ZZZP3oool000000080000000D0EEEE0000003oool0oooo0:ZZZP0P0?ooo`X0dLfY803oool01`2Z
ZZX0oooo0?ooo`2ZZZX0000005EEE@2ZZZX00P3oool00`2ZZZX0oooo0?ooo`0N0?ooo`X0dLfY803o
ool02P2ZZZX0oooo05EEE@3oool0000005EEE@3oool000000?ooo`2ZZZXP0?ooo`X0dLfY803oool0
1P2ZZZX000000000003oool0EEEE0:ZZZP80oooo00<000000:ZZZP3oool07`3oool<0=7=Z@002`3A
cJTQ0?ooo`0305EEE@000000oooo0080EEEE00<0oooo05EEE@1EEED08@3oool:0=7=ZB40oooo00H0
EEEE0?ooo`2ZZZX0000005EEE@2ZZZX205EEEB40oooo2P3AcJTQ0?ooo`0505EEE@3oool0EEEE0000
003oool00`1EEEDQ0?ooo`X0dLfY8@3oool01P1EEED0ZZZZ000000000000oooo00000080EEEE8@3o
ool:0=7=ZB40oooo0P1EEED01P000000ZZZZ0?ooo`000000ZZZZ05EEEB40oooo303AcJT000/0dLfY
8P3oool205EEE@030:ZZZP000000EEEE02<0oooo2P3AcJTR0?ooo`80EEEE00<0ZZZZ0000001EEED0
8`3oool:0=7=ZB80oooo0P1EEED00`2ZZZX0000005EEE@0S0?ooo`X0dLfY8P3oool205EEE@030:ZZ
ZP000000EEEE02<0oooo2P3AcJTR0?ooo`0505EEE@2ZZZX0oooo0?ooo`2ZZZX08`3oool<0=7=Z@00
2`3AcJTS0?ooo`040:ZZZP1EEED0oooo0:ZZZR<0oooo2P3AcJTS0?ooo`040:ZZZP1EEED0oooo0:ZZ
ZR<0oooo2P3AcJTS0?ooo`040:ZZZP1EEED0oooo0:ZZZR<0oooo2P3AcJTS0?ooo`040:ZZZP1EEED0
oooo0:ZZZR<0oooo2P3AcJTS0?ooo`040:ZZZP000000ZZZZ0:ZZZR<0oooo303AcJT000/0dLfY903o
ool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903o
ool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903o
ool00`2ZZZX0oooo0?ooo`0S0?ooo``0dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80
dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY000;0=7=Z@060?ooo`1EEED0EEEE0:ZZZP3oool0EEEE
0P0000001@3oool0ZZZZ0:ZZZP2ZZZX000000080ZZZZ0P0000030?ooo`@0EEEE00<0oooo0000002Z
ZZX00`1EEED01`3oool000000000003oool0ZZZZ05EEE@3oool00P1EEED0202ZZZX0oooo0000001E
EED0oooo05EEE@2ZZZX0EEEE0P0000000`3oool0EEEE05EEE@0205EEE@<0oooo00D000000:ZZZP2Z
ZZX0ZZZZ000000020:ZZZP80oooo00D000000:ZZZP1EEED0oooo0:ZZZP0205EEE@030?ooo`3AcJT0
dLfY00P0dLfY00<0oooo05EEE@1EEED0101EEED01`3oool0EEEE05EEE@000000EEEE0:ZZZP1EEED0
0P0000020:ZZZP040000003oool0EEEE05EEE@80oooo00<0EEEE0?ooo`0000000P2ZZZX01P000000
EEEE05EEE@1EEED0ZZZZ0?ooo`@0ZZZZ00<0oooo0:ZZZP1EEED00P1EEED01P000000ZZZZ0:ZZZP1E
EED0oooo05EEE@80oooo0P1EEED00`3oool00000000000020:ZZZP080000001EEED0ZZZZ05EEE@00
0000oooo05EEE@3oool605EEE@030?ooo`3AcJT0dLfY00P0dLfY00H0oooo05EEE@1EEED0EEEE0?oo
o`0000020:ZZZP0305EEE@3oool0oooo0080000000@0oooo0:ZZZP3oool000000`1EEED00`3oool0
ZZZZ0?ooo`050?ooo`060000002ZZZX0EEEE0?ooo`2ZZZX000000P2ZZZX205EEE@070:ZZZP000000
00000:ZZZP3oool0EEEE0:ZZZP070?ooo`040:ZZZP3oool0EEEE05EEE@80000000H0oooo0:ZZZP3o
ool0EEEE0000003oool205EEE@040:ZZZP0000000000000000<0EEEE00<0oooo0=7=Z@3AcJT0203A
cJT01@3oool0EEEE05EEE@1EEED000000080EEEE00<000000?ooo`2ZZZX00P1EEED00`000000EEEE
0:ZZZP02000000040:ZZZP1EEED00000000000<0EEEE00H0oooo000000000000EEEE0?ooo`000002
05EEE@030:ZZZP1EEED0ZZZZ00@000000P1EEED00`2ZZZX0EEEE05EEE@020000000505EEE@3oool0
00000?ooo`2ZZZX00P1EEED00`3oool0000005EEE@03000000030:ZZZP1EEED000000080EEEE0P3o
ool010000000oooo05EEE@00000305EEE@030?ooo`3AcJT0dLfY00P0dLfY00<0oooo05EEE@000000
0P1EEED00`2ZZZX000000:ZZZP0305EEE@030?ooo`1EEED000000080ZZZZ0`0000001`2ZZZX0EEEE
05EEE@2ZZZX0oooo05EEE@2ZZZX00P000000103oool0ZZZZ0:ZZZP2ZZZX205EEE@030000002ZZZX0
EEEE00<0ZZZZ0P1EEED00`3oool0ZZZZ0:ZZZP03000000090:ZZZP1EEED0EEEE0:ZZZP1EEED00000
0:ZZZP000000ZZZZ0080000000@0ZZZZ000000000000oooo0`1EEED30:ZZZP050000001EEED00000
05EEE@3oool0303AcJT000/0dLfY00<0oooo0:ZZZP1EEED00`3oool2000000070:ZZZP000000oooo
0:ZZZP000000ZZZZ0?ooo`02000000030:ZZZP000000ZZZZ00D0ZZZZ00@000000?ooo`2ZZZX00000
0P3oool2000000030:ZZZP3oool000000080oooo00@000000:ZZZP2ZZZX00000103oool00`2ZZZX0
0000000000060:ZZZP090000002ZZZX000000:ZZZP3oool0ZZZZ0000002ZZZX0oooo0080ZZZZ00<0
00000:ZZZP3oool00P3oool00`1EEED0oooo0?ooo`0:0=7=Z@090?ooo`2ZZZX0EEEE0:ZZZP1EEED0
ZZZZ05EEE@3oool0000000<0EEEE00D0oooo05EEE@1EEED000000:ZZZP0305EEE@040?ooo`000000
oooo00000080oooo10000000103oool000000?ooo`3oool50000000305EEE@3oool0oooo0080oooo
0`0000030?ooo`0405EEE@3oool000000:ZZZP80EEEE00<000000:ZZZP1EEED00P1EEED01P3oool0
EEEE05EEE@3oool000000?ooo`80ZZZZ00<0oooo0:ZZZP1EEED00P3oool:0=7=Z@060?ooo`2ZZZX0
oooo0?ooo`000000ZZZZ0P0000001@3oool0000005EEE@1EEED0ZZZZ008000000`2ZZZX20?ooo`09
05EEE@000000ZZZZ0000001EEED000000?ooo`000000EEEE0080oooo101EEED00`3oool0ZZZZ0?oo
o`020?ooo`80EEEE00X000000?ooo`3oool0EEEE0000001EEED0000005EEE@000000ZZZZ0P000002
0?ooo`0305EEE@2ZZZX000000080000000<0oooo05EEE@1EEED00P3oool010000000oooo0:ZZZP2Z
ZZX40?ooo`X0dLfY00D0oooo0:ZZZP3oool0oooo000000020?ooo`80000000@0ZZZZ0?ooo`3oool0
00000P3oool205EEE@80oooo00@0ZZZZ0000003oool0oooo0P2ZZZX02P000000oooo05EEE@2ZZZX0
00000?ooo`2ZZZX0oooo0:ZZZP3oool405EEE@030?ooo`2ZZZX0oooo0080oooo00D000000:ZZZP1E
EED0EEEE000000020:ZZZP80oooo00<000000:ZZZP3oool00`1EEED20?ooo`040:ZZZP3oool0oooo
0:ZZZP8000000P3oool00`000000oooo0?ooo`020?ooo`X0dLfY00@0oooo0:ZZZP1EEED000000`3o
ool00`1EEED0000005EEE@020000000305EEE@3oool0EEEE0080ZZZZ0`1EEED30:ZZZP80oooo00D0
00000:ZZZP2ZZZX0000005EEE@020?ooo`0405EEE@2ZZZX0ZZZZ00000080ZZZZ00@000000?ooo`2Z
ZZX0EEEE0P3oool205EEE@030:ZZZP1EEED000000080oooo0`2ZZZX305EEE@050:ZZZP000000EEEE
0?ooo`2ZZZX01000000205EEE@040?ooo`000000000005EEE@80oooo303AcJT000/0dLfY0`3oool3
0:ZZZP<0EEEE00<000000:ZZZP2ZZZX00`2ZZZX30000000405EEE@2ZZZX000000?ooo`<0ZZZZ00@0
00000?ooo`1EEED0oooo0`0000030?ooo`050:ZZZP1EEED0oooo0:ZZZP1EEED00P3oool300000008
0:ZZZP1EEED000000000002ZZZX0EEEE0:ZZZP3oool20:ZZZP0405EEE@2ZZZX00000000000D0ZZZZ
0`1EEED0103oool0ZZZZ0:ZZZP2ZZZX30?ooo`X0dLfY0`3oool01@2ZZZX00000000000000000EEEE
0080ZZZZ0P1EEED0103oool0ZZZZ0000003oool205EEE@0<0000003oool000000000003oool0EEEE
0?ooo`1EEED0ZZZZ05EEE@2ZZZX0EEEE0P2ZZZX00`000000EEEE05EEE@040:ZZZP0>0?ooo`1EEED0
00000?ooo`2ZZZX0EEEE0:ZZZP1EEED0oooo05EEE@3oool0EEEE0?ooo`0000020?ooo`070000001E
EED0EEEE0:ZZZP000000ZZZZ0?ooo`0205EEE@030?ooo`2ZZZX0EEEE0080000000<0EEEE0:ZZZP3o
ool00P3oool:0=7=Z@<0oooo0P2ZZZX40?ooo`<0000000D0EEEE0:ZZZP3oool0oooo0000000305EE
E@80oooo00P000000?ooo`3oool0ZZZZ0?ooo`2ZZZX000000:ZZZP80oooo0P0000000`1EEED0ZZZZ
0:ZZZP020:ZZZP0305EEE@00000000000080oooo00<0ZZZZ0000002ZZZX00P2ZZZX20?ooo`030000
003oool0oooo00<0EEEE00D000000?ooo`3oool0ZZZZ05EEE@02000000070:ZZZP3oool0oooo0:ZZ
ZP3oool000000:ZZZP030?ooo`X0dLfY0`3oool0102ZZZX000000000000000020?ooo`030000001E
EED0EEEE0080oooo00@0000005EEE@3oool000000P1EEED20?ooo`050000003oool0ZZZZ0000001E
EED00`000000102ZZZX0oooo0?ooo`3oool2000000030?ooo`1EEED0000000@0oooo00L0ZZZZ0000
00000000000005EEE@000000ZZZZ0080000000<0oooo0:ZZZP1EEED00P1EEED01@3oool000000000
003oool000000080EEEE103oool2000000040:ZZZP3oool0oooo0?ooo`X0dLfY0`3oool01@2ZZZX0
EEEE0?ooo`000000EEEE00<0ZZZZ00@0oooo05EEE@000000EEEE102ZZZX01`000000ZZZZ05EEE@1E
EED0ZZZZ05EEE@2ZZZX00P0000000`2ZZZX0000000000003000000060?ooo`000000oooo05EEE@00
0000oooo1@0000001P1EEED000000000002ZZZX0EEEE0:ZZZP80EEEE00D0ZZZZ0000002ZZZX00000
0:ZZZP0205EEE@090000001EEED0oooo0:ZZZP3oool0ZZZZ05EEE@2ZZZX0oooo0080ZZZZ0`3oool<
0=7=Z@002`3AcJT40?ooo`0505EEE@3oool0oooo0:ZZZP3oool01P0000000`3oool0000000000002
0?ooo`80EEEE0P2ZZZX0103oool000000:ZZZP2ZZZX505EEE@030:ZZZP3oool000000080ZZZZ00<0
000005EEE@2ZZZX0101EEED20:ZZZP80000000<0oooo0:ZZZP2ZZZX00P1EEED20?ooo`P000000P3o
ool0102ZZZX0oooo0?ooo`1EEED40?ooo`X0dLfY103oool405EEE@80oooo0P1EEED020000000EEEE
05EEE@000000oooo0:ZZZP000000EEEE0P0000002@3oool0EEEE0?ooo`000000ZZZZ0?ooo`1EEED0
oooo0:ZZZP0200000080oooo00@0ZZZZ0?ooo`2ZZZX0ZZZZ0P3oool00`000000ZZZZ0:ZZZP030?oo
o`090:ZZZP000000oooo05EEE@3oool000000?ooo`1EEED000000080oooo0`1EEED00`3oool0EEEE
05EEE@020?ooo`@0EEEE103oool:0=7=Z@@0oooo0P1EEED010000000ZZZZ0000001EEED20:ZZZP09
0?ooo`2ZZZX0ZZZZ0000002ZZZX0oooo0:ZZZP3oool000000080EEEE00H0000005EEE@3oool0EEEE
0000003oool2000000060?ooo`000000ZZZZ0?ooo`2ZZZX0oooo0P2ZZZX0103oool0ZZZZ0000001E
EED2000000060:ZZZP000000oooo0?ooo`1EEED0oooo0`1EEED01@3oool0ZZZZ0?ooo`2ZZZX00000
0080ZZZZ00D0EEEE0:ZZZP2ZZZX0ZZZZ000000020:ZZZP80EEEE103oool:0=7=Z@@0oooo0P1EEED0
10000000ZZZZ0000002ZZZX20?ooo`040000001EEED0000005EEE@80oooo00D0ZZZZ0?ooo`1EEED0
00000?ooo`03000000030?ooo`000000oooo0080000000<0EEEE0000001EEED00P0000020?ooo`03
0000003oool0EEEE00H0000000H0oooo000000000000ZZZZ0?ooo`0000020?ooo`070:ZZZP000000
oooo0:ZZZP000000EEEE000000020?ooo`80000000@0ZZZZ05EEE@1EEED0EEEE103oool:0=7=Z@@0
oooo0P0000001@2ZZZX0EEEE0?ooo`3oool0EEEE00<0000000L0oooo0:ZZZP2ZZZX0000005EEE@3o
ool000000080oooo00<0ZZZZ0?ooo`3oool00P1EEED20:ZZZP0405EEE@2ZZZX0EEEE0:ZZZP800000
0P3oool2000000060:ZZZP1EEED0ZZZZ05EEE@2ZZZX0oooo0P1EEED20?ooo`080:ZZZP3oool0oooo
05EEE@3oool0EEEE0?ooo`2ZZZX20?ooo`040000001EEED0000005EEE@80oooo00@0EEEE0:ZZZP00
0000EEEE103oool<0=7=Z@002`3AcJT40?ooo`050:ZZZP1EEED0ZZZZ05EEE@2ZZZX01P1EEED40000
000605EEE@2ZZZX0oooo05EEE@3oool0EEEE0P0000000`3oool0ZZZZ0:ZZZP040:ZZZP030?ooo`00
000000000080000000<0EEEE0:ZZZP2ZZZX0102ZZZX00`3oool0ZZZZ0000000305EEE@80oooo00@0
EEEE0000002ZZZX000000`1EEED01@000000EEEE05EEE@1EEED0ZZZZ00<0EEEE1@3oool:0=7=Z@@0
oooo00H0ZZZZ05EEE@3oool0EEEE0:ZZZP1EEED20:ZZZP80EEEE00<0oooo05EEE@0000000`1EEED2
000000030?ooo`1EEED0oooo00<0000000<0oooo05EEE@0000001P1EEED00`000000EEEE0:ZZZP03
05EEE@030000001EEED0EEEE00<0000000D0oooo05EEE@3oool000000?ooo`0205EEE@80000000@0
ZZZZ0?ooo`1EEED0EEEE0P2ZZZX01@1EEED0ZZZZ05EEE@2ZZZX0EEEE00D0oooo2P3AcJT40?ooo`03
0:ZZZP3oool0EEEE0080EEEE00<0oooo0000000000000P3oool305EEE@80000000D0oooo0:ZZZP2Z
ZZX0ZZZZ000000030?ooo`0>0000001EEED0EEEE0?ooo`2ZZZX0EEEE0:ZZZP000000ZZZZ0000001E
EED0ZZZZ0000002ZZZX205EEE@040?ooo`1EEED0ZZZZ000000<0oooo0`2ZZZX00`1EEED0oooo0000
000205EEE@040?ooo`1EEED0oooo0?ooo`80000000<0oooo05EEE@1EEED01`3oool:0=7=Z@@0oooo
00<0ZZZZ0?ooo`0000000P0000020:ZZZP040000003oool000000?ooo`80ZZZZ00D0EEEE0?ooo`3o
ool0oooo0:ZZZP02000000050?ooo`000000EEEE05EEE@3oool00`0000001@3oool0ZZZZ05EEE@1E
EED0000000<0EEEE00<0ZZZZ0?ooo`3oool00P00000205EEE@80000000@0oooo000000000000ZZZZ
0`3oool010000000ZZZZ0:ZZZP3oool3000000040:ZZZP3oool00000000000L0oooo2P3AcJT40?oo
o`030:ZZZP000000EEEE00@0000000@0EEEE0?ooo`00000000000P2ZZZX00`000000oooo0?ooo`03
000000050:ZZZP000000000005EEE@0000000P2ZZZX30?ooo`030:ZZZP1EEED0ZZZZ008000000`2Z
ZZX0103oool0EEEE0?ooo`2ZZZX5000000030:ZZZP000000000000<0oooo00<000000:ZZZP000000
0P000000102ZZZX0EEEE0000002ZZZX2000000030?ooo`000000oooo00@0oooo303AcJT000/0dLfY
1P3oool01`2ZZZX000000?ooo`1EEED0ZZZZ05EEE@0000000P2ZZZX00`000000EEEE05EEE@020000
00<0ZZZZ00L0EEEE0:ZZZP1EEED0ZZZZ05EEE@2ZZZX000000080oooo00<000000:ZZZP3oool00P3o
ool03P000000oooo0:ZZZP2ZZZX000000:ZZZP3oool000000:ZZZP1EEED0000005EEE@2ZZZX0EEEE
0`2ZZZX200000080EEEE00X000000:ZZZP2ZZZX0000005EEE@2ZZZX0EEEE0?ooo`000000ZZZZ1P3o
ool:0=7=Z@H0oooo00<0EEEE0000000000000`00000205EEE@030:ZZZP1EEED0oooo00<0oooo00T0
ZZZZ0?ooo`3oool0ZZZZ0?ooo`1EEED0oooo05EEE@3oool00P0000001@3oool0ZZZZ0:ZZZP000000
ZZZZ0080EEEE1@2ZZZX2000000@0EEEE00D0oooo0:ZZZP3oool0oooo05EEE@020?ooo`040:ZZZP3o
ool0EEEE0:ZZZP80EEEE1@0000000`2ZZZX0oooo0?ooo`040?ooo`X0dLfY1P3oool010000000ZZZZ
0:ZZZP3oool20:ZZZP030?ooo`2ZZZX000000080ZZZZ0P3oool01@2ZZZX000000?ooo`000000EEEE
00<0ZZZZ00@0000005EEE@1EEED0ZZZZ0`1EEED20:ZZZP80oooo00<0ZZZZ05EEE@1EEED00P1EEED0
1@2ZZZX0EEEE05EEE@000000oooo0080ZZZZ0P0000000`3oool0EEEE0:ZZZP020?ooo`050:ZZZP00
000000000:ZZZP3oool00P2ZZZX0103oool0ZZZZ0:ZZZP2ZZZX60?ooo`X0dLfY1P3oool3000000D0
oooo101EEED00`000000EEEE000000050:ZZZP050000001EEED0oooo0000003oool00`0000020:ZZ
ZP80oooo00@0ZZZZ00000000000000000P3oool010000000oooo05EEE@3oool50:ZZZP040000001E
EED000000?ooo`<0EEEE00<0oooo0000003oool00P3oool2000000030:ZZZP3oool0oooo00@0oooo
2P3AcJT60?ooo`0505EEE@000000ZZZZ05EEE@0000000P3oool205EEE@80ZZZZ00D000000?ooo`00
0000EEEE0000000205EEE@040?ooo`000000EEEE0?ooo`<0ZZZZ00H0EEEE0:ZZZP2ZZZX0ZZZZ0000
001EEED3000000D0ZZZZ0`3oool02`000000oooo0?ooo`1EEED000000:ZZZP000000oooo0000002Z
ZZX0000000<0EEEE00H0oooo000000000000ZZZZ0000002ZZZX60?ooo``0dLfY000;0=7=Z@H0oooo
0`1EEED20?ooo`0705EEE@00000000000000003oool000000?ooo`0200000080ZZZZ00H0EEEE0?oo
o`3oool0EEEE0000003oool305EEE@040:ZZZP000000000000000080EEEE00<0000005EEE@000000
0P0000000`2ZZZX0EEEE05EEE@020?ooo`070:ZZZP1EEED0oooo0:ZZZP1EEED0ZZZZ0?ooo`020000
00030?ooo`00000000000080000000@0ZZZZ05EEE@3oool0ZZZZ0P1EEED70?ooo`X0dLfY1P3oool6
05EEE@080?ooo`2ZZZX0oooo0?ooo`000000EEEE0:ZZZP1EEED30?ooo`0305EEE@3oool000000080
oooo0`1EEED40000000505EEE@3oool0EEEE05EEE@2ZZZX00P00000305EEE@040:ZZZP3oool0oooo
000000@0oooo0P1EEED01P2ZZZX0EEEE0000002ZZZX0oooo0:ZZZPH0EEEE1`3oool:0=7=Z@H0oooo
0`1EEED00`000000oooo000000020:ZZZP040?ooo`2ZZZX0EEEE00000080ZZZZ0P1EEED0202ZZZX0
EEEE0?ooo`3oool000000:ZZZP3oool0ZZZZ0`3oool00`2ZZZX0EEEE0?ooo`040?ooo`080:ZZZP3o
ool0ZZZZ0?ooo`2ZZZX0oooo0:ZZZP1EEED20?ooo`80ZZZZ00T0EEEE0?ooo`2ZZZX0ZZZZ0000001E
EED000000?ooo`2ZZZX00P000000103oool0EEEE05EEE@1EEED70?ooo`X0dLfY1P3oool305EEE@80
00000P1EEED01P000000oooo0:ZZZP1EEED000000?ooo`L0000000D0ZZZZ0?ooo`000000oooo0000
000405EEE@D0oooo0`1EEED010000000oooo05EEE@3oool6000000050?ooo`000000oooo0?ooo`1E
EED00P3oool010000000oooo05EEE@00000305EEE@L0oooo2P3AcJT60?ooo`0405EEE@2ZZZX00000
0?ooo`80EEEE0P0000000`1EEED0ZZZZ0:ZZZP0200000080ZZZZ00<0EEEE0000000000000P1EEED2
00000080ZZZZ00P000000:ZZZP2ZZZX000000?ooo`2ZZZX0EEEE00000080ZZZZ00D000000:ZZZP2Z
ZZX000000:ZZZP02000000<0EEEE0P000000201EEED0oooo0:ZZZP000000oooo0:ZZZP000000EEEE
0P00000205EEE@030:ZZZP000000ZZZZ00L0oooo303AcJT000/0dLfY1`3oool00`2ZZZX0EEEE0?oo
o`020?ooo`80000000<0ZZZZ0000001EEED00`1EEED20:ZZZP0605EEE@3oool0oooo0?ooo`2ZZZX0
00000`2ZZZX0101EEED0ZZZZ0000003oool2000000040?ooo`0000000000000000D0ZZZZ0P000003
0?ooo`0305EEE@2ZZZX0EEEE0080EEEE00H0ZZZZ05EEE@000000ZZZZ0000002ZZZX30?ooo`0305EE
E@2ZZZX0oooo00H0oooo2P3AcJT70?ooo`050:ZZZP1EEED0oooo05EEE@2ZZZX00P1EEED200000005
05EEE@2ZZZX0ZZZZ0?ooo`2ZZZX00`1EEED01`2ZZZX0EEEE0000001EEED0oooo0:ZZZP3oool00`1E
EED01@000000ZZZZ0?ooo`3oool0ZZZZ00@0EEEE00H0oooo0:ZZZP3oool0EEEE0000001EEED20:ZZ
ZP<0EEEE00@0oooo0:ZZZP2ZZZX0EEEE0P0000001`1EEED0ZZZZ0:ZZZP1EEED0ZZZZ05EEE@2ZZZX0
1`3oool:0=7=Z@L0oooo00D0ZZZZ0?ooo`2ZZZX000000:ZZZP03000000050?ooo`2ZZZX000000:ZZ
ZP1EEED00P3oool0202ZZZX0oooo0?ooo`3oool0ZZZZ0000001EEED0ZZZZ0P0000000`1EEED0oooo
0?ooo`020000000505EEE@000000oooo0?ooo`1EEED00P0000000`2ZZZX0EEEE000000030?ooo`80
ZZZZ00D0oooo0000001EEED0ZZZZ0?ooo`020:ZZZP80000000<0oooo0:ZZZP0000000P3oool00`2Z
ZZX0oooo0?ooo`050?ooo`X0dLfY1`3oool0102ZZZX0oooo0000000000020?ooo`80000000D0ZZZZ
0?ooo`000000ZZZZ0000000605EEE@80oooo0P0000000`2ZZZX0oooo000000020?ooo`80000000P0
EEEE0000003oool0oooo0000003oool0ZZZZ00000080oooo1`1EEED01@000000ZZZZ05EEE@3oool0
ZZZZ008000000P3oool010000000oooo0?ooo`2ZZZX70?ooo`X0dLfY1`3oool20:ZZZP0605EEE@00
000000000:ZZZP000000EEEE0P2ZZZX01`000000oooo0000001EEED0ZZZZ0?ooo`2ZZZX00P3oool0
1P1EEED0000005EEE@1EEED0ZZZZ00000080ZZZZ00H0EEEE0000002ZZZX0oooo0000001EEED40:ZZ
ZP0405EEE@2ZZZX000000:ZZZP80oooo00`000000?ooo`2ZZZX0EEEE0000003oool000000:ZZZP00
0000EEEE0000001EEED20000000305EEE@2ZZZX0ZZZZ00L0oooo303AcJT000/0dLfY2@3oool30:ZZ
ZP<0EEEE0P0000000`2ZZZX0EEEE05EEE@020:ZZZP070?ooo`00000000000000002ZZZX000000?oo
o`0205EEE@040:ZZZP3oool0000000000080oooo00H000000?ooo`3oool000000?ooo`2ZZZX305EE
E@@0000000@0ZZZZ0?ooo`2ZZZX0ZZZZ0P1EEED00`2ZZZX0000005EEE@0205EEE@040?ooo`2ZZZX0
ZZZZ0:ZZZPT0oooo2P3AcJT90?ooo`0;05EEE@00000000000000001EEED0ZZZZ0000002ZZZX00000
0?ooo`1EEED0100000001P1EEED0oooo05EEE@3oool000000:ZZZP80oooo0P00000305EEE@030?oo
o`1EEED0EEEE0080000000P0EEEE0?ooo`2ZZZX0EEEE0?ooo`1EEED0oooo05EEE@@0000000L0EEEE
0?ooo`2ZZZX0ZZZZ05EEE@2ZZZX0EEEE00<0000000<0ZZZZ0?ooo`3oool01`3oool:0=7=Z@T0oooo
00<000000:ZZZP3oool01@3oool205EEE@80ZZZZ103oool00`1EEED0oooo0:ZZZP020:ZZZP80oooo
0P2ZZZX200000080oooo00<000000?ooo`2ZZZX00P2ZZZX00`3oool0ZZZZ000000020:ZZZP0305EE
E@3oool0ZZZZ0080oooo00H000000:ZZZP1EEED0EEEE0?ooo`2ZZZX20?ooo`040:ZZZP3oool0ZZZZ
0:ZZZPT0oooo2P3AcJT90?ooo`@000000P3oool03@000000EEEE0000002ZZZX0oooo05EEE@3oool0
EEEE0?ooo`000000EEEE0?ooo`2ZZZX00P000000103oool000000000003oool2000000030:ZZZP1E
EED000000080oooo0P0000001P3oool0000005EEE@2ZZZX0oooo05EEE@80000000D0EEEE0?ooo`00
0000oooo0:ZZZP0205EEE@@0oooo0P0000000`2ZZZX0oooo0?ooo`070?ooo`X0dLfY2@3oool01000
0000oooo0?ooo`3oool2000000080:ZZZP1EEED000000:ZZZP1EEED0000005EEE@2ZZZX40?ooo`04
0:ZZZP000000000000000080oooo00D000000:ZZZP000000oooo05EEE@0300000080oooo0P000002
0:ZZZP@0oooo00D0ZZZZ05EEE@1EEED0EEEE0:ZZZP0305EEE@80000000@0EEEE0?ooo`3oool0ZZZZ
2@3oool<0=7=Z@002`3AcJT90?ooo`80EEEE0P3oool0102ZZZX0oooo0000000000030:ZZZP040?oo
o`2ZZZX0ZZZZ0?ooo`<0000000L0ZZZZ0?ooo`000000oooo05EEE@3oool000000080EEEE00<00000
0:ZZZP1EEED00P0000030?ooo`040000001EEED0ZZZZ0?ooo`<000001@2ZZZX01@3oool000000?oo
o`3oool0ZZZZ0080oooo00<0EEEE0?ooo`3oool0203oool:0=7=Z@T0oooo1@1EEED01@3oool00000
000000000000oooo00H0EEEE0`3oool200000080ZZZZ00<0000005EEE@3oool00P1EEED01@2ZZZX0
EEEE0:ZZZP1EEED000000080ZZZZ00D000000?ooo`3oool000000?ooo`0605EEE@030?ooo`000000
00000080oooo101EEED:0?ooo`X0dLfY2@3oool305EEE@030000002ZZZX000000080EEEE0P3oool0
0`2ZZZX0EEEE0000000205EEE@040:ZZZP1EEED0oooo0?ooo`<0EEEE0`0000001@2ZZZX0oooo05EE
E@000000oooo00<0000000@0ZZZZ05EEE@1EEED0EEEE0P3oool01@1EEED0ZZZZ05EEE@1EEED00000
0080ZZZZ00D0oooo0:ZZZP1EEED0ZZZZ000000020:ZZZP80EEEE2P3oool:0=7=Z@T0oooo0`1EEED0
1@000000ZZZZ0000002ZZZX0oooo00<000000`3oool00`2ZZZX000000?ooo`020?ooo`80ZZZZ101E
EED01P000000oooo0?ooo`2ZZZX0oooo000000@0EEEE00<0ZZZZ05EEE@3oool00P3oool200000080
oooo00<0ZZZZ0000000000000P3oool2000000040:ZZZP1EEED0EEEE05EEE@X0oooo2P3AcJT90?oo
o`80EEEE0P000000101EEED0ZZZZ0:ZZZP3oool20:ZZZP060?ooo`2ZZZX0ZZZZ0:ZZZP000000ZZZZ
0P000000102ZZZX0000005EEE@2ZZZX200000080ZZZZ00<0EEEE0000000000000P1EEED01@2ZZZX0
00000000002ZZZX0EEEE0080ZZZZ0P0000002@2ZZZX000000:ZZZP2ZZZX0EEEE0?ooo`2ZZZX0EEEE
0?ooo`020:ZZZP80EEEE00<0000005EEE@3oool02@3oool<0=7=Z@002`3AcJT;0?ooo`0305EEE@3o
ool0ZZZZ00@0oooo00<0ZZZZ0000001EEED00P2ZZZX01@000000oooo0?ooo`000000ZZZZ0080oooo
00@000000:ZZZP1EEED0EEEE0P2ZZZX2000000070:ZZZP000000EEEE05EEE@3oool000000?ooo`02
0:ZZZP040000003oool0oooo000000<0ZZZZ00H000000:ZZZP000000oooo0:ZZZP3oool20:ZZZP03
05EEE@3oool0oooo00T0oooo2P3AcJT;0?ooo`0305EEE@000000oooo00L0ZZZZ00T000000:ZZZP2Z
ZZX0ZZZZ0?ooo`2ZZZX0oooo05EEE@3oool00P1EEED01@3oool0EEEE0:ZZZP1EEED0000000@0EEEE
00D0oooo05EEE@1EEED0oooo0:ZZZP030?ooo`050:ZZZP3oool0ZZZZ0000003oool01P2ZZZX00`3o
ool0EEEE05EEE@0;0?ooo`X0dLfY2`3oool01`1EEED0oooo0?ooo`2ZZZX0EEEE0:ZZZP0000000`3o
ool2000000050?ooo`00000000000000001EEED00P000000102ZZZX0EEEE0:ZZZP3oool20:ZZZP80
EEEE0P2ZZZX01P3oool0ZZZZ0000002ZZZX000000?ooo`80EEEE1@0000030?ooo`80ZZZZ00D0EEEE
0:ZZZP3oool0000005EEE@0;0?ooo`X0dLfY2`3oool0101EEED0oooo0:ZZZP0000020?ooo`80EEEE
00@0ZZZZ0?ooo`000000oooo0P1EEED20?ooo`040000001EEED0oooo0?ooo`80ZZZZ0P0000040?oo
o`80000000<0ZZZZ0?ooo`3oool00P3oool2000000040?ooo`1EEED0EEEE0?ooo`80000000T0ZZZZ
05EEE@1EEED0oooo05EEE@000000ZZZZ0000001EEED02`3oool:0=7=Z@/0oooo00@0EEEE0000001E
EED0EEEE0`0000020:ZZZP80000000L0ZZZZ05EEE@3oool000000:ZZZP1EEED0ZZZZ0080000000<0
EEEE0000000000000`2ZZZX00`3oool0ZZZZ0000000500000080EEEE0P0000020?ooo`030:ZZZP00
0000EEEE00<0ZZZZ0P00000205EEE@030:ZZZP1EEED0oooo00X0oooo303AcJT000/0dLfY303oool0
1@2ZZZX000000?ooo`1EEED0ZZZZ00<0000000<0ZZZZ0?ooo`0000000P00000405EEE@80000000<0
ZZZZ0?ooo`3oool00P000000103oool000000000000000020?ooo`0:0:ZZZP00000000000?ooo`1E
EED0000005EEE@000000ZZZZ00000080oooo0P0000001P1EEED0ZZZZ05EEE@3oool000000:ZZZP`0
oooo2P3AcJT<0?ooo`0305EEE@000000000000D000000`1EEED300000080oooo00@0EEEE0:ZZZP1E
EED0ZZZZ0`1EEED00`3oool0EEEE05EEE@020?ooo`80EEEE00<0ZZZZ05EEE@2ZZZX00P3oool0101E
EED0000000000000000205EEE@P0000000<0ZZZZ0?ooo`3oool02P3oool:0=7=Z@`0oooo00/00000
0:ZZZP2ZZZX0oooo0:ZZZP3oool0000005EEE@2ZZZX0EEEE0:ZZZP0205EEE@070?ooo`2ZZZX0ZZZZ
0000003oool0ZZZZ05EEE@020?ooo`0305EEE@3oool0000000D0oooo0P2ZZZX01P3oool0ZZZZ0:ZZ
ZP1EEED0oooo05EEE@80ZZZZ0`1EEED010000000ZZZZ0:ZZZP3oool30:ZZZP`0oooo2P3AcJT<0?oo
o`<000000P3oool01@000000oooo0?ooo`1EEED0000000@0ZZZZ0P1EEED00`000000oooo05EEE@06
0000000305EEE@000000oooo00<0000000D0EEEE0?ooo`3oool0EEEE000000040:ZZZP030000001E
EED0oooo00@0oooo0P0000000`2ZZZX0oooo0?ooo`0:0?ooo`X0dLfY303oool0102ZZZX0EEEE0?oo
o`00000205EEE@050000003oool0ZZZZ0:ZZZP1EEED00`0000030:ZZZP060000001EEED0ZZZZ0:ZZ
ZP1EEED0ZZZZ0P000000102ZZZX000000:ZZZP1EEED20:ZZZP0505EEE@000000ZZZZ0:ZZZP3oool0
0P00000205EEE@0:0:ZZZP1EEED0oooo0000002ZZZX0EEEE0:ZZZP3oool0EEEE0:ZZZP`0oooo303A
cJT000/0dLfY303oool305EEE@80oooo00D0ZZZZ000000000000EEEE0?ooo`02000000030?ooo`00
000000000080oooo0P0000020:ZZZP@0000000H0ZZZZ0000002ZZZX000000:ZZZP3oool2000000<0
oooo00@000000?ooo`00000000000P3oool20000000305EEE@3oool0ZZZZ0080EEEE3@3oool:0=7=
Z@`0oooo2@1EEED00`3oool0EEEE05EEE@0205EEE@040?ooo`000000oooo05EEE@<0oooo00<00000
05EEE@1EEED00P2ZZZX01P1EEED0oooo0000003oool0EEEE0?ooo`80EEEE00<0000005EEE@1EEED0
0`1EEED00`3oool0EEEE05EEE@0605EEE@d0oooo2P3AcJT<0?ooo`<0EEEE00D000000?ooo`000000
ZZZZ0?ooo`040:ZZZP80oooo0`2ZZZX2000000@0oooo00@000000?ooo`1EEED000000`3oool30000
00030?ooo`2ZZZX0oooo00<0oooo0P2ZZZX20?ooo`030:ZZZP000000oooo00<0EEEE3@3oool:0=7=
Z@`0oooo0`1EEED2000000040?ooo`1EEED000000?ooo`D000000P3oool00`1EEED0ZZZZ05EEE@03
05EEE@80ZZZZ00<0oooo05EEE@2ZZZX00`1EEED01@3oool0EEEE0:ZZZP000000oooo00H0000000D0
oooo0000001EEED0EEEE0000000305EEE@d0oooo2P3AcJT<0?ooo`0905EEE@00000000000:ZZZP1E
EED0oooo0:ZZZP000000EEEE00<0oooo00D0ZZZZ0000001EEED0ZZZZ05EEE@020:ZZZP050?ooo`2Z
ZZX0ZZZZ0000002ZZZX00P1EEED70:ZZZP0605EEE@2ZZZX0EEEE0000002ZZZX000000P3oool20000
00040:ZZZP3oool0EEEE0:ZZZP8000003@3oool<0=7=Z@002`3AcJT>0?ooo`@0EEEE00<0ZZZZ0000
000000000P0000000`3oool0ZZZZ0?ooo`02000000030?ooo`00000000000080ZZZZ00D000000:ZZ
ZP000000EEEE0:ZZZP03000000050:ZZZP3oool000000000002ZZZX00P0000000`3oool0ZZZZ0?oo
o`0400000080ZZZZ00<0EEEE0:ZZZP1EEED03P3oool:0=7=Z@h0oooo00H0EEEE0000003oool0ZZZZ
0?ooo`00000205EEE@080:ZZZP1EEED0EEEE0?ooo`1EEED0ZZZZ05EEE@0000020:ZZZP80oooo00@0
ZZZZ0000002ZZZX0ZZZZ0P0000020?ooo`80ZZZZ00<000000?ooo`2ZZZX00P3oool00`1EEED0ZZZZ
0:ZZZP0205EEE@040000003oool0ZZZZ0?ooo`80EEEE3P3oool:0=7=Z@h0oooo00<0EEEE0?ooo`00
00000P1EEED50?ooo`0305EEE@2ZZZX0ZZZZ0080ZZZZ0100oooo0000002ZZZX0ZZZZ0?ooo`000000
oooo05EEE@000000oooo0:ZZZP3oool0ZZZZ05EEE@000000oooo102ZZZX205EEE@80oooo00@0EEEE
0?ooo`1EEED0ZZZZ0P0000000`1EEED0oooo0?ooo`0<0?ooo`X0dLfY3P3oool0101EEED0oooo0:ZZ
ZP00000305EEE@80oooo0P0000020:ZZZP030?ooo`1EEED0oooo00<0oooo00@0EEEE000000000000
ZZZZ0`0000000`1EEED0oooo0?ooo`050?ooo`030:ZZZP000000000000<0oooo0P1EEED010000000
ZZZZ0000001EEED>0?ooo`X0dLfY3P3oool01`1EEED00000000000000000EEEE0:ZZZP3oool00P1E
EED50:ZZZP030000002ZZZX0oooo00<0oooo00<000000:ZZZP0000000P2ZZZX00`000000oooo0?oo
o`020?ooo`040:ZZZP000000ZZZZ0?ooo`<0ZZZZ0`1EEED0102ZZZX0EEEE0?ooo`00000205EEE@h0
oooo303AcJT000/0dLfY3`3oool20:ZZZP050?ooo`1EEED0EEEE05EEE@0000000`2ZZZX305EEE@06
0?ooo`00000000000:ZZZP1EEED0ZZZZ0P0000001`2ZZZX0oooo000000000000ZZZZ05EEE@2ZZZX0
0P00000405EEE@040:ZZZP000000ZZZZ000000<0EEEE0`2ZZZX?0?ooo`X0dLfY3`3oool01@1EEED0
0000000000000000EEEE0080oooo00<0ZZZZ0?ooo`1EEED00P1EEED20?ooo`<000000P2ZZZX205EE
E@040000001EEED0EEEE00000080ZZZZ0`0000020?ooo`030:ZZZP1EEED0EEEE0080ZZZZ00<0oooo
0:ZZZP1EEED00`0000000`2ZZZX0oooo0?ooo`0=0?ooo`X0dLfY3`3oool00`000000ZZZZ0:ZZZP02
0?ooo`030000001EEED000000080oooo1@000000102ZZZX0EEEE0?ooo`3oool205EEE@80ZZZZ00<0
EEEE0?ooo`3oool00P3oool00`2ZZZX000000000000300000080oooo00<0000005EEE@3oool00`3o
ool20:ZZZPl0oooo2P3AcJT?0?ooo`80000000D0oooo0000003oool0oooo0000000305EEE@80oooo
00<0EEEE0?ooo`3oool0103oool01P000000oooo000000000000oooo000000D0oooo00@0000005EE
E@3oool0oooo0`1EEED00`000000oooo0?ooo`03000000030:ZZZP3oool0oooo00d0oooo2P3AcJT?
0?ooo`0505EEE@000000000005EEE@0000000P3oool01@000000EEEE0?ooo`000000EEEE00<0ZZZZ
0P0000001P2ZZZX000000?ooo`000000oooo05EEE@<0000000P0ZZZZ000000000000ZZZZ05EEE@2Z
ZZX0EEEE00000080oooo00P000000?ooo`3oool0000005EEE@2ZZZX000000:ZZZPl0oooo303AcJT0
00/0dLfY3`3oool205EEE@80oooo00D0ZZZZ0?ooo`00000000000?ooo`050:ZZZP80000000<0oooo
0:ZZZP1EEED00P0000001@1EEED0oooo0000002ZZZX0EEEE0080ZZZZ0P0000050:ZZZP<0000000D0
oooo0:ZZZP3oool0oooo05EEE@0@0?ooo`X0dLfY3`3oool505EEE@@0oooo00<000000?ooo`1EEED0
1P1EEED00`000000ZZZZ0?ooo`0205EEE@030?ooo`1EEED0000000@0EEEE00H0ZZZZ05EEE@3oool0
oooo0000001EEED30?ooo`@0EEEE403oool:0=7=Z@l0oooo0P1EEED01`2ZZZX000000:ZZZP2ZZZX0
oooo05EEE@2ZZZX01P1EEED20?ooo`040000001EEED0oooo0?ooo`80000000@0oooo0000001EEED0
00000P3oool0101EEED0oooo05EEE@3oool405EEE@040?ooo`000000ZZZZ00000080EEEE403oool:
0=7=Z@l0oooo0`1EEED01P000000ZZZZ0000002ZZZX0oooo0:ZZZP@0oooo00<0000005EEE@3oool0
0P1EEED30000000:05EEE@2ZZZX000000?ooo`000000EEEE0000003oool0EEEE000000H0oooo00@0
ZZZZ0000002ZZZX000000P1EEED@0?ooo`X0dLfY3`3oool01P1EEED0ZZZZ0:ZZZP3oool0EEEE0000
0080EEEE0P0000001@2ZZZX0oooo0:ZZZP2ZZZX0000000<0ZZZZ00<0oooo0:ZZZP0000000P3oool2
000000050?ooo`2ZZZX0EEEE0:ZZZP0000000P2ZZZX00`3oool0ZZZZ0000000505EEE@030?ooo`00
0000ZZZZ0100oooo303AcJT000/0dLfY4@3oool0102ZZZX0oooo0:ZZZP2ZZZX30?ooo`H0000000L0
ZZZZ0?ooo`1EEED0ZZZZ0000001EEED0oooo0080EEEE0P2ZZZX01`1EEED0oooo0:ZZZP000000ZZZZ
0000002ZZZX00`0000030?ooo`030:ZZZP3oool0EEEE0140oooo2P3AcJTA0?ooo`0305EEE@000000
oooo00<0ZZZZ00@0oooo05EEE@1EEED0ZZZZ0`3oool01P1EEED000000?ooo`2ZZZX0oooo05EEE@80
000000@0EEEE0000002ZZZX0oooo0P1EEED30?ooo`<0EEEE00L0oooo0:ZZZP2ZZZX0ZZZZ0?ooo`00
0000EEEE0140oooo2P3AcJTA0?ooo`030000003oool0oooo0080EEEE0P000000202ZZZX0EEEE0000
002ZZZX000000:ZZZP1EEED0ZZZZ0P0000001@2ZZZX0oooo0:ZZZP1EEED0oooo00<0000000P0oooo
05EEE@2ZZZX000000:ZZZP3oool0EEEE0:ZZZP80000000D0EEEE0:ZZZP3oool0oooo05EEE@0A0?oo
o`X0dLfY4@3oool010000000oooo0:ZZZP1EEED20?ooo`80EEEE00<0oooo05EEE@1EEED00P2ZZZX0
0`3oool00000000000020:ZZZP@0000000P0oooo0:ZZZP000000ZZZZ0?ooo`2ZZZX0oooo05EEE@80
oooo0P1EEED20?ooo`040000002ZZZX0oooo05EEEA40oooo2P3AcJTA0?ooo`80000000D0EEEE0:ZZ
ZP2ZZZX0000005EEE@020?ooo`0505EEE@000000ZZZZ0?ooo`1EEED00P0000000`3oool0ZZZZ05EE
E@0305EEE@80oooo0P0000001@1EEED0oooo000000000000ZZZZ0080oooo0P0000020:ZZZP0305EE
E@000000EEEE0140oooo303AcJT000/0dLfY4@3oool20:ZZZP060000001EEED0EEEE0:ZZZP000000
oooo0P0000020:ZZZP80000000D0EEEE0?ooo`2ZZZX0oooo000000020?ooo`80000000<0ZZZZ0?oo
o`0000000P0000002`1EEED0ZZZZ000000000000oooo05EEE@2ZZZX0EEEE0?ooo`000000ZZZZ0180
oooo2P3AcJTA0?ooo`030:ZZZP1EEED0000000<0000000<0EEEE0?ooo`1EEED01@3oool0101EEED0
00000000003oool405EEE@<0000000<0ZZZZ0?ooo`3oool00P3oool205EEE@030?ooo`0000000000
00<0000000<0EEEE0?ooo`3oool0403oool:0=7=ZA40oooo00<0ZZZZ0000002ZZZX00P3oool02@2Z
ZZX0oooo0:ZZZP2ZZZX000000?ooo`2ZZZX0oooo0:ZZZP0205EEE@050?ooo`1EEED0EEEE0?ooo`2Z
ZZX00P1EEED01`3oool0EEEE05EEE@2ZZZX0oooo0000003oool00`2ZZZX00`000000ZZZZ0?ooo`02
0:ZZZP030000003oool0oooo0100oooo2P3AcJTA0?ooo`030:ZZZP000000000000<0oooo00H00000
0?ooo`3oool0oooo0000001EEED20?ooo`80EEEE0P3oool405EEE@80oooo00<0EEEE0?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`<000004P3oool:0=7=ZA40oooo00H0ZZZZ0000003oool0
EEEE0?ooo`0000030?ooo`0605EEE@2ZZZX0EEEE05EEE@000000oooo0P0000050:ZZZPD0000000<0
EEEE0:ZZZP2ZZZX00`3oool2000000<0oooo00<000000?ooo`3oool0403oool<0=7=Z@002`3AcJTB
0?ooo`80EEEE00L0ZZZZ0?ooo`3oool0ZZZZ0000002ZZZX000000080oooo0P0000000`1EEED0oooo
0000000205EEE@070:ZZZP1EEED0EEEE0:ZZZP000000oooo0:ZZZP02000000060:ZZZP3oool00000
0:ZZZP000000EEEE0P3oool305EEEA80oooo2P3AcJTB0?ooo`H0EEEE00<0oooo0000003oool0103o
ool405EEE@@0ZZZZ0`1EEED60?ooo`030000003oool0EEEE00D0EEEE4P3oool:0=7=ZA80oooo0`1E
EED01`000000oooo0:ZZZP2ZZZX0oooo0:ZZZP1EEED00`3oool01@2ZZZX0oooo0?ooo`2ZZZX0EEEE
0080oooo00D0EEEE0?ooo`3oool0oooo05EEE@020?ooo`80EEEE00H0ZZZZ0?ooo`2ZZZX000000?oo
o`00000305EEEA80oooo2P3AcJTB0?ooo`<0EEEE0P0000000`3oool0EEEE0000000205EEE@030000
003oool0EEEE0080oooo0P0000002@3oool000000?ooo`3oool0EEEE0000003oool0000005EEE@02
0?ooo`0305EEE@00000000000080EEEE0P00000305EEEA80oooo2P3AcJTB0?ooo`<0EEEE01000000
05EEE@00000000000:ZZZP000000EEEE0?ooo`2ZZZX0EEEE0:ZZZP000000EEEE0000002ZZZX00000
0`2ZZZX0301EEED000000000001EEED0ZZZZ0?ooo`1EEED000000:ZZZP000000ZZZZ05EEE@800000
0P1EEEDB0?ooo``0dLfY000;0=7=ZA@0oooo00T0ZZZZ05EEE@1EEED0EEEE0:ZZZP000000oooo0:ZZ
ZP3oool00P0000000`1EEED0oooo0:ZZZP020?ooo`050:ZZZP1EEED0oooo0?ooo`2ZZZX00P3oool2
0000000405EEE@2ZZZX0000000000080ZZZZ0`1EEEDD0?ooo`X0dLfY503oool0201EEED000000?oo
o`2ZZZX0oooo0000003oool0EEEE0P3oool20:ZZZP040000002ZZZX0oooo05EEE@80oooo00L0EEEE
0000002ZZZX000000?ooo`2ZZZX0oooo0080EEEE00L0oooo0000003oool0ZZZZ0?ooo`000000EEEE
01@0oooo2P3AcJTD0?ooo`030000003oool0000000<0EEEE00/0oooo0:ZZZP000000000005EEE@00
0000oooo0000001EEED000000:ZZZP02000000060:ZZZP000000oooo0000001EEED000000P2ZZZX3
05EEE@040:ZZZP000000oooo05EEEA@0oooo2P3AcJTD0?ooo`040000003oool0ZZZZ00000080EEEE
0P3oool20:ZZZP80oooo00@0ZZZZ000000000000ZZZZ0P3oool0102ZZZX000000000002ZZZX20?oo
o`80ZZZZ0P3oool205EEE@040000002ZZZX0oooo05EEEA@0oooo2P3AcJTD0?ooo`030:ZZZP000000
EEEE0080000000<0EEEE0?ooo`3oool00`3oool00`1EEED0oooo05EEE@0200000080oooo00D00000
0:ZZZP1EEED0oooo000000040?ooo`80EEEE00D0000005EEE@1EEED0000005EEE@0D0?ooo``0dLfY
000;0=7=ZA@0oooo0`2ZZZX0103oool0EEEE05EEE@1EEED20:ZZZP80000000<0EEEE0:ZZZP1EEED0
0P1EEED01`3oool0ZZZZ05EEE@2ZZZX0EEEE0:ZZZP3oool00P0000020:ZZZP<0EEEE0`2ZZZXE0?oo
o`X0dLfY503oool00`2ZZZX0EEEE00000002000000@0EEEE0P00000305EEE@80ZZZZ00@000000:ZZ
ZP2ZZZX000000P1EEED3000000040?ooo`1EEED0ZZZZ05EEE@<0000000<0EEEE0?ooo`3oool04`3o
ool:0=7=ZA@0oooo00@0ZZZZ0000002ZZZX0ZZZZ0P3oool305EEE@030?ooo`1EEED0ZZZZ0080EEEE
00H0oooo0000003oool0ZZZZ0000003oool205EEE@030:ZZZP1EEED0oooo0080EEEE00H0ZZZZ0?oo
o`3oool0oooo0:ZZZP00000E0?ooo`X0dLfY503oool01@2ZZZX000000000003oool0000000<0oooo
00<0EEEE0?ooo`3oool00P3oool205EEE@@0oooo0P1EEED80?ooo`@000005@3oool:0=7=ZA@0oooo
0P2ZZZX0101EEED0ZZZZ0000001EEED4000000060:ZZZP3oool0oooo0?ooo`1EEED0ZZZZ0P000000
1P2ZZZX000000?ooo`3oool000000:ZZZP@0000000D0EEEE0000003oool0EEEE0:ZZZP0E0?ooo``0
dLfY000;0=7=ZAD0oooo0P1EEED20?ooo`040:ZZZP3oool000000?ooo`80000000P0EEEE0:ZZZP2Z
ZZX0EEEE0?ooo`000000ZZZZ0?ooo`<0ZZZZ00L0oooo000000000000ZZZZ0000003oool0ZZZZ0080
oooo0P1EEEDE0?ooo`X0dLfY5@3oool505EEE@030?ooo`000000EEEE00<0EEEE00@0oooo05EEE@1E
EED000000P1EEED010000000EEEE05EEE@3oool305EEE@030?ooo`000000oooo00D0EEEE5@3oool:
0=7=ZAD0oooo0P1EEED00`2ZZZX000000:ZZZP050?ooo`030000003oool0oooo0080EEEE0P3oool0
1@1EEED000000?ooo`3oool000000080oooo00D0ZZZZ0?ooo`2ZZZX0ZZZZ0000000305EEEAD0oooo
2P3AcJTE0?ooo`<0EEEE00@000000:ZZZP000000EEEE2`3oool00`2ZZZX0oooo0?ooo`030?ooo`05
0000001EEED000000:ZZZP0000000`1EEEDE0?ooo`X0dLfY5@3oool0101EEED000000:ZZZP2ZZZX5
05EEE@040?ooo`000000000000000080oooo0P1EEED00`3oool0000000000002000000070?ooo`1E
EED0EEEE05EEE@3oool0EEEE0:ZZZP020000000305EEE@3oool0oooo01<0oooo303AcJT000/0dLfY
5`3oool02@2ZZZX0oooo0:ZZZP2ZZZX0oooo0:ZZZP1EEED000000?ooo`020:ZZZP040?ooo`2ZZZX0
EEEE000000D0ZZZZ00<0000005EEE@1EEED00P3oool00`2ZZZX0oooo05EEE@0G0?ooo`X0dLfY5`3o
ool00`1EEED000000?ooo`030:ZZZP050?ooo`2ZZZX0ZZZZ0000001EEED00`2ZZZX0101EEED0ZZZZ
05EEE@1EEED2000000030:ZZZP3oool0ZZZZ0080ZZZZ00<0oooo0000001EEED05`3oool:0=7=ZAL0
oooo00L000000?ooo`3oool0EEEE0?ooo`2ZZZX000000080oooo00X0ZZZZ0?ooo`1EEED0ZZZZ0?oo
o`1EEED0ZZZZ0000003oool0ZZZZ0P3oool010000000oooo0?ooo`2ZZZX20?ooo`0305EEE@3oool0
oooo01D0oooo2P3AcJTG0?ooo`080000003oool0ZZZZ05EEE@3oool0ZZZZ0000003oool2000000P0
oooo00@000000?ooo`3oool000000P3oool010000000ZZZZ0?ooo`1EEEDG0?ooo`X0dLfY5`3oool0
0`1EEED0000000000002000000<0ZZZZ0P3oool205EEE@030:ZZZP1EEED000000080ZZZZ00<0EEEE
0?ooo`1EEED00P2ZZZX00`1EEED000000?ooo`020000000305EEE@3oool0oooo01D0oooo303AcJT0
00/0dLfY5`3oool20:ZZZP060000001EEED0EEEE0?ooo`000000oooo0P2ZZZX04@1EEED0ZZZZ0000
00000000oooo0000002ZZZX0EEEE0:ZZZP000000oooo0000002ZZZX0EEEE0?ooo`000000ZZZZ01P0
oooo2P3AcJTG0?ooo`030:ZZZP1EEED0000000@000000P1EEED00`000000ZZZZ0?ooo`0205EEE@05
0?ooo`1EEED0oooo0:ZZZP0000000P1EEED50000000305EEE@3oool0oooo01H0oooo2P3AcJTG0?oo
o`030:ZZZP000000ZZZZ00<0oooo1@1EEED20:ZZZP80oooo0P2ZZZX205EEE@030000001EEED0EEEE
0080oooo0P2ZZZX00`000000oooo0?ooo`0F0?ooo`X0dLfY5`3oool00`2ZZZX00000000000030?oo
o`80EEEE00<0oooo0000000000000`0000000`1EEED000000:ZZZP0300000080EEEE0P3oool30000
01P0oooo2P3AcJTG0?ooo`060:ZZZP1EEED000000000001EEED0oooo0P2ZZZX30?ooo`80ZZZZ00@0
EEEE0000002ZZZX0ZZZZ0`3oool30:ZZZP0405EEE@2ZZZX0000005EEEAP0oooo303AcJT000/0dLfY
603oool205EEE@040:ZZZP3oool0EEEE0:ZZZP80000000@0oooo0:ZZZP000000ZZZZ0P1EEED02@2Z
ZZX0oooo0:ZZZP3oool0ZZZZ0000002ZZZX0EEEE0?ooo`0305EEEAP0oooo2P3AcJTH0?ooo`X0EEEE
00H0oooo05EEE@1EEED0ZZZZ05EEE@00000205EEE@030?ooo`1EEED0EEEE00D0EEEE603oool:0=7=
ZAP0oooo0`1EEED00`000000EEEE0?ooo`020:ZZZP80oooo0P000000102ZZZX00000000000000002
0?ooo`0305EEE@2ZZZX0oooo008000000`1EEEDH0?ooo`X0dLfY603oool305EEE@060000001EEED0
oooo0:ZZZP000000oooo0P0000020?ooo`080000003oool000000000003oool0EEEE0:ZZZP3oool2
000000<0EEEE603oool:0=7=ZAP0oooo00H0EEEE0:ZZZP2ZZZX0oooo0000001EEED40?ooo`0505EE
E@000000ZZZZ0?ooo`0000001@3oool205EEE@040?ooo`000000ZZZZ05EEEAP0oooo303AcJT000/0
dLfY6P3oool01`2ZZZX0EEEE0:ZZZP2ZZZX000000:ZZZP0000000P3oool205EEE@040:ZZZP1EEED0
ZZZZ0?ooo`<0000000@0ZZZZ05EEE@1EEED0EEEE6P3oool:0=7=ZAX0oooo00@0EEEE0000002ZZZX0
ZZZZ1P3oool010000000EEEE0?ooo`2ZZZX20?ooo`060:ZZZP3oool0ZZZZ0?ooo`000000EEEE6P3o
ool:0=7=ZAX0oooo00@000000?ooo`2ZZZX000000P2ZZZX0103oool0000005EEE@1EEED20?ooo`04
05EEE@2ZZZX000000?ooo`80ZZZZ0P0000000`3oool0EEEE0?ooo`0I0?ooo`X0dLfY6P3oool01@00
0000oooo000000000000EEEE0080ZZZZ00l0EEEE0000003oool0oooo0:ZZZP3oool0000005EEE@2Z
ZZX0oooo05EEE@000000ZZZZ0?ooo`1EEED06P3oool:0=7=ZAX0oooo0P000000102ZZZX000000000
002ZZZX3000000040:ZZZP1EEED0EEEE0:ZZZPH0000000<0EEEE0000001EEED06P3oool<0=7=Z@00
2`3AcJTJ0?ooo`<0ZZZZ00@0EEEE0:ZZZP00000000000P3oool01P000000ZZZZ0?ooo`000000EEEE
0?ooo`80000000@0ZZZZ05EEE@2ZZZX0ZZZZ6`3oool:0=7=ZAX0oooo00<0ZZZZ05EEE@0000000P00
00001@1EEED0ZZZZ05EEE@000000oooo0080EEEE00D0oooo05EEE@1EEED0ZZZZ05EEE@0300000003
05EEE@3oool0oooo01T0oooo2P3AcJTJ0?ooo`070:ZZZP000000oooo0:ZZZP000000ZZZZ00000002
0:ZZZPD0oooo00@0ZZZZ0000001EEED000000P2ZZZX00`000000oooo0?ooo`0I0?ooo`X0dLfY6P3o
ool01P2ZZZX000000000003oool0000005EEE@80oooo00H0000005EEE@3oool0oooo05EEE@2ZZZX3
0?ooo`040000003oool00000000001/0oooo2P3AcJTJ0?ooo`030:ZZZP000000oooo0080EEEE00@0
oooo0000000000000000102ZZZX00`3oool000000000000305EEE@030?ooo`000000oooo01X0oooo
303AcJT000/0dLfY6`3oool00`1EEED0oooo0?ooo`0300000080ZZZZ00@000000?ooo`1EEED00000
0P2ZZZX010000000ZZZZ0000003oool205EEEA/0oooo2P3AcJTK0?ooo`@0EEEE00<0oooo05EEE@3o
ool00P1EEED20:ZZZP80EEEE00<0oooo05EEE@1EEED0101EEEDK0?ooo`X0dLfY6`3oool205EEE@03
0:ZZZP000000oooo0080EEEE00<0ZZZZ0000002ZZZX00P00000305EEE@030?ooo`000000ZZZZ0080
EEEE6`3oool:0=7=ZA/0oooo0`1EEED00`000000ZZZZ0:ZZZP02000000@0oooo0P0000020:ZZZP04
0000001EEED0EEEE05EEEA/0oooo2P3AcJTK0?ooo`0405EEE@000000EEEE000000<0EEEE00<00000
0:ZZZP0000000P2ZZZX305EEE@8000000`1EEEDK0?ooo``0dLfY000;0=7=ZA`0oooo00@0EEEE0:ZZ
ZP3oool00000101EEED00`2ZZZX0EEEE05EEE@0305EEE@030000003oool0ZZZZ01d0oooo2P3AcJTL
0?ooo`80EEEE00D000000:ZZZP2ZZZX0ZZZZ0000000405EEE@060?ooo`2ZZZX0ZZZZ0?ooo`000000
EEEE7@3oool:0=7=ZA`0oooo00H0EEEE0000003oool0ZZZZ0000002ZZZX205EEE@80oooo00@0EEEE
0:ZZZP2ZZZX000000P3oool00`000000oooo0?ooo`0K0?ooo`X0dLfY703oool01`1EEED000000?oo
o`000000EEEE0:ZZZP0000000P3oool020000000oooo0:ZZZP2ZZZX0EEEE0:ZZZP3oool000007@3o
ool:0=7=ZA`0oooo00<0EEEE0:ZZZP0000000P1EEED00`000000oooo0:ZZZP030:ZZZP0605EEE@00
0000EEEE05EEE@000000ZZZZ7@3oool<0=7=Z@002`3AcJTM0?ooo`80ZZZZ00T000000?ooo`3oool0
oooo05EEE@3oool0ZZZZ05EEE@2ZZZX00P3oool00`000000ZZZZ0:ZZZP0M0?ooo`X0dLfY7@3oool0
0`2ZZZX0EEEE000000020000000305EEE@2ZZZX0ZZZZ0080ZZZZ100000000`1EEED0ZZZZ0?ooo`0L
0?ooo`X0dLfY7@3oool01@2ZZZX000000:ZZZP3oool000000080oooo00<0EEEE0000003oool00P00
0000103oool0ZZZZ0000002ZZZXM0?ooo`X0dLfY7@3oool00`2ZZZX00000000000030?ooo`0305EE
E@2ZZZX000000080EEEE0P3oool2000000030:ZZZP3oool0oooo01/0oooo2P3AcJTM0?ooo`80ZZZZ
00H0oooo0:ZZZP1EEED000000:ZZZP0000020:ZZZP040000001EEED0ZZZZ05EEE@80ZZZZ7@3oool<
0=7=Z@002`3AcJTO0?ooo`0405EEE@3oool0ZZZZ0:ZZZP@0oooo0P2ZZZX00`3oool0ZZZZ0?ooo`0N
0?ooo`X0dLfY7`3oool01@1EEED0ZZZZ0?ooo`2ZZZX000000080ZZZZ00<000000?ooo`3oool00P2Z
ZZXO0?ooo`X0dLfY8@3oool00`2ZZZX0oooo0?ooo`02000000050?ooo`2ZZZX0ZZZZ0?ooo`2ZZZX0
7`3oool:0=7=ZB40oooo00@000000:ZZZP000000oooo0P000000102ZZZX000000?ooo`2ZZZXO0?oo
o`X0dLfY7`3oool010000000oooo05EEE@3oool40:ZZZP040?ooo`1EEED0oooo0:ZZZQl0oooo303A
cJT000/0dLfY7`3oool01P1EEED0ZZZZ05EEE@2ZZZX0EEEE0:ZZZP80EEEE00<0ZZZZ05EEE@2ZZZX0
803oool:0=7=ZAl0oooo0P1EEED010000000EEEE05EEE@00000205EEE@80000000<0EEEE0?ooo`3o
ool07P3oool:0=7=ZAl0oooo00H0EEEE0000003oool0000005EEE@3oool205EEE@030000003oool0
00000200oooo2P3AcJTO0?ooo`0;05EEE@000000oooo0:ZZZP3oool0ZZZZ0000003oool0ZZZZ0?oo
o`000000803oool:0=7=ZAl0oooo0P1EEED2000000040:ZZZP000000ZZZZ0:ZZZP80000000<0EEEE
0?ooo`3oool07P3oool<0=7=Z@002`3AcJTP0?ooo`80ZZZZ00@0oooo0:ZZZP1EEED0oooo102ZZZXP
0?ooo`X0dLfY803oool0102ZZZX0EEEE0:ZZZP3oool205EEE@040?ooo`000000EEEE0:ZZZR00oooo
2P3AcJTP0?ooo`040:ZZZP000000oooo00000080oooo00@000000:ZZZP000000ZZZZ803oool:0=7=
ZB00oooo00H0ZZZZ00000000000000000?ooo`2ZZZX3000000030:ZZZP3oool0oooo01h0oooo2P3A
cJTP0?ooo`030:ZZZP1EEED000000080oooo00D0EEEE0?ooo`2ZZZX0EEEE0:ZZZP0P0?ooo``0dLfY
000;0=7=ZB80oooo0P1EEED0103oool0EEEE05EEE@2ZZZXR0?ooo`X0dLfY8P3oool0101EEED0ZZZZ
0:ZZZP0000020:ZZZR80oooo2P3AcJTU0?ooo`0305EEE@3oool0ZZZZ0280oooo2P3AcJTT0?ooo`04
05EEE@000000oooo0:ZZZR80oooo2P3AcJTR0?ooo`80ZZZZ00@0oooo05EEE@2ZZZX0ZZZZ8P3oool<
0=7=Z@002`3AcJTR0?ooo`0505EEE@2ZZZX0oooo0?ooo`2ZZZX08`3oool:0=7=ZB80oooo0P1EEED0
0`2ZZZX0000005EEE@0S0?ooo`X0dLfY8P3oool01@1EEED000000?ooo`3oool0000002<0oooo2P3A
cJTR0?ooo`0505EEE@000000ZZZZ0?ooo`0000008`3oool:0=7=ZB80oooo00D0EEEE0000003oool0
oooo0000000S0?ooo``0dLfY000;0=7=ZB<0oooo00@0ZZZZ0000002ZZZX0ZZZZ8`3oool:0=7=ZB<0
oooo00@0ZZZZ0000001EEED0ZZZZ8`3oool:0=7=ZB<0oooo0P2ZZZX00`000000ZZZZ0?ooo`0R0?oo
o`X0dLfY8`3oool0102ZZZX000000000002ZZZXS0?ooo`X0dLfY8`3oool0102ZZZX000000000002Z
ZZXS0?ooo``0dLfY000;0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool:0=7=ZB@0oooo00<0ZZZZ
0?ooo`3oool08`3oool:0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool:0=7=ZB@0oooo00<0ZZZZ
0?ooo`3oool08`3oool:0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool<0=7=Z@00o`3AcJVb0=7=
Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@002`3AcJT02@3o
ool0EEEE0?ooo`000000oooo05EEE@000000oooo0:ZZZP020?ooo`040000003oool0oooo0?ooo`80
00000P2ZZZX01`000000oooo05EEE@000000EEEE0:ZZZP1EEED00`3oool00`1EEED0ZZZZ0?ooo`03
0?ooo`050000003oool0oooo0000002ZZZX00`3oool00`2ZZZX0EEEE0?ooo`020?ooo`0405EEE@2Z
ZZX0000000000080EEEE00@000000:ZZZP2ZZZX00000103oool010000000oooo0:ZZZP2ZZZX20?oo
o`0605EEE@3oool000000?ooo`1EEED0oooo2P3AcJT0103oool0ZZZZ05EEE@3oool300000080oooo
0P1EEED01P2ZZZX0EEEE0000001EEED0ZZZZ0?ooo`80ZZZZ00@0EEEE0?ooo`1EEED0EEEE0`3oool2
00000080oooo0P2ZZZX0103oool0EEEE05EEE@2ZZZX20?ooo`060:ZZZP000000EEEE0?ooo`1EEED0
ZZZZ0P3oool010000000EEEE0?ooo`3oool305EEE@0;0000001EEED0ZZZZ0000003oool0ZZZZ05EE
E@000000EEEE0:ZZZP1EEED00`3oool3000000040?ooo`1EEED0EEEE0?ooo`X0dLfY00@0oooo0:ZZ
ZP2ZZZX0EEEE1@2ZZZX01P000000ZZZZ0:ZZZP000000oooo00000080EEEE00/0ZZZZ000000000000
00000?ooo`2ZZZX0EEEE0:ZZZP1EEED0oooo05EEE@03000000030:ZZZP1EEED0EEEE0080ZZZZ0P3o
ool20:ZZZP80EEEE00L0ZZZZ000000000000ZZZZ05EEE@3oool0EEEE00<0ZZZZ0P3oool300000080
EEEE00<000000?ooo`3oool00P2ZZZX01@000000ZZZZ0:ZZZP1EEED0ZZZZ0080EEEE00<0ZZZZ05EE
E@3oool02P3AcJT02@3oool0EEEE05EEE@3oool000000?ooo`2ZZZX0EEEE0000000305EEE@80ZZZZ
00<0000005EEE@0000000P2ZZZX20?ooo`80000000D0ZZZZ0000002ZZZX0ZZZZ000000030?ooo`80
0000203oool200000080oooo00@0EEEE0000002ZZZX0ZZZZ1@000000203oool0ZZZZ0:ZZZP000000
EEEE0000002ZZZX000000P1EEED20000000505EEE@000000oooo0:ZZZP3oool00P1EEED00`3oool0
dLfY0=7=Z@080=7=Z@050?ooo`1EEED0EEEE05EEE@0000000P1EEED20?ooo`030:ZZZP1EEED0oooo
0080oooo00<0EEEE0?ooo`1EEED00`3oool01P1EEED0ZZZZ0?ooo`000000EEEE0?ooo`80EEEE00h0
ZZZZ05EEE@1EEED0EEEE0?ooo`2ZZZX0oooo05EEE@3oool0000005EEE@3oool0ZZZZ0?ooo`<0EEEE
00D0ZZZZ05EEE@1EEED0oooo05EEE@020?ooo`040:ZZZP1EEED0oooo0?ooo`80EEEE00<0ZZZZ05EE
E@3oool00P3oool01`1EEED0oooo0?ooo`3oool0ZZZZ05EEE@0000000`1EEED00`3oool0dLfY0=7=
Z@0:0=7=Z@002`3AcJT01`3oool0ZZZZ0?ooo`1EEED0000005EEE@2ZZZX00`0000000`2ZZZX00000
0?ooo`030?ooo`@0000000<0oooo0:ZZZP3oool00P2ZZZX00`3oool000000?ooo`020?ooo`@0ZZZZ
00<0oooo05EEE@0000000P1EEED50:ZZZPD0oooo00D0ZZZZ0000003oool0ZZZZ05EEE@05000000<0
oooo00<000000:ZZZP0000000P000000103oool0EEEE05EEE@1EEED30?ooo`X0dLfY00<0oooo0:ZZ
ZP2ZZZX01@1EEED00`2ZZZX0EEEE0?ooo`0405EEE@040?ooo`000000ZZZZ0?ooo`80EEEE0`2ZZZX2
05EEE@070000003oool0EEEE05EEE@2ZZZX000000?ooo`0205EEE@@0oooo0P1EEED20?ooo`050:ZZ
ZP1EEED000000?ooo`0000000`1EEED20:ZZZP80EEEE00@0oooo05EEE@000000oooo0P1EEED01@3o
ool0EEEE0?ooo`1EEED0ZZZZ00D0EEEE00<0ZZZZ0?ooo`3oool02P3AcJT00`3oool0ZZZZ0:ZZZP02
0:ZZZP060?ooo`1EEED0EEEE05EEE@2ZZZX0EEEE0P000000102ZZZX000000?ooo`0000020:ZZZP80
000000@0ZZZZ0000002ZZZX0ZZZZ0`3oool0102ZZZX000000:ZZZP3oool205EEE@030?ooo`000000
ZZZZ0080000000<0oooo05EEE@1EEED00P2ZZZX00`000000ZZZZ0?ooo`020?ooo`030:ZZZP1EEED0
00000080ZZZZ00H000000:ZZZP2ZZZX000000:ZZZP0000020:ZZZP030000001EEED0EEEE00<0EEEE
00@0oooo05EEE@2ZZZX0ZZZZ0P3oool:0=7=Z@040?ooo`2ZZZX0oooo0?ooo`80000000<0oooo0:ZZ
ZP3oool00`0000020?ooo`<0000000D0oooo0000003oool0EEEE000000020:ZZZP030?ooo`000000
oooo0080000000<0ZZZZ0000003oool00`0000020:ZZZP030000002ZZZX0ZZZZ00@0000000d0ZZZZ
000000000000oooo0000003oool0EEEE0:ZZZP000000EEEE0?ooo`000000oooo00<0000000<0oooo
0000000000000P000000103oool0ZZZZ0:ZZZP0000050?ooo`X0dLfY00H0oooo0:ZZZP3oool0oooo
05EEE@3oool20:ZZZP0305EEE@2ZZZX0oooo00@0oooo00@0ZZZZ05EEE@2ZZZX000000`3oool00`1E
EED0oooo000000030?ooo`040:ZZZP3oool0oooo0?ooo`80EEEE00@0oooo05EEE@1EEED0ZZZZ101E
EED0202ZZZX0oooo0?ooo`2ZZZX0oooo0:ZZZP3oool000000P1EEED01`3oool0ZZZZ0?ooo`000000
oooo05EEE@2ZZZX01@3oool01P2ZZZX0EEEE0:ZZZP2ZZZX0oooo000000@0oooo303AcJT000/0dLfY
0`3oool0202ZZZX000000:ZZZP3oool0EEEE0?ooo`000000ZZZZ103oool01@2ZZZX0oooo05EEE@00
0000ZZZZ00<0oooo00@0000005EEE@0000000000103oool205EEE@030000003oool000000080ZZZZ
00D000000?ooo`000000EEEE000000040?ooo`80000000@0EEEE0000003oool0oooo0P2ZZZX01000
0000ZZZZ0?ooo`0000020?ooo`060000003oool0ZZZZ05EEE@3oool0EEEE102ZZZX30?ooo`X0dLfY
0`3oool00`2ZZZX0oooo0?ooo`040:ZZZP0305EEE@3oool0ZZZZ0080ZZZZ00@0oooo0:ZZZP000000
EEEE0P3oool0101EEED000000:ZZZP2ZZZX20?ooo`070000003oool0oooo0?ooo`2ZZZX0EEEE0000
00060?ooo`030000001EEED0ZZZZ0080oooo00@0ZZZZ000000000000oooo0P2ZZZX010000000EEEE
0000003oool205EEE@070:ZZZP3oool0ZZZZ0:ZZZP1EEED0oooo05EEE@030:ZZZP0405EEE@3oool0
ZZZZ0:ZZZP<0oooo2P3AcJT30?ooo`040:ZZZP000000000000000080EEEE0P0000000`1EEED0ZZZZ
0:ZZZP030:ZZZP80000000H0ZZZZ05EEE@00000000000:ZZZP1EEED30:ZZZP090?ooo`000000EEEE
0:ZZZP000000oooo0000002ZZZX0oooo0080ZZZZ00D0EEEE0?ooo`000000ZZZZ05EEE@0200000004
0:ZZZP1EEED0ZZZZ05EEE@<000000P2ZZZX2000000080:ZZZP1EEED0ZZZZ0:ZZZP000000EEEE0000
002ZZZX205EEE@040:ZZZP000000ZZZZ0:ZZZP<0oooo2P3AcJT30?ooo`070:ZZZP00000000000:ZZ
ZP000000ZZZZ0?ooo`0205EEE@070:ZZZP3oool0ZZZZ0000003oool0ZZZZ0?ooo`0405EEE@80oooo
100000000`1EEED00000000000020?ooo`060:ZZZP000000EEEE05EEE@000000ZZZZ0`3oool00`00
0000EEEE0?ooo`03000000030?ooo`000000EEEE00<0EEEE0`3oool010000000ZZZZ0?ooo`000002
05EEE@030?ooo`2ZZZX0000000<0000000@0ZZZZ0?ooo`3oool0oooo2P3AcJT30?ooo`030:ZZZP00
0000EEEE0080EEEE0P3oool00`1EEED0oooo0:ZZZP030?ooo`0405EEE@2ZZZX0ZZZZ00000080EEEE
00l0ZZZZ0?ooo`000000oooo05EEE@2ZZZX0oooo0:ZZZP1EEED0oooo0000003oool0ZZZZ0000003o
ool00`0000001P3oool000000:ZZZP1EEED0ZZZZ0?ooo`80ZZZZ00@0oooo0000001EEED0ZZZZ0P1E
EED00`000000ZZZZ0?ooo`0205EEE@80oooo00<0ZZZZ0?ooo`1EEED00P3oool305EEE@030?ooo`2Z
ZZX0oooo0080oooo303AcJT000/0dLfY1@3oool0101EEED0oooo0000001EEED20:ZZZP040?ooo`1E
EED0000005EEE@80oooo00`0EEEE00000000000000000:ZZZP000000EEEE0000003oool000000?oo
o`0000020?ooo`80ZZZZ00<000000?ooo`0000000`000000103oool000000:ZZZP0000040?ooo`03
0000003oool000000080000000@0ZZZZ00000000000000000P3oool205EEE@040000001EEED0oooo
0:ZZZP80EEEE00@000000?ooo`1EEED0EEEE103oool:0=7=Z@@0oooo00<0ZZZZ05EEE@3oool00`2Z
ZZX20?ooo`030:ZZZP1EEED0oooo0080oooo0P1EEED0203oool000000000001EEED0oooo05EEE@2Z
ZZX000000P3oool00`1EEED000000?ooo`0205EEE@030:ZZZP1EEED0000000D0EEEE00X0oooo0000
001EEED000000?ooo`1EEED0ZZZZ05EEE@2ZZZX0EEEE0P0000000`3oool0EEEE05EEE@030?ooo`04
05EEE@3oool0oooo0?ooo`<0ZZZZ0`1EEED40?ooo`X0dLfY103oool00`2ZZZX0EEEE05EEE@020:ZZ
ZP060000003oool0EEEE0:ZZZP000000EEEE0P2ZZZX02`000000ZZZZ0:ZZZP2ZZZX000000:ZZZP00
0000EEEE0000003oool0ZZZZ00<0000000D0ZZZZ0000002ZZZX0oooo05EEE@020?ooo`0505EEE@00
0000ZZZZ0000001EEED00P0000030:ZZZP060000001EEED0ZZZZ0:ZZZP000000oooo1@2ZZZX01P1E
EED0000005EEE@1EEED0oooo05EEE@80ZZZZ0`1EEED40?ooo`X0dLfY103oool305EEE@80ZZZZ0`00
00030?ooo`80EEEE1@3oool00`2ZZZX0000005EEE@0305EEE@<000000P1EEED00`000000oooo0000
0003000000040?ooo`000000EEEE05EEE@8000001@1EEED0103oool0ZZZZ0?ooo`2ZZZX20?ooo`03
0000001EEED0EEEE0080oooo0`0000030:ZZZP030?ooo`1EEED0EEEE00@0oooo2P3AcJT40?ooo`05
05EEE@2ZZZX0oooo0000003oool00P00000305EEE@050?ooo`2ZZZX0ZZZZ05EEE@000000102ZZZX2
05EEE@040:ZZZP3oool0oooo05EEE@80oooo00<000000:ZZZP2ZZZX00`1EEED00`2ZZZX0EEEE05EE
E@020:ZZZP050000003oool0oooo05EEE@3oool00P2ZZZX00`1EEED0oooo0:ZZZP030:ZZZP050000
002ZZZX0ZZZZ05EEE@3oool00`1EEED01`000000ZZZZ0?ooo`000000oooo0:ZZZP1EEED0103oool<
0=7=Z@002`3AcJT50?ooo`0405EEE@3oool0000005EEE@<0oooo0`2ZZZX40?ooo`0305EEE@000000
ZZZZ0080oooo00<0000005EEE@3oool00P0000020?ooo`030000001EEED0000000<0000000H0oooo
0000002ZZZX0000005EEE@0000020?ooo`<0000000D0EEEE000000000000oooo0:ZZZP0205EEE@<0
oooo00@000000:ZZZP2ZZZX000000P3oool01@2ZZZX0EEEE000000000000EEEE00D0oooo2P3AcJT5
0?ooo`0405EEE@2ZZZX0ZZZZ05EEE@80ZZZZ00H0oooo0:ZZZP1EEED0EEEE0?ooo`1EEED50:ZZZP<0
EEEE00@0ZZZZ0?ooo`000000oooo0`1EEED30:ZZZP0405EEE@3oool0EEEE05EEE@<0ZZZZ00<0oooo
05EEE@1EEED00P0000001`3oool0ZZZZ05EEE@2ZZZX0EEEE0:ZZZP1EEED00`2ZZZX405EEE@80oooo
00<0ZZZZ05EEE@1EEED00P2ZZZX00`1EEED0oooo0?ooo`030?ooo`X0dLfY1@3oool00`1EEED0ZZZZ
0:ZZZP020:ZZZP0=05EEE@2ZZZX0EEEE0?ooo`2ZZZX0EEEE0000003oool0EEEE0:ZZZP000000oooo
000000020:ZZZP040?ooo`2ZZZX0000005EEE@80ZZZZ00D0EEEE0000003oool0ZZZZ000000020:ZZ
ZP040000003oool0oooo000000@0ZZZZ00<000000?ooo`3oool00P2ZZZX01@000000oooo0:ZZZP2Z
ZZX0EEEE0080000000H0oooo0:ZZZP3oool0EEEE0:ZZZP1EEED40:ZZZP0305EEE@3oool0oooo00<0
oooo2P3AcJT50?ooo`0305EEE@3oool0EEEE0080oooo0P1EEED01@2ZZZX0oooo0:ZZZP3oool00000
0080oooo00<0ZZZZ0000002ZZZX00P0000002P3oool000000?ooo`000000EEEE0000003oool00000
0?ooo`2ZZZX20000000:0:ZZZP3oool000000000002ZZZX0oooo0000003oool000000:ZZZP<00000
00P0oooo000000000000ZZZZ0000002ZZZX0oooo0:ZZZP80000000<0ZZZZ0?ooo`0000000P1EEED2
0?ooo`0305EEE@000000EEEE00D0oooo2P3AcJT50?ooo`80EEEE102ZZZX0103oool0EEEE05EEE@3o
ool205EEE@80oooo00@000000?ooo`2ZZZX0oooo0P2ZZZX01`3oool000000:ZZZP1EEED0ZZZZ05EE
E@3oool00P0000000`1EEED0ZZZZ0?ooo`030:ZZZP<0000000d0EEEE0:ZZZP2ZZZX0ZZZZ05EEE@3o
ool0ZZZZ05EEE@3oool0ZZZZ0?ooo`000000oooo00<0EEEE00@0oooo05EEE@1EEED0oooo102ZZZX2
05EEE@D0oooo303AcJT000/0dLfY1P3oool20000000405EEE@3oool0oooo0?ooo`<00000103oool0
10000000oooo05EEE@3oool2000000050?ooo`1EEED0000005EEE@0000000P1EEED00`3oool00000
0000000205EEE@050000001EEED000000000003oool00P1EEED30000000505EEE@3oool000000:ZZ
ZP3oool00P1EEED010000000oooo0?ooo`3oool4000000<0oooo00<0EEEE0000002ZZZX01P3oool:
0=7=Z@H0oooo00@0ZZZZ0?ooo`2ZZZX000000`3oool01P000000ZZZZ0?ooo`3oool0ZZZZ0?ooo`80
ZZZZ00<0oooo0:ZZZP2ZZZX00P3oool305EEE@80ZZZZ00<0EEEE0?ooo`2ZZZX00`2ZZZX01P1EEED0
ZZZZ0:ZZZP2ZZZX0oooo05EEE@80ZZZZ0P1EEED02P000000oooo0?ooo`3oool0ZZZZ0?ooo`1EEED0
ZZZZ0?ooo`2ZZZX20?ooo`030:ZZZP000000oooo00<0oooo00<0ZZZZ0?ooo`2ZZZX01P3oool:0=7=
Z@H0oooo0P2ZZZX01@3oool0ZZZZ0:ZZZP1EEED000000080EEEE0`0000001P2ZZZX0oooo05EEE@1E
EED000000?ooo`<0000000X0EEEE0?ooo`2ZZZX0ZZZZ0?ooo`000000EEEE0000002ZZZX0oooo0P2Z
ZZX205EEE@070000002ZZZX0ZZZZ0:ZZZP3oool0EEEE0:ZZZP02000000060?ooo`000000EEEE0:ZZ
ZP3oool0ZZZZ0P00000305EEE@050000001EEED0ZZZZ0:ZZZP3oool00P2ZZZX60?ooo`X0dLfY1P3o
ool6000000<0oooo00<0ZZZZ0000003oool00P3oool01`2ZZZX0oooo0:ZZZP1EEED000000?ooo`00
00000P2ZZZX00`3oool00000000000020:ZZZP80000000@0EEEE0?ooo`000000oooo0P2ZZZX01`1E
EED000000?ooo`3oool0ZZZZ0000003oool00P0000000`2ZZZX0oooo000000030?ooo`8000000P3o
ool3000000040:ZZZP00000000000:ZZZPH0oooo2P3AcJT80?ooo`0505EEE@3oool0EEEE0?ooo`2Z
ZZX00P3oool01P2ZZZX0oooo0:ZZZP000000oooo05EEE@80oooo0P2ZZZX20?ooo`0405EEE@3oool0
ZZZZ0:ZZZP<000000`3oool00`1EEED0oooo00000002000000<0ZZZZ00D0oooo05EEE@000000oooo
0:ZZZP030?ooo`0305EEE@3oool0000000D0oooo00L0EEEE0?ooo`1EEED0oooo05EEE@3oool0ZZZZ
00H0oooo303AcJT000/0dLfY1P3oool205EEE@@0oooo00<0000005EEE@000000103oool00`000000
ZZZZ0:ZZZP020000000?0?ooo`2ZZZX0EEEE0:ZZZP1EEED0oooo05EEE@3oool0EEEE0:ZZZP1EEED0
00000:ZZZP3oool000000080ZZZZ00T0EEEE0000001EEED0oooo0000002ZZZX0EEEE0:ZZZP3oool0
0P0000020:ZZZP040000003oool0oooo0?ooo`80000000L0EEEE0000003oool0oooo0000003oool0
EEEE00L0oooo2P3AcJT60?ooo`0305EEE@2ZZZX0EEEE00D000000`3oool02@000000oooo05EEE@1E
EED0oooo0000001EEED0oooo000000050:ZZZP0505EEE@2ZZZX0EEEE0?ooo`1EEED00P2ZZZX00`1E
EED0oooo05EEE@040:ZZZP0405EEE@2ZZZX0EEEE00000080oooo00@000000?ooo`3oool0EEEE1@3o
ool4000000030?ooo`1EEED0ZZZZ00L0oooo2P3AcJT60?ooo`0305EEE@2ZZZX000000080oooo00@0
EEEE0:ZZZP1EEED0ZZZZ1@1EEED01@2ZZZX0oooo0000001EEED000000080oooo0`0000000`3oool0
00000:ZZZP020:ZZZP0305EEE@3oool0oooo0080EEEE0P2ZZZX030000000oooo0000002ZZZX00000
05EEE@3oool0000005EEE@000000oooo00000080EEEE00@0ZZZZ05EEE@2ZZZX0ZZZZ0`1EEED0103o
ool000000000002ZZZX70?ooo`X0dLfY1P3oool305EEE@040:ZZZP000000oooo0:ZZZP80000000<0
oooo0:ZZZP0000000P2ZZZX30?ooo`8000000P1EEED20?ooo`0305EEE@00000000000080oooo00H0
EEEE0:ZZZP00000000000:ZZZP0000020?ooo`80000000<0EEEE0?ooo`3oool00P1EEED200000080
oooo00@000000:ZZZP2ZZZX000000P2ZZZX3000000030?ooo`000000oooo0080EEEE1`3oool:0=7=
Z@H0oooo0P1EEED0103oool000000?ooo`3oool20:ZZZP0405EEE@2ZZZX0oooo0:ZZZP80EEEE00D0
ZZZZ05EEE@2ZZZX0EEEE000000020:ZZZP030?ooo`1EEED0oooo0080oooo00@0000005EEE@000000
ZZZZ0P3oool01@2ZZZX0oooo05EEE@000000EEEE0080oooo00D0EEEE0?ooo`000000ZZZZ00000002
0:ZZZP0905EEE@3oool0EEEE05EEE@000000oooo0:ZZZP1EEED0ZZZZ00<0oooo00<0ZZZZ0?ooo`1E
EED01`3oool<0=7=Z@002`3AcJT80?ooo`D0EEEE00<0oooo0000003oool00`3oool01P000000oooo
0000002ZZZX0oooo05EEE@@0oooo00@0000005EEE@1EEED0ZZZZ0`3oool205EEE@<0oooo00D0ZZZZ
0000001EEED0000005EEE@030?ooo`0605EEE@3oool0ZZZZ0000002ZZZX000000`3oool200000006
0?ooo`2ZZZX0EEEE05EEE@2ZZZX0EEEE203oool:0=7=Z@P0oooo00D0EEEE0:ZZZP1EEED0ZZZZ05EE
E@020:ZZZP030?ooo`1EEED0EEEE0080oooo00D0EEEE0:ZZZP3oool0000005EEE@040:ZZZP80EEEE
00<0ZZZZ0?ooo`2ZZZX01@2ZZZX0101EEED0ZZZZ0?ooo`2ZZZX205EEE@@0ZZZZ00<0EEEE0000003o
ool00P2ZZZX20?ooo`<0EEEE102ZZZX00`1EEED0ZZZZ05EEE@080?ooo`X0dLfY203oool205EEE@06
0000003oool0EEEE0:ZZZP000000oooo0P2ZZZX20?ooo`030:ZZZP1EEED0ZZZZ0080ZZZZ1@1EEED2
0:ZZZP0405EEE@000000EEEE0:ZZZP80EEEE0P2ZZZX010000000EEEE0000002ZZZX305EEE@030:ZZ
ZP1EEED0ZZZZ0080ZZZZ0P1EEED20?ooo`80ZZZZ0P0000001P2ZZZX0EEEE0?ooo`000000ZZZZ05EE
E@P0oooo2P3AcJT80?ooo`0405EEE@3oool0EEEE05EEE@80oooo00<000000:ZZZP0000000P000000
102ZZZX0EEEE0:ZZZP3oool20000000805EEE@2ZZZX0EEEE0?ooo`000000ZZZZ0?ooo`1EEED20:ZZ
ZP@000000P2ZZZX0201EEED0oooo0:ZZZP000000ZZZZ05EEE@000000EEEE0P000000103oool0ZZZZ
0:ZZZP2ZZZX500000080oooo0P1EEED00`000000EEEE0?ooo`070?ooo`X0dLfY203oool01P1EEED0
ZZZZ05EEE@1EEED0ZZZZ05EEE@80ZZZZ0`1EEED01@000000ZZZZ05EEE@3oool0000000@0EEEE0P3o
ool03P2ZZZX0EEEE0:ZZZP000000ZZZZ0?ooo`2ZZZX0EEEE0?ooo`1EEED000000:ZZZP1EEED0ZZZZ
0P3oool01P1EEED0ZZZZ05EEE@1EEED000000?ooo`80EEEE00<0000005EEE@1EEED00P1EEED00`2Z
ZZX0EEEE05EEE@0405EEE@P0oooo303AcJT000/0dLfY2@3oool00`2ZZZX000000:ZZZP020?ooo`03
0000003oool0oooo0080oooo0P000000202ZZZX0oooo05EEE@3oool000000?ooo`000000EEEE0P2Z
ZZX01P1EEED0oooo0?ooo`000000oooo0:ZZZPD0oooo00/000000:ZZZP2ZZZX0oooo0000003oool0
00000?ooo`2ZZZX0oooo0:ZZZP02000000030?ooo`000000oooo0080000000D0oooo0:ZZZP2ZZZX0
00000:ZZZP090?ooo`X0dLfY2@3oool00`2ZZZX0oooo0?ooo`030:ZZZP@0EEEE00l0ZZZZ0?ooo`1E
EED0oooo0000003oool0ZZZZ0?ooo`2ZZZX0oooo0:ZZZP3oool000000?ooo`1EEED01P2ZZZX0101E
EED0oooo0?ooo`3oool50:ZZZP030?ooo`000000oooo0080EEEE00@0ZZZZ05EEE@3oool0EEEE0`2Z
ZZX0101EEED0oooo0?ooo`2ZZZX90?ooo`X0dLfY2@3oool02`2ZZZX0EEEE05EEE@000000EEEE0:ZZ
ZP1EEED0000005EEE@000000EEEE0080oooo0`2ZZZX02@3oool0000005EEE@000000EEEE0000002Z
ZZX0oooo000000020:ZZZP0=05EEE@2ZZZX0ZZZZ05EEE@000000oooo0:ZZZP000000EEEE0000001E
EED000000?ooo`030:ZZZP0:0?ooo`1EEED0EEEE0000002ZZZX0000005EEE@2ZZZX0EEEE00000080
EEEE00<0ZZZZ0?ooo`3oool01`3oool:0=7=Z@T0oooo0`0000002@2ZZZX000000:ZZZP000000oooo
0000003oool000000?ooo`020:ZZZP030?ooo`00000000000080oooo00<0ZZZZ0000003oool00P3o
ool01@2ZZZX0oooo0:ZZZP1EEED0000000<0ZZZZ0`3oool00`000000ZZZZ0?ooo`0400000080ZZZZ
00@0oooo0000003oool000000P3oool00`2ZZZX0000000000002000000030:ZZZP3oool0oooo00L0
oooo2P3AcJT:0?ooo`030:ZZZP3oool0ZZZZ0080ZZZZ00D0oooo05EEE@3oool0EEEE0:ZZZP020?oo
o`@0ZZZZ0P3oool00`2ZZZX000000?ooo`020?ooo`0;05EEE@000000oooo0?ooo`2ZZZX0oooo0000
001EEED0oooo0000003oool00P0000003@3oool0ZZZZ0:ZZZP2ZZZX000000:ZZZP3oool0EEEE0:ZZ
ZP1EEED0ZZZZ05EEE@3oool00P2ZZZX20?ooo`80ZZZZ2@3oool<0=7=Z@002`3AcJT:0?ooo`040:ZZ
ZP1EEED0000005EEE@<000000P1EEED010000000oooo0?ooo`1EEED20?ooo`80000000D0EEEE0?oo
o`1EEED0oooo000000020:ZZZP060?ooo`1EEED0ZZZZ0?ooo`1EEED000000P2ZZZX20?ooo`0305EE
E@2ZZZX0EEEE008000000P3oool01@1EEED0oooo000000000000EEEE0080000000<0EEEE0000001E
EED00P1EEED00`2ZZZX0oooo0?ooo`080?ooo`X0dLfY2P3oool30:ZZZP0305EEE@3oool0EEEE0080
ZZZZ00T0EEEE0?ooo`1EEED0EEEE0?ooo`000000oooo05EEE@2ZZZX00P1EEED20:ZZZP0305EEE@2Z
ZZX0ZZZZ00/0ZZZZ101EEED0103oool000000?ooo`1EEED20?ooo`0305EEE@2ZZZX0ZZZZ0080oooo
0P1EEED20:ZZZPX0oooo2P3AcJT:0?ooo`80ZZZZ00<0EEEE0:ZZZP3oool00P2ZZZX205EEE@80ZZZZ
00<0EEEE0:ZZZP1EEED00P2ZZZX00`1EEED0000005EEE@020:ZZZP<0EEEE0P00000205EEE@040000
002ZZZX0EEEE05EEE@<0ZZZZ0P0000000`1EEED0ZZZZ0:ZZZP020:ZZZP80EEEE00H0ZZZZ05EEE@2Z
ZZX0ZZZZ05EEE@3oool40:ZZZPX0oooo2P3AcJT:0?ooo`030:ZZZP3oool0oooo00<0ZZZZ1@000002
0?ooo`<0EEEE00H0ZZZZ0?ooo`2ZZZX0ZZZZ0?ooo`2ZZZX2000000030:ZZZP000000EEEE00D00000
0P3oool20:ZZZP040?ooo`000000EEEE05EEE@@0oooo100000000`3oool0ZZZZ0:ZZZP020?ooo`03
0:ZZZP3oool0oooo00P0oooo2P3AcJT:0?ooo`090:ZZZP3oool0oooo0000002ZZZX0EEEE0:ZZZP1E
EED000000080ZZZZ00H000000:ZZZP3oool0ZZZZ0?ooo`2ZZZX20?ooo`0405EEE@3oool000000?oo
o`80ZZZZ1@3oool05@2ZZZX0oooo0?ooo`3oool0EEEE0000003oool0EEEE0?ooo`2ZZZX0EEEE0:ZZ
ZP000000oooo0:ZZZP000000EEEE0:ZZZP3oool0ZZZZ000000020?ooo`030:ZZZP3oool0oooo00P0
oooo303AcJT000/0dLfY2`3oool00`1EEED0oooo0000000205EEE@040:ZZZP3oool0EEEE00000080
EEEE00T000000?ooo`000000oooo0000001EEED0oooo0000001EEED00`00000205EEE@030?ooo`2Z
ZZX0EEEE00<000000P1EEED02@000000oooo05EEE@2ZZZX0oooo0000003oool0000005EEE@020000
000505EEE@000000ZZZZ0:ZZZP1EEED00P0000000`1EEED0oooo0?ooo`090?ooo`X0dLfY2`3oool0
101EEED0ZZZZ0:ZZZP1EEED40:ZZZP0305EEE@2ZZZX0ZZZZ00<0EEEE00@0ZZZZ05EEE@3oool0EEEE
0P3oool;0:ZZZP0505EEE@3oool0oooo05EEE@3oool00P2ZZZX305EEE@060:ZZZP1EEED0EEEE0:ZZ
ZP3oool0ZZZZ0P1EEED20:ZZZP0305EEE@3oool0oooo00T0oooo2P3AcJT;0?ooo`0405EEE@000000
oooo0?ooo`80ZZZZ0P3oool20:ZZZP030000003oool0oooo0080ZZZZ00<0EEEE0:ZZZP1EEED00P3o
ool20:ZZZP0405EEE@000000ZZZZ05EEE@<0ZZZZ00<0EEEE0:ZZZP1EEED00P3oool00`1EEED0ZZZZ
0:ZZZP020:ZZZP060000003oool0000005EEE@2ZZZX0oooo0P2ZZZX30?ooo`030:ZZZP1EEED0oooo
00X0oooo2P3AcJT;0?ooo`0305EEE@3oool0EEEE0080oooo101EEED2000000040:ZZZP0000000000
00000080oooo00D0EEEE0?ooo`3oool0oooo000000020:ZZZP070?ooo`00000000000?ooo`1EEED0
ZZZZ000000050?ooo`@0000000<0ZZZZ0000001EEED0101EEED20?ooo`0305EEE@000000EEEE00/0
oooo2P3AcJT;0?ooo`0705EEE@3oool0EEEE0000003oool0EEEE0:ZZZP0205EEE@030000002ZZZX0
ZZZZ00<0EEEE0P2ZZZX00`1EEED0oooo0:ZZZP0200000080ZZZZ00H000000:ZZZP000000000005EE
E@2ZZZX2000000050:ZZZP3oool0EEEE0:ZZZP3oool00P1EEED00`3oool0ZZZZ0:ZZZP0305EEE@04
0?ooo`1EEED0ZZZZ000000<0EEEE2`3oool<0=7=Z@002`3AcJT<0?ooo`80000000H0EEEE0?ooo`2Z
ZZX0EEEE0?ooo`0000020?ooo`030:ZZZP000000ZZZZ0080oooo0`1EEED00`3oool0EEEE00000002
0000000505EEE@3oool0oooo05EEE@3oool00`0000000`3oool0EEEE0000000205EEE@080?ooo`2Z
ZZX000000:ZZZP3oool0ZZZZ0000003oool20:ZZZP040?ooo`1EEED000000:ZZZP`0oooo2P3AcJT<
0?ooo`040:ZZZP3oool0ZZZZ00000080oooo00H000000?ooo`3oool0EEEE0:ZZZP1EEED20:ZZZP80
EEEE00<0ZZZZ05EEE@1EEED00`2ZZZX00`3oool0ZZZZ0?ooo`060:ZZZP80EEEE00<0ZZZZ05EEE@3o
ool0102ZZZX0101EEED0ZZZZ0?ooo`0000030?ooo`030:ZZZP3oool0ZZZZ00`0oooo2P3AcJT<0?oo
o`050:ZZZP00000000000000001EEED00P0000020:ZZZP080000002ZZZX0ZZZZ0000001EEED00000
0?ooo`2ZZZX2000000070?ooo`2ZZZX0EEEE0000002ZZZX0oooo05EEE@020:ZZZP0305EEE@2ZZZX0
ZZZZ008000000P3oool0302ZZZX0EEEE000000000000ZZZZ0000001EEED0ZZZZ0000002ZZZX0EEEE
0:ZZZP80000000<0ZZZZ0?ooo`3oool02P3oool:0=7=Z@`0oooo2@0000001`3oool0000000000000
0000oooo0000002ZZZX00P0000020:ZZZP070000003oool0ZZZZ0:ZZZP1EEED000000:ZZZP020?oo
o`80000000X0ZZZZ000000000000ZZZZ0000003oool000000?ooo`000000oooo1@000000102ZZZX0
00000000002ZZZX<0?ooo`X0dLfY3@3oool01@000000oooo0?ooo`1EEED0ZZZZ00<0oooo00@0EEEE
0?ooo`3oool0ZZZZ0P1EEED00`3oool0ZZZZ0?ooo`04000000060?ooo`1EEED0oooo0000001EEED0
oooo100000040?ooo`0605EEE@2ZZZX0oooo0?ooo`1EEED000000P3oool01P2ZZZX0EEEE05EEE@3o
ool000000:ZZZP`0oooo303AcJT000/0dLfY3@3oool01P2ZZZX0oooo05EEE@000000oooo0:ZZZP@0
000000<0ZZZZ0?ooo`0000000P000000103oool0EEEE0:ZZZP2ZZZX205EEE@D0oooo0`1EEED20:ZZ
ZP0305EEE@00000000000080000000<0oooo0000000000000`0000001P2ZZZX0EEEE0000001EEED0
oooo0:ZZZPd0oooo2P3AcJT=0?ooo`80ZZZZ1@1EEED20:ZZZP0605EEE@000000oooo05EEE@2ZZZX0
EEEE0`3oool00`000000ZZZZ0:ZZZP0205EEE@030:ZZZP1EEED0EEEE00<0ZZZZ0`3oool205EEE@05
0:ZZZP1EEED0oooo0?ooo`1EEED00P2ZZZX505EEE@80ZZZZ3@3oool:0=7=Z@d0oooo1P2ZZZX20000
0080ZZZZ00<0EEEE0:ZZZP2ZZZX00`2ZZZX01P1EEED0ZZZZ0:ZZZP000000ZZZZ05EEE@80ZZZZ00D0
EEEE0:ZZZP000000ZZZZ000000020:ZZZP0305EEE@000000ZZZZ00H0ZZZZ00<0EEEE0000002ZZZX0
0P2ZZZX00`1EEED0ZZZZ0:ZZZP0=0?ooo`X0dLfY3@3oool01`2ZZZX0oooo0?ooo`000000ZZZZ0?oo
o`2ZZZX0100000040?ooo`050000002ZZZX0ZZZZ0?ooo`1EEED00P000000102ZZZX0EEEE0000002Z
ZZX20000000405EEE@3oool0ZZZZ0:ZZZP80oooo00<0ZZZZ0?ooo`3oool00`0000000`3oool0ZZZZ
0?ooo`0200000080oooo00<0ZZZZ0?ooo`3oool02`3oool:0=7=Z@d0oooo00D0ZZZZ0?ooo`2ZZZX0
oooo05EEE@02000000050?ooo`1EEED0oooo0000002ZZZX00P0000020:ZZZP0505EEE@3oool00000
0?ooo`0000000P3oool20:ZZZP80oooo00`000000?ooo`3oool0oooo05EEE@000000ZZZZ05EEE@00
0000ZZZZ05EEE@3oool205EEE@80000000D0EEEE0?ooo`2ZZZX0oooo0:ZZZP0=0?ooo``0dLfY000;
0=7=Z@h0oooo0`1EEED0102ZZZX0oooo0:ZZZP1EEED2000000<0ZZZZ0P0000000`2ZZZX0oooo0?oo
o`020?ooo`030:ZZZP3oool0oooo00@0oooo00<0ZZZZ0?ooo`1EEED00P3oool00`1EEED0000005EE
E@020:ZZZP060?ooo`00000000000000002ZZZX0oooo0P1EEED00`2ZZZX0EEEE0?ooo`0=0?ooo`X0
dLfY3P3oool01@1EEED0ZZZZ05EEE@2ZZZX0EEEE00@0ZZZZ0P1EEED40:ZZZP<0EEEE00@0ZZZZ0?oo
o`2ZZZX0EEEE0P2ZZZX01@1EEED0ZZZZ0?ooo`2ZZZX0000000<0EEEE0`2ZZZX205EEE@@0ZZZZ00D0
EEEE0:ZZZP1EEED0ZZZZ05EEE@0>0?ooo`X0dLfY3P3oool00`1EEED0ZZZZ0:ZZZP030:ZZZP080?oo
o`1EEED0oooo0000002ZZZX0EEEE0:ZZZP1EEED20?ooo`<0ZZZZ00<000000?ooo`1EEED00P2ZZZX2
05EEE@0:0000002ZZZX0ZZZZ0:ZZZP3oool0000005EEE@000000EEEE0:ZZZP80oooo00<0EEEE0000
002ZZZX0102ZZZX00`1EEED0oooo0?ooo`0<0?ooo`X0dLfY3P3oool00`1EEED0oooo05EEE@030?oo
o`0305EEE@2ZZZX00000008000000P2ZZZX00`000000ZZZZ05EEE@030?ooo`050:ZZZP3oool00000
0:ZZZP3oool00P0000001@2ZZZX0oooo0?ooo`3oool0EEEE008000000P2ZZZX01@000000oooo0000
002ZZZX000000080oooo0P1EEED00`000000EEEE0?ooo`0=0?ooo`X0dLfY3P3oool305EEE@050000
001EEED0oooo0?ooo`2ZZZX00P3oool0101EEED0oooo0?ooo`1EEED20000000705EEE@3oool00000
0:ZZZP1EEED0ZZZZ0?ooo`040:ZZZP0@0000001EEED0EEEE0000003oool0EEEE0000003oool0EEEE
0000003oool0ZZZZ0000003oool0EEEE000000<0EEEE3P3oool<0=7=Z@002`3AcJT?0?ooo`040:ZZ
ZP000000ZZZZ0?ooo`80EEEE00D000000:ZZZP3oool0oooo05EEE@02000000<0oooo00@0ZZZZ05EE
E@3oool000001P3oool04P1EEED0oooo0?ooo`3oool0EEEE0000003oool0EEEE0?ooo`1EEED0ZZZZ
0000003oool0EEEE0?ooo`2ZZZX000000:ZZZPl0oooo2P3AcJT?0?ooo`030:ZZZP3oool0EEEE00D0
ZZZZ00<0EEEE0:ZZZP2ZZZX00P2ZZZX0101EEED0oooo05EEE@1EEED20?ooo`0305EEE@2ZZZX0ZZZZ
0080ZZZZ0`3oool205EEE@030?ooo`2ZZZX0ZZZZ00T0ZZZZ0P3oool00`2ZZZX0oooo0?ooo`0=0?oo
o`X0dLfY3`3oool50:ZZZP80000000@0EEEE0000003oool000000P2ZZZX01`1EEED0000005EEE@3o
ool0EEEE0?ooo`2ZZZX00P0000002@3oool000000000003oool0EEEE0:ZZZP1EEED0000005EEE@02
0:ZZZP050000003oool0EEEE05EEE@0000000`2ZZZX00`3oool0ZZZZ0:ZZZP0?0?ooo`X0dLfY3`3o
ool3000000080:ZZZP000000oooo0?ooo`1EEED000000:ZZZP3oool30:ZZZPD0oooo00@0ZZZZ0000
001EEED0oooo0P0000050?ooo`0505EEE@2ZZZX0ZZZZ0?ooo`2ZZZX00P1EEED0103oool0ZZZZ0000
002ZZZX2000000030:ZZZP3oool0oooo00d0oooo2P3AcJTA0?ooo`0505EEE@3oool0ZZZZ0:ZZZP3o
ool00P2ZZZX0103oool0EEEE0:ZZZP2ZZZX205EEE@080:ZZZP1EEED0EEEE0:ZZZP1EEED0000005EE
E@2ZZZX2000000050:ZZZP1EEED0oooo0:ZZZP1EEED00P2ZZZX205EEE@0:0?ooo`000000ZZZZ0?oo
o`000000ZZZZ0?ooo`000000oooo0:ZZZPl0oooo303AcJT000/0dLfY403oool01P2ZZZX0EEEE0000
001EEED0oooo05EEE@@0oooo00<0EEEE00000000000010000000102ZZZX0EEEE05EEE@00000205EE
E@030000002ZZZX0000000D000001@3oool01P1EEED0000005EEE@000000EEEE0:ZZZQ00oooo2P3A
cJT@0?ooo`0:0:ZZZP1EEED0ZZZZ05EEE@3oool0EEEE0:ZZZP3oool0EEEE0:ZZZP80oooo00<0EEEE
0?ooo`1EEED00P2ZZZX405EEE@050:ZZZP1EEED0oooo05EEE@2ZZZX00P1EEED30?ooo`0805EEE@2Z
ZZX0EEEE05EEE@2ZZZX0EEEE0?ooo`1EEED30:ZZZQ00oooo2P3AcJT@0?ooo`040:ZZZP000000ZZZZ
00000080EEEE00<0ZZZZ0000002ZZZX00`2ZZZX04@3oool000000?ooo`2ZZZX000000:ZZZP3oool0
00000:ZZZP1EEED000000?ooo`2ZZZX000000:ZZZP3oool0000000L0ZZZZ00<0EEEE000000000000
0`2ZZZX@0?ooo`X0dLfY403oool01P2ZZZX0oooo0?ooo`2ZZZX0oooo0:ZZZP<0000000<0ZZZZ0000
000000000`2ZZZX00`3oool0ZZZZ000000020?ooo`80EEEE0P3oool00`000000ZZZZ05EEE@030:ZZ
ZP80000000@0ZZZZ0000003oool000000`2ZZZX20?ooo`030:ZZZP3oool0oooo00h0oooo2P3AcJT@
0?ooo`030:ZZZP000000EEEE0080EEEE00<0ZZZZ0?ooo`0000000P0000000`3oool0ZZZZ05EEE@05
00000080ZZZZ0P0000020:ZZZP80000000<0ZZZZ0000000000000`2ZZZX200000080oooo00H0ZZZZ
05EEE@1EEED0EEEE0?ooo`2ZZZX@0?ooo``0dLfY000;0=7=ZA40oooo00@000000?ooo`000000ZZZZ
1@3oool01P000000EEEE0000003oool0000005EEE@80000000D0oooo05EEE@3oool0000005EEE@05
000000030?ooo`000000EEEE00H0oooo00@0EEEE0000003oool0EEEE4@3oool:0=7=ZA40oooo0`2Z
ZZX00`1EEED0ZZZZ0:ZZZP020?ooo`060:ZZZP1EEED0EEEE05EEE@2ZZZX0EEEE0`2ZZZX01P1EEED0
oooo0?ooo`1EEED0oooo05EEE@<0ZZZZ00@0EEEE0:ZZZP2ZZZX0EEEE0P2ZZZX20?ooo`80ZZZZ00@0
EEEE0:ZZZP2ZZZX0EEEE4@3oool:0=7=ZA40oooo00<0ZZZZ05EEE@0000000P1EEED01P3oool0ZZZZ
0000001EEED0000005EEE@<0000000L0EEEE0?ooo`000000ZZZZ0000003oool0ZZZZ00<0000000h0
oooo0:ZZZP00000000000:ZZZP1EEED0ZZZZ05EEE@000000ZZZZ0?ooo`1EEED0oooo00000080EEEE
4@3oool:0=7=ZA40oooo00<000000?ooo`1EEED00P3oool01P1EEED000000:ZZZP3oool000000?oo
o`<0ZZZZ0P3oool00`000000ZZZZ00000003000000040:ZZZP000000oooo0?ooo`<0ZZZZ00@0oooo
0:ZZZP3oool0ZZZZ0P1EEED20?ooo`0305EEE@3oool0EEEE0140oooo2P3AcJTA0?ooo`0805EEE@2Z
ZZX0oooo0:ZZZP1EEED0000005EEE@2ZZZX205EEE@030?ooo`1EEED0ZZZZ0080EEEE00D0ZZZZ05EE
E@1EEED0EEEE0:ZZZP0405EEE@040:ZZZP1EEED0EEEE0:ZZZP80oooo0P1EEED0102ZZZX0EEEE0000
001EEED20?ooo`030:ZZZP1EEED0oooo0100oooo303AcJT000/0dLfY4P3oool205EEE@030000003o
ool0oooo0080000000<0ZZZZ05EEE@1EEED00P2ZZZX20?ooo`050000001EEED000000:ZZZP3oool0
0`2ZZZX01@1EEED000000000003oool0ZZZZ0080EEEE00<000000:ZZZP000000103oool205EEEA80
oooo2P3AcJTB0?ooo`0305EEE@2ZZZX0oooo00D0000000D0oooo05EEE@1EEED0oooo0000000205EE
E@80ZZZZ0P3oool02P2ZZZX0oooo0?ooo`2ZZZX0EEEE0?ooo`000000oooo0:ZZZP1EEED600000003
05EEE@2ZZZX0EEEE0180oooo2P3AcJTB0?ooo`0605EEE@2ZZZX0EEEE05EEE@2ZZZX0EEEE102ZZZX2
0000000305EEE@2ZZZX0EEEE0080ZZZZ00@0EEEE0000001EEED0EEEE0P2ZZZX305EEE@80000000<0
ZZZZ0?ooo`2ZZZX00`2ZZZX0101EEED0ZZZZ0:ZZZP1EEEDB0?ooo`X0dLfY4P3oool205EEE@080?oo
o`2ZZZX000000000002ZZZX000000:ZZZP3oool40:ZZZP0605EEE@2ZZZX0oooo0?ooo`2ZZZX00000
0P3oool00`2ZZZX0EEEE0:ZZZP030:ZZZP070?ooo`00000000000:ZZZP3oool000000:ZZZP0305EE
EA80oooo2P3AcJTB0?ooo`80EEEE0P2ZZZX010000000oooo05EEE@1EEED3000000050?ooo`2ZZZX0
ZZZZ0000003oool00P1EEED20?ooo`0305EEE@3oool0oooo0080000000@0ZZZZ0?ooo`3oool00000
0`1EEED00`3oool000000:ZZZP0305EEEA80oooo303AcJT000/0dLfY4`3oool01P2ZZZX0EEEE05EE
E@000000EEEE0?ooo`80EEEE00H0000005EEE@3oool0oooo0:ZZZP0000020?ooo`0305EEE@3oool0
oooo0080EEEE00<0oooo0000000000000`3oool02@000000oooo05EEE@3oool0EEEE0000001EEED0
oooo0:ZZZP0C0?ooo`X0dLfY4`3oool00`2ZZZX0EEEE05EEE@0505EEE@80ZZZZ0P1EEED20:ZZZP05
05EEE@000000oooo0:ZZZP1EEED00P3oool00`1EEED0ZZZZ05EEE@0205EEE@80ZZZZ1P1EEED20:ZZ
ZQ<0oooo2P3AcJTC0?ooo`80ZZZZ00<0EEEE0:ZZZP1EEED00P1EEED01@000000ZZZZ05EEE@2ZZZX0
EEEE0080ZZZZ00P0EEEE0:ZZZP2ZZZX0ZZZZ05EEE@2ZZZX0oooo05EEE@80ZZZZ00@0EEEE0:ZZZP1E
EED0ZZZZ0`1EEED00`3oool0ZZZZ05EEE@020:ZZZQ<0oooo2P3AcJTC0?ooo`070:ZZZP3oool0oooo
0000002ZZZX0oooo0:ZZZP020?ooo`030000003oool0oooo0080oooo00H0ZZZZ000000000000oooo
0:ZZZP0000020:ZZZP030?ooo`000000oooo00<0oooo00<000000:ZZZP3oool00P0000020?ooo`03
0:ZZZP3oool0oooo0140oooo2P3AcJTC0?ooo`050:ZZZP3oool0EEEE0?ooo`2ZZZX00P3oool205EE
E@060:ZZZP000000oooo05EEE@2ZZZX0EEEE0P2ZZZX0301EEED0ZZZZ0:ZZZP2ZZZX0EEEE0:ZZZP00
0000oooo0000002ZZZX0EEEE0:ZZZP80oooo00D000000?ooo`1EEED0oooo0:ZZZP0C0?ooo``0dLfY
000;0=7=ZA@0oooo00D0ZZZZ05EEE@1EEED0ZZZZ05EEE@020?ooo`0405EEE@000000oooo0?ooo`80
000000<0EEEE0:ZZZP3oool00`3oool205EEE@8000000P3oool205EEE@030000003oool0EEEE00@0
EEEE503oool:0=7=ZA@0oooo0P2ZZZX01@1EEED0ZZZZ05EEE@2ZZZX0EEEE00<0ZZZZ00@0EEEE0:ZZ
ZP2ZZZX0ZZZZ0P1EEED20:ZZZP80EEEE0`2ZZZX00`1EEED0ZZZZ0?ooo`030:ZZZP0505EEE@2ZZZX0
EEEE0:ZZZP1EEED0503oool:0=7=ZA@0oooo00H0ZZZZ0000003oool0oooo0:ZZZP3oool20:ZZZP05
05EEE@2ZZZX000000000003oool00P0000001P1EEED0ZZZZ0:ZZZP1EEED0ZZZZ00000080oooo00L0
00000:ZZZP2ZZZX0ZZZZ0000003oool0ZZZZ0080oooo00<0000005EEE@3oool04`3oool:0=7=ZA@0
oooo00<000000?ooo`1EEED00`3oool00`000000ZZZZ0000000205EEE@050000002ZZZX0ZZZZ0:ZZ
ZP0000000P3oool01@000000oooo0:ZZZP2ZZZX000000080EEEE00<000000:ZZZP0000000P3oool2
05EEE@030?ooo`1EEED0oooo01<0oooo2P3AcJTD0?ooo`0605EEE@3oool0ZZZZ0:ZZZP1EEED0ZZZZ
0P3oool01@000000oooo05EEE@2ZZZX0oooo00@0ZZZZ00D0oooo0:ZZZP3oool0ZZZZ0?ooo`0205EE
E@030?ooo`000000oooo0080ZZZZ00D0EEEE0000002ZZZX0oooo05EEE@0D0?ooo``0dLfY000;0=7=
ZAD0oooo00@0EEEE0?ooo`3oool0oooo100000001@3oool0EEEE000000000000ZZZZ00H0oooo00D0
ZZZZ000000000000EEEE0?ooo`02000000060?ooo`000000oooo05EEE@3oool0EEEE5@3oool:0=7=
ZAD0oooo00@0EEEE0:ZZZP1EEED0oooo0`2ZZZX205EEE@040:ZZZP3oool0oooo0?ooo`D0ZZZZ00D0
EEEE0?ooo`3oool0EEEE0:ZZZP0205EEE@<0ZZZZ00@0oooo05EEE@2ZZZX0EEEE5@3oool:0=7=ZAD0
oooo00L0EEEE0:ZZZP1EEED0EEEE0:ZZZP1EEED0000000<0ZZZZ00<000000:ZZZP2ZZZX00P2ZZZX2
000000L0ZZZZ00@0oooo0000002ZZZX0ZZZZ0P1EEED00`2ZZZX0EEEE0?ooo`0D0?ooo`X0dLfY5@3o
ool205EEE@050?ooo`1EEED0ZZZZ0:ZZZP000000101EEED00`000000ZZZZ00000002000000050?oo
o`000000ZZZZ0:ZZZP0000000`1EEED0103oool000000:ZZZP2ZZZX405EEEAD0oooo2P3AcJTE0?oo
o`@0EEEE00@0oooo0:ZZZP2ZZZX0ZZZZ0P3oool00`1EEED0oooo0:ZZZP020?ooo`070:ZZZP3oool0
oooo0?ooo`2ZZZX0oooo05EEE@020?ooo`80ZZZZ00@0EEEE0?ooo`1EEED0ZZZZ0P1EEEDE0?ooo``0
dLfY000;0=7=ZAH0oooo00<0ZZZZ05EEE@0000000P1EEED00`000000oooo0:ZZZP0305EEE@P0oooo
0`1EEED0202ZZZX00000000000000000EEEE0000001EEED0ZZZZ5P3oool:0=7=ZAH0oooo00X0ZZZZ
05EEE@2ZZZX0EEEE0?ooo`1EEED0ZZZZ05EEE@2ZZZX000000P1EEED20:ZZZP040?ooo`2ZZZX0ZZZZ
0:ZZZP80EEEE00L0oooo0:ZZZP1EEED0ZZZZ05EEE@3oool0EEEE00<0ZZZZ5P3oool:0=7=ZAH0oooo
00<0ZZZZ05EEE@2ZZZX00P2ZZZX0101EEED000000:ZZZP1EEED50:ZZZP030000002ZZZX0ZZZZ00<0
ZZZZ00<0000005EEE@2ZZZX00P1EEED50:ZZZQH0oooo2P3AcJTF0?ooo`060:ZZZP3oool0oooo0:ZZ
ZP3oool0ZZZZ1@0000000`3oool000000000000205EEE@030000003oool0oooo00D000000`2ZZZX2
0?ooo`030:ZZZP3oool0oooo01@0oooo2P3AcJTF0?ooo`80ZZZZ0P3oool40:ZZZP0605EEE@3oool0
oooo0?ooo`1EEED0oooo0P1EEED02@3oool0EEEE0?ooo`3oool0ZZZZ05EEE@2ZZZX0oooo0:ZZZP04
0?ooo`030:ZZZP3oool0oooo01@0oooo303AcJT000/0dLfY5`3oool00`2ZZZX00000000000020?oo
o`030:ZZZP3oool0ZZZZ00<0oooo00<000000?ooo`3oool01@3oool01P1EEED0ZZZZ0?ooo`2ZZZX0
oooo05EEE@800000603oool:0=7=ZAL0oooo0P2ZZZX20?ooo`040000003oool0EEEE000000<0ZZZZ
0P1EEED20:ZZZP0<05EEE@2ZZZX0ZZZZ0:ZZZP1EEED0000005EEE@3oool000000:ZZZP3oool0ZZZZ
603oool:0=7=ZAL0oooo1@2ZZZX00`1EEED000000000000200000080ZZZZ1@0000000`2ZZZX00000
0000000200000080ZZZZ00<0oooo0:ZZZP2ZZZX0603oool:0=7=ZAL0oooo00@0ZZZZ000000000000
ZZZZ1`00000505EEE@/00000603oool:0=7=ZAL0oooo00H0ZZZZ0?ooo`3oool000000?ooo`2ZZZX2
000000060:ZZZP1EEED0EEEE0?ooo`2ZZZX0oooo0P2ZZZX405EEE@8000007@3oool<0=7=Z@002`3A
cJTH0?ooo`80EEEE00D000000?ooo`1EEED0oooo0:ZZZP02000000030:ZZZP000000oooo00<0oooo
00<000000:ZZZP0000000P2ZZZX40?ooo`80EEEE603oool:0=7=ZAP0oooo00<0EEEE0:ZZZP3oool0
0`0000001@1EEED0ZZZZ0:ZZZP3oool0EEEE00D0ZZZZ00@0oooo0:ZZZP2ZZZX0EEEE0`0000000`1E
EED0ZZZZ05EEE@0H0?ooo`X0dLfY603oool0101EEED0ZZZZ0000003oool205EEE@040:ZZZP1EEED0
ZZZZ05EEE@D0000000H0oooo05EEE@2ZZZX0EEEE0:ZZZP1EEED20?ooo`030000002ZZZX0EEEE01P0
oooo2P3AcJTH0?ooo`80EEEE00D0oooo0:ZZZP3oool000000:ZZZP02000000030?ooo`0000000000
00@0000000@0oooo0000001EEED0ZZZZ0P000000102ZZZX0EEEE05EEE@1EEEDH0?ooo`X0dLfY603o
ool305EEE@040000001EEED0EEEE0:ZZZP80oooo00D0ZZZZ0?ooo`3oool0oooo05EEE@020?ooo`04
0:ZZZP3oool0EEEE0:ZZZP80EEEE00@000000?ooo`1EEED0EEEE603oool<0=7=Z@002`3AcJTI0?oo
o`070:ZZZP1EEED0EEEE05EEE@3oool0ZZZZ0?ooo`02000000040?ooo`000000oooo0?ooo`@00000
0P2ZZZX01@3oool0000005EEE@3oool0ZZZZ01T0oooo2P3AcJTI0?ooo`030:ZZZP1EEED0EEEE00<0
EEEE00<0oooo0000003oool01@2ZZZX0101EEED0oooo0000003oool405EEE@80ZZZZ6@3oool:0=7=
ZAT0oooo00H0ZZZZ0000002ZZZX0000005EEE@0000020?ooo`80000000<0ZZZZ0000002ZZZX00P2Z
ZZX01P000000oooo0:ZZZP000000EEEE000000<0ZZZZ6@3oool:0=7=ZAT0oooo00D0ZZZZ0?ooo`3o
ool000000:ZZZP020?ooo`050000002ZZZX0oooo0000001EEED00`0000001P2ZZZX000000:ZZZP3o
ool0ZZZZ00000080oooo00<0ZZZZ0?ooo`3oool05`3oool:0=7=ZAT0oooo00/0ZZZZ0000003oool0
ZZZZ0?ooo`1EEED0ZZZZ0000003oool0ZZZZ000000020?ooo`80000000H0oooo0000003oool0EEEE
0?ooo`1EEED20?ooo`030:ZZZP3oool0oooo01L0oooo303AcJT000/0dLfY6P3oool40:ZZZP<0oooo
00<0EEEE0000000000000P3oool20000000705EEE@3oool0EEEE0?ooo`2ZZZX000000:ZZZP0K0?oo
o`X0dLfY6P3oool20:ZZZP050?ooo`1EEED0ZZZZ0:ZZZP1EEED00`2ZZZX00`1EEED0oooo0:ZZZP02
0:ZZZP0605EEE@2ZZZX0ZZZZ05EEE@3oool0ZZZZ6`3oool:0=7=ZAX0oooo0P2ZZZX0101EEED00000
0000002ZZZX405EEE@80ZZZZ1@1EEED20000000305EEE@2ZZZX0oooo01X0oooo2P3AcJTJ0?ooo`04
0:ZZZP000000000000000080ZZZZ0P3oool2000000040?ooo`000000000005EEE@80oooo00<00000
0:ZZZP0000000P00000K0?ooo`X0dLfY6P3oool01@2ZZZX0oooo0:ZZZP3oool0000000<0EEEE0P2Z
ZZX205EEE@80ZZZZ0`1EEED00`000000oooo0:ZZZP0L0?ooo``0dLfY000;0=7=ZA/0oooo0P1EEED2
0?ooo`80EEEE0`0000020?ooo`050000003oool0000005EEE@0000000`3oool00`1EEED0oooo0?oo
o`0I0?ooo`X0dLfY6`3oool305EEE@050?ooo`2ZZZX0ZZZZ05EEE@3oool00P1EEED0102ZZZX0EEEE
0?ooo`1EEED20:ZZZP040?ooo`1EEED0ZZZZ05EEEA/0oooo2P3AcJTK0?ooo`0405EEE@2ZZZX0EEEE
05EEE@80ZZZZ00P0EEEE0:ZZZP1EEED0oooo0:ZZZP1EEED0ZZZZ05EEE@80ZZZZ0P1EEED00`2ZZZX0
EEEE0?ooo`0J0?ooo`X0dLfY6`3oool205EEE@040?ooo`1EEED0ZZZZ0:ZZZP80000000@0oooo0:ZZ
ZP000000oooo0P0000020:ZZZP0405EEE@3oool0EEEE05EEEA/0oooo2P3AcJTK0?ooo`<0EEEE00L0
00000?ooo`2ZZZX0oooo05EEE@3oool0ZZZZ00@0oooo00<0ZZZZ0?ooo`0000000`1EEEDK0?ooo``0
dLfY000;0=7=ZA`0oooo00P0EEEE0000003oool0EEEE0:ZZZP3oool0ZZZZ00000080oooo00L00000
0?ooo`3oool0ZZZZ0000003oool0000001d0oooo2P3AcJTL0?ooo`0305EEE@2ZZZX0ZZZZ0080EEEE
00H0000005EEE@2ZZZX0oooo05EEE@2ZZZX20000000405EEE@2ZZZX0ZZZZ0:ZZZQd0oooo2P3AcJTL
0?ooo`0305EEE@2ZZZX000000080oooo00P0ZZZZ0?ooo`2ZZZX0ZZZZ05EEE@2ZZZX0EEEE0:ZZZP80
oooo00<000000:ZZZP3oool0703oool:0=7=ZA`0oooo00<0EEEE0000003oool00`3oool200000080
EEEE0P0000020?ooo`0305EEE@3oool0000001d0oooo2P3AcJTL0?ooo`80EEEE1P3oool00`000000
EEEE0?ooo`030?ooo`030000003oool0EEEE01d0oooo303AcJT000/0dLfY7@3oool00`2ZZZX00000
05EEE@030?ooo`0405EEE@000000EEEE05EEE@<0oooo0P0000000`2ZZZX0oooo0?ooo`0K0?ooo`X0
dLfY7@3oool30:ZZZP030?ooo`000000oooo0080ZZZZ00@0EEEE0:ZZZP00000000000P3oool20:ZZ
ZQd0oooo2P3AcJTM0?ooo`80ZZZZ00D000000:ZZZP000000000005EEE@020:ZZZP80EEEE00<00000
0:ZZZP0000000P2ZZZXM0?ooo`X0dLfY7@3oool01P2ZZZX000000000002ZZZX000000?ooo`H00000
00@0ZZZZ000000000000ZZZZ7@3oool:0=7=ZAd0oooo0100ZZZZ0?ooo`1EEED0EEEE0?ooo`1EEED0
oooo0:ZZZP1EEED0oooo05EEE@3oool0EEEE0000003oool0ZZZZ7@3oool<0=7=Z@002`3AcJTN0?oo
o`0305EEE@3oool000000080oooo00@000000?ooo`1EEED000000P3oool00`000000EEEE05EEE@0N
0?ooo`X0dLfY7P3oool205EEE@040?ooo`000000oooo05EEE@80ZZZZ00H0EEEE000000000000oooo
0:ZZZP1EEEDN0?ooo`X0dLfY7P3oool405EEE@060:ZZZP00000000000?ooo`000000ZZZZ0P1EEED0
0`2ZZZX0EEEE0?ooo`0M0?ooo`X0dLfY7P3oool205EEE@030?ooo`2ZZZX0EEEE00@0EEEE00<00000
0:ZZZP3oool00P1EEEDN0?ooo`X0dLfY7P3oool02@1EEED0ZZZZ0?ooo`3oool0ZZZZ05EEE@3oool0
ZZZZ05EEE@030?ooo`80EEEE7P3oool<0=7=Z@002`3AcJTO0?ooo`0805EEE@2ZZZX0EEEE05EEE@2Z
ZZX0oooo05EEE@2ZZZX205EEE@030:ZZZP3oool0oooo01h0oooo2P3AcJTO0?ooo`0305EEE@2ZZZX0
ZZZZ00D0ZZZZ00<0EEEE0:ZZZP2ZZZX0803oool:0=7=ZAl0oooo00<0EEEE0:ZZZP2ZZZX00P2ZZZX0
0`000000ZZZZ0:ZZZP030:ZZZR00oooo2P3AcJTO0?ooo`0305EEE@000000oooo00H0EEEE00<0oooo
0000003oool07`3oool:0=7=ZAl0oooo101EEED01@000000ZZZZ000000000000ZZZZ0080EEEE803o
ool<0=7=Z@002`3AcJTP0?ooo`@0ZZZZ0P3oool0102ZZZX000000:ZZZP2ZZZXP0?ooo`X0dLfY803o
ool20:ZZZP0305EEE@3oool0EEEE0080oooo0`2ZZZXP0?ooo`X0dLfY803oool20:ZZZP050?ooo`1E
EED000000:ZZZP1EEED00`2ZZZXP0?ooo`X0dLfY803oool00`2ZZZX0000000000006000000030:ZZ
ZP3oool0oooo01h0oooo2P3AcJTP0?ooo`040:ZZZP3oool0EEEE0:ZZZP80EEEE00@0ZZZZ0?ooo`3o
ool0ZZZZ803oool<0=7=Z@002`3AcJTQ0?ooo`80EEEE00<0oooo0000003oool00P3oool00`1EEED0
oooo0?ooo`0O0?ooo`X0dLfY8@3oool0201EEED0oooo0000003oool0EEEE0000002ZZZX0EEEE8@3o
ool:0=7=ZB40oooo00P0EEEE000000000000ZZZZ05EEE@000000ZZZZ05EEEB40oooo2P3AcJTQ0?oo
o`80EEEE00@0oooo05EEE@1EEED0oooo0P1EEEDQ0?ooo`X0dLfY8@3oool00`1EEED0oooo0:ZZZP03
0:ZZZP80EEEE8@3oool<0=7=Z@002`3AcJTR0?ooo`0505EEE@000000ZZZZ0?ooo`0000008`3oool:
0=7=ZB80oooo00D0EEEE0:ZZZP3oool000000:ZZZP0S0?ooo`X0dLfY8P3oool01@1EEED0ZZZZ0000
001EEED0ZZZZ02<0oooo2P3AcJTR0?ooo`0505EEE@000000EEEE0?ooo`0000008`3oool:0=7=ZB80
oooo0`1EEED00`2ZZZX0EEEE0?ooo`0R0?ooo``0dLfY000;0=7=ZB<0oooo00@0ZZZZ000000000000
ZZZZ8`3oool:0=7=ZB<0oooo00@0ZZZZ0000001EEED0ZZZZ8`3oool:0=7=ZB<0oooo0P2ZZZX00`1E
EED0ZZZZ0?ooo`0R0?ooo`X0dLfY8`3oool0102ZZZX000000000002ZZZXS0?ooo`X0dLfY8`3oool2
0:ZZZP030?ooo`2ZZZX0oooo0280oooo303AcJT000/0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?oo
o`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?oo
o`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?oo
o``0dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=
ZK80dLfY000;0=7=Z@090?ooo`1EEED0EEEE0:ZZZP000000oooo0:ZZZP3oool0ZZZZ0080oooo00H0
ZZZZ0?ooo`1EEED0ZZZZ05EEE@2ZZZX20?ooo`050:ZZZP1EEED0ZZZZ05EEE@2ZZZX0101EEED02@2Z
ZZX0EEEE05EEE@1EEED000000:ZZZP3oool0ZZZZ000000040:ZZZP030000001EEED0EEEE00H0EEEE
00<0000005EEE@2ZZZX00P2ZZZX00`3oool000000:ZZZP020:ZZZP0405EEE@3oool0ZZZZ0?ooo`80
ZZZZ00<0oooo0:ZZZP3oool00P2ZZZX205EEE@030?ooo`3AcJT0dLfY00P0dLfY00D0oooo05EEE@1E
EED0EEEE0000000205EEE@<0000000@0EEEE0:ZZZP000000ZZZZ0P3oool205EEE@030?ooo`1EEED0
ZZZZ00<0oooo00@0ZZZZ05EEE@2ZZZX0ZZZZ0P1EEED01P2ZZZX000000:ZZZP2ZZZX000000?ooo`80
000000<0oooo0:ZZZP2ZZZX00`2ZZZX205EEE@80ZZZZ00<0EEEE0:ZZZP3oool00P3oool0102ZZZX0
EEEE0?ooo`2ZZZX205EEE@040?ooo`2ZZZX000000:ZZZP80EEEE0P0000000`2ZZZX0EEEE00000003
05EEE@030?ooo`3AcJT0dLfY00P0dLfY00X0oooo05EEE@3oool000000:ZZZP3oool0EEEE0?ooo`00
0000EEEE0`3oool0201EEED0oooo0?ooo`3oool0EEEE0000001EEED000000P3oool01`000000oooo
000000000000EEEE0:ZZZP3oool00P2ZZZX010000000EEEE05EEE@1EEED2000000<0EEEE00@00000
05EEE@2ZZZX0oooo0P1EEED0103oool000000?ooo`1EEED20?ooo`80EEEE00H0000005EEE@3oool0
EEEE0?ooo`1EEED30?ooo`0305EEE@000000oooo0080oooo0P0000000`3oool0EEEE0?ooo`0:0=7=
Z@050?ooo`1EEED0EEEE0:ZZZP0000000`2ZZZX0103oool0EEEE0:ZZZP2ZZZX205EEE@030000002Z
ZZX000000080oooo0P1EEED00`2ZZZX0oooo0:ZZZP020:ZZZP80EEEE0P3oool0102ZZZX0EEEE0000
000000020?ooo`80ZZZZ00@0oooo0:ZZZP00000000000P2ZZZX0103oool0ZZZZ05EEE@0000020:ZZ
ZP80oooo00T0ZZZZ0?ooo`1EEED0oooo0:ZZZP000000ZZZZ0000001EEED00`2ZZZX20?ooo`030:ZZ
ZP000000ZZZZ0080ZZZZ0P1EEED00`3oool0dLfY0=7=Z@080=7=Z@030?ooo`1EEED0EEEE00D0oooo
00@0EEEE0?ooo`2ZZZX0EEEE0`3oool01P2ZZZX000000000003oool0000005EEE@@0oooo00T00000
05EEE@2ZZZX0EEEE0?ooo`000000EEEE0000002ZZZX00P3oool200000080oooo00D0ZZZZ0000003o
ool000000?ooo`020:ZZZP040?ooo`000000oooo0:ZZZP80oooo00H0ZZZZ0000003oool0oooo0000
001EEED30?ooo`0405EEE@2ZZZX0ZZZZ05EEE@D0oooo0P1EEED00`3oool0dLfY0=7=Z@0:0=7=Z@00
2`3AcJT01@3oool0ZZZZ0?ooo`3oool0EEEE00D0ZZZZ00L0EEEE0?ooo`3oool0oooo0:ZZZP3oool0
000000@0ZZZZ00<000000?ooo`1EEED01@1EEED20000000305EEE@2ZZZX0EEEE00<0ZZZZ00D0EEEE
0:ZZZP2ZZZX0EEEE0:ZZZP03000000D0EEEE00@000000?ooo`000000EEEE0`2ZZZX2000000060:ZZ
ZP3oool0oooo0?ooo`1EEED0oooo0P2ZZZX00`3oool0ZZZZ05EEE@040?ooo`X0dLfY00D0oooo0:ZZ
ZP3oool000000:ZZZP0200000080ZZZZ00H0oooo05EEE@1EEED0000005EEE@2ZZZX20?ooo`030:ZZ
ZP1EEED0oooo00@0oooo0P0000000`3oool0000000000002000000<0EEEE0P2ZZZX010000000ZZZZ
0:ZZZP00000205EEE@030:ZZZP000000000000D000000`3oool0101EEED0oooo05EEE@2ZZZX20?oo
o`030:ZZZP1EEED000000080EEEE00L000000:ZZZP2ZZZX0oooo0000002ZZZX0000000<0oooo2P3A
cJT0103oool0ZZZZ0?ooo`1EEED30?ooo`030000003oool0oooo00@0oooo00P0ZZZZ0000003oool0
ZZZZ0?ooo`000000oooo0:ZZZP80EEEE00@0oooo0:ZZZP2ZZZX0oooo0`2ZZZX00`3oool0EEEE05EE
E@0205EEE@030?ooo`1EEED0EEEE00<0EEEE00<0oooo0:ZZZP2ZZZX00P3oool00`000000ZZZZ0?oo
o`0205EEE@030:ZZZP000000000000<0oooo00<0EEEE0:ZZZP3oool00`3oool01@2ZZZX0oooo0000
00000000oooo0080EEEE0`3oool:0=7=Z@030?ooo`2ZZZX0oooo0080oooo0P1EEED00`000000oooo
0?ooo`020:ZZZP070000003oool000000:ZZZP000000EEEE0:ZZZP020?ooo`<0ZZZZ0P0000020?oo
o`@0ZZZZ00D0oooo0000002ZZZX0ZZZZ0?ooo`030:ZZZP030000003oool0oooo00<0ZZZZ00@0oooo
0:ZZZP00000000000`2ZZZX20?ooo`070:ZZZP3oool000000:ZZZP000000oooo000000020:ZZZP80
oooo00@000000?ooo`1EEED0EEEE103oool:0=7=Z@030?ooo`2ZZZX0oooo00H0oooo0P2ZZZX40?oo
o`80ZZZZ00<0oooo05EEE@2ZZZX00`3oool01@1EEED0ZZZZ0000003oool0ZZZZ0080oooo00L00000
05EEE@1EEED000000?ooo`000000ZZZZ00@0000000@0EEEE0:ZZZP000000oooo0P2ZZZX00`3oool0
00000:ZZZP030?ooo`80ZZZZ0P1EEED00`2ZZZX0oooo0?ooo`030?ooo`80ZZZZ103oool00`000000
oooo0?ooo`020?ooo``0dLfY000;0=7=Z@<0oooo302ZZZX020000000ZZZZ0:ZZZP2ZZZX0EEEE0:ZZ
ZP1EEED0ZZZZ1P1EEED010000000EEEE0:ZZZP0000020:ZZZP0405EEE@000000ZZZZ05EEE@80ZZZZ
0P0000001@1EEED000000:ZZZP1EEED0ZZZZ0080EEEE0P2ZZZX305EEE@040:ZZZP000000ZZZZ0000
00D0ZZZZ00@0EEEE0:ZZZP2ZZZX0EEEE0`2ZZZX30?ooo`X0dLfY0`3oool01@2ZZZX0EEEE05EEE@00
0000EEEE00<000000P2ZZZX50?ooo`030:ZZZP1EEED000000080EEEE00D0ZZZZ05EEE@000000ZZZZ
0000000205EEE@030000003oool0EEEE0080ZZZZ00<000000?ooo`2ZZZX00P0000001@2ZZZX0EEEE
000000000000EEEE00@0000000L0EEEE0000001EEED0EEEE0:ZZZP1EEED0ZZZZ00H0oooo00@0ZZZZ
0000003oool000000`1EEED20:ZZZP<0oooo2P3AcJT30?ooo`0>0:ZZZP000000oooo05EEE@000000
EEEE0?ooo`1EEED0ZZZZ0000002ZZZX0oooo0:ZZZP3oool405EEE@060:ZZZP3oool0oooo0000003o
ool0ZZZZ0`3oool01@2ZZZX0EEEE0:ZZZP3oool0EEEE00@0oooo00L0ZZZZ0?ooo`2ZZZX0EEEE0:ZZ
ZP3oool0000000<0oooo00D0000005EEE@3oool0ZZZZ0000000305EEE@<0oooo0`2ZZZX0201EEED0
ZZZZ05EEE@000000EEEE0?ooo`000000ZZZZ0`3oool:0=7=Z@<0oooo102ZZZX01P000000ZZZZ0000
002ZZZX0000005EEE@80ZZZZ0P0000001`1EEED0000005EEE@000000EEEE0?ooo`1EEED00P2ZZZX0
2`3oool0ZZZZ0?ooo`000000ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP3oool000000080oooo00<0000005EE
E@2ZZZX00P2ZZZX00`000000ZZZZ0:ZZZP030:ZZZP0305EEE@3oool0EEEE0080EEEE0`0000030:ZZ
ZP030?ooo`000000ZZZZ0080ZZZZ00<0000005EEE@2ZZZX00P2ZZZX30?ooo`X0dLfY0`3oool01P2Z
ZZX0EEEE0?ooo`2ZZZX0000005EEE@P0oooo00<0EEEE0:ZZZP3oool01@3oool01P1EEED000000000
00000000oooo05EEE@<0oooo0P1EEED20?ooo`80EEEE0`3oool01P1EEED0oooo000000000000oooo
05EEE@H0oooo0P2ZZZX70?ooo`050:ZZZP1EEED0000005EEE@3oool00P2ZZZX30?ooo``0dLfY000;
0=7=Z@@0oooo00<0EEEE0?ooo`2ZZZX00P0000000`1EEED0ZZZZ0:ZZZP020:ZZZP<0EEEE00H00000
0:ZZZP000000000005EEE@00000305EEE@8000000P1EEED20:ZZZP030000002ZZZX000000080ZZZZ
00@0EEEE0:ZZZP000000ZZZZ0P000000102ZZZX0EEEE05EEE@00000405EEE@0;0000001EEED0EEEE
0000002ZZZX0oooo05EEE@2ZZZX0EEEE0:ZZZP1EEED00`2ZZZX200000080oooo00<0EEEE0?ooo`3o
ool00P3oool:0=7=Z@D0oooo00<0EEEE0?ooo`0000000P2ZZZX00`000000ZZZZ0?ooo`060?ooo`05
05EEE@00000000000000001EEED00`2ZZZX01@1EEED0ZZZZ0:ZZZP1EEED0ZZZZ0080oooo00@00000
05EEE@3oool0oooo0P1EEED20?ooo`80EEEE00@0ZZZZ05EEE@1EEED000000P2ZZZX300000080EEEE
1P3oool00`1EEED0ZZZZ000000020:ZZZP040000001EEED0EEEE05EEE@@0oooo2P3AcJT40?ooo`04
05EEE@3oool000000?ooo`80ZZZZ00<0EEEE0000001EEED00P3oool205EEE@030000001EEED00000
0080oooo00@0EEEE0:ZZZP2ZZZX0EEEE0P2ZZZX00`3oool0EEEE00000002000000030:ZZZP3oool0
oooo00<0oooo0P2ZZZX04P000000EEEE0000001EEED000000:ZZZP3oool0EEEE0:ZZZP000000EEEE
0?ooo`2ZZZX0000005EEE@2ZZZX0EEEE00000080oooo00T0EEEE0000001EEED0oooo0:ZZZP3oool0
00000?ooo`1EEED0103oool:0=7=Z@@0oooo00<0000005EEE@1EEED00`2ZZZX20000000305EEE@2Z
ZZX0EEEE00<0ZZZZ01@000000?ooo`00000000000?ooo`2ZZZX0oooo0:ZZZP3oool0EEEE0000003o
ool0ZZZZ0?ooo`1EEED000000?ooo`2ZZZX0oooo05EEE@80ZZZZ00@0000005EEE@2ZZZX0ZZZZ0P3o
ool00`1EEED0ZZZZ0:ZZZP030?ooo`80000000@0oooo0000001EEED0ZZZZ0P1EEED01@2ZZZX00000
000000000000oooo0080ZZZZ0`1EEED40?ooo`X0dLfY1@3oool01@000000EEEE0?ooo`1EEED00000
00H0oooo00<0000005EEE@3oool01`3oool0101EEED0ZZZZ05EEE@2ZZZX40?ooo`030:ZZZP3oool0
oooo00L0oooo102ZZZX80?ooo`8000001P3oool01P000000EEEE0?ooo`3oool0000005EEE@@0oooo
303AcJT000/0dLfY103oool0102ZZZX0oooo0:ZZZP2ZZZX200000080EEEE00H0ZZZZ0?ooo`2ZZZX0
ZZZZ0?ooo`00000205EEE@030000002ZZZX0EEEE00@0EEEE00<0ZZZZ0000002ZZZX00P1EEED02@2Z
ZZX0EEEE05EEE@1EEED0ZZZZ0000001EEED0ZZZZ05EEE@020:ZZZP0405EEE@2ZZZX0EEEE0:ZZZPD0
EEEE0P2ZZZX205EEE@<0oooo00<0ZZZZ0?ooo`0000000P1EEED0102ZZZX000000:ZZZP1EEED60?oo
o`X0dLfY103oool0202ZZZX0EEEE0:ZZZP2ZZZX000000:ZZZP000000ZZZZ203oool01P000000ZZZZ
0:ZZZP2ZZZX0oooo0:ZZZP<0000000L0ZZZZ05EEE@2ZZZX0oooo05EEE@2ZZZX000000080oooo00L0
00000:ZZZP1EEED0oooo0:ZZZP1EEED0ZZZZ008000000P2ZZZX00`3oool000000:ZZZP020:ZZZPL0
oooo00<000000:ZZZP0000000P0000020:ZZZP0305EEE@3oool0oooo00<0oooo2P3AcJT40?ooo`05
0:ZZZP3oool0EEEE0?ooo`2ZZZX00P0000030?ooo`030000002ZZZX0oooo00<0EEEE0`3oool30000
00040?ooo`1EEED0EEEE0:ZZZP80000000<0ZZZZ0?ooo`2ZZZX01@2ZZZX0203oool0ZZZZ0?ooo`00
0000ZZZZ0?ooo`1EEED0oooo0P000000102ZZZX0oooo0?ooo`3oool205EEE@<0oooo00D000000?oo
o`2ZZZX0oooo000000020:ZZZP030?ooo`1EEED0oooo00D0oooo2P3AcJT40?ooo`040:ZZZP000000
ZZZZ00000080ZZZZ00<000000?ooo`0000000`1EEED00`2ZZZX000000?ooo`030:ZZZP0305EEE@2Z
ZZX0ZZZZ0080ZZZZ00@0EEEE000000000000EEEE0P0000000`3oool0ZZZZ0:ZZZP020?ooo`80ZZZZ
00@0oooo0000001EEED0EEEE0P000000301EEED0oooo0:ZZZP2ZZZX0oooo05EEE@2ZZZX0EEEE0:ZZ
ZP3oool0EEEE0:ZZZP<0EEEE00<0ZZZZ0?ooo`0000000P2ZZZX00`000000EEEE000000050?ooo`X0
dLfY103oool00`2ZZZX0EEEE0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01`3oool00`1EEED0000005EEE@050?ooo`8000000P3oool2000000D0oooo0P0000090?ooo`03
0:ZZZP000000oooo00D0oooo00D0ZZZZ0?ooo`3oool0ZZZZ05EEE@050?ooo``0dLfY000;0=7=Z@H0
oooo00L0ZZZZ0000002ZZZX0000005EEE@000000oooo0080ZZZZ0P3oool01@000000EEEE0:ZZZP1E
EED000000080EEEE00P0ZZZZ0000002ZZZX0ZZZZ0000001EEED0ZZZZ05EEE@80000000H0ZZZZ0000
001EEED0EEEE0000002ZZZX20000000405EEE@2ZZZX0EEEE00000080ZZZZ00P000000:ZZZP2ZZZX0
EEEE0000001EEED0ZZZZ05EEE@<0oooo0P2ZZZX20000000505EEE@000000ZZZZ0000002ZZZX01P3o
ool:0=7=Z@L0oooo00D000000:ZZZP000000oooo000000090:ZZZP80EEEE00P0ZZZZ0000003oool0
00000:ZZZP000000oooo05EEE@80ZZZZ00D0oooo0000002ZZZX0000005EEE@020:ZZZP050?ooo`2Z
ZZX0oooo05EEE@3oool00P2ZZZX20?ooo`040000001EEED0EEEE05EEE@T0ZZZZ00H000000?ooo`2Z
ZZX0ZZZZ0000002ZZZX60?ooo`X0dLfY1P3oool2000000080?ooo`2ZZZX0000005EEE@3oool0EEEE
0?ooo`2ZZZX20?ooo`0605EEE@3oool0EEEE0:ZZZP1EEED0ZZZZ0P3oool40:ZZZPD0oooo00@0ZZZZ
05EEE@1EEED0ZZZZ0`3oool01@2ZZZX0oooo0:ZZZP000000ZZZZ00@0oooo00H0EEEE0:ZZZP2ZZZX0
oooo05EEE@0000030?ooo`0805EEE@3oool0EEEE0000001EEED0oooo0000002ZZZX60?ooo`X0dLfY
203oool205EEE@0;0?ooo`1EEED0oooo0?ooo`2ZZZX0oooo0:ZZZP000000EEEE0000003oool00`2Z
ZZX0101EEED000000:ZZZP2ZZZX205EEE@040000001EEED0oooo05EEE@D0oooo00<0ZZZZ05EEE@3o
ool00P0000001P1EEED0oooo0:ZZZP2ZZZX0000005EEE@@0ZZZZ00T0000005EEE@3oool0ZZZZ0?oo
o`2ZZZX0oooo0:ZZZP1EEED00P3oool00`1EEED0oooo0:ZZZP060?ooo`X0dLfY1P3oool00`000000
oooo000000020?ooo`050:ZZZP3oool0ZZZZ0?ooo`2ZZZX01`3oool02@000000oooo0?ooo`000000
ZZZZ0000003oool000000?ooo`0205EEE@80ZZZZ00@0oooo05EEE@2ZZZX0oooo0P1EEED00`2ZZZX0
00000?ooo`020:ZZZP<0oooo00<000000?ooo`3oool01`3oool0202ZZZX0oooo0:ZZZP3oool0ZZZZ
0000003oool0ZZZZ1P3oool<0=7=Z@002`3AcJT60?ooo`80EEEE00H0ZZZZ0000002ZZZX0EEEE0:ZZ
ZP3oool40:ZZZP060000001EEED0EEEE05EEE@2ZZZX000000P1EEED00`2ZZZX0EEEE05EEE@0205EE
E@040:ZZZP1EEED0EEEE0:ZZZP@0EEEE00@0ZZZZ05EEE@1EEED000000P1EEED00`2ZZZX0EEEE0:ZZ
ZP0205EEE@030000002ZZZX0EEEE0080EEEE00<000000:ZZZP2ZZZX00P2ZZZX00`3oool0EEEE05EE
E@030:ZZZP0305EEE@3oool0oooo00D0oooo2P3AcJT60?ooo`0305EEE@2ZZZX0EEEE00<0ZZZZ00<0
00000:ZZZP1EEED00P1EEED00`2ZZZX0000005EEE@04000000<0ZZZZ00@000000:ZZZP2ZZZX0ZZZZ
0P3oool01@1EEED000000:ZZZP2ZZZX0EEEE0080ZZZZ00<0EEEE0?ooo`1EEED00P2ZZZX2000000<0
ZZZZ0`0000002@2ZZZX0EEEE000000000000EEEE0000001EEED0ZZZZ000000020:ZZZP030000001E
EED0ZZZZ00L0oooo2P3AcJT60?ooo`80EEEE00l0oooo0000002ZZZX0oooo0000003oool0000005EE
E@3oool000000:ZZZP1EEED000000:ZZZP000000103oool205EEE@80oooo00@0EEEE0:ZZZP1EEED0
0000101EEED00`3oool0EEEE0:ZZZP040?ooo`0705EEE@3oool0oooo0?ooo`1EEED000000:ZZZP02
05EEE@80ZZZZ0P3oool020000000oooo0?ooo`3oool0ZZZZ0000003oool0EEEE1`3oool:0=7=Z@H0
oooo00<0EEEE0:ZZZP3oool00P00000205EEE@040?ooo`2ZZZX0ZZZZ0:ZZZP<0EEEE0P3oool405EE
E@050?ooo`1EEED000000?ooo`0000000`3oool60:ZZZP80oooo00H0ZZZZ0000003oool0000005EE
E@3oool205EEE@040000001EEED0oooo0?ooo`80EEEE00P0oooo0:ZZZP2ZZZX0ZZZZ0?ooo`2ZZZX0
EEEE00000080oooo00<0ZZZZ0?ooo`3oool01@3oool:0=7=Z@H0oooo0`1EEED30?ooo`030:ZZZP3o
ool0ZZZZ00@0oooo00L000000?ooo`000000oooo0:ZZZP3oool0EEEE008000000`1EEED00`3oool0
000005EEE@020:ZZZP80oooo00D0ZZZZ0?ooo`1EEED000000?ooo`0205EEE@80000000P0ZZZZ05EE
E@3oool000000?ooo`000000oooo000000<0oooo00@0EEEE0:ZZZP3oool0EEEE0`3oool205EEE@L0
oooo303AcJT000/0dLfY1`3oool00`2ZZZX0oooo0:ZZZP02000000L0ZZZZ0`0000000`1EEED0ZZZZ
05EEE@03000000040:ZZZP1EEED000000:ZZZP80oooo00<0ZZZZ0?ooo`2ZZZX00P3oool01P2ZZZX0
oooo0?ooo`2ZZZX0000005EEE@80000000<0ZZZZ0000001EEED00P1EEED01`000000EEEE0000002Z
ZZX0EEEE0:ZZZP1EEED00P2ZZZX01P1EEED000000000002ZZZX0oooo0:ZZZPL0oooo2P3AcJT70?oo
o`80ZZZZ0P1EEED2000000030?ooo`000000ZZZZ0080EEEE0P0000020:ZZZP030000002ZZZX00000
0080000000@0EEEE000000000000ZZZZ0P3oool2000000030:ZZZP3oool000000080ZZZZ00P00000
0?ooo`000000ZZZZ0000003oool0EEEE0:ZZZP80000000<0ZZZZ0000002ZZZX00`0000001`2ZZZX0
EEEE0:ZZZP000000oooo05EEE@0000000P1EEED20:ZZZPL0oooo2P3AcJT70?ooo`030:ZZZP3oool0
EEEE00<0oooo00@0ZZZZ05EEE@3oool0oooo0P1EEED01@000000oooo0:ZZZP2ZZZX000000080oooo
00D000000?ooo`3oool000000?ooo`03000000D0EEEE00<0oooo0000000000000P3oool2000000@0
oooo00<0EEEE0:ZZZP2ZZZX00P0000001`1EEED0oooo0?ooo`2ZZZX0EEEE0:ZZZP0000000P3oool0
0`1EEED0oooo0:ZZZP070?ooo`X0dLfY1`3oool30:ZZZP0605EEE@2ZZZX0ZZZZ05EEE@3oool0EEEE
0P3oool0102ZZZX0oooo0?ooo`3oool2000000070?ooo`000000EEEE0000003oool000000?ooo`03
0:ZZZP030?ooo`2ZZZX0oooo00H0ZZZZ00<0oooo0000002ZZZX00`0000000`3oool0000000000003
0?ooo`030:ZZZP3oool0oooo0080oooo00@0EEEE0000002ZZZX0EEEE0`2ZZZX70?ooo`X0dLfY1`3o
ool00`2ZZZX0oooo000000020?ooo`<0ZZZZ103oool02`000000EEEE0?ooo`1EEED0ZZZZ0?ooo`1E
EED000000:ZZZP3oool0EEEE0080000000D0oooo0:ZZZP1EEED0oooo000000030?ooo`0A0:ZZZP3o
ool0oooo0000001EEED000000:ZZZP000000EEEE0?ooo`2ZZZX0EEEE0?ooo`2ZZZX000000?ooo`00
00000P3oool20:ZZZPD0oooo00<0ZZZZ0?ooo`3oool01@3oool<0=7=Z@002`3AcJT90?ooo`040:ZZ
ZP1EEED0000000000080ZZZZ0P1EEED30:ZZZPD0EEEE00@0ZZZZ05EEE@00000000000P1EEED20:ZZ
ZP<0oooo0P2ZZZX30?ooo`80ZZZZ0P1EEED0102ZZZX000000:ZZZP2ZZZX405EEE@030000002ZZZX0
ZZZZ00<0EEEE0`2ZZZX00`000000EEEE0:ZZZP090?ooo`X0dLfY2@3oool00`1EEED0ZZZZ0:ZZZP02
000000<0ZZZZ00<0oooo0:ZZZP3oool00P1EEED0102ZZZX000000000000000020:ZZZP80EEEE00@0
ZZZZ0000001EEED0EEEE0P00000205EEE@8000000`1EEED0102ZZZX0EEEE0?ooo`2ZZZX300000080
ZZZZ00<0EEEE0?ooo`3oool00`2ZZZX00`000000ZZZZ000000040:ZZZPT0oooo2P3AcJT90?ooo`80
000000@0oooo05EEE@000000EEEE0P0000001@1EEED000000000003oool0ZZZZ008000000P2ZZZX2
0?ooo`030:ZZZP3oool000000080EEEE00<000000:ZZZP1EEED00P2ZZZX0201EEED0oooo0000001E
EED0oooo0000003oool0ZZZZ0P3oool20:ZZZP0405EEE@000000ZZZZ0?ooo`80000000T0ZZZZ0000
003oool0EEEE0000001EEED0oooo0000002ZZZX02@3oool:0=7=Z@T0oooo00<0000005EEE@2ZZZX0
1@2ZZZX20?ooo`0505EEE@3oool0EEEE0?ooo`0000000P2ZZZX02@1EEED0oooo0:ZZZP000000ZZZZ
0?ooo`1EEED0oooo0:ZZZP040?ooo`030000003oool0EEEE0080ZZZZ00@0000005EEE@3oool00000
0P2ZZZX01@000000oooo05EEE@3oool0EEEE0080oooo102ZZZX010000000ZZZZ05EEE@2ZZZX90?oo
o`X0dLfY2@3oool02@2ZZZX0EEEE0?ooo`2ZZZX000000:ZZZP3oool0EEEE0:ZZZP020?ooo`030:ZZ
ZP1EEED0ZZZZ00<0oooo0P1EEED01P3oool0EEEE0000001EEED000000?ooo`80000000<0oooo05EE
E@0000000P3oool30000000305EEE@000000EEEE00@0oooo00<0ZZZZ05EEE@3oool00P3oool02@2Z
ZZX0EEEE05EEE@2ZZZX0000005EEE@3oool0EEEE0:ZZZP090?ooo``0dLfY000;0=7=Z@T0oooo0`1E
EED00`2ZZZX000000?ooo`030?ooo`80ZZZZ1`1EEED20:ZZZP0305EEE@000000oooo00@0ZZZZ00<0
oooo0:ZZZP2ZZZX0102ZZZX01@000000EEEE05EEE@2ZZZX0000000H0EEEE0`2ZZZX01@3oool0ZZZZ
0?ooo`000000ZZZZ0080EEEE2P3oool:0=7=Z@T0oooo0`1EEED200000080EEEE00<0000005EEE@3o
ool00P3oool01@2ZZZX0oooo0:ZZZP000000ZZZZ0080000000L0oooo0:ZZZP3oool000000:ZZZP3o
ool0EEEE00D0000000L0oooo0:ZZZP2ZZZX0oooo0:ZZZP3oool000000080ZZZZ00@000000:ZZZP3o
ool0ZZZZ0`3oool01@2ZZZX000000:ZZZP1EEED0000000<0EEEE2P3oool:0=7=Z@T0oooo0P1EEED0
103oool000000?ooo`2ZZZX205EEE@030?ooo`2ZZZX000000080oooo0P1EEED20?ooo`070:ZZZP1E
EED0oooo05EEE@2ZZZX0000005EEE@020:ZZZP040?ooo`1EEED0oooo0?ooo`80ZZZZ00D0EEEE0:ZZ
ZP2ZZZX0EEEE0?ooo`0205EEE@80oooo0P1EEED20?ooo`0:0000002ZZZX0oooo05EEE@3oool0ZZZZ
0?ooo`000000oooo05EEE@X0oooo2P3AcJT90?ooo`<0EEEE00<0ZZZZ0000002ZZZX00P2ZZZX00`1E
EED0ZZZZ0?ooo`020?ooo`<0ZZZZ00<000000?ooo`3oool00P2ZZZX0101EEED0ZZZZ0?ooo`3oool5
0:ZZZP030000003oool0oooo0080EEEE00P0ZZZZ0?ooo`3oool0ZZZZ0000002ZZZX0EEEE0:ZZZP<0
oooo00L0ZZZZ0?ooo`2ZZZX000000:ZZZP000000ZZZZ0080EEEE2P3oool:0=7=Z@T0oooo00L0EEEE
0?ooo`000000EEEE0?ooo`1EEED0000000D0oooo00H0EEEE0000003oool000000?ooo`00000205EE
E@030:ZZZP1EEED0ZZZZ00<0000000D0ZZZZ0?ooo`3oool0ZZZZ0?ooo`02000000050:ZZZP1EEED0
ZZZZ0?ooo`1EEED00P3oool30000000505EEE@3oool0oooo0?ooo`1EEED00P3oool0101EEED0oooo
0?ooo`00000;0?ooo``0dLfY000;0=7=Z@/0oooo00<0EEEE0?ooo`3oool00P2ZZZX30?ooo`H00000
00`0EEEE0000002ZZZX0000005EEE@000000oooo0:ZZZP000000EEEE0000002ZZZX20000000605EE
E@000000ZZZZ0:ZZZP000000EEEE0P2ZZZX00`000000EEEE00000005000000<0oooo0P2ZZZX00`3o
ool0ZZZZ05EEE@0;0?ooo`X0dLfY2`3oool205EEE@040000002ZZZX0ZZZZ000000H0oooo00@0ZZZZ
0000003oool00000102ZZZX20000000:0:ZZZP1EEED000000000002ZZZX000000?ooo`2ZZZX00000
05EEE@@0ZZZZ0P3oool00`000000ZZZZ0?ooo`040?ooo`8000000P2ZZZX00`000000ZZZZ05EEE@0;
0?ooo`X0dLfY2`3oool0101EEED0ZZZZ05EEE@3oool205EEE@040000003oool0000000000080ZZZZ
00H0oooo05EEE@000000ZZZZ0000003oool305EEE@040?ooo`00000000000?ooo`80EEEE00<0oooo
05EEE@0000000P3oool205EEE@80000000<0oooo0000001EEED00`2ZZZX00`3oool000000?ooo`02
05EEE@80oooo00<0EEEE0000001EEED02`3oool:0=7=Z@/0oooo00D0EEEE0?ooo`3oool0000005EE
E@030:ZZZP050000002ZZZX0oooo0:ZZZP1EEED00P000000102ZZZX000000000002ZZZX20?ooo`04
0:ZZZP3oool0ZZZZ0?ooo`80ZZZZ00H0oooo0000003oool0ZZZZ0000003oool20:ZZZP@000000P2Z
ZZX00`3oool0ZZZZ000000030:ZZZP80000000<0oooo0:ZZZP1EEED02`3oool:0=7=Z@/0oooo00D0
EEEE0000003oool0000005EEE@070?ooo`80EEEE00<0oooo0:ZZZP1EEED00P3oool00`1EEED0oooo
0?ooo`060?ooo`060:ZZZP3oool0oooo0:ZZZP1EEED0oooo0P1EEED20?ooo`80EEEE1`3oool20000
00030?ooo`000000EEEE00/0oooo303AcJT000/0dLfY303oool:0:ZZZP060000002ZZZX000000:ZZ
ZP1EEED0ZZZZ0`1EEED20:ZZZP@0EEEE00@0ZZZZ05EEE@1EEED0EEEE0P2ZZZX205EEE@80ZZZZ00L0
EEEE0:ZZZP000000ZZZZ0000002ZZZX0000000@0ZZZZ00@0EEEE0:ZZZP2ZZZX0ZZZZ303oool:0=7=
Z@`0oooo00D0ZZZZ05EEE@1EEED0000005EEE@060?ooo`0<0000002ZZZX0ZZZZ0:ZZZP000000ZZZZ
0000001EEED0ZZZZ0000002ZZZX0oooo0P1EEED02P000000EEEE05EEE@2ZZZX000000:ZZZP1EEED0
000005EEE@0000030:ZZZP030000003oool0oooo00<0oooo00<0000005EEE@1EEED00P1EEED00`2Z
ZZX0oooo0?ooo`0:0?ooo`X0dLfY303oool2000000030?ooo`2ZZZX000000080ZZZZ00X0000005EE
E@1EEED0000005EEE@2ZZZX000000?ooo`1EEED0oooo0P0000001P3oool0ZZZZ05EEE@000000oooo
0:ZZZP80oooo00@0ZZZZ05EEE@2ZZZX0oooo0P00000205EEE@0?0?ooo`000000ZZZZ05EEE@000000
EEEE0?ooo`000000ZZZZ05EEE@000000EEEE0?ooo`000000ZZZZ00`0oooo2P3AcJT<0?ooo`@0ZZZZ
00<000000:ZZZP0000001@2ZZZX01@1EEED0ZZZZ05EEE@1EEED000000080ZZZZ00<0EEEE0?ooo`3o
ool00P2ZZZX0103oool0ZZZZ0:ZZZP0000020?ooo`<0ZZZZ00H0oooo05EEE@2ZZZX0ZZZZ05EEE@00
00020:ZZZP060?ooo`2ZZZX000000:ZZZP000000EEEE0`2ZZZX<0?ooo`X0dLfY303oool00`000000
oooo000000080?ooo`050:ZZZP3oool0oooo0000001EEED00P0000020?ooo`030:ZZZP1EEED0oooo
00D0oooo00P0EEEE0:ZZZP1EEED0oooo0000003oool0EEEE000000X0oooo00@0ZZZZ0000003oool0
ZZZZ303oool<0=7=Z@002`3AcJT<0?ooo`80EEEE00@0oooo0:ZZZP000000ZZZZ0P0000000`2ZZZX0
EEEE0:ZZZP020:ZZZP80000000H0oooo0000001EEED000000?ooo`2ZZZX3000000050:ZZZP3oool0
000005EEE@0000000P2ZZZX010000000EEEE0:ZZZP3oool2000000050:ZZZP1EEED0ZZZZ05EEE@2Z
ZZX0100000020?ooo`0305EEE@3oool0oooo00/0oooo2P3AcJT<0?ooo`0505EEE@3oool0EEEE0?oo
o`0000001P2ZZZX010000000ZZZZ0000001EEED2000000060?ooo`1EEED0000005EEE@3oool0ZZZZ
0P1EEED0102ZZZX0EEEE0?ooo`3oool305EEE@050?ooo`000000000005EEE@000000202ZZZX00`00
0000EEEE05EEE@0>0?ooo`X0dLfY303oool205EEE@060?ooo`000000ZZZZ0?ooo`1EEED0oooo0P00
00030?ooo`0505EEE@2ZZZX0oooo0:ZZZP1EEED00`2ZZZX01P3oool0EEEE05EEE@3oool0ZZZZ05EE
E@80oooo0`2ZZZX00`1EEED0oooo0?ooo`0205EEE@0<0?ooo`2ZZZX0oooo0000001EEED0oooo05EE
E@3oool0ZZZZ0000003oool0EEEE3@3oool:0=7=Z@`0oooo00T0EEEE0000001EEED0EEEE0:ZZZP3o
ool0ZZZZ0000001EEED00P3oool01@1EEED0ZZZZ0000002ZZZX0EEEE0080000000H0ZZZZ0000003o
ool0oooo0:ZZZP0000020:ZZZP8000000P3oool01@000000ZZZZ000000000000EEEE0080000000@0
ZZZZ05EEE@3oool0oooo0P0000030:ZZZP80EEEE00<000000?ooo`3oool02`3oool:0=7=Z@`0oooo
0`1EEED90?ooo`0405EEE@2ZZZX0oooo0:ZZZP80EEEE0P3oool00`1EEED0oooo0?ooo`040?ooo`0;
0000003oool0EEEE0:ZZZP3oool0EEEE0?ooo`2ZZZX000000:ZZZP1EEED02@3oool205EEE@d0oooo
303AcJT000/0dLfY3P3oool0101EEED000000000002ZZZX305EEE@040:ZZZP1EEED0000000000080
ZZZZ00H0oooo0000001EEED000000?ooo`2ZZZX2000000060:ZZZP3oool0oooo0:ZZZP1EEED00000
0P2ZZZX01`000000EEEE0:ZZZP3oool000000:ZZZP0000000P1EEED0202ZZZX0oooo05EEE@1EEED0
ZZZZ0000002ZZZX0EEEE3P3oool:0=7=Z@h0oooo0`1EEED01@000000EEEE0:ZZZP2ZZZX000000080
ZZZZ00<000000?ooo`2ZZZX00P0000001`2ZZZX000000000002ZZZX0oooo05EEE@2ZZZX00P3oool2
0:ZZZP060?ooo`2ZZZX000000000002ZZZX0EEEE0P0000002@3oool000000:ZZZP2ZZZX0000005EE
E@2ZZZX0EEEE0000000305EEE@h0oooo2P3AcJT>0?ooo`0405EEE@2ZZZX0EEEE00000080ZZZZ00@0
oooo05EEE@3oool0oooo0P1EEED0103oool0EEEE0?ooo`1EEED200000080oooo0P2ZZZX0103oool0
ZZZZ0:ZZZP2ZZZX30?ooo`030000001EEED0oooo00@0EEEE00@0ZZZZ0?ooo`1EEED0EEEE0P2ZZZX0
103oool0EEEE0000001EEED>0?ooo`X0dLfY3P3oool205EEE@070:ZZZP000000ZZZZ0000003oool0
EEEE0:ZZZP0200000080oooo00D000000:ZZZP2ZZZX0EEEE0:ZZZP02000000060:ZZZP000000ZZZZ
0:ZZZP000000EEEE0P00000205EEE@80ZZZZ0P0000001`3oool000000000002ZZZX0EEEE0?ooo`00
00000`2ZZZX205EEE@h0oooo2P3AcJT>0?ooo`0305EEE@000000oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0205EEE@80oooo00<0ZZZZ0?ooo`2ZZZX01@3oool00`2ZZZX0
EEEE0?ooo`020000000305EEE@3oool0oooo0080oooo00P000000?ooo`3oool0oooo0000003oool0
ZZZZ05EEE@h0oooo303AcJT000/0dLfY3`3oool00`2ZZZX0000000000002000000060?ooo`2ZZZX0
00000000003oool0EEEE0P2ZZZX305EEE@80ZZZZ0P1EEED40:ZZZP80EEEE0P2ZZZX205EEE@80ZZZZ
0P1EEED01@3oool0EEEE0000002ZZZX0oooo0080000000<0ZZZZ0000002ZZZX03`3oool:0=7=ZA00
oooo00D000000:ZZZP000000oooo0:ZZZP0205EEE@040000002ZZZX0ZZZZ00000080EEEE00H00000
0:ZZZP000000ZZZZ05EEE@3oool40:ZZZP030?ooo`1EEED0ZZZZ0080ZZZZ00<000000?ooo`1EEED0
0`2ZZZX305EEE@060000003oool000000:ZZZP000000ZZZZ3`3oool:0=7=Z@l0oooo0P00000205EE
E@0;0000002ZZZX0oooo0?ooo`1EEED0ZZZZ0000002ZZZX0oooo0000001EEED00P2ZZZX0101EEED0
oooo0:ZZZP3oool20:ZZZP040?ooo`2ZZZX0oooo05EEE@80ZZZZ00H0EEEE0?ooo`3oool0EEEE0000
002ZZZX30?ooo`0605EEE@000000EEEE0?ooo`000000ZZZZ3`3oool:0=7=ZA80oooo00<0EEEE0?oo
o`2ZZZX00P3oool00`1EEED0oooo05EEE@020:ZZZP0505EEE@2ZZZX0EEEE0:ZZZP0000000P3oool2
0:ZZZP040000002ZZZX0ZZZZ0?ooo`80000000<0EEEE0:ZZZP1EEED00P2ZZZX00`1EEED0oooo05EE
E@020?ooo`0605EEE@3oool0EEEE05EEE@3oool0ZZZZ3`3oool:0=7=Z@l0oooo00P0ZZZZ05EEE@1E
EED0ZZZZ0000002ZZZX0oooo00000080oooo00H0000005EEE@2ZZZX0EEEE0000002ZZZX40?ooo`04
05EEE@3oool0ZZZZ05EEE@<0oooo0P2ZZZX01@000000ZZZZ0:ZZZP3oool000000080oooo00P00000
0?ooo`1EEED000000:ZZZP3oool0EEEE0:ZZZPl0oooo303AcJT000/0dLfY3`3oool205EEE@030:ZZ
ZP000000ZZZZ0080ZZZZ0P1EEED0102ZZZX0oooo0:ZZZP2ZZZX20000000705EEE@2ZZZX0EEEE0:ZZ
ZP1EEED0ZZZZ05EEE@020:ZZZP080000002ZZZX0EEEE0:ZZZP1EEED000000?ooo`2ZZZX20?ooo`03
0:ZZZP1EEED0EEEE00<0ZZZZ00<000000:ZZZP1EEED0403oool:0=7=Z@l0oooo00<0EEEE0:ZZZP00
00000P2ZZZX4000000<0EEEE0P2ZZZX305EEE@050:ZZZP000000oooo0000002ZZZX00P0000000`3o
ool000000:ZZZP0305EEE@80ZZZZ0`1EEED3000000<0ZZZZ00<0EEEE0:ZZZP3oool03`3oool:0=7=
Z@l0oooo0P1EEED200000080oooo00P0ZZZZ05EEE@00000000000:ZZZP3oool0EEEE0?ooo`@00000
0`3oool01@1EEED0oooo0?ooo`1EEED0oooo00@0000000L0ZZZZ05EEE@3oool0ZZZZ0000003oool0
EEEE0080ZZZZ00@0oooo0000003oool0EEEE403oool:0=7=Z@l0oooo00<0EEEE0:ZZZP3oool00P00
00000`2ZZZX0EEEE0?ooo`030?ooo`090:ZZZP000000EEEE0000001EEED0ZZZZ0?ooo`000000EEEE
0080ZZZZ00/0EEEE0:ZZZP3oool000000?ooo`2ZZZX0EEEE0000002ZZZX000000:ZZZP020?ooo`04
0:ZZZP3oool0EEEE05EEE@80000000<0oooo0:ZZZP3oool03`3oool:0=7=Z@l0oooo00D0EEEE0?oo
o`3oool0EEEE0?ooo`02000000090?ooo`1EEED000000:ZZZP1EEED0000005EEE@3oool0EEEE00D0
oooo0P2ZZZX50?ooo`0>05EEE@3oool000000000003oool0ZZZZ0000002ZZZX0oooo0000001EEED0
oooo05EEE@00000A0?ooo``0dLfY000;0=7=ZA40oooo0P2ZZZX01@1EEED0ZZZZ0:ZZZP2ZZZX0oooo
00@0ZZZZ00@0EEEE000000000000ZZZZ0P0000000`2ZZZX0EEEE05EEE@0205EEE@<0000000<0ZZZZ
0000000000000P2ZZZX0101EEED0ZZZZ0:ZZZP1EEED20:ZZZP80EEEE00<0ZZZZ05EEE@3oool0403o
ool:0=7=ZA80oooo0P1EEED020000000ZZZZ0:ZZZP3oool0EEEE0000001EEED000000P2ZZZX01@00
0000ZZZZ0000002ZZZX0EEEE0080ZZZZ00P000000:ZZZP000000ZZZZ0000002ZZZX000000:ZZZP@0
000000D0EEEE0000002ZZZX0ZZZZ0?ooo`0305EEEA40oooo2P3AcJTA0?ooo`040000002ZZZX0EEEE
0?ooo`80EEEE00<0ZZZZ0?ooo`3oool00P3oool0101EEED0oooo0?ooo`2ZZZX20?ooo`060:ZZZP3o
ool0EEEE05EEE@3oool0EEEE0P3oool00`2ZZZX0oooo0?ooo`060?ooo`80EEEE00@0oooo05EEE@2Z
ZZX0EEEE4@3oool:0=7=ZA40oooo00<0000005EEE@1EEED00P2ZZZX30?ooo`030000002ZZZX0oooo
0080oooo0`1EEED01@2ZZZX000000?ooo`3oool0ZZZZ0080oooo00@0ZZZZ05EEE@1EEED0EEEE103o
ool01@000000oooo0?ooo`3oool0ZZZZ00@0EEEE4@3oool:0=7=ZA40oooo0P0000000`3oool00000
05EEE@0205EEE@80ZZZZ0P0000020?ooo`@0ZZZZ00@0oooo05EEE@000000ZZZZ0P1EEED20:ZZZP04
05EEE@2ZZZX0oooo05EEE@8000000P2ZZZX305EEE@040000003oool0000005EEEA40oooo303AcJT0
00/0dLfY4@3oool20:ZZZP0605EEE@2ZZZX000000000001EEED0oooo0P1EEED00`000000EEEE05EE
E@030:ZZZP040000002ZZZX0oooo0:ZZZP80oooo00D0ZZZZ0000002ZZZX0EEEE0:ZZZP0205EEE@05
0000001EEED0EEEE0?ooo`2ZZZX00`0000000`1EEED0ZZZZ0?ooo`0A0?ooo`X0dLfY4@3oool0102Z
ZZX0EEEE0:ZZZP2ZZZX200000080ZZZZ00@0EEEE0:ZZZP2ZZZX0ZZZZ0P0000000`1EEED000000000
000205EEE@040?ooo`000000EEEE0?ooo`80000000D0EEEE00000000000000000:ZZZP0205EEE@80
ZZZZ0P0000020:ZZZP0305EEE@3oool0oooo0100oooo2P3AcJTA0?ooo`060:ZZZP000000000005EE
E@2ZZZX000001@3oool00`1EEED000000?ooo`030?ooo`80ZZZZ00<0EEEE0000002ZZZX00`3oool0
101EEED0oooo0000000000040?ooo`0405EEE@000000ZZZZ0?ooo`8000004P3oool:0=7=ZA40oooo
00@0ZZZZ0000001EEED000001@2ZZZX70?ooo`80ZZZZ00@0EEEE0?ooo`3oool0EEEE0P2ZZZX00`3o
ool0ZZZZ0?ooo`030?ooo`0305EEE@2ZZZX0ZZZZ00@0ZZZZ00<0EEEE0000003oool04@3oool:0=7=
ZA40oooo00@0ZZZZ0000003oool0ZZZZ103oool305EEE@030?ooo`00000000000080oooo00D0EEEE
0000003oool0oooo05EEE@020?ooo`0305EEE@3oool0EEEE00<0000000D0EEEE0?ooo`1EEED0oooo
0:ZZZP020?ooo`030000003oool000000180oooo303AcJT000/0dLfY4P3oool205EEE@80ZZZZ00T0
00000?ooo`3oool0000005EEE@2ZZZX000000:ZZZP1EEED00P0000001@2ZZZX0oooo0:ZZZP3oool0
EEEE00<0ZZZZ00H000000:ZZZP1EEED0ZZZZ05EEE@2ZZZX2000000040?ooo`2ZZZX000000:ZZZP<0
EEEE4P3oool:0=7=ZA80oooo0`1EEED2000000040:ZZZP000000000000000080ZZZZ0P1EEED01@2Z
ZZX0EEEE05EEE@3oool000000080ZZZZ00D000000:ZZZP1EEED0EEEE0:ZZZP0205EEE@030000002Z
ZZX000000080000000<0EEEE0000000000000`1EEEDB0?ooo`X0dLfY4P3oool205EEE@80000000H0
ZZZZ0?ooo`000000oooo0000003oool205EEE@80oooo00@0EEEE0:ZZZP3oool0oooo0P1EEED01P3o
ool0EEEE0:ZZZP1EEED0ZZZZ0?ooo`80EEEE0`3oool01@000000oooo0:ZZZP000000oooo0080EEEE
4P3oool:0=7=ZA80oooo0P1EEED20:ZZZP8000000P2ZZZX50?ooo`0605EEE@2ZZZX0oooo0:ZZZP3o
ool000000P3oool00`2ZZZX0oooo0:ZZZP060?ooo`<0ZZZZ00<000000:ZZZP1EEED00P1EEEDB0?oo
o`X0dLfY4P3oool205EEE@<0oooo00D0EEEE0:ZZZP3oool0oooo0:ZZZP02000000060:ZZZP3oool0
oooo0?ooo`1EEED0ZZZZ0P3oool20:ZZZP<0oooo00@0ZZZZ0000003oool0ZZZZ0P3oool0102ZZZX0
oooo0?ooo`3oool305EEEA80oooo303AcJT000/0dLfY503oool01P2ZZZX0oooo0?ooo`2ZZZX0oooo
0:ZZZP8000000P2ZZZX305EEE@030000003oool0ZZZZ00@0ZZZZ00D0000005EEE@1EEED0EEEE0:ZZ
ZP0200000080ZZZZ00D0oooo0:ZZZP3oool0oooo05EEE@0D0?ooo`X0dLfY503oool00`2ZZZX0EEEE
000000020:ZZZP060000001EEED0ZZZZ0:ZZZP000000ZZZZ0`0000001P1EEED0oooo0000001EEED0
oooo0:ZZZP8000000P2ZZZX01@000000ZZZZ0:ZZZP3oool000000080ZZZZ00<0000005EEE@1EEED0
503oool:0=7=ZA@0oooo00@000000:ZZZP1EEED000000P2ZZZX20?ooo`030:ZZZP1EEED000000080
oooo00<0ZZZZ05EEE@1EEED00`1EEED01`000000ZZZZ0?ooo`1EEED0000005EEE@2ZZZX00P3oool2
0:ZZZP040?ooo`1EEED0ZZZZ05EEEA@0oooo2P3AcJTD0?ooo`050:ZZZP3oool0oooo0000001EEED0
202ZZZX00`000000ZZZZ0:ZZZP020?ooo`80ZZZZ00<000000:ZZZP2ZZZX01P2ZZZX01@1EEED00000
0?ooo`3oool0EEEE01@0oooo2P3AcJTD0?ooo`030:ZZZP000000oooo0080oooo00@0EEEE0?ooo`1E
EED0ZZZZ1P3oool0102ZZZX0oooo0000002ZZZX70?ooo`0805EEE@3oool0EEEE0?ooo`000000oooo
0000001EEEDD0?ooo``0dLfY000;0=7=ZA@0oooo0`2ZZZX0301EEED0ZZZZ0?ooo`2ZZZX000000:ZZ
ZP3oool0000005EEE@000000ZZZZ05EEE@80oooo00@0EEEE0?ooo`2ZZZX0ZZZZ0`0000001@3oool0
ZZZZ0000002ZZZX0oooo00@0ZZZZ5@3oool:0=7=ZA@0oooo0P2ZZZX205EEE@070000002ZZZX0ZZZZ
05EEE@2ZZZX000000:ZZZP020000000;05EEE@3oool0ZZZZ0:ZZZP1EEED0ZZZZ0?ooo`1EEED00000
05EEE@2ZZZX00P000000101EEED0ZZZZ0:ZZZP00000205EEE@030:ZZZP3oool0oooo01<0oooo2P3A
cJTD0?ooo`030:ZZZP00000000000080EEEE00H000000?ooo`000000EEEE0000002ZZZX30?ooo`H0
EEEE0`3oool0202ZZZX0000005EEE@000000EEEE0000001EEED0oooo0P00000E0?ooo`X0dLfY503o
ool30:ZZZP0505EEE@2ZZZX000000000002ZZZX00P0000001@2ZZZX000000:ZZZP000000EEEE00D0
oooo00D000000:ZZZP2ZZZX0ZZZZ000000030:ZZZP030000002ZZZX0ZZZZ0080ZZZZ5@3oool:0=7=
ZA@0oooo0P2ZZZX205EEE@040:ZZZP000000EEEE0?ooo`8000001P3oool205EEE@H0oooo0P000000
1`3oool0ZZZZ0000002ZZZX0oooo05EEE@2ZZZX05@3oool<0=7=Z@002`3AcJTE0?ooo`80EEEE00@0
oooo0:ZZZP2ZZZX0EEEE1@2ZZZX305EEE@050:ZZZP3oool0oooo0:ZZZP0000000P1EEED010000000
ZZZZ0:ZZZP1EEED40:ZZZP030?ooo`1EEED0EEEE01D0oooo2P3AcJTE0?ooo`0605EEE@3oool0EEEE
0?ooo`000000ZZZZ0P1EEED01@000000oooo0:ZZZP2ZZZX000000080oooo0P1EEED20?ooo`070000
002ZZZX000000?ooo`000000ZZZZ05EEE@02000000040?ooo`1EEED0oooo05EEEAD0oooo2P3AcJTE
0?ooo`80EEEE0P0000020?ooo`<0EEEE103oool00`2ZZZX0oooo0:ZZZP070?ooo`<0EEEE00@0ZZZZ
0?ooo`000000oooo0P1EEEDE0?ooo`X0dLfY5@3oool0201EEED0000005EEE@1EEED0ZZZZ0?ooo`00
0000oooo0`1EEED00`2ZZZX0EEEE0?ooo`040?ooo`040:ZZZP1EEED0ZZZZ0:ZZZP<0EEEE00<00000
0:ZZZP2ZZZX00P1EEED00`000000EEEE0?ooo`0D0?ooo`X0dLfY5@3oool0101EEED0oooo0?ooo`1E
EED20?ooo`040000002ZZZX00000000000D0oooo00<0ZZZZ0?ooo`3oool0103oool2000000080?oo
o`000000EEEE0?ooo`1EEED000000?ooo`1EEEDE0?ooo``0dLfY000;0=7=ZAL0oooo00H0ZZZZ0000
00000000EEEE0:ZZZP1EEED20:ZZZP040000001EEED00000000000@0ZZZZ0P0000001@1EEED0ZZZZ
0:ZZZP2ZZZX0EEEE0080ZZZZ0P0000000`1EEED0oooo0?ooo`0E0?ooo`X0dLfY5`3oool305EEE@03
0000002ZZZX0ZZZZ00<0000000/0EEEE0000001EEED0000005EEE@2ZZZX0000005EEE@000000EEEE
0?ooo`0200000080ZZZZ00@0000005EEE@1EEED0EEEE5`3oool:0=7=ZAL0oooo00@000000:ZZZP1E
EED0oooo0P1EEED01@3oool0EEEE0000003oool0EEEE0080oooo0P2ZZZX01`3oool0000005EEE@3o
ool0ZZZZ05EEE@3oool00P1EEED0103oool0EEEE0:ZZZP1EEEDG0?ooo`X0dLfY5`3oool205EEE@04
0:ZZZP000000000005EEE@80ZZZZ00<0EEEE0000001EEED01P2ZZZX00`1EEED000000:ZZZP030:ZZ
ZP030000002ZZZX0ZZZZ0080EEEE5`3oool:0=7=ZAL0oooo0P0000000`3oool0000005EEE@020?oo
o`H0EEEE00<0oooo05EEE@1EEED01@1EEED20?ooo`0505EEE@000000oooo0000001EEED05`3oool<
0=7=Z@002`3AcJTG0?ooo`80ZZZZ0P00000305EEE@070000001EEED0ZZZZ0000002ZZZX000000:ZZ
ZP02000000050:ZZZP000000ZZZZ05EEE@0000000`1EEED00`2ZZZX000000:ZZZP0H0?ooo`X0dLfY
5`3oool01`2ZZZX0oooo0000002ZZZX000000:ZZZP0000000P2ZZZX010000000oooo05EEE@3oool2
000000040?ooo`1EEED0oooo00000080ZZZZ0`0000000`2ZZZX000000?ooo`0H0?ooo`X0dLfY5`3o
ool0202ZZZX000000000001EEED0ZZZZ05EEE@2ZZZX0oooo0P1EEED0102ZZZX0oooo0?ooo`1EEED2
0?ooo`030000002ZZZX0EEEE0080oooo00@0ZZZZ0000002ZZZX0oooo0P00000H0?ooo`X0dLfY5`3o
ool01P2ZZZX0oooo0?ooo`3oool0EEEE000000<0ZZZZ00D0EEEE0:ZZZP000000ZZZZ000000020:ZZ
ZP040000002ZZZX0EEEE00000080ZZZZ0`1EEEDJ0?ooo`X0dLfY5`3oool0102ZZZX000000?ooo`2Z
ZZX60?ooo`030:ZZZP3oool0ZZZZ0080oooo00D0ZZZZ0?ooo`2ZZZX0oooo0:ZZZP040?ooo`030000
003oool0000001P0oooo303AcJT000/0dLfY603oool205EEE@040:ZZZP00000000000:ZZZP<0EEEE
00P000000:ZZZP2ZZZX0ZZZZ0000002ZZZX0oooo000000<0EEEE00@0ZZZZ05EEE@000000ZZZZ0P1E
EEDH0?ooo`X0dLfY603oool01P1EEED0ZZZZ0000002ZZZX0000005EEE@80000000d0EEEE0?ooo`3o
ool0oooo05EEE@000000oooo0:ZZZP3oool0EEEE0:ZZZP000000EEEE0080ZZZZ00<0EEEE0:ZZZP1E
EED0603oool:0=7=ZAP0oooo0P1EEED200000080oooo0P1EEED040000000ZZZZ0?ooo`3oool0EEEE
0000003oool000000:ZZZP000000ZZZZ05EEE@3oool0ZZZZ0000003oool205EEEAP0oooo2P3AcJTH
0?ooo`0505EEE@2ZZZX0oooo0000003oool00P2ZZZX00`000000EEEE0:ZZZP020:ZZZP80000000D0
ZZZZ05EEE@2ZZZX0EEEE0?ooo`020:ZZZP80000000<0oooo0:ZZZP1EEED0603oool:0=7=ZAP0oooo
0P1EEED50?ooo`0405EEE@2ZZZX0oooo05EEE@@0oooo00<0ZZZZ0?ooo`2ZZZX01@3oool305EEEAP0
oooo303AcJT000/0dLfY6P3oool20:ZZZP050000001EEED0ZZZZ0:ZZZP0000000P2ZZZX03@000000
EEEE05EEE@000000oooo0:ZZZP000000EEEE0:ZZZP1EEED000000:ZZZP1EEED06P3oool:0=7=ZA/0
oooo00<0EEEE0?ooo`0000000`1EEED030000000EEEE0?ooo`3oool0EEEE0?ooo`2ZZZX0000005EE
E@3oool0EEEE000000<0EEEE6P3oool:0=7=ZAX0oooo00@000000:ZZZP3oool000000P2ZZZX20000
00030:ZZZP1EEED0EEEE0080EEEE00T0ZZZZ000000000000EEEE0:ZZZP000000EEEE0:ZZZP1EEED0
6P3oool:0=7=ZAX0oooo00<0000005EEE@1EEED00`0000000`2ZZZX0EEEE00000002000000040?oo
o`000000ZZZZ05EEE@80ZZZZ0P00000305EEEAX0oooo2P3AcJTJ0?ooo`030:ZZZP000000000000@0
oooo00<0EEEE0?ooo`3oool0103oool00`1EEED0oooo0?ooo`030?ooo`030000001EEED0oooo01T0
oooo303AcJT000/0dLfY6P3oool20:ZZZP0305EEE@2ZZZX000000080EEEE0P2ZZZX405EEE@80ZZZZ
00H0EEEE000000000000ZZZZ05EEE@2ZZZXK0?ooo`X0dLfY6P3oool02P2ZZZX0EEEE0:ZZZP2ZZZX0
00000?ooo`2ZZZX0000005EEE@2ZZZX20?ooo`80ZZZZ00@000000:ZZZP3oool000000P2ZZZX00`1E
EED0oooo0?ooo`0I0?ooo`X0dLfY6P3oool00`2ZZZX000000?ooo`0205EEE@060:ZZZP000000oooo
0:ZZZP3oool0ZZZZ0P3oool0102ZZZX0oooo00000000000205EEE@8000006`3oool:0=7=ZAX0oooo
00H0ZZZZ0000002ZZZX000000?ooo`2ZZZX205EEE@80ZZZZ00<0oooo05EEE@2ZZZX00`1EEED01@2Z
ZZX0oooo0000001EEED0000001/0oooo2P3AcJTJ0?ooo`80ZZZZ00D0oooo05EEE@2ZZZX0EEEE0:ZZ
ZP080?ooo`030:ZZZP000000ZZZZ0080EEEE00<0ZZZZ0?ooo`3oool06@3oool<0=7=Z@002`3AcJTK
0?ooo`<0EEEE00<0oooo05EEE@0000001P0000001@2ZZZX00000000000000000oooo00<0EEEE6`3o
ool:0=7=ZA/0oooo0`1EEED01@000000oooo000000000000EEEE00@0oooo00D0EEEE000000000000
oooo0000000305EEEA/0oooo2P3AcJTK0?ooo`0405EEE@3oool0000000000080ZZZZ00X0EEEE0?oo
o`1EEED0oooo0:ZZZP1EEED0oooo05EEE@2ZZZX0oooo0P00000205EEEA/0oooo2P3AcJTK0?ooo`80
EEEE0P2ZZZX00`3oool0ZZZZ0?ooo`020:ZZZP80oooo00<0ZZZZ0?ooo`3oool0102ZZZX205EEEA/0
oooo2P3AcJTK0?ooo`0305EEE@000000oooo0080EEEE0P0000060?ooo`80000000D0oooo05EEE@3o
ool0oooo05EEE@0K0?ooo``0dLfY000;0=7=ZA`0oooo00D0EEEE0:ZZZP3oool0000005EEE@020000
000305EEE@2ZZZX000000080EEEE00D0000005EEE@000000oooo0:ZZZP0M0?ooo`X0dLfY703oool0
1P1EEED0ZZZZ05EEE@2ZZZX0000005EEE@H0oooo00D0EEEE000000000000EEEE0:ZZZP0M0?ooo`X0
dLfY703oool00`1EEED000000:ZZZP020?ooo`0405EEE@3oool0oooo05EEE@80oooo00H0000005EE
E@3oool0EEEE0:ZZZP00000M0?ooo`X0dLfY703oool01@1EEED0ZZZZ0?ooo`3oool0000000@0ZZZZ
00D000000:ZZZP1EEED0ZZZZ000000020?ooo`030:ZZZP3oool0oooo01/0oooo2P3AcJTL0?ooo`03
05EEE@000000000000800000201EEED010000000oooo00000000000M0?ooo``0dLfY000;0=7=ZAd0
oooo0P2ZZZX010000000ZZZZ05EEE@1EEED20:ZZZP040000002ZZZX0EEEE05EEE@@0ZZZZ7@3oool:
0=7=ZAd0oooo0P2ZZZX205EEE@P0ZZZZ0P1EEED20:ZZZQd0oooo2P3AcJTM0?ooo`050:ZZZP000000
oooo05EEE@2ZZZX00`3oool01@000000oooo0000002ZZZX0EEEE0080000000<0ZZZZ0?ooo`3oool0
6`3oool:0=7=ZAd0oooo102ZZZX205EEE@80ZZZZ00@0EEEE0:ZZZP1EEED0EEEE102ZZZXM0?ooo`X0
dLfY7@3oool0202ZZZX000000000002ZZZX0oooo0:ZZZP3oool0ZZZZ103oool0102ZZZX0oooo0000
002ZZZXM0?ooo``0dLfY000;0=7=ZB00oooo00<0EEEE0000002ZZZX00P1EEED01P2ZZZX0EEEE05EE
E@000000EEEE0:ZZZQl0oooo2P3AcJTO0?ooo`0805EEE@2ZZZX0ZZZZ0:ZZZP1EEED0ZZZZ0?ooo`1E
EED40:ZZZQl0oooo2P3AcJTP0?ooo`80EEEE00<0oooo0000002ZZZX00P000000103oool0EEEE05EE
E@2ZZZXO0?ooo`X0dLfY7`3oool030000000EEEE0:ZZZP2ZZZX0000005EEE@2ZZZX0000005EEE@2Z
ZZX0EEEE0:ZZZQl0oooo2P3AcJTQ0?ooo`030000003oool0oooo0080ZZZZ0P3oool00`000000oooo
0:ZZZP0O0?ooo``0dLfY000;0=7=ZAl0oooo00L0EEEE0:ZZZP000000EEEE0:ZZZP3oool000000080
ZZZZ00<000000:ZZZP3oool07`3oool:0=7=ZAl0oooo0`1EEED01P2ZZZX0EEEE0?ooo`2ZZZX0EEEE
00000080EEEE803oool:0=7=ZAl0oooo00T0EEEE000000000000oooo0000003oool0ZZZZ0000001E
EED00P00000P0?ooo`X0dLfY7`3oool305EEE@040000002ZZZX0ZZZZ0?ooo`80ZZZZ0P1EEEDP0?oo
o`X0dLfY7`3oool01P1EEED0ZZZZ000000000000oooo05EEE@<0oooo00<000000:ZZZP3oool07`3o
ool<0=7=Z@002`3AcJTP0?ooo`80ZZZZ0P0000020:ZZZP8000000P2ZZZXP0?ooo`X0dLfY803oool0
102ZZZX0oooo05EEE@1EEED20?ooo`0405EEE@000000oooo0:ZZZR00oooo2P3AcJTP0?ooo`040:ZZ
ZP00000000000?ooo`80ZZZZ0P3oool00`000000ZZZZ0?ooo`0O0?ooo`X0dLfY803oool01`2ZZZX0
oooo05EEE@1EEED0oooo0:ZZZP1EEED00P3oool00`2ZZZX0oooo0?ooo`0N0?ooo`X0dLfY803oool2
0:ZZZP040?ooo`1EEED000000:ZZZP80EEEE0P2ZZZXP0?ooo``0dLfY000;0=7=ZB<0oooo00<0ZZZZ
0?ooo`3oool00P2ZZZXR0?ooo`X0dLfY8P3oool01P2ZZZX0EEEE0:ZZZP000000EEEE0:ZZZR80oooo
2P3AcJTS0?ooo`030:ZZZP1EEED0ZZZZ0080ZZZZ8P3oool:0=7=ZB80oooo0P2ZZZX010000000ZZZZ
0:ZZZP2ZZZXR0?ooo`X0dLfY8P3oool0101EEED0ZZZZ0?ooo`3oool20:ZZZR80oooo303AcJT000/0
dLfY8P3oool00`1EEED0ZZZZ0:ZZZP020:ZZZR<0oooo2P3AcJTR0?ooo`0405EEE@3oool0000005EE
EB@0oooo2P3AcJTR0?ooo`0505EEE@000000EEEE05EEE@0000008`3oool:0=7=ZB80oooo00D0EEEE
0000003oool0EEEE0000000S0?ooo`X0dLfY8P3oool00`1EEED000000?ooo`02000002<0oooo303A
cJT000/0dLfY8`3oool0102ZZZX0EEEE0:ZZZP2ZZZXS0?ooo`X0dLfY8`3oool20:ZZZP0305EEE@2Z
ZZX0oooo0280oooo2P3AcJTS0?ooo`040:ZZZP1EEED000000:ZZZR<0oooo2P3AcJTS0?ooo`040:ZZ
ZP1EEED000000:ZZZR<0oooo2P3AcJTS0?ooo`040:ZZZP3oool000000:ZZZR<0oooo303AcJT000/0
dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0
dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0
dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo``0dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o
0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY000;0=7=ZA/0oooo00@0EEEE000000000000
oooo0P0000000`2ZZZX0oooo0?ooo`030?ooo`080000002ZZZX000000:ZZZP3oool000000:ZZZP1E
EEDK0?ooo`X0dLfY603oool0102ZZZX0EEEE05EEE@2ZZZX205EEE@<0ZZZZ00/0oooo05EEE@3oool0
00000:ZZZP3oool0EEEE0?ooo`2ZZZX000000:ZZZP0205EEE@040:ZZZP3oool0EEEE0:ZZZQP0oooo
2P3AcJT60?ooo`080000001EEED0oooo05EEE@2ZZZX0oooo0:ZZZP3oool20:ZZZP80oooo00H0ZZZZ
0?ooo`1EEED000000:ZZZP0000020?ooo`030:ZZZP3oool0ZZZZ0080oooo00<0ZZZZ05EEE@1EEED0
0P1EEED20?ooo`0505EEE@3oool0EEEE05EEE@2ZZZX00P3oool00`1EEED0oooo05EEE@020?ooo`06
0000002ZZZX0000005EEE@3oool0ZZZZ0`3oool0202ZZZX0oooo0000003oool0ZZZZ05EEE@3oool0
EEEE1`3oool:0=7=Z@80oooo00H000000:ZZZP00000000000?ooo`0000020:ZZZP070?ooo`2ZZZX0
oooo0:ZZZP3oool0000005EEE@020?ooo`80EEEE00D0000005EEE@3oool0oooo05EEE@050?ooo`03
0000002ZZZX0ZZZZ00D0oooo00@000000:ZZZP2ZZZX00000103oool205EEE@030?ooo`1EEED0EEEE
0080000000@0EEEE0?ooo`3oool0EEEE0P3oool01P2ZZZX0oooo0:ZZZP3oool0EEEE0:ZZZP<00000
0P2ZZZX00`000000oooo0?ooo`0:0=7=Z@070?ooo`00000000000000003oool000000?ooo`0205EE
E@0<0000001EEED0EEEE0:ZZZP1EEED0oooo05EEE@3oool000000:ZZZP000000ZZZZ0P000000301E
EED000000:ZZZP1EEED000000:ZZZP3oool000000?ooo`2ZZZX0000005EEE@80oooo00L000000?oo
o`00000000000:ZZZP3oool000000080oooo00D0000005EEE@2ZZZX000000?ooo`02000000090?oo
o`000000ZZZZ0000003oool0ZZZZ0?ooo`1EEED0oooo0080EEEE00H0000005EEE@1EEED0EEEE0000
001EEED200000080oooo303AcJT000/0dLfY703oool02@1EEED0ZZZZ000000000000oooo0:ZZZP00
0000EEEE0000000305EEE@040:ZZZP3oool0000000000080ZZZZ703oool:0=7=ZAP0oooo00<0EEEE
0000002ZZZX0101EEED01`2ZZZX000000:ZZZP1EEED000000?ooo`1EEED00P0000000`2ZZZX00000
0:ZZZP0405EEE@80000000<0EEEE0?ooo`3oool05P3oool:0=7=Z@L0oooo00@0000005EEE@1EEED0
EEEE0P0000000`2ZZZX0EEEE00000003000000030:ZZZP1EEED0ZZZZ00<0oooo00@0EEEE0000002Z
ZZX0EEEE0P000000101EEED0oooo0000002ZZZX505EEE@030000003oool0EEEE008000000100EEEE
0:ZZZP3oool0EEEE0?ooo`000000oooo0:ZZZP1EEED0ZZZZ0000003oool000000:ZZZP1EEED0ZZZZ
0P000000101EEED0ZZZZ05EEE@0000070?ooo`X0dLfY0`3oool020000000oooo0?ooo`3oool0EEEE
0:ZZZP3oool000001@1EEED0103oool000000?ooo`1EEED2000000040:ZZZP3oool0oooo05EEE@<0
oooo00<0EEEE0000003oool00P0000060?ooo`80000000<0oooo0000001EEED00P3oool205EEE@80
oooo00P0ZZZZ0000001EEED0EEEE0?ooo`1EEED0oooo0:ZZZP80EEEE00P0ZZZZ05EEE@0000000000
0:ZZZP1EEED000000?ooo`8000000`3oool:0=7=Z@80oooo00@000000:ZZZP3oool0EEEE0P000000
3@3oool0ZZZZ0?ooo`3oool0ZZZZ0000001EEED0ZZZZ0000001EEED000000?ooo`1EEED00P000002
05EEE@040?ooo`000000oooo0:ZZZP80000000<0EEEE0000003oool00P0000000`3oool0ZZZZ0000
00020?ooo`080000001EEED000000000002ZZZX0oooo0000003oool205EEE@8000000P3oool30000
0080EEEE00`000000:ZZZP3oool0oooo0000003oool000000:ZZZP1EEED0oooo0:ZZZP0000020?oo
o``0dLfY000;0=7=ZA`0oooo0P2ZZZX00`3oool0ZZZZ0:ZZZP02000000040:ZZZP3oool0oooo0:ZZ
ZP80000000<0ZZZZ0?ooo`3oool00P2ZZZXL0?ooo`X0dLfY603oool00`1EEED0ZZZZ05EEE@0505EE
E@040:ZZZP000000EEEE05EEE@80oooo00@0EEEE0:ZZZP000000ZZZZ1P1EEED00`2ZZZX0EEEE0?oo
o`0G0?ooo`X0dLfY2@3oool01@1EEED0oooo05EEE@2ZZZX000000080ZZZZ0P3oool01`2ZZZX00000
0?ooo`3oool0ZZZZ0?ooo`1EEED00P2ZZZX01P1EEED0oooo0000002ZZZX000000?ooo`80ZZZZ00H0
EEEE0:ZZZP2ZZZX0EEEE0?ooo`2ZZZX20?ooo`070:ZZZP000000ZZZZ05EEE@000000ZZZZ05EEE@02
0:ZZZP030?ooo`2ZZZX000000080ZZZZ00<0oooo0000002ZZZX00P0000000`1EEED0oooo00000009
0?ooo`X0dLfY103oool00`000000EEEE0?ooo`020000000405EEE@3oool0000000000080EEEE00D0
00000?ooo`3oool0EEEE0?ooo`03000000070:ZZZP1EEED0oooo0000002ZZZX000000?ooo`020000
00X0oooo00T0EEEE0000003oool0EEEE0:ZZZP000000oooo05EEE@2ZZZX00`0000001@3oool0EEEE
0000003oool000000080EEEE0P0000000`3oool0EEEE000000020000000305EEE@3oool0oooo00<0
oooo2P3AcJT40?ooo`80000000@0oooo0000001EEED0oooo0P00000605EEE@80000000P0oooo0:ZZ
ZP3oool0ZZZZ0?ooo`000000ZZZZ0?ooo`<0EEEE00<0ZZZZ0000000000000P00000205EEE@050000
002ZZZX000000000003oool00P1EEED20?ooo`070:ZZZP000000oooo0000003oool0ZZZZ05EEE@02
000000030:ZZZP1EEED0EEEE0080EEEE0`000000103oool0EEEE0000001EEED2000000@0oooo303A
cJT000/0dLfY703oool020000000oooo0?ooo`3oool0ZZZZ05EEE@2ZZZX0EEEE0P3oool01@1EEED0
000005EEE@2ZZZX0EEEE01l0oooo2P3AcJTI0?ooo`D0000000L0EEEE0:ZZZP1EEED0EEEE0000003o
ool0EEEE00<0oooo0P1EEED01`000000EEEE0000003oool0000005EEE@0000006@3oool:0=7=Z@T0
oooo00D0000005EEE@2ZZZX0oooo05EEE@020:ZZZP80EEEE0P2ZZZX01P1EEED00000000000000000
EEEE0?ooo`80ZZZZ00<0oooo0000003oool00P2ZZZX0103oool000000:ZZZP1EEED20:ZZZP050000
003oool0ZZZZ0:ZZZP3oool00P0000001@2ZZZX0EEEE0?ooo`1EEED0ZZZZ008000000`2ZZZX01000
0000EEEE0:ZZZP2ZZZX205EEE@030:ZZZP1EEED0oooo00T0oooo2P3AcJT50?ooo`80000000T0ZZZZ
0000001EEED000000?ooo`000000oooo0:ZZZP0000000P2ZZZX0103oool0000005EEE@00000305EE
E@060?ooo`000000oooo0:ZZZP000000ZZZZ1@3oool00`1EEED0oooo0?ooo`030?ooo`040000002Z
ZZX00000000000<0oooo0`1EEED010000000EEEE0000003oool20:ZZZP030000002ZZZX0oooo0080
oooo0`0000020:ZZZP030000003oool0oooo00<0oooo2P3AcJT40?ooo`080000002ZZZX0oooo05EE
E@2ZZZX000000:ZZZP3oool505EEE@030:ZZZP000000oooo0080ZZZZ00D0000005EEE@3oool0oooo
05EEE@020?ooo`030:ZZZP3oool0EEEE0080000000<0oooo05EEE@1EEED00`1EEED200000080oooo
00@0ZZZZ0?ooo`3oool000000P3oool2000000040:ZZZP3oool0oooo000000H0EEEE00L0oooo0:ZZ
ZP000000ZZZZ05EEE@3oool0ZZZZ00D0oooo303AcJT000/0dLfY703oool01@1EEED000000?ooo`1E
EED000000080EEEE103oool01P2ZZZX0EEEE000000000000oooo000001d0oooo2P3AcJTJ0?ooo`05
05EEE@000000000005EEE@0000000P1EEED01P3oool0EEEE0:ZZZP000000oooo0:ZZZP80oooo00<0
EEEE0000000000000P1EEED00`000000ZZZZ0?ooo`0I0?ooo`X0dLfY2`3oool02@000000oooo05EE
E@2ZZZX0oooo05EEE@3oool0EEEE0:ZZZP02000000060?ooo`1EEED0EEEE0:ZZZP1EEED00000103o
ool0102ZZZX0EEEE0?ooo`1EEED20:ZZZP0505EEE@3oool0EEEE0:ZZZP0000000P3oool01@1EEED0
000005EEE@2ZZZX0EEEE0080oooo00<000000?ooo`2ZZZX00`1EEED20:ZZZP80EEEE00<000000?oo
o`3oool02@3oool:0=7=Z@H0oooo00@000000?ooo`3oool0oooo0P0000001@3oool000000000001E
EED0000000@0ZZZZ0`1EEED2000000<0ZZZZ0P000000102ZZZX000000?ooo`3oool205EEE@060000
001EEED0EEEE0?ooo`000000ZZZZ0`0000001@2ZZZX0EEEE000000000000oooo0080EEEE00@00000
0:ZZZP2ZZZX0EEEE1`00000:0?ooo`X0dLfY1P3oool20000000505EEE@000000EEEE0?ooo`1EEED0
0P0000000`1EEED0oooo00000002000000030?ooo`2ZZZX0ZZZZ0080000000D0ZZZZ05EEE@3oool0
ZZZZ05EEE@030?ooo`0405EEE@00000000000?ooo`<0000000@0EEEE0?ooo`000000oooo0P1EEED0
103oool000000:ZZZP0000030:ZZZP060?ooo`00000000000:ZZZP3oool0EEEE0P0000001@1EEED0
oooo05EEE@3oool0EEEE008000001P3oool<0=7=Z@002`3AcJTM0?ooo`030:ZZZP000000oooo0080
EEEE1@3oool00`2ZZZX0EEEE05EEE@02000000030:ZZZP3oool0oooo01/0oooo2P3AcJTJ0?ooo`03
0000002ZZZX0EEEE00<0EEEE00<0ZZZZ0000000000000P3oool01P1EEED0oooo000000000000ZZZZ
0?ooo`80EEEE00<0oooo0:ZZZP1EEED06P3oool:0=7=Z@`0oooo00D0EEEE0:ZZZP1EEED0ZZZZ0?oo
o`020:ZZZP8000000`3oool00`2ZZZX0oooo05EEE@020?ooo`80ZZZZ00H0EEEE0?ooo`1EEED0ZZZZ
05EEE@3oool205EEE@040000001EEED0oooo0?ooo`<0ZZZZ00@0oooo0000003oool0ZZZZ103oool0
20000000ZZZZ0?ooo`3oool0ZZZZ05EEE@2ZZZX00000303oool:0=7=Z@L0oooo00P0000005EEE@3o
ool0EEEE0:ZZZP1EEED0000005EEE@80000000<0EEEE0:ZZZP0000000P1EEED01`3oool000000000
00000000EEEE0:ZZZP0000000P3oool00`000000oooo0?ooo`020:ZZZP030?ooo`1EEED0ZZZZ00<0
oooo00D000000?ooo`3oool000000:ZZZP030000000605EEE@3oool0EEEE05EEE@000000ZZZZ0P00
000205EEE@070000003oool0ZZZZ05EEE@3oool0EEEE000000070?ooo`X0dLfY1P3oool03`000000
ZZZZ0?ooo`1EEED0ZZZZ0000003oool000000:ZZZP3oool0ZZZZ0000003oool0ZZZZ000000030:ZZ
ZP040?ooo`1EEED00000000000<0EEEE00<000000:ZZZP0000000`0000001P1EEED0000005EEE@00
0000ZZZZ00000080EEEE00H0ZZZZ000000000000EEEE0?ooo`0000020:ZZZP030000002ZZZX0oooo
0080ZZZZ00<0oooo0:ZZZP0000000P000000102ZZZX0oooo0?ooo`2ZZZX70?ooo``0dLfY000;0=7=
ZA`0oooo00<0EEEE0?ooo`2ZZZX00P1EEED00`2ZZZX0oooo0?ooo`030?ooo`0505EEE@2ZZZX0EEEE
0000002ZZZX07P3oool:0=7=ZAX0oooo0P2ZZZX010000000EEEE0000002ZZZX405EEE@80000000@0
EEEE0?ooo`1EEED0EEEE0P000000101EEED000000:ZZZP1EEEDJ0?ooo`X0dLfY303oool01`000000
EEEE05EEE@2ZZZX0EEEE0:ZZZP3oool00P0000000`3oool0000005EEE@020:ZZZP0605EEE@000000
oooo0:ZZZP000000EEEE0P3oool0101EEED0ZZZZ05EEE@1EEED20:ZZZP80oooo0P0000020:ZZZP04
0000003oool0ZZZZ0:ZZZP8000000P3oool01@000000oooo0000001EEED0ZZZZ0080EEEE3@3oool:
0=7=Z@P0oooo00l000000:ZZZP000000oooo05EEE@000000EEEE0000002ZZZX0000005EEE@2ZZZX0
00000:ZZZP3oool0100000000`1EEED0oooo05EEE@040?ooo`060000002ZZZX0ZZZZ05EEE@2ZZZX0
EEEE0P3oool01@000000oooo05EEE@2ZZZX0EEEE00<0000000X0ZZZZ0?ooo`2ZZZX0oooo0:ZZZP1E
EED000000:ZZZP000000EEEE0P000000103oool000000:ZZZP0000080?ooo`X0dLfY1`3oool00`00
0000EEEE000000030:ZZZP040?ooo`000000EEEE00000080EEEE00<000000?ooo`0000000P1EEED0
10000000EEEE0:ZZZP1EEED30000000405EEE@000000oooo0:ZZZP80000000@0oooo0000003oool0
oooo10000000403oool0EEEE0:ZZZP1EEED000000?ooo`1EEED000000?ooo`000000EEEE0?ooo`00
0000EEEE0000003oool30:ZZZP80EEEE00<000000?ooo`3oool01@3oool<0=7=Z@002`3AcJTN0?oo
o`030000003oool0ZZZZ00H0oooo00D0EEEE0?ooo`2ZZZX0oooo0000000N0?ooo`X0dLfY6P3oool2
05EEE@080000002ZZZX0EEEE0?ooo`000000ZZZZ0?ooo`2ZZZX20?ooo`070:ZZZP3oool0ZZZZ0000
003oool0EEEE0:ZZZP0205EEEA/0oooo2P3AcJT>0?ooo`030000002ZZZX0EEEE00@0000000L0EEEE
000000000000oooo05EEE@000000EEEE00@0ZZZZ0P1EEED30:ZZZP030000002ZZZX0oooo0080EEEE
00<0oooo0:ZZZP2ZZZX00P1EEED00`000000EEEE0?ooo`020000000405EEE@0000000000000000<0
EEEE00<000000?ooo`3oool0303oool:0=7=Z@T0oooo00P000000?ooo`1EEED000000?ooo`000000
EEEE00000080EEEE00H000000?ooo`2ZZZX0oooo0000002ZZZX2000000030:ZZZP3oool000000080
ZZZZ00@0EEEE0?ooo`00000000000P3oool00`000000EEEE0?ooo`0205EEE@040:ZZZP0000000000
0:ZZZP80000000H0ZZZZ0000003oool0ZZZZ0?ooo`00000205EEE@030000003oool000000080oooo
00<0EEEE0?ooo`3oool02@3oool:0=7=Z@T0oooo00@0ZZZZ0?ooo`3oool0ZZZZ0P0000000`3oool0
EEEE05EEE@0205EEE@080000001EEED0ZZZZ0?ooo`2ZZZX0EEEE0?ooo`0000020?ooo`070000001E
EED000000000003oool0ZZZZ000000020:ZZZPD0000000P0oooo000000000000000005EEE@2ZZZX0
EEEE0:ZZZPH0EEEE00@0ZZZZ000000000000EEEE0P3oool00`000000oooo0?ooo`070?ooo``0dLfY
000;0=7=ZAh0oooo00@0EEEE00000000000000001@3oool00`1EEED000000000000205EEEAh0oooo
2P3AcJTK0?ooo`030:ZZZP1EEED0EEEE00<0ZZZZ00<0EEEE0000001EEED00P3oool305EEE@060:ZZ
ZP3oool0ZZZZ05EEE@3oool0ZZZZ6`3oool:0=7=Z@l0oooo0`1EEED0303oool0ZZZZ0?ooo`2ZZZX0
oooo0:ZZZP3oool0ZZZZ05EEE@2ZZZX0EEEE00000080EEEE00X0oooo0000002ZZZX0ZZZZ0?ooo`1E
EED0ZZZZ05EEE@000000oooo0P1EEED03`000000EEEE0:ZZZP3oool0ZZZZ0?ooo`1EEED0oooo0:ZZ
ZP1EEED0ZZZZ0?ooo`2ZZZX0EEEE0000000?0?ooo`X0dLfY2P3oool00`000000EEEE0?ooo`020?oo
o`0905EEE@00000000000000001EEED0ZZZZ05EEE@000000oooo00@000000P3oool01@000000EEEE
0:ZZZP2ZZZX0000000D0oooo0P2ZZZX200000080oooo100000000`3oool0000005EEE@0205EEE@04
0000001EEED0000000000080oooo00<0000005EEE@0000002P3oool:0=7=Z@T0oooo00<0000005EE
E@1EEED00`2ZZZX6000000070:ZZZP1EEED0EEEE0000003oool0ZZZZ000000030?ooo`070:ZZZP1E
EED0ZZZZ05EEE@3oool0EEEE000000020?ooo`030:ZZZP1EEED0000000<0oooo0P0000001P3oool0
000005EEE@1EEED0ZZZZ0?ooo`80000000<0oooo0000002ZZZX00P2ZZZX00`000000EEEE05EEE@0:
0?ooo``0dLfY000;0=7=ZAh0oooo00H0EEEE0:ZZZP2ZZZX0EEEE0?ooo`1EEED20?ooo`0605EEE@3o
ool0EEEE0:ZZZP3oool0EEEE7P3oool:0=7=ZA/0oooo00@0EEEE0:ZZZP2ZZZX000000P1EEED00`2Z
ZZX0EEEE0:ZZZP02000000060:ZZZP1EEED0ZZZZ05EEE@3oool000000P2ZZZX00`1EEED0oooo0?oo
o`0I0?ooo`X0dLfY403oool010000000ZZZZ05EEE@3oool20:ZZZP80000000P0ZZZZ05EEE@3oool0
oooo0:ZZZP1EEED000000?ooo`80ZZZZ00H0EEEE0000003oool0oooo0000003oool30:ZZZP070000
001EEED0oooo0?ooo`2ZZZX0EEEE0:ZZZP02000000030:ZZZP1EEED0oooo0080EEEE00<000000?oo
o`3oool03P3oool:0=7=Z@`0oooo0P0000000`3oool0EEEE00000003000000<0EEEE00<0ZZZZ0000
002ZZZX00P2ZZZX01P000000oooo0?ooo`1EEED0ZZZZ000000H0oooo00<000000:ZZZP3oool00P3o
ool20:ZZZP040000002ZZZX000000:ZZZP80EEEE1P0000000`3oool000000000000<0?ooo`X0dLfY
2`3oool010000000oooo0?ooo`1EEED3000000070:ZZZP3oool000000000001EEED0oooo05EEE@02
0?ooo`030000001EEED0ZZZZ0080000000D0ZZZZ000000000000000005EEE@02000000060?ooo`00
0000ZZZZ0?ooo`000000ZZZZ0P0000020?ooo`<0EEEE00/000000?ooo`3oool0ZZZZ0?ooo`000000
ZZZZ05EEE@3oool0ZZZZ0000000;0?ooo``0dLfY000;0=7=ZAl0oooo0`2ZZZX01P000000EEEE0?oo
o`3oool0EEEE000000<0ZZZZ7`3oool:0=7=ZA/0oooo0`1EEED01`2ZZZX0oooo05EEE@2ZZZX00000
0:ZZZP1EEED00P2ZZZX00`1EEED0ZZZZ05EEE@020:ZZZP0305EEE@2ZZZX0EEEE01/0oooo2P3AcJTA
0?ooo`80EEEE0P2ZZZX02P3oool000000?ooo`000000ZZZZ05EEE@000000oooo0:ZZZP3oool205EE
E@030000002ZZZX0EEEE0080oooo0P1EEED01@000000EEEE05EEE@3oool0ZZZZ008000000P2ZZZX0
20000000oooo0000003oool000000:ZZZP1EEED000004@3oool:0=7=Z@`0oooo00D000000?ooo`3o
ool000000:ZZZP040000000405EEE@000000oooo00000080oooo00@000000?ooo`3oool0oooo0P00
00000`3oool0EEEE0?ooo`050?ooo`040000001EEED0oooo0?ooo`<0000000D0oooo000000000000
000005EEE@04000000030:ZZZP3oool0oooo00h0oooo2P3AcJT<0?ooo`80EEEE00H000000:ZZZP2Z
ZZX0oooo0000001EEED20000000305EEE@000000000000@000000P2ZZZX01@3oool0EEEE0000002Z
ZZX0oooo0080EEEE00@0oooo000000000000EEEE0`2ZZZX00`1EEED000000:ZZZP02000000030:ZZ
ZP1EEED000000080EEEE00L000000:ZZZP2ZZZX0ZZZZ0000001EEED0000000`0oooo303AcJT000/0
dLfY7@3oool00`1EEED0oooo000000020?ooo`030:ZZZP3oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`1EEED0oooo0?ooo`0K0?ooo`X0dLfY6`3oool205EEE@070000002ZZZX000000000
001EEED0ZZZZ000000020:ZZZP040000003oool0EEEE00000080ZZZZ00<000000:ZZZP1EEED06`3o
ool:0=7=ZA40oooo00<0000005EEE@3oool00P2ZZZX30?ooo`0<0000003oool0oooo0?ooo`000000
ZZZZ05EEE@2ZZZX0EEEE0000002ZZZX0oooo0P2ZZZX01@3oool0EEEE0:ZZZP1EEED0ZZZZ00800000
00X0oooo0:ZZZP000000oooo05EEE@3oool0ZZZZ05EEE@3oool0EEEE4P3oool:0=7=Z@d0oooo00<0
000005EEE@3oool01P0000002@1EEED000000?ooo`3oool0000005EEE@000000oooo05EEE@020000
00040:ZZZP3oool0oooo05EEE@80oooo0P2ZZZX20000000405EEE@3oool0EEEE05EEE@<0oooo0P1E
EED6000000030?ooo`1EEED0000000d0oooo2P3AcJT<0?ooo`<0000000@0oooo0000003oool0oooo
0P0000000`1EEED000000:ZZZP020:ZZZP050000003oool0ZZZZ0000002ZZZX00P0000000`3oool0
000005EEE@0305EEE@80oooo00@000000:ZZZP2ZZZX000000P3oool40:ZZZP080000001EEED00000
0000003oool0EEEE0000001EEED2000000d0oooo303AcJT000/0dLfY7P3oool0102ZZZX0oooo0?oo
o`1EEED50?ooo`050:ZZZP1EEED0oooo0000002ZZZX07P3oool:0=7=ZA/0oooo0P1EEED20?ooo`0:
0:ZZZP000000ZZZZ0?ooo`000000oooo05EEE@000000oooo0:ZZZP8000000P3oool00`2ZZZX0EEEE
0?ooo`0J0?ooo`X0dLfY4`3oool01@000000EEEE0:ZZZP2ZZZX000000080ZZZZ00H000000?ooo`1E
EED0EEEE0000002ZZZX20?ooo`060:ZZZP3oool0EEEE05EEE@3oool0EEEE0`3oool00`000000EEEE
05EEE@020?ooo`80ZZZZ00D0EEEE0:ZZZP2ZZZX0EEEE0000000C0?ooo`X0dLfY3`3oool00`000000
oooo000000020?ooo`<000000P1EEED0103oool0EEEE05EEE@1EEED20?ooo`040000002ZZZX00000
00000080EEEE00H0oooo05EEE@1EEED000000:ZZZP0000020?ooo`80EEEE0P3oool00`1EEED00000
00000002000000@0oooo00<000000?ooo`3oool03@3oool:0=7=Z@h0oooo00<0000005EEE@000000
0`2ZZZX010000000oooo0000002ZZZX20?ooo`80000000@0ZZZZ0000002ZZZX0ZZZZ0P000000102Z
ZZX000000?ooo`3oool400000080ZZZZ00<0000005EEE@0000000`3oool2000000030?ooo`000000
ZZZZ0080ZZZZ00<0000005EEE@0000003P3oool<0=7=Z@002`3AcJTO0?ooo`050000001EEED00000
0?ooo`1EEED00P3oool01@1EEED0oooo0000001EEED0000001l0oooo2P3AcJTK0?ooo`80EEEE0P3o
ool01@1EEED0ZZZZ0:ZZZP000000ZZZZ0080oooo00D0ZZZZ0000002ZZZX0ZZZZ05EEE@020?ooo`03
0:ZZZP1EEED0oooo01X0oooo2P3AcJTD0?ooo`0905EEE@3oool0EEEE0:ZZZP3oool0000005EEE@3o
ool0ZZZZ0080oooo00H000000:ZZZP1EEED0oooo0:ZZZP0000020:ZZZP040000001EEED0ZZZZ0000
00@0oooo00<0ZZZZ0000003oool00P1EEED00`3oool000000?ooo`0C0?ooo`X0dLfY3`3oool00`00
0000oooo0?ooo`020:ZZZP@0000000@0oooo0:ZZZP3oool000000P3oool405EEE@060000002ZZZX0
ZZZZ0?ooo`2ZZZX000000P1EEED01@000000EEEE0?ooo`2ZZZX000000080ZZZZ00<0oooo0:ZZZP00
00000P0000020:ZZZP0305EEE@3oool0oooo00l0oooo2P3AcJT?0?ooo`80000000<0oooo0000001E
EED00P1EEED00`000000EEEE0?ooo`020?ooo`80000000<0EEEE0000001EEED00`0000001@3oool0
EEEE0?ooo`3oool0EEEE0080000000D0oooo0000001EEED0oooo000000030?ooo`80000000D0EEEE
0?ooo`1EEED0000005EEE@02000000l0oooo303AcJT000/0dLfY7`3oool205EEE@030:ZZZP000000
EEEE0080oooo00<0EEEE0000002ZZZX00P1EEEDO0?ooo`X0dLfY703oool00`1EEED0000005EEE@02
05EEE@<0ZZZZ0P0000000`2ZZZX0EEEE0:ZZZP0305EEE@800000703oool:0=7=ZA@0oooo00@00000
05EEE@2ZZZX0EEEE0P0000030:ZZZP030000001EEED0oooo0080EEEE00@0oooo0:ZZZP0000000000
0P2ZZZX205EEE@050:ZZZP1EEED000000?ooo`2ZZZX00`0000000`1EEED0ZZZZ05EEE@0E0?ooo`X0
dLfY403oool2000000030?ooo`00000000000080000000H0EEEE0?ooo`000000oooo05EEE@000002
0:ZZZP090?ooo`1EEED0EEEE0:ZZZP1EEED0oooo0000001EEED0oooo00<0EEEE0`2ZZZX01@1EEED0
00000000003oool0ZZZZ00@0000000<0oooo05EEE@000000403oool:0=7=Z@l0oooo00P000000:ZZ
ZP3oool0EEEE0:ZZZP000000oooo00000080oooo00<0EEEE0?ooo`1EEED00P0000020?ooo`040:ZZ
ZP00000000000:ZZZP80000000@0ZZZZ0?ooo`000000ZZZZ0P3oool03P000000EEEE05EEE@3oool0
EEEE0?ooo`2ZZZX000000?ooo`000000ZZZZ05EEE@3oool0ZZZZ403oool<0=7=Z@002`3AcJTN0?oo
o`0305EEE@00000000000080ZZZZ00@0EEEE0000001EEED0EEEE0P2ZZZX00`000000oooo05EEE@0N
0?ooo`X0dLfY703oool00`2ZZZX0EEEE000000020?ooo`80EEEE00@0ZZZZ0?ooo`3oool0ZZZZ0P1E
EED0103oool0EEEE0000001EEEDM0?ooo`X0dLfY5P3oool00`000000oooo05EEE@02000000070:ZZ
ZP00000000000000003oool0000005EEE@050:ZZZP80EEEE00D0000005EEE@00000000000?ooo`02
0:ZZZP040000001EEED0EEEE000001H0oooo2P3AcJTA0?ooo`<0000000l0oooo0000000000000000
0:ZZZP1EEED0ZZZZ05EEE@000000oooo05EEE@3oool0000005EEE@000000103oool01@000000EEEE
0000002ZZZX0EEEE0080oooo00<0EEEE0000001EEED00P2ZZZX2000000030?ooo`00000000000180
oooo2P3AcJTA0?ooo`80000000@0EEEE0000001EEED0oooo0`000000303oool0EEEE0?ooo`2ZZZX0
oooo0000003oool0ZZZZ0000002ZZZX0000005EEE@<0ZZZZ00@0oooo0000003oool0ZZZZ0`1EEED2
00000080oooo00<0EEEE0?ooo`1EEED00P00000A0?ooo``0dLfY000;0=7=ZAh0oooo00h0EEEE0000
003oool000000?ooo`000000oooo05EEE@000000oooo0000003oool0000005EEEAh0oooo2P3AcJTL
0?ooo`0305EEE@000000ZZZZ0080oooo00<0EEEE0000001EEED00P3oool00`1EEED0ZZZZ05EEE@02
0?ooo`030:ZZZP000000oooo01`0oooo2P3AcJTG0?ooo`0805EEE@2ZZZX0EEEE05EEE@2ZZZX0oooo
05EEE@2ZZZX20?ooo`040000003oool0EEEE0?ooo`<0EEEE00D000000?ooo`3oool0ZZZZ05EEE@02
0:ZZZP040?ooo`1EEED0ZZZZ000001L0oooo2P3AcJTB0?ooo`040000003oool0oooo0?ooo`800000
00@0oooo000000000000EEEE0P3oool205EEE@030:ZZZP3oool0oooo00@0oooo00<000000?ooo`2Z
ZZX00P1EEED01@3oool0000005EEE@2ZZZX000000080oooo00D000000?ooo`3oool0oooo0000000B
0?ooo`X0dLfY4@3oool02@000000ZZZZ0?ooo`1EEED0ZZZZ0000002ZZZX0oooo05EEE@0300000080
ZZZZ00<000000:ZZZP0000000P2ZZZX01`1EEED000000:ZZZP2ZZZX000000:ZZZP3oool00P2ZZZX2
000000030:ZZZP1EEED0oooo0080000000@0ZZZZ0?ooo`3oool0ZZZZ4P3oool<0=7=Z@002`3AcJTM
0?ooo`0705EEE@000000oooo0?ooo`1EEED0ZZZZ05EEE@020?ooo`0405EEE@2ZZZX0EEEE0?ooo`80
000000<0EEEE0?ooo`3oool06`3oool:0=7=ZAd0oooo00@0000005EEE@1EEED0EEEE0P3oool02P2Z
ZZX0oooo05EEE@2ZZZX0EEEE0?ooo`1EEED0oooo05EEE@00000M0?ooo`X0dLfY603oool00`000000
EEEE05EEE@030:ZZZP070000003oool0oooo0?ooo`000000EEEE0:ZZZP0205EEE@<0oooo00<0EEEE
0000002ZZZX00P2ZZZX00`3oool0EEEE0000000H0?ooo`X0dLfY503oool20:ZZZP8000000P2ZZZX2
000000050?ooo`00000000000:ZZZP000000203oool01@000000EEEE000000000000ZZZZ00800000
0P2ZZZX0103oool000000:ZZZP00000D0?ooo`X0dLfY4`3oool20000000;05EEE@3oool0EEEE0?oo
o`1EEED000000:ZZZP3oool0EEEE0000003oool00P0000000`1EEED0oooo0:ZZZP020?ooo`060:ZZ
ZP00000000000?ooo`000000EEEE0P2ZZZX205EEE@040?ooo`000000oooo05EEE@8000004`3oool<
0=7=Z@002`3AcJTN0?ooo`070:ZZZP1EEED0000005EEE@2ZZZX0EEEE0000000205EEE@050?ooo`1E
EED000000000002ZZZX07P3oool:0=7=ZAd0oooo0P1EEED200000080EEEE00@000000?ooo`3oool0
00000P1EEED010000000EEEE05EEE@1EEEDM0?ooo`X0dLfY6@3oool01P000000ZZZZ05EEE@2ZZZX0
EEEE0:ZZZP@0oooo00@000000?ooo`1EEED00000103oool00`2ZZZX0EEEE0:ZZZP0205EEE@030000
003oool0oooo01L0oooo2P3AcJTD0?ooo`8000000P3oool2000000030?ooo`00000000000080EEEE
00<000000?ooo`3oool0203oool01P000000EEEE05EEE@3oool000000?ooo`8000000P3oool00`00
0000oooo0?ooo`0C0?ooo`X0dLfY503oool0102ZZZX0oooo0?ooo`2ZZZX3000000030:ZZZP000000
00000080oooo0P1EEED3000000030:ZZZP000000oooo0080EEEE0P3oool010000000ZZZZ0:ZZZP3o
ool20000000405EEE@3oool0oooo000001@0oooo303AcJT000/0dLfY7P3oool03P1EEED0ZZZZ0000
001EEED0oooo0000003oool0EEEE0000003oool0EEEE0000002ZZZX0EEEE7P3oool:0=7=ZAh0oooo
00<0ZZZZ0?ooo`1EEED00`1EEED20?ooo`D0EEEE00<0ZZZZ0?ooo`3oool0703oool:0=7=ZAX0oooo
0P1EEED00`2ZZZX0EEEE05EEE@020?ooo`0505EEE@3oool0oooo05EEE@0000000P3oool00`1EEED0
oooo0?ooo`0205EEE@030:ZZZP1EEED0000001X0oooo2P3AcJTE0?ooo`090000003oool0oooo0000
003oool0EEEE0000003oool0ZZZZ00`0oooo00D000000?ooo`2ZZZX0EEEE000000020?ooo`040000
001EEED0oooo000001D0oooo2P3AcJTD0?ooo`030000001EEED0EEEE00<0ZZZZ00<0oooo0000003o
ool01@1EEED2000000030?ooo`1EEED0000000<0EEEE00D0000005EEE@1EEED0EEEE000000030:ZZ
ZP030000001EEED0EEEE01D0oooo303AcJT000/0dLfY7`3oool010000000EEEE05EEE@0000040?oo
o`030:ZZZP1EEED0EEEE0200oooo2P3AcJTN0?ooo`0505EEE@2ZZZX0EEEE05EEE@000000103oool3
05EEE@030:ZZZP1EEED0oooo01d0oooo2P3AcJTK0?ooo`040000002ZZZX0EEEE05EEE@80oooo0`00
00001`3oool0EEEE0000001EEED000000?ooo`0000000`1EEED00`000000oooo0?ooo`0I0?ooo`X0
dLfY5`3oool0102ZZZX000000:ZZZP0000020:ZZZP030000003oool0oooo00`0oooo00<0000005EE
E@2ZZZX00P2ZZZX2000001L0oooo2P3AcJTF0?ooo`040000003oool0oooo05EEE@80000000D0oooo
05EEE@000000oooo000000020:ZZZP0A05EEE@000000EEEE05EEE@3oool0ZZZZ0000002ZZZX00000
05EEE@2ZZZX000000:ZZZP1EEED0oooo0:ZZZP0000005P3oool<0=7=Z@002`3AcJTO0?ooo`80EEEE
00<0ZZZZ0?ooo`1EEED00P3oool205EEE@030:ZZZP1EEED0oooo01l0oooo2P3AcJTN0?ooo`D0EEEE
103oool305EEE@030:ZZZP1EEED0oooo01d0oooo2P3AcJTL0?ooo`80EEEE00<0ZZZZ0?ooo`3oool0
0P1EEED20?ooo`090:ZZZP3oool0ZZZZ05EEE@3oool0EEEE0:ZZZP1EEED0000001`0oooo2P3AcJTG
0?ooo`@0000000<0oooo0:ZZZP1EEED03P3oool0101EEED000000?ooo`3oool2000001P0oooo2P3A
cJTG0?ooo`80EEEE00<000000:ZZZP2ZZZX00`0000020?ooo`0:0000001EEED0ZZZZ05EEE@000000
ZZZZ05EEE@000000oooo05EEE@8000000`2ZZZX00`000000EEEE0000000G0?ooo``0dLfY000;0=7=
ZAl0oooo00D0EEEE0?ooo`2ZZZX0000005EEE@020?ooo`0305EEE@2ZZZX0ZZZZ0240oooo2P3AcJTO
0?ooo`80EEEE0P3oool00`1EEED0oooo05EEE@0205EEE@030?ooo`1EEED0EEEE01l0oooo2P3AcJTM
0?ooo`040000001EEED0EEEE0?ooo`80ZZZZ00<0oooo05EEE@1EEED00P3oool01@2ZZZX0oooo0:ZZ
ZP1EEED0000001d0oooo2P3AcJTI0?ooo`040000003oool0oooo0:ZZZQ00oooo00@000000?ooo`1E
EED000006@3oool:0=7=ZAP0oooo00@000000:ZZZP3oool0EEEE0P0000030?ooo`0405EEE@2ZZZX0
00000?ooo`80000000/0oooo05EEE@3oool0EEEE0?ooo`000000ZZZZ05EEE@3oool0ZZZZ0000000H
0?ooo``0dLfY000;0=7=ZB00oooo0`2ZZZX0101EEED0000005EEE@1EEED30:ZZZR00oooo2P3AcJTO
0?ooo`050:ZZZP1EEED000000000001EEED00P00000205EEE@030000001EEED0oooo01l0oooo2P3A
cJTN0?ooo`070000001EEED0ZZZZ0000003oool0ZZZZ000000020:ZZZP80000000<0ZZZZ05EEE@00
00007P3oool:0=7=ZAX0oooo0P2ZZZX02`000000oooo05EEE@000000EEEE0?ooo`1EEED0000005EE
E@3oool000000080oooo00L0EEEE0?ooo`1EEED0oooo0000002ZZZX0000001X0oooo2P3AcJTI0?oo
o`030000001EEED0000000<0ZZZZ0`3oool01P2ZZZX000000?ooo`3oool000000:ZZZP<0oooo0`2Z
ZZX00`000000EEEE0000000I0?ooo``0dLfY000;0=7=ZB40oooo00P000000?ooo`000000oooo05EE
E@000000oooo00000240oooo2P3AcJTO0?ooo`0305EEE@000000ZZZZ0080EEEE00H0oooo05EEE@1E
EED0oooo0:ZZZP00000P0?ooo`X0dLfY7`3oool01@1EEED0oooo05EEE@3oool0ZZZZ008000000P2Z
ZZX00`1EEED0oooo0000000O0?ooo`X0dLfY6P3oool2000000030?ooo`000000EEEE0080oooo00H0
ZZZZ0?ooo`3oool0EEEE0000003oool20:ZZZP060?ooo`000000EEEE0000003oool000006`3oool:
0=7=ZAX0oooo0P0000000`3oool0000005EEE@030?ooo`030000003oool0oooo0080oooo00L0EEEE
0?ooo`3oool0oooo05EEE@000000EEEE008000006P3oool<0=7=Z@002`3AcJTQ0?ooo`0505EEE@3o
ool000000000002ZZZX00P0000000`1EEED0oooo0?ooo`0O0?ooo`X0dLfY803oool01@000000EEEE
05EEE@1EEED0oooo0080EEEE00<0oooo05EEE@000000803oool:0=7=ZB00oooo00<0000005EEE@2Z
ZZX0102ZZZX205EEE@030000003oool0oooo01h0oooo2P3AcJTL0?ooo`0;05EEE@000000oooo05EE
E@000000oooo0000001EEED0oooo0000001EEED00P3oool2000000030?ooo`000000000001`0oooo
2P3AcJTK0?ooo`030000001EEED0000000<0ZZZZ00<000000?ooo`3oool0103oool01`000000ZZZZ
0:ZZZP2ZZZX0000005EEE@0000006`3oool<0=7=Z@002`3AcJTP0?ooo`0:05EEE@3oool000000:ZZ
ZP3oool0EEEE0:ZZZP000000oooo05EEEB00oooo2P3AcJTP0?ooo`80EEEE0P0000020?ooo`040000
001EEED0EEEE05EEEB00oooo2P3AcJTQ0?ooo`040000003oool0EEEE0?ooo`<0EEEE00<000000?oo
o`3oool07`3oool:0=7=ZA`0oooo00@000000:ZZZP00000000000`3oool2000000030:ZZZP000000
oooo0080oooo00<0ZZZZ0000002ZZZX07@3oool:0=7=ZA`0oooo0P0000000`1EEED0000005EEE@03
0?ooo`0805EEE@3oool0oooo05EEE@3oool0EEEE0?ooo`1EEED2000001`0oooo303AcJT000/0dLfY
8@3oool01@2ZZZX0EEEE000000000000ZZZZ0080000000<0ZZZZ0?ooo`3oool07`3oool:0=7=ZB40
oooo0P1EEED01P2ZZZX000000000002ZZZX0000005EEEB40oooo2P3AcJTR0?ooo`030000001EEED0
ZZZZ0080EEEE8`3oool:0=7=ZAh0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01`0oooo2P3AcJTM0?ooo`030000001EEED000000080ZZZZ00@0EEEE
0:ZZZP3oool0EEEE102ZZZX205EEE@030000003oool0oooo01/0oooo303AcJT000/0dLfY8@3oool0
1@1EEED000000:ZZZP3oool0EEEE0080ZZZZ00<0EEEE0?ooo`3oool07`3oool:0=7=ZB80oooo00<0
ZZZZ05EEE@3oool00P1EEED00`000000oooo0?ooo`0P0?ooo`X0dLfY8`3oool010000000oooo05EE
E@00000S0?ooo`X0dLfY7`3oool02@1EEED0oooo0?ooo`000000oooo0000001EEED0oooo05EEE@02
0?ooo`030000003oool0oooo01d0oooo2P3AcJTN0?ooo`80000000X0EEEE0?ooo`1EEED0ZZZZ0000
001EEED0ZZZZ0000003oool0EEEE0P00000N0?ooo``0dLfY000;0=7=ZB80oooo00@0EEEE0:ZZZP3o
ool0oooo0P2ZZZXR0?ooo`X0dLfY8P3oool01P1EEED0ZZZZ0?ooo`3oool0ZZZZ05EEEB80oooo2P3A
cJTT0?ooo`0305EEE@000000oooo02<0oooo2P3AcJTO0?ooo`040000002ZZZX0ZZZZ0?ooo`800000
00<0EEEE0000003oool00P2ZZZXP0?ooo`X0dLfY7`3oool02@2ZZZX0oooo0?ooo`2ZZZX0000005EE
E@2ZZZX0000005EEE@020?ooo`030000003oool0oooo01d0oooo303AcJT000/0dLfY8P3oool00`2Z
ZZX0EEEE0000000205EEEB<0oooo2P3AcJTR0?ooo`0505EEE@000000EEEE0:ZZZP0000008`3oool:
0=7=ZB@0oooo00<0000005EEE@3oool08`3oool:0=7=ZB40oooo00<0000005EEE@1EEED00P000000
0`1EEED0oooo0000000Q0?ooo`X0dLfY803oool20000000505EEE@3oool000000000003oool00`00
000P0?ooo``0dLfY000;0=7=ZB<0oooo00@000000?ooo`1EEED000008`3oool:0=7=ZB<0oooo00@0
00000:ZZZP2ZZZX000008`3oool:0=7=ZB<0oooo00@0EEEE0000003oool0EEEE8`3oool:0=7=ZB80
oooo00<0EEEE0000000000000`00000R0?ooo`X0dLfY8@3oool010000000oooo0?ooo`0000020?oo
o`030:ZZZP000000oooo0200oooo303AcJT000/0dLfY8P3oool0101EEED0oooo0000001EEEDT0?oo
o`X0dLfY8`3oool0101EEED0ZZZZ05EEE@1EEEDS0?ooo`X0dLfY8P3oool0101EEED0oooo00000000
000T0?ooo`X0dLfY8P3oool01@000000ZZZZ000000000000ZZZZ02<0oooo2P3AcJTR0?ooo`<0EEEE
00<0000005EEE@0000008P3oool<0=7=Z@002`3AcJTS0?ooo`80ZZZZ00<000000:ZZZP3oool08P3o
ool:0=7=ZB<0oooo0P1EEED00`2ZZZX0EEEE0?ooo`0R0?ooo`X0dLfY8`3oool0101EEED0oooo05EE
E@1EEEDS0?ooo`X0dLfY9@3oool00`000000oooo0?ooo`0R0?ooo`X0dLfY8`3oool2000000030:ZZ
ZP000000oooo0280oooo303AcJT000/0dLfY903oool2000002@0oooo2P3AcJTT0?ooo`0305EEE@00
0000oooo02<0oooo2P3AcJTU0?ooo`030:ZZZP3oool0oooo0280oooo2P3AcJTT0?ooo`030:ZZZP1E
EED0oooo02<0oooo2P3AcJTT0?ooo`0305EEE@000000oooo02<0oooo303AcJT000/0dLfY903oool0
0`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool0
0`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool0
0`2ZZZX0oooo0?ooo`0S0?ooo``0dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY
003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY000;0=7=Z@090?ooo`2ZZZX0oooo0:ZZ
ZP1EEED0oooo0000002ZZZX0EEEE0080oooo0P1EEED00`000000EEEE0?ooo`030:ZZZP0:0000003o
ool000000:ZZZP3oool0EEEE0000001EEED0ZZZZ00000080EEEE00D0ZZZZ0000001EEED0EEEE0000
000205EEE@050000001EEED0EEEE0000003oool00`1EEED00`2ZZZX0EEEE0000000205EEE@090:ZZ
ZP000000oooo0000002ZZZX000000:ZZZP000000EEEE0080000000`0EEEE0?ooo`1EEED0EEEE0:ZZ
ZP000000oooo05EEE@2ZZZX0oooo0:ZZZP3oool:0=7=Z@040?ooo`2ZZZX0oooo00000080ZZZZ00@0
oooo0:ZZZP3oool000000`3oool00`2ZZZX0oooo000000020?ooo`80000000@0oooo0:ZZZP000000
EEEE1P000000103oool000000000000000060?ooo`8000000P3oool8000000050:ZZZP0000000000
0000002ZZZX00`3oool01P2ZZZX000000?ooo`3oool0ZZZZ0?ooo`<0ZZZZ00D0oooo0000003oool0
ZZZZ0?ooo`0:0=7=Z@040?ooo`2ZZZX0oooo0?ooo`@0ZZZZ00@0EEEE0:ZZZP2ZZZX0oooo0`2ZZZX0
10000000EEEE0:ZZZP1EEED20:ZZZP80000000D0EEEE0?ooo`3oool0oooo05EEE@020?ooo`80EEEE
00@0ZZZZ05EEE@2ZZZX000000P1EEED20000000405EEE@2ZZZX0ZZZZ05EEE@80oooo00D0EEEE0?oo
o`3oool0oooo05EEE@03000000050:ZZZP1EEED0ZZZZ05EEE@0000000`2ZZZX0103oool0ZZZZ05EE
E@1EEED40:ZZZP80oooo00<0ZZZZ0?ooo`3AcJT02@3AcJT00`3oool0EEEE000000030:ZZZP0905EE
E@2ZZZX0EEEE0000001EEED0ZZZZ0000001EEED000000080EEEE0P0000001`3oool0ZZZZ0:ZZZP2Z
ZZX000000:ZZZP3oool00P1EEED01`2ZZZX000000000002ZZZX000000:ZZZP1EEED01P2ZZZX01P00
0000EEEE000000000000oooo05EEE@80oooo102ZZZX01@000000oooo000000000000EEEE00800000
00<0EEEE0:ZZZP2ZZZX00`1EEED0202ZZZX0EEEE0:ZZZP000000ZZZZ0000002ZZZX0oooo2P3AcJT0
1P3oool000000?ooo`3oool0EEEE0:ZZZP<0EEEE00H0oooo05EEE@3oool0ZZZZ05EEE@0000020?oo
o`030000001EEED0oooo00<000000P3oool00`000000ZZZZ0:ZZZP040?ooo`80ZZZZ0P000000101E
EED0oooo0000000000020:ZZZP<0oooo0P2ZZZX200000080oooo0`0000002`3oool0EEEE0000003o
ool0EEEE0000001EEED000000?ooo`1EEED000000080EEEE00<000000:ZZZP1EEED00P3oool00`2Z
ZZX0oooo0=7=Z@0;0=7=Z@002`3AcJT02@3oool0ZZZZ0?ooo`000000ZZZZ0000003oool0000005EE
E@0300000080EEEE00D000000:ZZZP3oool0EEEE000000030?ooo`0305EEE@000000000000<0EEEE
0P0000001`1EEED0ZZZZ000000000000ZZZZ0000001EEED00P0000001`1EEED000000000002ZZZX0
EEEE0000002ZZZX00`1EEED20000000505EEE@3oool0oooo0?ooo`0000000P3oool200000080EEEE
0`0000001P1EEED000000?ooo`000000EEEE000000<0oooo2P3AcJT00`3oool0ZZZZ0?ooo`020000
00060:ZZZP00000000000:ZZZP3oool000000P2ZZZX300000080oooo00/000000?ooo`0000000000
0:ZZZP000000oooo0000003oool000000?ooo`03000000030?ooo`000000000000H0000000<0oooo
0000000000001@0000000`3oool0EEEE0:ZZZP02000000040?ooo`000000ZZZZ0?ooo`<0000000D0
oooo0:ZZZP000000oooo0:ZZZP02000000030:ZZZP000000000000<0oooo2P3AcJT04P3oool0ZZZZ
000000000000oooo0000001EEED0ZZZZ0000002ZZZX0EEEE0000002ZZZX000000?ooo`1EEED0oooo
0:ZZZP80EEEE00L0oooo0:ZZZP2ZZZX000000:ZZZP000000ZZZZ00<0000000<0ZZZZ05EEE@1EEED0
0P3oool01`2ZZZX000000:ZZZP2ZZZX000000?ooo`1EEED00P2ZZZX00`000000ZZZZ000000020000
00@0ZZZZ00d0oooo05EEE@1EEED000000?ooo`2ZZZX0oooo0000001EEED0000005EEE@2ZZZX00000
0080ZZZZ00@000000:ZZZP00000000000P3oool:0=7=Z@050?ooo`2ZZZX0000005EEE@2ZZZX00`00
0000102ZZZX0000000000000000205EEE@030?ooo`1EEED0EEEE00<0ZZZZ00@0EEEE000000000000
00000`1EEED01`2ZZZX000000000003oool0ZZZZ0000001EEED00`000000101EEED000000000001E
EED2000000030?ooo`000000ZZZZ0080ZZZZ0P1EEED0102ZZZX000000000000000020:ZZZP040?oo
o`1EEED0oooo0?ooo`80EEEE0P0000000`3oool0ZZZZ000000030000000405EEE@000000oooo0?oo
o`X0dLfY00<0oooo0:ZZZP0000000`1EEED30000000405EEE@2ZZZX0EEEE00000080ZZZZ0P1EEED0
1@3oool0EEEE0000003oool0000000@0oooo00<0EEEE0000001EEED0101EEED3000000050:ZZZP1E
EED0000005EEE@0000001@1EEED00`000000EEEE0?ooo`030?ooo`030000002ZZZX0000000@0EEEE
0P2ZZZX00`000000EEEE0:ZZZP040000000405EEE@2ZZZX0EEEE00000080oooo303AcJT000/0dLfY
0`3oool02P2ZZZX0oooo000000000000EEEE0000003oool0ZZZZ05EEE@0000020:ZZZP0305EEE@00
0000000000@0EEEE0`0000000`2ZZZX0oooo0?ooo`02000000040?ooo`2ZZZX0oooo05EEE@800000
0P1EEED00`000000oooo05EEE@030?ooo`0:0000003oool0oooo05EEE@2ZZZX0000005EEE@000000
EEEE00000080EEEE00<0oooo0000003oool00P2ZZZX205EEE@040:ZZZP1EEED0000005EEE@800000
0P2ZZZX30?ooo`X0dLfY0`3oool02`2ZZZX00000000000000000oooo0:ZZZP000000oooo0:ZZZP00
0000EEEE00<0000000P0ZZZZ0?ooo`2ZZZX0oooo0000003oool0ZZZZ0?ooo`<0000000D0oooo0000
0000000000000?ooo`0300000080oooo0`0000000`3oool0000000000005000000<0oooo00@00000
0:ZZZP2ZZZX0oooo0P0000002@3oool0000005EEE@000000ZZZZ0?ooo`000000ZZZZ0?ooo`020000
0080ZZZZ0`3oool:0=7=Z@<0oooo00<0ZZZZ0000002ZZZX00P2ZZZX0101EEED000000:ZZZP1EEED3
000000040?ooo`1EEED0000000000080ZZZZ00H000000:ZZZP00000000000:ZZZP00000205EEE@04
0:ZZZP00000000000?ooo`80ZZZZ0P0000001@2ZZZX000000:ZZZP2ZZZX0oooo0080000000H0ZZZZ
0000001EEED0EEEE0:ZZZP0000020:ZZZP030000002ZZZX0ZZZZ0080000000@0EEEE000000000000
00000P1EEED20:ZZZP0605EEE@2ZZZX000000:ZZZP000000ZZZZ0`3oool:0=7=Z@<0oooo00<0ZZZZ
0000003oool00P3oool010000000EEEE0000001EEED2000000050:ZZZP1EEED0EEEE0000003oool0
0P2ZZZX2000000080?ooo`000000EEEE0:ZZZP1EEED000000?ooo`2ZZZX500000080ZZZZ00/00000
05EEE@00000000000?ooo`2ZZZX0oooo0000001EEED0000005EEE@0400000080ZZZZ00D0oooo0:ZZ
ZP1EEED000000:ZZZP020000000405EEE@0000000000000000<0oooo00<000000:ZZZP3oool00P3o
ool:0=7=Z@<0oooo00@0ZZZZ0000001EEED00000101EEED00`3oool0EEEE00000002000000030:ZZ
ZP000000000000@0EEEE0P3oool205EEE@80ZZZZ00<0oooo0000002ZZZX00P2ZZZX01@000000EEEE
05EEE@2ZZZX0EEEE00<0ZZZZ00<0oooo0000003oool00P2ZZZX205EEE@80oooo101EEED00`000000
ZZZZ0:ZZZP0300000080oooo00<0EEEE0000001EEED00`1EEED00`000000ZZZZ0?ooo`020?ooo``0
dLfY000;0=7=Z@D0oooo00P000000?ooo`000000000005EEE@2ZZZX0EEEE00000080ZZZZ00/0oooo
0000002ZZZX0EEEE0000002ZZZX0EEEE0000002ZZZX0oooo05EEE@03000000040:ZZZP000000ZZZZ
0?ooo`80000000@0ZZZZ05EEE@000000ZZZZ0P0000020?ooo`030000002ZZZX000000080000000D0
EEEE0?ooo`1EEED0000005EEE@020000000405EEE@3oool0000000000080ZZZZ00@0000005EEE@2Z
ZZX0ZZZZ0P0000000`3oool000000:ZZZP040?ooo`X0dLfY1@3oool0102ZZZX0oooo0:ZZZP000003
0?ooo`0505EEE@3oool000000000001EEED0103oool00`000000oooo0000000400000080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo008000000P3oool020000000oooo
000000000000ZZZZ0?ooo`000000ZZZZ0P3oool01P2ZZZX0EEEE000000000000oooo0:ZZZP80oooo
0P0000040:ZZZP@0oooo2P3AcJT40?ooo`050:ZZZP3oool0EEEE05EEE@3oool00P0000000`3oool0
000000000002000000H0ZZZZ00L0oooo000000000000000005EEE@2ZZZX0oooo00@000000`2ZZZX0
1@000000oooo0:ZZZP1EEED0ZZZZ00@0000000<0EEEE0:ZZZP3oool00`0000000`3oool0ZZZZ05EE
E@040:ZZZP<0000000H0EEEE0?ooo`00000000000?ooo`1EEED20?ooo`030:ZZZP3oool0oooo0080
oooo2P3AcJT40?ooo`0505EEE@000000EEEE0000003oool00P0000002@3oool0ZZZZ0:ZZZP3oool0
00000:ZZZP3oool0EEEE0000000405EEE@030:ZZZP3oool000000080ZZZZ0P1EEED20?ooo`800000
00@0oooo0:ZZZP3oool0oooo0P0000002@3oool0000005EEE@1EEED0oooo0:ZZZP000000oooo0:ZZ
ZP0305EEE@80000000<0EEEE0?ooo`2ZZZX00P3oool20:ZZZP080?ooo`00000000000?ooo`000000
oooo0000002ZZZX40?ooo`X0dLfY103oool00`000000oooo000000020000000405EEE@3oool00000
0?ooo`D0EEEE1@0000000`3oool000000000000400000080oooo00<0ZZZZ0?ooo`2ZZZX00P000000
1@2ZZZX000000?ooo`3oool0ZZZZ0080oooo00<000000:ZZZP0000002P000000101EEED0oooo05EE
E@1EEED2000000070?ooo`00000000000000001EEED0oooo0:ZZZP040?ooo``0dLfY000;0=7=Z@D0
oooo00L0ZZZZ0?ooo`2ZZZX0EEEE0000003oool0000000<0EEEE00<0ZZZZ0000001EEED00P1EEED0
0`000000EEEE0?ooo`0405EEE@090000001EEED0EEEE05EEE@000000oooo05EEE@2ZZZX000000080
oooo00<0000005EEE@1EEED00P3oool205EEE@8000000`1EEED20?ooo`0705EEE@000000EEEE05EE
E@2ZZZX000000?ooo`0205EEE@80000000<0oooo05EEE@1EEED00`2ZZZX50?ooo`X0dLfY1@3oool0
1`2ZZZX0oooo0?ooo`3oool000000?ooo`0000000P1EEED00`000000ZZZZ0?ooo`020000000705EE
E@00000000000000001EEED000000?ooo`05000000030?ooo`000000000000H0oooo1`0000020?oo
o`070000002ZZZX000000000002ZZZX0EEEE000000030?ooo`040000001EEED00000000000@0oooo
0P2ZZZX50?ooo`X0dLfY1@3oool00`2ZZZX0oooo0?ooo`040:ZZZP0305EEE@2ZZZX0ZZZZ0080ZZZZ
0`1EEED0102ZZZX000000?ooo`1EEED30?ooo`@0ZZZZ00@0oooo0:ZZZP1EEED0oooo1000000205EE
E@@0ZZZZ00<000000:ZZZP000000103oool00`000000ZZZZ05EEE@0205EEE@030:ZZZP1EEED0ZZZZ
00H0ZZZZ00<0oooo0:ZZZP2ZZZX01@3oool:0=7=Z@D0oooo0P2ZZZX00`1EEED0ZZZZ000000020:ZZ
ZP030000003oool000000080ZZZZ00<0oooo0:ZZZP1EEED01`1EEED01@000000EEEE000000000000
EEEE0080ZZZZ00H000000:ZZZP1EEED000000:ZZZP0000020:ZZZP040?ooo`00000000000?ooo`80
00001`1EEED01@2ZZZX0oooo0:ZZZP2ZZZX000000080oooo0P2ZZZX01@1EEED0ZZZZ05EEE@1EEED0
ZZZZ00D0oooo2P3AcJT50?ooo`80ZZZZ0P1EEED010000000EEEE0000003oool200000080EEEE00<0
00000?ooo`1EEED00P2ZZZX00`000000ZZZZ0?ooo`030000000805EEE@3oool0oooo0000001EEED0
00000?ooo`1EEED200000080EEEE00<0000005EEE@0000000P3oool20000000;05EEE@000000oooo
05EEE@000000ZZZZ0000001EEED0oooo0000001EEED00`0000000`3oool0000005EEE@0305EEE@03
0000002ZZZX0oooo00@0oooo303AcJT000/0dLfY1`3oool00`000000EEEE000000030000000505EE
E@000000oooo0?ooo`1EEED00P0000000`1EEED000000:ZZZP020000000305EEE@000000EEEE0080
000000D0EEEE0:ZZZP3oool0000005EEE@040?ooo`80000000@0oooo0:ZZZP1EEED000000P1EEED0
1`000000EEEE0000003oool0ZZZZ0000001EEED00`0000001@3oool0ZZZZ0000001EEED0ZZZZ0080
000000@0ZZZZ05EEE@000000ZZZZ1P3oool:0=7=Z@L0oooo00<000000:ZZZP0000000`0000000`1E
EED0oooo00000002000000030?ooo`000000EEEE0080EEEE00H000000?ooo`3oool0oooo0000003o
ool200000080oooo200000020?ooo`@000000`3oool405EEE@080000003oool000000000002ZZZX0
oooo05EEE@3oool2000000040?ooo`2ZZZX000000:ZZZPH0oooo2P3AcJT60?ooo`80000000H0ZZZZ
0000002ZZZX0EEEE0000002ZZZX205EEE@050000002ZZZX000000:ZZZP1EEED00`000000102ZZZX0
00000000002ZZZX405EEE@030000002ZZZX0000000@000000P2ZZZX01P000000EEEE05EEE@1EEED0
oooo0:ZZZP8000000P2ZZZX200000080ZZZZ00D000000:ZZZP000000ZZZZ05EEE@020:ZZZP0605EE
E@2ZZZX0oooo0:ZZZP000000ZZZZ1P3oool:0=7=Z@H0oooo0`0000001@3oool0ZZZZ0?ooo`3oool0
EEEE00<0000000<0ZZZZ0000000000001P0000001@3oool0ZZZZ0000003oool000000080EEEE00H0
00000?ooo`3oool0EEEE0:ZZZP3oool20000000405EEE@3oool000000?ooo`80ZZZZ2@0000001@2Z
ZZX000000:ZZZP000000EEEE0080oooo0P2ZZZX2000000030:ZZZP3oool0oooo00@0oooo2P3AcJT6
0?ooo`@0000000P0EEEE0?ooo`3oool0oooo05EEE@2ZZZX000000?ooo`8000000P1EEED200000009
0:ZZZP1EEED000000?ooo`1EEED000000:ZZZP3oool0EEEE008000000P3oool0101EEED0oooo0000
0000000205EEE@030:ZZZP000000oooo0080oooo00D0EEEE0:ZZZP000000000005EEE@0300000004
0:ZZZP000000ZZZZ05EEE@<0oooo00D0EEEE00000000000000000:ZZZP060?ooo``0dLfY000;0=7=
Z@H0oooo00@0ZZZZ000000000000EEEE0P3oool03@000000EEEE0000003oool0EEEE0000002ZZZX0
00000?ooo`000000oooo05EEE@000000101EEED01@000000EEEE05EEE@1EEED0oooo00D000000P3o
ool0101EEED0ZZZZ05EEE@00000205EEE@050000001EEED0000005EEE@3oool00`0000001@2ZZZX0
EEEE05EEE@1EEED000000080EEEE0`3oool2000000L0oooo2P3AcJT60?ooo`030:ZZZP000000EEEE
0080oooo0P000000103oool0EEEE0000002ZZZX30000000305EEE@000000oooo00D000000P3oool4
000000030?ooo`000000oooo0080000000<0oooo0000000000000P0000020?ooo`@0000000@0EEEE
0?ooo`000000oooo0P0000001@1EEED0ZZZZ05EEE@1EEED0oooo0080000000@0oooo05EEE@1EEED0
00001`3oool:0=7=Z@H0oooo0P2ZZZX20?ooo`80EEEE0P2ZZZX205EEE@040:ZZZP3oool0ZZZZ05EE
E@<0ZZZZ00@0oooo000000000000EEEE0P0000050:ZZZPD0000000@0EEEE0:ZZZP2ZZZX000000`2Z
ZZX4000000080?ooo`2ZZZX0ZZZZ0000001EEED0ZZZZ0?ooo`2ZZZX205EEE@80ZZZZ0P1EEED20?oo
o`030:ZZZP3oool0oooo00D0oooo2P3AcJT60?ooo`090:ZZZP1EEED000000000002ZZZX000000:ZZ
ZP000000oooo0080ZZZZ00<0oooo0:ZZZP2ZZZX01`2ZZZX010000000ZZZZ05EEE@1EEED20:ZZZP03
05EEE@2ZZZX0ZZZZ0080000000@0ZZZZ0000001EEED0ZZZZ0`1EEED2000000T0ZZZZ00L0oooo0:ZZ
ZP3oool0oooo0000002ZZZX000000080ZZZZ00<0000005EEE@3oool01P3oool:0=7=Z@H0oooo00<0
ZZZZ0000003oool00P1EEED00`2ZZZX0EEEE0:ZZZP0300000080EEEE00@0oooo05EEE@000000oooo
0P1EEED2000000060?ooo`000000000005EEE@2ZZZX000000P2ZZZX01`1EEED0oooo0000001EEED0
oooo0:ZZZP0000000P1EEED200000080oooo00D0000005EEE@3oool0oooo000000020?ooo`80EEEE
00L000000:ZZZP000000ZZZZ0000002ZZZX0EEEE0080oooo00<000000?ooo`3oool01@3oool<0=7=
Z@002`3AcJT80?ooo`030:ZZZP000000oooo0080oooo0P0000001`1EEED000000000003oool0ZZZZ
05EEE@3oool00`0000000`3oool000000:ZZZP020?ooo`0305EEE@000000EEEE0080000000@0oooo
05EEE@1EEED0oooo0P0000004P1EEED0000005EEE@3oool000000:ZZZP000000oooo0000002ZZZX0
00000?ooo`000000ZZZZ0?ooo`1EEED0000005EEE@<000000`3oool00`2ZZZX0oooo0?ooo`060?oo
o`X0dLfY203oool20:ZZZP070?ooo`00000000000000001EEED000000:ZZZP0400000080ZZZZ00D0
oooo000000000000oooo0:ZZZP0200000080oooo100000000`3oool000000000000300000080oooo
00<0000005EEE@2ZZZX0100000030:ZZZP8000000P2ZZZX205EEE@<000000P3oool00`2ZZZX0oooo
0?ooo`060?ooo`X0dLfY203oool01@2ZZZX0oooo0?ooo`1EEED0oooo0080000000P0oooo0:ZZZP1E
EED0ZZZZ0?ooo`000000oooo05EEE@80ZZZZ00@0oooo0:ZZZP000000ZZZZ101EEED0202ZZZX00000
0000001EEED0ZZZZ0000003oool0ZZZZ101EEED20000000;0:ZZZP3oool0ZZZZ0:ZZZP1EEED0oooo
0000003oool0ZZZZ05EEE@2ZZZX00`00000205EEE@030?ooo`2ZZZX0ZZZZ00P0oooo2P3AcJT80?oo
o`80ZZZZ0P0000030:ZZZP070?ooo`000000ZZZZ0000001EEED0ZZZZ0?ooo`03000000040?ooo`1E
EED0000000000080oooo00D000000?ooo`2ZZZX0ZZZZ000000020:ZZZP80000000<0ZZZZ0?ooo`00
00000P3oool2000000030:ZZZP3oool000000080000000<0oooo0:ZZZP1EEED0100000020:ZZZP05
0?ooo`000000000005EEE@2ZZZX0203oool:0=7=Z@P0oooo0P2ZZZX010000000ZZZZ0:ZZZP2ZZZX3
0?ooo`80000000@0EEEE0:ZZZP2ZZZX0EEEE0P0000020:ZZZP080?ooo`000000oooo0:ZZZP3oool0
00000?ooo`0000040?ooo`0;05EEE@3oool000000?ooo`2ZZZX0oooo0000003oool000000:ZZZP00
00000P1EEED20:ZZZP0305EEE@000000000000<0oooo0`2ZZZX2000000030:ZZZP3oool0oooo00H0
oooo303AcJT000/0dLfY2@3oool3000000030:ZZZP3oool0ZZZZ0080000000@0EEEE0?ooo`1EEED0
EEEE0P2ZZZX2000000<0ZZZZ0`0000000`1EEED00000000000020000000405EEE@00000000000:ZZ
ZP80000000P0EEEE00000000000000000:ZZZP3oool0ZZZZ000000<0ZZZZ00P0000005EEE@3oool0
ZZZZ0000001EEED0ZZZZ0?ooo`<0000000<0ZZZZ0?ooo`3oool01`3oool:0=7=Z@T0oooo10000000
1P2ZZZX0EEEE0:ZZZP3oool0ZZZZ05EEE@8000000P1EEED2000000040?ooo`1EEED0EEEE0?ooo`@0
000000<0oooo0000000000000P3oool00`000000oooo0?ooo`050000000305EEE@3oool0oooo0080
00000P1EEED00`2ZZZX0000005EEE@020?ooo`80EEEE00D0ZZZZ05EEE@00000000000:ZZZP090?oo
o`X0dLfY2@3oool2000000030:ZZZP00000000000080000000<0ZZZZ05EEE@2ZZZX00`0000001@2Z
ZZX0EEEE0:ZZZP000000oooo0080ZZZZ101EEED01@2ZZZX000000000002ZZZX0EEEE0080000000<0
ZZZZ05EEE@2ZZZX00P1EEED20:ZZZP8000000`2ZZZX3000000030:ZZZP1EEED0ZZZZ00<000000P2Z
ZZX00`000000ZZZZ0?ooo`080?ooo`X0dLfY2@3oool200000080oooo00@0ZZZZ0?ooo`000000EEEE
0P3oool0101EEED0000005EEE@3oool30:ZZZP80000000L0oooo05EEE@000000oooo0000001EEED0
ZZZZ0080000000T0EEEE000000000000EEEE0000003oool0000005EEE@3oool00P0000030:ZZZP07
0?ooo`1EEED0EEEE05EEE@3oool0ZZZZ05EEE@020?ooo`050:ZZZP3oool0oooo0000002ZZZX02@3o
ool:0=7=Z@T0oooo0P0000000`1EEED0000005EEE@0305EEE@80oooo00D0000005EEE@000000EEEE
000000020?ooo`80000000@0oooo000000000000EEEE0P00000505EEE@040?ooo`00000000000:ZZ
ZP80000000<0oooo0000002ZZZX00`3oool01@1EEED0000005EEE@000000oooo00L0EEEE00<00000
0:ZZZP3oool0203oool<0=7=Z@002`3AcJT:0?ooo`090:ZZZP3oool0EEEE0:ZZZP000000oooo0000
001EEED0ZZZZ00<0000000@0oooo05EEE@00000000000`3oool01@000000ZZZZ05EEE@3oool0EEEE
008000000P1EEED00`000000EEEE05EEE@020?ooo`050:ZZZP000000oooo0?ooo`2ZZZX00P000000
3P2ZZZX0oooo0000002ZZZX000000:ZZZP1EEED000000?ooo`000000ZZZZ0000003oool0ZZZZ2P3o
ool:0=7=Z@X0oooo00H0ZZZZ0?ooo`1EEED000000:ZZZP0000030?ooo`040:ZZZP000000ZZZZ0:ZZ
ZP8000000P3oool00`2ZZZX0oooo0?ooo`03000000030?ooo`000000000000<000000P3oool30000
0080oooo0P2ZZZX00`3oool000000?ooo`020:ZZZP070?ooo`2ZZZX0oooo0000003oool000000:ZZ
ZP02000000030?ooo`2ZZZX0oooo00T0oooo2P3AcJT:0?ooo`060:ZZZP000000ZZZZ0?ooo`000000
EEEE0`2ZZZX205EEE@090:ZZZP000000EEEE05EEE@2ZZZX0EEEE0:ZZZP000000EEEE0080ZZZZ0P00
0000101EEED000000?ooo`3oool400000080ZZZZ00d0EEEE0000002ZZZX0oooo0:ZZZP1EEED0oooo
0000002ZZZX0000005EEE@2ZZZX000000080ZZZZ00D000000?ooo`00000000000:ZZZP0:0?ooo`X0
dLfY2P3oool01`2ZZZX000000?ooo`1EEED0oooo0000002ZZZX00P0000000`2ZZZX0EEEE00000002
000000060?ooo`2ZZZX0ZZZZ0000003oool0EEEE0`000000101EEED0oooo05EEE@00000205EEE@03
0?ooo`1EEED000000080000000<0EEEE0:ZZZP0000000P2ZZZX02`3oool00000000000000000EEEE
0:ZZZP000000EEEE0:ZZZP1EEED0oooo0080EEEE00<000000:ZZZP3oool02@3oool:0=7=Z@X0oooo
00D0ZZZZ0000003oool0EEEE0?ooo`030:ZZZP0305EEE@000000oooo0080EEEE103oool00`2ZZZX0
00000000000205EEE@030000002ZZZX0oooo00@0ZZZZ00P0EEEE0:ZZZP000000oooo05EEE@000000
EEEE0:ZZZP@0oooo0P1EEED20000000505EEE@3oool0ZZZZ0:ZZZP3oool00P1EEED00`000000ZZZZ
0?ooo`090?ooo``0dLfY000;0=7=Z@/0oooo00<0ZZZZ0000003oool00`1EEED01P000000EEEE0?oo
o`2ZZZX0EEEE0?ooo`8000000P2ZZZX0103oool0ZZZZ0?ooo`2ZZZX4000000D0EEEE0P0000002`3o
ool0ZZZZ0?ooo`000000oooo0000002ZZZX0000005EEE@3oool0EEEE0080oooo00P0EEEE0000001E
EED0oooo05EEE@3oool000000:ZZZP/0oooo2P3AcJT;0?ooo`060:ZZZP1EEED0oooo0?ooo`2ZZZX0
oooo0`000000103oool0ZZZZ0?ooo`3oool2000000030:ZZZP3oool0oooo0080oooo00H000000?oo
o`3oool0oooo0000003oool2000000<0oooo00<000000?ooo`3oool00P3oool300000080oooo0P2Z
ZZX3000000060?ooo`2ZZZX0oooo0?ooo`000000ZZZZ2`3oool:0=7=Z@/0oooo00D0ZZZZ0?ooo`3o
ool0oooo05EEE@020:ZZZP0305EEE@2ZZZX0oooo008000000P2ZZZX00`000000EEEE0:ZZZP020:ZZ
ZP070000002ZZZX0ZZZZ0:ZZZP1EEED000000:ZZZP02000000050?ooo`2ZZZX0ZZZZ05EEE@000000
0`2ZZZX00`1EEED000000:ZZZP030000000305EEE@2ZZZX0EEEE0080ZZZZ00<0EEEE0?ooo`3oool0
0P2ZZZX;0?ooo`X0dLfY2`3oool20:ZZZP0305EEE@2ZZZX0ZZZZ008000000P3oool01`000000oooo
0000003oool0EEEE0000002ZZZX00P0000001`3oool0ZZZZ0:ZZZP2ZZZX0oooo05EEE@3oool00P1E
EED00`3oool000000?ooo`030:ZZZP030?ooo`1EEED000000080000000D0EEEE0?ooo`000000oooo
0:ZZZP020?ooo`80000000D0EEEE0:ZZZP1EEED0EEEE0:ZZZP0;0?ooo`X0dLfY2`3oool20:ZZZP80
EEEE00D0000005EEE@1EEED000000?ooo`03000000030?ooo`00000000000080000000<0ZZZZ05EE
E@3oool00P000000101EEED0ZZZZ0000002ZZZX200000080EEEE0P0000001@3oool0EEEE0:ZZZP00
0000oooo00D000000P3oool00`000000EEEE05EEE@0305EEE@030000002ZZZX0oooo00X0oooo303A
cJT000/0dLfY303oool0102ZZZX0oooo00000000000505EEE@8000000P3oool00`000000EEEE0:ZZ
ZP030?ooo`80000000<0ZZZZ05EEE@1EEED00`1EEED010000000ZZZZ0000002ZZZX20?ooo`80ZZZZ
00<0EEEE0000003oool00`0000001@3oool0EEEE05EEE@000000EEEE0080000000<0oooo0:ZZZP3o
ool02`3oool:0=7=Z@`0oooo00<0ZZZZ0000003oool00P3oool2000000030?ooo`2ZZZX0000000<0
000000<0EEEE0?ooo`3oool00`3oool500000080oooo100000050?ooo`030:ZZZP1EEED0000000<0
00000P3oool01`000000oooo0?ooo`2ZZZX0oooo0000002ZZZX0303oool:0=7=Z@`0oooo0P000004
0:ZZZP030000002ZZZX0EEEE00<0000000D0oooo0:ZZZP1EEED0ZZZZ05EEE@020:ZZZP030000003o
ool0000000<0ZZZZ00D0oooo0:ZZZP00000000000?ooo`050:ZZZP0305EEE@2ZZZX0oooo00<00000
00T0EEEE0:ZZZP000000EEEE0:ZZZP000000ZZZZ0000002ZZZX0303oool:0=7=Z@`0oooo0`000005
0?ooo`80ZZZZ00@000000?ooo`000000ZZZZ0P0000020:ZZZP030000001EEED0EEEE0080000000L0
ZZZZ05EEE@2ZZZX0ZZZZ0?ooo`000000EEEE0080000000T0ZZZZ0?ooo`000000EEEE0:ZZZP000000
EEEE0000002ZZZX00`3oool00`1EEED0oooo0:ZZZP02000000030:ZZZP3oool0oooo00X0oooo2P3A
cJT<0?ooo`@0000000D0EEEE0000001EEED0000005EEE@020?ooo`80EEEE0P3oool4000000030?oo
o`000000ZZZZ00<0000000H0EEEE0000002ZZZX0ZZZZ0000003oool2000000040:ZZZP000000oooo
0?ooo`80EEEE0P3oool01@2ZZZX0000005EEE@3oool0EEEE00<0000000<0ZZZZ0?ooo`3oool02P3o
ool<0=7=Z@002`3AcJT=0?ooo`030:ZZZP00000000000080000000D0ZZZZ05EEE@3oool000000:ZZ
ZP0205EEE@030:ZZZP1EEED0EEEE0080000000<0EEEE0:ZZZP2ZZZX00P1EEED01P000000EEEE05EE
E@000000ZZZZ05EEE@80ZZZZ00`0EEEE000000000000EEEE0?ooo`2ZZZX0EEEE0?ooo`2ZZZX00000
0?ooo`1EEED20:ZZZP<0000000<0ZZZZ0?ooo`3oool02`3oool:0=7=Z@d0oooo00<0ZZZZ0000003o
ool01P0000001`2ZZZX000000:ZZZP000000oooo0000003oool01@0000050?ooo`<0000000<0oooo
000000000000100000000`2ZZZX000000:ZZZP04000000050?ooo`00000000000000002ZZZX03@3o
ool:0=7=Z@d0oooo00@0ZZZZ0000002ZZZX0ZZZZ0`0000060:ZZZP0805EEE@2ZZZX0EEEE05EEE@2Z
ZZX0EEEE0000001EEED20:ZZZP030000002ZZZX0ZZZZ0080EEEE00@0000005EEE@2ZZZX0EEEE0P2Z
ZZX00`1EEED0ZZZZ0:ZZZP030:ZZZP@0000000@0ZZZZ000000000000ZZZZ3@3oool:0=7=Z@d0oooo
00@0ZZZZ000000000000ZZZZ0`0000000`3oool000000000000405EEE@040000002ZZZX0EEEE0:ZZ
ZP80000000<0EEEE0000003oool00P2ZZZX00`3oool0000005EEE@02000000050:ZZZP1EEED0oooo
0000003oool00P1EEED3000000080:ZZZP00000000000000002ZZZX0EEEE0000002ZZZX=0?ooo`X0
dLfY3@3oool0102ZZZX000000:ZZZP1EEED2000000070?ooo`00000000000?ooo`2ZZZX0oooo0:ZZ
ZP02000000070?ooo`00000000000:ZZZP1EEED000000:ZZZP02000000060:ZZZP000000EEEE0000
001EEED0oooo0P0000002`1EEED0000005EEE@2ZZZX0oooo0:ZZZP3oool0000005EEE@3oool00000
00<0EEEE00<000000:ZZZP3oool0303oool<0=7=Z@002`3AcJT>0?ooo`090:ZZZP3oool0ZZZZ05EE
E@000000oooo0:ZZZP3oool0ZZZZ0080000000@0oooo05EEE@1EEED000000P1EEED01P2ZZZX0EEEE
05EEE@2ZZZX000000?ooo`8000002@1EEED02@3oool000000?ooo`2ZZZX0oooo0000003oool00000
05EEE@030:ZZZPh0oooo2P3AcJT>0?ooo`030:ZZZP3oool0000000@0ZZZZ00<0EEEE0000002ZZZX0
0P3oool200000080oooo0P0000020?ooo`H000000P3oool200000080oooo0P0000020?ooo`0405EE
E@000000EEEE0?ooo`80ZZZZ00@0oooo0000002ZZZX0ZZZZ3P3oool:0=7=Z@h0oooo00<0ZZZZ0?oo
o`3oool0102ZZZX00`1EEED0ZZZZ05EEE@020:ZZZP0405EEE@2ZZZX0EEEE05EEE@D0ZZZZ00D0EEEE
0:ZZZP2ZZZX0EEEE000000020:ZZZP030000002ZZZX0EEEE0080ZZZZ00<0EEEE0:ZZZP2ZZZX00P2Z
ZZX00`1EEED0ZZZZ0:ZZZP020:ZZZP030?ooo`2ZZZX0ZZZZ00h0oooo2P3AcJT>0?ooo`80ZZZZ00@0
00000?ooo`3oool00000102ZZZX00`1EEED0ZZZZ000000020?ooo`030:ZZZP000000oooo00800000
00@0oooo000000000000EEEE1P0000000`2ZZZX0oooo0?ooo`020:ZZZP0405EEE@2ZZZX0ZZZZ0:ZZ
ZP80000000D0oooo000000000000EEEE0:ZZZP0>0?ooo`X0dLfY3P3oool20:ZZZP040000002ZZZX0
ZZZZ05EEE@80oooo00L000000:ZZZP000000EEEE0:ZZZP3oool0EEEE0080ZZZZ00@0000005EEE@3o
ool000000P1EEED010000000EEEE05EEE@3oool205EEE@80ZZZZ00@000000?ooo`1EEED0EEEE0`00
00000`3oool0000005EEE@020:ZZZP80000000<0ZZZZ0?ooo`3oool0303oool<0=7=Z@002`3AcJT@
0?ooo`040000002ZZZX0000000000080ZZZZ00<0EEEE0?ooo`3oool0101EEED3000000040?ooo`00
0000oooo05EEE@80oooo00D0EEEE000000000000oooo05EEE@02000000@0EEEE00@0oooo05EEE@1E
EED0ZZZZ0`0000000`1EEED000000:ZZZP0?0?ooo`X0dLfY403oool2000000030:ZZZP0000000000
0080ZZZZ0`0000000`3oool0000000000005000000030?ooo`000000oooo00D0000000<0oooo0000
000000001@0000030:ZZZP80000000@0ZZZZ000000000000ZZZZ3`3oool:0=7=Z@l0oooo0P000000
1@3oool000000:ZZZP2ZZZX000000080ZZZZ00D0EEEE0000002ZZZX000000:ZZZP0205EEE@060?oo
o`2ZZZX0oooo0000002ZZZX0EEEE0P2ZZZX20?ooo`030:ZZZP3oool0EEEE0080EEEE00<000000:ZZ
ZP0000000P1EEED0202ZZZX0000005EEE@2ZZZX000000:ZZZP000000ZZZZ3`3oool:0=7=Z@l0oooo
0P0000030?ooo`030000001EEED0000000@0000000@0EEEE0000001EEED00000101EEED0102ZZZX0
00000?ooo`2ZZZX305EEE@060:ZZZP000000EEEE0?ooo`1EEED0ZZZZ0P000000101EEED0000005EE
E@0000030?ooo`030000002ZZZX0oooo00h0oooo2P3AcJT?0?ooo`80000000<0EEEE0000001EEED0
0`3oool01P2ZZZX000000?ooo`000000EEEE0:ZZZP8000000P2ZZZX00`000000oooo05EEE@020000
0080EEEE00<000000:ZZZP2ZZZX00P000000102ZZZX0EEEE05EEE@3oool2000000<0oooo00D0EEEE
0000001EEED000000:ZZZP0?0?ooo``0dLfY000;0=7=ZA00oooo00<0ZZZZ0?ooo`0000000P000002
0?ooo`0505EEE@3oool0oooo0000002ZZZX00P3oool205EEE@<0000000@0EEEE000000000000EEEE
100000001@1EEED0oooo0000002ZZZX0000000D0oooo0`0000020:ZZZQ00oooo2P3AcJT@0?ooo`06
0:ZZZP00000000000000003oool0ZZZZ0`0000030?ooo`H0000000<0EEEE0000000000001@000000
0`3oool00000000000040?ooo`<0000000@0ZZZZ00000000000000000P2ZZZX@0?ooo`X0dLfY403o
ool01P2ZZZX000000:ZZZP000000ZZZZ05EEE@<0ZZZZ00@0000005EEE@000000ZZZZ0P0000001@3o
ool000000?ooo`1EEED0oooo0080000000D0oooo0:ZZZP3oool0000005EEE@020000000=0:ZZZP00
0000EEEE0000002ZZZX000000:ZZZP1EEED0ZZZZ0000002ZZZX000000:ZZZP0@0?ooo`X0dLfY403o
ool0102ZZZX0EEEE0?ooo`1EEED2000000070?ooo`1EEED000000000003oool0000005EEE@020000
00060?ooo`00000000000000003oool0ZZZZ0`3oool70000000;05EEE@00000000000000003oool0
00000?ooo`1EEED0oooo0000002ZZZX0403oool:0=7=ZA00oooo00@0ZZZZ05EEE@3oool0EEEE0P3o
ool305EEE@80000000<0oooo05EEE@2ZZZX00P1EEED01@2ZZZX00000000000000000ZZZZ00@00000
00H0ZZZZ0000001EEED0ZZZZ05EEE@3oool2000000<0EEEE0P3oool0101EEED0oooo0000002ZZZX@
0?ooo``0dLfY000;0=7=ZA80oooo00L000000?ooo`000000oooo0:ZZZP3oool0000000<0ZZZZ0`00
000205EEE@040000001EEED000000:ZZZP80000000@0EEEE0000001EEED0EEEE0`0000000`2ZZZX0
oooo0:ZZZP02000000060:ZZZP3oool0oooo0?ooo`000000ZZZZ4@3oool:0=7=ZA80oooo0`2ZZZX2
000000030?ooo`000000000000<0000000@0oooo000000000000oooo0P0000001`1EEED0oooo0:ZZ
ZP1EEED0oooo0000003oool00P0000000`3oool0000000000003000000040?ooo`00000000000?oo
o`<0ZZZZ4@3oool:0=7=ZA40oooo00D0ZZZZ0?ooo`3oool0EEEE0?ooo`02000000050?ooo`2ZZZX0
EEEE0:ZZZP3oool00P2ZZZX300000080EEEE0P000000101EEED0ZZZZ0000000000030:ZZZP050?oo
o`2ZZZX0EEEE0:ZZZP3oool00P0000001@3oool0EEEE0?ooo`3oool0ZZZZ0140oooo2P3AcJTA0?oo
o`0905EEE@2ZZZX0EEEE05EEE@000000ZZZZ0?ooo`000000oooo0080ZZZZ00<0oooo000000000000
0P3oool01@1EEED000000?ooo`000000EEEE0080oooo00<0EEEE0?ooo`3oool00P0000020:ZZZP03
0000003oool000000080ZZZZ00<000000:ZZZP1EEED00P2ZZZXA0?ooo`X0dLfY4@3oool00`000000
ZZZZ05EEE@0505EEE@030:ZZZP3oool00000008000000P2ZZZX50000000305EEE@000000EEEE0080
00000P2ZZZX300000080ZZZZ00<0EEEE0:ZZZP1EEED00`1EEED20:ZZZQ40oooo303AcJT000/0dLfY
4P3oool30:ZZZP<0EEEE00@0oooo0000001EEED0EEEE0`000000202ZZZX000000?ooo`3oool00000
05EEE@3oool000000P3oool4000000040?ooo`1EEED0oooo00000080oooo0P1EEED00`3oool0ZZZZ
0:ZZZP0B0?ooo`X0dLfY4P3oool20:ZZZP@0oooo0P0000020?ooo`H0000000<0ZZZZ0?ooo`000000
0`3oool2000000030:ZZZP00000000000080oooo100000030?ooo`80ZZZZ4P3oool:0=7=ZA80oooo
0P2ZZZX00`3oool0ZZZZ0:ZZZP030:ZZZP0405EEE@2ZZZX0oooo0:ZZZPD00000102ZZZX5000000<0
ZZZZ00<0EEEE0:ZZZP2ZZZX00`2ZZZX00`3oool0ZZZZ0:ZZZP0B0?ooo`X0dLfY4P3oool0102ZZZX0
EEEE0:ZZZP0000030:ZZZP080000003oool0ZZZZ0?ooo`000000EEEE0000002ZZZX30000000305EE
E@00000000000080000000@0ZZZZ05EEE@1EEED000000P2ZZZX01@3oool000000:ZZZP000000ZZZZ
0080000000<0EEEE0:ZZZP3oool04@3oool:0=7=ZA80oooo00<0ZZZZ0000003oool00P1EEED0103o
ool0ZZZZ0?ooo`1EEED40000000805EEE@3oool000000000001EEED0oooo0000001EEED20000000:
0?ooo`00000000000000003oool0000005EEE@3oool0ZZZZ0?ooo`80EEEE00<0oooo0000002ZZZX0
4P3oool<0=7=Z@002`3AcJTC0?ooo`080:ZZZP000000EEEE0:ZZZP3oool000000:ZZZP3oool20000
00070:ZZZP000000ZZZZ0:ZZZP3oool0ZZZZ0?ooo`0205EEE@040?ooo`000000oooo0:ZZZP800000
00D0ZZZZ00000000000000000:ZZZP02000000040:ZZZP1EEED0oooo0:ZZZQ<0oooo2P3AcJTC0?oo
o`040:ZZZP000000ZZZZ0?ooo`80000000P0oooo00000000000000000?ooo`000000ZZZZ05EEE@80
000000@0ZZZZ0000003oool0ZZZZ0P000000101EEED000000000003oool3000000070?ooo`000000
00000?ooo`2ZZZX0oooo0:ZZZP0C0?ooo`X0dLfY4`3oool01P2ZZZX000000:ZZZP3oool0ZZZZ05EE
E@<0ZZZZ00<0000005EEE@2ZZZX00`2ZZZX00`1EEED0ZZZZ05EEE@020:ZZZP050?ooo`2ZZZX0ZZZZ
0?ooo`2ZZZX00P1EEED02@2ZZZX000000:ZZZP1EEED000000?ooo`2ZZZX000000:ZZZP0C0?ooo`X0
dLfY4`3oool01@2ZZZX0EEEE0000002ZZZX0EEEE0080000000<0EEEE0000002ZZZX00`2ZZZX20?oo
o`060000003oool000000000003oool000000P3oool00`1EEED0ZZZZ0:ZZZP02000000050?ooo`00
000000000000002ZZZX00P0000000`2ZZZX0oooo0?ooo`0A0?ooo`X0dLfY4`3oool00`2ZZZX0EEEE
0:ZZZP0305EEE@0;0000002ZZZX000000000002ZZZX0oooo0:ZZZP1EEED0000005EEE@0000000P3o
ool300000080EEEE00H0oooo0:ZZZP3oool000000:ZZZP00000305EEE@030:ZZZP000000ZZZZ01<0
oooo303AcJT000/0dLfY503oool200000080oooo00P0EEEE0?ooo`3oool0ZZZZ0?ooo`2ZZZX0oooo
0:ZZZP80EEEE00H0oooo0:ZZZP1EEED000000:ZZZP3oool305EEE@060?ooo`2ZZZX0EEEE0:ZZZP00
0000oooo0P1EEED00`3oool000000:ZZZP0D0?ooo`X0dLfY503oool010000000EEEE05EEE@3oool2
000000030?ooo`000000oooo0080oooo00L000000:ZZZP2ZZZX0oooo0:ZZZP000000oooo00@0ZZZZ
00<000000?ooo`3oool01@000000103oool0EEEE05EEE@2ZZZXD0?ooo`X0dLfY503oool00`2ZZZX0
oooo0?ooo`0205EEE@80ZZZZ0P1EEED0103oool000000:ZZZP1EEED200000080ZZZZ00D0EEEE0:ZZ
ZP2ZZZX0000005EEE@02000000030?ooo`2ZZZX0EEEE0080ZZZZ00D0EEEE0?ooo`3oool0oooo0:ZZ
ZP0D0?ooo`X0dLfY503oool0101EEED0ZZZZ0000003oool20:ZZZP040000003oool0000005EEE@80
000000D0EEEE0?ooo`3oool0oooo000000020?ooo`030000003oool0EEEE0080000000<0EEEE0000
003oool00`2ZZZX200000080ZZZZ503oool:0=7=ZA@0oooo00P000000:ZZZP000000ZZZZ0000002Z
ZZX0oooo0:ZZZP80000000L0ZZZZ05EEE@000000oooo05EEE@000000oooo008000000P3oool02`00
0000EEEE0:ZZZP000000EEEE0:ZZZP3oool0ZZZZ0000002ZZZX000000080ZZZZ503oool<0=7=Z@00
2`3AcJTE0?ooo`060:ZZZP3oool0oooo0?ooo`000000ZZZZ0P0000001@2ZZZX0oooo0000002ZZZX0
EEEE008000000P1EEED20000000=05EEE@2ZZZX0EEEE0?ooo`2ZZZX0EEEE0000002ZZZX000000?oo
o`000000oooo0:ZZZP0E0?ooo`X0dLfY5@3oool00`2ZZZX0oooo0?ooo`02000000030?ooo`000000
000000<000000P3oool20:ZZZP80oooo0P2ZZZX20?ooo`P0000000<0ZZZZ0?ooo`2ZZZX05@3oool:
0=7=ZAD0oooo0P2ZZZX00`3oool0EEEE05EEE@02000000030?ooo`1EEED000000080000000@0ZZZZ
05EEE@2ZZZX00000102ZZZX30000000405EEE@00000000000?ooo`80EEEE00<0oooo0:ZZZP2ZZZX0
5@3oool:0=7=ZAD0oooo00H0ZZZZ05EEE@3oool0EEEE0000003oool2000000060:ZZZP1EEED0EEEE
0:ZZZP000000ZZZZ0P0000001@1EEED00000000000000000ZZZZ0080EEEE00T0ZZZZ000000000000
EEEE0000001EEED0000005EEE@2ZZZX05@3oool:0=7=ZAD0oooo00<0ZZZZ0000001EEED00P000000
101EEED0ZZZZ0000001EEED20?ooo`030000001EEED0oooo00@000000P1EEED2000000050?ooo`1E
EED0ZZZZ0:ZZZP1EEED00P0000000`3oool000000:ZZZP0E0?ooo``0dLfY000;0=7=ZAH0oooo00H0
ZZZZ00000000000000000:ZZZP0000020?ooo`0?0:ZZZP1EEED0EEEE0:ZZZP000000ZZZZ05EEE@00
0000ZZZZ0000002ZZZX0EEEE0000002ZZZX0oooo0080000000D0ZZZZ00000000000000000:ZZZP0F
0?ooo`X0dLfY5P3oool0102ZZZX000000000001EEED4000000050?ooo`00000000000000002ZZZX0
1`0000020?ooo`050000001EEED000000000001EEED00P0000000`2ZZZX0oooo0?ooo`0D0?ooo`X0
dLfY5P3oool0102ZZZX000000:ZZZP2ZZZX3000000H0ZZZZ00<0EEEE0:ZZZP2ZZZX00P1EEED50:ZZ
ZP<000000P2ZZZX00`000000ZZZZ0?ooo`0E0?ooo`X0dLfY5P3oool00`2ZZZX0EEEE0?ooo`0205EE
E@030000001EEED0000000<0000000<0EEEE0?ooo`3oool00P1EEED00`3oool0ZZZZ05EEE@040000
00070:ZZZP000000oooo05EEE@3oool000000:ZZZP0F0?ooo`X0dLfY5P3oool00`2ZZZX0EEEE0?oo
o`0405EEE@0<0000003oool0oooo0000003oool000000:ZZZP1EEED0oooo0:ZZZP1EEED0oooo0P00
00002@3oool000000000001EEED0ZZZZ05EEE@3oool000000:ZZZP0F0?ooo``0dLfY000;0=7=ZAL0
oooo00D0ZZZZ0?ooo`000000ZZZZ000000020?ooo`030000001EEED0EEEE00<000000P1EEED30000
000805EEE@2ZZZX000000?ooo`2ZZZX0000005EEE@00000I0?ooo`X0dLfY5`3oool0202ZZZX0oooo
000000000000ZZZZ0?ooo`000000oooo0`0000000`2ZZZX000000:ZZZP02000000030?ooo`000000
00000080oooo00D000000:ZZZP2ZZZX0EEEE0000000I0?ooo`X0dLfY5`3oool02P2ZZZX000000000
003oool0000005EEE@2ZZZX0000005EEE@3oool2000000040?ooo`000000EEEE0?ooo`80000000<0
oooo0:ZZZP0000000P2ZZZX010000000ZZZZ00000000000H0?ooo`X0dLfY5`3oool01P2ZZZX00000
0000002ZZZX0oooo05EEE@<0oooo00@0EEEE000000000000EEEE0P000000101EEED0ZZZZ0000001E
EED50?ooo`<00000603oool:0=7=ZAL0oooo00@0ZZZZ00000000000000000P1EEED200000080oooo
00H0000005EEE@3oool0000005EEE@3oool200000080oooo0P0000000`2ZZZX0EEEE000000020000
01P0oooo303AcJT000/0dLfY603oool01`2ZZZX000000?ooo`1EEED000000:ZZZP3oool00P000000
0`1EEED0000005EEE@0505EEE@060000001EEED0oooo0:ZZZP3oool0EEEE0P0000000`2ZZZX0oooo
0?ooo`0F0?ooo`X0dLfY603oool00`2ZZZX000000?ooo`020?ooo`<0000000L0oooo000000000000
ZZZZ0000001EEED0ZZZZ0080000000T0oooo00000000000000000:ZZZP3oool0EEEE0000002ZZZX0
603oool:0=7=ZAP0oooo0P2ZZZX20?ooo`0305EEE@2ZZZX0ZZZZ0080EEEE0`0000020:ZZZP<00000
00D0EEEE0:ZZZP2ZZZX0ZZZZ05EEE@020?ooo`80ZZZZ603oool:0=7=ZAP0oooo00D0ZZZZ05EEE@2Z
ZZX000000:ZZZP0405EEE@80oooo101EEED0102ZZZX0oooo05EEE@2ZZZX205EEE@050:ZZZP000000
000005EEE@2ZZZX0603oool:0=7=ZAP0oooo00<0ZZZZ0000003oool00P1EEED00`3oool0EEEE05EE
E@0305EEE@050000002ZZZX0ZZZZ0000003oool0101EEED01P3oool0000005EEE@3oool000000:ZZ
ZQP0oooo303AcJT000/0dLfY6@3oool0102ZZZX0oooo0000000000020:ZZZP060000001EEED0EEEE
05EEE@000000oooo0P00000405EEE@80ZZZZ0P0000020:ZZZQT0oooo2P3AcJTI0?ooo`060:ZZZP00
0000oooo0?ooo`000000oooo1@0000020:ZZZP040000003oool0000000000080oooo00<000000:ZZ
ZP3oool00P2ZZZXI0?ooo`X0dLfY6@3oool00`2ZZZX000000:ZZZP020:ZZZP0305EEE@000000ZZZZ
00<0ZZZZ00<0EEEE0:ZZZP2ZZZX0102ZZZX01P1EEED0ZZZZ0000002ZZZX000000:ZZZQT0oooo2P3A
cJTI0?ooo`030:ZZZP1EEED0000000<0000000H0ZZZZ0?ooo`000000EEEE0:ZZZP1EEED20:ZZZP03
05EEE@000000oooo00<0000000@0ZZZZ000000000000ZZZZ6@3oool:0=7=ZAT0oooo00@0ZZZZ05EE
E@2ZZZX0oooo1@0000000`3oool0EEEE0000000205EEE@H0000000@0EEEE0:ZZZP000000ZZZZ6@3o
ool<0=7=Z@002`3AcJTJ0?ooo`050:ZZZP00000000000000001EEED00`3oool20:ZZZP0405EEE@2Z
ZZX0ZZZZ05EEE@80oooo0P1EEED3000001/0oooo2P3AcJTJ0?ooo`030:ZZZP000000oooo00800000
00<0ZZZZ05EEE@1EEED00`0000000`1EEED000000000000205EEE@D000006`3oool:0=7=ZAX0oooo
00@0ZZZZ0000002ZZZX0ZZZZ100000001P1EEED0oooo000000000000oooo0:ZZZP@0000000<0ZZZZ
0000000000006`3oool:0=7=ZAX0oooo00<0ZZZZ0000003oool00P3oool20000000405EEE@2ZZZX0
oooo00000080oooo0P1EEED010000000oooo0?ooo`3oool2000001/0oooo2P3AcJTJ0?ooo`050:ZZ
ZP000000EEEE05EEE@2ZZZX00P0000001@2ZZZX000000000002ZZZX0EEEE0080000000D0ZZZZ0000
00000000ZZZZ05EEE@02000001/0oooo303AcJT000/0dLfY6`3oool0102ZZZX0oooo0:ZZZP1EEED3
000000050?ooo`1EEED0oooo0000001EEED010000000101EEED0ZZZZ0:ZZZP2ZZZXK0?ooo`X0dLfY
6`3oool01@2ZZZX0oooo0000003oool000000080ZZZZ00@0EEEE0000002ZZZX0ZZZZ0P0000020:ZZ
ZP030000003oool000000080ZZZZ6`3oool:0=7=ZA/0oooo00<0ZZZZ0?ooo`3oool0102ZZZX205EE
E@80000000<0EEEE0:ZZZP2ZZZX00`2ZZZX00`3oool0ZZZZ0:ZZZP0K0?ooo`X0dLfY6`3oool01@2Z
ZZX000000?ooo`1EEED0oooo00<0000000@0EEEE0000003oool0EEEE10000000101EEED0oooo05EE
E@2ZZZXK0?ooo`X0dLfY6`3oool00`2ZZZX0oooo05EEE@030000000605EEE@3oool0oooo0000001E
EED0oooo0P1EEED01P000000EEEE0000001EEED000000:ZZZQ/0oooo303AcJT000/0dLfY703oool0
0`2ZZZX000000000000405EEE@030?ooo`00000000000080oooo0P1EEED00`3oool000000000000M
0?ooo`X0dLfY703oool04@2ZZZX0000005EEE@3oool000000:ZZZP3oool0EEEE0:ZZZP3oool0EEEE
0000002ZZZX000000:ZZZP1EEED0000001d0oooo2P3AcJTL0?ooo`80ZZZZ0P3oool205EEE@80ZZZZ
00@0000005EEE@2ZZZX0ZZZZ0P1EEED20?ooo`030:ZZZP3oool0oooo01/0oooo2P3AcJTL0?ooo`07
0:ZZZP1EEED0ZZZZ0:ZZZP1EEED000000:ZZZP020000000405EEE@000000ZZZZ00000080EEEE00<0
ZZZZ05EEE@3oool0703oool:0=7=ZA`0oooo00P0ZZZZ0000002ZZZX0EEEE0?ooo`1EEED0ZZZZ0?oo
o`80000000L0oooo0000001EEED0oooo05EEE@2ZZZX0000001d0oooo303AcJT000/0dLfY7@3oool2
0:ZZZP80000000X0oooo0:ZZZP1EEED0oooo0:ZZZP1EEED000000?ooo`000000oooo0P2ZZZXM0?oo
o`X0dLfY7@3oool20:ZZZP8000000P1EEED0103oool0ZZZZ0000003oool205EEE@8000000P2ZZZXM
0?ooo`X0dLfY7@3oool01`2ZZZX000000:ZZZP000000ZZZZ05EEE@0000000P2ZZZX00`000000ZZZZ
0:ZZZP03000000030:ZZZP3oool0oooo01/0oooo2P3AcJTM0?ooo`040:ZZZP00000000000:ZZZP<0
oooo0P1EEED0103oool0ZZZZ0?ooo`2ZZZX2000000030:ZZZP3oool0oooo01/0oooo2P3AcJTM0?oo
o`0<0:ZZZP00000000000000003oool0EEEE0000003oool0ZZZZ0000001EEED0oooo0`0000000`2Z
ZZX0oooo0?ooo`0K0?ooo``0dLfY000;0=7=ZAh0oooo00D0ZZZZ0000003oool0oooo0000000205EE
E@030:ZZZP1EEED0oooo00<0oooo00<0ZZZZ0?ooo`3oool0703oool:0=7=ZAh0oooo1P2ZZZX01000
0000EEEE0:ZZZP0000020:ZZZP030?ooo`2ZZZX0oooo01d0oooo2P3AcJTN0?ooo`090:ZZZP3oool0
oooo05EEE@3oool000000:ZZZP3oool000000080EEEE00<0oooo0:ZZZP2ZZZX07P3oool:0=7=ZAh0
oooo00<0ZZZZ0000002ZZZX00P0000000`2ZZZX0EEEE0:ZZZP020:ZZZP040000002ZZZX0EEEE0:ZZ
ZQh0oooo2P3AcJTN0?ooo`030:ZZZP3oool0oooo00<000000P1EEED3000000030?ooo`000000ZZZZ
01h0oooo303AcJT000/0dLfY7`3oool20:ZZZP050?ooo`2ZZZX0ZZZZ05EEE@0000000P2ZZZX00`3o
ool0ZZZZ0?ooo`0O0?ooo`X0dLfY7`3oool20:ZZZP030?ooo`000000EEEE0080oooo00@0EEEE0?oo
o`3oool0ZZZZ803oool:0=7=ZAl0oooo0P2ZZZX0103oool0ZZZZ0:ZZZP0000020:ZZZP80oooo00<0
ZZZZ0?ooo`3oool07P3oool:0=7=ZAl0oooo00D0ZZZZ05EEE@2ZZZX000000?ooo`020:ZZZP040?oo
o`000000ZZZZ05EEEB00oooo2P3AcJTO0?ooo`0;0:ZZZP000000ZZZZ0000003oool0000005EEE@3o
ool000000:ZZZP000000803oool<0=7=Z@002`3AcJTP0?ooo`030:ZZZP3oool0EEEE0080oooo00D0
00000?ooo`000000oooo0:ZZZP0P0?ooo`X0dLfY803oool01@2ZZZX0oooo0:ZZZP1EEED0oooo0080
EEEE00<000000?ooo`2ZZZX0803oool:0=7=ZB00oooo00@0ZZZZ0000002ZZZX0oooo0P000000103o
ool000000000002ZZZXP0?ooo`X0dLfY803oool01@2ZZZX000000?ooo`3oool0ZZZZ0080oooo0P00
00000`2ZZZX0oooo0?ooo`0N0?ooo`X0dLfY803oool0102ZZZX0000005EEE@0000020:ZZZP<00000
00<0ZZZZ0?ooo`3oool07P3oool<0=7=Z@002`3AcJTQ0?ooo`080:ZZZP000000oooo05EEE@2ZZZX0
oooo0000002ZZZXQ0?ooo`X0dLfY8@3oool0202ZZZX0EEEE05EEE@1EEED0ZZZZ05EEE@000000ZZZZ
8@3oool:0=7=ZB40oooo00@0ZZZZ0?ooo`3oool0EEEE0P3oool20:ZZZR40oooo2P3AcJTQ0?ooo`08
0:ZZZP000000oooo0000001EEED0oooo05EEE@2ZZZXQ0?ooo`X0dLfY8@3oool0102ZZZX0oooo05EE
E@00000205EEE@030000002ZZZX0oooo0200oooo303AcJT000/0dLfY8P3oool0102ZZZX0oooo0?oo
o`00000T0?ooo`X0dLfY8P3oool0102ZZZX0oooo0?ooo`2ZZZXT0?ooo`X0dLfY8P3oool20:ZZZP03
0000003oool0ZZZZ02<0oooo2P3AcJTR0?ooo`050:ZZZP1EEED0EEEE0:ZZZP1EEED08`3oool:0=7=
ZB80oooo00D0ZZZZ0000001EEED0ZZZZ0000000S0?ooo``0dLfY000;0=7=ZB<0oooo00@0ZZZZ0000
00000000ZZZZ8`3oool:0=7=ZB<0oooo00@0ZZZZ000000000000ZZZZ8`3oool:0=7=ZB<0oooo00@0
ZZZZ000000000000ZZZZ8`3oool:0=7=ZB<0oooo00@0ZZZZ000000000000ZZZZ8`3oool:0=7=ZB<0
oooo00@0ZZZZ000000000000ZZZZ8`3oool<0=7=Z@002`3AcJTT0?ooo`030:ZZZP3oool0oooo02<0
oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0
oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0
oooo303AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0
dLfY/P3AcJT000/0dLfY00L0oooo0:ZZZP2ZZZX0ZZZZ0?ooo`000000EEEE00D0ZZZZ0P3oool20000
0080oooo00D000000:ZZZP3oool0oooo05EEE@02000000060?ooo`1EEED0ZZZZ0000003oool0EEEE
0`2ZZZX00`1EEED0000000000002000000<0ZZZZ00L0000005EEE@3oool0EEEE0:ZZZP1EEED0oooo
0080000000D0EEEE0?ooo`3oool0ZZZZ000000030?ooo`030000003oool0EEEE00D0ZZZZ00<0oooo
0000001EEED00`2ZZZX00`3oool0dLfY0=7=Z@080=7=Z@040?ooo`2ZZZX0000005EEE@80oooo00<0
EEEE0:ZZZP2ZZZX00P1EEED2000000030:ZZZP1EEED0EEEE0080EEEE00@0oooo05EEE@1EEED0EEEE
0P00000305EEE@060000001EEED000000000002ZZZX000000`1EEED20000000305EEE@2ZZZX0EEEE
00H000000`1EEED20000000<05EEE@2ZZZX0EEEE0?ooo`2ZZZX0EEEE0:ZZZP1EEED0ZZZZ05EEE@00
0000EEEE0`2ZZZX20?ooo`050000001EEED000000:ZZZP3oool02P3AcJT0203oool0EEEE0?ooo`2Z
ZZX0EEEE0?ooo`000000oooo101EEED01@3oool0ZZZZ0?ooo`3oool0ZZZZ00D0oooo0`1EEED01@00
0000oooo0:ZZZP3oool0EEEE0080oooo00@0ZZZZ05EEE@3oool0ZZZZ0P000000102ZZZX0EEEE05EE
E@2ZZZX20?ooo`0805EEE@2ZZZX0ZZZZ05EEE@000000EEEE0000001EEED50?ooo`040:ZZZP1EEED0
oooo0:ZZZPD0EEEE00P0oooo0000003oool0oooo0:ZZZP3oool0ZZZZ0?ooo`X0dLfY00@0oooo05EE
E@1EEED000000P3oool00`2ZZZX000000000000205EEE@030000001EEED000000080EEEE00T00000
0:ZZZP00000000000:ZZZP1EEED0ZZZZ0?ooo`0000000P1EEED02@000000ZZZZ0:ZZZP000000EEEE
0000001EEED0oooo0000000205EEE@070000002ZZZX0EEEE0000003oool000000:ZZZP0200000007
0?ooo`1EEED000000000002ZZZX0EEEE0:ZZZP02000000070:ZZZP000000EEEE05EEE@000000EEEE
0000000205EEE@80000000L0EEEE0?ooo`1EEED0000005EEE@2ZZZX0oooo00X0dLfY00D0oooo0000
00000000EEEE0?ooo`020:ZZZP0805EEE@000000EEEE05EEE@2ZZZX0EEEE0:ZZZP1EEED300000003
0?ooo`1EEED0EEEE00<0ZZZZ00H0oooo0:ZZZP000000ZZZZ05EEE@2ZZZX205EEE@030000002ZZZX0
EEEE00H0ZZZZ00X0000005EEE@1EEED0ZZZZ05EEE@2ZZZX0EEEE0:ZZZP3oool0EEEE0P2ZZZX01000
0000EEEE0?ooo`2ZZZX20000000505EEE@2ZZZX0EEEE0:ZZZP1EEED00P0000000`1EEED0ZZZZ0:ZZ
ZP0205EEE@030000002ZZZX0oooo00`0dLfY000;0=7=Z@040?ooo`2ZZZX000000?ooo`80EEEE00H0
oooo0000002ZZZX0oooo0:ZZZP3oool3000000@0oooo00@0EEEE0:ZZZP1EEED0EEEE0P0000030:ZZ
ZP070000001EEED0oooo0:ZZZP1EEED0ZZZZ05EEE@020000000705EEE@000000ZZZZ0:ZZZP1EEED0
ZZZZ0?ooo`0205EEE@<0ZZZZ00<0000005EEE@1EEED00`1EEED30?ooo`0805EEE@00000000000000
003oool0ZZZZ0?ooo`2ZZZX20000000405EEE@2ZZZX0oooo00000080oooo2P3AcJT0103oool0ZZZZ
00000000000305EEE@<0ZZZZ0P1EEED010000000ZZZZ0?ooo`1EEED20:ZZZP0605EEE@0000000000
05EEE@000000EEEE1@000000102ZZZX000000:ZZZP3oool20:ZZZP0305EEE@000000EEEE0080EEEE
00@0ZZZZ0?ooo`00000000000P2ZZZX01`000000EEEE000000000000EEEE0000001EEED00P000002
05EEE@050:ZZZP1EEED0oooo0:ZZZP0000000`1EEED20:ZZZP<0EEEE0P0000020?ooo`X0dLfY00@0
oooo0:ZZZP1EEED0EEEE0P3oool01P1EEED0oooo0000003oool000000?ooo`8000000P2ZZZX00`00
0000oooo00000003000000070?ooo`1EEED0EEEE0?ooo`000000EEEE000000040?ooo`80ZZZZ1000
00000`1EEED0ZZZZ0?ooo`030?ooo`80EEEE0P3oool01@1EEED0oooo0?ooo`000000oooo00@00000
0P2ZZZX01P000000oooo0?ooo`000000oooo000000<0oooo00<0000005EEE@1EEED00P3oool:0=7=
Z@040?ooo`2ZZZX0EEEE0?ooo`80000000<0ZZZZ0?ooo`2ZZZX00`2ZZZX00`3oool0ZZZZ0:ZZZP02
0:ZZZP050000002ZZZX0ZZZZ0?ooo`2ZZZX00P000000103oool0EEEE05EEE@3oool205EEE@800000
00<0oooo05EEE@000000102ZZZX205EEE@80oooo00@0000005EEE@000000oooo0P1EEED01@3oool0
00000000002ZZZX0oooo0080ZZZZ00<000000:ZZZP2ZZZX00P2ZZZX00`000000ZZZZ0:ZZZP020:ZZ
ZP80oooo00@000000?ooo`3oool0EEEE0P3oool:0=7=Z@040?ooo`2ZZZX000000?ooo`80000000d0
EEEE0?ooo`2ZZZX0EEEE0?ooo`2ZZZX0EEEE0:ZZZP1EEED0oooo05EEE@000000ZZZZ0080EEEE00D0
ZZZZ05EEE@00000000000?ooo`020:ZZZP030000002ZZZX0ZZZZ0080ZZZZ00@0oooo0:ZZZP1EEED0
ZZZZ0P1EEED20?ooo`@0ZZZZ00D000000:ZZZP1EEED0oooo0000000205EEE@0<0:ZZZP3oool0EEEE
0:ZZZP3oool0EEEE0?ooo`1EEED0ZZZZ0?ooo`2ZZZX0oooo0P2ZZZX00`3oool00000000000020?oo
o`030000003oool0oooo00`0dLfY000;0=7=Z@<0oooo00D0ZZZZ000000000000EEEE0?ooo`0205EE
E@0=0:ZZZP1EEED0EEEE0:ZZZP000000oooo0:ZZZP3oool0EEEE0:ZZZP1EEED0ZZZZ05EEE@020000
0080oooo00<0000005EEE@1EEED00P3oool010000000ZZZZ0:ZZZP2ZZZX205EEE@090:ZZZP1EEED0
ZZZZ0000001EEED0oooo05EEE@3oool000000080oooo00H000000:ZZZP1EEED0ZZZZ0000002ZZZX2
05EEE@0;0:ZZZP00000000000:ZZZP000000EEEE0:ZZZP000000EEEE0?ooo`1EEED00P000000102Z
ZZX0oooo0?ooo`3oool:0=7=Z@<0oooo00D0ZZZZ05EEE@3oool000000?ooo`020:ZZZP0405EEE@3o
ool0EEEE05EEE@80000000<0ZZZZ05EEE@3oool00P1EEED00`3oool0EEEE0?ooo`020000000505EE
E@3oool0EEEE0000002ZZZX00`3oool01@2ZZZX0EEEE0000002ZZZX0EEEE00@0oooo00<0ZZZZ0000
002ZZZX00P3oool2000000030?ooo`1EEED0oooo0080EEEE00H0oooo05EEE@2ZZZX0ZZZZ0000001E
EED20?ooo`0805EEE@000000ZZZZ0?ooo`1EEED0oooo0000002ZZZX30?ooo`X0dLfY0`3oool0102Z
ZZX0EEEE05EEE@1EEED300000080oooo00P0EEEE0?ooo`2ZZZX0EEEE0?ooo`1EEED0ZZZZ05EEE@80
oooo00P0EEEE000000000000oooo05EEE@3oool0EEEE0:ZZZP<0EEEE00<0ZZZZ0000001EEED00P00
00000`1EEED000000:ZZZP0305EEE@060:ZZZP1EEED0oooo0000003oool000000P1EEED0103oool0
EEEE05EEE@2ZZZX20?ooo`80ZZZZ103oool3000000040:ZZZP1EEED0EEEE0:ZZZP<0oooo2P3AcJT3
0?ooo`050:ZZZP1EEED000000?ooo`2ZZZX00P1EEED00`3oool0ZZZZ0:ZZZP030000000=0:ZZZP00
0000oooo05EEE@3oool000000:ZZZP3oool0EEEE0000002ZZZX0oooo0:ZZZP0200000080ZZZZ00H0
00000?ooo`1EEED0oooo0:ZZZP1EEED200000080ZZZZ0`000000103oool0EEEE0000001EEED20:ZZ
ZP040000002ZZZX0EEEE0?ooo`80ZZZZ0`0000020:ZZZP080?ooo`2ZZZX0EEEE0:ZZZP1EEED00000
05EEE@2ZZZX30?ooo`X0dLfY0`3oool00`2ZZZX0000005EEE@040:ZZZP030?ooo`1EEED0EEEE00@0
ZZZZ0`1EEED00`3oool0EEEE00000002000000060:ZZZP3oool0ZZZZ0000002ZZZX000000P2ZZZX0
101EEED000000:ZZZP3oool20:ZZZP070?ooo`1EEED0ZZZZ0?ooo`000000ZZZZ05EEE@030:ZZZP<0
0000101EEED60:ZZZP0305EEE@3oool0EEEE0080ZZZZ00@0000005EEE@000000ZZZZ0`3oool<0=7=
Z@002`3AcJT40?ooo`060:ZZZP3oool0EEEE0?ooo`000000EEEE0P2ZZZX01`3oool0EEEE05EEE@1E
EED0oooo0:ZZZP1EEED00P3oool00`2ZZZX0oooo05EEE@04000000<0ZZZZ00@0EEEE0?ooo`3oool0
EEEE1@2ZZZX20?ooo`040000002ZZZX0ZZZZ0:ZZZP@0000000D0EEEE0?ooo`2ZZZX0EEEE0?ooo`02
05EEE@040?ooo`000000EEEE05EEE@<0ZZZZ0P000000103oool0ZZZZ0?ooo`2ZZZX40?ooo`X0dLfY
103oool02@2ZZZX000000000001EEED0ZZZZ0?ooo`000000EEEE000000020:ZZZP0:0?ooo`1EEED0
ZZZZ05EEE@000000EEEE0:ZZZP000000EEEE00000080EEEE00<0ZZZZ0?ooo`3oool01@1EEED20?oo
o`030:ZZZP3oool0EEEE00@0EEEE00<0oooo0000002ZZZX00P1EEED01P000000ZZZZ0000002ZZZX0
oooo000000<0EEEE00H0oooo0:ZZZP2ZZZX0ZZZZ05EEE@0000020:ZZZP80EEEE00<000000:ZZZP3o
ool00`3oool:0=7=Z@@0oooo00P0EEEE0?ooo`3oool0EEEE0?ooo`1EEED0oooo000000@0oooo00D0
00000?ooo`2ZZZX0oooo0:ZZZP0305EEE@80oooo0P1EEED01@3oool0ZZZZ0?ooo`1EEED0oooo00<0
ZZZZ00T0oooo0:ZZZP2ZZZX0oooo0:ZZZP3oool0EEEE0?ooo`2ZZZX00P1EEED40?ooo`<0EEEE00D0
oooo0:ZZZP1EEED000000:ZZZP020?ooo`8000000`3oool0101EEED0ZZZZ0?ooo`2ZZZX40?ooo`X0
dLfY103oool01P1EEED0oooo000000000000ZZZZ0?ooo`@0000000D0EEEE0000001EEED000000?oo
o`020000000605EEE@000000EEEE05EEE@3oool0ZZZZ0P0000000`1EEED000000:ZZZP0300000005
0:ZZZP3oool0oooo0:ZZZP1EEED01000000205EEE@80000000P0oooo05EEE@1EEED0000005EEE@2Z
ZZX000000?ooo`80EEEE00@0oooo05EEE@000000ZZZZ0P0000000`3oool0ZZZZ000000020?ooo`03
0:ZZZP3oool0oooo0080oooo2P3AcJT40?ooo`070000003oool0EEEE0000003oool0ZZZZ05EEE@02
0000000305EEE@0000000000008000000`1EEED01@2ZZZX0oooo0:ZZZP1EEED0ZZZZ0080EEEE00<0
oooo0:ZZZP3oool00`000000101EEED0ZZZZ05EEE@1EEED20:ZZZP<0000000<0oooo0:ZZZP2ZZZX0
0P1EEED01P2ZZZX0EEEE0:ZZZP3oool0ZZZZ000000<0EEEE0`00000205EEE@050000001EEED0EEEE
0?ooo`0000000P3oool00`2ZZZX0oooo0?ooo`020?ooo``0dLfY000;0=7=Z@@0oooo00D0ZZZZ0000
003oool0EEEE0000000205EEE@030?ooo`1EEED0ZZZZ008000000P2ZZZX00`1EEED0oooo0?ooo`02
05EEE@060000001EEED0EEEE0000001EEED0oooo0P1EEED01P3oool0000005EEE@1EEED0ZZZZ05EE
E@80ZZZZ00@0oooo05EEE@000000oooo101EEED010000000EEEE05EEE@2ZZZX205EEE@030000003o
ool0EEEE0080ZZZZ00D0EEEE0000002ZZZX0EEEE0?ooo`0205EEE@040000001EEED0ZZZZ000000D0
oooo2P3AcJT40?ooo`070:ZZZP000000EEEE05EEE@2ZZZX0EEEE0000000205EEE@060?ooo`1EEED0
EEEE05EEE@3oool000000P1EEED20:ZZZP030000001EEED0EEEE0080EEEE0`3oool0301EEED0oooo
0:ZZZP1EEED0ZZZZ0?ooo`000000ZZZZ05EEE@2ZZZX0oooo000000<0oooo00D0EEEE0:ZZZP1EEED0
EEEE0?ooo`020:ZZZP80EEEE00<000000:ZZZP1EEED00P1EEED20?ooo`0505EEE@000000ZZZZ0:ZZ
ZP1EEED00P0000050?ooo`X0dLfY103oool00`2ZZZX0EEEE000000030?ooo`80000000<0EEEE0?oo
o`0000000P2ZZZX01@1EEED0000005EEE@2ZZZX0oooo0080EEEE00<0oooo0000003oool00P2ZZZX2
000000050?ooo`000000EEEE05EEE@0000000P1EEED01@000000EEEE05EEE@000000oooo00800000
00D0EEEE0:ZZZP00000000000?ooo`0205EEE@80oooo00@0EEEE0000003oool0ZZZZ0P000000103o
ool000000000000000030?ooo`80EEEE1@3oool:0=7=Z@@0oooo00L0ZZZZ05EEE@2ZZZX0ZZZZ0000
003oool000000080EEEE00D000000?ooo`3oool0EEEE0?ooo`020000000705EEE@2ZZZX0ZZZZ0?oo
o`2ZZZX0EEEE000000020:ZZZP060000003oool0000005EEE@3oool00000101EEED20?ooo`80EEEE
00P0oooo0000002ZZZX0ZZZZ0000001EEED0ZZZZ00000080ZZZZ00<0EEEE0000000000000P1EEED2
0?ooo`80000000L0EEEE00000000000000000:ZZZP000000EEEE00D0oooo2P3AcJT40?ooo`050:ZZ
ZP000000ZZZZ0?ooo`0000000`2ZZZX0101EEED0oooo0:ZZZP1EEED20:ZZZP0405EEE@3oool0ZZZZ
0:ZZZP<000000`2ZZZX010000000EEEE0000003oool20:ZZZP0305EEE@000000ZZZZ0080000000H0
EEEE0:ZZZP2ZZZX0ZZZZ0000001EEED40:ZZZP030000001EEED000000080ZZZZ00<0oooo05EEE@2Z
ZZX00`2ZZZX20?ooo`80ZZZZ0P0000000`3oool0EEEE000000050?ooo``0dLfY000;0=7=Z@H0oooo
00D0000005EEE@2ZZZX0ZZZZ0?ooo`0305EEE@060:ZZZP1EEED0ZZZZ05EEE@3oool000000P1EEED0
1@000000EEEE05EEE@3oool0EEEE0080ZZZZ1@0000000`2ZZZX0EEEE05EEE@0205EEE@030?ooo`00
0000000000<000000P2ZZZX01P1EEED0oooo05EEE@3oool0000005EEE@80000000<0oooo05EEE@2Z
ZZX00P2ZZZX00`1EEED0000005EEE@020?ooo`030:ZZZP1EEED0ZZZZ00H0oooo2P3AcJT60?ooo`07
0000001EEED0oooo05EEE@2ZZZX0000005EEE@02000000030?ooo`1EEED0EEEE0080EEEE00@0ZZZZ
0000001EEED000000`1EEED01@3oool0EEEE05EEE@2ZZZX0EEEE0080oooo00<0ZZZZ05EEE@1EEED0
0P1EEED40?ooo`040:ZZZP1EEED0ZZZZ0?ooo`<0EEEE00@0000005EEE@000000ZZZZ101EEED30000
000705EEE@000000ZZZZ05EEE@3oool0EEEE0:ZZZP060?ooo`X0dLfY1P3oool405EEE@040000003o
ool0oooo0?ooo`80EEEE00H0oooo05EEE@000000EEEE0:ZZZP3oool205EEE@040000003oool0oooo
0?ooo`80ZZZZ00H0oooo0:ZZZP000000oooo05EEE@3oool2000000070?ooo`1EEED0oooo0000002Z
ZZX0oooo0:ZZZP040?ooo`80000000H0EEEE0?ooo`2ZZZX0EEEE0000001EEED20?ooo`0605EEE@3o
ool0oooo0?ooo`000000ZZZZ0P1EEED00`2ZZZX0oooo0?ooo`040?ooo`X0dLfY1P3oool01@1EEED0
oooo0?ooo`000000oooo0080000000<0oooo0000003oool00P0000001@3oool0EEEE05EEE@3oool0
ZZZZ0080EEEE00D000000?ooo`3oool0EEEE0?ooo`0200000080oooo00<0ZZZZ0?ooo`2ZZZX00P3o
ool00`000000oooo0?ooo`02000000030?ooo`1EEED0oooo0080000000@0EEEE0:ZZZP2ZZZX0oooo
0P1EEED00`3oool0000000000002000000050?ooo`2ZZZX000000?ooo`0000000P3oool00`2ZZZX0
oooo0?ooo`040?ooo`X0dLfY1P3oool03@000000oooo0?ooo`3oool0EEEE0:ZZZP3oool0EEEE0:ZZ
ZP3oool0ZZZZ0?ooo`2ZZZX00`0000002`1EEED0ZZZZ0000002ZZZX0oooo0:ZZZP000000ZZZZ05EE
E@2ZZZX0oooo0080000000H0oooo0:ZZZP1EEED0oooo05EEE@0000020?ooo`0705EEE@2ZZZX0ZZZZ
0:ZZZP3oool0ZZZZ0000000205EEE@030000002ZZZX0000000<0ZZZZ00L0EEEE0:ZZZP1EEED0EEEE
0:ZZZP1EEED0ZZZZ0080oooo00<0ZZZZ0?ooo`3oool0103oool<0=7=Z@002`3AcJT60?ooo`<0ZZZZ
00d0EEEE0?ooo`000000EEEE0:ZZZP000000ZZZZ05EEE@3oool0EEEE0000002ZZZX0EEEE0080oooo
00D000000?ooo`2ZZZX000000:ZZZP040000000305EEE@2ZZZX0ZZZZ00<0ZZZZ0P1EEED02@000000
EEEE000000000000oooo0000001EEED0oooo000000020?ooo`0905EEE@000000000005EEE@2ZZZX0
EEEE0?ooo`000000ZZZZ0080000000@0oooo05EEE@2ZZZX0ZZZZ1`3oool:0=7=Z@H0oooo0P2ZZZX2
000000090?ooo`2ZZZX000000:ZZZP000000ZZZZ05EEE@2ZZZX0EEEE00<0oooo0`1EEED00`2ZZZX0
EEEE0:ZZZP020?ooo`030000001EEED0EEEE0080EEEE00@0oooo05EEE@000000oooo0`1EEED03@2Z
ZZX000000?ooo`000000ZZZZ05EEE@2ZZZX0EEEE0000001EEED0oooo0:ZZZP3oool00`1EEED20000
00<0ZZZZ00@0oooo05EEE@000000ZZZZ1`3oool:0=7=Z@H0oooo00P0ZZZZ05EEE@3oool0oooo05EE
E@3oool000000?ooo`80EEEE0`3oool02P1EEED0000005EEE@2ZZZX0oooo05EEE@3oool000000?oo
o`00000205EEE@040000001EEED000000?ooo`@0000000<0oooo0000001EEED0101EEED0103oool0
00000?ooo`1EEED20:ZZZP<0EEEE00<0oooo0000003oool00P1EEED01`3oool000000?ooo`1EEED0
ZZZZ0?ooo`1EEED01`3oool:0=7=Z@H0oooo00D0ZZZZ05EEE@000000ZZZZ0000000205EEE@0=0000
002ZZZX0000005EEE@000000EEEE0:ZZZP1EEED0ZZZZ0000002ZZZX0oooo05EEE@020?ooo`050000
003oool000000000003oool00P000000102ZZZX0000005EEE@2ZZZX2000000030?ooo`1EEED00000
00@0oooo00@0EEEE0?ooo`00000000000`2ZZZX00`1EEED0000005EEE@020:ZZZP80000000D0EEEE
0000002ZZZX0000005EEE@070?ooo`X0dLfY1P3oool01@2ZZZX0000005EEE@1EEED000000080EEEE
00<0ZZZZ0?ooo`0000000P0000002`3oool0EEEE0:ZZZP2ZZZX0EEEE0:ZZZP3oool000000:ZZZP00
0000ZZZZ0080oooo0P0000000`3oool0EEEE0:ZZZP0200000080ZZZZ00<0oooo0000000000000P3o
ool0102ZZZX0000005EEE@0000020?ooo`0505EEE@2ZZZX0EEEE05EEE@3oool00P0000020?ooo`07
0:ZZZP000000EEEE0000002ZZZX0EEEE000000070?ooo``0dLfY000;0=7=Z@L0oooo00<0ZZZZ0000
000000000P00000205EEE@80oooo0P2ZZZX00`1EEED0oooo05EEE@0405EEE@8000000P2ZZZX0203o
ool0ZZZZ0:ZZZP3oool0ZZZZ0?ooo`1EEED0oooo0`1EEED02`2ZZZX0oooo0:ZZZP2ZZZX0oooo0000
002ZZZX0oooo0000001EEED0ZZZZ0080EEEE0P3oool205EEE@030:ZZZP3oool0oooo0080EEEE0P00
00000`3oool000000:ZZZP070?ooo`X0dLfY1`3oool00`2ZZZX0000005EEE@0305EEE@060?ooo`1E
EED0oooo0:ZZZP1EEED0oooo0P000000103oool0000005EEE@2ZZZX305EEE@<0oooo00@0EEEE0:ZZ
ZP1EEED0ZZZZ0P1EEED01P000000EEEE05EEE@1EEED0ZZZZ05EEE@<0oooo00L0EEEE0:ZZZP1EEED0
ZZZZ05EEE@000000oooo0080000000D0oooo05EEE@2ZZZX0oooo05EEE@020?ooo`80EEEE0P000000
0`2ZZZX0oooo0?ooo`050?ooo`X0dLfY1`3oool00`2ZZZX0EEEE000000020?ooo`0905EEE@3oool0
00000?ooo`000000EEEE0?ooo`000000oooo00<0EEEE00X0oooo05EEE@000000EEEE0:ZZZP3oool0
EEEE0:ZZZP3oool0EEEE1@000000303oool0EEEE0?ooo`2ZZZX0EEEE0?ooo`2ZZZX0EEEE0000001E
EED0oooo00000080EEEE00<0oooo0000003oool00P0000000`3oool000000?ooo`030?ooo`80EEEE
00<0ZZZZ0?ooo`3oool01@3oool:0=7=Z@L0oooo00D0ZZZZ05EEE@000000EEEE0?ooo`020:ZZZP07
0000002ZZZX0ZZZZ0000002ZZZX0oooo0:ZZZP03000000080:ZZZP1EEED0000005EEE@000000ZZZZ
05EEE@3oool4000000030?ooo`2ZZZX0000000<000000P1EEED20:ZZZP0405EEE@2ZZZX0EEEE0:ZZ
ZP<000000P3oool30:ZZZP8000000P2ZZZX01@3oool0EEEE05EEE@1EEED0ZZZZ00L0oooo2P3AcJT7
0?ooo`050:ZZZP000000EEEE05EEE@3oool00P2ZZZX01P000000ZZZZ0:ZZZP2ZZZX0000005EEE@<0
00000`1EEED0102ZZZX0oooo05EEE@0000030:ZZZP0405EEE@000000ZZZZ0?ooo`80ZZZZ00D00000
05EEE@2ZZZX0EEEE0:ZZZP0200000080oooo0P1EEED00`2ZZZX000000000000205EEE@050000003o
ool0ZZZZ05EEE@0000000P2ZZZX01@3oool0EEEE000000000000ZZZZ00L0oooo303AcJT000/0dLfY
2@3oool20000000505EEE@3oool0EEEE0:ZZZP0000000P3oool20:ZZZP<0000000@0ZZZZ05EEE@3o
ool00000101EEED01`2ZZZX0oooo05EEE@3oool0EEEE0:ZZZP3oool00`1EEED01P3oool0EEEE05EE
E@1EEED0oooo05EEE@80oooo00@0EEEE0:ZZZP00000000000`2ZZZX30?ooo`060:ZZZP1EEED0ZZZZ
05EEE@000000ZZZZ2@3oool:0=7=Z@T0oooo00@0000005EEE@3oool00000101EEED00`3oool0ZZZZ
05EEE@020000000905EEE@3oool0oooo0?ooo`1EEED0ZZZZ05EEE@2ZZZX0EEEE00<0ZZZZ00<0oooo
0000000000000P0000000`1EEED0ZZZZ0:ZZZP0205EEE@040:ZZZP1EEED0ZZZZ0:ZZZP<0oooo00D0
EEEE0000001EEED0EEEE0:ZZZP0605EEE@030?ooo`1EEED0ZZZZ00T0oooo2P3AcJT90?ooo`@0EEEE
0`0000030?ooo`0505EEE@3oool0oooo05EEE@2ZZZX00P3oool0101EEED0ZZZZ0:ZZZP3oool205EE
E@030?ooo`000000000000H0000000@0oooo0000001EEED0oooo0P2ZZZX01@000000oooo0?ooo`00
0000EEEE0080oooo00@0EEEE0?ooo`3oool0oooo0`000000102ZZZX0EEEE05EEE@2ZZZX90?ooo`X0
dLfY2@3oool00`1EEED000000:ZZZP03000000050?ooo`2ZZZX0ZZZZ0?ooo`2ZZZX01@00000305EE
E@80ZZZZ00L000000?ooo`1EEED0000005EEE@3oool000000080oooo0P0000001@1EEED000000000
002ZZZX0oooo00<0EEEE1@0000001@2ZZZX0oooo0000002ZZZX0EEEE008000000P2ZZZX00`000000
ZZZZ0?ooo`080?ooo`X0dLfY2@3oool01@000000EEEE0:ZZZP3oool0ZZZZ0080EEEE00<0000005EE
E@0000000P0000001@1EEED0ZZZZ0:ZZZP1EEED0ZZZZ00<0000000D0EEEE0?ooo`2ZZZX000000:ZZ
ZP02000000030:ZZZP00000000000080ZZZZ00H000000?ooo`3oool0EEEE0:ZZZP0000020:ZZZP80
EEEE00<0ZZZZ05EEE@0000000P000000101EEED000000000001EEED30:ZZZP0305EEE@2ZZZX0oooo
00P0oooo303AcJT000/0dLfY2@3oool20:ZZZP040?ooo`1EEED0ZZZZ0?ooo`@0EEEE00D0oooo05EE
E@00000000000?ooo`03000000030:ZZZP1EEED0EEEE0080EEEE00<0oooo0000003oool00P1EEED0
1@2ZZZX0EEEE000000000000oooo00@0EEEE00D0ZZZZ00000000000000000:ZZZP020000000;05EE
E@3oool0EEEE0:ZZZP1EEED000000?ooo`2ZZZX0EEEE0?ooo`2ZZZX02P3oool:0=7=Z@T0oooo0P2Z
ZZX20000000405EEE@3oool0EEEE00000080oooo00`0ZZZZ0?ooo`3oool0EEEE0000001EEED0ZZZZ
0?ooo`1EEED0ZZZZ05EEE@2ZZZX205EEE@040?ooo`2ZZZX000000:ZZZP80000000D0EEEE0?ooo`1E
EED0oooo0:ZZZP0305EEE@080000002ZZZX0EEEE0:ZZZP1EEED0oooo05EEE@2ZZZX20?ooo`800000
00D0oooo05EEE@1EEED000000:ZZZP0:0?ooo`X0dLfY2@3oool03P2ZZZX0EEEE0?ooo`3oool0EEEE
0?ooo`1EEED0oooo0000003oool0EEEE0000001EEED0ZZZZ0`3oool405EEE@030:ZZZP3oool0EEEE
0080000000@0EEEE000000000000EEEE0P0000001P1EEED0ZZZZ0:ZZZP1EEED0000005EEE@<0oooo
0P2ZZZX01@1EEED0ZZZZ05EEE@3oool0000000<0oooo00@0EEEE0:ZZZP3oool0EEEE2P3oool:0=7=
Z@T0oooo00@0ZZZZ05EEE@1EEED0EEEE0P3oool00`2ZZZX0000005EEE@0205EEE@<0000000@0EEEE
0?ooo`000000oooo0P1EEED01`000000EEEE0000003oool0ZZZZ0000003oool00P0000001`3oool0
ZZZZ0:ZZZP3oool0000005EEE@0000000P1EEED00`2ZZZX000000?ooo`0400000080EEEE0P000000
101EEED0oooo0?ooo`00000205EEE@X0oooo2P3AcJT90?ooo`040:ZZZP000000000000000080ZZZZ
00P0EEEE0?ooo`2ZZZX0oooo0000003oool0ZZZZ05EEE@80000000H0ZZZZ0000003oool0oooo0:ZZ
ZP1EEED20:ZZZP060?ooo`2ZZZX0ZZZZ0:ZZZP3oool0ZZZZ0P3oool00`2ZZZX0000005EEE@020:ZZ
ZP040?ooo`2ZZZX0ZZZZ00000080EEEE0P2ZZZX010000000oooo05EEE@3oool30:ZZZP0305EEE@00
0000000000X0oooo303AcJT000/0dLfY2`3oool01P2ZZZX0EEEE0000003oool0EEEE0:ZZZP<00000
00<0EEEE0:ZZZP1EEED0102ZZZX3000000030:ZZZP000000000000<0EEEE0P3oool305EEE@030000
002ZZZX0ZZZZ00<0000000D0oooo0:ZZZP2ZZZX0ZZZZ05EEE@020:ZZZP8000000P2ZZZX20?ooo`03
0000002ZZZX0ZZZZ00/0oooo2P3AcJT;0?ooo`080:ZZZP3oool0EEEE0:ZZZP3oool0ZZZZ0?ooo`2Z
ZZX205EEE@050000001EEED0oooo05EEE@3oool00`1EEED20:ZZZP@0oooo00@0EEEE0000001EEED0
EEEE0`3oool01@1EEED0ZZZZ0:ZZZP2ZZZX0EEEE0080oooo00@0EEEE0:ZZZP1EEED000000P1EEED0
0`2ZZZX0EEEE0:ZZZP020:ZZZP0305EEE@2ZZZX0ZZZZ00/0oooo2P3AcJT;0?ooo`030:ZZZP3oool0
oooo00D0oooo00@0000005EEE@1EEED000000P1EEED00`3oool0EEEE0000000205EEE@80oooo00@0
ZZZZ0?ooo`3oool0ZZZZ0P3oool01P2ZZZX0oooo0?ooo`2ZZZX0EEEE0?ooo`80EEEE00@0000005EE
E@3oool0EEEE0P00000205EEE@030000003oool0EEEE00@0oooo00<0EEEE0:ZZZP3oool02P3oool:
0=7=Z@/0oooo00@0ZZZZ0000002ZZZX0ZZZZ0P1EEED01@000000EEEE05EEE@1EEED000000080EEEE
00<000000?ooo`1EEED00`1EEED01@000000ZZZZ0:ZZZP000000EEEE0080000000@0oooo00000000
000000000P2ZZZX010000000EEEE0000001EEED20?ooo`030000001EEED0EEEE00800000101EEED0
1@000000ZZZZ0:ZZZP1EEED0ZZZZ00/0oooo2P3AcJT;0?ooo`090:ZZZP1EEED0ZZZZ0?ooo`000000
ZZZZ0?ooo`2ZZZX0EEEE00<0ZZZZ00@0EEEE0:ZZZP00000000000P2ZZZX01@000000EEEE0:ZZZP1E
EED0ZZZZ0080oooo00D0ZZZZ05EEE@3oool0EEEE0:ZZZP0305EEE@070000003oool0ZZZZ05EEE@00
0000ZZZZ0?ooo`020:ZZZP80EEEE0`2ZZZX01@000000oooo0:ZZZP000000ZZZZ00/0oooo303AcJT0
00/0dLfY303oool01P000000EEEE05EEE@1EEED0oooo05EEE@80000000@0oooo05EEE@1EEED0oooo
0P1EEED00`000000ZZZZ0000000305EEE@<0oooo1@0000030?ooo`80EEEE00<000000:ZZZP3oool0
1@1EEED01P2ZZZX000000000001EEED0oooo0:ZZZP80EEEE00<0ZZZZ0?ooo`3oool02P3oool:0=7=
Z@`0oooo00<0000005EEE@3oool00P1EEED3000000070?ooo`2ZZZX0ZZZZ05EEE@000000oooo0000
000205EEE@80ZZZZ1@1EEED00`3oool0ZZZZ05EEE@0405EEE@80ZZZZ00D0oooo05EEE@000000oooo
000000030:ZZZP0405EEE@00000000000?ooo`80EEEE00<0oooo05EEE@2ZZZX0303oool:0=7=Z@`0
oooo101EEED010000000oooo0?ooo`3oool40:ZZZP050000003oool0EEEE0?ooo`0000000P3oool0
10000000EEEE05EEE@00000405EEE@030:ZZZP1EEED0EEEE00D0oooo00@0EEEE0?ooo`000000oooo
0P2ZZZX01P1EEED0oooo0?ooo`3oool000000:ZZZP80EEEE00<0ZZZZ0?ooo`3oool02P3oool:0=7=
Z@`0oooo0P1EEED01P000000oooo0:ZZZP2ZZZX0EEEE0?ooo`80ZZZZ00<0oooo05EEE@3oool00P3o
ool01`000000ZZZZ0:ZZZP2ZZZX000000:ZZZP0000000P2ZZZX01`1EEED000000:ZZZP2ZZZX00000
0:ZZZP0000000`2ZZZX01P000000oooo0?ooo`3oool0EEEE0?ooo`80ZZZZ00P0oooo05EEE@1EEED0
ZZZZ05EEE@000000EEEE0:ZZZP`0oooo2P3AcJT<0?ooo`80000000T0EEEE0:ZZZP1EEED0ZZZZ0000
002ZZZX0000005EEE@0000000P3oool20:ZZZP80oooo0`2ZZZX2000000050:ZZZP1EEED0EEEE0000
001EEED00`0000030:ZZZP80oooo0P2ZZZX01`3oool000000000001EEED000000:ZZZP0000000P1E
EED0102ZZZX0EEEE0000002ZZZX<0?ooo``0dLfY000;0=7=Z@`0oooo0`2ZZZX0101EEED0oooo0?oo
o`3oool205EEE@030000002ZZZX0oooo0080000000@0EEEE0?ooo`3oool0oooo0P0000000`3oool0
EEEE000000020000000505EEE@000000000005EEE@3oool00P000000103oool0EEEE0?ooo`3oool2
0000000805EEE@2ZZZX000000?ooo`1EEED0oooo0000003oool30:ZZZPd0oooo2P3AcJT<0?ooo`80
ZZZZ0P0000020?ooo`0305EEE@3oool0000000<000000P1EEED010000000EEEE0:ZZZP2ZZZX305EE
E@030:ZZZP1EEED0ZZZZ0080oooo00P0ZZZZ05EEE@2ZZZX0EEEE0:ZZZP1EEED0ZZZZ000000@0EEEE
0`0000020?ooo`0605EEE@3oool0oooo05EEE@000000ZZZZ3@3oool:0=7=Z@`0oooo00D0ZZZZ05EE
E@3oool0oooo05EEE@02000000030?ooo`1EEED000000080EEEE0P0000000`3oool000000?ooo`03
0?ooo`0505EEE@2ZZZX0oooo05EEE@3oool00P1EEED00`3oool0ZZZZ05EEE@030?ooo`0305EEE@00
0000oooo008000000P1EEED02@000000EEEE0?ooo`000000oooo05EEE@2ZZZX0oooo05EEE@0=0?oo
o`X0dLfY303oool00`2ZZZX0EEEE0?ooo`0200000080oooo00D000000:ZZZP00000000000?ooo`04
000000040:ZZZP00000000000:ZZZP80000000H0EEEE0000003oool0EEEE0000001EEED200000003
0:ZZZP00000000000080000000@0oooo000000000000oooo100000000`3oool0ZZZZ000000020?oo
o`0305EEE@3oool0oooo00/0oooo2P3AcJT<0?ooo`070:ZZZP000000oooo0:ZZZP3oool0ZZZZ05EE
E@050:ZZZP030000001EEED0000000D0000000@0oooo0:ZZZP3oool0EEEE0P2ZZZX01@1EEED00000
0:ZZZP3oool0EEEE0080000000H0oooo000000000000EEEE0000001EEED20:ZZZP0405EEE@2ZZZX0
EEEE05EEE@<0oooo00<000000?ooo`3oool02`3oool<0=7=Z@002`3AcJT>0?ooo`040:ZZZP000000
oooo00000080ZZZZ00<0EEEE0000003oool01@1EEED20?ooo`040000001EEED0ZZZZ00000080EEEE
00H000000?ooo`1EEED0oooo0000002ZZZX2000000040?ooo`2ZZZX0EEEE000000<0EEEE00<0oooo
0000002ZZZX00P2ZZZX010000000oooo0:ZZZP2ZZZX>0?ooo`X0dLfY3P3oool00`2ZZZX0oooo05EE
E@0205EEE@030:ZZZP3oool0EEEE00<0000000<0ZZZZ05EEE@0000000`0000001P1EEED0ZZZZ0:ZZ
ZP1EEED0000005EEE@8000000`2ZZZX02`3oool000000000003oool0000005EEE@2ZZZX0000005EE
E@000000EEEE0080ZZZZ00<0EEEE0:ZZZP1EEED00P2ZZZX>0?ooo`X0dLfY3P3oool00`2ZZZX0oooo
0?ooo`020?ooo`80000000D0oooo05EEE@3oool000000:ZZZP0205EEE@80oooo00H0EEEE00000000
0000ZZZZ0000001EEED20?ooo`0405EEE@2ZZZX0ZZZZ00000080EEEE00H0oooo0:ZZZP1EEED0EEEE
0:ZZZP00000205EEE@030?ooo`000000000000<0oooo00<0EEEE0:ZZZP3oool03@3oool:0=7=Z@h0
oooo00<0ZZZZ05EEE@0000000`3oool00`2ZZZX0EEEE0?ooo`04000000050?ooo`2ZZZX000000000
002ZZZX00P00000205EEE@040?ooo`1EEED0EEEE0:ZZZP80000000D0ZZZZ000000000000ZZZZ0?oo
o`04000000030?ooo`1EEED0EEEE0080oooo00@0EEEE0000001EEED0ZZZZ3P3oool:0=7=Z@h0oooo
00@0ZZZZ0000001EEED0oooo0P2ZZZX01@1EEED0oooo05EEE@000000EEEE008000000P3oool03@1E
EED000000:ZZZP1EEED000000:ZZZP3oool0ZZZZ05EEE@3oool0ZZZZ0000001EEED00P0000000`1E
EED0ZZZZ0?ooo`02000000<0EEEE00@0oooo0:ZZZP2ZZZX0ZZZZ0P1EEED00`000000ZZZZ0?ooo`0=
0?ooo``0dLfY000;0=7=Z@l0oooo0P00000205EEE@030?ooo`1EEED0EEEE00<0000000H0oooo05EE
E@2ZZZX0oooo05EEE@00000205EEE@80oooo00@0000005EEE@3oool000000P3oool205EEE@040000
001EEED000000:ZZZP80oooo00<000000?ooo`0000000P1EEED01@3oool0EEEE000000000000ZZZZ
00l0oooo2P3AcJT?0?ooo`070000001EEED0EEEE0000003oool0000005EEE@0200000080EEEE00@0
000005EEE@1EEED000000P1EEED30:ZZZP050?ooo`2ZZZX0ZZZZ0?ooo`1EEED00P2ZZZX205EEE@04
0000001EEED0EEEE0?ooo`<0EEEE00P0000005EEE@2ZZZX0oooo0000003oool0EEEE0:ZZZPl0oooo
2P3AcJT?0?ooo`80EEEE00<0ZZZZ05EEE@0000000P0000001@3oool00000000000000000oooo0080
000000P0EEEE0:ZZZP2ZZZX0oooo0:ZZZP3oool0EEEE0:ZZZP80EEEE00<0oooo0:ZZZP3oool00P2Z
ZZX0101EEED0ZZZZ0000002ZZZX200000080oooo0`00000305EEE@030:ZZZP3oool0oooo00d0oooo
2P3AcJT?0?ooo`0905EEE@3oool000000000003oool0ZZZZ0000003oool0EEEE0080000000<0EEEE
0000000000000P0000001@1EEED000000000002ZZZX0oooo0080EEEE00D0oooo0000000000000000
05EEE@02000000030:ZZZP000000000000<0000000D0oooo000000000000oooo000000020?ooo`03
0:ZZZP3oool0oooo00d0oooo2P3AcJT?0?ooo`030000003oool0000000<0000000H0EEEE0:ZZZP1E
EED0oooo0:ZZZP1EEED20:ZZZP0605EEE@3oool0EEEE0:ZZZP3oool0EEEE0P0000002@2ZZZX00000
0000003oool0ZZZZ05EEE@3oool0EEEE000000030:ZZZP80oooo00<0ZZZZ05EEE@1EEED00P000002
0?ooo`030:ZZZP3oool0oooo00d0oooo303AcJT000/0dLfY3`3oool30:ZZZP0305EEE@3oool00000
0080oooo0P0000001@1EEED000000?ooo`2ZZZX0000000H0EEEE00@0oooo0000001EEED0ZZZZ101E
EED01`000000ZZZZ0?ooo`3oool0EEEE0000001EEED00P3oool01@000000oooo05EEE@3oool0ZZZZ
0100oooo2P3AcJT?0?ooo`80ZZZZ00H0EEEE0000001EEED0ZZZZ0?ooo`1EEED30:ZZZP@0EEEE00@0
00000?ooo`000000ZZZZ0P1EEED0303oool0EEEE05EEE@3oool0ZZZZ0000003oool0000005EEE@2Z
ZZX0EEEE00000080ZZZZ00D0oooo05EEE@3oool0ZZZZ05EEE@02000000030:ZZZP3oool0oooo00h0
oooo2P3AcJT?0?ooo`080:ZZZP1EEED0ZZZZ0?ooo`1EEED0oooo05EEE@3oool300000080ZZZZ00<0
oooo05EEE@1EEED00`1EEED01P2ZZZX0EEEE0:ZZZP3oool0EEEE00000080EEEE00D0000005EEE@1E
EED0oooo0:ZZZP04000000040?ooo`1EEED0oooo05EEE@80oooo00<0EEEE0?ooo`3oool03P3oool:
0=7=Z@l0oooo00@0ZZZZ05EEE@2ZZZX0ZZZZ0P0000001@1EEED000000:ZZZP2ZZZX0oooo0080ZZZZ
0P000000101EEED0ZZZZ0000002ZZZX20?ooo`030000003oool0oooo0080ZZZZ00<000000?ooo`1E
EED00P0000020:ZZZP040?ooo`2ZZZX0ZZZZ00000080EEEE00@000000:ZZZP000000EEEE403oool:
0=7=Z@l0oooo00L0ZZZZ0000002ZZZX0ZZZZ0?ooo`1EEED0ZZZZ0080oooo0`0000000`2ZZZX0EEEE
05EEE@04000000060:ZZZP1EEED0EEEE0:ZZZP1EEED0oooo0P0000000`2ZZZX0000005EEE@020:ZZ
ZP<000000P3oool20:ZZZP040?ooo`2ZZZX0EEEE00000100oooo303AcJT000/0dLfY4@3oool01`2Z
ZZX0EEEE05EEE@000000ZZZZ05EEE@3oool00P2ZZZX01@000000ZZZZ0:ZZZP3oool0ZZZZ00800000
00<0ZZZZ0000003oool00`3oool20:ZZZP070000002ZZZX0ZZZZ0?ooo`000000ZZZZ05EEE@030:ZZ
ZP0305EEE@2ZZZX0EEEE0080EEEE00<0ZZZZ0?ooo`3oool03`3oool:0=7=ZA40oooo00D0ZZZZ0?oo
o`1EEED0ZZZZ05EEE@020?ooo`<0EEEE0P2ZZZX605EEE@050?ooo`2ZZZX0EEEE0?ooo`2ZZZX01@1E
EED20:ZZZP<0EEEE0P3oool01@1EEED0ZZZZ05EEE@3oool0ZZZZ0140oooo2P3AcJTA0?ooo`0305EE
E@3oool0oooo00D0oooo00<0EEEE0:ZZZP2ZZZX00`2ZZZX00`3oool0EEEE05EEE@02000000040?oo
o`2ZZZX000000?ooo`80EEEE00<000000:ZZZP2ZZZX00P2ZZZX0103oool0EEEE0?ooo`1EEED50?oo
o`030:ZZZP3oool0oooo00l0oooo2P3AcJTA0?ooo`0505EEE@3oool0oooo0000002ZZZX00P000002
05EEE@80ZZZZ0P0000000`3oool0ZZZZ0:ZZZP020?ooo`030:ZZZP00000000000080ZZZZ00H0oooo
0:ZZZP3oool0oooo0000003oool20:ZZZP80EEEE0P0000001@2ZZZX000000?ooo`3oool0ZZZZ0140
oooo2P3AcJTA0?ooo`080000003oool0oooo0000003oool0EEEE0:ZZZP3oool20000000:05EEE@00
000000000?ooo`000000EEEE0000003oool0ZZZZ000000<0ZZZZ00D0000005EEE@3oool0oooo0000
000205EEE@8000000P3oool00`1EEED0oooo05EEE@020?ooo`030:ZZZP3oool0oooo00l0oooo303A
cJT000/0dLfY4@3oool01`2ZZZX0000005EEE@3oool0ZZZZ0?ooo`1EEED00P2ZZZX20?ooo`040:ZZ
ZP1EEED0EEEE05EEE@80oooo1@000000102ZZZX0oooo0?ooo`3oool205EEE@030:ZZZP3oool0EEEE
0080ZZZZ00H0EEEE0?ooo`2ZZZX0ZZZZ05EEE@00000B0?ooo`X0dLfY4@3oool00`2ZZZX0000005EE
E@0205EEE@070:ZZZP1EEED0ZZZZ05EEE@2ZZZX0EEEE0:ZZZP0205EEE@040?ooo`1EEED000000000
0080EEEE00H0ZZZZ05EEE@000000000005EEE@2ZZZX205EEE@0;0:ZZZP1EEED0oooo05EEE@2ZZZX0
00000:ZZZP1EEED0oooo05EEE@0000004P3oool:0=7=ZA40oooo00H0ZZZZ05EEE@1EEED0ZZZZ05EE
E@0000030?ooo`040000002ZZZX000000:ZZZP8000000P3oool200000080EEEE0P0000020?ooo`80
000000@0ZZZZ0000002ZZZX000000`3oool00`000000EEEE05EEE@0205EEEA80oooo2P3AcJTA0?oo
o`040:ZZZP1EEED000000:ZZZP80000000/0EEEE0?ooo`2ZZZX000000:ZZZP1EEED000000?ooo`00
0000ZZZZ0000000205EEE@8000000P1EEED010000000ZZZZ0000003oool2000000040:ZZZP000000
ZZZZ0?ooo`<0000000<0ZZZZ0000001EEED04P3oool:0=7=ZA40oooo00@0ZZZZ0000001EEED0oooo
0P00000305EEE@050?ooo`1EEED0oooo0:ZZZP0000000`2ZZZX305EEE@030:ZZZP1EEED0EEEE0080
ZZZZ00H0EEEE0000002ZZZX0ZZZZ05EEE@3oool205EEE@060:ZZZP00000000000:ZZZP1EEED00000
4P3oool<0=7=Z@002`3AcJTB0?ooo`80ZZZZ0P1EEED0203oool000000?ooo`2ZZZX0EEEE0000002Z
ZZX000000P1EEED01@000000oooo05EEE@000000EEEE0080000000h0EEEE0?ooo`000000ZZZZ05EE
E@000000oooo0000003oool0ZZZZ0?ooo`000000oooo05EEE@<0ZZZZ4P3oool:0=7=ZA80oooo0P2Z
ZZX00`1EEED000000?ooo`020:ZZZP80EEEE00D0oooo0000003oool0oooo0:ZZZP0405EEE@80ZZZZ
00D0EEEE0000001EEED0EEEE000000020?ooo`040:ZZZP3oool0EEEE05EEE@80ZZZZ00<0oooo0000
000000000P2ZZZXB0?ooo`X0dLfY4P3oool01@2ZZZX0EEEE0:ZZZP3oool0EEEE008000000`3oool0
0`2ZZZX0oooo0?ooo`030?ooo`0305EEE@3oool0000000D0oooo00X0EEEE0?ooo`3oool0ZZZZ0?oo
o`1EEED0oooo0000003oool0EEEE0P3oool00`1EEED0ZZZZ0?ooo`0A0?ooo`X0dLfY4P3oool01`2Z
ZZX0EEEE0000001EEED0oooo05EEE@2ZZZX00`0000020:ZZZP<000000`2ZZZX00`000000ZZZZ0:ZZ
ZP020:ZZZP030000001EEED000000080ZZZZ0`0000000`2ZZZX0oooo0?ooo`0305EEE@030:ZZZP3o
ool0oooo0100oooo2P3AcJTB0?ooo`030:ZZZP000000EEEE0080ZZZZ00<0EEEE0000001EEED00P1E
EED00`000000oooo05EEE@020000000905EEE@2ZZZX0EEEE0000003oool0EEEE0?ooo`1EEED00000
0080EEEE00<0oooo0000001EEED00P1EEED010000000EEEE0:ZZZP2ZZZX2000000030:ZZZP3oool0
oooo0100oooo303AcJT000/0dLfY503oool00`2ZZZX000000000000405EEE@060?ooo`1EEED0ZZZZ
0:ZZZP1EEED0ZZZZ0P00000405EEE@80000000<0ZZZZ0000002ZZZX00P2ZZZX20?ooo`<0EEEE0P00
00000`2ZZZX0oooo0?ooo`0B0?ooo`X0dLfY503oool0202ZZZX0oooo05EEE@1EEED000000?ooo`1E
EED0ZZZZ101EEED0102ZZZX0oooo0?ooo`2ZZZX205EEE@040:ZZZP3oool0oooo0:ZZZP@0EEEE00P0
ZZZZ05EEE@3oool000000:ZZZP1EEED0oooo0:ZZZQ@0oooo2P3AcJTD0?ooo`0305EEE@3oool0oooo
0080oooo0P000000103oool0EEEE0:ZZZP3oool300000080oooo00@0EEEE0?ooo`3oool0EEEE0P00
00020?ooo`030:ZZZP3oool0oooo00800000103oool00`2ZZZX0oooo0?ooo`0B0?ooo`X0dLfY503o
ool0101EEED000000:ZZZP00000205EEE@030000001EEED0EEEE00D0000000<0ZZZZ000000000000
0P000000102ZZZX000000000002ZZZX3000000@0EEEE0P2ZZZX00`000000ZZZZ0?ooo`0C0?ooo`X0
dLfY503oool020000000EEEE0:ZZZP000000EEEE0000001EEED000000P1EEED01@2ZZZX0EEEE05EE
E@1EEED0oooo0080ZZZZ00<000000:ZZZP2ZZZX00P1EEED20:ZZZP0305EEE@000000000000800000
0P1EEED00`2ZZZX0EEEE0:ZZZP0D0?ooo``0dLfY000;0=7=ZA@0oooo00D0ZZZZ000000000000ZZZZ
0?ooo`0205EEE@050000002ZZZX0EEEE0:ZZZP3oool01`1EEED00`000000EEEE05EEE@020:ZZZP07
05EEE@3oool000000:ZZZP1EEED0oooo05EEE@02000001D0oooo2P3AcJTD0?ooo`050:ZZZP000000
EEEE05EEE@0000000P1EEED01@3oool000000000001EEED0oooo00@0EEEE00<000000?ooo`1EEED0
0`1EEED02`000000EEEE0000001EEED0oooo0:ZZZP1EEED000000?ooo`1EEED0000001D0oooo2P3A
cJTD0?ooo`050:ZZZP1EEED0EEEE0:ZZZP1EEED00`00000205EEE@030000002ZZZX0oooo0080ZZZZ
00@000000?ooo`1EEED000000P2ZZZX01@3oool0ZZZZ0000001EEED0oooo00<00000101EEEDE0?oo
o`X0dLfY503oool01@2ZZZX0EEEE05EEE@1EEED0oooo0080ZZZZ00<0EEEE0000003oool00P1EEED0
0`3oool0000005EEE@040000000505EEE@000000oooo0000001EEED00P3oool205EEE@030:ZZZP3o
ool000000080EEEE5@3oool:0=7=ZA@0oooo00l0ZZZZ000000000000EEEE0?ooo`2ZZZX0EEEE0?oo
o`1EEED0000005EEE@000000ZZZZ0000001EEED00P2ZZZX02P1EEED0ZZZZ000000000000ZZZZ0000
001EEED0000005EEE@3oool20:ZZZP040?ooo`1EEED00000000001D0oooo303AcJT000/0dLfY5@3o
ool20:ZZZP80EEEE00T0ZZZZ000000000000ZZZZ05EEE@3oool0EEEE0:ZZZP0000001P1EEED02`00
0000ZZZZ05EEE@3oool0EEEE0:ZZZP000000oooo0:ZZZP1EEED0oooo0080ZZZZ5@3oool:0=7=ZAD0
oooo0P2ZZZX0101EEED0000005EEE@1EEED20:ZZZP8000000P1EEED0202ZZZX0EEEE0:ZZZP000000
EEEE0:ZZZP1EEED0ZZZZ0P1EEED3000000030:ZZZP3oool0EEEE008000000P2ZZZXE0?ooo`X0dLfY
5@3oool02@2ZZZX0EEEE0:ZZZP3oool0EEEE0?ooo`1EEED000000:ZZZP060?ooo`80EEEE00/0oooo
0:ZZZP3oool0oooo0:ZZZP3oool0ZZZZ0?ooo`1EEED0oooo05EEE@020?ooo`0305EEE@2ZZZX0oooo
01@0oooo2P3AcJTE0?ooo`030:ZZZP1EEED0oooo008000000P3oool2000000060?ooo`1EEED0EEEE
05EEE@3oool0EEEE0P000000101EEED0ZZZZ05EEE@1EEED20?ooo`80000000L0oooo0:ZZZP000000
00000?ooo`1EEED0ZZZZ01D0oooo2P3AcJTE0?ooo`030:ZZZP000000oooo00<0000000L0ZZZZ0?oo
o`2ZZZX0ZZZZ05EEE@2ZZZX0EEEE0080ZZZZ0P0000020:ZZZP0305EEE@2ZZZX0ZZZZ0080ZZZZ00<0
EEEE0:ZZZP0000000P0000000`3oool000000:ZZZP0E0?ooo``0dLfY000;0=7=ZAL0oooo00`0ZZZZ
05EEE@000000oooo05EEE@000000ZZZZ05EEE@000000ZZZZ0?ooo`2ZZZX2000000040:ZZZP000000
ZZZZ0?ooo`80ZZZZ00P0EEEE0:ZZZP2ZZZX0EEEE0?ooo`000000EEEE0:ZZZQL0oooo2P3AcJTG0?oo
o`050:ZZZP3oool0EEEE0:ZZZP3oool00P0000000`3oool000000?ooo`020:ZZZP0905EEE@000000
ZZZZ05EEE@000000ZZZZ0?ooo`2ZZZX0oooo0080000000D0oooo0:ZZZP1EEED0oooo0:ZZZP0G0?oo
o`X0dLfY5`3oool00`1EEED0oooo0?ooo`020?ooo`0305EEE@3oool0EEEE00<0oooo00H0EEEE0?oo
o`1EEED0EEEE0?ooo`1EEED20?ooo`80EEEE1P3oool00`2ZZZX0oooo0?ooo`0E0?ooo`X0dLfY5`3o
ool205EEE@050000003oool0oooo05EEE@2ZZZX00P1EEED00`2ZZZX0000000000002000000050?oo
o`00000000000000002ZZZX00P1EEED01`2ZZZX0oooo0?ooo`1EEED0000005EEE@2ZZZX05`3oool:
0=7=ZAL0oooo0P0000002@1EEED0ZZZZ0:ZZZP1EEED0oooo0:ZZZP1EEED0ZZZZ05EEE@030:ZZZP04
0000002ZZZX0EEEE05EEE@<0ZZZZ00L0oooo05EEE@2ZZZX0000005EEE@000000ZZZZ01L0oooo303A
cJT000/0dLfY5`3oool0102ZZZX0000005EEE@2ZZZX205EEE@030?ooo`1EEED0ZZZZ0080oooo00@0
ZZZZ0?ooo`3oool0ZZZZ103oool0102ZZZX0EEEE0?ooo`3oool305EEE@030000003oool0oooo01H0
oooo2P3AcJTG0?ooo`030:ZZZP000000EEEE0080EEEE00<0000005EEE@1EEED00`3oool01P2ZZZX0
EEEE05EEE@3oool0EEEE0:ZZZP80oooo1@1EEED00`3oool0EEEE0000000H0?ooo`X0dLfY5`3oool0
1@2ZZZX0EEEE05EEE@2ZZZX0EEEE00@0oooo00D0000005EEE@1EEED0EEEE0?ooo`0205EEE@040?oo
o`1EEED0000000000080oooo00<0000005EEE@1EEED00P1EEEDH0?ooo`X0dLfY5`3oool00`2ZZZX0
EEEE0?ooo`03000000030:ZZZP000000ZZZZ0080000000D0EEEE0?ooo`00000000000?ooo`030000
00050?ooo`000000ZZZZ0?ooo`0000000P3oool00`1EEED0oooo0?ooo`0F0?ooo`X0dLfY5`3oool0
1P2ZZZX000000?ooo`1EEED000000?ooo`<0000000<0EEEE0000001EEED00P2ZZZX0101EEED0ZZZZ
05EEE@00000205EEE@80000000D0oooo0000003oool0oooo0000000H0?ooo``0dLfY000;0=7=ZAP0
oooo0`2ZZZX01@1EEED000000?ooo`1EEED0ZZZZ00<0EEEE0P2ZZZX00`1EEED0ZZZZ0:ZZZP0205EE
E@050:ZZZP1EEED0oooo0?ooo`1EEED00`2ZZZXH0?ooo`X0dLfY603oool20:ZZZP0505EEE@000000
oooo05EEE@2ZZZX00`1EEED0103oool0EEEE0000002ZZZX505EEE@030:ZZZP1EEED0oooo00800000
0P2ZZZXH0?ooo`X0dLfY603oool00`2ZZZX0EEEE0:ZZZP020?ooo`040000001EEED0oooo0?ooo`80
EEEE00@0oooo05EEE@1EEED0oooo0P1EEED20?ooo`0305EEE@000000EEEE0080oooo00<0EEEE0:ZZ
ZP3oool05`3oool:0=7=ZAP0oooo00/0ZZZZ05EEE@2ZZZX0ZZZZ05EEE@000000EEEE0:ZZZP000000
ZZZZ0?ooo`0400000080ZZZZ0P0000001`1EEED000000000002ZZZX0000005EEE@2ZZZX0603oool:
0=7=ZAP0oooo00H0ZZZZ0000002ZZZX0oooo0000003oool20:ZZZP060?ooo`1EEED0000005EEE@2Z
ZZX0oooo0`1EEED02@3oool0ZZZZ0:ZZZP3oool000000?ooo`1EEED000000:ZZZP0H0?ooo``0dLfY
000;0=7=ZAX0oooo0100ZZZZ00000000000000000:ZZZP3oool0000005EEE@2ZZZX0EEEE0000002Z
ZZX0EEEE0:ZZZP1EEED000000P2ZZZX010000000oooo0000002ZZZXJ0?ooo`X0dLfY6P3oool00`2Z
ZZX0oooo0:ZZZP0405EEE@80oooo00<0EEEE0000002ZZZX00P1EEED00`3oool0EEEE0?ooo`0305EE
E@030?ooo`2ZZZX0oooo01T0oooo2P3AcJTJ0?ooo`0305EEE@3oool0oooo0080oooo00D0ZZZZ0?oo
o`1EEED0EEEE0?ooo`0205EEE@050?ooo`1EEED0EEEE0?ooo`000000103oool00`2ZZZX0oooo0?oo
o`0H0?ooo`X0dLfY6P3oool01@1EEED0oooo000000000000ZZZZ00<000000P2ZZZX00`000000ZZZZ
0:ZZZP04000000050:ZZZP000000oooo0?ooo`2ZZZX06P3oool:0=7=ZAX0oooo00H000000?ooo`2Z
ZZX0oooo05EEE@3oool305EEE@040?ooo`2ZZZX000000?ooo`<0EEEE00<0oooo05EEE@3oool00P3o
ool00`2ZZZX0oooo0?ooo`0H0?ooo``0dLfY000;0=7=ZAX0oooo00<0ZZZZ0000000000000`1EEED0
0`000000EEEE0:ZZZP0205EEE@060?ooo`1EEED0ZZZZ05EEE@000000oooo0P1EEED2000001/0oooo
2P3AcJTJ0?ooo`070:ZZZP000000oooo05EEE@000000oooo05EEE@020:ZZZP80EEEE00D0oooo05EE
E@000000ZZZZ05EEE@0200000080EEEE00<000000?ooo`3oool06@3oool:0=7=ZAX0oooo00L0ZZZZ
05EEE@1EEED0ZZZZ05EEE@000000ZZZZ00<0EEEE00T0oooo05EEE@1EEED0oooo05EEE@2ZZZX00000
05EEE@2ZZZX00P1EEEDK0?ooo`X0dLfY6P3oool0102ZZZX0EEEE0:ZZZP2ZZZX20000000305EEE@00
0000EEEE0080EEEE00D0000005EEE@000000000005EEE@02000000030:ZZZP000000EEEE01/0oooo
2P3AcJTJ0?ooo`060:ZZZP000000ZZZZ05EEE@000000ZZZZ10000000102ZZZX0oooo0000002ZZZX2
0000000505EEE@000000EEEE05EEE@0000006`3oool<0=7=Z@002`3AcJTK0?ooo`040:ZZZP3oool0
ZZZZ05EEE@80000000/0EEEE0:ZZZP1EEED000000?ooo`1EEED0ZZZZ05EEE@000000oooo05EEE@03
0:ZZZQ/0oooo2P3AcJTK0?ooo`040:ZZZP000000EEEE00000080EEEE00H0ZZZZ0?ooo`0000000000
0?ooo`0000020:ZZZP80EEEE00@0000005EEE@2ZZZX0ZZZZ6`3oool:0=7=ZA/0oooo00<0ZZZZ0?oo
o`2ZZZX00`3oool03P2ZZZX0EEEE0?ooo`000000ZZZZ0?ooo`1EEED0ZZZZ0?ooo`1EEED0oooo0:ZZ
ZP1EEED0ZZZZ6`3oool:0=7=ZA/0oooo00T0ZZZZ05EEE@000000EEEE0?ooo`1EEED0ZZZZ05EEE@3o
ool00P2ZZZX02@3oool0EEEE0:ZZZP1EEED0oooo05EEE@000000EEEE0:ZZZP0K0?ooo`X0dLfY6`3o
ool02@2ZZZX0000005EEE@1EEED0ZZZZ0?ooo`000000ZZZZ0?ooo`02000000030?ooo`2ZZZX00000
0080oooo0P1EEED00`000000ZZZZ0?ooo`0J0?ooo``0dLfY000;0=7=ZA`0oooo0P2ZZZX205EEE@0:
0000002ZZZX0oooo05EEE@000000oooo05EEE@000000ZZZZ00000080EEEE00<0ZZZZ0?ooo`3oool0
6`3oool:0=7=ZA`0oooo0P2ZZZX00`3oool0ZZZZ0:ZZZP0200000080oooo00P0EEEE0?ooo`1EEED0
00000:ZZZP1EEED0oooo0:ZZZQd0oooo2P3AcJTL0?ooo`030:ZZZP1EEED0oooo00<0oooo00<0ZZZZ
0000000000000P0000050?ooo`0305EEE@3oool0oooo01/0oooo2P3AcJTL0?ooo`050:ZZZP1EEED0
00000:ZZZP0000000P1EEED0103oool000000:ZZZP3oool205EEE@040000002ZZZX0000005EEEAd0
oooo2P3AcJTL0?ooo`050:ZZZP000000EEEE0:ZZZP1EEED00P2ZZZX02P1EEED0ZZZZ0000001EEED0
00000:ZZZP1EEED0ZZZZ05EEE@00000M0?ooo``0dLfY000;0=7=ZAd0oooo00D0ZZZZ0000002ZZZX0
oooo0:ZZZP020000000905EEE@3oool000000000002ZZZX0oooo05EEE@000000ZZZZ01d0oooo2P3A
cJTM0?ooo`030:ZZZP000000oooo0080EEEE00H000000:ZZZP1EEED0EEEE0:ZZZP00000305EEE@03
0000002ZZZX0oooo01`0oooo2P3AcJTM0?ooo`040:ZZZP1EEED0EEEE0:ZZZP80EEEE1000000205EE
E@040:ZZZP1EEED0EEEE0:ZZZQd0oooo2P3AcJTM0?ooo`070:ZZZP1EEED0000005EEE@3oool0EEEE
0:ZZZP0200000080ZZZZ00D0oooo05EEE@1EEED0EEEE0:ZZZP0M0?ooo`X0dLfY7@3oool01P2ZZZX0
000005EEE@000000EEEE0?ooo`80ZZZZ00@0EEEE0:ZZZP3oool0EEEE0`0000000`2ZZZX0oooo0?oo
o`0K0?ooo``0dLfY000;0=7=ZAl0oooo00<000000?ooo`0000000P0000000`1EEED0oooo00000002
000000030?ooo`2ZZZX0oooo01h0oooo2P3AcJTO0?ooo`80000000X0EEEE0:ZZZP1EEED0EEEE0000
001EEED0ZZZZ05EEE@000000ZZZZ7`3oool:0=7=ZAl0oooo0P1EEED02P000000oooo0000003oool0
EEEE0000003oool0000005EEE@2ZZZXO0?ooo`X0dLfY7`3oool00`1EEED000000:ZZZP0300000006
0?ooo`000000ZZZZ0:ZZZP000000ZZZZ7`3oool:0=7=ZAl0oooo00D0000005EEE@2ZZZX0oooo05EE
E@020:ZZZP0505EEE@3oool0ZZZZ05EEE@2ZZZX07`3oool<0=7=Z@002`3AcJTO0?ooo`80ZZZZ00H0
000005EEE@1EEED0oooo0000001EEED2000000030:ZZZP3oool0oooo01h0oooo2P3AcJTO0?ooo`80
ZZZZ00<0oooo05EEE@3oool00P2ZZZX0103oool0EEEE0?ooo`2ZZZXP0?ooo`X0dLfY7`3oool00`2Z
ZZX0EEEE0?ooo`020?ooo`80EEEE0`3oool00`1EEED0oooo0?ooo`0N0?ooo`X0dLfY7`3oool01@2Z
ZZX0EEEE05EEE@1EEED0oooo0080000000@0oooo0000001EEED0EEEE803oool:0=7=ZAl0oooo00@0
ZZZZ000000000000ZZZZ100000000`1EEED000000000000P0?ooo``0dLfY000;0=7=ZB00oooo00@0
ZZZZ0000001EEED0ZZZZ0P000000102ZZZX000000000002ZZZXP0?ooo`X0dLfY803oool00`2ZZZX0
00000?ooo`040000000305EEE@000000ZZZZ0200oooo2P3AcJTP0?ooo`040:ZZZP1EEED0EEEE05EE
E@80ZZZZ0`1EEED00`2ZZZX0oooo0?ooo`0N0?ooo`X0dLfY803oool00`2ZZZX0EEEE0?ooo`040000
00030?ooo`1EEED0ZZZZ0200oooo2P3AcJTP0?ooo`050:ZZZP000000oooo0:ZZZP3oool00P2ZZZX0
0`3oool000000:ZZZP0P0?ooo``0dLfY000;0=7=ZB80oooo00@000000:ZZZP000000EEEE0P2ZZZXR
0?ooo`X0dLfY8P3oool30000000305EEE@000000ZZZZ0280oooo2P3AcJTR0?ooo`<0EEEE00<0oooo
05EEE@2ZZZX08P3oool:0=7=ZB80oooo0`1EEED00`000000EEEE0:ZZZP0R0?ooo`X0dLfY8P3oool2
000000040:ZZZP00000000000:ZZZR80oooo303AcJT000/0dLfY8P3oool20:ZZZP030000001EEED0
ZZZZ02<0oooo2P3AcJTR0?ooo`80ZZZZ00<0EEEE0?ooo`2ZZZX08`3oool:0=7=ZB80oooo00D0ZZZZ
05EEE@000000oooo05EEE@0S0?ooo`X0dLfY8P3oool01@2ZZZX0EEEE0000003oool0EEEE02<0oooo
2P3AcJTR0?ooo`050:ZZZP000000ZZZZ0?ooo`0000008`3oool<0=7=Z@002`3AcJTS0?ooo`040:ZZ
ZP1EEED000000:ZZZR<0oooo2P3AcJTS0?ooo`040:ZZZP1EEED000000:ZZZR<0oooo2P3AcJTS0?oo
o`040:ZZZP1EEED000000:ZZZR<0oooo2P3AcJTS0?ooo`040:ZZZP1EEED000000:ZZZR<0oooo2P3A
cJTS0?ooo`040:ZZZP1EEED000000:ZZZR<0oooo303AcJT000/0dLfY903oool00`2ZZZX0oooo0?oo
o`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?oo
o`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?oo
o`0S0?ooo``0dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY
003o0=7=ZK80dLfY000;0=7=Z@060?ooo`2ZZZX0ZZZZ0:ZZZP000000EEEE0P3oool010000000oooo
0000003oool405EEE@80ZZZZ0P1EEED30?ooo`0605EEE@3oool0oooo0?ooo`1EEED0ZZZZ0P1EEED0
0`2ZZZX0oooo0?ooo`020:ZZZP80oooo0P2ZZZX20?ooo`<0EEEE00<0ZZZZ05EEE@3oool01@3oool4
05EEE@060:ZZZP1EEED0EEEE05EEE@2ZZZX0oooo0`0000020?ooo`0305EEE@000000ZZZZ0080ZZZZ
00<0oooo0=7=Z@3AcJT0203AcJT0203oool0ZZZZ0:ZZZP3oool000000?ooo`1EEED0ZZZZ0P1EEED0
1@000000oooo0?ooo`3oool0000000D0ZZZZ0`1EEED01@000000oooo0000003oool000000080ZZZZ
0P1EEED00`3oool0EEEE05EEE@020:ZZZP050000002ZZZX0EEEE05EEE@3oool00P1EEED20:ZZZP03
0000003oool000000080oooo0P1EEED30:ZZZP0:05EEE@2ZZZX0EEEE0000003oool0EEEE0?ooo`00
0000oooo05EEE@80ZZZZ00<0oooo0:ZZZP3oool00P2ZZZX00`3oool0dLfY0=7=Z@080=7=Z@030?oo
o`2ZZZX0ZZZZ00T0ZZZZ00<0EEEE0?ooo`0000000P1EEED;0?ooo`80EEEE00<0ZZZZ05EEE@1EEED0
0`1EEED20?ooo`@0EEEE00<0oooo0:ZZZP1EEED01@3oool010000000oooo0?ooo`0000030?ooo`80
EEEE00<000000?ooo`1EEED00P2ZZZX00`000000ZZZZ0:ZZZP060:ZZZP030?ooo`3AcJT0dLfY00P0
dLfY00<0oooo0:ZZZP2ZZZX00P3oool0202ZZZX0oooo0000002ZZZX0oooo05EEE@3oool0EEEE0`00
00020?ooo`050000003oool0EEEE0000002ZZZX00P1EEED20?ooo`0:05EEE@3oool0EEEE05EEE@2Z
ZZX0EEEE0000002ZZZX0oooo0:ZZZP80oooo00@0EEEE0000001EEED0ZZZZ0P1EEED03P3oool0EEEE
0?ooo`3oool0EEEE0?ooo`2ZZZX0000005EEE@3oool000000:ZZZP3oool0ZZZZ0`000000103oool0
EEEE0:ZZZP2ZZZX2000000030:ZZZP3oool0oooo0080ZZZZ00<0oooo0=7=Z@3AcJT0203AcJT00`3o
ool0ZZZZ0:ZZZP020?ooo`0305EEE@3oool0000000<0EEEE0P0000001P2ZZZX000000?ooo`3oool0
EEEE00000080EEEE0P000000102ZZZX0oooo0000000000020?ooo`030:ZZZP1EEED000000080EEEE
00<0ZZZZ05EEE@2ZZZX01`1EEED01P2ZZZX000000?ooo`3oool000000?ooo`<000000100ZZZZ05EE
E@000000ZZZZ0?ooo`2ZZZX000000:ZZZP1EEED0000005EEE@3oool0EEEE0000003oool0EEEE0P3o
ool20:ZZZP030?ooo`3AcJT0dLfY00X0dLfY000;0=7=Z@090?ooo`2ZZZX0oooo0?ooo`2ZZZX0oooo
05EEE@3oool0EEEE0080oooo00D0EEEE0:ZZZP3oool0EEEE0?ooo`0205EEE@050000001EEED00000
0:ZZZP3oool00P0000001P3oool000000?ooo`2ZZZX0oooo05EEE@<0oooo00<0ZZZZ0?ooo`3oool0
1@3oool00`2ZZZX0EEEE0?ooo`020?ooo`060:ZZZP3oool000000000003oool0ZZZZ0P1EEED20000
000405EEE@2ZZZX0EEEE0?ooo`80EEEE0P3oool01@1EEED0oooo05EEE@3oool0ZZZZ00@0oooo2P3A
cJT0103oool0ZZZZ0?ooo`3oool20:ZZZP80EEEE00<0ZZZZ0?ooo`3oool00P1EEED01`3oool0EEEE
0:ZZZP3oool0000005EEE@0000000`1EEED30?ooo`0305EEE@3oool0ZZZZ0080oooo00@000000?oo
o`2ZZZX0oooo0P2ZZZX01P3oool0ZZZZ05EEE@2ZZZX0oooo000000@0oooo00<0EEEE0?ooo`3oool0
101EEED00`000000EEEE0?ooo`020?ooo`0705EEE@3oool0EEEE05EEE@3oool000000:ZZZP0205EE
E@030:ZZZP3oool0oooo00<0oooo2P3AcJT00`3oool0ZZZZ0?ooo`050?ooo`80ZZZZ0P3oool01P1E
EED0oooo05EEE@2ZZZX0EEEE0?ooo`80EEEE0`3oool205EEE@050?ooo`1EEED0oooo05EEE@2ZZZX0
0P3oool010000000oooo0000003oool205EEE@<0oooo00T000000?ooo`3oool0ZZZZ05EEE@3oool0
EEEE0?ooo`1EEED0103oool405EEE@040?ooo`1EEED0oooo0:ZZZP<0oooo00D0ZZZZ0?ooo`2ZZZX0
oooo0:ZZZP040?ooo`X0dLfY00<0oooo0:ZZZP3oool00`3oool0102ZZZX0EEEE05EEE@1EEED20000
0080ZZZZ0P3oool00`2ZZZX0EEEE05EEE@030:ZZZP80oooo00D000000?ooo`000000000005EEE@02
0000000:0?ooo`000000oooo0:ZZZP000000ZZZZ0?ooo`000000EEEE0?ooo`@0000000D0EEEE0000
002ZZZX0oooo000000020?ooo`<0ZZZZ00D0EEEE0000002ZZZX0ZZZZ0?ooo`020:ZZZP8000000`1E
EED00`2ZZZX0oooo0?ooo`040?ooo`X0dLfY00D0oooo0:ZZZP000000oooo000000030?ooo`80EEEE
00<0oooo0:ZZZP2ZZZX00P3oool0101EEED0ZZZZ0:ZZZP3oool20:ZZZP030?ooo`2ZZZX0oooo0080
oooo00D0000005EEE@3oool0oooo0:ZZZP020?ooo`0;0000003oool0ZZZZ0?ooo`1EEED0ZZZZ0?oo
o`000000oooo05EEE@2ZZZX00P3oool205EEE@80oooo0P2ZZZX01`3oool0EEEE0:ZZZP3oool0EEEE
0:ZZZP1EEED00P3oool20:ZZZP030?ooo`2ZZZX0EEEE00<0oooo00<000000?ooo`0000000P3oool<
0=7=Z@002`3AcJT30?ooo`80ZZZZ00H0oooo05EEE@1EEED0EEEE0?ooo`1EEED20:ZZZP030?ooo`2Z
ZZX0ZZZZ0080oooo00L0000005EEE@000000EEEE0:ZZZP1EEED0oooo0080EEEE00T0ZZZZ0?ooo`3o
ool0oooo05EEE@000000EEEE0000001EEED00P3oool305EEE@060000001EEED0oooo0?ooo`1EEED0
ZZZZ0P1EEED01P3oool0ZZZZ0:ZZZP1EEED0oooo05EEE@8000000P3oool01P2ZZZX0oooo05EEE@2Z
ZZX0EEEE00000080EEEE00@000000?ooo`2ZZZX0ZZZZ0`3oool:0=7=Z@<0oooo00P0ZZZZ05EEE@1E
EED0EEEE0?ooo`1EEED0000005EEE@80ZZZZ0P0000020:ZZZP0<05EEE@3oool0EEEE05EEE@000000
EEEE0:ZZZP1EEED0000005EEE@2ZZZX0oooo0`0000002`3oool0EEEE000000000000ZZZZ05EEE@00
0000oooo05EEE@3oool0ZZZZ0080000000@0EEEE0:ZZZP1EEED000000`1EEED20000000305EEE@3o
ool0ZZZZ0080ZZZZ0P0000000`1EEED0ZZZZ05EEE@0205EEE@80oooo00<0EEEE0:ZZZP2ZZZX00`3o
ool:0=7=Z@<0oooo102ZZZX40?ooo`80ZZZZ0P00000205EEE@80oooo0P1EEED00`3oool0EEEE05EE
E@020?ooo`80EEEE1`3oool01@2ZZZX0EEEE0000002ZZZX0000000D0oooo00<0ZZZZ05EEE@3oool0
0P3oool205EEE@030?ooo`1EEED0EEEE0080oooo0P1EEED200000080ZZZZ103oool40:ZZZP<0oooo
2P3AcJT30?ooo`040:ZZZP000000EEEE05EEE@80oooo00L0EEEE0?ooo`2ZZZX000000?ooo`2ZZZX0
oooo0080000000D0EEEE0:ZZZP2ZZZX0oooo05EEE@02000000050:ZZZP00000000000:ZZZP1EEED0
0P0000001@3oool000000?ooo`3oool000000080oooo00<0EEEE0000003oool00P0000001@1EEED0
oooo0000003oool0ZZZZ0080000000@0EEEE0?ooo`3oool0ZZZZ0P1EEED2000000060:ZZZP3oool0
00000:ZZZP3oool000000`3oool00`1EEED0ZZZZ0:ZZZP030?ooo`X0dLfY0`3oool0102ZZZX00000
0:ZZZP1EEED30?ooo`030:ZZZP1EEED000000080oooo0P1EEED010000000oooo0?ooo`0000020?oo
o`80000000D0ZZZZ05EEE@3oool0oooo0:ZZZP020?ooo`0505EEE@3oool0ZZZZ0000003oool00P00
00020?ooo`0305EEE@000000oooo0080ZZZZ00<0oooo0000002ZZZX00P0000020?ooo`060:ZZZP3o
ool0oooo0?ooo`1EEED0ZZZZ0`3oool00`1EEED0ZZZZ0?ooo`030?ooo`030:ZZZP000000ZZZZ00<0
oooo303AcJT000/0dLfY1P3oool02@1EEED0ZZZZ0?ooo`3oool0EEEE0:ZZZP3oool000000:ZZZP02
05EEE@80oooo00@0EEEE0:ZZZP3oool0EEEE1@3oool0101EEED000000:ZZZP3oool30:ZZZP040?oo
o`1EEED0EEEE0?ooo`<0ZZZZ00H0EEEE0:ZZZP000000ZZZZ0?ooo`0000020?ooo`050000001EEED0
oooo0:ZZZP1EEED00P3oool01P1EEED0ZZZZ0:ZZZP000000EEEE0:ZZZP80EEEE00D0oooo0:ZZZP3o
ool0oooo0:ZZZP040?ooo`X0dLfY1@3oool0101EEED0ZZZZ0:ZZZP1EEED30:ZZZP0305EEE@3oool0
oooo008000000P1EEED01`3oool0ZZZZ0:ZZZP3oool0ZZZZ05EEE@3oool00P000000103oool0ZZZZ
0:ZZZP3oool205EEE@80oooo00<0ZZZZ05EEE@3oool00`1EEED00`3oool0ZZZZ0:ZZZP0200000080
oooo0P1EEED0103oool0ZZZZ0:ZZZP3oool205EEE@050000001EEED0oooo0?ooo`0000000P2ZZZX0
1P3oool0EEEE0:ZZZP2ZZZX0EEEE0:ZZZP@0oooo2P3AcJT>0?ooo`0305EEE@000000oooo0080EEEE
0P3oool205EEE@050?ooo`1EEED0EEEE0?ooo`0000000`1EEED00`3oool0EEEE05EEE@020?ooo`80
ZZZZ0P3oool605EEE@050000001EEED0EEEE05EEE@2ZZZX00P1EEED010000000oooo05EEE@1EEED2
0?ooo`0305EEE@3oool0ZZZZ00D0oooo00<0ZZZZ0?ooo`2ZZZX0103oool:0=7=Z@D0oooo0P2ZZZX0
1P3oool000000:ZZZP2ZZZX0EEEE0?ooo`80EEEE0P2ZZZX02@1EEED000000000002ZZZX0oooo0000
001EEED0oooo000000020:ZZZP030?ooo`000000oooo00<0oooo0`2ZZZX00`1EEED0ZZZZ05EEE@02
0?ooo`0505EEE@3oool000000000002ZZZX00P0000020?ooo`030000003oool0oooo0080000000<0
oooo0:ZZZP1EEED00P1EEED01`000000EEEE0:ZZZP2ZZZX000000?ooo`1EEED00P2ZZZX40?ooo`X0
dLfY103oool00`2ZZZX0oooo0?ooo`03000000050?ooo`2ZZZX0000005EEE@2ZZZX00P3oool305EE
E@<0oooo00<0EEEE0?ooo`3oool00P2ZZZX00`3oool0EEEE05EEE@03000000040?ooo`1EEED0oooo
0?ooo`80EEEE0P00000305EEE@030000002ZZZX0ZZZZ00D0oooo0`1EEED010000000oooo0000002Z
ZZX205EEE@030:ZZZP3oool0EEEE008000000P3oool00`2ZZZX0oooo0?ooo`020?ooo``0dLfY000;
0=7=Z@D0oooo0P2ZZZX010000000EEEE0:ZZZP3oool30:ZZZP0605EEE@000000oooo0:ZZZP3oool0
EEEE0P2ZZZX0103oool0ZZZZ0000000000030?ooo`80EEEE0`2ZZZX00`000000ZZZZ0?ooo`020:ZZ
ZP040000002ZZZX0ZZZZ0:ZZZP80EEEE00<000000?ooo`3oool00`000000103oool0ZZZZ0?ooo`1E
EED30?ooo`030000001EEED0ZZZZ0080ZZZZ00@0oooo0:ZZZP1EEED000000P2ZZZX50?ooo`X0dLfY
1@3oool20:ZZZP060?ooo`2ZZZX0EEEE05EEE@3oool000000P1EEED20:ZZZP<000000P3oool00`1E
EED000000:ZZZP0205EEE@070:ZZZP1EEED0oooo0:ZZZP1EEED0000005EEE@020000000305EEE@3o
ool000000080EEEE00@000000?ooo`2ZZZX0oooo0P2ZZZX00`3oool0EEEE0:ZZZP0205EEE@030?oo
o`00000000000080000000<0ZZZZ05EEE@1EEED00P1EEED01@3oool0EEEE0:ZZZP2ZZZX0oooo0080
ZZZZ1@3oool:0=7=Z@D0oooo202ZZZX20?ooo`80ZZZZ00<0EEEE0000003oool00P1EEED0103oool0
00000?ooo`3oool205EEE@<0oooo0P1EEED02@000000EEEE05EEE@3oool0ZZZZ05EEE@3oool00000
05EEE@030?ooo`80EEEE00<0ZZZZ0?ooo`3oool00P3oool205EEE@050?ooo`000000EEEE0:ZZZP00
00000P3oool80:ZZZPD0oooo2P3AcJT50?ooo`80ZZZZ0P3oool00`2ZZZX000000?ooo`020?ooo`05
05EEE@3oool0oooo0:ZZZP1EEED00P2ZZZX01@1EEED000000:ZZZP3oool0ZZZZ0080oooo00<0ZZZZ
0?ooo`1EEED01@1EEED20?ooo`0605EEE@2ZZZX0EEEE05EEE@2ZZZX0EEEE103oool0402ZZZX0oooo
0:ZZZP000000EEEE0?ooo`2ZZZX0EEEE0:ZZZP3oool0000005EEE@3oool000000?ooo`0000030?oo
o`80ZZZZ1@3oool:0=7=Z@D0oooo0P2ZZZX40?ooo`060:ZZZP1EEED000000000003oool0ZZZZ0P1E
EED01@000000EEEE0?ooo`3oool0EEEE0080oooo0P000000103oool0EEEE0000000000030?ooo`04
05EEE@3oool0oooo05EEE@<0oooo00<0EEEE0000001EEED00`0000060?ooo`030000001EEED0EEEE
0080ZZZZ0P000000103oool0ZZZZ0?ooo`1EEED20?ooo`80ZZZZ1@3oool<0=7=Z@002`3AcJT80?oo
o`H0EEEE102ZZZX00`1EEED000000:ZZZP0205EEE@040?ooo`2ZZZX0ZZZZ00000080ZZZZ0P000000
1@2ZZZX000000:ZZZP3oool0ZZZZ0080oooo0`2ZZZX01`000000ZZZZ000000000000oooo0:ZZZP3o
ool00P2ZZZX01@3oool0EEEE05EEE@1EEED000000080EEEE00D0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP02
05EEE@040:ZZZP1EEED0oooo0:ZZZPH0oooo2P3AcJT:0?ooo`0505EEE@2ZZZX0ZZZZ0?ooo`1EEED0
0P3oool01P2ZZZX0oooo0:ZZZP3oool000000:ZZZP80oooo0P2ZZZX00`3oool0ZZZZ05EEE@020:ZZ
ZP040?ooo`2ZZZX0oooo0?ooo`80EEEE00L0oooo05EEE@2ZZZX0oooo05EEE@2ZZZX0EEEE0080oooo
00H0EEEE0:ZZZP3oool0EEEE0:ZZZP0000020:ZZZP060?ooo`2ZZZX0oooo0:ZZZP1EEED0oooo0P2Z
ZZX01@1EEED0ZZZZ0?ooo`3oool0ZZZZ00H0oooo2P3AcJT80?ooo`070:ZZZP3oool0ZZZZ0?ooo`2Z
ZZX0oooo0000000205EEE@040?ooo`1EEED0oooo000000<0oooo0P1EEED00`000000oooo00000003
00000080oooo00H0EEEE0:ZZZP3oool0oooo0:ZZZP1EEED30?ooo`8000000P3oool305EEE@<0oooo
00D0EEEE0?ooo`1EEED0000005EEE@02000000<0oooo00D0ZZZZ0?ooo`2ZZZX0oooo0:ZZZP060?oo
o`X0dLfY2P3oool20:ZZZP0705EEE@000000EEEE0?ooo`2ZZZX0EEEE0:ZZZP020?ooo`040:ZZZP1E
EED0EEEE05EEE@<000000`3oool300000080oooo00<0ZZZZ0000003oool0100000020?ooo`040:ZZ
ZP000000ZZZZ000000<0EEEE00X0ZZZZ0?ooo`3oool0ZZZZ0000002ZZZX0000005EEE@000000EEEE
0P2ZZZX30?ooo`030:ZZZP3oool0oooo00@0oooo2P3AcJT60?ooo`070000003oool000000000003o
ool0000005EEE@020?ooo`80EEEE00@0ZZZZ05EEE@3oool0oooo0`000000103oool000000:ZZZP00
00030:ZZZP0305EEE@3oool000000080000000D0EEEE000000000000EEEE000000020?ooo`80ZZZZ
100000020?ooo`8000000P3oool0101EEED0oooo05EEE@1EEED20?ooo`030:ZZZP000000oooo0080
000000<0oooo0:ZZZP3oool01@3oool<0=7=Z@002`3AcJT60?ooo`050:ZZZP000000EEEE0:ZZZP3o
ool00P1EEED02`3oool0ZZZZ0000001EEED0ZZZZ0?ooo`1EEED0ZZZZ0?ooo`1EEED0ZZZZ0080EEEE
00<0ZZZZ0?ooo`3oool00P2ZZZX0103oool0ZZZZ0:ZZZP2ZZZX40?ooo`040000002ZZZX0ZZZZ0?oo
o`80ZZZZ0P3oool01@2ZZZX0EEEE05EEE@2ZZZX0EEEE0080oooo00X0EEEE0?ooo`3oool0EEEE0?oo
o`2ZZZX0oooo0:ZZZP1EEED0oooo0P1EEED00`000000oooo0?ooo`050?ooo`X0dLfY1P3oool0102Z
ZZX000000?ooo`3oool200000080ZZZZ00T0EEEE0000002ZZZX0oooo0:ZZZP000000ZZZZ0?ooo`2Z
ZZX00P1EEED20?ooo`0805EEE@3oool000000?ooo`2ZZZX0EEEE0:ZZZP3oool505EEE@050:ZZZP1E
EED0EEEE0?ooo`0000000P1EEED01P000000oooo05EEE@3oool0ZZZZ0?ooo`80000000H0ZZZZ0?oo
o`2ZZZX0oooo05EEE@2ZZZX3000000030:ZZZP3oool0000000L0oooo2P3AcJT60?ooo`030:ZZZP00
0000EEEE0080EEEE00<000000?ooo`3oool00P3oool200000080ZZZZ1@3oool01@000000oooo0?oo
o`3oool0EEEE0080oooo0P1EEED00`2ZZZX0oooo0?ooo`020?ooo`<0EEEE0P3oool01@1EEED0oooo
0?ooo`1EEED0000000@0oooo00H0EEEE0:ZZZP2ZZZX0EEEE0000001EEED20?ooo`030:ZZZP000000
EEEE0080EEEE00<000000?ooo`3oool01@3oool:0=7=Z@H0oooo00T0ZZZZ00000000000000000?oo
o`000000EEEE0000003oool00P1EEED00`2ZZZX0oooo0?ooo`020?ooo`030:ZZZP3oool0ZZZZ0080
EEEE00L0ZZZZ0000001EEED0EEEE0?ooo`1EEED0oooo0080EEEE00<0oooo0000001EEED00P3oool0
0`1EEED0oooo05EEE@0205EEE@060:ZZZP1EEED0EEEE0:ZZZP1EEED0ZZZZ103oool205EEE@80oooo
0`000000103oool0ZZZZ0000000000070?ooo`X0dLfY1P3oool20:ZZZP040000002ZZZX000000:ZZ
ZP<0oooo00H000000?ooo`3oool0ZZZZ05EEE@00000205EEE@080000002ZZZX0ZZZZ0:ZZZP000000
ZZZZ0?ooo`0000020:ZZZP80000000@0ZZZZ000000000000ZZZZ0P0000020:ZZZP050000003oool0
00000000003oool00P2ZZZX01P000000EEEE05EEE@000000EEEE0:ZZZPD0oooo00<000000:ZZZP00
00000P0000000`2ZZZX0oooo0?ooo`050?ooo``0dLfY000;0=7=Z@P0oooo00<0ZZZZ0?ooo`2ZZZX0
0P2ZZZX02@1EEED0oooo0?ooo`2ZZZX0oooo0000003oool0EEEE000000020?ooo`0605EEE@2ZZZX0
ZZZZ0000002ZZZX0EEEE0P3oool00`1EEED0oooo000000020?ooo`0505EEE@3oool0ZZZZ0?ooo`1E
EED00P3oool01P1EEED000000000003oool0ZZZZ05EEE@80oooo00H000000?ooo`3oool000000?oo
o`2ZZZX20?ooo`80EEEE0P2ZZZX00`3oool0ZZZZ0?ooo`070?ooo`X0dLfY203oool01P2ZZZX0EEEE
0:ZZZP2ZZZX0oooo05EEE@L0oooo00L000000:ZZZP3oool0EEEE0:ZZZP1EEED0oooo0080EEEE00L0
ZZZZ0?ooo`1EEED0oooo0000001EEED000000080EEEE0P3oool205EEE@0;0:ZZZP1EEED0oooo0?oo
o`1EEED0ZZZZ05EEE@3oool0ZZZZ0000002ZZZX0103oool0102ZZZX0oooo05EEE@1EEED20:ZZZP03
0?ooo`2ZZZX0oooo00L0oooo2P3AcJT80?ooo`030:ZZZP3oool0ZZZZ00D0oooo00<0EEEE0000002Z
ZZX00P3oool00`000000oooo000000030?ooo`0305EEE@3oool0EEEE0080EEEE00@0oooo05EEE@1E
EED0EEEE0P000000101EEED0oooo05EEE@3oool305EEE@030?ooo`1EEED0oooo00@0oooo00H00000
0?ooo`3oool0ZZZZ0?ooo`1EEED50?ooo`030:ZZZP3oool0ZZZZ00P0oooo2P3AcJT80?ooo`80ZZZZ
00<0EEEE0:ZZZP0000000`2ZZZX01@3oool0EEEE05EEE@1EEED0oooo0080ZZZZ00@000000:ZZZP3o
ool000000P2ZZZX0103oool000000000003oool2000000040?ooo`1EEED0ZZZZ0?ooo`80000000H0
oooo000000000000oooo05EEE@2ZZZX20?ooo`050:ZZZP3oool0ZZZZ0:ZZZP3oool00P1EEED00`2Z
ZZX0oooo0:ZZZP020:ZZZP050?ooo`2ZZZX0EEEE0?ooo`2ZZZX0203oool:0=7=Z@P0oooo00/0ZZZZ
0?ooo`3oool0oooo0:ZZZP3oool0EEEE0?ooo`000000oooo0:ZZZP0205EEE@<0ZZZZ00D0EEEE0:ZZ
ZP1EEED0ZZZZ05EEE@02000000080?ooo`000000000005EEE@2ZZZX0EEEE0?ooo`2ZZZX300000003
0?ooo`00000000000080ZZZZ00@0EEEE0:ZZZP1EEED0EEEE0`2ZZZX0201EEED0ZZZZ0?ooo`000000
oooo05EEE@3oool0ZZZZ0P3oool20:ZZZPP0oooo303AcJT000/0dLfY2@3oool01`000000EEEE0000
003oool0ZZZZ05EEE@2ZZZX00`3oool00`1EEED0oooo0:ZZZP040:ZZZP060?ooo`1EEED0oooo0:ZZ
ZP1EEED000000P3oool20:ZZZP030?ooo`1EEED0ZZZZ00<0oooo00H0ZZZZ05EEE@2ZZZX0oooo05EE
E@0000020:ZZZP0305EEE@2ZZZX0ZZZZ0080EEEE0`3oool01`000000EEEE0:ZZZP3oool0000005EE
E@2ZZZX02@3oool:0=7=Z@T0oooo00D0000005EEE@000000oooo0:ZZZP0205EEE@050:ZZZP1EEED0
ZZZZ0:ZZZP1EEED00P3oool01@000000oooo0?ooo`1EEED0oooo00<0EEEE00P000000?ooo`3oool0
oooo05EEE@3oool0ZZZZ05EEE@<0oooo00H0ZZZZ05EEE@1EEED0EEEE0?ooo`2ZZZX20?ooo`040:ZZ
ZP3oool0oooo05EEE@D0ZZZZ00H0EEEE0:ZZZP000000000005EEE@2ZZZX90?ooo`X0dLfY2@3oool0
0`000000EEEE05EEE@0505EEE@030:ZZZP3oool0oooo0080oooo00<0EEEE0?ooo`3oool00`3oool0
10000000oooo05EEE@3oool205EEE@80ZZZZ00@0oooo0:ZZZP2ZZZX0ZZZZ0P1EEED010000000EEEE
0?ooo`0000040?ooo`80EEEE103oool00`2ZZZX0EEEE05EEE@0505EEE@030:ZZZP3oool0oooo00L0
oooo2P3AcJT90?ooo`0<0000001EEED000000?ooo`2ZZZX0oooo0:ZZZP3oool0000005EEE@000000
ZZZZ0P3oool01@000000ZZZZ05EEE@2ZZZX0oooo0080000000H0ZZZZ0000002ZZZX000000:ZZZP3o
ool2000000030?ooo`2ZZZX0000000<0ZZZZ00D000000?ooo`3oool0ZZZZ05EEE@020:ZZZP80oooo
0P0000000`1EEED000000?ooo`020?ooo`80ZZZZ00<0000005EEE@2ZZZX02@3oool:0=7=Z@T0oooo
00@0000005EEE@000000oooo0P000000101EEED0oooo0?ooo`3oool20:ZZZP80oooo00<0EEEE0:ZZ
ZP3oool00`3oool01`1EEED0oooo0?ooo`3oool0EEEE0?ooo`0000000P2ZZZX00`000000oooo05EE
E@030?ooo`0505EEE@2ZZZX0oooo0000003oool00P2ZZZX20?ooo`0305EEE@2ZZZX0oooo0080oooo
0`000000102ZZZX0000005EEE@2ZZZX90?ooo``0dLfY000;0=7=Z@X0oooo00D0ZZZZ0?ooo`3oool0
EEEE0000000205EEE@030?ooo`1EEED0EEEE0080oooo00<0EEEE0:ZZZP0000000`3oool3000000<0
ZZZZ00<0EEEE0?ooo`3oool00P3oool30:ZZZP0:05EEE@00000000000000003oool0ZZZZ0?ooo`00
0000ZZZZ05EEE@80oooo101EEED00`3oool0000005EEE@020?ooo`030:ZZZP3oool0oooo00P0oooo
2P3AcJT:0?ooo`030:ZZZP3oool0oooo0080ZZZZ00H000000?ooo`2ZZZX0oooo05EEE@2ZZZX20?oo
o`80EEEE00<0oooo05EEE@1EEED00P3oool205EEE@<0ZZZZ00@0EEEE0000003oool0EEEE0`2ZZZX0
1`3oool0EEEE0?ooo`3oool0EEEE0:ZZZP3oool00P1EEED20?ooo`040000001EEED0oooo05EEE@80
oooo0P2ZZZX20?ooo`030:ZZZP3oool0oooo00P0oooo2P3AcJT:0?ooo`030:ZZZP3oool0ZZZZ00@0
oooo00@0ZZZZ0?ooo`3oool0EEEE0`3oool00`1EEED0oooo0?ooo`020:ZZZP030?ooo`2ZZZX0ZZZZ
0080EEEE00<0ZZZZ0?ooo`3oool00P3oool01P000000EEEE05EEE@000000ZZZZ0?ooo`80ZZZZ0P3o
ool00`1EEED0oooo0?ooo`040?ooo`030:ZZZP3oool0ZZZZ00@0oooo00<0ZZZZ0?ooo`3oool0203o
ool:0=7=Z@X0oooo00<0ZZZZ0?ooo`3oool00P3oool01`2ZZZX0EEEE05EEE@1EEED000000:ZZZP00
00000P1EEED2000000050:ZZZP000000oooo05EEE@2ZZZX00`000000102ZZZX0EEEE0:ZZZP3oool2
05EEE@80000000H0EEEE0:ZZZP1EEED0EEEE0000003oool2000000030?ooo`1EEED0000000800000
0`1EEED00`2ZZZX0oooo0?ooo`020?ooo`030:ZZZP3oool0oooo00P0oooo2P3AcJT:0?ooo`040:ZZ
ZP0000000000000000<0oooo0P2ZZZX20?ooo`040000003oool0EEEE0:ZZZP@000000P1EEED00`00
0000EEEE000000030?ooo`040000003oool0EEEE000000@0EEEE100000020:ZZZP060?ooo`000000
oooo0?ooo`2ZZZX0EEEE0`3oool010000000oooo0000002ZZZX:0?ooo``0dLfY000;0=7=Z@/0oooo
00@0ZZZZ05EEE@2ZZZX0oooo0`0000020?ooo`040:ZZZP1EEED0ZZZZ0?ooo`80ZZZZ00H0EEEE0?oo
o`3oool0oooo05EEE@2ZZZX30?ooo`@0EEEE00T0ZZZZ0?ooo`3oool0oooo05EEE@3oool0EEEE0?oo
o`1EEED00P2ZZZX0103oool0ZZZZ05EEE@0000020?ooo`80000000D0ZZZZ0?ooo`2ZZZX000000:ZZ
ZP0;0?ooo`X0dLfY2`3oool00`2ZZZX0oooo0:ZZZP020?ooo`80EEEE0P2ZZZX30?ooo`030000003o
ool000000080ZZZZ00h0EEEE0:ZZZP2ZZZX0EEEE0?ooo`000000EEEE0000003oool0ZZZZ0000001E
EED000000?ooo`H0ZZZZ00<000000?ooo`3oool00P3oool30:ZZZP80EEEE0P3oool00`2ZZZX00000
0:ZZZP0;0?ooo`X0dLfY2`3oool02`2ZZZX0EEEE05EEE@1EEED000000:ZZZP3oool0ZZZZ0000002Z
ZZX0oooo0080000000<0oooo05EEE@1EEED0101EEED00`000000ZZZZ0:ZZZP050?ooo`<0ZZZZ00@0
000005EEE@1EEED000000`1EEED02@3oool000000000003oool0EEEE0000002ZZZX0oooo0:ZZZP03
05EEE@030000002ZZZX0oooo00X0oooo2P3AcJT;0?ooo`030:ZZZP000000ZZZZ00D0000000D0EEEE
0?ooo`2ZZZX0ZZZZ05EEE@020?ooo`80EEEE00D0oooo0000003oool0oooo05EEE@020?ooo`030000
002ZZZX0oooo0080000000H0oooo05EEE@000000oooo0000002ZZZX205EEE@80oooo0`2ZZZX02P3o
ool0EEEE0000001EEED000000?ooo`000000ZZZZ0000002ZZZX;0?ooo`X0dLfY2`3oool0102ZZZX0
00000000002ZZZX2000000030?ooo`2ZZZX000000080000000/0ZZZZ05EEE@3oool0EEEE0?ooo`1E
EED0oooo05EEE@2ZZZX0EEEE0?ooo`020:ZZZP040000001EEED0EEEE00000080ZZZZ0P3oool01`2Z
ZZX0EEEE0?ooo`1EEED0oooo05EEE@3oool00P2ZZZX02@000000EEEE0000002ZZZX0oooo0000001E
EED0ZZZZ000000020:ZZZP/0oooo303AcJT000/0dLfY303oool20:ZZZP030000003oool0oooo00<0
oooo00@0EEEE0000001EEED0ZZZZ0P3oool0101EEED0oooo0:ZZZP00000205EEE@040:ZZZP000000
00000:ZZZP80000000@0ZZZZ05EEE@000000ZZZZ0P1EEED010000000EEEE0?ooo`2ZZZX20?ooo`03
0000001EEED0000000<0oooo00@0EEEE0?ooo`1EEED000000P2ZZZX<0?ooo`X0dLfY303oool00`2Z
ZZX0EEEE05EEE@0405EEE@040000001EEED0oooo05EEE@<0oooo00L0000005EEE@3oool0000005EE
E@000000oooo00<0ZZZZ0P3oool30:ZZZP030?ooo`000000EEEE008000000P1EEED20?ooo`80EEEE
00<0oooo05EEE@0000000`1EEED0103oool0EEEE05EEE@2ZZZX<0?ooo`X0dLfY303oool40:ZZZP<0
oooo00<0ZZZZ0000000000000`0000001@3oool000000?ooo`1EEED0000000<0oooo00<0ZZZZ0?oo
o`3oool0103oool01@2ZZZX0oooo05EEE@3oool0000000@0oooo00@0000005EEE@00000000000P2Z
ZZX30?ooo`@0ZZZZ303oool:0=7=Z@`0oooo00P0ZZZZ0000001EEED0EEEE0?ooo`000000EEEE0?oo
o`80000000H0oooo000000000000ZZZZ05EEE@2ZZZX20?ooo`0:05EEE@2ZZZX0ZZZZ0:ZZZP1EEED0
00000:ZZZP3oool0000005EEE@80ZZZZ0P1EEED20?ooo`030:ZZZP3oool0ZZZZ0080000000D0oooo
0000002ZZZX0oooo05EEE@030?ooo`0305EEE@000000ZZZZ00`0oooo2P3AcJT<0?ooo`80000000<0
ZZZZ05EEE@3oool00P3oool20:ZZZP030?ooo`2ZZZX0oooo0080oooo00D000000?ooo`3oool0oooo
000000020:ZZZP030000002ZZZX0000000<0000000D0oooo0000002ZZZX0ZZZZ000000030?ooo`06
0000003oool0oooo0000002ZZZX0oooo0P2ZZZX40?ooo`030:ZZZP000000ZZZZ00`0oooo303AcJT0
00/0dLfY3@3oool01`2ZZZX0000005EEE@2ZZZX0oooo05EEE@2ZZZX00P1EEED00`2ZZZX0EEEE05EE
E@0205EEE@80ZZZZ00T0EEEE0:ZZZP3oool000000:ZZZP000000ZZZZ0000001EEED00`2ZZZX01P00
0000ZZZZ0:ZZZP1EEED0oooo0:ZZZP@0EEEE00@0ZZZZ05EEE@3oool0ZZZZ0P1EEED0102ZZZX0EEEE
0000002ZZZX=0?ooo`X0dLfY3@3oool0102ZZZX0000000000000000205EEE@80ZZZZ0P0000001@3o
ool000000000001EEED0oooo00<0ZZZZ00L0EEEE0:ZZZP2ZZZX0EEEE0?ooo`1EEED0ZZZZ0080oooo
0P2ZZZX01@1EEED0ZZZZ0:ZZZP1EEED0oooo00<0000000H0EEEE000000000000EEEE0:ZZZP1EEED2
0000000305EEE@000000ZZZZ00d0oooo2P3AcJT=0?ooo`030:ZZZP000000EEEE00@0EEEE00<00000
0:ZZZP0000001P3oool00`2ZZZX0oooo000000020:ZZZP80oooo00<0EEEE0?ooo`3oool00`2ZZZX2
0?ooo`030:ZZZP000000oooo00<0oooo0P0000000`2ZZZX0EEEE05EEE@0405EEE@030000002ZZZX0
oooo00`0oooo2P3AcJT=0?ooo`030:ZZZP00000000000080ZZZZ0P3oool205EEE@8000000`3oool2
05EEE@040:ZZZP1EEED0ZZZZ00000080ZZZZ00<0000005EEE@0000000P000000202ZZZX000000:ZZ
ZP1EEED0ZZZZ0000001EEED000000P3oool20000000305EEE@2ZZZX0oooo0080oooo00@0ZZZZ05EE
E@000000ZZZZ3@3oool:0=7=Z@d0oooo00@0ZZZZ000000000000ZZZZ0P0000000`2ZZZX0EEEE05EE
E@030:ZZZP050?ooo`000000oooo05EEE@3oool00P0000040?ooo`030000002ZZZX0oooo00@0oooo
00X000000?ooo`3oool0oooo05EEE@3oool0ZZZZ05EEE@2ZZZX0EEEE0P2ZZZX2000000040:ZZZP1E
EED000000:ZZZPd0oooo303AcJT000/0dLfY3P3oool30:ZZZP030000003oool0oooo008000001P2Z
ZZX0103oool0EEEE0:ZZZP1EEED30?ooo`030:ZZZP1EEED0oooo0080ZZZZ0P3oool0101EEED0ZZZZ
05EEE@0000060:ZZZP050000002ZZZX0oooo0?ooo`0000000`2ZZZX>0?ooo`X0dLfY3P3oool20:ZZ
ZP050?ooo`2ZZZX0ZZZZ0:ZZZP1EEED00P3oool20:ZZZP070?ooo`2ZZZX0ZZZZ0?ooo`000000EEEE
0:ZZZP0205EEE@80ZZZZ0P1EEED20:ZZZP80EEEE00@0oooo05EEE@000000EEEE0P2ZZZX00`3oool0
ZZZZ05EEE@020?ooo`050000002ZZZX0ZZZZ0:ZZZP3oool00P2ZZZX>0?ooo`X0dLfY3P3oool70:ZZ
ZP<0oooo101EEED20?ooo`090:ZZZP1EEED0000005EEE@000000ZZZZ0000003oool0ZZZZ0080EEEE
0P0000001@2ZZZX0oooo0?ooo`1EEED0oooo00<0EEEE0P3oool70:ZZZPh0oooo2P3AcJT>0?ooo`80
ZZZZ0P3oool00`2ZZZX00000000000020?ooo`050000003oool0ZZZZ0:ZZZP3oool00P0000000`3o
ool0ZZZZ0?ooo`020:ZZZP030?ooo`2ZZZX0ZZZZ0080oooo00/0ZZZZ0?ooo`3oool0oooo0000001E
EED0oooo0000002ZZZX0oooo05EEE@030?ooo`040000002ZZZX0oooo0?ooo`80ZZZZ3P3oool:0=7=
Z@h0oooo0P2ZZZX00`3oool0EEEE0?ooo`020?ooo`0505EEE@2ZZZX0ZZZZ05EEE@2ZZZX00`3oool0
1P000000EEEE05EEE@000000ZZZZ00000080EEEE00D0oooo05EEE@2ZZZX0ZZZZ0000000205EEE@06
0000003oool0oooo05EEE@2ZZZX0EEEE0P2ZZZX00`1EEED0ZZZZ0?ooo`030?ooo`80ZZZZ3P3oool<
0=7=Z@002`3AcJTA0?ooo`0;0:ZZZP3oool000000:ZZZP3oool0ZZZZ0?ooo`2ZZZX0oooo0:ZZZP3o
ool00P1EEED2000000060:ZZZP1EEED0EEEE0:ZZZP000000EEEE0P2ZZZX01@1EEED0ZZZZ00000000
0000EEEE00@0oooo00X0ZZZZ0?ooo`2ZZZX0oooo0:ZZZP000000oooo0:ZZZP3oool0ZZZZ3`3oool:
0=7=ZA40oooo00<0ZZZZ0?ooo`3oool00P2ZZZX01`1EEED000000:ZZZP2ZZZX0EEEE0000003oool0
0P2ZZZX305EEE@030000001EEED0EEEE00D0EEEE0`2ZZZX20000000505EEE@2ZZZX0ZZZZ0:ZZZP1E
EED00P2ZZZX40?ooo`030:ZZZP3oool0oooo00d0oooo2P3AcJTC0?ooo`040:ZZZP3oool0ZZZZ0000
0080oooo0P0000040?ooo`80ZZZZ00P0oooo000000000000oooo0:ZZZP000000EEEE0?ooo`80ZZZZ
1@3oool02`000000oooo0?ooo`000000ZZZZ0?ooo`2ZZZX0oooo0:ZZZP3oool0ZZZZ00l0oooo2P3A
cJTC0?ooo`030:ZZZP1EEED0EEEE0080000000<0oooo0:ZZZP2ZZZX00P3oool01@1EEED0000005EE
E@1EEED000000080oooo00D0ZZZZ0?ooo`3oool0ZZZZ0000000205EEE@030000001EEED000000080
oooo00D0ZZZZ0?ooo`1EEED0000005EEE@020:ZZZP<0oooo00<0ZZZZ0?ooo`3oool03@3oool:0=7=
Z@l0oooo00h000000?ooo`00000000000?ooo`2ZZZX0EEEE0?ooo`1EEED0oooo0:ZZZP1EEED00000
05EEE@@0oooo00<0EEEE0?ooo`3oool00P0000001@3oool0EEEE05EEE@3oool000000080oooo0P00
0000203oool0ZZZZ0?ooo`1EEED0oooo05EEE@000000oooo0P0000000`3oool0ZZZZ0?ooo`0>0?oo
o``0dLfY000;0=7=ZA00oooo0P2ZZZX0303oool000000?ooo`3oool0ZZZZ0?ooo`2ZZZX0EEEE0:ZZ
ZP3oool0EEEE000000@0oooo00D0EEEE0:ZZZP3oool0oooo0:ZZZP030?ooo`050:ZZZP3oool00000
05EEE@3oool00P1EEED01`2ZZZX0EEEE0:ZZZP3oool0EEEE0000003oool00P2ZZZX@0?ooo`X0dLfY
403oool0302ZZZX0EEEE05EEE@3oool0ZZZZ0?ooo`2ZZZX0EEEE0?ooo`1EEED0ZZZZ0?ooo`<0EEEE
00<0ZZZZ0?ooo`2ZZZX00P1EEED20?ooo`0405EEE@3oool0ZZZZ0?ooo`<0EEEE00D000000?ooo`3o
ool0EEEE0?ooo`020:ZZZP<0oooo00<0EEEE0:ZZZP2ZZZX0403oool:0=7=ZA00oooo102ZZZX30?oo
o`050000003oool0EEEE05EEE@3oool00P1EEED01@2ZZZX0EEEE0?ooo`000000ZZZZ00D0oooo00L0
00000?ooo`3oool0ZZZZ05EEE@2ZZZX0oooo0080EEEE103oool50:ZZZQ00oooo2P3AcJT@0?ooo`03
0:ZZZP000000EEEE00<0oooo00<0000005EEE@0000000P0000001@3oool0EEEE0:ZZZP2ZZZX0EEEE
008000000P3oool205EEE@040?ooo`2ZZZX00000000000<0ZZZZ00<000000?ooo`1EEED00P000000
1P1EEED000000?ooo`1EEED0oooo05EEE@80ZZZZ403oool:0=7=ZA00oooo00@0ZZZZ0000002ZZZX0
oooo0P0000001P1EEED000000:ZZZP2ZZZX0oooo00000080oooo00H0ZZZZ0?ooo`3oool0oooo0000
003oool2000000070?ooo`1EEED0oooo0?ooo`1EEED0ZZZZ0?ooo`020000000;0?ooo`2ZZZX0ZZZZ
0000001EEED000000:ZZZP3oool0ZZZZ0000002ZZZX0403oool<0=7=Z@002`3AcJTD0?ooo`030:ZZ
ZP000000oooo0080ZZZZ00@000000:ZZZP2ZZZX0oooo0P2ZZZX205EEE@040?ooo`1EEED000000?oo
o`80000000@0EEEE0?ooo`1EEED0EEEE0P2ZZZX02@1EEED0ZZZZ000000000000ZZZZ05EEE@3oool0
000005EEE@020?ooo`030:ZZZP3oool0oooo00l0oooo2P3AcJTB0?ooo`0605EEE@2ZZZX0EEEE05EE
E@3oool0EEEE0P2ZZZX205EEE@040?ooo`000000oooo0?ooo`80EEEE0P2ZZZX0101EEED0ZZZZ0:ZZ
ZP2ZZZX205EEE@050000003oool000000?ooo`1EEED00`2ZZZX00`000000oooo05EEE@020:ZZZP03
05EEE@2ZZZX0oooo0100oooo2P3AcJTC0?ooo`030:ZZZP3oool0oooo0080oooo101EEED01P000000
oooo0?ooo`000000ZZZZ0?ooo`80000000D0oooo000000000000ZZZZ0?ooo`020:ZZZP80oooo0P1E
EED00`2ZZZX0EEEE05EEE@040?ooo`030:ZZZP3oool0ZZZZ0140oooo2P3AcJTB0?ooo`040:ZZZP1E
EED0oooo000000<0ZZZZ00@0oooo05EEE@1EEED0oooo0`0000001@3oool0EEEE0:ZZZP000000EEEE
00<0000000<0EEEE0?ooo`3oool00P000000103oool0EEEE0:ZZZP3oool30:ZZZP030000002ZZZX0
EEEE0080ZZZZ4@3oool:0=7=ZA40oooo00<0ZZZZ0?ooo`3oool00P2ZZZX30?ooo`030:ZZZP1EEED0
00000080EEEE0P2ZZZX01@000000ZZZZ0?ooo`3oool0EEEE0080oooo00<0EEEE0:ZZZP0000000P2Z
ZZX205EEE@80000000D0ZZZZ0?ooo`1EEED0oooo0:ZZZP030?ooo`030:ZZZP3oool0oooo00l0oooo
303AcJT000/0dLfY4P3oool20:ZZZP070000001EEED0ZZZZ05EEE@3oool0EEEE0000000205EEE@03
0:ZZZP3oool000000080ZZZZ00<0000005EEE@3oool00P1EEED30:ZZZP80oooo00D0ZZZZ0?ooo`1E
EED0ZZZZ05EEE@020?ooo`030:ZZZP1EEED0ZZZZ0080ZZZZ4P3oool:0=7=ZA80oooo0P2ZZZX0103o
ool0ZZZZ0000002ZZZX305EEE@<0ZZZZ00<0EEEE0:ZZZP2ZZZX00P2ZZZX20?ooo`0305EEE@3oool0
ZZZZ00<0ZZZZ00@0EEEE0:ZZZP2ZZZX0ZZZZ0`1EEED00`3oool000000:ZZZP030:ZZZQ80oooo2P3A
cJTB0?ooo`L0ZZZZ0`000000102ZZZX0EEEE0000001EEED20?ooo`030000003oool0oooo0080oooo
00D0ZZZZ0?ooo`3oool0oooo0000000205EEE@<000001`2ZZZXB0?ooo`X0dLfY4P3oool20:ZZZP<0
oooo00@000000?ooo`000000ZZZZ0P3oool00`2ZZZX0EEEE000000020?ooo`030000001EEED0EEEE
0080EEEE00`0ZZZZ0?ooo`3oool0000005EEE@2ZZZX0EEEE0?ooo`2ZZZX000000?ooo`2ZZZX20?oo
o`<0ZZZZ4P3oool:0=7=ZA80oooo0P2ZZZX50?ooo`80000000@0oooo0000003oool0ZZZZ0P1EEED0
3P3oool000000:ZZZP2ZZZX000000:ZZZP000000oooo05EEE@3oool0ZZZZ0?ooo`2ZZZX0oooo0P00
0000103oool0EEEE0?ooo`3oool30:ZZZQ80oooo303AcJT000/0dLfY4`3oool02@2ZZZX0oooo05EE
E@2ZZZX0000005EEE@2ZZZX0oooo05EEE@020000000305EEE@2ZZZX0oooo0080oooo00<0ZZZZ0?oo
o`1EEED00P2ZZZX20?ooo`070:ZZZP1EEED000000:ZZZP1EEED0oooo0:ZZZP0205EEE@040:ZZZP1E
EED0oooo0:ZZZQ<0oooo2P3AcJTC0?ooo`040:ZZZP3oool0oooo0:ZZZPL0EEEE00H000000:ZZZP00
000000000:ZZZP0000020?ooo`@0000000@0ZZZZ0000001EEED0ZZZZ101EEED20:ZZZP80oooo00<0
ZZZZ0?ooo`3oool04@3oool:0=7=ZA<0oooo00D0ZZZZ0?ooo`2ZZZX0oooo0:ZZZP040?ooo`090000
001EEED0oooo0?ooo`000000ZZZZ0?ooo`1EEED0oooo0080EEEE00<0oooo0:ZZZP0000000P3oool2
05EEE@030?ooo`1EEED0oooo00<0oooo00<0ZZZZ0?ooo`2ZZZX04`3oool:0=7=ZA<0oooo00@0ZZZZ
0?ooo`3oool0oooo0P2ZZZX305EEE@040000002ZZZX0EEEE0?ooo`80EEEE1@2ZZZX01`000000EEEE
05EEE@3oool0EEEE0:ZZZP0000000`1EEED00`2ZZZX0oooo0?ooo`020?ooo`030:ZZZP3oool0oooo
0140oooo2P3AcJTC0?ooo`040:ZZZP3oool00000000000D0oooo0P2ZZZX200000080oooo00@0EEEE
0?ooo`3oool0EEEE1@3oool01@000000ZZZZ0?ooo`3oool0EEEE00<0oooo0`0000000`2ZZZX0oooo
0?ooo`0A0?ooo``0dLfY000;0=7=ZA@0oooo00D0000005EEE@1EEED0oooo0:ZZZP0205EEE@80oooo
0P2ZZZX02P000000ZZZZ0?ooo`1EEED0ZZZZ0?ooo`1EEED0ZZZZ0000003oool50:ZZZP030?ooo`1E
EED0EEEE0080ZZZZ0P1EEED00`2ZZZX0oooo0?ooo`0B0?ooo`X0dLfY503oool010000000oooo0:ZZ
ZP3oool40000000305EEE@2ZZZX0oooo0080oooo00@0EEEE0?ooo`2ZZZX0EEEE0P2ZZZX02@3oool0
EEEE0?ooo`2ZZZX0oooo0:ZZZP3oool000000?ooo`02000000040?ooo`2ZZZX0oooo0:ZZZQ@0oooo
2P3AcJTD0?ooo`060000001EEED0EEEE05EEE@000000ZZZZ0P1EEED20:ZZZP030000002ZZZX0ZZZZ
00@0oooo00d000000?ooo`3oool0oooo0:ZZZP1EEED000000:ZZZP3oool0EEEE0?ooo`2ZZZX00000
00<0EEEE00<0ZZZZ0?ooo`3oool04P3oool:0=7=ZA@0oooo0P0000000`2ZZZX0oooo000000030000
00060?ooo`000000000005EEE@3oool0ZZZZ1P1EEED00`2ZZZX0oooo05EEE@020000000305EEE@00
0000EEEE00<0000000<0ZZZZ0000002ZZZX0503oool:0=7=ZA@0oooo00@0ZZZZ000000000000EEEE
0P0000030?ooo`030:ZZZP000000EEEE00<0EEEE0P3oool00`000000oooo0:ZZZP0205EEE@800000
00@0ZZZZ0?ooo`3oool0oooo0P000000102ZZZX000000000002ZZZXD0?ooo``0dLfY000;0=7=ZAD0
oooo00D0ZZZZ0?ooo`2ZZZX0ZZZZ05EEE@030000000505EEE@3oool0ZZZZ0?ooo`0000000P3oool0
0`1EEED0ZZZZ0?ooo`02000000<0oooo00H0EEEE000000000000oooo05EEE@2ZZZX20?ooo`030:ZZ
ZP3oool0oooo01<0oooo2P3AcJTE0?ooo`030:ZZZP3oool0ZZZZ00@0ZZZZ00L0EEEE0?ooo`000000
EEEE0:ZZZP1EEED0000000@0ZZZZ0P1EEED0102ZZZX0oooo0000003oool20:ZZZP0605EEE@2ZZZX0
ZZZZ05EEE@3oool0ZZZZ5@3oool:0=7=ZAD0oooo00<0ZZZZ0?ooo`2ZZZX0103oool00`1EEED00000
0:ZZZP020?ooo`8000001@3oool01P000000oooo05EEE@2ZZZX0000005EEE@H0oooo00<0ZZZZ0?oo
o`3oool04`3oool:0=7=ZAD0oooo00D0ZZZZ0?ooo`1EEED0ZZZZ0?ooo`020:ZZZP0A05EEE@000000
oooo0000003oool0000005EEE@000000EEEE0?ooo`000000oooo0000003oool000000?ooo`000000
0P2ZZZX01P000000oooo0:ZZZP2ZZZX0oooo0:ZZZQD0oooo2P3AcJTE0?ooo`80ZZZZ0P3oool01P00
0000EEEE0000001EEED000000:ZZZP80oooo00<000000:ZZZP0000000`0000001`2ZZZX000000?oo
o`3oool0ZZZZ0000003oool00`0000020?ooo`80ZZZZ5@3oool<0=7=Z@002`3AcJTF0?ooo`030:ZZ
ZP1EEED000000080oooo00@0EEEE0?ooo`1EEED0ZZZZ0P1EEED01P3oool0EEEE05EEE@000000oooo
05EEE@80oooo00H0EEEE0:ZZZP2ZZZX0EEEE0?ooo`1EEED20?ooo`80000000<0ZZZZ0?ooo`3oool0
503oool:0=7=ZAH0oooo00X0ZZZZ05EEE@00000000000?ooo`1EEED000000?ooo`2ZZZX0EEEE0P00
00001P3oool0EEEE05EEE@000000EEEE0?ooo`8000000P2ZZZX00`3oool0000005EEE@0400000003
0:ZZZP3oool0oooo01@0oooo2P3AcJTF0?ooo`030:ZZZP1EEED0EEEE00<0EEEE00<0ZZZZ0?ooo`2Z
ZZX00P1EEED20?ooo`0405EEE@3oool0EEEE05EEE@80oooo00@0EEEE0?ooo`2ZZZX0oooo1@1EEED0
0`000000ZZZZ0?ooo`0E0?ooo`X0dLfY5P3oool00`2ZZZX0EEEE000000020:ZZZP050?ooo`2ZZZX0
EEEE05EEE@3oool00P1EEED20:ZZZP8000000P2ZZZX205EEE@030?ooo`1EEED0EEEE00<0oooo00@0
ZZZZ000000000000ZZZZ5P3oool:0=7=ZAH0oooo00@0ZZZZ05EEE@000000ZZZZ0P0000020:ZZZP@0
oooo00<0EEEE0?ooo`1EEED00P3oool00`1EEED0oooo0?ooo`020?ooo`80ZZZZ0P000000102ZZZX0
00000000002ZZZXF0?ooo``0dLfY000;0=7=ZAL0oooo00@0ZZZZ0?ooo`3oool0EEEE0`000000103o
ool0EEEE0?ooo`3oool20:ZZZP80oooo00T0ZZZZ0?ooo`3oool0oooo05EEE@3oool000000:ZZZP00
00006`3oool:0=7=ZAL0oooo00P0ZZZZ0?ooo`3oool0ZZZZ0?ooo`1EEED0oooo0:ZZZP80EEEE00P0
oooo0:ZZZP3oool0EEEE0000003oool0EEEE0?ooo`80EEEE00<0ZZZZ0?ooo`1EEED0703oool:0=7=
ZAL0oooo00<0ZZZZ0?ooo`3oool00`3oool20:ZZZP040?ooo`000000000005EEE@@0oooo00@0EEEE
000000000000oooo0`2ZZZX00`3oool0ZZZZ0?ooo`0I0?ooo`X0dLfY5`3oool00`2ZZZX0oooo0?oo
o`020?ooo`030:ZZZP1EEED0EEEE0080EEEE0P3oool205EEE@060000001EEED0oooo0?ooo`1EEED0
00000P1EEED00`2ZZZX0oooo0?ooo`0J0?ooo`X0dLfY5`3oool00`2ZZZX000000?ooo`0300000003
0:ZZZP1EEED0EEEE00<0EEEE00@000000:ZZZP00000000001@1EEED01P2ZZZX0oooo000000000000
oooo000001P0oooo303AcJT000/0dLfY603oool00`2ZZZX000000:ZZZP020?ooo`80ZZZZ00@0oooo
0:ZZZP000000ZZZZ1@3oool00`000000ZZZZ05EEE@030:ZZZP040?ooo`1EEED000000:ZZZQP0oooo
2P3AcJTH0?ooo`030:ZZZP000000ZZZZ0080oooo00<000000:ZZZP2ZZZX00P2ZZZX01P000000oooo
0:ZZZP2ZZZX0oooo05EEE@@0ZZZZ0P0000020?ooo`030000002ZZZX0oooo01L0oooo2P3AcJTH0?oo
o`060:ZZZP000000EEEE05EEE@000000ZZZZ0`0000000`1EEED0oooo0?ooo`030?ooo`030000001E
EED000000080000000H0ZZZZ05EEE@1EEED0EEEE0000002ZZZXH0?ooo`X0dLfY603oool00`2ZZZX0
00000:ZZZP040000000<0?ooo`2ZZZX0EEEE0:ZZZP1EEED000000?ooo`1EEED0ZZZZ05EEE@2ZZZX0
EEEE0P0000001@3oool00000000000000000ZZZZ01P0oooo2P3AcJTH0?ooo`80ZZZZ00H000000:ZZ
ZP2ZZZX000000?ooo`0000050?ooo`0305EEE@3oool0000000@0oooo0P000000102ZZZX000000:ZZ
ZP2ZZZXH0?ooo``0dLfY000;0=7=ZAT0oooo0P2ZZZX01@000000oooo05EEE@000000ZZZZ0080oooo
00<0EEEE0:ZZZP1EEED00P2ZZZX00`1EEED0oooo0?ooo`0200000080EEEE00<000000:ZZZP2ZZZX0
6@3oool:0=7=ZAT0oooo00<0ZZZZ05EEE@1EEED00P3oool305EEE@040:ZZZP3oool0oooo0:ZZZP80
oooo00D0EEEE0:ZZZP1EEED0000005EEE@020?ooo`0305EEE@2ZZZX0ZZZZ01T0oooo2P3AcJTI0?oo
o`@0ZZZZ103oool0101EEED000000000003oool30000000305EEE@3oool0EEEE0080oooo102ZZZXI
0?ooo`X0dLfY6@3oool01@2ZZZX0000005EEE@1EEED0oooo0080000000<0EEEE0:ZZZP3oool00P2Z
ZZX0101EEED0ZZZZ0?ooo`2ZZZX205EEE@040000003oool0oooo05EEE@80ZZZZ6@3oool:0=7=ZAT0
oooo00@0ZZZZ0000002ZZZX0ZZZZ0`0000002@1EEED0ZZZZ0000003oool0ZZZZ05EEE@3oool00000
0:ZZZP0205EEE@80000000@0oooo0:ZZZP000000ZZZZ6@3oool<0=7=Z@002`3AcJTJ0?ooo`040:ZZ
ZP000000EEEE0:ZZZP80EEEE102ZZZX0101EEED0oooo0:ZZZP3oool20:ZZZP80EEEE00<0ZZZZ05EE
E@0000006`3oool:0=7=ZAX0oooo00P0ZZZZ00000000000000000?ooo`1EEED0ZZZZ0?ooo`80EEEE
00/000000:ZZZP1EEED0ZZZZ0?ooo`2ZZZX0EEEE0?ooo`000000EEEE0000000K0?ooo`X0dLfY6P3o
ool00`2ZZZX0000005EEE@0305EEE@80oooo0P0000020?ooo`030000003oool0oooo0080oooo0`1E
EED00`000000oooo0?ooo`0I0?ooo`X0dLfY6P3oool01@2ZZZX000000000002ZZZX0oooo0080EEEE
00D000000:ZZZP1EEED0EEEE0:ZZZP0205EEE@070000001EEED0ZZZZ0?ooo`2ZZZX0EEEE0000000K
0?ooo`X0dLfY6P3oool01@2ZZZX000000000002ZZZX0oooo0080000000P0oooo0:ZZZP3oool0oooo
0000003oool0ZZZZ0?ooo`80000000@0oooo0:ZZZP1EEED000006`3oool<0=7=Z@002`3AcJTK0?oo
o`<0ZZZZ0P0000020:ZZZP0605EEE@3oool000000000003oool000000P2ZZZX2000000<0ZZZZ6`3o
ool:0=7=ZA/0oooo0P2ZZZX0103oool0ZZZZ05EEE@2ZZZX205EEE@80oooo00P0ZZZZ0?ooo`2ZZZX0
EEEE0:ZZZP000000ZZZZ0?ooo`80ZZZZ6`3oool:0=7=ZA/0oooo102ZZZX405EEE@D0oooo0P1EEED5
0:ZZZQ/0oooo2P3AcJTK0?ooo`80ZZZZ0P3oool0102ZZZX0EEEE0?ooo`3oool2000000050?ooo`00
000000000?ooo`1EEED00`3oool20:ZZZQ/0oooo2P3AcJTK0?ooo`80ZZZZ0P3oool01@1EEED0oooo
0?ooo`2ZZZX000000080EEEE00<000000?ooo`3oool0103oool20:ZZZQ/0oooo303AcJT000/0dLfY
703oool0202ZZZX0000005EEE@000000oooo05EEE@3oool0ZZZZ0P3oool01`2ZZZX0EEEE05EEE@3o
ool0000005EEE@0000007@3oool:0=7=ZA`0oooo00<0ZZZZ0000003oool00P3oool20:ZZZP@0oooo
0P2ZZZX0103oool0ZZZZ0?ooo`00000M0?ooo`X0dLfY703oool02@2ZZZX0000005EEE@3oool0EEEE
0?ooo`1EEED0oooo05EEE@020?ooo`0305EEE@3oool0EEEE0080EEEE00<000000?ooo`3oool06`3o
ool:0=7=ZA`0oooo00D0ZZZZ00000000000000000?ooo`0200000080oooo00H000000?ooo`3oool0
00000?ooo`2ZZZX2000001d0oooo2P3AcJTL0?ooo`80ZZZZ00L000000:ZZZP1EEED000000?ooo`1E
EED0oooo0080EEEE0P000000101EEED000000000002ZZZXM0?ooo``0dLfY000;0=7=ZAd0oooo0P2Z
ZZX01P3oool0ZZZZ0000002ZZZX0EEEE0?ooo`80EEEE0P0000040:ZZZQd0oooo2P3AcJTM0?ooo`80
ZZZZ00H0EEEE0?ooo`1EEED0oooo05EEE@3oool205EEE@040000001EEED0oooo05EEE@80ZZZZ7@3o
ool:0=7=ZAd0oooo0`2ZZZX205EEE@060000001EEED000000:ZZZP1EEED0oooo0P1EEED30:ZZZQd0
oooo2P3AcJTM0?ooo`80ZZZZ00@0EEEE0?ooo`1EEED0EEEE0P3oool01P1EEED0oooo0?ooo`1EEED0
oooo00000080ZZZZ7@3oool:0=7=ZAd0oooo00D0ZZZZ0000002ZZZX0oooo05EEE@030?ooo`050000
003oool0oooo05EEE@3oool00P0000000`2ZZZX0oooo0?ooo`0K0?ooo``0dLfY000;0=7=ZAh0oooo
00@0ZZZZ0?ooo`3oool0ZZZZ0`3oool010000000oooo0:ZZZP2ZZZX20?ooo`030:ZZZP3oool0oooo
01`0oooo2P3AcJTN0?ooo`060:ZZZP1EEED0ZZZZ0:ZZZP3oool000000P3oool01P000000ZZZZ0:ZZ
ZP2ZZZX0oooo0:ZZZQh0oooo2P3AcJTN0?ooo`030:ZZZP3oool0ZZZZ0080EEEE0P3oool01`2ZZZX0
oooo0?ooo`1EEED0ZZZZ0?ooo`2ZZZX07P3oool:0=7=ZAh0oooo0P2ZZZX01P1EEED0ZZZZ0000003o
ool0EEEE0:ZZZP80oooo00@0ZZZZ05EEE@3oool0ZZZZ7P3oool:0=7=ZAh0oooo00H0ZZZZ0?ooo`3o
ool0oooo0000001EEED20?ooo`0405EEE@000000oooo0?ooo`80ZZZZ7P3oool<0=7=Z@002`3AcJTO
0?ooo`<0ZZZZ0P0000020?ooo`8000000P2ZZZXP0?ooo`X0dLfY7`3oool30:ZZZP0305EEE@2ZZZX0
EEEE0080ZZZZ00<0oooo0:ZZZP2ZZZX0803oool:0=7=ZAl0oooo0`2ZZZX00`000000EEEE0?ooo`02
05EEE@030000002ZZZX0ZZZZ0200oooo2P3AcJTO0?ooo`<0ZZZZ0P3oool20:ZZZP80oooo0P2ZZZXP
0?ooo`X0dLfY7`3oool30:ZZZP060?ooo`1EEED0oooo0?ooo`1EEED0oooo0P2ZZZXP0?ooo``0dLfY
000;0=7=ZB00oooo00<0ZZZZ0?ooo`1EEED01P3oool00`2ZZZX0oooo0?ooo`0N0?ooo`X0dLfY803o
ool0102ZZZX0oooo0?ooo`00000205EEE@040000003oool0oooo0:ZZZR00oooo2P3AcJTP0?ooo`03
0:ZZZP3oool0EEEE0080oooo00D000000?ooo`3oool0oooo0:ZZZP0P0?ooo`X0dLfY803oool01@2Z
ZZX0oooo0?ooo`3oool0ZZZZ00@0oooo00<0ZZZZ0?ooo`3oool07P3oool:0=7=ZB00oooo00D0ZZZZ
00000000000000000?ooo`02000000030?ooo`000000ZZZZ0200oooo303AcJT000/0dLfY8@3oool0
0`2ZZZX0EEEE05EEE@0305EEE@030000002ZZZX0oooo0200oooo2P3AcJTQ0?ooo`030:ZZZP3oool0
ZZZZ00<0ZZZZ00<000000:ZZZP3oool0803oool:0=7=ZB40oooo00P0ZZZZ05EEE@3oool0oooo05EE
E@3oool000000:ZZZR40oooo2P3AcJTQ0?ooo`080:ZZZP000000ZZZZ0?ooo`000000ZZZZ0000002Z
ZZXQ0?ooo`X0dLfY8@3oool01P2ZZZX00000000000000000ZZZZ00000080ZZZZ8@3oool<0=7=Z@00
2`3AcJTR0?ooo`030:ZZZP3oool0ZZZZ02D0oooo2P3AcJTR0?ooo`040:ZZZP3oool0ZZZZ05EEEB@0
oooo2P3AcJTR0?ooo`030:ZZZP3oool0000002D0oooo2P3AcJTR0?ooo`040:ZZZP3oool0EEEE0:ZZ
ZR@0oooo2P3AcJTR0?ooo`80ZZZZ0P3oool00`2ZZZX0oooo0?ooo`0Q0?ooo``0dLfY000;0=7=ZB<0
oooo00@0ZZZZ05EEE@000000ZZZZ8`3oool:0=7=ZB<0oooo00@0ZZZZ05EEE@000000ZZZZ8`3oool:
0=7=ZB<0oooo00@0ZZZZ05EEE@000000ZZZZ8`3oool:0=7=ZB<0oooo00@0ZZZZ05EEE@000000ZZZZ
8`3oool:0=7=ZB<0oooo00@0ZZZZ05EEE@000000ZZZZ8`3oool<0=7=Z@002`3AcJTT0?ooo`030:ZZ
ZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZ
ZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZ
ZP3oool0oooo02<0oooo303AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0
dLfY/P3AcJT00?l0dLfY/P3AcJT000/0dLfY00D0oooo0:ZZZP2ZZZX000000?ooo`0400000080EEEE
00@0000005EEE@1EEED0EEEE1@3oool20:ZZZP0405EEE@3oool0oooo05EEE@80oooo00<0EEEE0?oo
o`3oool00`1EEED50?ooo`<0EEEE0`3oool01@000000oooo0000001EEED0oooo0080EEEE0P2ZZZX4
0?ooo`050:ZZZP1EEED0EEEE0:ZZZP0000000P1EEED4000000050?ooo`000000ZZZZ0:ZZZP3oool0
2P3AcJT0103oool0ZZZZ0:ZZZP0000060:ZZZP060000003oool0ZZZZ05EEE@3oool0EEEE0`3oool0
4@1EEED0ZZZZ05EEE@2ZZZX000000?ooo`000000ZZZZ0000003oool000000?ooo`1EEED0ZZZZ0?oo
o`2ZZZX000000080oooo00@0000005EEE@3oool0ZZZZ0P3oool04@000000EEEE0000001EEED00000
0?ooo`000000ZZZZ05EEE@000000EEEE0?ooo`1EEED0oooo0000003oool0EEEE0080oooo00<00000
0?ooo`2ZZZX00`2ZZZX01@3oool000000:ZZZP2ZZZX0oooo00X0dLfY00D0oooo0:ZZZP000000oooo
05EEE@020:ZZZP0305EEE@00000000000080EEEE00<0oooo0:ZZZP1EEED01@00000305EEE@<00000
00@0EEEE000000000000EEEE0P00000205EEE@060?ooo`2ZZZX000000?ooo`2ZZZX0oooo0P1EEED0
0`2ZZZX0000005EEE@02000000040?ooo`000000000000000080EEEE00@0ZZZZ000000000000ZZZZ
0P0000000`1EEED0ZZZZ05EEE@0205EEE@80000000P0EEEE0:ZZZP2ZZZX000000?ooo`000000ZZZZ
0?ooo`X0dLfY00<0oooo0000002ZZZX00`3oool20:ZZZP030?ooo`000000ZZZZ00d0ZZZZ101EEED9
0:ZZZP0305EEE@2ZZZX0ZZZZ00H0ZZZZ101EEED?0:ZZZP060?ooo`2ZZZX0ZZZZ0?ooo`2ZZZX0oooo
0P2ZZZX00`3oool0dLfY0=7=Z@080=7=Z@030?ooo`2ZZZX0ZZZZ0080000000@0oooo0:ZZZP2ZZZX0
EEEE0P3oool0202ZZZX0EEEE05EEE@3oool0EEEE0:ZZZP3oool0EEEE103oool0202ZZZX0oooo0000
001EEED0ZZZZ05EEE@3oool000000P2ZZZX00`1EEED0oooo0?ooo`040?ooo`0705EEE@2ZZZX0oooo
0000003oool0EEEE0:ZZZP02000000070?ooo`1EEED0oooo0?ooo`1EEED0oooo05EEE@020:ZZZP80
oooo00@0EEEE0?ooo`2ZZZX0oooo0P1EEED00`2ZZZX0EEEE0?ooo`0200000080ZZZZ00<0oooo0=7=
Z@3AcJT02P3AcJT000/0dLfY00<0oooo0:ZZZP1EEED01@3oool305EEE@040?ooo`2ZZZX000000?oo
o`80EEEE00H0ZZZZ0000001EEED0ZZZZ05EEE@3oool305EEE@80oooo101EEED3000000030:ZZZP1E
EED0EEEE0080ZZZZ0P00000305EEE@<0oooo0`1EEED01@3oool0EEEE0?ooo`1EEED000000080EEEE
00<0ZZZZ0?ooo`0000000P3oool01@1EEED0oooo05EEE@3oool0EEEE00<0oooo00<0EEEE0?ooo`3o
ool02P3AcJT00`3oool0ZZZZ05EEE@020?ooo`030:ZZZP3oool0ZZZZ0080oooo0P0000020:ZZZP80
EEEE00<0oooo0:ZZZP2ZZZX00P0000000`3oool0ZZZZ000000020:ZZZP050000003oool0ZZZZ0000
001EEED00`2ZZZX20?ooo`040000001EEED0oooo00000080ZZZZ0P1EEED200000080oooo0P2ZZZX0
201EEED0ZZZZ0?ooo`3oool000000:ZZZP000000oooo0P1EEED20:ZZZP8000000P3oool00`2ZZZX0
oooo0:ZZZP020?ooo`0305EEE@3oool0oooo00X0dLfY00L0oooo0:ZZZP1EEED000000:ZZZP1EEED0
ZZZZ00@0EEEE00P0ZZZZ05EEE@00000000000?ooo`000000EEEE0:ZZZP80000000<0oooo05EEE@1E
EED00P1EEED010000000oooo0000003oool20:ZZZP040?ooo`000000000000000080EEEE00@00000
0:ZZZP000000oooo0P2ZZZX00`3oool000000?ooo`0505EEE@040?ooo`1EEED000000:ZZZPD00000
00<0EEEE0:ZZZP1EEED00`1EEED01@3oool0EEEE05EEE@000000EEEE0080oooo2P3AcJT0103oool0
ZZZZ0000002ZZZX205EEE@030:ZZZP1EEED0EEEE00l0ZZZZ100000070:ZZZP80000000<0ZZZZ0000
002ZZZX01P2ZZZX010000000ZZZZ00000000000>0:ZZZPH0EEEE00@0ZZZZ0000003oool0oooo2P3A
cJT00`3oool0ZZZZ0?ooo`030?ooo`@0000000<0oooo0:ZZZP0000000`3oool00`000000oooo05EE
E@020:ZZZP80EEEE103oool0102ZZZX0EEEE0:ZZZP2ZZZX2000000P0oooo00L000000?ooo`2ZZZX0
ZZZZ0?ooo`2ZZZX0EEEE0080oooo00<0ZZZZ05EEE@1EEED00P2ZZZX00`1EEED00000000000040?oo
o`030:ZZZP3oool0ZZZZ008000000P3oool00`1EEED0oooo0?ooo`020?ooo``0dLfY000;0=7=Z@<0
oooo0P2ZZZX01`1EEED0oooo0?ooo`1EEED0oooo05EEE@3oool00P2ZZZX01P000000oooo0?ooo`2Z
ZZX000000:ZZZP@0oooo0P1EEED20?ooo`<000000P1EEED020000000EEEE0?ooo`1EEED0ZZZZ0?oo
o`2ZZZX000000P1EEED2000000030:ZZZP3oool0EEEE00<0EEEE0P3oool02P000000ZZZZ0000002Z
ZZX0oooo05EEE@000000ZZZZ05EEE@3oool305EEE@030?ooo`2ZZZX0EEEE0080ZZZZ0`3oool:0=7=
Z@<0oooo0P2ZZZX0103oool0ZZZZ0:ZZZP2ZZZX20?ooo`80000000@0EEEE0?ooo`000000EEEE0P2Z
ZZX02`000000oooo0:ZZZP1EEED0ZZZZ0000001EEED0ZZZZ0000002ZZZX0EEEE0080oooo00@00000
0:ZZZP2ZZZX0ZZZZ0P3oool30:ZZZP0;0000003oool0oooo05EEE@2ZZZX000000:ZZZP1EEED00000
0?ooo`1EEED00P2ZZZX010000000ZZZZ0:ZZZP1EEED20?ooo`80EEEE00<000000?ooo`2ZZZX00`2Z
ZZX00`3oool0ZZZZ0:ZZZP030?ooo`X0dLfY0`3oool01`2ZZZX000000000002ZZZX000000:ZZZP1E
EED00P000000102ZZZX0oooo0000002ZZZX200000080oooo0P2ZZZX01@1EEED0oooo0?ooo`1EEED0
oooo00<0ZZZZ00@000000:ZZZP1EEED000000P3oool01@1EEED0ZZZZ0?ooo`3oool000000080EEEE
00<000000:ZZZP0000000P2ZZZX01@1EEED0oooo0:ZZZP1EEED0ZZZZ00<0oooo00D0EEEE0000002Z
ZZX000000?ooo`04000000040:ZZZP000000EEEE00000080ZZZZ0`3oool:0=7=Z@<0oooo0P2ZZZX2
0?ooo`030:ZZZP3oool0ZZZZ00H0ZZZZ00<0EEEE0:ZZZP2ZZZX01@2ZZZX010000000ZZZZ0:ZZZP00
00080:ZZZP030000001EEED0ZZZZ00L0ZZZZ0P0000000`2ZZZX000000:ZZZP050:ZZZP80EEEE1`2Z
ZZX01P3oool0ZZZZ0:ZZZP3oool000000:ZZZP<0oooo2P3AcJT30?ooo`040:ZZZP000000ZZZZ0000
00<0oooo00H0ZZZZ0?ooo`1EEED0EEEE0?ooo`1EEED20?ooo`0305EEE@3oool0oooo0080oooo00<0
EEEE0?ooo`2ZZZX0103oool205EEE@050:ZZZP1EEED0ZZZZ05EEE@2ZZZX0101EEED00`2ZZZX0oooo
05EEE@030?ooo`80ZZZZ103oool02`1EEED0oooo05EEE@000000oooo05EEE@3oool0EEEE0:ZZZP3o
ool0ZZZZ00<0oooo102ZZZX30?ooo``0dLfY000;0=7=Z@@0oooo00D0EEEE0?ooo`2ZZZX000000:ZZ
ZP0200000080EEEE00<0ZZZZ0?ooo`0000000`2ZZZX0103oool0EEEE0000002ZZZX205EEE@030?oo
o`1EEED0ZZZZ0080oooo0`1EEED01P3oool000000:ZZZP3oool0EEEE0:ZZZP80oooo00T0EEEE0?oo
o`1EEED0oooo05EEE@2ZZZX0EEEE0?ooo`1EEED00P2ZZZX00`000000oooo0?ooo`040:ZZZP040?oo
o`2ZZZX0oooo05EEE@80000000D0ZZZZ0000001EEED0oooo0:ZZZP040?ooo`X0dLfY103oool01@1E
EED0oooo0?ooo`3oool0000000<0oooo0P1EEED00`3oool0EEEE0:ZZZP030:ZZZP80oooo00<0ZZZZ
0000001EEED00`2ZZZX00`3oool0ZZZZ000000020:ZZZP030?ooo`2ZZZX0oooo00D0oooo00D0ZZZZ
000000000000ZZZZ0?ooo`030:ZZZP0305EEE@000000ZZZZ0080oooo102ZZZX010000000oooo05EE
E@1EEED30?ooo`050000003oool000000?ooo`2ZZZX0103oool:0=7=Z@@0oooo00P0EEEE0000002Z
ZZX0ZZZZ0?ooo`1EEED000000:ZZZP80000000@0ZZZZ0?ooo`2ZZZX000000`1EEED200000080EEEE
00H000000?ooo`3oool0000005EEE@0000020:ZZZP<0EEEE0P0000000`1EEED0000005EEE@020:ZZ
ZP030000001EEED000000080oooo00<0000005EEE@0000000`00000205EEE@80ZZZZ00H0EEEE0:ZZ
ZP000000EEEE0:ZZZP0000020?ooo`80ZZZZ00<000000:ZZZP3oool00`3oool:0=7=Z@@0oooo00@0
00000:ZZZP1EEED0EEEE0`2ZZZX01P000000ZZZZ0:ZZZP000000ZZZZ00000080ZZZZ00<000000:ZZ
ZP2ZZZX00P2ZZZX010000000oooo0?ooo`0000080:ZZZP800000202ZZZX010000000EEEE0?ooo`00
00040:ZZZP060000002ZZZX000000000002ZZZX000000P2ZZZX010000000ZZZZ0000002ZZZX205EE
E@80ZZZZ103oool:0=7=Z@D0oooo00<0ZZZZ0?ooo`1EEED0101EEED2000000070:ZZZP1EEED0ZZZZ
0?ooo`000000oooo0:ZZZP0205EEE@030000003oool0ZZZZ00D0oooo00D0ZZZZ0000001EEED00000
0:ZZZP02000000030:ZZZP1EEED0EEEE008000001@3oool00`2ZZZX0oooo0?ooo`0305EEE@080?oo
o`000000ZZZZ0:ZZZP3oool0ZZZZ0000002ZZZX205EEE@040:ZZZP1EEED0EEEE0?ooo`80ZZZZ103o
ool<0=7=Z@002`3AcJT40?ooo`070:ZZZP000000oooo05EEE@3oool0ZZZZ0?ooo`020:ZZZP80oooo
1P2ZZZX00`3oool0ZZZZ0?ooo`0205EEE@050?ooo`1EEED0ZZZZ0000002ZZZX00P1EEED00`000000
ZZZZ0?ooo`0205EEE@080?ooo`2ZZZX0000005EEE@000000ZZZZ0000002ZZZX505EEE@030:ZZZP3o
ool0000000@0ZZZZ0`3oool020000000ZZZZ0?ooo`2ZZZX0oooo05EEE@2ZZZX000001@3oool:0=7=
Z@@0oooo00@0ZZZZ0000001EEED0EEEE0P2ZZZX02@000000ZZZZ0?ooo`2ZZZX0000005EEE@2ZZZX0
oooo000000040?ooo`080:ZZZP3oool000000?ooo`2ZZZX0EEEE0:ZZZP3oool30:ZZZP<0000000<0
ZZZZ0000000000000`2ZZZX0203oool0ZZZZ05EEE@2ZZZX0oooo0000003oool0ZZZZ103oool02000
0000oooo0:ZZZP2ZZZX000000:ZZZP000000ZZZZ0P000000102ZZZX0EEEE0:ZZZP0000050?ooo`X0
dLfY103oool0202ZZZX00000000000000000EEEE0000003oool000000P2ZZZX01@3oool0000005EE
E@000000oooo0080EEEE00<0ZZZZ0000002ZZZX00P1EEED01`000000EEEE05EEE@1EEED0oooo0:ZZ
ZP3oool00P1EEED0102ZZZX0oooo0:ZZZP2ZZZX205EEE@<0oooo1`1EEED01P000000ZZZZ05EEE@1E
EED0oooo00000080EEEE00D0oooo0:ZZZP3oool000000?ooo`0205EEE@030000001EEED0000000D0
oooo2P3AcJT40?ooo`050:ZZZP00000000000000002ZZZX00P3oool30:ZZZP050000001EEED0ZZZZ
0?ooo`1EEED01P2ZZZX205EEE@P0ZZZZ00@000000?ooo`2ZZZX00000202ZZZX00`000000EEEE0:ZZ
ZP050:ZZZP0905EEE@2ZZZX0ZZZZ0?ooo`000000ZZZZ0000002ZZZX0oooo0080ZZZZ00<000000:ZZ
ZP0000001@3oool:0=7=Z@@0oooo00P0ZZZZ0000003oool0EEEE0:ZZZP3oool000000?ooo`80ZZZZ
0P3oool00`000000oooo05EEE@020?ooo`080000003oool0oooo05EEE@000000oooo0000003oool2
05EEE@060?ooo`2ZZZX0ZZZZ0:ZZZP3oool0EEEE0P3oool30:ZZZP080?ooo`1EEED0EEEE05EEE@00
0000ZZZZ0000001EEED20?ooo`80000000@0oooo05EEE@00000000000P3oool01P2ZZZX0oooo0?oo
o`000000oooo0:ZZZP80EEEE00<000000?ooo`3oool00`3oool<0=7=Z@002`3AcJT60?ooo`0505EE
E@3oool0oooo05EEE@0000000`3oool70:ZZZP030000002ZZZX0ZZZZ00<0oooo00D0EEEE0?ooo`3o
ool000000?ooo`0305EEE@80oooo00<0EEEE0?ooo`2ZZZX00`1EEED00`000000oooo0:ZZZP0205EE
E@80oooo0P2ZZZX00`000000ZZZZ0:ZZZP050:ZZZP040?ooo`000000oooo000000<0oooo00<0ZZZZ
0?ooo`3oool0103oool:0=7=Z@H0oooo00H0EEEE0?ooo`1EEED0EEEE0?ooo`0000020:ZZZP0;0000
003oool0oooo0?ooo`2ZZZX0oooo0:ZZZP1EEED0ZZZZ0?ooo`2ZZZX00P0000000`2ZZZX0oooo0?oo
o`020?ooo`0305EEE@000000oooo0080000000D0EEEE0000003oool0000005EEE@030?ooo`<0ZZZZ
00L000000:ZZZP2ZZZX0ZZZZ05EEE@000000oooo0080ZZZZ00/0oooo0:ZZZP000000ZZZZ0?ooo`00
0000oooo0:ZZZP1EEED0oooo0:ZZZP060?ooo`X0dLfY1P3oool00`1EEED000000?ooo`020:ZZZP05
05EEE@2ZZZX0000005EEE@0000000P3oool20:ZZZP030000003oool0ZZZZ00@0ZZZZ00H0oooo05EE
E@3oool0oooo0:ZZZP3oool2000000@0oooo00@0EEEE0000003oool0ZZZZ0P3oool00`2ZZZX0oooo
05EEE@040:ZZZP050?ooo`000000ZZZZ0:ZZZP0000000P3oool01@1EEED0000005EEE@1EEED0ZZZZ
0080oooo00<000000:ZZZP3oool01@3oool:0=7=Z@H0oooo00<000000:ZZZP1EEED00`1EEED30:ZZ
ZP80000000<0EEEE0:ZZZP2ZZZX0102ZZZX010000000ZZZZ0:ZZZP0000070:ZZZP@0EEEE1`2ZZZX0
10000000oooo0:ZZZP0000070:ZZZP8000000P2ZZZX505EEE@80ZZZZ1P3oool:0=7=Z@P0oooo00<0
EEEE0?ooo`0000000P1EEED030000000ZZZZ0:ZZZP1EEED0ZZZZ0?ooo`2ZZZX0EEEE0?ooo`000000
oooo0:ZZZP<0oooo100000001@2ZZZX000000:ZZZP000000oooo00@0000000@0ZZZZ000000000000
0000103oool01`2ZZZX0oooo0000003oool0EEEE0:ZZZP3oool00P1EEED02P3oool0ZZZZ0000003o
ool0EEEE0000003oool0EEEE0?ooo`2ZZZX60?ooo``0dLfY000;0=7=Z@H0oooo00@0ZZZZ0000002Z
ZZX0EEEE0P3oool01P1EEED000000?ooo`000000oooo0:ZZZP@0oooo00<0EEEE0?ooo`1EEED00P00
0000102ZZZX0oooo0?ooo`3oool205EEE@030?ooo`2ZZZX0ZZZZ0080000000<0ZZZZ05EEE@3oool0
0P1EEED30?ooo`80ZZZZ00H0000005EEE@2ZZZX0EEEE0?ooo`2ZZZX60?ooo`070000003oool0oooo
0?ooo`1EEED0ZZZZ000000070?ooo`X0dLfY1P3oool00`2ZZZX000000:ZZZP0205EEE@060000002Z
ZZX0ZZZZ0:ZZZP1EEED000000P3oool010000000ZZZZ0?ooo`0000020?ooo`80000000<0oooo0000
001EEED00`1EEED30?ooo`80EEEE0`3oool0101EEED0000005EEE@1EEED20?ooo`8000000P3oool0
10000000oooo05EEE@0000020?ooo`030000003oool0ZZZZ0080ZZZZ00D0000005EEE@3oool0ZZZZ
000000070?ooo`X0dLfY1P3oool00`2ZZZX0000005EEE@0200000080EEEE00<0ZZZZ000000000000
0P1EEED2000000030:ZZZP00000000000080000000@0EEEE0?ooo`3oool000000P1EEED00`000000
EEEE05EEE@050?ooo`<0EEEE00<0000005EEE@1EEED00P3oool010000000EEEE0000001EEED20000
000305EEE@00000000000080EEEE00H0ZZZZ0000002ZZZX0oooo05EEE@00000205EEE@030000003o
ool0oooo00D0oooo2P3AcJT60?ooo`060:ZZZP000000ZZZZ0000002ZZZX000000`2ZZZX0103oool0
ZZZZ0:ZZZP0000060:ZZZP80EEEE0P2ZZZX00`000000ZZZZ000000030:ZZZP040000002ZZZX00000
000000D0ZZZZ00<000000:ZZZP2ZZZX00P1EEED60:ZZZP800000102ZZZX2000000040:ZZZP000000
ZZZZ000000L0oooo2P3AcJT60?ooo`030:ZZZP000000oooo0080oooo0P1EEED20?ooo`0;0000001E
EED000000:ZZZP3oool000000?ooo`1EEED0000005EEE@2ZZZX00`1EEED40?ooo`060:ZZZP3oool0
oooo0?ooo`1EEED0oooo0P2ZZZX00`3oool0EEEE0?ooo`020?ooo`0605EEE@2ZZZX0ZZZZ05EEE@3o
ool0EEEE0`3oool0102ZZZX0EEEE05EEE@2ZZZX20?ooo`030:ZZZP1EEED0oooo0080oooo00<00000
0?ooo`3oool01@3oool<0=7=Z@002`3AcJT70?ooo`80ZZZZ00@0EEEE0:ZZZP1EEED0EEEE0`3oool0
101EEED0oooo0?ooo`3oool2000000040?ooo`1EEED0EEEE0?ooo`80ZZZZ00@000000:ZZZP1EEED0
oooo0P1EEED20:ZZZP040?ooo`2ZZZX0ZZZZ0:ZZZP@0EEEE0`2ZZZX20?ooo`0405EEE@2ZZZX0oooo
000000<0oooo00<0000005EEE@3oool00P3oool205EEE@@0ZZZZ1`3oool:0=7=Z@L0oooo0P2ZZZX0
0`000000oooo0:ZZZP030:ZZZP070000003oool0EEEE05EEE@000000oooo05EEE@02000000080:ZZ
ZP000000ZZZZ0000002ZZZX0oooo0000001EEED20:ZZZP030000002ZZZX0EEEE0080ZZZZ00X00000
0:ZZZP2ZZZX0ZZZZ0000003oool0ZZZZ0000001EEED000000P2ZZZX01`000000EEEE0:ZZZP000000
EEEE0000003oool01@2ZZZX0103oool0ZZZZ0:ZZZP2ZZZX70?ooo`X0dLfY1`3oool20:ZZZP030?oo
o`000000000000<0ZZZZ00D0oooo05EEE@2ZZZX0EEEE000000020:ZZZP070?ooo`000000EEEE0:ZZ
ZP000000EEEE000000020:ZZZP0605EEE@2ZZZX0ZZZZ0:ZZZP000000ZZZZ0`0000020:ZZZP030000
002ZZZX0ZZZZ00<0EEEE00@0ZZZZ05EEE@2ZZZX0oooo0P2ZZZX01@000000EEEE05EEE@1EEED0oooo
0080ZZZZ100000020:ZZZPL0oooo2P3AcJT70?ooo`060:ZZZP000000oooo0:ZZZP3oool000000`2Z
ZZX00`1EEED0oooo000000060:ZZZP030000002ZZZX000000080ZZZZ00<0EEEE0000002ZZZX00`2Z
ZZX010000000oooo0:ZZZP0000020:ZZZP040?ooo`1EEED0ZZZZ0:ZZZP<000001P2ZZZX010000000
EEEE05EEE@0000030:ZZZP050?ooo`2ZZZX0ZZZZ0000002ZZZX01`3oool:0=7=Z@L0oooo102ZZZX0
10000000oooo0?ooo`3oool30:ZZZP<0oooo00D0EEEE0000003oool0oooo000000020?ooo`80EEEE
0P2ZZZX02P1EEED0ZZZZ05EEE@3oool0ZZZZ05EEE@3oool000000:ZZZP1EEED20:ZZZP0305EEE@00
0000oooo0080000000@0oooo05EEE@000000EEEE0`3oool20:ZZZP<0oooo0P000000102ZZZX00000
0:ZZZP2ZZZX70?ooo``0dLfY000;0=7=Z@T0oooo00<000000:ZZZP3oool00`2ZZZX205EEE@030?oo
o`00000000000080000000<0EEEE0?ooo`3oool01@2ZZZX00`000000ZZZZ0:ZZZP030?ooo`800000
0`3oool00`2ZZZX00000000000050:ZZZP80oooo00<0EEEE0000000000000`0000001P1EEED0oooo
0:ZZZP2ZZZX0EEEE0?ooo`80ZZZZ2@3oool:0=7=Z@T0oooo00@000000:ZZZP00000000000P2ZZZX0
0`000000ZZZZ0:ZZZP0305EEE@050?ooo`1EEED0oooo0?ooo`2ZZZX00P1EEED01P2ZZZX000000:ZZ
ZP1EEED0oooo0:ZZZP80oooo00H0ZZZZ0000003oool0oooo0:ZZZP3oool20:ZZZP8000000P1EEED0
1@2ZZZX0oooo0000001EEED0oooo00<0EEEE00<0oooo0:ZZZP2ZZZX00P2ZZZX200000080ZZZZ2@3o
ool:0=7=Z@T0oooo00L0000005EEE@3oool0ZZZZ0000001EEED0ZZZZ0080EEEE00<0oooo0:ZZZP1E
EED00P2ZZZX20000000405EEE@2ZZZX0EEEE0?ooo`80000000@0ZZZZ05EEE@1EEED000000P1EEED0
0`000000EEEE0000000205EEE@040?ooo`00000000000:ZZZP<0EEEE010000000?ooo`2ZZZX0ZZZZ
0000002ZZZX0oooo0000001EEED0ZZZZ05EEE@000000ZZZZ0?ooo`1EEED0ZZZZ2@3oool:0=7=Z@T0
oooo00<000000:ZZZP000000102ZZZX2000000L0ZZZZ0P000000101EEED0ZZZZ0000000000040:ZZ
ZP0505EEE@000000000005EEE@0000000P2ZZZX300000080EEEE00<0oooo0000002ZZZX01P2ZZZX3
00000080ZZZZ0P0000020:ZZZPT0oooo2P3AcJT90?ooo`030000001EEED0oooo0080ZZZZ1`3oool2
000000070:ZZZP1EEED0oooo0000001EEED0oooo05EEE@040?ooo`030:ZZZP3oool0EEEE00D0oooo
00<0EEEE0?ooo`1EEED00`1EEED00`3oool0EEEE0?ooo`0300000080oooo00T0EEEE0?ooo`1EEED0
oooo0:ZZZP1EEED0oooo05EEE@2ZZZX02@3oool<0=7=Z@002`3AcJT90?ooo`<0ZZZZ0P3oool00`00
0000EEEE05EEE@020?ooo`0505EEE@3oool0EEEE0?ooo`000000202ZZZX40?ooo`0305EEE@3oool0
oooo00@0oooo1`2ZZZX01@1EEED0oooo05EEE@3oool0EEEE0080oooo00D0EEEE0?ooo`000000oooo
000000020:ZZZPX0oooo2P3AcJT90?ooo`L0ZZZZ0P3oool010000000ZZZZ0000002ZZZX200000004
05EEE@3oool000000?ooo`80ZZZZ00@0oooo0:ZZZP00000000000P2ZZZX00`1EEED000000:ZZZP03
00000080oooo0P2ZZZX02P3oool0ZZZZ0?ooo`1EEED0oooo0000002ZZZX0oooo0:ZZZP0000020?oo
o`<0ZZZZ00<0oooo0:ZZZP2ZZZX02P3oool:0=7=Z@T0oooo0P2ZZZX01P000000EEEE0000002ZZZX0
oooo00000080EEEE00<000000?ooo`2ZZZX00P3oool0101EEED0oooo00000000000305EEE@<00000
00@0oooo0000002ZZZX0EEEE1000000305EEE@80000000<0EEEE0?ooo`1EEED00P3oool0202ZZZX0
00000000001EEED0ZZZZ0000003oool0ZZZZ0`0000000`2ZZZX0oooo0?ooo`080?ooo`X0dLfY2@3o
ool0102ZZZX000000:ZZZP2ZZZX20?ooo`<0ZZZZ00<000000:ZZZP2ZZZX01@2ZZZX3000000030:ZZ
ZP3oool0ZZZZ0080ZZZZ0P1EEED20000000605EEE@2ZZZX0ZZZZ0:ZZZP000000oooo0P2ZZZX00`00
0000EEEE0:ZZZP060:ZZZP040000003oool0ZZZZ0:ZZZP<0oooo00<0ZZZZ0000003oool02@3oool:
0=7=Z@T0oooo0`2ZZZX2000000040?ooo`2ZZZX0ZZZZ0?ooo`80EEEE0P3oool00`1EEED000000000
00020:ZZZP050?ooo`2ZZZX0ZZZZ0:ZZZP3oool00P1EEED30000000305EEE@000000oooo00<0EEEE
0P2ZZZX01`1EEED0oooo0:ZZZP2ZZZX000000?ooo`1EEED00P3oool305EEE@030:ZZZP1EEED0oooo
008000000P2ZZZX:0?ooo``0dLfY000;0=7=Z@/0oooo0P2ZZZX205EEE@080:ZZZP3oool0ZZZZ0?oo
o`1EEED0oooo05EEE@3oool2000000<0oooo00<0EEEE0?ooo`3oool00P3oool00`1EEED0oooo0?oo
o`0205EEE@80oooo00<0EEEE0?ooo`3oool00P3oool03P000000oooo0?ooo`3oool0000005EEE@3o
ool0EEEE0?ooo`1EEED0oooo0000003oool0ZZZZ0P1EEED00`000000ZZZZ0?ooo`0:0?ooo`X0dLfY
2`3oool20:ZZZP80EEEE00D000000:ZZZP2ZZZX000000:ZZZP0305EEE@80ZZZZ0`0000050?ooo`08
0000001EEED0ZZZZ0:ZZZP1EEED0ZZZZ0?ooo`0000040?ooo`050:ZZZP000000oooo0000002ZZZX0
0`1EEED0103oool0ZZZZ0000000000020:ZZZP80EEEE00<000000:ZZZP3oool02P3oool:0=7=Z@/0
oooo00<0ZZZZ05EEE@0000000`0000020:ZZZP0405EEE@3oool0EEEE0?ooo`80ZZZZ0`3oool0102Z
ZZX0EEEE0000001EEED20?ooo`0305EEE@2ZZZX0ZZZZ0080ZZZZ00<000000?ooo`3oool00P000000
1P1EEED0oooo0?ooo`2ZZZX0oooo0:ZZZP80oooo0`1EEED20:ZZZP030000002ZZZX0000000800000
00<0ZZZZ0?ooo`3oool02@3oool:0=7=Z@/0oooo0P2ZZZX3000000030:ZZZP000000ZZZZ00L0ZZZZ
0P3oool20000000705EEE@2ZZZX0ZZZZ0:ZZZP3oool0EEEE0?ooo`0205EEE@060000002ZZZX0ZZZZ
0:ZZZP1EEED000000P3oool00`1EEED0ZZZZ0:ZZZP060:ZZZP030000002ZZZX0ZZZZ00<0000000<0
ZZZZ0?ooo`3oool02@3oool:0=7=Z@/0oooo00<0ZZZZ0?ooo`3oool00P3oool0101EEED0oooo0:ZZ
ZP0000020?ooo`060:ZZZP1EEED000000000002ZZZX0EEEE0P3oool305EEE@80oooo00@0ZZZZ0000
003oool0ZZZZ0P3oool0101EEED0oooo05EEE@3oool305EEE@80000000<0EEEE0:ZZZP3oool00P00
00000`2ZZZX0oooo05EEE@030?ooo`030000002ZZZX0oooo00X0oooo303AcJT000/0dLfY303oool2
0:ZZZP0505EEE@3oool0oooo05EEE@2ZZZX00`00000205EEE@@0oooo1P1EEED00`2ZZZX0EEEE0?oo
o`0205EEE@030000001EEED0EEEE00<0EEEE1P3oool01@1EEED000000?ooo`000000ZZZZ0080oooo
00@0ZZZZ05EEE@2ZZZX0ZZZZ303oool:0=7=Z@`0oooo0P2ZZZX02`1EEED0oooo0:ZZZP2ZZZX0EEEE
0000002ZZZX0oooo0000003oool0EEEE0080ZZZZ00T0EEEE0000002ZZZX0ZZZZ0000002ZZZX00000
0?ooo`1EEED00P2ZZZX205EEE@030000002ZZZX000000080ZZZZ00P0000005EEE@000000ZZZZ05EE
E@2ZZZX000000?ooo`80000000D0EEEE0?ooo`2ZZZX0ZZZZ05EEE@020:ZZZP`0oooo2P3AcJT<0?oo
o`040:ZZZP000000EEEE0?ooo`D0ZZZZ00@000000:ZZZP000000EEEE0P0000000`1EEED000000000
000200000080EEEE00<0ZZZZ0?ooo`0000000P3oool010000000EEEE05EEE@3oool2000000<0EEEE
00@0000005EEE@000000ZZZZ0P0000050:ZZZP0305EEE@000000ZZZZ00`0oooo2P3AcJT<0?ooo`04
0000002ZZZX0oooo0?ooo`X0ZZZZ00<000000?ooo`0000000P0000001@2ZZZX000000:ZZZP1EEED0
00000080EEEE00D000000:ZZZP2ZZZX000000:ZZZP03000000030?ooo`000000ZZZZ00L0ZZZZ00@0
oooo0:ZZZP2ZZZX0oooo0P2ZZZX<0?ooo`X0dLfY303oool0102ZZZX000000:ZZZP0000030?ooo`07
0:ZZZP3oool0000005EEE@3oool0EEEE0?ooo`03000000040:ZZZP3oool0EEEE00000080EEEE00T0
00000?ooo`2ZZZX000000?ooo`1EEED0000005EEE@3oool00P2ZZZX01`000000oooo0?ooo`1EEED0
ZZZZ05EEE@0000000P2ZZZX30?ooo`80ZZZZ00<000000:ZZZP3oool02`3oool<0=7=Z@002`3AcJT<
0?ooo`070:ZZZP1EEED0oooo0:ZZZP000000ZZZZ05EEE@020?ooo`0305EEE@3oool0000000<00000
00<0oooo0000001EEED00`1EEED20?ooo`080:ZZZP00000000000:ZZZP1EEED0oooo05EEE@3oool2
05EEE@030000003oool000000080000000<0EEEE0?ooo`1EEED00P3oool01P1EEED0ZZZZ0000001E
EED0oooo05EEE@d0oooo2P3AcJT<0?ooo`080:ZZZP1EEED0oooo0:ZZZP1EEED000000?ooo`2ZZZX3
0?ooo`060:ZZZP1EEED0ZZZZ0:ZZZP3oool000000P3oool010000000oooo0?ooo`1EEED40:ZZZP04
05EEE@3oool0oooo00000080oooo00@000000?ooo`3oool0ZZZZ0P1EEED20?ooo`80ZZZZ0P3oool2
05EEE@030?ooo`1EEED0oooo00`0oooo2P3AcJT<0?ooo`030:ZZZP1EEED0000000@0oooo0P000000
0`3oool000000000000200000080ZZZZ0`1EEED01@000000ZZZZ0:ZZZP1EEED000000080EEEE0P00
00020:ZZZP@0EEEE00H0ZZZZ0?ooo`00000000000?ooo`0000020?ooo`030000003oool0ZZZZ0080
oooo00<0000005EEE@3oool0303oool:0=7=Z@`0oooo00<0ZZZZ0000002ZZZX00P1EEED00`000000
ZZZZ0:ZZZP050:ZZZP030000003oool0000000<0000000<0oooo0000002ZZZX00P0000000`2ZZZX0
0000000000020:ZZZP030000001EEED0000000<0000000@0ZZZZ0000002ZZZX000000P2ZZZX01000
0000ZZZZ0:ZZZP2ZZZX205EEE@030:ZZZP000000oooo00`0oooo2P3AcJT<0?ooo`060:ZZZP3oool0
ZZZZ0?ooo`1EEED0ZZZZ0`1EEED20?ooo`040000001EEED0EEEE0:ZZZP80oooo00D0ZZZZ0?ooo`3o
ool0oooo05EEE@020:ZZZP80oooo0P2ZZZX0101EEED0oooo0000003oool20:ZZZP050?ooo`2ZZZX0
EEEE05EEE@0000000P3oool505EEE@030?ooo`2ZZZX0oooo00d0oooo303AcJT000/0dLfY3P3oool2
0:ZZZP80000000D0oooo05EEE@3oool0EEEE0?ooo`020000000;0?ooo`1EEED0EEEE0000003oool0
EEEE0?ooo`1EEED0oooo05EEE@2ZZZX00P3oool00`2ZZZX0oooo0?ooo`0305EEE@0;0?ooo`2ZZZX0
EEEE05EEE@3oool0000005EEE@3oool0EEEE0?ooo`1EEED00P3oool00`000000ZZZZ0:ZZZP0>0?oo
o`X0dLfY3P3oool20:ZZZP030000002ZZZX0ZZZZ00<0ZZZZ00@0oooo0:ZZZP000000ZZZZ0P1EEED0
20000000EEEE0?ooo`3oool0ZZZZ0000003oool0ZZZZ0P000000302ZZZX0oooo0000002ZZZX0EEEE
0?ooo`1EEED0ZZZZ05EEE@3oool0ZZZZ00000080oooo102ZZZX0103oool000000:ZZZP2ZZZX>0?oo
o`X0dLfY3P3oool01P2ZZZX000000?ooo`1EEED0ZZZZ05EEE@80oooo1@0000001`3oool0EEEE05EE
E@2ZZZX0000005EEE@0000001@1EEED20000000605EEE@000000ZZZZ05EEE@000000oooo1@000000
1P3oool0EEEE05EEE@2ZZZX000000?ooo`80ZZZZ3P3oool:0=7=Z@h0oooo0P2ZZZX40?ooo`0:0:ZZ
ZP000000ZZZZ05EEE@000000EEEE0000002ZZZX0oooo0:ZZZP8000000P2ZZZX205EEE@030:ZZZP1E
EED0EEEE00<0ZZZZ0P0000001P2ZZZX000000:ZZZP3oool0EEEE00000080ZZZZ00P000000?ooo`3o
ool0oooo0:ZZZP3oool000000:ZZZPh0oooo2P3AcJT>0?ooo`80ZZZZ0P000000101EEED0oooo0?oo
o`3oool205EEE@040:ZZZP3oool0oooo0?ooo`80ZZZZ0P3oool30:ZZZP0505EEE@3oool0EEEE05EE
E@0000000P2ZZZX20?ooo`80ZZZZ0`3oool20:ZZZP0505EEE@3oool0oooo0?ooo`1EEED00P000002
0:ZZZPh0oooo303AcJT000/0dLfY3`3oool01P1EEED0oooo0?ooo`1EEED000000?ooo`80EEEE0P3o
ool02P1EEED000000:ZZZP3oool0EEEE0000001EEED0oooo05EEE@2ZZZX40?ooo`030000001EEED0
oooo0080000000H0EEEE0?ooo`2ZZZX0000005EEE@3oool305EEE@80000000@0EEEE0?ooo`3oool0
ZZZZ3`3oool:0=7=Z@l0oooo00H0EEEE0?ooo`3oool0ZZZZ0?ooo`2ZZZX30?ooo`80000000L0ZZZZ
0?ooo`3oool000000:ZZZP3oool0EEEE00<0ZZZZ00P0oooo0:ZZZP2ZZZX000000:ZZZP1EEED00000
0:ZZZP80000000@0oooo00000000000000001@3oool0102ZZZX0oooo0?ooo`2ZZZX?0?ooo`X0dLfY
3`3oool01P1EEED000000:ZZZP1EEED0oooo000000L0EEEE0P2ZZZX00`1EEED0oooo05EEE@0205EE
E@040:ZZZP1EEED0ZZZZ0:ZZZP<0EEEE00@0oooo05EEE@2ZZZX00000201EEED01@3oool0EEEE05EE
E@000000ZZZZ00l0oooo2P3AcJT?0?ooo`030000002ZZZX0EEEE00<0EEEE0P2ZZZX30000000405EE
E@2ZZZX0ZZZZ00000080ZZZZ00<000000:ZZZP0000000P0000002@2ZZZX000000:ZZZP2ZZZX00000
0?ooo`2ZZZX0000005EEE@020:ZZZP8000000`2ZZZX405EEE@80ZZZZ3`3oool:0=7=ZA<0oooo00D0
00000?ooo`1EEED000000:ZZZP040?ooo`030:ZZZP3oool0oooo0080oooo0P2ZZZX00`3oool0ZZZZ
05EEE@020?ooo`030:ZZZP3oool0oooo00L0oooo00T0EEEE0000001EEED0EEEE0000003oool0EEEE
0?ooo`2ZZZX03`3oool<0=7=Z@002`3AcJT?0?ooo`060:ZZZP000000EEEE05EEE@3oool0EEEE0P00
000305EEE@050?ooo`1EEED0EEEE05EEE@3oool00P1EEED00`2ZZZX0oooo0?ooo`030?ooo`80ZZZZ
00L0EEEE0?ooo`3oool0EEEE0:ZZZP1EEED0oooo00<0EEEE0P0000020?ooo`0305EEE@2ZZZX00000
0100oooo2P3AcJT?0?ooo`030:ZZZP0000000000008000000P2ZZZX010000000ZZZZ0:ZZZP3oool2
0:ZZZP0805EEE@3oool0oooo0:ZZZP000000oooo05EEE@2ZZZX20?ooo`050:ZZZP3oool0oooo0000
002ZZZX00P3oool01@000000ZZZZ0:ZZZP3oool0ZZZZ008000000P2ZZZX2000000030:ZZZP000000
oooo00l0oooo2P3AcJT?0?ooo`040:ZZZP000000oooo0:ZZZP80000000L0oooo05EEE@2ZZZX0EEEE
0:ZZZP1EEED0ZZZZ0080oooo00l0ZZZZ0000002ZZZX0oooo05EEE@3oool0EEEE0:ZZZP3oool00000
0?ooo`2ZZZX000000:ZZZP3oool00P2ZZZX00`1EEED0ZZZZ05EEE@0205EEE@060?ooo`0000000000
0:ZZZP1EEED00000403oool:0=7=Z@l0oooo00H0ZZZZ00000000000000000:ZZZP0000030:ZZZP03
0?ooo`2ZZZX0ZZZZ0080000000H0ZZZZ0?ooo`3oool0ZZZZ0000002ZZZX20?ooo`050:ZZZP3oool0
ZZZZ0000002ZZZX00P3oool20:ZZZP80000000<0ZZZZ0?ooo`2ZZZX00P2ZZZX01@000000ZZZZ0000
002ZZZX000000100oooo2P3AcJT?0?ooo`030:ZZZP000000oooo0080oooo00<0ZZZZ05EEE@3oool0
0P0000001@1EEED0oooo05EEE@3oool000000080EEEE0P000000102ZZZX0oooo0?ooo`0000020?oo
o`80000000P0oooo05EEE@000000000005EEE@000000EEEE00000080oooo0P1EEED30?ooo`030000
003oool0oooo00h0oooo303AcJT000/0dLfY4@3oool01`1EEED0oooo05EEE@2ZZZX0EEEE0000003o
ool0100000020:ZZZP030?ooo`2ZZZX0oooo0080oooo00@0EEEE0?ooo`3oool0EEEE0`3oool01P2Z
ZZX0oooo0:ZZZP2ZZZX0000005EEE@80000000L0ZZZZ0000001EEED0ZZZZ05EEE@3oool0ZZZZ0140
oooo2P3AcJTA0?ooo`0505EEE@3oool000000?ooo`0000000P3oool00`000000EEEE000000020000
00030?ooo`2ZZZX00000008000001@3oool300000080ZZZZ00<0oooo0:ZZZP0000000P1EEED02000
0000oooo0?ooo`000000oooo0000003oool0ZZZZ4@3oool:0=7=ZA40oooo00H0EEEE0000002ZZZX0
ZZZZ0?ooo`00000205EEE@<0000000<0EEEE0000001EEED00P1EEED010000000EEEE0:ZZZP3oool2
0:ZZZP0305EEE@000000EEEE0080EEEE00<0000005EEE@0000000P00000205EEE@060000003oool0
ZZZZ0:ZZZP000000ZZZZ4@3oool:0=7=ZA40oooo00@000000:ZZZP1EEED0EEEE0`2ZZZX305EEE@80
ZZZZ100000020:ZZZP0405EEE@000000EEEE05EEE@80ZZZZ00@000000:ZZZP00000000000P2ZZZX0
0`000000EEEE05EEE@030:ZZZP80EEEE0P2ZZZXA0?ooo`X0dLfY4P3oool0102ZZZX0oooo05EEE@3o
ool200000080oooo00@0ZZZZ0?ooo`1EEED0oooo0`0000020?ooo`80ZZZZ00T0EEEE0:ZZZP2ZZZX0
oooo0000003oool000000?ooo`1EEED0103oool00`1EEED000000?ooo`020?ooo`80ZZZZ4@3oool<
0=7=Z@002`3AcJTA0?ooo`040:ZZZP000000ZZZZ05EEE@80ZZZZ0P3oool205EEE@050?ooo`2ZZZX0
oooo0?ooo`2ZZZX00P1EEED00`000000EEEE05EEE@0205EEE@030:ZZZP1EEED0EEEE00H0oooo00<0
EEEE0?ooo`3oool00P2ZZZX00`3oool0ZZZZ0000000B0?ooo`X0dLfY4@3oool01@2ZZZX000000:ZZ
ZP1EEED0ZZZZ0080000000L0ZZZZ05EEE@2ZZZX0oooo05EEE@000000oooo0080ZZZZ00T0oooo0:ZZ
ZP00000000000:ZZZP000000ZZZZ0?ooo`2ZZZX00P3oool01@000000ZZZZ0?ooo`2ZZZX0EEEE0080
ZZZZ00D000000:ZZZP1EEED0ZZZZ0000000B0?ooo`X0dLfY4@3oool0102ZZZX0000005EEE@000002
05EEE@030?ooo`1EEED0EEEE0080EEEE0P2ZZZX00`3oool0EEEE0?ooo`040000000805EEE@000000
00000000003oool000000?ooo`2ZZZX805EEE@030000001EEED000000180oooo2P3AcJTA0?ooo`04
0:ZZZP000000ZZZZ00000080ZZZZ00@000000:ZZZP00000000000`2ZZZX205EEE@80ZZZZ00@00000
0:ZZZP00000000001@2ZZZX0101EEED0ZZZZ0:ZZZP2ZZZX2000000@0ZZZZ00<000000:ZZZP000000
4P3oool:0=7=ZA40oooo00@0ZZZZ0000001EEED0EEEE0P2ZZZX00`1EEED0oooo000000020?ooo`04
0000003oool0EEEE05EEE@80oooo00D0ZZZZ0000001EEED0EEEE000000040?ooo`0605EEE@3oool0
oooo0?ooo`2ZZZX000000P3oool20:ZZZP030?ooo`1EEED000000180oooo303AcJT000/0dLfY4P3o
ool20:ZZZP030000003oool0oooo00<0000000<0oooo05EEE@3oool00`3oool01@2ZZZX000000?oo
o`1EEED0oooo0080EEEE00<0oooo0000002ZZZX00`3oool00`000000EEEE05EEE@0300000080oooo
0`2ZZZXB0?ooo`X0dLfY4P3oool20:ZZZP0605EEE@2ZZZX0oooo0?ooo`2ZZZX0EEEE0P3oool0102Z
ZZX0000005EEE@0000020?ooo`040000003oool0oooo000000D0oooo00H0EEEE0000003oool0oooo
0:ZZZP1EEED20:ZZZP030?ooo`2ZZZX0ZZZZ0080ZZZZ4P3oool:0=7=ZA80oooo0P2ZZZX02@1EEED0
ZZZZ0:ZZZP2ZZZX000000:ZZZP000000ZZZZ000000020?ooo`80EEEE00T0000005EEE@000000oooo
0:ZZZP000000ZZZZ0000001EEED0103oool30:ZZZP8000000P2ZZZX00`000000ZZZZ0:ZZZP0B0?oo
o`X0dLfY4P3oool01@2ZZZX000000?ooo`2ZZZX0oooo00@0ZZZZ00<000000:ZZZP0000000P2ZZZX0
1@000000ZZZZ0:ZZZP3oool0EEEE0080oooo0P2ZZZX2000000050:ZZZP000000ZZZZ0000003oool0
0P2ZZZX20?ooo`80ZZZZ00<000000:ZZZP3oool04@3oool:0=7=ZA80oooo0P2ZZZX30000000305EE
E@2ZZZX0ZZZZ00<0oooo0P1EEED40?ooo`@0ZZZZ0`3oool00`000000EEEE05EEE@030?ooo`80ZZZZ
00<0oooo0000000000000`2ZZZXB0?ooo``0dLfY000;0=7=ZA@0oooo00<000000:ZZZP1EEED00P2Z
ZZX00`000000EEEE00000002000000040?ooo`00000000000?ooo`80ZZZZ00<0oooo0:ZZZP2ZZZX0
0P3oool2000000070?ooo`00000000000000001EEED000000:ZZZP0205EEE@80ZZZZ503oool:0=7=
ZA@0oooo00D000000:ZZZP3oool0EEEE000000020:ZZZP0405EEE@00000000000:ZZZP80000000D0
EEEE0?ooo`2ZZZX0ZZZZ000000020:ZZZP0705EEE@000000oooo0:ZZZP000000ZZZZ05EEE@020:ZZ
ZP030000001EEED0oooo0080ZZZZ503oool:0=7=ZA@0oooo00H0000005EEE@1EEED0000005EEE@00
000205EEE@050:ZZZP1EEED0ZZZZ0?ooo`2ZZZX00`1EEED00`000000EEEE05EEE@0205EEE@030:ZZ
ZP000000ZZZZ00@0EEEE00<0000005EEE@0000000P1EEED00`2ZZZX0oooo0?ooo`0B0?ooo`X0dLfY
503oool01`000000ZZZZ0000002ZZZX000000:ZZZP0000000`2ZZZX010000000oooo0000003oool2
0:ZZZP80000000<0ZZZZ0?ooo`3oool00`0000030:ZZZP030000002ZZZX00000008000000P2ZZZXD
0?ooo`X0dLfY503oool00`000000oooo0?ooo`020?ooo`0605EEE@000000oooo0:ZZZP1EEED00000
0P3oool00`1EEED0ZZZZ0:ZZZP040:ZZZP0505EEE@3oool0oooo0000001EEED00`3oool00`1EEED0
oooo0?ooo`020?ooo`030:ZZZP3oool0oooo0180oooo303AcJT000/0dLfY503oool40:ZZZP80oooo
00<0EEEE0?ooo`1EEED00P3oool01@1EEED0oooo0?ooo`3oool0ZZZZ0080oooo00<0ZZZZ0?ooo`3o
ool01P3oool0101EEED0oooo0?ooo`1EEED20:ZZZQD0oooo2P3AcJTD0?ooo`<0ZZZZ00<0oooo0:ZZ
ZP2ZZZX00P2ZZZX20?ooo`80EEEE00@000000:ZZZP3oool0oooo0P2ZZZX20?ooo`060:ZZZP000000
ZZZZ05EEE@3oool0EEEE102ZZZX00`000000ZZZZ0:ZZZP0E0?ooo`X0dLfY503oool20:ZZZP@00000
0P1EEED20:ZZZP0;05EEE@3oool0oooo0000002ZZZX000000?ooo`2ZZZX000000:ZZZP0000000P3o
ool01@1EEED0ZZZZ0:ZZZP1EEED0oooo0080000000<0oooo0000002ZZZX05@3oool:0=7=ZA@0oooo
00D0ZZZZ0000002ZZZX0ZZZZ0?ooo`040:ZZZP080000002ZZZX000000000001EEED000000:ZZZP3o
ool30:ZZZP0505EEE@000000oooo0:ZZZP0000000P2ZZZX01P3oool0ZZZZ0?ooo`3oool0ZZZZ0000
01D0oooo2P3AcJTD0?ooo`80ZZZZ00<000000:ZZZP0000000P3oool0101EEED000000?ooo`3oool2
000000P0EEEE00H0000005EEE@3oool0oooo0000001EEED20?ooo`040000002ZZZX000000:ZZZQD0
oooo303AcJT000/0dLfY5@3oool0102ZZZX0EEEE05EEE@2ZZZX40000000305EEE@2ZZZX0000000<0
0000103oool30000000305EEE@2ZZZX0EEEE0080000000H0ZZZZ0000002ZZZX0oooo05EEE@2ZZZXE
0?ooo`X0dLfY5@3oool02P2ZZZX0EEEE0?ooo`3oool0ZZZZ05EEE@2ZZZX0000005EEE@3oool20:ZZ
ZP<0oooo00<0ZZZZ0?ooo`3oool00P3oool0202ZZZX0EEEE0?ooo`1EEED0oooo0:ZZZP3oool0ZZZZ
0P3oool00`1EEED0ZZZZ0?ooo`0D0?ooo`X0dLfY5@3oool01P2ZZZX0EEEE05EEE@2ZZZX0000005EE
E@@0ZZZZ00<000000:ZZZP0000000P0000020?ooo`050000001EEED000000:ZZZP000000102ZZZX0
1P1EEED000000:ZZZP000000EEEE0:ZZZQD0oooo2P3AcJTE0?ooo`030:ZZZP000000EEEE0080EEEE
00@000000:ZZZP000000ZZZZ0P3oool205EEE@060?ooo`2ZZZX0oooo0?ooo`2ZZZX000000P1EEED2
0?ooo`@0ZZZZ0P1EEED00`2ZZZX000000:ZZZP0E0?ooo`X0dLfY5@3oool0202ZZZX0oooo0?ooo`3o
ool0EEEE0:ZZZP1EEED0oooo0P1EEED00`3oool0ZZZZ0:ZZZP090:ZZZP80EEEE00P0oooo05EEE@1E
EED0EEEE0?ooo`2ZZZX0oooo0:ZZZQD0oooo303AcJT000/0dLfY5`3oool20:ZZZP8000000P3oool0
0`2ZZZX0oooo05EEE@0205EEE@030000002ZZZX000000080ZZZZ0`1EEED00`000000oooo0:ZZZP03
0?ooo`030000002ZZZX0ZZZZ01L0oooo2P3AcJTG0?ooo`80ZZZZ00D0oooo0:ZZZP2ZZZX000000:ZZ
ZP030?ooo`80ZZZZ00<0oooo05EEE@3oool00P3oool01P2ZZZX0oooo0000003oool0ZZZZ00000080
ZZZZ00<0oooo0:ZZZP2ZZZX05`3oool:0=7=ZAL0oooo00H0ZZZZ00000000000000000:ZZZP000002
05EEE@090000001EEED0EEEE0?ooo`2ZZZX0oooo0000002ZZZX000000080EEEE00H0000005EEE@1E
EED000000:ZZZP1EEED2000000030:ZZZP3oool0oooo01D0oooo2P3AcJTG0?ooo`030000002ZZZX0
oooo00<0oooo00D0ZZZZ000000000000oooo05EEE@050?ooo`80EEEE00@0oooo0:ZZZP000000ZZZZ
0P3oool0102ZZZX0oooo0:ZZZP2ZZZXG0?ooo`X0dLfY5`3oool20:ZZZP80000000@0EEEE0?ooo`00
0000ZZZZ1@3oool0101EEED0oooo0?ooo`1EEED20?ooo`0505EEE@2ZZZX000000?ooo`1EEED00P00
00020:ZZZQL0oooo303AcJT000/0dLfY5`3oool01`2ZZZX0EEEE0?ooo`3oool0EEEE0?ooo`000000
0P3oool305EEE@80oooo00<0ZZZZ0?ooo`3oool00`1EEED0103oool000000000001EEED20?ooo`03
05EEE@3oool0oooo01H0oooo2P3AcJTG0?ooo`030:ZZZP1EEED0oooo0080oooo00D000000?ooo`3o
ool0EEEE000000020?ooo`040000003oool0EEEE00000080oooo00T000000?ooo`3oool0oooo0000
003oool000000?ooo`1EEED0603oool:0=7=ZAL0oooo00l0ZZZZ05EEE@000000ZZZZ0?ooo`1EEED0
oooo05EEE@2ZZZX0EEEE0:ZZZP000000EEEE0:ZZZP0000000P1EEED0102ZZZX0EEEE0000001EEED3
0?ooo`030:ZZZP000000EEEE01P0oooo2P3AcJTG0?ooo`030:ZZZP000000ZZZZ00@0EEEE0P2ZZZX0
0`1EEED0000005EEE@0505EEE@040000001EEED0ZZZZ0:ZZZP@0EEEE00<0ZZZZ0000003oool05`3o
ool:0=7=ZAL0oooo00<0ZZZZ0?ooo`3oool00P3oool00`1EEED0oooo0?ooo`0205EEE@030?ooo`2Z
ZZX0EEEE0080ZZZZ0P1EEED00`3oool0EEEE0:ZZZP020?ooo`030000003oool0EEEE01X0oooo303A
cJT000/0dLfY603oool0102ZZZX0000005EEE@1EEED20?ooo`0305EEE@00000000000080EEEE00@0
00000?ooo`3oool000000P1EEED20000000705EEE@3oool0oooo05EEE@2ZZZX000000:ZZZP0H0?oo
o`X0dLfY603oool01@2ZZZX0000005EEE@1EEED000000080EEEE00@0oooo0:ZZZP2ZZZX000000P2Z
ZZX00`1EEED0ZZZZ000000020:ZZZP080000001EEED0EEEE0:ZZZP1EEED0ZZZZ0000002ZZZXH0?oo
o`X0dLfY603oool00`2ZZZX0000000000002000000040:ZZZP000000EEEE0?ooo`80EEEE0P000000
1`3oool000000:ZZZP1EEED0oooo0:ZZZP0000000P2ZZZX010000000EEEE0000002ZZZXH0?ooo`X0
dLfY603oool00`2ZZZX000000000000300000080ZZZZ0P0000000`2ZZZX000000:ZZZP0500000080
ZZZZ00H000000:ZZZP000000ZZZZ0000002ZZZXH0?ooo`X0dLfY603oool01@2ZZZX000000?ooo`3o
ool0EEEE0080ZZZZ00<0000005EEE@1EEED00P3oool2000000030?ooo`2ZZZX0EEEE0080EEEE0P2Z
ZZX30?ooo`030000002ZZZX0oooo01L0oooo303AcJT000/0dLfY6P3oool01`1EEED0oooo0:ZZZP2Z
ZZX0EEEE0000002ZZZX01P0000002@1EEED000000:ZZZP2ZZZX0EEEE0:ZZZP1EEED0oooo0:ZZZP0J
0?ooo`X0dLfY6P3oool0101EEED0oooo0:ZZZP1EEED20?ooo`<0EEEE00@000000:ZZZP2ZZZX00000
0`1EEED20?ooo`80EEEE00<0oooo0:ZZZP3oool06@3oool:0=7=ZAX0oooo00T0EEEE0000003oool0
oooo0000002ZZZX0000005EEE@0000000P1EEED01`2ZZZX0EEEE0000001EEED0000005EEE@000000
0P3oool00`000000ZZZZ0?ooo`0I0?ooo`X0dLfY6P3oool010000000ZZZZ05EEE@1EEED30:ZZZP03
05EEE@3oool0oooo0080000000<0oooo0000001EEED00`2ZZZX205EEE@80ZZZZ6P3oool:0=7=ZA/0
oooo00<0ZZZZ0?ooo`1EEED00`3oool01P000000EEEE0?ooo`000000EEEE0?ooo`8000000`3oool0
101EEED0oooo0:ZZZP2ZZZXJ0?ooo``0dLfY000;0=7=ZAX0oooo00@0ZZZZ0000003oool0EEEE0P2Z
ZZX01@3oool0EEEE05EEE@3oool0EEEE00<0oooo00L0EEEE0?ooo`2ZZZX0ZZZZ05EEE@2ZZZX00000
01/0oooo2P3AcJTJ0?ooo`030:ZZZP000000oooo00@0EEEE00@0oooo05EEE@3oool0ZZZZ0P3oool0
101EEED0oooo05EEE@00000205EEE@030:ZZZP000000oooo01X0oooo2P3AcJTJ0?ooo`050:ZZZP00
0000EEEE0000001EEED00P2ZZZX0203oool000000?ooo`1EEED0ZZZZ0?ooo`000000oooo0P2ZZZX0
101EEED0000005EEE@00000K0?ooo`X0dLfY6P3oool0102ZZZX000000000000000020:ZZZP030000
002ZZZX0oooo00D0000000L0ZZZZ0000002ZZZX0ZZZZ0000002ZZZX0000001/0oooo2P3AcJTJ0?oo
o`060:ZZZP000000oooo05EEE@2ZZZX0EEEE0`2ZZZX01@1EEED0oooo0:ZZZP1EEED0oooo00@0ZZZZ
0P1EEED00`000000oooo0?ooo`0I0?ooo``0dLfY000;0=7=ZA/0oooo0P2ZZZX010000000oooo0000
003oool205EEE@040000001EEED0ZZZZ00000080EEEE0`3oool00`000000ZZZZ0:ZZZP0K0?ooo`X0
dLfY6`3oool20:ZZZP040000003oool0ZZZZ05EEE@<0ZZZZ0P0000001`2ZZZX0EEEE0:ZZZP1EEED0
ZZZZ0?ooo`0000000P2ZZZXK0?ooo`X0dLfY6`3oool00`2ZZZX000000?ooo`03000000<0EEEE0P00
000305EEE@040000001EEED000000?ooo`80ZZZZ6`3oool:0=7=ZA/0oooo0P2ZZZX00`3oool0ZZZZ
0?ooo`020:ZZZP0305EEE@0000000000008000000`2ZZZX01@3oool0ZZZZ0?ooo`000000ZZZZ01/0
oooo2P3AcJTK0?ooo`80ZZZZ0`000000103oool0000005EEE@2ZZZX20?ooo`030:ZZZP0000000000
0080oooo0P0000020:ZZZQ/0oooo303AcJT000/0dLfY703oool00`2ZZZX000000:ZZZP0205EEE@06
0?ooo`1EEED0ZZZZ0?ooo`1EEED0ZZZZ0P3oool205EEE@030:ZZZP000000oooo01`0oooo2P3AcJTL
0?ooo`050:ZZZP000000ZZZZ0000001EEED00P3oool010000000oooo05EEE@0000020?ooo`0405EE
E@000000ZZZZ000001d0oooo2P3AcJTL0?ooo`050:ZZZP000000EEEE0:ZZZP0000000P1EEED02P2Z
ZZX0oooo0?ooo`2ZZZX0000005EEE@000000oooo05EEE@00000M0?ooo`X0dLfY703oool01@2ZZZX0
00000:ZZZP000000ZZZZ00@0000000P0EEEE0000002ZZZX000000:ZZZP000000ZZZZ000001d0oooo
2P3AcJTL0?ooo`050:ZZZP000000oooo0?ooo`0000000P2ZZZX01`3oool0ZZZZ0:ZZZP3oool00000
0:ZZZP0000000P3oool00`000000oooo0?ooo`0K0?ooo``0dLfY000;0=7=ZAd0oooo0P2ZZZX01@1E
EED0ZZZZ0:ZZZP2ZZZX0oooo0080EEEE00<0oooo0000002ZZZX0102ZZZXM0?ooo`X0dLfY7@3oool2
0:ZZZP040?ooo`2ZZZX0000000000080ZZZZ00@0EEEE0:ZZZP2ZZZX00000102ZZZXM0?ooo`X0dLfY
7@3oool20:ZZZP040000001EEED0ZZZZ000000@0oooo00@0EEEE0:ZZZP1EEED000000P2ZZZXM0?oo
o`X0dLfY7@3oool0102ZZZX000000?ooo`2ZZZX20?ooo`030:ZZZP00000000000080ZZZZ00D0oooo
0:ZZZP2ZZZX000000:ZZZP0M0?ooo`X0dLfY7@3oool30:ZZZP040?ooo`2ZZZX0ZZZZ0?ooo`800000
0P3oool00`2ZZZX0oooo000000020:ZZZQd0oooo303AcJT000/0dLfY7`3oool010000000ZZZZ0?oo
o`3oool2000000040:ZZZP000000oooo0?ooo`80ZZZZ7`3oool:0=7=ZAl0oooo00D000000:ZZZP1E
EED0EEEE0:ZZZP02000000030:ZZZP1EEED0EEEE0080ZZZZ7`3oool:0=7=ZAl0oooo00D0000005EE
E@000000EEEE0:ZZZP0205EEE@050:ZZZP000000000005EEE@2ZZZX07`3oool:0=7=ZAl0oooo00<0
00000:ZZZP0000000P2ZZZX20?ooo`030:ZZZP00000000000080ZZZZ7`3oool:0=7=ZAl0oooo00P0
000005EEE@3oool0EEEE0:ZZZP1EEED000000:ZZZP80oooo00<0EEEE0:ZZZP3oool07P3oool<0=7=
Z@002`3AcJTO0?ooo`D0ZZZZ00@0EEEE0?ooo`2ZZZX000000P2ZZZXP0?ooo`X0dLfY7`3oool50:ZZ
ZP040?ooo`2ZZZX0ZZZZ05EEE@80ZZZZ803oool:0=7=ZAl0oooo0P2ZZZX010000000ZZZZ0:ZZZP1E
EED20:ZZZP0305EEE@000000ZZZZ0200oooo2P3AcJTO0?ooo`040:ZZZP000000ZZZZ0:ZZZPD0oooo
00<0ZZZZ0000003oool07`3oool:0=7=ZAl0oooo0`2ZZZX20?ooo`80ZZZZ00@0oooo0000002ZZZX0
ZZZZ803oool<0=7=Z@002`3AcJTP0?ooo`0:0:ZZZP1EEED0oooo0:ZZZP000000EEEE0:ZZZP3oool0
EEEE0:ZZZR00oooo2P3AcJTP0?ooo`040:ZZZP1EEED0EEEE0:ZZZP80oooo00@0ZZZZ0?ooo`1EEED0
ZZZZ803oool:0=7=ZB00oooo00X0ZZZZ05EEE@3oool0oooo05EEE@2ZZZX0oooo0000001EEED0ZZZZ
803oool:0=7=ZB00oooo00<0ZZZZ0000001EEED0101EEED00`2ZZZX000000:ZZZP0P0?ooo`X0dLfY
803oool01@2ZZZX0oooo05EEE@000000oooo008000000P3oool00`2ZZZX0oooo0?ooo`0N0?ooo``0
dLfY000;0=7=ZB80oooo0P2ZZZX010000000EEEE0:ZZZP2ZZZXR0?ooo`X0dLfY8P3oool20:ZZZP04
0?ooo`000000ZZZZ0:ZZZR80oooo2P3AcJTR0?ooo`030:ZZZP1EEED0EEEE0080EEEE00<0ZZZZ0?oo
o`3oool0803oool:0=7=ZB80oooo00@000000:ZZZP000000oooo0P2ZZZXR0?ooo`X0dLfY8P3oool0
1P2ZZZX000000000002ZZZX000000:ZZZR80oooo303AcJT000/0dLfY8P3oool01@2ZZZX0EEEE05EE
E@3oool0EEEE02<0oooo2P3AcJTR0?ooo`050:ZZZP1EEED0oooo0?ooo`1EEED08`3oool:0=7=ZB80
oooo00<0ZZZZ05EEE@3oool00P1EEEDS0?ooo`X0dLfY8P3oool01@2ZZZX0000005EEE@2ZZZX00000
02<0oooo2P3AcJTR0?ooo`040:ZZZP3oool0oooo0:ZZZR@0oooo303AcJT000/0dLfY8`3oool20:ZZ
ZP030000002ZZZX0oooo0280oooo2P3AcJTS0?ooo`80ZZZZ00<000000:ZZZP3oool08P3oool:0=7=
ZB<0oooo0P2ZZZX00`000000ZZZZ0?ooo`0R0?ooo`X0dLfY8`3oool20:ZZZP030000002ZZZX0oooo
0280oooo2P3AcJTS0?ooo`040:ZZZP1EEED000000:ZZZR<0oooo303AcJT000/0dLfY903oool00`2Z
ZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2Z
ZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2Z
ZZX0oooo0?ooo`0S0?ooo``0dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o
0=7=ZK80dLfY003o0=7=ZK80dLfY000;0=7=Z@040?ooo`2ZZZX0EEEE00000080oooo00<0EEEE0000
000000000P2ZZZX20?ooo`<000000`3oool00`1EEED0ZZZZ0:ZZZP020?ooo``0000000<0ZZZZ0000
000000002`0000001@1EEED0oooo0:ZZZP000000EEEE00<0oooo0`000000101EEED0oooo0:ZZZP1E
EED200000080oooo00D0EEEE0000001EEED0ZZZZ0?ooo`0:0=7=Z@040?ooo`2ZZZX0oooo05EEE@80
ZZZZ00@000000:ZZZP2ZZZX0ZZZZ0P0000020?ooo`030:ZZZP0000000000008000001P2ZZZX0101E
EED0ZZZZ0000000000030:ZZZP040000002ZZZX0000000000080oooo00<000000:ZZZP2ZZZX00P00
00020:ZZZP80000000<0ZZZZ05EEE@2ZZZX01@2ZZZX00`000000ZZZZ000000020:ZZZP030?ooo`1E
EED00000008000001@2ZZZX0101EEED0oooo0:ZZZP3oool:0=7=Z@060?ooo`000000EEEE05EEE@00
0000ZZZZ0`3oool01`000000oooo000000000000EEEE0:ZZZP1EEED00`2ZZZX00`000000oooo0000
0002000000060?ooo`00000000000?ooo`2ZZZX0EEEE0`2ZZZX0103oool0EEEE0:ZZZP1EEED30:ZZ
ZP040?ooo`2ZZZX0ZZZZ0:ZZZP80EEEE0P3oool00`000000oooo00000002000000030?ooo`000000
ZZZZ0080ZZZZ00D0EEEE0:ZZZP1EEED0oooo000000040?ooo`0305EEE@2ZZZX0oooo0080EEEE00<0
ZZZZ0?ooo`3AcJT02@3AcJT00`3oool0ZZZZ0:ZZZP020?ooo`050:ZZZP00000000000000002ZZZX0
0P1EEED0103oool0EEEE0000002ZZZX20?ooo`030000002ZZZX0EEEE00D0EEEE0`3oool00`1EEED0
oooo0:ZZZP020:ZZZP0405EEE@3oool0ZZZZ0:ZZZP80oooo0P2ZZZX20?ooo`80EEEE00<0oooo05EE
E@1EEED0101EEED01@3oool0ZZZZ0000001EEED0oooo0080000000D0EEEE0?ooo`1EEED0EEEE0:ZZ
ZP0200000080ZZZZ00D0EEEE0?ooo`2ZZZX0ZZZZ0?ooo`0:0=7=Z@040?ooo`2ZZZX0ZZZZ000000H0
EEEE01<000000?ooo`2ZZZX0ZZZZ05EEE@2ZZZX0oooo0000001EEED0oooo0000002ZZZX0000005EE
E@3oool000000?ooo`2ZZZX0oooo0080000000D0ZZZZ05EEE@3oool0oooo0:ZZZP0205EEE@80ZZZZ
00<0oooo05EEE@2ZZZX00P0000020:ZZZP8000000P3oool010000000ZZZZ0?ooo`3oool205EEE@07
0?ooo`1EEED0EEEE0:ZZZP000000oooo0000000505EEE@050?ooo`000000ZZZZ0:ZZZP3oool0303A
cJT000/0dLfY00<0oooo0:ZZZP3oool00P0000001P1EEED000000000002ZZZX0oooo05EEE@800000
0`1EEED01P000000EEEE000000000000oooo05EEE@8000002`1EEED2000000030:ZZZP000000EEEE
00X0EEEE0P0000000`1EEED0000000000003000000<0EEEE0P0000000`1EEED000000:ZZZP020000
000305EEE@000000000000<0oooo2P3AcJT02P3oool0ZZZZ0?ooo`1EEED0000005EEE@000000ZZZZ
05EEE@0000020:ZZZP80oooo00<000000:ZZZP2ZZZX01@0000000`2ZZZX000000:ZZZP0300000007
05EEE@000000ZZZZ0:ZZZP000000ZZZZ05EEE@040?ooo`050000002ZZZX000000000002ZZZX00`00
00001`3oool000000:ZZZP000000ZZZZ0000002ZZZX00`0000001@2ZZZX000000000003oool00000
0080ZZZZ00@0000005EEE@2ZZZX0ZZZZ0`1EEED30?ooo`X0dLfY00<0oooo0:ZZZP0000000P2ZZZX0
0`1EEED0oooo0?ooo`020?ooo`0305EEE@2ZZZX0ZZZZ0080EEEE00@0ZZZZ05EEE@000000EEEE0`2Z
ZZX00`1EEED0ZZZZ05EEE@020?ooo`80EEEE00@000000?ooo`000000oooo0P000000301EEED00000
0:ZZZP1EEED0oooo0000003oool000000?ooo`000000ZZZZ05EEE@80oooo00<0EEEE0:ZZZP1EEED0
0`2ZZZX00`1EEED0000005EEE@0305EEE@80ZZZZ00H0EEEE0?ooo`3oool0oooo0000001EEED20:ZZ
ZP030000003oool0oooo00X0dLfY00@0oooo0:ZZZP3oool0EEEE0`2ZZZX0103oool0ZZZZ0:ZZZP2Z
ZZX2000000030?ooo`1EEED0oooo0080ZZZZ00D0oooo0:ZZZP000000EEEE0:ZZZP0405EEE@080:ZZ
ZP000000oooo05EEE@3oool0ZZZZ0?ooo`1EEED40:ZZZP0305EEE@3oool0ZZZZ0080EEEE00@0oooo
0:ZZZP2ZZZX0ZZZZ0`1EEED0302ZZZX0EEEE0?ooo`2ZZZX0oooo0000002ZZZX0oooo05EEE@3oool0
ZZZZ000000<0ZZZZ00<0oooo0:ZZZP2ZZZX00P1EEED30?ooo`X0dLfY00@0oooo0:ZZZP3oool0oooo
1`1EEED00`2ZZZX0oooo0?ooo`0200000080EEEE00<0ZZZZ0000002ZZZX00P2ZZZX2000000040:ZZ
ZP000000oooo00000080ZZZZ00<0EEEE0:ZZZP0000000P3oool200000080oooo00<000000:ZZZP3o
ool00P2ZZZX20?ooo`80ZZZZ0P0000020:ZZZP80000000<0ZZZZ05EEE@1EEED00P0000000`3oool0
ZZZZ0:ZZZP0705EEE@@0oooo303AcJT000/0dLfY0`3oool00`2ZZZX0EEEE0?ooo`02000000050?oo
o`00000000000000002ZZZX00P3oool00`000000ZZZZ0:ZZZP03000000030:ZZZP000000EEEE00`0
EEEE0P00000<05EEE@80000000@0ZZZZ00000000000000000`2ZZZX20?ooo`<0000000<0EEEE0?oo
o`0000000P3oool00`000000ZZZZ0?ooo`020?ooo`X0dLfY0`3oool0102ZZZX000000?ooo`1EEED2
0?ooo`050000002ZZZX0ZZZZ0000002ZZZX00P0000000`2ZZZX000000:ZZZP020:ZZZPL0000000<0
ZZZZ0000003oool00P2ZZZX0103oool0ZZZZ0000003oool3000000040?ooo`2ZZZX0ZZZZ0?ooo`<0
000000<0ZZZZ000000000000100000040:ZZZP80000000D0ZZZZ0000002ZZZX0ZZZZ000000040?oo
o`030000002ZZZX0oooo0080oooo2P3AcJT30?ooo`<0ZZZZ00H0EEEE0000002ZZZX0000005EEE@2Z
ZZX30000000405EEE@3oool0oooo05EEE@<0000000H0EEEE0000002ZZZX0EEEE0000003oool30:ZZ
ZP030000002ZZZX0ZZZZ0080000000<0oooo0:ZZZP0000000`2ZZZX02P000000ZZZZ0:ZZZP000000
oooo0000001EEED0ZZZZ0?ooo`1EEED30000000405EEE@000000oooo05EEE@8000000P2ZZZX205EE
E@060:ZZZP00000000000:ZZZP000000ZZZZ0`3oool:0=7=Z@<0oooo0P2ZZZX010000000oooo0?oo
o`3oool205EEE@@0oooo00D000000:ZZZP3oool000000?ooo`0205EEE@80oooo00<0EEEE0?ooo`3o
ool01P1EEED00`3oool0ZZZZ0:ZZZP040:ZZZP030?ooo`1EEED0EEEE0080EEEE00D0oooo05EEE@1E
EED0oooo05EEE@020?ooo`80EEEE00D0oooo0000003oool0ZZZZ05EEE@020?ooo`030:ZZZP3oool0
EEEE00@0oooo00<000000:ZZZP2ZZZX00`3oool:0=7=Z@<0oooo00T0ZZZZ0?ooo`2ZZZX000000:ZZ
ZP3oool0ZZZZ0000002ZZZX00P3oool205EEE@0=0?ooo`1EEED0oooo0000002ZZZX0oooo0:ZZZP00
0000oooo05EEE@3oool000000?ooo`0205EEE@030?ooo`00000000000080ZZZZ0P0000020:ZZZP80
000000<0oooo05EEE@1EEED00P00000205EEE@040?ooo`000000ZZZZ0?ooo`80000000<0oooo0000
003oool00P1EEED01P3oool000000:ZZZP000000ZZZZ0?ooo`D0ZZZZ0`3oool<0=7=Z@002`3AcJT4
0?ooo`070:ZZZP1EEED0ZZZZ0:ZZZP3oool0EEEE0000000205EEE@0:0:ZZZP3oool000000:ZZZP00
0000ZZZZ05EEE@2ZZZX000000:ZZZPd0000000<0ZZZZ00000000000030000000102ZZZX000000000
001EEED30:ZZZP0305EEE@3oool0ZZZZ0080EEEE00L0000005EEE@3oool0ZZZZ0?ooo`1EEED0ZZZZ
00@0oooo2P3AcJT40?ooo`030:ZZZP3oool0ZZZZ0080ZZZZ00X000000:ZZZP000000EEEE0000001E
EED0000005EEE@000000oooo0P0000001@3oool0EEEE0000001EEED0000000<0ZZZZ00@0oooo0:ZZ
ZP000000EEEE0P2ZZZX00`3oool0ZZZZ0:ZZZP020?ooo`040:ZZZP1EEED0EEEE0:ZZZP80oooo00L0
ZZZZ000000000000EEEE0000001EEED0oooo0080000000D0oooo05EEE@1EEED0oooo05EEE@030000
00@0ZZZZ00<0EEEE0?ooo`2ZZZX0103oool:0=7=Z@@0oooo00X0000005EEE@3oool000000:ZZZP1E
EED0oooo0000002ZZZX0oooo0`2ZZZX01@1EEED0oooo0000003oool000000080ZZZZ00X0EEEE0000
002ZZZX0ZZZZ05EEE@000000EEEE0:ZZZP1EEED000000P2ZZZX20?ooo`070:ZZZP1EEED0000005EE
E@2ZZZX0EEEE000000020:ZZZP030?ooo`000000EEEE0080ZZZZ00@000000:ZZZP000000oooo0P2Z
ZZX00`000000ZZZZ0?ooo`02000000040?ooo`1EEED0ZZZZ00000080EEEE00<0ZZZZ0?ooo`3oool0
0P3oool:0=7=Z@D0oooo0`1EEED01@3oool0EEEE05EEE@1EEED0ZZZZ0080000000H0ZZZZ0?ooo`3o
ool0oooo05EEE@2ZZZX505EEE@030000002ZZZX0EEEE00D0EEEE00<0ZZZZ0?ooo`2ZZZX00`3oool5
05EEE@80ZZZZ00@0oooo05EEE@1EEED0oooo101EEED30?ooo`040:ZZZP00000000000?ooo`<0EEEE
00D0oooo05EEE@3oool0EEEE0:ZZZP040?ooo`X0dLfY1@3oool00`000000oooo05EEE@030:ZZZP80
oooo101EEED2000000090:ZZZP3oool0oooo0?ooo`2ZZZX0oooo0000003oool0ZZZZ00<0000000<0
ZZZZ0000002ZZZX00P2ZZZX00`3oool0ZZZZ0:ZZZP020:ZZZP040000003oool0000000000080ZZZZ
0P000000103oool0ZZZZ0?ooo`3oool20:ZZZP030000003oool0EEEE00@0EEEE00P0oooo0:ZZZP2Z
ZZX0ZZZZ05EEE@3oool000000:ZZZP@0oooo303AcJT000/0dLfY1@3oool02@2ZZZX0000000000000
0000EEEE0000001EEED0oooo000000030?ooo`040000001EEED0oooo0?ooo`80EEEE3@0000000`1E
EED0oooo0000000;000000030?ooo`1EEED0EEEE0080oooo00D0EEEE0?ooo`3oool0ZZZZ0?ooo`02
0000000305EEE@000000ZZZZ0080000000<0EEEE0:ZZZP3oool0103oool:0=7=Z@D0oooo0`2ZZZX0
103oool000000000003oool2000000@0ZZZZ00<0oooo05EEE@2ZZZX00P2ZZZX01@1EEED0ZZZZ0?oo
o`000000ZZZZ00<0oooo0P0000030?ooo`030000002ZZZX0oooo0080oooo0P0000030?ooo`80ZZZZ
00<0oooo0:ZZZP0000000`2ZZZX00`1EEED0oooo05EEE@030:ZZZP030000002ZZZX0oooo00800000
00@0oooo0:ZZZP1EEED0ZZZZ1@3oool:0=7=Z@D0oooo00@0ZZZZ05EEE@1EEED0EEEE0P2ZZZX01000
0000oooo0?ooo`3oool20:ZZZP0B0?ooo`00000000000?ooo`000000ZZZZ05EEE@3oool000000?oo
o`1EEED0ZZZZ0000002ZZZX0EEEE0?ooo`000000EEEE1@3oool01@000000oooo05EEE@2ZZZX00000
0080EEEE00L0oooo0000003oool0EEEE0:ZZZP000000oooo00<0000000@0ZZZZ0?ooo`3oool0oooo
0P0000020:ZZZP80EEEE00<000000:ZZZP3oool0103oool:0=7=Z@D0oooo0P2ZZZX00`3oool0EEEE
000000030:ZZZP040?ooo`1EEED0ZZZZ05EEE@80oooo102ZZZX01`3oool0EEEE0:ZZZP1EEED0oooo
0:ZZZP0000000P2ZZZX01@000000ZZZZ0000003oool0EEEE0080oooo0P2ZZZX02P000000ZZZZ0:ZZ
ZP000000EEEE0?ooo`1EEED0ZZZZ05EEE@3oool40:ZZZP80oooo00D0EEEE0:ZZZP1EEED0oooo0000
00030:ZZZP0405EEE@3oool0ZZZZ0:ZZZPD0oooo2P3AcJT50?ooo`80ZZZZ00<000000?ooo`1EEED0
0P000000101EEED0oooo0?ooo`1EEED20?ooo`030:ZZZP3oool0ZZZZ0080ZZZZ00T000000:ZZZP2Z
ZZX0ZZZZ0000002ZZZX0EEEE0?ooo`2ZZZX00P00000205EEE@80000000@0EEEE0000000000000000
0P3oool00`1EEED0oooo000000030:ZZZP070?ooo`2ZZZX0ZZZZ0000003oool0ZZZZ05EEE@040?oo
o`<0000000<0EEEE0?ooo`0000000P2ZZZX50?ooo``0dLfY000;0=7=Z@H0oooo00T0000005EEE@2Z
ZZX0ZZZZ0?ooo`2ZZZX0EEEE0000001EEED00P3oool6000000d0EEEE0P00000905EEE@030000001E
EED0EEEE00<0000000<0EEEE0000000000000P3oool02P000000EEEE000000000000ZZZZ0?ooo`00
0000ZZZZ05EEE@2ZZZX60?ooo`X0dLfY1P3oool2000000040?ooo`1EEED0oooo0?ooo`D000000P3o
ool300000080ZZZZ0P3oool2000000<0oooo00<0EEEE0000003oool00P3oool2000000<0oooo00<0
00000?ooo`3oool00P3oool200000080oooo00T000000:ZZZP000000ZZZZ0000003oool0ZZZZ0000
002ZZZX00`0000040?ooo`030000002ZZZX0oooo00D0oooo2P3AcJT60?ooo`070000002ZZZX0ZZZZ
05EEE@000000ZZZZ000000030?ooo`80ZZZZ00L0EEEE0:ZZZP2ZZZX0ZZZZ05EEE@3oool0EEEE00@0
ZZZZ00<0EEEE0:ZZZP2ZZZX00P2ZZZX01P3oool000000?ooo`3oool0000005EEE@80ZZZZ00@00000
0:ZZZP1EEED000000`2ZZZX00`1EEED0000005EEE@030:ZZZP0305EEE@3oool0ZZZZ00@0oooo00<0
ZZZZ0000000000000`2ZZZX60?ooo`X0dLfY1`3oool205EEE@050?ooo`2ZZZX0EEEE0?ooo`000000
0`2ZZZX010000000ZZZZ0?ooo`2ZZZX20?ooo`030000003oool000000080000000D0EEEE0?ooo`3o
ool0oooo05EEE@020?ooo`030:ZZZP3oool000000080ZZZZ00<0oooo05EEE@2ZZZX00P3oool01P2Z
ZZX000000?ooo`000000oooo0:ZZZP@0oooo00<0ZZZZ0000002ZZZX00P2ZZZX00`000000oooo05EE
E@020:ZZZP80EEEE00<0ZZZZ0?ooo`3oool0103oool:0=7=Z@P0oooo0`1EEED0102ZZZX0EEEE05EE
E@3oool205EEE@040:ZZZP3oool0EEEE0:ZZZP80oooo1@2ZZZX00`000000oooo000000020?ooo`0;
05EEE@000000000005EEE@3oool000000?ooo`1EEED0oooo0:ZZZP0000000P3oool40:ZZZP030000
003oool0oooo0080EEEE00D0oooo0000001EEED0EEEE0?ooo`0205EEE@060:ZZZP1EEED0EEEE05EE
E@3oool0ZZZZ1P3oool<0=7=Z@002`3AcJT60?ooo`80ZZZZ0P1EEED00`2ZZZX0oooo05EEE@0205EE
E@80oooo0P0000000`3oool0ZZZZ00000002000000030?ooo`2ZZZX0000000T0000000<0ZZZZ0000
000000002@0000000`2ZZZX0oooo0:ZZZP03000000030?ooo`000000oooo0080oooo0P1EEED20?oo
o`040:ZZZP1EEED0EEEE0:ZZZPL0oooo2P3AcJT60?ooo`80ZZZZ00D0oooo0:ZZZP2ZZZX0ZZZZ0000
00020:ZZZP8000000P3oool01@000000ZZZZ05EEE@1EEED000000080oooo00<0EEEE0000003oool0
0P3oool00`000000ZZZZ0:ZZZP020:ZZZP030000002ZZZX0ZZZZ00<0ZZZZ103oool01@000000oooo
0?ooo`3oool0000000<0EEEE00<000000?ooo`0000000P0000050:ZZZP0305EEE@3oool0ZZZZ00L0
oooo2P3AcJT60?ooo`060:ZZZP000000EEEE0?ooo`000000ZZZZ0`3oool010000000oooo0?ooo`00
000205EEE@090000001EEED0oooo0000001EEED000000?ooo`2ZZZX000000080ZZZZ00<0000005EE
E@1EEED0103oool01@2ZZZX0EEEE0000001EEED0ZZZZ0080000000H0oooo0000001EEED000000?oo
o`1EEED20000000305EEE@000000000000@0oooo00<0EEEE0:ZZZP0000000P1EEED00`000000oooo
0?ooo`050?ooo`X0dLfY1P3oool01@2ZZZX000000:ZZZP3oool0EEEE00<0ZZZZ00H0oooo0000003o
ool0EEEE0?ooo`2ZZZX2000000030:ZZZP1EEED0oooo0080EEEE00@0oooo000000000000ZZZZ0P1E
EED20:ZZZP0405EEE@3oool0oooo05EEE@80ZZZZ00@0EEEE0?ooo`2ZZZX000000`3oool0101EEED0
oooo0?ooo`2ZZZX2000000030:ZZZP3oool0oooo00<0oooo00<0ZZZZ05EEE@2ZZZX00P1EEED00`2Z
ZZX000000?ooo`060?ooo`X0dLfY1P3oool00`2ZZZX0000000000003000000030:ZZZP000000EEEE
0080EEEE00<0ZZZZ0?ooo`0000000`3oool0101EEED0ZZZZ0?ooo`2ZZZX205EEE@030?ooo`1EEED0
ZZZZ008000000P2ZZZX2000000060:ZZZP00000000000000003oool0EEEE0P3oool0101EEED0oooo
0?ooo`2ZZZX30?ooo`80000000<0oooo05EEE@1EEED00P1EEED00`000000EEEE00000004000000L0
oooo303AcJT000/0dLfY203oool01P2ZZZX000000?ooo`3oool0000005EEE@<0oooo00H0000005EE
E@1EEED0oooo0000002ZZZX20?ooo`/0000000<0EEEE0?ooo`0000002P000000103oool000000:ZZ
ZP00000305EEE@060000003oool0oooo0?ooo`1EEED000000P3oool00`1EEED0ZZZZ0?ooo`070?oo
o`X0dLfY203oool30:ZZZP060?ooo`00000000000?ooo`2ZZZX000000`3oool00`2ZZZX0oooo0000
00040:ZZZP060000002ZZZX0EEEE0000002ZZZX000000P2ZZZX2000000080:ZZZP000000ZZZZ0:ZZ
ZP000000EEEE0000001EEED2000000<0ZZZZ00@0oooo0000003oool000000`3oool00`000000ZZZZ
0?ooo`02000000040?ooo`2ZZZX0EEEE0:ZZZPP0oooo2P3AcJT80?ooo`040:ZZZP1EEED0EEEE05EE
E@D0ZZZZ00<0EEEE0:ZZZP0000000P2ZZZX205EEE@080:ZZZP000000ZZZZ0:ZZZP1EEED000000?oo
o`2ZZZX205EEE@D0ZZZZ0`1EEED00`000000oooo000000030:ZZZP040000002ZZZX0000005EEE@80
ZZZZ00<000000:ZZZP0000001@2ZZZX205EEE@030000002ZZZX0oooo00L0oooo2P3AcJT80?ooo`03
0:ZZZP1EEED0oooo0080EEEE00L0oooo05EEE@000000000005EEE@3oool0ZZZZ0080EEEE0`3oool2
05EEE@040:ZZZP3oool0EEEE05EEE@<0ZZZZ0P000000101EEED0oooo0000000000020:ZZZP050?oo
o`1EEED0EEEE0000002ZZZX00P1EEED01P3oool000000?ooo`1EEED000000:ZZZP80oooo00<00000
05EEE@1EEED00P3oool0101EEED0oooo0?ooo`2ZZZX80?ooo`X0dLfY203oool01P2ZZZX000000?oo
o`3oool0ZZZZ00000080oooo00<0000005EEE@2ZZZX00P2ZZZX02P000000oooo05EEE@3oool00000
0?ooo`1EEED000000?ooo`00000205EEE@030000003oool0ZZZZ008000000P2ZZZX010000000EEEE
0?ooo`0000020?ooo`0305EEE@000000000000<0oooo00X000000:ZZZP2ZZZX0ZZZZ05EEE@000000
EEEE0?ooo`000000EEEE0`3oool00`2ZZZX0oooo0?ooo`060?ooo``0dLfY000;0=7=Z@T0oooo00D0
000005EEE@000000ZZZZ000000020?ooo`D0000000@0EEEE0:ZZZP00000000002`1EEED2000000/0
EEEE00@0000005EEE@2ZZZX0EEEE0`000000103oool000000?ooo`3oool30000000305EEE@2ZZZX0
oooo00P0oooo2P3AcJT90?ooo`80000000D0oooo05EEE@3oool0oooo000000040:ZZZP<0oooo00<0
ZZZZ0000000000000`0000000`2ZZZX0oooo00000004000000040:ZZZP1EEED000000:ZZZP800000
00<0ZZZZ0?ooo`2ZZZX00P000000103oool000000000001EEED20?ooo`D0ZZZZ00<000000?ooo`3o
ool00P3oool00`000000ZZZZ0?ooo`080?ooo`X0dLfY2@3oool02@000000ZZZZ0:ZZZP1EEED00000
0:ZZZP000000EEEE0:ZZZP02000000<0EEEE00<0ZZZZ0000000000000`1EEED20:ZZZP0705EEE@00
0000oooo0000001EEED0ZZZZ0000000205EEE@030?ooo`000000ZZZZ0080ZZZZ0P1EEED300000003
0:ZZZP1EEED0EEEE00<0000000@0ZZZZ05EEE@1EEED0ZZZZ0P0000030:ZZZPT0oooo2P3AcJT90?oo
o`060000002ZZZX000000000002ZZZX000000P3oool205EEE@030?ooo`2ZZZX000000080ZZZZ00@0
00000?ooo`000000oooo0`1EEED00`3oool0ZZZZ0?ooo`020?ooo`80EEEE00@0oooo05EEE@3oool0
ZZZZ0`1EEED20?ooo`080000003oool000000?ooo`2ZZZX000000:ZZZP3oool205EEE@030?ooo`1E
EED000000080ZZZZ00<000000:ZZZP2ZZZX02@3oool:0=7=Z@T0oooo00D000000:ZZZP0000000000
0?ooo`0205EEE@030?ooo`000000oooo0080oooo00D0EEEE0000001EEED0EEEE0?ooo`0205EEE@<0
oooo0`1EEED01P3oool0000005EEE@3oool000000:ZZZP<0EEEE0P3oool205EEE@070000003oool0
EEEE05EEE@000000EEEE0:ZZZP020?ooo`040000003oool0EEEE05EEE@80oooo00<000000:ZZZP2Z
ZZX02@3oool<0=7=Z@002`3AcJT:0?ooo`060:ZZZP3oool000000000001EEED000000P1EEED00`3o
ool0000000000002000000080:ZZZP1EEED000000:ZZZP000000ZZZZ05EEE@00000405EEE@800000
00<0ZZZZ0000001EEED00`1EEED01P000000EEEE000000000000EEEE00000080EEEE100000001@3o
ool0EEEE05EEE@000000EEEE0080000000<0oooo0:ZZZP3oool02@3oool:0=7=Z@X0oooo00X0ZZZZ
0?ooo`1EEED0000005EEE@000000ZZZZ05EEE@2ZZZX000000`2ZZZX200000080EEEE00L000000:ZZ
ZP1EEED0oooo0:ZZZP3oool0ZZZZ008000000P2ZZZX01`000000ZZZZ0:ZZZP3oool0ZZZZ0?ooo`1E
EED00P00000205EEE@030000002ZZZX0ZZZZ0080ZZZZ00<000000:ZZZP1EEED00P2ZZZX01@1EEED0
000005EEE@3oool0ZZZZ00X0oooo2P3AcJT:0?ooo`080:ZZZP000000ZZZZ0:ZZZP1EEED0oooo05EE
E@2ZZZX20?ooo`040:ZZZP000000EEEE0:ZZZP80oooo00H000000:ZZZP3oool0ZZZZ0000002ZZZX2
00000080ZZZZ00@000000:ZZZP2ZZZX0EEEE0P0000001P2ZZZX000000:ZZZP3oool0ZZZZ00000080
oooo00<0ZZZZ05EEE@0000000`3oool0102ZZZX0EEEE0000001EEED20:ZZZP030000002ZZZX0oooo
00T0oooo2P3AcJT:0?ooo`030:ZZZP3oool0EEEE00<0ZZZZ00@0oooo05EEE@3oool0oooo10000000
0`3oool0ZZZZ0?ooo`0505EEE@80ZZZZ0`3oool00`1EEED0oooo0:ZZZP020:ZZZPD0EEEE00<00000
0:ZZZP3oool00`0000001@2ZZZX0oooo0?ooo`2ZZZX0oooo00<0ZZZZ00<0EEEE0?ooo`2ZZZX02P3o
ool:0=7=Z@X0oooo00<0ZZZZ0?ooo`1EEED0101EEED0103oool000000000001EEED4000000030?oo
o`2ZZZX0ZZZZ00<0ZZZZ00H0oooo05EEE@3oool0ZZZZ0000003oool3000000030?ooo`1EEED00000
0080ZZZZ00H000000:ZZZP000000oooo0000003oool2000000030?ooo`000000000000D0EEEE0P3o
ool00`2ZZZX0oooo0?ooo`080?ooo``0dLfY000;0=7=Z@/0oooo00<0ZZZZ0000002ZZZX01@000000
2`1EEED0000005EEE@1EEED0oooo0000002ZZZX0oooo05EEE@3oool0ZZZZ00H0000000<0EEEE0?oo
o`0000001@0000001P2ZZZX0oooo05EEE@000000ZZZZ000000D0EEEE0`0000001@3oool000000:ZZ
ZP1EEED0ZZZZ00/0oooo2P3AcJT;0?ooo`<0ZZZZ00@0oooo000000000000ZZZZ0P000000102ZZZX0
00000000000000050:ZZZP0405EEE@2ZZZX0oooo0:ZZZP80EEEE00<000000?ooo`0000000P000000
201EEED0ZZZZ0?ooo`2ZZZX0EEEE0000002ZZZX0EEEE0`2ZZZX5000000070?ooo`00000000000?oo
o`2ZZZX0EEEE0:ZZZP0;0?ooo`X0dLfY2`3oool0102ZZZX0EEEE05EEE@1EEED20:ZZZP040000003o
ool0oooo0?ooo`80ZZZZ00@000000?ooo`3oool0ZZZZ0`3oool0102ZZZX0EEEE0:ZZZP2ZZZX205EE
E@8000000P1EEED20:ZZZP030000002ZZZX0oooo0080oooo00@000000?ooo`3oool000000P2ZZZX3
0?ooo`030000002ZZZX0ZZZZ0080EEEE00<000000:ZZZP3oool02P3oool:0=7=Z@/0oooo0P2ZZZX0
101EEED0oooo0?ooo`3oool2000000030:ZZZP1EEED0oooo00@0oooo00@0ZZZZ05EEE@1EEED0EEEE
0P2ZZZX0301EEED0oooo0?ooo`000000EEEE0:ZZZP000000ZZZZ0?ooo`1EEED000000:ZZZP<0EEEE
00@0ZZZZ0?ooo`3oool0EEEE0`3oool02@2ZZZX000000?ooo`3oool0ZZZZ0?ooo`1EEED000000:ZZ
ZP0;0?ooo`X0dLfY2`3oool00`2ZZZX0000000000002000000060?ooo`000000ZZZZ0:ZZZP000000
oooo0P1EEED0103oool000000:ZZZP2ZZZX20?ooo`050000001EEED0EEEE05EEE@0000000P3oool0
0`1EEED0oooo0?ooo`0205EEE@030?ooo`000000oooo00<0ZZZZ00H000000?ooo`3oool0EEEE0?oo
o`0000020:ZZZP030000003oool0000000<0000000<0ZZZZ0?ooo`3oool02@3oool<0=7=Z@002`3A
cJT<0?ooo`030000001EEED0oooo00@0000000<0oooo0000000000000P0000002P1EEED0ZZZZ0000
00000000EEEE0000003oool000000:ZZZP00000205EEE@8000000P1EEED010000000ZZZZ0000003o
ool30000000305EEE@2ZZZX0EEEE00<0000000D0ZZZZ0?ooo`000000oooo000000020?ooo`0305EE
E@2ZZZX0oooo00/0oooo2P3AcJT<0?ooo`80000000<0oooo05EEE@3oool0100000020:ZZZP800000
0P2ZZZX2000000040:ZZZP3oool0oooo0?ooo`80ZZZZ00H0oooo0:ZZZP2ZZZX0oooo0000002ZZZX3
0?ooo`050:ZZZP000000000005EEE@2ZZZX00P0000020:ZZZP<00000103oool00`000000ZZZZ0?oo
o`0;0?ooo`X0dLfY303oool01`000000ZZZZ0:ZZZP1EEED000000?ooo`0000000`3oool40:ZZZPD0
oooo00T0ZZZZ000000000000ZZZZ0000003oool0ZZZZ0000002ZZZX00P0000000`2ZZZX0oooo0?oo
o`020?ooo`<0ZZZZ00<0oooo0:ZZZP3oool00P3oool010000000ZZZZ0000000000030:ZZZP`0oooo
2P3AcJT<0?ooo`80ZZZZ00T000000?ooo`3oool0oooo05EEE@3oool000000:ZZZP0000000P1EEED5
000000040?ooo`1EEED0ZZZZ00000080oooo00H0ZZZZ05EEE@3oool0oooo0000002ZZZX20?ooo`03
0000003oool000000080000000<0EEEE0?ooo`0000000P2ZZZX00`3oool0EEEE0?ooo`020?ooo`03
0000002ZZZX0ZZZZ00`0oooo2P3AcJT<0?ooo`040:ZZZP3oool0ZZZZ000000@0ZZZZ00<0oooo0:ZZ
ZP0000000P1EEED01P3oool000000?ooo`2ZZZX000000?ooo`<0EEEE00D0oooo0000001EEED0ZZZZ
0000000405EEE@030?ooo`000000oooo00<0oooo0P1EEED00`000000ZZZZ0:ZZZP020:ZZZP060?oo
o`2ZZZX0ZZZZ0:ZZZP3oool0ZZZZ303oool<0=7=Z@002`3AcJT=0?ooo`040:ZZZP3oool0oooo05EE
E@80000000@0EEEE0:ZZZP3oool000000P1EEED50000000305EEE@00000000000080EEEE0P000000
102ZZZX0000005EEE@1EEED20000000305EEE@000000000000<0000000H0EEEE0:ZZZP000000oooo
0000001EEED20000000405EEE@000000oooo0:ZZZPd0oooo2P3AcJT=0?ooo`070:ZZZP3oool0EEEE
0000002ZZZX000000:ZZZP02000000040:ZZZP000000oooo0?ooo`80000000<0EEEE0?ooo`3oool0
1P3oool00`000000oooo05EEE@050?ooo`<000000P3oool20:ZZZP090000001EEED0ZZZZ0000001E
EED0000005EEE@3oool0ZZZZ00d0oooo2P3AcJT=0?ooo`050:ZZZP000000ZZZZ0:ZZZP000000103o
ool01P1EEED0ZZZZ0:ZZZP1EEED0oooo000000@0oooo00<000000?ooo`2ZZZX0103oool010000000
oooo0000000000030?ooo`030000002ZZZX0EEEE0080ZZZZ00<0EEEE0?ooo`3oool00P3oool01@1E
EED0ZZZZ0:ZZZP000000ZZZZ00d0oooo2P3AcJT=0?ooo`040:ZZZP00000000000:ZZZP<0EEEE00H0
oooo0:ZZZP3oool0oooo05EEE@0000040:ZZZP030000003oool000000080oooo1@2ZZZX01`3oool0
0000000000000000ZZZZ05EEE@2ZZZX00P000000101EEED0oooo0?ooo`2ZZZX305EEE@<0ZZZZ00<0
00000:ZZZP3oool0303oool:0=7=Z@d0oooo00<0ZZZZ0000000000000`3oool01P2ZZZX0oooo0000
00000000ZZZZ00000080ZZZZ0P3oool705EEE@80oooo1`1EEED20?ooo`80ZZZZ00`000000:ZZZP00
000000000?ooo`2ZZZX0oooo0000003oool0ZZZZ0000002ZZZX=0?ooo``0dLfY000;0=7=Z@h0oooo
00@0ZZZZ000000000000ZZZZ0P0000002@3oool0EEEE0:ZZZP2ZZZX0oooo0000002ZZZX0EEEE0:ZZ
ZP02000000030?ooo`00000000000080000000<0EEEE0?ooo`0000001`0000001`1EEED000000000
003oool000000:ZZZP1EEED01@0000000`1EEED0ZZZZ0?ooo`0=0?ooo`X0dLfY3P3oool30:ZZZP<0
00000P2ZZZX020000000ZZZZ0:ZZZP2ZZZX000000:ZZZP3oool000000`3oool00`000000ZZZZ05EE
E@020?ooo`0305EEE@3oool0000000<0oooo00<000000:ZZZP2ZZZX00`2ZZZX2000000080:ZZZP3o
ool000000000003oool0ZZZZ05EEE@2ZZZX>0?ooo`X0dLfY3P3oool00`2ZZZX0EEEE05EEE@060:ZZ
ZP0405EEE@2ZZZX0000005EEE@@0oooo00<0EEEE0:ZZZP2ZZZX01@3oool30:ZZZPD0oooo00@0ZZZZ
0000002ZZZX000001@2ZZZX205EEE@030000002ZZZX0oooo00d0oooo2P3AcJT>0?ooo`80ZZZZ00@0
oooo0:ZZZP000000ZZZZ100000000`3oool0EEEE0?ooo`02000000<0oooo00<0EEEE0?ooo`2ZZZX0
102ZZZX0101EEED0oooo05EEE@1EEED30?ooo`050000003oool0EEEE0?ooo`2ZZZX00P0000020:ZZ
ZP030000001EEED0oooo0080ZZZZ3P3oool:0=7=Z@h0oooo0P2ZZZX01P000000EEEE05EEE@000000
ZZZZ000000<0ZZZZ00L0oooo0000003oool000000?ooo`000000oooo00@0000000@0ZZZZ00000000
0000oooo100000000`3oool0ZZZZ0?ooo`020?ooo`<0ZZZZ0`0000000`1EEED0oooo000000020:ZZ
ZPh0oooo303AcJT000/0dLfY3`3oool030000000EEEE0000002ZZZX000000:ZZZP3oool0000005EE
E@2ZZZX0oooo0:ZZZP8000000`1EEED010000000EEEE05EEE@1EEED2000000<0EEEE0P00000205EE
E@0:0?ooo`000000ZZZZ0?ooo`2ZZZX0EEEE0000003oool0EEEE00000080ZZZZ00<0EEEE0:ZZZP3o
ool03P3oool:0=7=Z@l0oooo0P0000000`3oool0EEEE0?ooo`02000000040:ZZZP00000000000:ZZ
ZP80000000P0EEEE0?ooo`000000oooo0000003oool0ZZZZ00000080oooo00P0000005EEE@3oool0
00000?ooo`000000oooo0:ZZZP80000000D0ZZZZ0000002ZZZX0ZZZZ000000020?ooo`0405EEE@3o
ool000000:ZZZPl0oooo2P3AcJT?0?ooo`090000002ZZZX0000005EEE@000000EEEE0000001EEED0
ZZZZ008000001P2ZZZX3000000D0oooo0P0000050:ZZZP<0000000H0ZZZZ05EEE@000000ZZZZ0000
001EEED30:ZZZPl0oooo2P3AcJT@0?ooo`0405EEE@2ZZZX0oooo0:ZZZP80oooo00D0EEEE0:ZZZP2Z
ZZX0EEEE0?ooo`0205EEE@050?ooo`1EEED0EEEE0?ooo`0000001P2ZZZX010000000oooo05EEE@1E
EED20?ooo`<0EEEE00L0ZZZZ0?ooo`1EEED0oooo05EEE@2ZZZX0oooo0080EEEE00<0ZZZZ0?ooo`3o
ool03@3oool:0=7=ZA40oooo101EEED02`3oool000000?ooo`000000oooo0000002ZZZX0EEEE0?oo
o`1EEED000000080ZZZZ00H0000005EEE@000000oooo05EEE@3oool20:ZZZP040?ooo`1EEED0oooo
0?ooo`80ZZZZ00H0oooo0000003oool000000?ooo`2ZZZX305EEE@030?ooo`2ZZZX0oooo00h0oooo
303AcJT000/0dLfY403oool01@2ZZZX000000:ZZZP3oool0EEEE0080ZZZZ00@0000005EEE@3oool0
00000P1EEED00`000000ZZZZ0:ZZZP05000000030?ooo`000000oooo008000000P2ZZZX200000005
05EEE@2ZZZX0oooo05EEE@0000000P2ZZZX20?ooo`030:ZZZP3oool0ZZZZ0100oooo2P3AcJT@0?oo
o`080:ZZZP1EEED0EEEE0000002ZZZX000000:ZZZP1EEED20:ZZZP80oooo00L0EEEE0?ooo`2ZZZX0
oooo0:ZZZP3oool0EEEE00@0oooo00T0EEEE0?ooo`2ZZZX0oooo0:ZZZP3oool0EEEE0?ooo`000000
0P2ZZZX0201EEED0ZZZZ0000001EEED0000005EEE@3oool0ZZZZ403oool:0=7=ZA00oooo102ZZZX0
10000000oooo05EEE@2ZZZX20?ooo`080:ZZZP00000000000:ZZZP3oool0EEEE0000001EEED50?oo
o`030000001EEED000000080oooo00<0ZZZZ0?ooo`0000000`3oool0102ZZZX0EEEE0?ooo`1EEED2
0:ZZZP030000002ZZZX0oooo00l0oooo2P3AcJT@0?ooo`80ZZZZ00H000000?ooo`3oool000000?oo
o`1EEED20?ooo`<0EEEE0P3oool01@000000oooo0000003oool0ZZZZ008000000P2ZZZX00`000000
oooo000000020?ooo`<0EEEE103oool2000000040?ooo`000000ZZZZ0:ZZZQ00oooo2P3AcJT@0?oo
o`030:ZZZP3oool0ZZZZ0080ZZZZ00L0EEEE0?ooo`2ZZZX0oooo05EEE@000000oooo00@0EEEE0P2Z
ZZX01P3oool000000000003oool0000005EEE@80ZZZZ0`1EEED02@2ZZZX0oooo0:ZZZP1EEED0oooo
0:ZZZP3oool0EEEE000000040:ZZZQ00oooo303AcJT000/0dLfY4@3oool0101EEED000000?ooo`00
00020:ZZZP80EEEE0P3oool01P2ZZZX000000000002ZZZX000000:ZZZP80000000<0EEEE0?ooo`2Z
ZZX00P1EEED010000000ZZZZ0:ZZZP2ZZZX200000080ZZZZ00<0oooo05EEE@0000000P2ZZZX20?oo
o`030000002ZZZX0oooo0100oooo2P3AcJTA0?ooo`0305EEE@2ZZZX0ZZZZ00<0000000<0ZZZZ0000
000000000P2ZZZX00`1EEED0ZZZZ0?ooo`020?ooo`H0ZZZZ00<0EEEE0:ZZZP3oool00P3oool40:ZZ
ZP80000000@0oooo000000000000oooo0`2ZZZXA0?ooo`X0dLfY4@3oool00`000000EEEE05EEE@03
0:ZZZP040000003oool0oooo0?ooo`80ZZZZ0`3oool205EEE@H0ZZZZ0P1EEED00`000000oooo0?oo
o`020:ZZZP<0oooo00<000000:ZZZP2ZZZX00`1EEED00`2ZZZX0oooo0?ooo`0?0?ooo`X0dLfY4P3o
ool01P1EEED0oooo0?ooo`1EEED0oooo05EEE@80ZZZZ101EEED40?ooo`80ZZZZ00@0oooo0:ZZZP2Z
ZZX0EEEE0P3oool0101EEED0oooo05EEE@2ZZZX205EEE@80ZZZZ00L0EEEE0?ooo`1EEED0EEEE0?oo
o`1EEED0ZZZZ0140oooo2P3AcJTB0?ooo`080000003oool0EEEE0:ZZZP000000oooo0000002ZZZX2
0?ooo`D0000000D0EEEE0:ZZZP00000000000:ZZZP020000000305EEE@000000oooo008000000P3o
ool01P1EEED0ZZZZ0000003oool000000:ZZZP80oooo00<000000:ZZZP3oool0403oool<0=7=Z@00
2`3AcJTB0?ooo`80ZZZZ00D0000005EEE@3oool000000:ZZZP020000000305EEE@2ZZZX0oooo0080
oooo00@0EEEE0000001EEED000000P3oool01@000000EEEE0000001EEED0000000<0oooo00H0EEEE
000000000000ZZZZ0000003oool205EEE@80ZZZZ4P3oool:0=7=ZA80oooo0P2ZZZX01P1EEED0ZZZZ
0:ZZZP2ZZZX000000:ZZZP<000001@3oool30:ZZZP0305EEE@2ZZZX0oooo00D0oooo0P0000020:ZZ
ZP050000002ZZZX0ZZZZ0:ZZZP3oool00P2ZZZXB0?ooo`X0dLfY4P3oool01P2ZZZX0000005EEE@3o
ool0000005EEE@<0oooo0P0000020?ooo`040000001EEED0EEEE05EEE@80ZZZZ00<0EEEE0:ZZZP2Z
ZZX00P1EEED40?ooo`0:0000003oool0oooo0?ooo`2ZZZX000000?ooo`1EEED000000:ZZZQ80oooo
2P3AcJTB0?ooo`80ZZZZ00<0oooo05EEE@3oool0102ZZZX00`3oool0ZZZZ0?ooo`020:ZZZP030?oo
o`2ZZZX0000000@0oooo0P2ZZZX20?ooo`040:ZZZP3oool0oooo0?ooo`@0ZZZZ00<0oooo05EEE@2Z
ZZX00P2ZZZXB0?ooo`X0dLfY4P3oool20:ZZZP030000003oool0EEEE0080EEEE00D0oooo0:ZZZP2Z
ZZX000000?ooo`03000000030?ooo`2ZZZX0oooo0080EEEE00L0oooo05EEE@3oool000000:ZZZP00
0000oooo0080ZZZZ00<000000?ooo`1EEED00P1EEED0103oool0ZZZZ0:ZZZP2ZZZXB0?ooo``0dLfY
000;0=7=ZA<0oooo00@0ZZZZ00000000000000000P1EEED0102ZZZX000000:ZZZP1EEED200000003
0:ZZZP3oool00000008000000P3oool3000000080?ooo`1EEED000000000003oool0ZZZZ0000002Z
ZZX205EEE@80000000<0oooo0:ZZZP3oool04P3oool:0=7=ZA<0oooo00L0ZZZZ05EEE@1EEED00000
0:ZZZP000000ZZZZ008000001P3oool2000000030:ZZZP3oool0000000H0oooo00X0EEEE0000001E
EED0ZZZZ0000001EEED0000005EEE@3oool0ZZZZ4`3oool:0=7=ZA<0oooo102ZZZX00`000000oooo
0?ooo`020?ooo`@0ZZZZ0P1EEED010000000ZZZZ0:ZZZP0000020:ZZZP80EEEE0`2ZZZX00`1EEED0
oooo0?ooo`020?ooo`0505EEE@2ZZZX0ZZZZ0000002ZZZX04`3oool:0=7=ZA<0oooo00<0ZZZZ05EE
E@1EEED01`2ZZZX0203oool000000:ZZZP1EEED0ZZZZ0?ooo`1EEED0oooo0P1EEED01`3oool0ZZZZ
05EEE@3oool000000?ooo`1EEED01P2ZZZX00`1EEED0oooo0:ZZZP0C0?ooo`X0dLfY4`3oool00`2Z
ZZX0oooo05EEE@0405EEE@050?ooo`2ZZZX0EEEE0000001EEED00P2ZZZX2000000@0EEEE0P000000
1`2ZZZX0oooo05EEE@000000oooo0:ZZZP3oool01@1EEED00`3oool0ZZZZ0?ooo`0B0?ooo``0dLfY
000;0=7=ZA@0oooo00D0EEEE0000002ZZZX0oooo0:ZZZP020000000405EEE@2ZZZX0000000000080
oooo00@000000:ZZZP000000EEEE100000003@3oool0ZZZZ000000000000oooo05EEE@2ZZZX00000
0:ZZZP000000ZZZZ0000002ZZZX0503oool:0=7=ZA@0oooo00<0EEEE0:ZZZP2ZZZX00`0000020:ZZ
ZPH0oooo00D0000005EEE@2ZZZX0oooo05EEE@060?ooo`030000002ZZZX0oooo0080000000@0oooo
0:ZZZP2ZZZX0ZZZZ503oool:0=7=ZA@0oooo00<0000005EEE@1EEED01@2ZZZX01P000000EEEE05EE
E@000000oooo05EEE@80000000L0ZZZZ0?ooo`000000000005EEE@3oool000000080EEEE1@2ZZZX3
05EEE@030:ZZZP3oool0oooo0180oooo2P3AcJTD0?ooo`040000002ZZZX0EEEE0:ZZZP<0oooo0P1E
EED0103oool0EEEE05EEE@2ZZZX405EEE@0;0:ZZZP1EEED0oooo05EEE@2ZZZX0oooo05EEE@3oool0
ZZZZ05EEE@2ZZZX00`3oool00`1EEED0ZZZZ0:ZZZP0D0?ooo`X0dLfY503oool5000000030?ooo`2Z
ZZX0oooo0080EEEE00D0ZZZZ0?ooo`3oool000000?ooo`040000000505EEE@000000oooo0000002Z
ZZX00P1EEED00`3oool000000?ooo`04000000030:ZZZP3oool0oooo0180oooo303AcJT000/0dLfY
5@3oool20:ZZZP070?ooo`2ZZZX0EEEE0:ZZZP000000EEEE0?ooo`020:ZZZP<0000000@0oooo05EE
E@3oool0oooo0`0000001@1EEED0ZZZZ0?ooo`1EEED000000080EEEE00@0ZZZZ05EEE@2ZZZX0ZZZZ
5@3oool:0=7=ZAD0oooo0P2ZZZX0101EEED0ZZZZ0:ZZZP2ZZZX3000000060:ZZZP000000oooo0000
002ZZZX0EEEE0P3oool02@1EEED000000000003oool000000:ZZZP000000ZZZZ000000030:ZZZP03
0?ooo`2ZZZX0ZZZZ01D0oooo2P3AcJTE0?ooo`050:ZZZP000000EEEE0?ooo`0000000P1EEED20000
00030:ZZZP3oool0oooo0080EEEE0P3oool010000000oooo0:ZZZP1EEED20?ooo`0:0:ZZZP000000
oooo05EEE@2ZZZX000000?ooo`1EEED000000:ZZZQD0oooo2P3AcJTE0?ooo`030:ZZZP3oool0oooo
00<0EEEE0P3oool01P1EEED0oooo0?ooo`2ZZZX0oooo05EEE@80oooo00T0EEEE0?ooo`3oool0oooo
0:ZZZP1EEED0oooo05EEE@2ZZZX00P3oool305EEE@030?ooo`2ZZZX0oooo01@0oooo2P3AcJTE0?oo
o`050:ZZZP3oool0oooo0?ooo`1EEED00P2ZZZX00`1EEED0ZZZZ0:ZZZP02000000030?ooo`1EEED0
ZZZZ0080oooo00D0ZZZZ05EEE@3oool000000?ooo`020:ZZZP0805EEE@2ZZZX0ZZZZ05EEE@3oool0
00000?ooo`2ZZZXE0?ooo``0dLfY000;0=7=ZAH0oooo00D0ZZZZ0000003oool0EEEE0?ooo`030000
0080EEEE00@000000:ZZZP000000EEEE0P00000205EEE@040:ZZZP000000oooo05EEE@<000000P1E
EED20?ooo`030:ZZZP3oool0oooo01@0oooo2P3AcJTF0?ooo`060:ZZZP1EEED0EEEE0000002ZZZX0
00000P1EEED50:ZZZP030000003oool0oooo008000000P2ZZZX02P000000ZZZZ05EEE@2ZZZX00000
05EEE@000000EEEE0?ooo`2ZZZXF0?ooo`X0dLfY5P3oool40:ZZZP040000003oool0ZZZZ0:ZZZP<0
oooo00<000000:ZZZP1EEED00P3oool205EEE@080000003oool0oooo0?ooo`2ZZZX0EEEE0?ooo`1E
EED20:ZZZP030000002ZZZX0oooo01D0oooo2P3AcJTF0?ooo`80ZZZZ00H000000:ZZZP1EEED0EEEE
0:ZZZP00000205EEE@060?ooo`2ZZZX0oooo0000001EEED0ZZZZ0P0000001`2ZZZX0oooo05EEE@1E
EED000000?ooo`1EEED00P2ZZZX2000000030:ZZZP3oool0oooo01@0oooo2P3AcJTF0?ooo`80ZZZZ
00D000000?ooo`3oool0oooo000000020?ooo`80ZZZZ00<0oooo0000003oool00`3oool010000000
oooo0:ZZZP0000020?ooo`040000003oool000000?ooo`80000000<0ZZZZ0?ooo`3oool0503oool<
0=7=Z@002`3AcJTG0?ooo`030:ZZZP000000EEEE00<0000000@0oooo0:ZZZP3oool0ZZZZ0P000000
2P3oool0EEEE05EEE@3oool0EEEE0000002ZZZX0oooo0:ZZZP3oool2000000030:ZZZP1EEED00000
01P0oooo2P3AcJTG0?ooo`060:ZZZP00000000000?ooo`1EEED0oooo100000001@2ZZZX000000:ZZ
ZP000000EEEE00<0ZZZZ100000000`3oool0EEEE0?ooo`02000001P0oooo2P3AcJTG0?ooo`080:ZZ
ZP000000ZZZZ0000001EEED0ZZZZ0?ooo`0000020?ooo`030000001EEED0EEEE00<0EEEE00P0oooo
0000003oool0oooo0000003oool0000005EEE@80ZZZZ00<000000?ooo`3oool05P3oool:0=7=ZAL0
oooo00@0ZZZZ0?ooo`1EEED0ZZZZ0P3oool01@000000ZZZZ0?ooo`3oool000000080EEEE00<00000
0?ooo`1EEED00P0000001P3oool0ZZZZ0:ZZZP000000ZZZZ0?ooo`80EEEE6@3oool:0=7=ZAL0oooo
00<0ZZZZ0?ooo`3oool00P1EEED00`3oool000000000000205EEE@030?ooo`2ZZZX0oooo0080ZZZZ
0`3oool0101EEED0oooo00000000000305EEEAX0oooo303AcJT000/0dLfY603oool20:ZZZP0505EE
E@000000000005EEE@0000000P3oool00`2ZZZX0EEEE0000000300000080ZZZZ0P3oool01@000000
EEEE0:ZZZP000000EEEE0080ZZZZ603oool:0=7=ZAP0oooo0P2ZZZX0201EEED0ZZZZ0:ZZZP2ZZZX0
00000:ZZZP000000ZZZZ0P000000203oool0ZZZZ0000001EEED0ZZZZ0000002ZZZX000000`2ZZZX0
0`3oool0ZZZZ0:ZZZP0H0?ooo`X0dLfY603oool01P2ZZZX0000005EEE@3oool0ZZZZ05EEE@@0oooo
00<0ZZZZ05EEE@2ZZZX00`1EEED40?ooo`0605EEE@000000oooo05EEE@000000ZZZZ603oool:0=7=
ZAP0oooo00@0ZZZZ0000001EEED0oooo0P2ZZZX0303oool000000:ZZZP3oool0ZZZZ0000003oool0
ZZZZ0000002ZZZX0oooo0:ZZZP80oooo00H0ZZZZ05EEE@3oool0ZZZZ0000002ZZZXH0?ooo`X0dLfY
603oool00`2ZZZX000000000000200000080ZZZZ0`0000020?ooo`040:ZZZP3oool0oooo0:ZZZP80
000000<0oooo0:ZZZP2ZZZX0100000000`2ZZZX0oooo0?ooo`0F0?ooo``0dLfY000;0=7=ZAT0oooo
00<0ZZZZ0000002ZZZX00P1EEED50?ooo`050000003oool000000000002ZZZX0103oool205EEE@03
0:ZZZP3oool0ZZZZ01T0oooo2P3AcJTI0?ooo`090:ZZZP1EEED0EEEE05EEE@2ZZZX0000005EEE@00
0000oooo0080ZZZZ0P3oool02`2ZZZX000000?ooo`000000ZZZZ0000002ZZZX0000005EEE@3oool0
ZZZZ01T0oooo2P3AcJTI0?ooo`<0ZZZZ00<0EEEE0000003oool00`3oool01P1EEED0ZZZZ05EEE@1E
EED0ZZZZ000000@0oooo00D000000:ZZZP2ZZZX000000:ZZZP0I0?ooo`X0dLfY6@3oool20:ZZZP80
00000`3oool0101EEED0ZZZZ0:ZZZP2ZZZX20?ooo`<0ZZZZ00<0EEEE0?ooo`3oool00P3oool00`00
0000ZZZZ0:ZZZP0I0?ooo`X0dLfY6@3oool01@2ZZZX0oooo0:ZZZP3oool0ZZZZ0080oooo00L0EEEE
0?ooo`2ZZZX000000:ZZZP3oool000000080oooo00<0EEEE0?ooo`3oool01@2ZZZXI0?ooo``0dLfY
000;0=7=ZAX0oooo00D0ZZZZ000000000000oooo000000040?ooo`040:ZZZP00000000000:ZZZP@0
oooo00@000000?ooo`1EEED000006`3oool:0=7=ZAX0oooo00H0ZZZZ0000003oool0oooo05EEE@3o
ool3000000D0ZZZZ0P0000000`3oool0EEEE0?ooo`02000001/0oooo2P3AcJTJ0?ooo`0:0:ZZZP00
0000ZZZZ0000001EEED0ZZZZ05EEE@000000EEEE0:ZZZP80EEEE00T0ZZZZ05EEE@000000EEEE0000
001EEED000000:ZZZP0000006`3oool:0=7=ZAX0oooo00D0ZZZZ000000000000ZZZZ000000020?oo
o`0305EEE@3oool0oooo00<0oooo0P1EEED00`3oool0EEEE000000020:ZZZP030000003oool0oooo
01T0oooo2P3AcJTJ0?ooo`040:ZZZP00000000000?ooo`80ZZZZ00L0oooo0:ZZZP2ZZZX0EEEE0?oo
o`000000EEEE0080ZZZZ00H0oooo0:ZZZP2ZZZX0oooo0:ZZZP00000K0?ooo``0dLfY000;0=7=ZA/0
oooo00@0ZZZZ05EEE@0000000000103oool010000000EEEE05EEE@0000040?ooo`8000000P2ZZZXK
0?ooo`X0dLfY6`3oool00`2ZZZX0oooo05EEE@030:ZZZP040000001EEED0EEEE00000080EEEE00<0
ZZZZ0000002ZZZX00P2ZZZX00`1EEED0ZZZZ0:ZZZP0K0?ooo`X0dLfY6`3oool01@2ZZZX0EEEE05EE
E@3oool0ZZZZ0080EEEE00<0000005EEE@2ZZZX00P1EEED0203oool0EEEE05EEE@000000oooo05EE
E@000000ZZZZ6`3oool:0=7=ZA/0oooo0P2ZZZX0203oool0EEEE0000002ZZZX000000?ooo`1EEED0
oooo0`1EEED01@000000ZZZZ0?ooo`1EEED0oooo0080ZZZZ6`3oool:0=7=ZA/0oooo0P2ZZZX01P00
0000oooo0000003oool0ZZZZ05EEE@80ZZZZ00@000000:ZZZP3oool0ZZZZ0`3oool00`000000ZZZZ
0:ZZZP0K0?ooo``0dLfY000;0=7=ZA`0oooo00<0ZZZZ05EEE@0000000P0000000`1EEED0000005EE
E@0305EEE@060000001EEED0000005EEE@000000EEEE7@3oool:0=7=ZA`0oooo00@0ZZZZ05EEE@2Z
ZZX0oooo0P0000001@3oool0EEEE0000002ZZZX0EEEE00<000000P2ZZZX00`1EEED0oooo0?ooo`0K
0?ooo`X0dLfY703oool0102ZZZX0000005EEE@1EEED20:ZZZP80000000<0ZZZZ0?ooo`0000000`2Z
ZZX205EEE@030000003oool0oooo01/0oooo2P3AcJTL0?ooo`070:ZZZP000000ZZZZ0?ooo`2ZZZX0
000005EEE@020?ooo`080000003oool0oooo0000002ZZZX0EEEE0:ZZZP00000M0?ooo`X0dLfY703o
ool01`2ZZZX00000000000000000ZZZZ0?ooo`1EEED00P0000001@2ZZZX000000000003oool0ZZZZ
00<000007@3oool<0=7=Z@002`3AcJTM0?ooo`050:ZZZP00000000000:ZZZP1EEED01@0000000`2Z
ZZX0EEEE0:ZZZP02000000030:ZZZP3oool0oooo01/0oooo2P3AcJTM0?ooo`060:ZZZP000000oooo
0?ooo`1EEED0oooo0P0000001@2ZZZX000000?ooo`1EEED0oooo0080000000<0ZZZZ0?ooo`3oool0
6`3oool:0=7=ZAd0oooo00H0ZZZZ0000002ZZZX0000005EEE@2ZZZX20?ooo`080000003oool00000
05EEE@000000ZZZZ0000002ZZZXM0?ooo`X0dLfY7@3oool20:ZZZP030000003oool0oooo0080EEEE
0P3oool205EEE@80oooo0`2ZZZXM0?ooo`X0dLfY7@3oool50:ZZZP80EEEE00@0oooo0:ZZZP1EEED0
EEEE0P2ZZZX00`3oool0ZZZZ0:ZZZP0M0?ooo``0dLfY000;0=7=ZAh0oooo00@0ZZZZ0?ooo`2ZZZX0
oooo0P1EEED01@000000EEEE05EEE@000000oooo00<0ZZZZ7P3oool:0=7=ZAh0oooo00<0ZZZZ0?oo
o`1EEED00`2ZZZX2000000<0ZZZZ00<0EEEE0:ZZZP2ZZZX07P3oool:0=7=ZAh0oooo00H0ZZZZ05EE
E@1EEED0oooo0:ZZZP1EEED20?ooo`0605EEE@000000oooo05EEE@000000ZZZZ7P3oool:0=7=ZAh0
oooo00L0ZZZZ05EEE@3oool0EEEE0:ZZZP1EEED0oooo00@0EEEE0P3oool00`2ZZZX0oooo0?ooo`0L
0?ooo`X0dLfY7P3oool0102ZZZX000000?ooo`3oool200000080oooo0P0000030?ooo`030:ZZZP3o
ool0oooo01`0oooo303AcJT000/0dLfY7`3oool0102ZZZX0EEEE0:ZZZP1EEED2000000050?ooo`00
000000000:ZZZP1EEED0803oool:0=7=ZAl0oooo00D0ZZZZ05EEE@2ZZZX0000005EEE@0200000004
05EEE@2ZZZX0ZZZZ05EEEB00oooo2P3AcJTO0?ooo`040:ZZZP000000EEEE05EEE@@0ZZZZ0P1EEED0
0`000000oooo0?ooo`0N0?ooo`X0dLfY7`3oool30:ZZZP0605EEE@2ZZZX0ZZZZ0?ooo`2ZZZX0oooo
0P2ZZZXP0?ooo`X0dLfY7`3oool30:ZZZP8000000P2ZZZX200000080ZZZZ803oool<0=7=Z@002`3A
cJTP0?ooo`030:ZZZP00000000000080oooo00D000000?ooo`2ZZZX000000:ZZZP0P0?ooo`X0dLfY
803oool01@2ZZZX0000005EEE@2ZZZX000000080ZZZZ00<0EEEE0000002ZZZX0803oool:0=7=ZB00
oooo00D0ZZZZ0000002ZZZX000000?ooo`02000000030:ZZZP000000ZZZZ0200oooo2P3AcJTP0?oo
o`0:0:ZZZP3oool0EEEE0:ZZZP000000oooo0:ZZZP1EEED0oooo0:ZZZR00oooo2P3AcJTP0?ooo`05
0:ZZZP3oool0EEEE0?ooo`000000103oool00`2ZZZX0oooo0?ooo`0N0?ooo``0dLfY000;0=7=ZB40
oooo00H0ZZZZ0000001EEED0EEEE0000001EEED20:ZZZR40oooo2P3AcJTQ0?ooo`030:ZZZP1EEED0
ZZZZ008000000`2ZZZXQ0?ooo`X0dLfY8@3oool00`2ZZZX0EEEE05EEE@020?ooo`0305EEE@000000
ZZZZ0240oooo2P3AcJTQ0?ooo`80ZZZZ0P1EEED0103oool0EEEE0000002ZZZXQ0?ooo`X0dLfY8@3o
ool01@2ZZZX000000000003oool0ZZZZ0080000000<0ZZZZ0?ooo`3oool07`3oool<0=7=Z@002`3A
cJTR0?ooo`030:ZZZP1EEED000000080EEEE8`3oool:0=7=ZB80oooo00<0ZZZZ05EEE@2ZZZX00P1E
EEDS0?ooo`X0dLfY8P3oool00`2ZZZX000000:ZZZP02000002<0oooo2P3AcJTR0?ooo`040:ZZZP3o
ool0oooo05EEEB@0oooo2P3AcJTR0?ooo`040:ZZZP3oool0oooo000002@0oooo303AcJT000/0dLfY
8`3oool0102ZZZX0oooo0000002ZZZXS0?ooo`X0dLfY8`3oool0102ZZZX0oooo0000002ZZZXS0?oo
o`X0dLfY8`3oool0102ZZZX0oooo0000002ZZZXS0?ooo`X0dLfY8`3oool20:ZZZP030000002ZZZX0
oooo0280oooo2P3AcJTS0?ooo`80ZZZZ00<000000:ZZZP3oool08P3oool<0=7=Z@002`3AcJTT0?oo
o`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?oo
o`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?oo
o`030:ZZZP3oool0oooo02<0oooo303AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3A
cJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT000/0dLfY00T0oooo000000000000ZZZZ0?ooo`2ZZZX0
oooo0000003oool00P2ZZZX01P1EEED0ZZZZ0?ooo`3oool0EEEE0:ZZZP<0oooo00H000000?ooo`3o
ool0000005EEE@2ZZZX405EEE@060000003oool0EEEE05EEE@3oool000000P1EEED01P000000EEEE
05EEE@1EEED0oooo000000<0EEEE00@0oooo0:ZZZP1EEED0ZZZZ1@3oool00`1EEED0ZZZZ00000002
0?ooo`80EEEE00/0ZZZZ05EEE@3oool0000005EEE@2ZZZX0oooo0:ZZZP000000ZZZZ0?ooo`0:0=7=
Z@070?ooo`00000000000:ZZZP1EEED0oooo000000020:ZZZP0405EEE@000000000005EEE@800000
00@0oooo0:ZZZP1EEED0EEEE103oool305EEE@80oooo00<0EEEE0000002ZZZX00P3oool00`2ZZZX0
oooo000000020?ooo`030000002ZZZX0ZZZZ0080oooo00@0ZZZZ000000000000oooo0`1EEED50?oo
o`80EEEE00D0ZZZZ05EEE@00000000000?ooo`0300000080ZZZZ0P3oool01@1EEED0ZZZZ0000002Z
ZZX0oooo00X0dLfY00<0oooo0:ZZZP2ZZZX00P3oool20000000705EEE@000000000005EEE@000000
ZZZZ000000020:ZZZP0405EEE@000000ZZZZ000000<0oooo00P0000005EEE@2ZZZX000000:ZZZP3o
ool0ZZZZ0?ooo`<000000P3oool2000000030?ooo`00000000000080000000P0oooo0:ZZZP1EEED0
ZZZZ0000002ZZZX0EEEE0:ZZZP80oooo0P0000001@2ZZZX0oooo05EEE@000000ZZZZ00<0000000D0
EEEE000000000000EEEE0?ooo`02000000040?ooo`2ZZZX0ZZZZ0?ooo`X0dLfY00D0oooo0:ZZZP2Z
ZZX0ZZZZ0?ooo`0205EEE@80oooo0`2ZZZX02@3oool0ZZZZ0000001EEED0oooo0:ZZZP000000ZZZZ
0?ooo`030:ZZZP80oooo0P0000001@2ZZZX0oooo05EEE@3oool0EEEE00P0oooo0`1EEED0103oool0
ZZZZ0000001EEED20?ooo`<0ZZZZ00T0oooo0:ZZZP000000EEEE0?ooo`2ZZZX000000:ZZZP3oool0
0`2ZZZX20?ooo`030000001EEED0oooo00<0ZZZZ00<0oooo0=7=Z@3AcJT0203AcJT0103oool0ZZZZ
0?ooo`1EEED40:ZZZP0405EEE@3oool0oooo0?ooo`80000000@0EEEE0:ZZZP2ZZZX0oooo0P2ZZZX0
1P1EEED0ZZZZ05EEE@1EEED0ZZZZ05EEE@80oooo00@0EEEE0:ZZZP000000ZZZZ0`3oool0101EEED0
oooo0000001EEED30?ooo`0305EEE@000000ZZZZ00<0oooo00@0EEEE0:ZZZP1EEED0EEEE102ZZZX0
1@3oool0ZZZZ05EEE@1EEED0000000<0oooo00<0000005EEE@2ZZZX00`2ZZZX0101EEED0oooo0:ZZ
ZP3oool<0=7=Z@002`3AcJT01P3oool0ZZZZ05EEE@3oool000000?ooo`80EEEE00@000000?ooo`3o
ool0ZZZZ0`3oool01@000000ZZZZ05EEE@000000ZZZZ0080000000@0oooo05EEE@1EEED0oooo1@00
00001P2ZZZX000000?ooo`000000EEEE0?ooo`80EEEE00@0ZZZZ0?ooo`000000EEEE1@000000203o
ool0EEEE0000003oool0000005EEE@2ZZZX000000P2ZZZX30?ooo`80ZZZZ00<0oooo0:ZZZP000000
0P1EEED0103oool000000?ooo`1EEED20?ooo`X0dLfY00<0oooo0:ZZZP000000103oool00`000000
EEEE0:ZZZP020:ZZZP<0000000<0ZZZZ05EEE@0000001P1EEED200000080EEEE0P3oool010000000
ZZZZ0000001EEED2000000090?ooo`00000000000?ooo`1EEED0000005EEE@000000oooo00<0EEEE
0P00000805EEE@<0000000H0EEEE0:ZZZP2ZZZX0oooo05EEE@0000020?ooo`0305EEE@3oool00000
0080oooo2P3AcJT03P3oool0ZZZZ0000003oool0EEEE0:ZZZP000000oooo05EEE@3oool0EEEE0000
001EEED0ZZZZ0P0000020:ZZZP030?ooo`000000oooo0080oooo0P2ZZZX3000000030?ooo`2ZZZX0
000000<000000P3oool2000000030?ooo`000000000000<0000000H0ZZZZ05EEE@000000oooo0000
002ZZZX30?ooo`80000000D0oooo0:ZZZP2ZZZX0oooo000000020:ZZZP070000001EEED0oooo05EE
E@3oool000000:ZZZP020?ooo`030000003oool0oooo00X0dLfY00D0oooo0:ZZZP3oool0oooo05EE
E@020?ooo`0405EEE@2ZZZX0oooo0:ZZZP<0oooo00<0ZZZZ0000003oool00P2ZZZX30?ooo`030:ZZ
ZP3oool0ZZZZ0080EEEE00L0oooo0:ZZZP3oool0EEEE0?ooo`2ZZZX0000000D0oooo0P0000000`2Z
ZZX0EEEE05EEE@040?ooo`0405EEE@2ZZZX0oooo0:ZZZP<0oooo00<0ZZZZ0000003oool00P2ZZZX3
0?ooo`030:ZZZP3oool0ZZZZ0080EEEE00<0oooo0:ZZZP3oool00`3oool:0=7=Z@030?ooo`2ZZZX0
oooo00H0EEEE103oool01`1EEED0oooo05EEE@1EEED0oooo05EEE@0000001@1EEED40:ZZZP80EEEE
00D000000?ooo`3oool000000?ooo`020:ZZZP@0oooo00<0000005EEE@1EEED0102ZZZX0201EEED0
oooo05EEE@1EEED0oooo0000001EEED0ZZZZ0P1EEED00`3oool0EEEE0?ooo`030?ooo`H0EEEE0`3o
ool<0=7=Z@002`3AcJT30?ooo`80ZZZZ103oool0102ZZZX0EEEE0:ZZZP0000020?ooo`8000000P3o
ool00`2ZZZX0EEEE05EEE@030?ooo`<0000000H0ZZZZ00000000000000000:ZZZP00000205EEE@07
0?ooo`1EEED0EEEE0?ooo`000000ZZZZ0?ooo`020000000705EEE@000000oooo0000003oool00000
0?ooo`0205EEE@050:ZZZP3oool000000000002ZZZX00P3oool20:ZZZP0805EEE@2ZZZX0oooo0?oo
o`2ZZZX0oooo05EEE@2ZZZX30?ooo`X0dLfY0`3oool04@2ZZZX000000:ZZZP000000EEEE0000001E
EED000000?ooo`000000EEEE0000002ZZZX0oooo05EEE@3oool0EEEE0080ZZZZ0P3oool0102ZZZX0
00000?ooo`1EEED2000000<0EEEE00<0ZZZZ05EEE@0000000P3oool00`000000ZZZZ0:ZZZP0305EE
E@0K0000001EEED0EEEE0?ooo`000000ZZZZ05EEE@3oool0ZZZZ0?ooo`1EEED0oooo0:ZZZP3oool0
ZZZZ0000001EEED000000?ooo`000000ZZZZ0000001EEED000000:ZZZP000000ZZZZ00<0oooo2P3A
cJT30?ooo`090:ZZZP3oool0ZZZZ0:ZZZP3oool0ZZZZ0?ooo`2ZZZX000000080oooo00<000000?oo
o`3oool00P1EEED00`000000oooo0?ooo`030?ooo`040:ZZZP000000ZZZZ000000@0oooo00<00000
0?ooo`3oool00P0000001@3oool000000000003oool0EEEE0080oooo102ZZZX50?ooo`0=0000001E
EED0oooo0?ooo`2ZZZX000000?ooo`1EEED000000:ZZZP000000ZZZZ0?ooo`020:ZZZP030000002Z
ZZX0oooo0080oooo2P3AcJT30?ooo`040:ZZZP000000EEEE05EEE@8000001P3oool00`1EEED00000
05EEE@050?ooo`050:ZZZP00000000000?ooo`1EEED00P0000000`2ZZZX0oooo05EEE@060?ooo`03
05EEE@3oool0EEEE0080ZZZZ0P00000205EEE@8000001P3oool00`1EEED0000005EEE@050?ooo`07
0:ZZZP00000000000?ooo`1EEED000000:ZZZP030?ooo`X0dLfY0`3oool20:ZZZP<0EEEE00@0oooo
05EEE@2ZZZX000000P1EEED20:ZZZP0305EEE@3oool0ZZZZ0080EEEE102ZZZX01P1EEED0oooo05EE
E@1EEED0oooo05EEE@D0ZZZZ00<0000005EEE@2ZZZX0102ZZZX00`1EEED0oooo05EEE@0305EEE@04
0:ZZZP000000ZZZZ0:ZZZP80EEEE0P2ZZZX03P1EEED0ZZZZ0:ZZZP1EEED0ZZZZ0000002ZZZX00000
0?ooo`1EEED0ZZZZ05EEE@000000ZZZZ0`3oool<0=7=Z@002`3AcJT40?ooo`030000002ZZZX0EEEE
0080EEEE00P0ZZZZ05EEE@2ZZZX0EEEE0000002ZZZX0EEEE000000<0EEEE00D0ZZZZ05EEE@2ZZZX0
00000?ooo`02000000030?ooo`1EEED000000080EEEE00@000000?ooo`3oool0EEEE0P3oool0101E
EED0oooo0?ooo`00000205EEE@0:0000003oool0oooo0?ooo`000000oooo0000002ZZZX0EEEE0:ZZ
ZP<0EEEE00H0000005EEE@2ZZZX0000005EEE@2ZZZX505EEE@80ZZZZ103oool:0=7=Z@@0oooo00@0
00000?ooo`2ZZZX0oooo0P2ZZZX00`000000oooo0?ooo`020:ZZZP0405EEE@2ZZZX0ZZZZ00000080
EEEE00L0ZZZZ05EEE@1EEED0ZZZZ05EEE@000000EEEE00D0000000@0ZZZZ000000000000oooo0P00
00020:ZZZP030000001EEED000000080000000L0EEEE0:ZZZP1EEED0ZZZZ0000001EEED0ZZZZ0080
EEEE0P0000001P2ZZZX0EEEE0:ZZZP2ZZZX000000?ooo`80000000D0ZZZZ0?ooo`1EEED0oooo0:ZZ
ZP040?ooo`X0dLfY103oool50:ZZZP030000001EEED0000000<0ZZZZ0P3oool010000000EEEE0?oo
o`0000050?ooo`040000001EEED0000000000080ZZZZ0P0000020?ooo`80000000<0oooo00000000
00000P0000001@2ZZZX000000000001EEED0ZZZZ0080oooo00<000000?ooo`3oool00P3oool0101E
EED0oooo0?ooo`3oool30:ZZZP030000001EEED0EEEE0080ZZZZ00<0EEEE0:ZZZP2ZZZX0103oool:
0=7=Z@@0oooo00<0ZZZZ0?ooo`3oool00P2ZZZX60?ooo`030:ZZZP3oool0000000H0oooo0P2ZZZX0
20000000oooo0:ZZZP3oool0ZZZZ0?ooo`000000ZZZZ1@3oool01`000000ZZZZ0000003oool0ZZZZ
0?ooo`2ZZZX00P3oool20:ZZZPH0oooo00<0ZZZZ0?ooo`0000001P3oool20:ZZZP030000003oool0
ZZZZ00@0oooo2P3AcJT40?ooo`080:ZZZP000000EEEE05EEE@3oool0ZZZZ05EEE@0000020:ZZZP<0
EEEE00D000000?ooo`1EEED0oooo05EEE@02000000030:ZZZP1EEED0ZZZZ00@0ZZZZ00`0EEEE0:ZZ
ZP000000EEEE0000003oool0ZZZZ0000002ZZZX000000:ZZZP1EEED20:ZZZP0405EEE@2ZZZX0ZZZZ
05EEE@80ZZZZ00@0000005EEE@1EEED0EEEE0P3oool305EEE@0:0:ZZZP1EEED0000005EEE@2ZZZX0
oooo05EEE@3oool000000:ZZZP@0oooo303AcJT000/0dLfY103oool02P2ZZZX0EEEE0?ooo`3oool0
EEEE0?ooo`2ZZZX000000?ooo`0000020?ooo`0905EEE@2ZZZX0EEEE0:ZZZP000000ZZZZ0?ooo`00
0000oooo0080000000<0oooo0000000000000P2ZZZX4000000040?ooo`00000000000?ooo`800000
00@0oooo0:ZZZP00000000000P3oool010000000oooo0?ooo`3oool30:ZZZP0<05EEE@2ZZZX0EEEE
05EEE@3oool000000:ZZZP000000ZZZZ0?ooo`1EEED0oooo0P1EEED50?ooo`X0dLfY103oool01@2Z
ZZX0000005EEE@2ZZZX000000080oooo0P0000002@3oool0EEEE0000001EEED0ZZZZ0?ooo`1EEED0
oooo05EEE@020000000305EEE@3oool0ZZZZ00@0000000<0ZZZZ0?ooo`1EEED00`3oool01@000000
oooo0000001EEED0oooo00D000000P3oool01P1EEED000000000001EEED0oooo05EEE@80oooo00@0
EEEE0000001EEED0oooo0P0000001P3oool0ZZZZ0000002ZZZX0EEEE000000D0oooo2P3AcJT40?oo
o`060:ZZZP000000EEEE05EEE@3oool000000P2ZZZX00`000000ZZZZ0?ooo`030?ooo`050000001E
EED000000:ZZZP0000000P3oool01@000000ZZZZ0:ZZZP1EEED0ZZZZ0080000000<0ZZZZ05EEE@2Z
ZZX01@0000002P1EEED0ZZZZ0?ooo`000000ZZZZ0000002ZZZX0oooo0000003oool2000000030:ZZ
ZP1EEED0EEEE0080000000D0oooo0000003oool0ZZZZ0?ooo`020:ZZZP0505EEE@3oool0EEEE0?oo
o`0000001@3oool:0=7=Z@@0oooo00@0ZZZZ0?ooo`3oool0ZZZZ1`3oool00`1EEED000000?ooo`07
0?ooo`030:ZZZP1EEED0oooo00<0oooo00<0EEEE0?ooo`3oool01P2ZZZX20?ooo`040:ZZZP3oool0
oooo0:ZZZP80oooo00<0ZZZZ0?ooo`3oool01@3oool00`1EEED000000?ooo`070?ooo`030:ZZZP1E
EED0oooo00D0oooo2P3AcJT40?ooo`030:ZZZP3oool0EEEE0080ZZZZ00L000000:ZZZP3oool00000
05EEE@2ZZZX0EEEE0080ZZZZ00@0oooo05EEE@3oool0ZZZZ0P000000102ZZZX0EEEE0000002ZZZX3
05EEE@030:ZZZP1EEED000000080ZZZZ0P3oool01@2ZZZX0EEEE0000001EEED0ZZZZ0080EEEE0`2Z
ZZX01@1EEED0ZZZZ000000000000ZZZZ0080EEEE00<0oooo0:ZZZP2ZZZX00P2ZZZX00`1EEED0ZZZZ
0?ooo`050:ZZZPH0oooo303AcJT000/0dLfY1P3oool01P1EEED00000000000000000ZZZZ00000080
oooo00D0000005EEE@3oool0ZZZZ000000020?ooo`80ZZZZ0`0000020:ZZZP040?ooo`1EEED0oooo
0:ZZZP80EEEE00H000000?ooo`3oool000000?ooo`00000205EEE@80oooo00<0EEEE0:ZZZP2ZZZX0
100000020:ZZZP030000003oool000000080oooo0P0000020?ooo`030000002ZZZX0EEEE00800000
00<0ZZZZ0?ooo`3oool0103oool:0=7=Z@H0oooo00`000000?ooo`1EEED000000:ZZZP000000oooo
05EEE@3oool000000?ooo`2ZZZX200000080ZZZZ0P1EEED00`2ZZZX0oooo05EEE@0205EEE@060?oo
o`000000EEEE0000003oool000000P3oool010000000oooo0?ooo`3oool3000000030?ooo`1EEED0
EEEE0080oooo00@0ZZZZ0?ooo`1EEED0ZZZZ0`0000001@2ZZZX0oooo0:ZZZP3oool0EEEE00800000
00D0ZZZZ0000001EEED0oooo0:ZZZP060?ooo`X0dLfY1P3oool02@000000oooo0000001EEED0ZZZZ
05EEE@2ZZZX0EEEE0?ooo`03000000040:ZZZP3oool0oooo0?ooo`80000000<0ZZZZ0000002ZZZX0
0P2ZZZX01@000000EEEE0?ooo`1EEED000000080ZZZZ00T0oooo0:ZZZP2ZZZX0oooo0000001EEED0
ZZZZ05EEE@0000000P2ZZZX00`1EEED000000:ZZZP02000000030?ooo`2ZZZX0oooo0080ZZZZ00H0
00000?ooo`3oool0EEEE0:ZZZP1EEED20:ZZZP030000003oool0ZZZZ00H0oooo2P3AcJT60?ooo`03
0000002ZZZX0EEEE00L0oooo00<0000005EEE@3oool01@3oool00`1EEED0ZZZZ0:ZZZP020?ooo`80
00000P2ZZZX02P1EEED0ZZZZ0000002ZZZX0oooo0000002ZZZX0EEEE0:ZZZP1EEED200000080oooo
00<000000:ZZZP1EEED01`3oool00`000000EEEE0?ooo`050?ooo`0305EEE@2ZZZX0ZZZZ00H0oooo
2P3AcJT60?ooo`80000000D0ZZZZ0000002ZZZX0EEEE0:ZZZP0200000080ZZZZ0`0000000`2ZZZX0
oooo05EEE@030:ZZZP80000000@0ZZZZ05EEE@1EEED0ZZZZ0P1EEED00`3oool0ZZZZ0:ZZZP030:ZZ
ZP80EEEE00@0ZZZZ05EEE@1EEED0ZZZZ0P0000030:ZZZP0305EEE@3oool0oooo00<0000000<0ZZZZ
05EEE@0000000P0000001P1EEED0ZZZZ0000002ZZZX000000:ZZZPH0oooo303AcJT000/0dLfY1P3o
ool02@2ZZZX000000000003oool0EEEE0000002ZZZX0000005EEE@0300000080EEEE00H000000:ZZ
ZP2ZZZX0000005EEE@0000030:ZZZP0505EEE@2ZZZX0EEEE0?ooo`1EEED00P0000020?ooo`090000
001EEED0EEEE0?ooo`000000ZZZZ05EEE@000000ZZZZ0080000000@0EEEE0000002ZZZX0ZZZZ0`1E
EED02@3oool000000000001EEED0000005EEE@000000EEEE0:ZZZP02000000L0oooo2P3AcJT60?oo
o`070:ZZZP000000EEEE0?ooo`2ZZZX0oooo0:ZZZP0200000080EEEE00H0ZZZZ05EEE@2ZZZX0ZZZZ
0000002ZZZX205EEE@030:ZZZP1EEED000000080000000<0oooo0000000000000P0000020?ooo`03
0000003oool0oooo0080000000@0ZZZZ0?ooo`000000EEEE0P0000001@2ZZZX0EEEE0000002ZZZX0
00000080ZZZZ0`1EEED01P3oool000000000001EEED0oooo0:ZZZP80EEEE00<000000?ooo`3oool0
1@3oool:0=7=Z@H0oooo0`2ZZZX02`000000EEEE0000002ZZZX000000:ZZZP000000oooo0:ZZZP1E
EED0ZZZZ0080oooo0P0000001P3oool0ZZZZ0000003oool000000?ooo`80000000@0EEEE0?ooo`00
0000ZZZZ0P3oool00`2ZZZX0oooo0?ooo`0205EEE@040000003oool0ZZZZ0?ooo`80ZZZZ00<0oooo
0000000000000P3oool02`2ZZZX0EEEE0000003oool000000:ZZZP000000oooo0000001EEED0oooo
0080ZZZZ1`3oool:0=7=Z@H0oooo0P2ZZZX01@000000oooo000000000000oooo0080000000<0oooo
05EEE@2ZZZX00P0000001P3oool000000000003oool000000:ZZZP@0oooo0P1EEED030000000oooo
0?ooo`3oool0ZZZZ05EEE@3oool0ZZZZ0?ooo`000000oooo05EEE@<0oooo0P2ZZZX01@000000oooo
000000000000oooo0080000000<0oooo05EEE@2ZZZX00P0000001P3oool000000000003oool00000
0:ZZZPL0oooo2P3AcJT60?ooo`80ZZZZ00<0oooo05EEE@3oool00P00000205EEE@070000003oool0
oooo0?ooo`1EEED0ZZZZ0?ooo`0205EEE@0<0:ZZZP1EEED0EEEE05EEE@3oool000000:ZZZP3oool0
ZZZZ0000001EEED0ZZZZ0P1EEED01P2ZZZX0oooo0000002ZZZX0oooo0:ZZZP80000000@0EEEE0000
001EEED0ZZZZ0P1EEED20?ooo`0505EEE@3oool0EEEE0?ooo`0000000P1EEED00`2ZZZX000000?oo
o`020?ooo`030:ZZZP3oool0oooo00D0oooo303AcJT000/0dLfY1`3oool00`2ZZZX0EEEE00000002
00000080oooo0`0000001@2ZZZX0oooo0:ZZZP1EEED0oooo00D0000000@0oooo0:ZZZP1EEED0ZZZZ
0`3oool00`1EEED000000?ooo`020000000505EEE@3oool0oooo05EEE@2ZZZX00P1EEED01`3oool0
EEEE000000000000EEEE0000003oool00P2ZZZX01`3oool0EEEE0000002ZZZX000000?ooo`2ZZZX0
0P0000000`3oool0EEEE0:ZZZP070?ooo`X0dLfY1`3oool00`2ZZZX000000:ZZZP0205EEE@030000
003oool0ZZZZ00<0000000P0ZZZZ0000002ZZZX000000?ooo`1EEED0000005EEE@80ZZZZ00D0oooo
05EEE@1EEED0ZZZZ0?ooo`0200000080oooo00D000000?ooo`3oool000000?ooo`0305EEE@80ZZZZ
00P0oooo05EEE@000000EEEE0?ooo`000000ZZZZ00000080ZZZZ00@0000005EEE@2ZZZX0oooo0`1E
EED2000000030:ZZZP3oool0oooo00D0oooo2P3AcJT70?ooo`040:ZZZP000000oooo05EEE@800000
00@0oooo0000001EEED000000P2ZZZX00`000000oooo0?ooo`0200000080oooo00<0000005EEE@3o
ool00P3oool010000000ZZZZ0:ZZZP2ZZZX40?ooo`<0ZZZZ00<0EEEE0?ooo`3oool00P1EEED00`2Z
ZZX0oooo0?ooo`0200000080oooo00d000000:ZZZP1EEED000000:ZZZP000000oooo0:ZZZP000000
EEEE0?ooo`000000ZZZZ00L0oooo2P3AcJT70?ooo`030:ZZZP3oool0EEEE0080000000<0ZZZZ0?oo
o`2ZZZX00P0000020:ZZZP070?ooo`1EEED000000000002ZZZX0oooo0:ZZZP030?ooo`80000000<0
oooo0:ZZZP2ZZZX00P0000000`2ZZZX0oooo000000030:ZZZP<000000`3oool00`2ZZZX0oooo05EE
E@02000000030:ZZZP3oool0ZZZZ008000000P2ZZZX01`3oool0EEEE000000000000ZZZZ0?ooo`2Z
ZZX01`3oool:0=7=Z@L0oooo00<0ZZZZ0?ooo`2ZZZX00P2ZZZX01@3oool0EEEE05EEE@3oool0EEEE
00<0ZZZZ00D0oooo0000003oool000000?ooo`02000000030?ooo`2ZZZX0ZZZZ00<0oooo0P2ZZZX0
101EEED0oooo05EEE@1EEED20:ZZZP<0oooo0P2ZZZX0203oool0ZZZZ0000003oool0ZZZZ0?ooo`00
0000EEEE0`2ZZZX01@1EEED0oooo05EEE@1EEED0oooo0080ZZZZ00<0EEEE0?ooo`2ZZZX01`3oool<
0=7=Z@002`3AcJT90?ooo`0405EEE@2ZZZX0oooo05EEE@80000000D0oooo0000003oool0oooo05EE
E@020:ZZZP050000002ZZZX000000?ooo`0000000`3oool500000080oooo00<000000?ooo`000000
100000000`3oool0ZZZZ0?ooo`020?ooo`<0000000L0ZZZZ05EEE@1EEED0oooo05EEE@000000EEEE
0080000000@0ZZZZ0?ooo`2ZZZX0ZZZZ2@3oool:0=7=Z@T0oooo00P0000005EEE@1EEED0EEEE0000
003oool0ZZZZ05EEE@80ZZZZ0`1EEED20:ZZZP0405EEE@3oool0oooo0:ZZZP@0000000<0oooo0000
000000000P3oool01P000000oooo0?ooo`000000oooo0:ZZZP8000000`2ZZZX0103oool0EEEE0?oo
o`2ZZZX305EEE@030:ZZZP000000EEEE0080oooo00D0000005EEE@1EEED0EEEE0:ZZZP090?ooo`X0
dLfY2@3oool01`000000oooo0:ZZZP000000EEEE0000002ZZZX00P3oool200000080oooo0P000003
0?ooo`030:ZZZP1EEED0000000@0ZZZZ1P3oool20:ZZZP0505EEE@2ZZZX000000000002ZZZX00`3o
ool200000080oooo0P0000001@1EEED0oooo0:ZZZP000000EEEE0080ZZZZ00<0oooo0:ZZZP3oool0
203oool:0=7=Z@T0oooo00@000000?ooo`3oool0ZZZZ0P3oool00`000000oooo05EEE@020?ooo`04
0000003oool0oooo0:ZZZPD0oooo0P0000020?ooo`050000001EEED0EEEE0:ZZZP3oool00P1EEED0
0`000000oooo00000002000000D0oooo00@000000?ooo`3oool0ZZZZ0P3oool00`000000oooo05EE
E@020?ooo`040000003oool0oooo0:ZZZPT0oooo2P3AcJT90?ooo`040000002ZZZX000000:ZZZP80
EEEE00<000000?ooo`0000000P1EEED40:ZZZP090000002ZZZX0ZZZZ0:ZZZP000000EEEE0:ZZZP1E
EED0ZZZZ0080EEEE00T0ZZZZ0000002ZZZX0ZZZZ0000001EEED0ZZZZ05EEE@2ZZZX00P1EEED30:ZZ
ZP040000002ZZZX0ZZZZ0:ZZZP<0EEEE00<0ZZZZ0?ooo`3oool00`1EEED00`000000ZZZZ0:ZZZP09
0?ooo``0dLfY000;0=7=Z@T0oooo00D0ZZZZ0000002ZZZX0EEEE0?ooo`020:ZZZP80000000X0oooo
0000003oool0oooo0:ZZZP3oool000000?ooo`000000ZZZZ1@1EEED00`000000ZZZZ0000000205EE
E@<0000000<0EEEE0000001EEED00P1EEED02P2ZZZX000000?ooo`000000EEEE0:ZZZP3oool0ZZZZ
0000003oool20000000605EEE@2ZZZX0oooo05EEE@2ZZZX000002P3oool:0=7=Z@T0oooo00<0ZZZZ
000000000000100000001P1EEED0oooo0000001EEED0000005EEE@8000000P1EEED00`2ZZZX00000
0:ZZZP020:ZZZP040000003oool0000000000080oooo00D000000?ooo`3oool000000?ooo`040:ZZ
ZP0:0000001EEED0EEEE05EEE@3oool0000005EEE@000000EEEE00000080EEEE00@0oooo00000000
0000ZZZZ0P00000:0?ooo`X0dLfY2@3oool40:ZZZP040000002ZZZX0ZZZZ0:ZZZP<000000P3oool2
00000080oooo00P000000?ooo`2ZZZX0000005EEE@3oool0ZZZZ000000H0oooo00H000000:ZZZP00
0000EEEE0000002ZZZX40?ooo`8000000P3oool200000080ZZZZ00@0EEEE0:ZZZP000000EEEE0P2Z
ZZX:0?ooo`X0dLfY2@3oool30:ZZZP80oooo00H000000:ZZZP2ZZZX0oooo0000003oool30:ZZZPL0
oooo00X0EEEE0?ooo`3oool0oooo05EEE@3oool0ZZZZ05EEE@3oool0EEEE0`3oool00`1EEED0oooo
0?ooo`040?ooo`<0ZZZZ0P3oool01P000000ZZZZ0:ZZZP3oool000000?ooo`<0ZZZZ2P3oool:0=7=
Z@T0oooo0P2ZZZX010000000EEEE0:ZZZP2ZZZX20?ooo`80ZZZZ00/0EEEE0:ZZZP000000ZZZZ0000
002ZZZX000000:ZZZP000000oooo0:ZZZP030000000;0?ooo`2ZZZX0EEEE0:ZZZP000000EEEE0:ZZ
ZP3oool0000005EEE@0000000P2ZZZX00`000000ZZZZ000000030:ZZZP040000002ZZZX0EEEE0:ZZ
ZP80oooo00<0EEEE0:ZZZP2ZZZX00P0000000`2ZZZX0oooo0?ooo`080?ooo``0dLfY000;0=7=Z@/0
oooo00L0ZZZZ0?ooo`000000000005EEE@2ZZZX0oooo0080ZZZZ00/0EEEE0:ZZZP000000oooo0:ZZ
ZP000000ZZZZ05EEE@000000oooo0000000205EEE@030000001EEED0oooo0080EEEE0100oooo0:ZZ
ZP000000EEEE0:ZZZP000000oooo0:ZZZP1EEED0oooo0000002ZZZX0EEEE0000002ZZZX000000P2Z
ZZX00`1EEED0ZZZZ0?ooo`03000000030:ZZZP3oool0oooo00T0oooo2P3AcJT;0?ooo`070:ZZZP1E
EED0EEEE0:ZZZP3oool0ZZZZ0000000305EEE@050?ooo`00000000000?ooo`1EEED00P3oool01@1E
EED0ZZZZ000000000000oooo00<0000000<0oooo0000000000000P000000103oool000000000002Z
ZZX20?ooo`80EEEE0P3oool00`000000oooo05EEE@0205EEE@070000002ZZZX000000:ZZZP1EEED0
00000:ZZZP0;0?ooo`X0dLfY2`3oool20:ZZZP030000002ZZZX0ZZZZ0080oooo0P0000000`2ZZZX0
000000000002000000030:ZZZP00000000000080EEEE0P0000000`2ZZZX0EEEE0?ooo`050?ooo`05
05EEE@2ZZZX0oooo0000001EEED00`0000000`2ZZZX0000000000006000000040?ooo`2ZZZX0ZZZZ
00000080ZZZZ2`3oool:0=7=Z@/0oooo00/0ZZZZ0?ooo`000000ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP00
0000EEEE0:ZZZP080?ooo`0305EEE@3oool0oooo00<0oooo00@0ZZZZ05EEE@3oool0EEEE0`3oool0
0`1EEED0oooo0?ooo`060?ooo`0;0:ZZZP3oool000000:ZZZP3oool0ZZZZ05EEE@2ZZZX0000005EE
E@2ZZZX02`3oool:0=7=Z@/0oooo00@0ZZZZ0000002ZZZX0oooo0`00000205EEE@040?ooo`1EEED0
000000000080EEEE00@000000:ZZZP2ZZZX0ZZZZ0P3oool00`1EEED0000005EEE@020?ooo`070000
003oool0oooo0000001EEED0ZZZZ0?ooo`030:ZZZP<0EEEE00@0ZZZZ0000001EEED0ZZZZ0P1EEED0
1`3oool000000000003oool0ZZZZ05EEE@2ZZZX02`3oool<0=7=Z@002`3AcJT<0?ooo`0305EEE@00
000000000080ZZZZ00<0oooo0000001EEED00P2ZZZX2000000050?ooo`1EEED000000:ZZZP3oool0
0P0000000`2ZZZX0oooo0000000205EEE@070?ooo`1EEED0EEEE0?ooo`000000oooo0:ZZZP020000
00050?ooo`2ZZZX0ZZZZ05EEE@3oool00P0000000`2ZZZX0oooo05EEE@02000000050:ZZZP1EEED0
00000000002ZZZX0303oool:0=7=Z@`0oooo0P000000102ZZZX0EEEE0000002ZZZX400000080oooo
0P00000305EEE@070000003oool000000?ooo`000000oooo000000020?ooo`030000003oool00000
00<0oooo00@0000005EEE@1EEED0EEEE0P0000020?ooo`060000002ZZZX000000000003oool00000
0P2ZZZX00`000000ZZZZ0?ooo`0;0?ooo`X0dLfY303oool010000000oooo0000003oool200000003
0?ooo`000000oooo00@0ZZZZ00D0oooo000000000000oooo05EEE@020000000405EEE@000000oooo
00000080oooo00L000000?ooo`000000EEEE0:ZZZP000000EEEE00<0000000<0oooo0:ZZZP3oool0
0P2ZZZX200000080oooo00D000000:ZZZP000000oooo0:ZZZP0<0?ooo`X0dLfY303oool200000080
EEEE00D0ZZZZ0?ooo`1EEED000000:ZZZP080?ooo`8000000P3oool200000080ZZZZ00D0EEEE0:ZZ
ZP00000000000?ooo`03000000P0oooo0P00000205EEE@050:ZZZP3oool0EEEE0000002ZZZX0303o
ool:0=7=Z@`0oooo0P000000103oool0EEEE0?ooo`3oool205EEE@030000003oool0ZZZZ00800000
00P0EEEE0000002ZZZX0EEEE0:ZZZP1EEED000000?ooo`80ZZZZ00@0EEEE0?ooo`3oool0EEEE0P2Z
ZZX20?ooo`0705EEE@2ZZZX0EEEE0:ZZZP000000EEEE000000020:ZZZP80oooo0P1EEED40?ooo`03
0000002ZZZX0oooo00/0oooo303AcJT000/0dLfY303oool00`2ZZZX00000000000020?ooo`0<05EE
E@00000000000?ooo`1EEED0000005EEE@000000ZZZZ0?ooo`000000ZZZZ0P0000001@2ZZZX00000
05EEE@1EEED0oooo0080EEEE00D0oooo05EEE@1EEED000000:ZZZP020000000805EEE@000000oooo
0:ZZZP000000EEEE0000001EEED3000000030:ZZZP3oool0ZZZZ008000003@3oool:0=7=Z@`0oooo
00<0ZZZZ0000003oool00P000000103oool0EEEE0:ZZZP0000040?ooo`L0000000D0oooo00000000
000000000?ooo`02000000040?ooo`000000oooo0?ooo`80000000@0ZZZZ0000002ZZZX00000103o
ool20:ZZZP0605EEE@000000000005EEE@3oool000003@3oool:0=7=Z@`0oooo0`2ZZZX01`000000
oooo0?ooo`000000oooo0000002ZZZX00P3oool00`2ZZZX000000?ooo`0200000080ZZZZ00<0oooo
05EEE@0000000P0000020?ooo`050000002ZZZX0000005EEE@3oool00P2ZZZX4000000060:ZZZP00
0000oooo0:ZZZP000000oooo0P0000020?ooo`80ZZZZ3@3oool:0=7=Z@`0oooo0P2ZZZX20?ooo`04
0:ZZZP000000oooo0:ZZZPL0oooo00@000000?ooo`3oool0EEEE1@3oool010000000ZZZZ0?ooo`1E
EED30?ooo`0405EEE@3oool00000000000H0oooo0P2ZZZX20?ooo`040:ZZZP000000oooo0:ZZZPd0
oooo2P3AcJT<0?ooo`80ZZZZ00<0oooo0:ZZZP2ZZZX00P2ZZZX00`1EEED0oooo0:ZZZP0205EEE@05
0000001EEED0EEEE05EEE@2ZZZX00P1EEED30:ZZZP0305EEE@2ZZZX0ZZZZ0080ZZZZ00@000000:ZZ
ZP2ZZZX0oooo0P1EEED01@2ZZZX0EEEE0000001EEED000000080EEEE0P2ZZZX01`1EEED0ZZZZ0:ZZ
ZP2ZZZX0EEEE0?ooo`2ZZZX03@3oool<0=7=Z@002`3AcJT>0?ooo`030:ZZZP1EEED000000080ZZZZ
00L0oooo05EEE@3oool0oooo0:ZZZP3oool0000000<0EEEE00<0oooo0:ZZZP3oool00`1EEED0103o
ool0EEEE05EEE@3oool305EEE@030000002ZZZX0oooo0080EEEE0P0000040?ooo`0405EEE@3oool0
ZZZZ05EEE@80000000<0ZZZZ0?ooo`3oool0303oool:0=7=Z@h0oooo00@0ZZZZ0000002ZZZX0EEEE
0P3oool010000000EEEE0000001EEED2000000080:ZZZP3oool0oooo0?ooo`000000oooo0000003o
ool200000080oooo00<000000?ooo`3oool00`0000030?ooo`0305EEE@00000000000080000000P0
EEEE0000003oool0oooo05EEE@2ZZZX000000:ZZZPh0oooo2P3AcJT>0?ooo`<0ZZZZ00L0oooo0000
0000000000000:ZZZP000000oooo0080ZZZZ00<0oooo0000000000000P3oool205EEE@030?ooo`00
000000000080oooo0P0000000`3oool0EEEE0:ZZZP020?ooo`<000000`2ZZZX00`000000ZZZZ0:ZZ
ZP03000000<0ZZZZ3P3oool:0=7=Z@h0oooo0P2ZZZX01@3oool000000:ZZZP000000EEEE00H0oooo
0P1EEED0103oool000000:ZZZP3oool20:ZZZP0905EEE@000000000005EEE@3oool0ZZZZ0?ooo`2Z
ZZX000000080oooo00<0EEEE0?ooo`3oool0103oool00`2ZZZX000000:ZZZP020?ooo`0305EEE@2Z
ZZX0oooo00d0oooo2P3AcJT>0?ooo`D0ZZZZ00@0EEEE0?ooo`2ZZZX0EEEE0P2ZZZX205EEE@040:ZZ
ZP1EEED0ZZZZ0:ZZZP80EEEE00@0oooo0:ZZZP2ZZZX0oooo0P2ZZZX20?ooo`0305EEE@2ZZZX0ZZZZ
00<0ZZZZ00D0oooo05EEE@2ZZZX0ZZZZ05EEE@020:ZZZP0605EEE@2ZZZX0EEEE0:ZZZP1EEED0ZZZZ
3P3oool<0=7=Z@002`3AcJT?0?ooo`0305EEE@2ZZZX0ZZZZ0080oooo101EEED01`2ZZZX000000:ZZ
ZP3oool000000?ooo`0000000P1EEED0103oool0EEEE05EEE@3oool205EEE@80oooo0P1EEED01000
0000oooo0:ZZZP3oool2000000040:ZZZP1EEED0EEEE05EEE@@0oooo0P2ZZZX?0?ooo`X0dLfY3`3o
ool00`000000oooo0?ooo`020?ooo`060000002ZZZX000000?ooo`1EEED0ZZZZ1P3oool01@000000
oooo000000000000oooo00<0000000<0oooo000000000000103oool20:ZZZP0405EEE@3oool00000
0:ZZZP<0oooo00<0EEEE0?ooo`2ZZZX03`3oool:0=7=Z@l0oooo00T000000?ooo`2ZZZX0ZZZZ0?oo
o`000000EEEE0000003oool00P1EEED50?ooo`80ZZZZ0`0000020?ooo`<0000000D0ZZZZ0000003o
ool0oooo05EEE@020?ooo`80EEEE00D0ZZZZ0000001EEED0ZZZZ0?ooo`020:ZZZP030?ooo`2ZZZX0
oooo00h0oooo2P3AcJT?0?ooo`060000002ZZZX0oooo0?ooo`2ZZZX000000`3oool3000000030?oo
o`1EEED0ZZZZ00<0oooo00@0000005EEE@2ZZZX0oooo0P2ZZZX01@1EEED000000?ooo`2ZZZX0oooo
0080ZZZZ0P3oool2000000<0oooo0P2ZZZX0103oool0EEEE0:ZZZP2ZZZX?0?ooo`X0dLfY3`3oool0
0`000000ZZZZ0:ZZZP0205EEE@040000003oool0EEEE0:ZZZP80EEEE00H0ZZZZ0000002ZZZX0EEEE
0000001EEED30:ZZZP040000002ZZZX0ZZZZ000000@0ZZZZ00D0000005EEE@2ZZZX000000?ooo`04
05EEE@80oooo0`1EEED20:ZZZPl0oooo303AcJT000/0dLfY3`3oool00`2ZZZX0000005EEE@0305EE
E@060?ooo`1EEED0oooo05EEE@000000EEEE0P2ZZZX00`000000EEEE0?ooo`0305EEE@040?ooo`1E
EED0EEEE0?ooo`D0EEEE0P0000000`2ZZZX0EEEE0000000305EEE@060?ooo`1EEED0EEEE05EEE@2Z
ZZX00000403oool:0=7=Z@l0oooo00<0ZZZZ0000001EEED00`1EEED01@3oool0000005EEE@000000
EEEE00@000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool000000?ooo`80000000X0
oooo0000003oool000000?ooo`1EEED000000:ZZZP000000oooo101EEED00`000000oooo0?ooo`0>
0?ooo`X0dLfY3`3oool20:ZZZP0805EEE@2ZZZX0ZZZZ05EEE@000000oooo0:ZZZP0000030:ZZZP80
000000<0ZZZZ05EEE@0000000`0000020?ooo`D0000000<0ZZZZ0000002ZZZX00`2ZZZX200000003
0?ooo`000000ZZZZ00@0ZZZZ403oool:0=7=Z@l0oooo0P2ZZZX20?ooo`040000003oool0oooo0000
0080oooo00D0EEEE0:ZZZP2ZZZX000000?ooo`0205EEE@040?ooo`2ZZZX0EEEE0:ZZZP80EEEE0`2Z
ZZX0103oool0ZZZZ05EEE@3oool20:ZZZP030?ooo`1EEED0oooo0080000000H0oooo05EEE@000000
oooo0000002ZZZX@0?ooo`X0dLfY3`3oool20:ZZZP030?ooo`1EEED0EEEE00@0ZZZZ00<0EEEE0:ZZ
ZP2ZZZX00`0000001@1EEED0ZZZZ0:ZZZP000000ZZZZ00@0000000<0ZZZZ0000002ZZZX00P1EEED3
00000080ZZZZ0P1EEED20:ZZZP050?ooo`1EEED0EEEE0000002ZZZX0403oool<0=7=Z@002`3AcJTA
0?ooo`050000003oool000000000003oool0100000000`1EEED0ZZZZ0?ooo`0205EEE@050?ooo`1E
EED0EEEE05EEE@3oool00P1EEED00`3oool0EEEE05EEE@0405EEE@030000002ZZZX0oooo00@00000
00D0oooo000000000000oooo0:ZZZP0A0?ooo`X0dLfY4@3oool02P000000oooo05EEE@3oool0ZZZZ
0000001EEED0000005EEE@3oool4000000030?ooo`0000000000008000000P3oool900000080EEEE
00<000000:ZZZP0000000P2ZZZX00`1EEED0oooo0:ZZZP0A0?ooo`X0dLfY4@3oool20:ZZZP800000
00P0ZZZZ05EEE@000000ZZZZ05EEE@3oool0ZZZZ00000080ZZZZ1@0000020?ooo`@000000`2ZZZX0
10000000ZZZZ0:ZZZP1EEED20:ZZZP0405EEE@2ZZZX0ZZZZ00000080ZZZZ4@3oool:0=7=ZA40oooo
0P1EEED00`3oool0EEEE0?ooo`020:ZZZP050000002ZZZX0oooo0?ooo`2ZZZX00P1EEED02@000000
ZZZZ0:ZZZP3oool0ZZZZ0?ooo`000000ZZZZ0?ooo`020:ZZZP030?ooo`1EEED0EEEE00<0oooo00@0
ZZZZ0000001EEED0ZZZZ0`3oool00`1EEED0ZZZZ0?ooo`0@0?ooo`X0dLfY4@3oool00`1EEED00000
00000002000000060:ZZZP3oool0ZZZZ0:ZZZP3oool0ZZZZ0P0000020:ZZZP040?ooo`2ZZZX00000
0:ZZZP8000000`2ZZZX0103oool0ZZZZ0:ZZZP0000050:ZZZP030?ooo`2ZZZX0000000<0000000<0
ZZZZ0?ooo`3oool03`3oool<0=7=Z@002`3AcJTA0?ooo`070:ZZZP1EEED0000005EEE@000000ZZZZ
0000000205EEE@030:ZZZP3oool0000000<0000000<0oooo0:ZZZP3oool0100000020:ZZZP040?oo
o`000000000000000080oooo00D0000005EEE@1EEED000000:ZZZP030000000305EEE@3oool0oooo
0100oooo2P3AcJTA0?ooo`070:ZZZP000000EEEE0:ZZZP000000ZZZZ0?ooo`0305EEE@80ZZZZ00<0
EEEE0:ZZZP000000100000000`3oool0000000000003000000030?ooo`2ZZZX0EEEE0080ZZZZ00H0
000005EEE@1EEED0oooo0:ZZZP00000205EEE@030000003oool0oooo0100oooo2P3AcJTA0?ooo`05
0:ZZZP000000oooo0:ZZZP1EEED00P2ZZZX00`000000oooo05EEE@02000000030?ooo`2ZZZX0oooo
00@000000P3oool50000000=0:ZZZP3oool000000000001EEED0oooo0000001EEED0ZZZZ05EEE@00
0000oooo0000000B0?ooo`X0dLfY4@3oool01P2ZZZX000000?ooo`000000ZZZZ00000080oooo00<0
EEEE0:ZZZP0000000P2ZZZX00`1EEED0oooo0:ZZZP030?ooo`80ZZZZ0`3oool20:ZZZP0305EEE@2Z
ZZX000000080000000D0EEEE0?ooo`2ZZZX000000:ZZZP020?ooo`030000003oool0oooo0100oooo
2P3AcJTA0?ooo`030:ZZZP0000000000008000000`2ZZZX010000000ZZZZ0:ZZZP2ZZZX200000003
0?ooo`1EEED0ZZZZ0080EEEE00H0000005EEE@1EEED000000:ZZZP1EEED400000080ZZZZ00H00000
0:ZZZP2ZZZX0ZZZZ0000002ZZZX200000180oooo303AcJT000/0dLfY4P3oool0102ZZZX000000:ZZ
ZP3oool305EEE@030?ooo`000000EEEE0080000000@0EEEE0000001EEED0ZZZZ0`1EEED02P000000
EEEE05EEE@2ZZZX0EEEE0000001EEED000000:ZZZP1EEED20?ooo`0405EEE@000000EEEE0?ooo`80
000000<0ZZZZ0?ooo`3oool0403oool:0=7=ZA80oooo00@0ZZZZ0000002ZZZX0ZZZZ0`1EEED20000
000305EEE@000000EEEE0080000000@0oooo0:ZZZP2ZZZX0oooo0P1EEED00`3oool0EEEE0:ZZZP02
0?ooo`040000001EEED0oooo05EEE@8000000`1EEED0102ZZZX000000000002ZZZXB0?ooo`X0dLfY
4P3oool20:ZZZP040?ooo`000000EEEE0?ooo`80ZZZZ00@000000:ZZZP000000ZZZZ0P000000103o
ool000000000000000020?ooo`<000000P3oool00`000000ZZZZ05EEE@040:ZZZP030000001EEED0
000000<0ZZZZ4P3oool:0=7=ZA80oooo0`2ZZZX20?ooo`050000001EEED0EEEE0?ooo`2ZZZX00P3o
ool20:ZZZP@0EEEE00<0ZZZZ05EEE@1EEED00`1EEED00`000000ZZZZ0?ooo`020:ZZZP040?ooo`1E
EED0EEEE05EEE@80oooo0`2ZZZXB0?ooo`X0dLfY4P3oool20:ZZZP050?ooo`1EEED0oooo05EEE@2Z
ZZX00`0000020:ZZZP040?ooo`2ZZZX0ZZZZ05EEE@<0000000@0EEEE0000001EEED0EEEE0P2ZZZX0
0`3oool0ZZZZ00000003000000050:ZZZP000000oooo05EEE@3oool00P2ZZZXB0?ooo``0dLfY000;
0=7=ZA@0oooo00H0000005EEE@00000000000?ooo`0000020?ooo`0805EEE@2ZZZX0ZZZZ0000003o
ool0ZZZZ0000001EEED20?ooo`0505EEE@3oool0ZZZZ0?ooo`1EEED00P2ZZZX30?ooo`060000003o
ool0EEEE0000001EEED0ZZZZ503oool:0=7=ZA@0oooo00H0000005EEE@1EEED0ZZZZ0?ooo`1EEED2
0:ZZZP8000000P3oool03@2ZZZX0EEEE0000003oool000000:ZZZP3oool0000005EEE@2ZZZX00000
0?ooo`0000000`2ZZZX00`1EEED0oooo0?ooo`0205EEE@030:ZZZP3oool0oooo0180oooo2P3AcJTD
0?ooo`<0ZZZZ00L0EEEE0000002ZZZX0oooo0000002ZZZX0oooo0080ZZZZ100000020?ooo`D00000
00<0ZZZZ0?ooo`1EEED00P0000000`2ZZZX00000000000030:ZZZQ@0oooo2P3AcJTD0?ooo`0605EE
E@3oool0000005EEE@2ZZZX000000P2ZZZX20?ooo`050000001EEED000000000001EEED00P3oool0
0`2ZZZX0oooo0?ooo`02000000070?ooo`000000oooo05EEE@2ZZZX0oooo000000020:ZZZP030000
003oool0ZZZZ01@0oooo2P3AcJTD0?ooo`0305EEE@2ZZZX000000080ZZZZ00<0oooo0:ZZZP000000
0`2ZZZX00`1EEED0oooo0?ooo`020:ZZZP80oooo00D0ZZZZ0?ooo`3oool0oooo05EEE@020:ZZZP04
0?ooo`00000000000?ooo`80ZZZZ00<000000:ZZZP2ZZZX0503oool<0=7=Z@002`3AcJTD0?ooo`0?
0:ZZZP1EEED0ZZZZ0:ZZZP1EEED000000?ooo`000000oooo0:ZZZP3oool0EEEE0:ZZZP000000EEEE
00@0oooo00<0ZZZZ0000002ZZZX00P3oool00`2ZZZX00000000000020000000405EEE@3oool0ZZZZ
05EEEAD0oooo2P3AcJTD0?ooo`030:ZZZP000000000000<0EEEE00@0oooo05EEE@3oool0oooo0P00
00002P3oool0EEEE0:ZZZP000000oooo05EEE@000000oooo05EEE@3oool2000000040?ooo`000000
EEEE00000080EEEE00<0ZZZZ0000000000005@3oool:0=7=ZA@0oooo00`0ZZZZ0000003oool0ZZZZ
0000001EEED0ZZZZ0000003oool0EEEE0:ZZZP3oool400000080oooo100000020:ZZZP80EEEE0P00
00001@1EEED000000:ZZZP3oool0000001D0oooo2P3AcJTD0?ooo`060:ZZZP00000000000?ooo`1E
EED000000P2ZZZX30?ooo`80ZZZZ00<0oooo05EEE@2ZZZX00P3oool20:ZZZP030?ooo`2ZZZX0EEEE
0080oooo00@000000:ZZZP00000000000P1EEED2000001D0oooo2P3AcJTD0?ooo`070:ZZZP000000
ZZZZ05EEE@2ZZZX0EEEE0?ooo`020:ZZZP070000001EEED0ZZZZ05EEE@3oool0EEEE000000020?oo
o`070000002ZZZX0oooo05EEE@2ZZZX0EEEE000000020:ZZZP060?ooo`1EEED0ZZZZ0000002ZZZX0
00005@3oool<0=7=Z@002`3AcJTE0?ooo`080:ZZZP000000EEEE05EEE@3oool0EEEE0000002ZZZX3
05EEE@030?ooo`000000EEEE00@0EEEE00<0oooo0000003oool00`1EEED2000000060:ZZZP3oool0
EEEE0:ZZZP000000ZZZZ5@3oool:0=7=ZAD0oooo00<0ZZZZ0000001EEED00P3oool01P2ZZZX00000
0000003oool000000?ooo`80000000@0ZZZZ05EEE@3oool0oooo0P1EEED2000000030?ooo`000000
oooo0080000000H0EEEE0?ooo`3oool0oooo0000002ZZZXE0?ooo`X0dLfY5@3oool20:ZZZP0405EE
E@2ZZZX0000005EEE@80ZZZZ00<000000:ZZZP3oool00P0000000`3oool000000:ZZZP0500000004
0?ooo`2ZZZX0000000000080ZZZZ00<000000:ZZZP2ZZZX00P2ZZZXE0?ooo`X0dLfY5@3oool20:ZZ
ZP030000003oool0ZZZZ0080oooo0`2ZZZX205EEE@80ZZZZ103oool00`000000ZZZZ05EEE@040:ZZ
ZP030?ooo`2ZZZX0ZZZZ0080oooo0P2ZZZXE0?ooo`X0dLfY5@3oool20:ZZZP030000001EEED0ZZZZ
00@0ZZZZ00D0oooo0000003oool0ZZZZ05EEE@040?ooo`0705EEE@2ZZZX0oooo0000003oool0ZZZZ
000000030:ZZZP0405EEE@000000ZZZZ0:ZZZQD0oooo303AcJT000/0dLfY5`3oool01P000000oooo
0000003oool0EEEE0?ooo`<0000000D0oooo0000001EEED0000005EEE@04000000060?ooo`000000
00000000002ZZZX0EEEE0P0000000`3oool0ZZZZ0?ooo`0F0?ooo`X0dLfY5`3oool2000000050:ZZ
ZP000000000005EEE@3oool00P0000000`3oool0ZZZZ0?ooo`040?ooo`0505EEE@2ZZZX0oooo0?oo
o`0000000P3oool2000000030:ZZZP000000ZZZZ01L0oooo2P3AcJTG0?ooo`80ZZZZ00D000000:ZZ
ZP2ZZZX0000005EEE@0500000080ZZZZ00<000000:ZZZP0000000P000000102ZZZX0000005EEE@3o
ool20:ZZZP030000002ZZZX0ZZZZ01L0oooo2P3AcJTG0?ooo`0405EEE@2ZZZX0oooo0?ooo`800000
00D0EEEE0:ZZZP3oool0oooo05EEE@050?ooo`080000001EEED0oooo0?ooo`2ZZZX0EEEE0?ooo`00
00020?ooo`80ZZZZ5`3oool:0=7=ZAL0oooo00<0EEEE0000002ZZZX00`0000001@1EEED0ZZZZ0:ZZ
ZP2ZZZX0EEEE00H0000000@0EEEE0:ZZZP2ZZZX0ZZZZ0P1EEED01@000000oooo0:ZZZP000000ZZZZ
01L0oooo303AcJT000/0dLfY5`3oool01P2ZZZX0EEEE0000001EEED0ZZZZ00000080EEEE00<00000
05EEE@2ZZZX00P1EEED20000000505EEE@3oool0ZZZZ05EEE@0000000P1EEED20:ZZZP80000000<0
EEEE0?ooo`3oool05P3oool:0=7=ZAL0oooo00/0ZZZZ0000003oool0ZZZZ0?ooo`000000ZZZZ05EE
E@000000oooo0000000605EEE@0:0000003oool0ZZZZ05EEE@2ZZZX000000?ooo`1EEED0oooo0000
01P0oooo2P3AcJTG0?ooo`040:ZZZP000000oooo0:ZZZP80oooo00H0000005EEE@2ZZZX0oooo0:ZZ
ZP3oool20:ZZZP070?ooo`2ZZZX0ZZZZ0:ZZZP3oool0ZZZZ05EEE@02000000040?ooo`000000oooo
000001P0oooo2P3AcJTG0?ooo`040:ZZZP000000ZZZZ0?ooo`80ZZZZ00<0oooo0000001EEED00P1E
EED01P3oool000000?ooo`3oool000000?ooo`<0EEEE00L000000?ooo`2ZZZX0ZZZZ05EEE@2ZZZX0
000001P0oooo2P3AcJTG0?ooo`040:ZZZP00000000000?ooo`80EEEE00P0oooo05EEE@2ZZZX0EEEE
0000002ZZZX000000:ZZZP@0000000<0EEEE0000001EEED00P3oool0101EEED0oooo00000000000H
0?ooo``0dLfY000;0=7=ZAP0oooo00H0ZZZZ0000002ZZZX0oooo0:ZZZP1EEED30:ZZZP80EEEE00@0
oooo0000003oool0oooo0P1EEED30:ZZZP0305EEE@3oool0oooo0080000000<0ZZZZ0?ooo`3oool0
5P3oool:0=7=ZAP0oooo00H0ZZZZ0000001EEED0ZZZZ0?ooo`2ZZZX20?ooo`80000000<0ZZZZ0000
001EEED01@000000202ZZZX0oooo0:ZZZP000000ZZZZ05EEE@000000ZZZZ603oool:0=7=ZAP0oooo
0P2ZZZX0103oool000000000003oool3000000050:ZZZP3oool0oooo05EEE@2ZZZX00P3oool0102Z
ZZX0000005EEE@0000020?ooo`040000002ZZZX0ZZZZ0:ZZZQP0oooo2P3AcJTH0?ooo`80ZZZZ1@3o
ool01P1EEED0oooo05EEE@1EEED000000?ooo`8000000P1EEED01`3oool0EEEE0?ooo`3oool0ZZZZ
0?ooo`0000000P2ZZZXH0?ooo`X0dLfY603oool20:ZZZP0405EEE@2ZZZX0ZZZZ05EEE@80oooo00<0
00000:ZZZP0000000P000000202ZZZX000000000002ZZZX0000005EEE@3oool0EEEE0P2ZZZX00`3o
ool0ZZZZ0:ZZZP0H0?ooo``0dLfY000;0=7=ZAX0oooo00<0000005EEE@1EEED00P2ZZZX01`1EEED0
oooo0?ooo`3oool0ZZZZ05EEE@3oool00P2ZZZX20?ooo`0605EEE@2ZZZX0ZZZZ0000001EEED0ZZZZ
6P3oool:0=7=ZAX0oooo00<000000?ooo`0000000P0000020:ZZZP80000000<0ZZZZ05EEE@000000
0P2ZZZX00`000000ZZZZ0?ooo`020000000305EEE@3oool0ZZZZ01X0oooo2P3AcJTJ0?ooo`80ZZZZ
00<000000?ooo`0000000`2ZZZX205EEE@80000000@0EEEE0:ZZZP2ZZZX0ZZZZ0P000000103oool0
ZZZZ0:ZZZP2ZZZXJ0?ooo`X0dLfY6P3oool205EEE@<0oooo00<0EEEE0000002ZZZX00P0000001P2Z
ZZX000000000003oool0ZZZZ000000@0oooo00<0EEEE0:ZZZP3oool06@3oool:0=7=ZAX0oooo00@0
EEEE0:ZZZP1EEED0ZZZZ0P1EEED0103oool0ZZZZ05EEE@2ZZZX20?ooo`040:ZZZP1EEED0ZZZZ0?oo
o`80EEEE102ZZZXJ0?ooo``0dLfY000;0=7=ZAX0oooo00D0ZZZZ05EEE@3oool0ZZZZ0?ooo`0305EE
E@050:ZZZP000000EEEE0:ZZZP0000000`1EEED20?ooo`80ZZZZ00<0EEEE0?ooo`3oool06@3oool:
0=7=ZAX0oooo00P0ZZZZ0000001EEED0oooo0:ZZZP1EEED0oooo00000080EEEE00/0oooo0:ZZZP1E
EED0oooo0000003oool000000:ZZZP3oool0EEEE0000000K0?ooo`X0dLfY6P3oool00`2ZZZX00000
0:ZZZP030:ZZZP050000003oool000000:ZZZP3oool00`2ZZZX00`3oool000000?ooo`020:ZZZP03
0?ooo`000000oooo01X0oooo2P3AcJTJ0?ooo`030:ZZZP000000oooo0080oooo0P000000201EEED0
ZZZZ0:ZZZP2ZZZX0oooo0:ZZZP3oool0EEEE0P0000030?ooo`030000003oool0oooo01T0oooo2P3A
cJTJ0?ooo`090:ZZZP000000EEEE0:ZZZP1EEED0ZZZZ05EEE@3oool0ZZZZ00@0oooo00D000000?oo
o`1EEED0ZZZZ05EEE@020:ZZZP030000003oool0oooo01T0oooo303AcJT000/0dLfY6`3oool20:ZZ
ZP<0EEEE00L0oooo05EEE@3oool0000005EEE@3oool000000080EEEE00H0oooo05EEE@1EEED0EEEE
0000002ZZZXK0?ooo`X0dLfY6`3oool0102ZZZX000000:ZZZP1EEED30?ooo`060000001EEED0oooo
0000001EEED000000P3oool205EEE@030:ZZZP000000ZZZZ01/0oooo2P3AcJTK0?ooo`80ZZZZ00@0
EEEE0:ZZZP2ZZZX0EEEE0P0000001`2ZZZX0oooo0?ooo`2ZZZX0EEEE0000001EEED00P2ZZZX00`1E
EED0ZZZZ0:ZZZP0K0?ooo`X0dLfY6`3oool40:ZZZP090?ooo`2ZZZX0ZZZZ0000003oool0ZZZZ05EE
E@3oool0EEEE00L0ZZZZ6`3oool:0=7=ZA/0oooo00<0ZZZZ0000003oool00P1EEED20:ZZZPD0oooo
0`2ZZZX205EEE@030?ooo`2ZZZX0ZZZZ01/0oooo303AcJT000/0dLfY703oool00`2ZZZX000000?oo
o`03000000030?ooo`000000EEEE00H0000000<0oooo0000003oool0703oool:0=7=ZA`0oooo00<0
ZZZZ0000001EEED0101EEED20?ooo`030000003oool0EEEE00@0EEEE00<000000?ooo`3oool06`3o
ool:0=7=ZA`0oooo102ZZZX00`000000ZZZZ0:ZZZP040:ZZZP0405EEE@2ZZZX0000000000080ZZZZ
7@3oool:0=7=ZA`0oooo00<0ZZZZ05EEE@3oool00P3oool205EEE@80oooo00P0ZZZZ0?ooo`1EEED0
EEEE0?ooo`000000oooo05EEEAd0oooo2P3AcJTL0?ooo`030:ZZZP1EEED000000080000000@0EEEE
0:ZZZP1EEED0ZZZZ101EEED30000000305EEE@3oool0oooo01/0oooo303AcJT000/0dLfY7@3oool0
1@2ZZZX0EEEE0000001EEED000000080EEEE0P00000205EEE@050000001EEED0000005EEE@2ZZZX0
7@3oool:0=7=ZAd0oooo00<0ZZZZ0000002ZZZX0100000020?ooo`030000001EEED0000000<00000
00<0ZZZZ0?ooo`3oool06`3oool:0=7=ZAd0oooo00@0ZZZZ000000000000ZZZZ0P1EEED00`2ZZZX0
EEEE0:ZZZP020:ZZZP0505EEE@2ZZZX0oooo0000002ZZZX07@3oool:0=7=ZAd0oooo00<0ZZZZ0000
001EEED0101EEED0103oool0000005EEE@3oool205EEE@80000000<0ZZZZ0?ooo`3oool06`3oool:
0=7=ZAd0oooo00<0ZZZZ0000002ZZZX00`0000001@3oool000000:ZZZP3oool0EEEE00@0000000<0
ZZZZ0?ooo`3oool06`3oool<0=7=Z@002`3AcJTO0?ooo`0305EEE@3oool0000000<0000000H0oooo
00000000000000000?ooo`2ZZZXO0?ooo`X0dLfY7`3oool01P000000EEEE05EEE@1EEED000000:ZZ
ZP80000000@0ZZZZ05EEE@1EEED0ZZZZ7`3oool:0=7=ZAl0oooo00T000000?ooo`3oool000000:ZZ
ZP3oool000000:ZZZP1EEED00P3oool00`2ZZZX0oooo0?ooo`0M0?ooo`X0dLfY803oool01@1EEED0
oooo000000000000ZZZZ00<0000000<0oooo05EEE@2ZZZX07`3oool:0=7=ZB00oooo00L0EEEE0:ZZ
ZP2ZZZX0EEEE0000003oool0EEEE0080ZZZZ00<0EEEE0:ZZZP3oool07P3oool<0=7=Z@002`3AcJTO
0?ooo`0;0:ZZZP000000EEEE0000001EEED0ZZZZ0000001EEED0000005EEE@000000803oool:0=7=
ZAl0oooo00T0ZZZZ000000000000ZZZZ0?ooo`2ZZZX0EEEE0?ooo`2ZZZX00P00000P0?ooo`X0dLfY
7`3oool30:ZZZP050000001EEED0ZZZZ0000001EEED00`2ZZZXP0?ooo`X0dLfY7`3oool00`2ZZZX0
EEEE0:ZZZP030:ZZZP050?ooo`2ZZZX0oooo0:ZZZP1EEED0803oool:0=7=ZAl0oooo00/0ZZZZ05EE
E@2ZZZX0ZZZZ05EEE@3oool0ZZZZ05EEE@000000ZZZZ05EEE@0P0?ooo``0dLfY000;0=7=ZB00oooo
00X0ZZZZ05EEE@3oool0EEEE0:ZZZP3oool0EEEE0:ZZZP1EEED0ZZZZ803oool:0=7=ZB00oooo00<0
ZZZZ0000001EEED00P0000001@2ZZZX000000?ooo`000000ZZZZ0200oooo2P3AcJTP0?ooo`0:0:ZZ
ZP000000ZZZZ0:ZZZP1EEED000000:ZZZP3oool000000:ZZZR00oooo2P3AcJTP0?ooo`0:0:ZZZP00
0000EEEE05EEE@000000ZZZZ05EEE@2ZZZX000000:ZZZR00oooo2P3AcJTP0?ooo`040:ZZZP000000
00000:ZZZP80oooo0P2ZZZX00`000000ZZZZ0?ooo`0O0?ooo``0dLfY000;0=7=ZB80oooo0P1EEED0
10000000oooo05EEE@2ZZZXR0?ooo`X0dLfY8P3oool20000000405EEE@2ZZZX000000:ZZZR80oooo
2P3AcJTR0?ooo`060000003oool0EEEE05EEE@3oool0ZZZZ8P3oool:0=7=ZB<0oooo00<0ZZZZ05EE
E@1EEED00P2ZZZXR0?ooo`X0dLfY8`3oool50:ZZZR80oooo303AcJT000/0dLfY8P3oool01@2ZZZX0
00000000003oool0000002<0oooo2P3AcJTR0?ooo`050:ZZZP000000EEEE0?ooo`0000008`3oool:
0=7=ZB80oooo0P2ZZZX00`000000ZZZZ0:ZZZP0S0?ooo`X0dLfY8P3oool00`2ZZZX0EEEE0?ooo`02
05EEEB<0oooo2P3AcJTR0?ooo`030:ZZZP1EEED0ZZZZ0080EEEE8`3oool<0=7=Z@002`3AcJTS0?oo
o`040:ZZZP000000EEEE0:ZZZR<0oooo2P3AcJTS0?ooo`040:ZZZP000000EEEE0:ZZZR<0oooo2P3A
cJTS0?ooo`040:ZZZP3oool000000:ZZZR<0oooo2P3AcJTS0?ooo`040:ZZZP3oool000000:ZZZR<0
oooo2P3AcJTS0?ooo`040:ZZZP3oool000000:ZZZR<0oooo303AcJT000/0dLfY903oool00`2ZZZX0
oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0
oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0
oooo0?ooo`0S0?ooo``0dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=
ZK80dLfY003o0=7=ZK80dLfY000;0=7=Z@070?ooo`2ZZZX0ZZZZ0000001EEED0oooo05EEE@020?oo
o`060000001EEED0EEEE05EEE@000000EEEE0P3oool2000000050?ooo`2ZZZX0EEEE0000002ZZZX0
0P0000000`2ZZZX0EEEE05EEE@020000000505EEE@3oool0oooo0?ooo`0000000P1EEED00`000000
EEEE0?ooo`020?ooo`8000000`1EEED20000000<0:ZZZP000000EEEE0:ZZZP3oool000000:ZZZP3o
ool0ZZZZ05EEE@000000oooo0P1EEED00`000000oooo0?ooo`030?ooo`040000002ZZZX0ZZZZ0?oo
o`X0dLfY00<0oooo0:ZZZP1EEED00P0000000`3oool00000000000020:ZZZP<0000000@0EEEE0000
0000000000000`2ZZZX01P000000oooo05EEE@000000ZZZZ05EEE@80000000D0oooo0000002ZZZX0
EEEE0:ZZZP03000000050?ooo`00000000000?ooo`0000000`2ZZZX01@000000EEEE0000002ZZZX0
EEEE0080ZZZZ00<0EEEE0?ooo`2ZZZX00P2ZZZX2000000030?ooo`000000EEEE00<000000P2ZZZX2
00000080oooo00@0000005EEE@2ZZZX0oooo2P3AcJT03@3oool0ZZZZ05EEE@3oool0EEEE0000002Z
ZZX000000:ZZZP1EEED0ZZZZ0000003oool00P2ZZZX205EEE@80ZZZZ00P0EEEE0000002ZZZX0EEEE
0:ZZZP1EEED0ZZZZ000000<0ZZZZ00D0EEEE0000002ZZZX0ZZZZ000000020:ZZZP030000002ZZZX0
ZZZZ0080ZZZZ00@0000005EEE@2ZZZX000000`2ZZZX0101EEED0000005EEE@2ZZZX205EEE@040:ZZ
ZP3oool0EEEE0?ooo`80ZZZZ0P0000001@2ZZZX0EEEE0:ZZZP000000oooo0080000000@0oooo05EE
E@2ZZZX0oooo2P3AcJT00`3oool0ZZZZ0:ZZZP0200000080ZZZZ00<0EEEE0:ZZZP3oool00`3oool0
0`2ZZZX0EEEE000000020:ZZZP0405EEE@3oool0ZZZZ0?ooo`80ZZZZ00L0EEEE0:ZZZP3oool0EEEE
0:ZZZP000000ZZZZ00<0oooo00@0ZZZZ05EEE@2ZZZX0oooo0P1EEED20?ooo`0505EEE@2ZZZX00000
0:ZZZP1EEED00P2ZZZX02@1EEED0oooo0:ZZZP3oool0EEEE0?ooo`1EEED0oooo0:ZZZP0205EEE@06
0:ZZZP3oool0oooo0?ooo`1EEED0ZZZZ0P1EEED00`2ZZZX0oooo000000020:ZZZP030?ooo`3AcJT0
dLfY00P0dLfY00<0oooo0000000000000`1EEED00`2ZZZX0EEEE05EEE@02000000050?ooo`1EEED0
EEEE05EEE@2ZZZX00P0000000`1EEED00000000000020?ooo`050:ZZZP3oool0ZZZZ05EEE@3oool0
0`2ZZZX205EEE@030?ooo`1EEED0oooo0080EEEE00<0oooo05EEE@3oool00P1EEED20:ZZZP0605EE
E@3oool0EEEE0:ZZZP3oool000000P3oool00`1EEED0000005EEE@0300000080EEEE0P3oool20000
0080EEEE00L0ZZZZ05EEE@3oool0EEEE0000002ZZZX0oooo00`0dLfY000;0=7=Z@040?ooo`2ZZZX0
oooo0?ooo`<0ZZZZ00L0EEEE0:ZZZP2ZZZX0ZZZZ0000003oool0ZZZZ0080EEEE00<000000:ZZZP3o
ool00`1EEED0202ZZZX0oooo0:ZZZP1EEED0oooo0:ZZZP3oool0ZZZZ0P1EEED01@000000EEEE0:ZZ
ZP2ZZZX0oooo0080ZZZZ0P1EEED00`000000oooo05EEE@030:ZZZP050?ooo`1EEED0ZZZZ0?ooo`2Z
ZZX00`1EEED00`3oool0EEEE0000000205EEE@80ZZZZ00@000000:ZZZP2ZZZX0ZZZZ0P1EEED00`2Z
ZZX000000?ooo`030?ooo`X0dLfY00<0oooo0:ZZZP3oool00P2ZZZX30?ooo`070000002ZZZX0EEEE
05EEE@3oool0EEEE0?ooo`020:ZZZP040000001EEED0EEEE05EEE@80ZZZZ00<0oooo000000000000
0P2ZZZX00`3oool000000?ooo`0200000080oooo00@000000?ooo`3oool000000P3oool200000004
0?ooo`000000ZZZZ0:ZZZP<0000000<0oooo0:ZZZP2ZZZX00`1EEED20:ZZZP040000003oool0EEEE
0:ZZZP80EEEE0P0000001@3oool000000?ooo`1EEED0ZZZZ00<0oooo2P3AcJT0103oool0ZZZZ0000
001EEED20:ZZZP060000003oool0oooo0:ZZZP3oool000000P3oool20:ZZZP0505EEE@3oool0ZZZZ
0000002ZZZX00P3oool20:ZZZP030?ooo`2ZZZX0EEEE0080oooo0`2ZZZX01@1EEED0ZZZZ0:ZZZP3o
ool0EEEE0080ZZZZ00L0EEEE0:ZZZP2ZZZX0ZZZZ0?ooo`2ZZZX0EEEE0080oooo00/0ZZZZ05EEE@3o
ool0oooo05EEE@000000ZZZZ0000001EEED000000:ZZZP020?ooo`030000003oool0ZZZZ0080oooo
0P2ZZZX00`3oool0EEEE000000020?ooo`X0dLfY00<0oooo0:ZZZP0000000P3oool010000000ZZZZ
05EEE@1EEED50?ooo`040:ZZZP3oool0EEEE05EEE@80oooo0P1EEED010000000ZZZZ0?ooo`2ZZZX2
0?ooo`0605EEE@3oool0ZZZZ0:ZZZP000000EEEE0P2ZZZX00`1EEED000000:ZZZP0205EEE@800000
00<0ZZZZ0?ooo`1EEED00P3oool01@2ZZZX0oooo000000000000EEEE00<0oooo0P1EEED20:ZZZPD0
oooo0P1EEED01@2ZZZX000000?ooo`3oool000000080oooo2P3AcJT00`3oool0ZZZZ05EEE@020?oo
o`<0EEEE00<0oooo0000003oool00P3oool205EEE@060:ZZZP3oool0ZZZZ0?ooo`000000ZZZZ0P1E
EED30?ooo`030000003oool0EEEE0080EEEE00H0oooo05EEE@1EEED0ZZZZ05EEE@3oool205EEE@03
0:ZZZP1EEED0EEEE00@0EEEE00D0oooo0:ZZZP3oool0oooo0:ZZZP0205EEE@040?ooo`000000oooo
05EEE@80oooo0P1EEED50?ooo`<0EEEE0P3oool00`1EEED0oooo0?ooo`0<0=7=Z@002`3AcJT30?oo
o`070:ZZZP3oool0ZZZZ0:ZZZP1EEED0oooo0:ZZZP0205EEE@0;0?ooo`1EEED0EEEE05EEE@000000
ZZZZ0000002ZZZX0EEEE0?ooo`1EEED00`3oool01@1EEED0oooo05EEE@1EEED0ZZZZ0080000000<0
ZZZZ05EEE@3oool00P2ZZZX0203oool0ZZZZ0:ZZZP000000EEEE0:ZZZP1EEED0ZZZZ103oool0202Z
ZZX0EEEE0?ooo`3oool0ZZZZ0000002ZZZX000001P1EEED20?ooo`0505EEE@2ZZZX0ZZZZ05EEE@2Z
ZZX00`3oool:0=7=Z@<0oooo00<0ZZZZ0?ooo`2ZZZX00P0000001P3oool0000005EEE@3oool0EEEE
0:ZZZP@0000000@0EEEE0?ooo`3oool0oooo0P0000000`2ZZZX000000:ZZZP030:ZZZP0305EEE@00
0000ZZZZ0080000000@0oooo000000000000oooo0P0000001P2ZZZX0EEEE05EEE@2ZZZX0oooo0:ZZ
ZP80000000L0ZZZZ000000000000oooo0000003oool0EEEE00@000000P2ZZZX0103oool0EEEE0000
003oool2000000030:ZZZP1EEED0ZZZZ00<0oooo2P3AcJT30?ooo`80ZZZZ00<000000?ooo`3oool0
0P3oool0102ZZZX0EEEE0:ZZZP0000030?ooo`050000003oool0oooo0?ooo`1EEED00P3oool00`2Z
ZZX0EEEE0:ZZZP020?ooo`80000000@0EEEE0000001EEED0EEEE0P0000001P2ZZZX000000:ZZZP1E
EED000000:ZZZP8000000P3oool01P000000EEEE0:ZZZP1EEED0oooo05EEE@<0oooo00P0ZZZZ0?oo
o`3oool0oooo0000003oool0EEEE0:ZZZP@0oooo00<000000:ZZZP2ZZZX00`3oool:0=7=Z@<0oooo
0P2ZZZX2000000030?ooo`2ZZZX0EEEE0080ZZZZ00L0oooo0:ZZZP2ZZZX0ZZZZ0?ooo`1EEED0oooo
00<0EEEE0P3oool0102ZZZX0EEEE0?ooo`2ZZZX305EEE@030?ooo`000000ZZZZ0080ZZZZ0P3oool0
102ZZZX0EEEE0:ZZZP00000405EEE@040:ZZZP3oool0EEEE0:ZZZP80oooo00<0EEEE0:ZZZP1EEED0
0`3oool60:ZZZP050?ooo`2ZZZX0oooo0?ooo`0000000P2ZZZX30?ooo`X0dLfY0`3oool00`2ZZZX0
oooo0?ooo`0205EEE@@0ZZZZ103oool02P2ZZZX0oooo0?ooo`3oool000000:ZZZP1EEED0000005EE
E@00000205EEE@<0oooo00H0000005EEE@1EEED0oooo05EEE@2ZZZX205EEE@040?ooo`1EEED0EEEE
05EEE@<0oooo0P1EEED01@000000EEEE0000001EEED0ZZZZ00@0oooo00D0ZZZZ05EEE@3oool0oooo
05EEE@040:ZZZP0505EEE@3oool0oooo05EEE@2ZZZX00`3oool<0=7=Z@002`3AcJT40?ooo`050:ZZ
ZP1EEED0000005EEE@3oool00P1EEED00`2ZZZX0EEEE0?ooo`020?ooo`@0000000<0EEEE0:ZZZP2Z
ZZX0103oool205EEE@060:ZZZP1EEED0oooo0?ooo`000000oooo101EEED2000000040?ooo`000000
EEEE0:ZZZP80EEEE103oool20:ZZZP0605EEE@00000000000?ooo`000000EEEE0P3oool02@1EEED0
ZZZZ05EEE@1EEED0oooo05EEE@000000EEEE0:ZZZP040?ooo`X0dLfY103oool01@2ZZZX0EEEE0?oo
o`3oool000000080ZZZZ00<0oooo0000000000001@2ZZZX20?ooo`030:ZZZP000000ZZZZ00<00000
0P2ZZZX30000000405EEE@2ZZZX0oooo00000080ZZZZ00@0000005EEE@2ZZZX0EEEE0`0000000`1E
EED0ZZZZ05EEE@02000000050:ZZZP000000ZZZZ0000003oool01@2ZZZX2000000080?ooo`2ZZZX0
ZZZZ0000003oool0000005EEE@2ZZZX40?ooo`X0dLfY103oool00`000000oooo0?ooo`040?ooo`03
0:ZZZP000000oooo00<0oooo00<0ZZZZ05EEE@1EEED00`1EEED20000000305EEE@3oool0oooo0080
oooo00H000000:ZZZP2ZZZX0ZZZZ0?ooo`1EEED20:ZZZP0605EEE@3oool0ZZZZ0:ZZZP3oool00000
0`3oool0102ZZZX0EEEE0000002ZZZX205EEE@030000001EEED0EEEE00D0oooo0P2ZZZX60?ooo`03
0:ZZZP3oool0oooo0080oooo2P3AcJT40?ooo`030000003oool0oooo0080000000@0ZZZZ05EEE@2Z
ZZX0EEEE1000000305EEE@030:ZZZP000000ZZZZ0080EEEE0`3oool00`2ZZZX000000:ZZZP030000
00030?ooo`1EEED0EEEE00<0EEEE0P0000020:ZZZP030000002ZZZX0oooo0080oooo00D0EEEE0000
002ZZZX000000:ZZZP0205EEE@030:ZZZP000000EEEE008000000P2ZZZX205EEE@8000000P3oool0
0`2ZZZX0oooo0?ooo`020?ooo`X0dLfY103oool2000000030?ooo`1EEED0EEEE00<0EEEE00@0oooo
0000001EEED0EEEE0`0000000`1EEED0oooo0?ooo`030:ZZZP80EEEE00@0oooo0000001EEED0EEEE
0P2ZZZX00`3oool0EEEE0?ooo`0205EEE@030?ooo`000000oooo0080ZZZZ0`1EEED20?ooo`0=05EE
E@2ZZZX0ZZZZ0:ZZZP3oool0000005EEE@000000ZZZZ0000003oool0EEEE0000000705EEE@030000
002ZZZX0oooo00<0oooo303AcJT000/0dLfY1@3oool0102ZZZX0EEEE0?ooo`1EEED30?ooo`030:ZZ
ZP3oool0EEEE0080EEEE00<0ZZZZ0000001EEED00`2ZZZX00`3oool0ZZZZ05EEE@020:ZZZP80oooo
00<0EEEE0:ZZZP1EEED00P2ZZZX0101EEED000000000001EEED20:ZZZP0605EEE@2ZZZX0EEEE0?oo
o`000000ZZZZ0P1EEED40:ZZZP80EEEE00<000000:ZZZP1EEED00P1EEED40?ooo`80EEEE00<0oooo
0000002ZZZX01@3oool:0=7=Z@D0oooo00<0ZZZZ0000000000000`3oool40:ZZZP0605EEE@2ZZZX0
00000:ZZZP000000oooo0P2ZZZX00`000000oooo0?ooo`0405EEE@040?ooo`2ZZZX0ZZZZ05EEE@D0
000000<0ZZZZ05EEE@2ZZZX00P3oool00`1EEED0ZZZZ05EEE@030?ooo`@0ZZZZ00D000000:ZZZP2Z
ZZX0ZZZZ05EEE@020:ZZZP0505EEE@2ZZZX0oooo0000003oool00P0000000`2ZZZX0oooo0?ooo`03
0?ooo`X0dLfY1@3oool0102ZZZX0oooo05EEE@3oool2000000090?ooo`000000EEEE0?ooo`2ZZZX0
oooo05EEE@3oool0000000<0ZZZZ00<0oooo0:ZZZP3oool01@3oool3000000050?ooo`1EEED0oooo
0:ZZZP1EEED00`0000070?ooo`060:ZZZP3oool0ZZZZ0:ZZZP1EEED000000`3oool01P2ZZZX0oooo
05EEE@2ZZZX0oooo00000080oooo00<0EEEE0:ZZZP2ZZZX01@3oool:0=7=Z@D0oooo0P2ZZZX01P00
0000oooo05EEE@2ZZZX0EEEE0?ooo`80EEEE00@0ZZZZ0000001EEED0EEEE0`2ZZZX01P000000oooo
05EEE@000000EEEE0?ooo`80EEEE00X0ZZZZ05EEE@1EEED0EEEE0?ooo`1EEED000000:ZZZP1EEED0
oooo0P1EEED20:ZZZP0505EEE@000000oooo0?ooo`0000000P1EEED01`000000ZZZZ05EEE@2ZZZX0
EEEE0?ooo`0000000`1EEED01P000000EEEE0:ZZZP000000oooo00000080ZZZZ1@3oool:0=7=Z@D0
oooo00D0ZZZZ0000001EEED0oooo05EEE@020:ZZZP0305EEE@000000000000<0oooo00L0ZZZZ0000
003oool0oooo05EEE@3oool0EEEE0080oooo00<000000?ooo`1EEED00P1EEED2000000060?ooo`2Z
ZZX0oooo0?ooo`2ZZZX0EEEE0P0000000`2ZZZX0EEEE05EEE@0200000080oooo0`1EEED0103oool0
ZZZZ0000002ZZZX20?ooo`<0000000P0EEEE0:ZZZP2ZZZX0EEEE0?ooo`1EEED000000:ZZZPD0oooo
303AcJT000/0dLfY1P3oool205EEE@040?ooo`1EEED0EEEE0?ooo`80EEEE00H0000005EEE@3oool0
ZZZZ0?ooo`1EEED20000000605EEE@2ZZZX0000005EEE@3oool0ZZZZ0P1EEED01@3oool0ZZZZ0?oo
o`2ZZZX0oooo00@0ZZZZ00<0oooo0:ZZZP3oool00P3oool01@1EEED0oooo0:ZZZP3oool0EEEE0080
000000@0EEEE0000003oool0EEEE103oool02@000000EEEE05EEE@3oool0EEEE0000003oool0EEEE
0:ZZZP060?ooo`X0dLfY1P3oool01@1EEED0oooo0:ZZZP2ZZZX0oooo0080000000@0ZZZZ00000000
000000000`1EEED00`000000oooo000000020:ZZZP0405EEE@2ZZZX0oooo0?ooo`<0ZZZZ0P000002
0:ZZZP030000002ZZZX0ZZZZ00<0000000P0EEEE0:ZZZP2ZZZX0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP80
000000D0oooo0:ZZZP1EEED0EEEE0:ZZZP03000000080:ZZZP00000000000?ooo`000000ZZZZ0?oo
o`2ZZZX60?ooo`X0dLfY1P3oool01P000000ZZZZ05EEE@2ZZZX0oooo05EEE@80000000X0oooo05EE
E@3oool0EEEE0:ZZZP1EEED0oooo0:ZZZP000000EEEE0P0000001@2ZZZX000000000002ZZZX00000
00@0ZZZZ0P0000000`1EEED000000:ZZZP030:ZZZP050000002ZZZX0ZZZZ0000002ZZZX00P000000
2P3oool000000:ZZZP3oool0EEEE0:ZZZP000000oooo05EEE@3oool20000000405EEE@3oool0EEEE
05EEE@80ZZZZ1P3oool:0=7=Z@H0oooo00H000000?ooo`3oool0000005EEE@0000020?ooo`0605EE
E@3oool0ZZZZ0000003oool0EEEE0P2ZZZX01P1EEED0oooo0?ooo`1EEED000000:ZZZP80oooo00<0
EEEE0?ooo`3oool00`1EEED20:ZZZP0405EEE@000000EEEE0?ooo`80EEEE00D0oooo05EEE@2ZZZX0
ZZZZ05EEE@020?ooo`0905EEE@2ZZZX0EEEE05EEE@3oool0EEEE0:ZZZP3oool0EEEE0080oooo00<0
000005EEE@3oool00P3oool00`2ZZZX0oooo0?ooo`040?ooo`X0dLfY1P3oool00`1EEED0oooo0?oo
o`0305EEE@80oooo00<000000?ooo`3oool00P3oool0102ZZZX0000005EEE@1EEED20?ooo`80EEEE
00@0oooo05EEE@1EEED0oooo0`2ZZZX205EEE@030000001EEED0EEEE00<0ZZZZ0P3oool01@1EEED0
ZZZZ0?ooo`000000EEEE0080oooo0`1EEED00`2ZZZX0oooo0?ooo`020?ooo`030000003oool0EEEE
0080EEEE0`3oool00`2ZZZX0oooo0?ooo`040?ooo``0dLfY000;0=7=Z@H0oooo0P2ZZZX02`000000
oooo05EEE@3oool000000?ooo`1EEED0ZZZZ0?ooo`2ZZZX0EEEE0080ZZZZ00@0oooo05EEE@2ZZZX0
oooo0`1EEED20?ooo`0705EEE@000000ZZZZ0000001EEED000000?ooo`020000000305EEE@000000
ZZZZ0080EEEE00D0oooo05EEE@1EEED0oooo05EEE@020?ooo`0@05EEE@3oool0EEEE0:ZZZP1EEED0
00000?ooo`2ZZZX0EEEE0?ooo`1EEED0oooo05EEE@3oool000000:ZZZPL0oooo2P3AcJT60?ooo`80
ZZZZ00L0EEEE0?ooo`000000ZZZZ0000002ZZZX000000080ZZZZ0`0000020:ZZZP0505EEE@2ZZZX0
00000000003oool00P0000000`3oool00000000000020:ZZZP<0000000<0oooo0000002ZZZX00P2Z
ZZX2000000030?ooo`2ZZZX0000000<000000P1EEED00`2ZZZX000000000000200000080ZZZZ00@0
00000:ZZZP2ZZZX0ZZZZ0P0000000`1EEED0ZZZZ0?ooo`060?ooo`X0dLfY1P3oool02P2ZZZX0EEEE
0:ZZZP1EEED0000005EEE@3oool0EEEE0:ZZZP0000020:ZZZP040?ooo`000000ZZZZ00000080oooo
00<0EEEE0:ZZZP3oool00P2ZZZX20?ooo`030:ZZZP3oool0oooo0080oooo0P0000001@3oool0ZZZZ
0?ooo`3oool000000080oooo00D0EEEE0:ZZZP3oool0ZZZZ05EEE@020?ooo`<0000000P0oooo0:ZZ
ZP2ZZZX0EEEE0:ZZZP1EEED0ZZZZ05EEE@80000000<0ZZZZ05EEE@3oool01P3oool:0=7=Z@H0oooo
00/0ZZZZ05EEE@000000ZZZZ0?ooo`2ZZZX000000:ZZZP1EEED0000005EEE@040?ooo`80EEEE00<0
000005EEE@1EEED00P2ZZZX00`1EEED0000005EEE@030?ooo`030:ZZZP1EEED0oooo00<0EEEE0`3o
ool00`1EEED0000005EEE@020:ZZZP80EEEE00@0ZZZZ05EEE@1EEED0EEEE0P3oool02`000000EEEE
05EEE@1EEED0ZZZZ05EEE@2ZZZX0oooo05EEE@000000EEEE00L0oooo2P3AcJT60?ooo`040:ZZZP00
000000000?ooo`<0EEEE0P0000001@1EEED000000?ooo`000000EEEE0080ZZZZ0`1EEED20:ZZZP80
EEEE00D0oooo05EEE@1EEED0ZZZZ000000020:ZZZP090000003oool0ZZZZ05EEE@000000ZZZZ0000
001EEED0oooo0080EEEE0P2ZZZX00`1EEED0ZZZZ05EEE@020:ZZZP0305EEE@000000EEEE00@00000
00@0oooo05EEE@1EEED0EEEE0P0000070?ooo``0dLfY000;0=7=Z@P0oooo102ZZZX20000000505EE
E@3oool0EEEE05EEE@0000000P1EEED20:ZZZP040?ooo`2ZZZX0ZZZZ05EEE@8000000P3oool305EE
E@80oooo00@0ZZZZ0000003oool0oooo0P1EEED30?ooo`8000001P2ZZZX02@000000EEEE00000000
0000EEEE0?ooo`1EEED0000005EEE@020:ZZZP030000002ZZZX0oooo00L0oooo2P3AcJT80?ooo`04
0:ZZZP00000000000?ooo`@0000000<0ZZZZ0?ooo`0000000P0000030:ZZZPH0000000@0ZZZZ0000
002ZZZX0ZZZZ0P000000102ZZZX000000000000000020:ZZZP030000002ZZZX000000080000000<0
ZZZZ0000000000000`2ZZZX300000080ZZZZ00D0EEEE000000000000ZZZZ0?ooo`02000000030:ZZ
ZP3oool0oooo00H0oooo2P3AcJT80?ooo`060:ZZZP1EEED0oooo0000003oool0EEEE0`3oool20:ZZ
ZP80000000H0ZZZZ0?ooo`2ZZZX0ZZZZ0?ooo`2ZZZX205EEE@080:ZZZP3oool0ZZZZ0000001EEED0
oooo05EEE@3oool205EEE@030:ZZZP1EEED000000080oooo0P2ZZZX00`1EEED0oooo0?ooo`020:ZZ
ZP060?ooo`2ZZZX000000000002ZZZX000000`3oool01P1EEED0oooo0000003oool000000:ZZZPP0
oooo2P3AcJT80?ooo`050:ZZZP3oool0oooo0?ooo`2ZZZX00P3oool2000000030?ooo`2ZZZX0EEEE
0080EEEE00H0ZZZZ0?ooo`3oool0oooo0000002ZZZX20?ooo`040:ZZZP3oool0ZZZZ05EEE@80ZZZZ
00<0oooo05EEE@2ZZZX00P1EEED30:ZZZP80oooo0P2ZZZX20?ooo`80ZZZZ00<0EEEE0:ZZZP1EEED0
0P2ZZZX01@000000EEEE0?ooo`3oool000000080oooo00<000000:ZZZP3oool01`3oool:0=7=Z@P0
oooo00@0ZZZZ0000001EEED0oooo1@1EEED01@000000EEEE0?ooo`3oool0ZZZZ0080EEEE00<0oooo
05EEE@1EEED00P3oool405EEE@030000003oool0ZZZZ00<0ZZZZ00<0oooo0000001EEED00`1EEED3
0?ooo`0405EEE@3oool0000005EEE@80ZZZZ00<0oooo05EEE@3oool01@1EEED0103oool0EEEE0000
002ZZZX80?ooo``0dLfY000;0=7=Z@T0oooo00P0EEEE000000000000oooo0:ZZZP1EEED0oooo05EE
E@<0ZZZZ00/0EEEE000000000000000005EEE@000000EEEE0?ooo`1EEED0oooo05EEE@020?ooo`<0
EEEE00H0ZZZZ0?ooo`1EEED0oooo05EEE@3oool205EEE@030?ooo`2ZZZX0oooo008000000P1EEED2
000000040?ooo`2ZZZX0ZZZZ0?ooo`<0EEEE00D0ZZZZ05EEE@00000000000:ZZZP090?ooo`X0dLfY
2@3oool0201EEED0oooo0:ZZZP000000EEEE0?ooo`2ZZZX000000`2ZZZX00`000000ZZZZ00000002
05EEE@040:ZZZP3oool0000005EEE@80000000<0ZZZZ0000000000000`2ZZZX00`000000ZZZZ0:ZZ
ZP02000000070:ZZZP00000000000?ooo`000000oooo0:ZZZP0205EEE@030000002ZZZX0ZZZZ0080
ZZZZ00T0EEEE0000002ZZZX0oooo05EEE@000000ZZZZ0?ooo`2ZZZX02@3oool:0=7=Z@T0oooo00<0
EEEE0000003oool00P3oool205EEE@80oooo00<0ZZZZ0?ooo`2ZZZX00P3oool01@2ZZZX0oooo0000
001EEED0oooo0080ZZZZ00X0EEEE0:ZZZP2ZZZX0ZZZZ0000001EEED000000:ZZZP1EEED0oooo0P2Z
ZZX205EEE@050:ZZZP3oool0oooo05EEE@000000103oool01`1EEED0oooo0:ZZZP000000oooo0000
001EEED00`3oool00`000000ZZZZ0?ooo`080?ooo`X0dLfY2@3oool0101EEED0000005EEE@3oool2
0000000505EEE@2ZZZX0oooo0?ooo`2ZZZX00P1EEED00`2ZZZX0EEEE000000020:ZZZP@0oooo0P00
00002P1EEED0oooo0:ZZZP2ZZZX000000:ZZZP3oool0EEEE0000002ZZZX40?ooo`0305EEE@2ZZZX0
00000080ZZZZ00<0EEEE0:ZZZP2ZZZX00P3oool0202ZZZX0oooo000000000000ZZZZ05EEE@000000
ZZZZ2@3oool:0=7=Z@T0oooo00<0EEEE0?ooo`3oool00P1EEED01P3oool0EEEE0?ooo`3oool00000
0:ZZZP<0EEEE0P2ZZZX00`000000EEEE05EEE@0205EEE@040?ooo`1EEED0oooo0?ooo`D0EEEE00`0
00000?ooo`3oool0EEEE0?ooo`1EEED0ZZZZ05EEE@3oool000000:ZZZP3oool205EEE@030000002Z
ZZX000000080oooo00<0EEEE0?ooo`1EEED00`3oool00`2ZZZX0oooo0?ooo`070?ooo``0dLfY000;
0=7=Z@X0oooo00L0ZZZZ0?ooo`2ZZZX0EEEE0?ooo`000000EEEE00<0ZZZZ00<0EEEE000000000000
0P2ZZZX010000000oooo05EEE@2ZZZX20?ooo`8000000P3oool00`1EEED0ZZZZ05EEE@0205EEE@03
0?ooo`000000EEEE00<0oooo00D0EEEE000000000000ZZZZ05EEE@02000000<0ZZZZ00D0oooo05EE
E@1EEED0oooo05EEE@020?ooo`030:ZZZP3oool0oooo00P0oooo2P3AcJT:0?ooo`030:ZZZP3oool0
EEEE00@0ZZZZ00@000000:ZZZP1EEED0oooo102ZZZX2000000050?ooo`1EEED0EEEE0000002ZZZX0
0P0000000`2ZZZX0000000000002000000050:ZZZP00000000000:ZZZP0000000P1EEED00`3oool0
ZZZZ000000040:ZZZP030?ooo`1EEED0ZZZZ0080ZZZZ00H0oooo0:ZZZP2ZZZX0ZZZZ0?ooo`2ZZZX:
0?ooo`X0dLfY2P3oool01`2ZZZX000000?ooo`2ZZZX0EEEE0000002ZZZX00P0000000`3oool0EEEE
05EEE@020?ooo`0905EEE@000000oooo05EEE@3oool0ZZZZ0?ooo`1EEED0ZZZZ00<0EEEE00D00000
0?ooo`1EEED0oooo05EEE@020:ZZZP0:0?ooo`2ZZZX0oooo05EEE@2ZZZX0000005EEE@2ZZZX0oooo
05EEE@80oooo0P0000020:ZZZP0505EEE@2ZZZX0oooo0000002ZZZX02P3oool:0=7=Z@X0oooo00P0
ZZZZ0000003oool0oooo0000002ZZZX0EEEE0:ZZZP80oooo00@0EEEE0?ooo`2ZZZX000000`2ZZZX0
10000000EEEE05EEE@0000020:ZZZP0;0000001EEED000000?ooo`2ZZZX0000005EEE@000000ZZZZ
05EEE@0000000P1EEED020000000EEEE0:ZZZP2ZZZX000000:ZZZP3oool0EEEE0P3oool205EEE@80
00000P3oool00`000000ZZZZ0?ooo`090?ooo`X0dLfY2P3oool0102ZZZX0EEEE0?ooo`3oool305EE
E@030?ooo`000000oooo0080oooo00<0EEEE0:ZZZP3oool00P1EEED01@3oool0EEEE05EEE@000000
EEEE0080oooo0P1EEED20?ooo`0705EEE@000000oooo0?ooo`1EEED0000005EEE@020?ooo`030000
001EEED0oooo0080EEEE0`3oool00`000000oooo05EEE@0205EEE@80oooo00<0EEEE0:ZZZP3oool0
2@3oool<0=7=Z@002`3AcJT;0?ooo`030:ZZZP000000EEEE0080oooo00D0ZZZZ05EEE@000000ZZZZ
000000020?ooo`0;05EEE@00000000000000002ZZZX0EEEE0000001EEED0ZZZZ0?ooo`1EEED00`2Z
ZZX01@3oool0ZZZZ05EEE@1EEED0oooo0080EEEE00<000000:ZZZP2ZZZX0100000020?ooo`0305EE
E@2ZZZX000000080ZZZZ00D0EEEE0?ooo`1EEED000000:ZZZP0;0?ooo`X0dLfY2`3oool01P2ZZZX0
00000000003oool0ZZZZ00000080oooo00D0ZZZZ05EEE@2ZZZX000000:ZZZP020000000305EEE@2Z
ZZX0oooo0080ZZZZ00D000000?ooo`1EEED0ZZZZ000000020:ZZZP80000000<0EEEE0?ooo`000000
102ZZZX00`1EEED0000000000002000000<0ZZZZ00D0oooo00000000000000000?ooo`0200000003
0:ZZZP3oool0oooo00T0oooo2P3AcJT;0?ooo`090:ZZZP1EEED000000000002ZZZX0EEEE0?ooo`1E
EED0ZZZZ00<0EEEE00P000000:ZZZP1EEED0EEEE0000002ZZZX000000?ooo`80EEEE0P3oool0101E
EED000000?ooo`1EEED20?ooo`80EEEE00P0oooo0000002ZZZX000000?ooo`1EEED0ZZZZ000000<0
EEEE00D0ZZZZ05EEE@2ZZZX0EEEE0?ooo`020000000305EEE@2ZZZX0oooo00X0oooo2P3AcJT;0?oo
o`040:ZZZP000000EEEE0:ZZZP<0EEEE00<0ZZZZ0000003oool00P3oool00`1EEED0oooo05EEE@02
0:ZZZP030?ooo`2ZZZX0ZZZZ0080oooo00<0ZZZZ05EEE@2ZZZX00P3oool0102ZZZX0EEEE0:ZZZP3o
ool50:ZZZP80EEEE00H0oooo0:ZZZP3oool0oooo05EEE@0000020:ZZZP0305EEE@3oool0ZZZZ0080
EEEE00<0ZZZZ0?ooo`3oool02@3oool:0=7=Z@/0oooo00H0ZZZZ0000001EEED0oooo05EEE@3oool4
0000000405EEE@3oool0EEEE05EEE@80ZZZZ00<0EEEE0:ZZZP2ZZZX00P3oool01@1EEED000000?oo
o`1EEED0ZZZZ0080EEEE00H0oooo0000001EEED0EEEE0?ooo`2ZZZX205EEE@80ZZZZ0P1EEED00`3o
ool0EEEE05EEE@020000000705EEE@3oool0EEEE0?ooo`1EEED000000:ZZZP0;0?ooo``0dLfY000;
0=7=Z@`0oooo00<0EEEE0?ooo`3oool00`1EEED00`2ZZZX0oooo05EEE@020:ZZZP80oooo00H00000
0?ooo`000000EEEE0?ooo`2ZZZX30?ooo`80000000@0ZZZZ0?ooo`000000EEEE0P3oool20:ZZZP07
0?ooo`00000000000?ooo`000000oooo05EEE@020:ZZZP80oooo00<0ZZZZ05EEE@1EEED00`3oool0
0`2ZZZX0oooo0?ooo`0:0?ooo`X0dLfY303oool0201EEED0oooo0:ZZZP2ZZZX000000:ZZZP1EEED0
ZZZZ0P0000000`2ZZZX0000005EEE@030000000605EEE@2ZZZX000000000003oool0ZZZZ0P000002
05EEE@060000002ZZZX0ZZZZ0?ooo`1EEED000000P2ZZZX30000000305EEE@2ZZZX0ZZZZ00800000
00<0ZZZZ05EEE@2ZZZX00P0000000`2ZZZX0oooo0:ZZZP0<0?ooo`X0dLfY303oool01`2ZZZX0oooo
05EEE@1EEED0ZZZZ0?ooo`1EEED00`3oool03P1EEED0ZZZZ05EEE@2ZZZX000000?ooo`2ZZZX0oooo
05EEE@2ZZZX0EEEE0000001EEED0ZZZZ0P0000001P2ZZZX0EEEE0000001EEED0000005EEE@<0oooo
00X000000:ZZZP1EEED0oooo05EEE@3oool0EEEE0?ooo`1EEED000000P2ZZZX00`1EEED0oooo0:ZZ
ZP0<0?ooo`X0dLfY303oool20:ZZZP8000000P1EEED02P3oool0EEEE05EEE@000000EEEE0:ZZZP00
0000EEEE0?ooo`2ZZZX20?ooo`050:ZZZP3oool0oooo0?ooo`2ZZZX0103oool01@2ZZZX0oooo0?oo
o`3oool0ZZZZ0080oooo00T0ZZZZ0?ooo`1EEED000000:ZZZP1EEED000000:ZZZP1EEED00P3oool0
0`1EEED0oooo000000020:ZZZP`0oooo2P3AcJT<0?ooo`0305EEE@3oool0oooo0080EEEE0`2ZZZX0
101EEED0oooo0?ooo`1EEED40?ooo`<0EEEE00<0ZZZZ0000003oool00P3oool205EEE@<0oooo00<0
00000:ZZZP1EEED00P1EEED00`3oool0ZZZZ0?ooo`040?ooo`@0ZZZZ00D0EEEE0?ooo`3oool0oooo
0:ZZZP0<0?ooo``0dLfY000;0=7=Z@d0oooo00T0ZZZZ0?ooo`3oool0oooo0:ZZZP3oool0EEEE0?oo
o`2ZZZX00P1EEED01@000000oooo0?ooo`1EEED0oooo00@0ZZZZ00H0EEEE0:ZZZP000000EEEE0?oo
o`00000205EEE@040:ZZZP3oool0ZZZZ0:ZZZP80EEEE00P0ZZZZ0?ooo`000000oooo05EEE@2ZZZX0
000005EEE@<0oooo00<0ZZZZ0?ooo`2ZZZX03@3oool:0=7=Z@d0oooo00D0ZZZZ0?ooo`1EEED0ZZZZ
000000020?ooo`030000002ZZZX0EEEE0080ZZZZ0P3oool30:ZZZP030000002ZZZX0oooo0080ZZZZ
00@0oooo0:ZZZP1EEED0oooo0P2ZZZX02@3oool000000000002ZZZX000000:ZZZP000000oooo0:ZZ
ZP0205EEE@030:ZZZP000000oooo0080oooo0P2ZZZX00`3oool0ZZZZ0?ooo`0<0?ooo`X0dLfY3@3o
ool00`2ZZZX0EEEE000000040?ooo`<0ZZZZ00D0000005EEE@2ZZZX0ZZZZ0?ooo`030:ZZZP030000
003oool00000008000000P2ZZZX01@000000EEEE0000003oool0EEEE00<0ZZZZ00@0oooo0000002Z
ZZX0EEEE0`2ZZZX00`1EEED0oooo0?ooo`020?ooo`030:ZZZP1EEED0ZZZZ00d0oooo2P3AcJT=0?oo
o`030:ZZZP1EEED0EEEE0080ZZZZ00@0oooo0:ZZZP00000000000P1EEED50:ZZZP0405EEE@3oool0
ZZZZ0?ooo`80ZZZZ00X000000:ZZZP000000000005EEE@2ZZZX0oooo0:ZZZP3oool0EEEE0P2ZZZX0
20000000ZZZZ0:ZZZP000000EEEE0000001EEED0ZZZZ0P3oool0102ZZZX0000005EEE@2ZZZX=0?oo
o`X0dLfY3@3oool01`2ZZZX0EEEE0?ooo`3oool0EEEE0?ooo`1EEED00`3oool0202ZZZX000000?oo
o`3oool000000:ZZZP3oool000000P1EEED40:ZZZP0405EEE@2ZZZX0ZZZZ0:ZZZP80EEEE00@00000
0?ooo`2ZZZX000000P3oool200000080oooo0P1EEED01P3oool0EEEE0?ooo`3oool0EEEE0:ZZZPd0
oooo303AcJT000/0dLfY3P3oool0102ZZZX0EEEE05EEE@1EEED20:ZZZP<0EEEE00D0ZZZZ0?ooo`1E
EED0EEEE0?ooo`0305EEE@80000000T0EEEE0?ooo`2ZZZX0ZZZZ05EEE@2ZZZX0oooo05EEE@000000
0`1EEED20?ooo`80EEEE00D0oooo0:ZZZP1EEED0EEEE0?ooo`020:ZZZP040000001EEED000000:ZZ
ZPh0oooo2P3AcJT>0?ooo`050:ZZZP00000000000:ZZZP1EEED00P2ZZZX30000000;0?ooo`000000
ZZZZ05EEE@000000ZZZZ05EEE@2ZZZX000000?ooo`0000000P2ZZZX01@3oool0ZZZZ0000003oool0
00000080EEEE00H0ZZZZ0000001EEED0ZZZZ0000003oool300000080ZZZZ00D0EEEE0?ooo`000000
00000:ZZZP0>0?ooo`X0dLfY3P3oool00`2ZZZX0EEEE0?ooo`0205EEE@040000002ZZZX0ZZZZ05EE
E@80ZZZZ0140oooo0000002ZZZX0oooo0:ZZZP3oool0EEEE0:ZZZP1EEED0oooo0000002ZZZX0oooo
0000003oool0EEEE0:ZZZP020?ooo`030:ZZZP000000ZZZZ0080oooo0P2ZZZX01`1EEED0ZZZZ05EE
E@000000EEEE0000003oool00P2ZZZX>0?ooo`X0dLfY3P3oool20:ZZZP80000000@0ZZZZ05EEE@1E
EED0oooo0P2ZZZX20?ooo`0605EEE@2ZZZX0EEEE0:ZZZP1EEED000000P1EEED01P3oool0ZZZZ0?oo
o`1EEED0ZZZZ0?ooo`80EEEE00<0000005EEE@2ZZZX00`2ZZZX20?ooo`80ZZZZ00H0oooo0:ZZZP1E
EED0ZZZZ0?ooo`0000020:ZZZPh0oooo2P3AcJT>0?ooo`030:ZZZP000000EEEE0080EEEE00<0ZZZZ
05EEE@1EEED00P0000040?ooo`070000003oool0EEEE0:ZZZP3oool0ZZZZ0?ooo`020:ZZZP090?oo
o`2ZZZX0oooo0:ZZZP3oool0ZZZZ05EEE@3oool0000000@0oooo0P000000201EEED0ZZZZ0:ZZZP1E
EED0oooo05EEE@000000ZZZZ3P3oool<0=7=Z@002`3AcJT?0?ooo`80EEEE00L0oooo0:ZZZP3oool0
oooo05EEE@3oool0000000D0EEEE0`3oool01P2ZZZX0EEEE0000001EEED0oooo000000<0EEEE00<0
ZZZZ05EEE@3oool00P3oool01`1EEED0ZZZZ05EEE@1EEED000000?ooo`1EEED00P3oool20:ZZZP03
05EEE@2ZZZX0oooo00h0oooo2P3AcJT?0?ooo`0305EEE@3oool0000000@0000000D0EEEE0:ZZZP1E
EED0ZZZZ0?ooo`020:ZZZP<000000P2ZZZX01P1EEED0ZZZZ0?ooo`000000ZZZZ05EEE@80ZZZZ0`00
00020:ZZZP070?ooo`2ZZZX0EEEE0?ooo`1EEED000000?ooo`02000000030:ZZZP3oool0ZZZZ00l0
oooo2P3AcJT?0?ooo`040000001EEED0ZZZZ0:ZZZP80oooo0P1EEED0203oool0EEEE05EEE@1EEED0
oooo0:ZZZP1EEED0ZZZZ0P1EEED30?ooo`0305EEE@000000oooo0080oooo0P1EEED01@2ZZZX0EEEE
05EEE@3oool0ZZZZ00H0EEEE00D0oooo0:ZZZP3oool0EEEE0:ZZZP0?0?ooo`X0dLfY3`3oool01@00
0000oooo0?ooo`000000ZZZZ00H0EEEE0P3oool01P000000ZZZZ0?ooo`1EEED0oooo00000080EEEE
0P3oool205EEE@040000003oool0ZZZZ0?ooo`80ZZZZ00D0oooo05EEE@1EEED0EEEE0?ooo`0205EE
E@80ZZZZ00@000000?ooo`3oool0ZZZZ3`3oool:0=7=Z@l0oooo00<0EEEE0?ooo`3oool00`1EEED7
0?ooo`030000003oool0EEEE0080EEEE00<000000:ZZZP0000000P1EEED00`000000ZZZZ00000003
05EEE@H0oooo00<000000?ooo`3oool00`1EEED20?ooo`030:ZZZP3oool0oooo00d0oooo303AcJT0
00/0dLfY403oool03P2ZZZX0EEEE0?ooo`000000EEEE0:ZZZP1EEED0000005EEE@2ZZZX0oooo05EE
E@2ZZZX0EEEE0`3oool05P1EEED0ZZZZ0000003oool0EEEE0000002ZZZX0EEEE0?ooo`2ZZZX0oooo
05EEE@000000EEEE0?ooo`2ZZZX0EEEE0000001EEED0ZZZZ05EEE@0000020?ooo`030:ZZZP3oool0
oooo00h0oooo2P3AcJT@0?ooo`80ZZZZ00D0EEEE0:ZZZP00000000000:ZZZP020?ooo`80000000H0
ZZZZ0000003oool0EEEE0?ooo`0000030:ZZZP0305EEE@2ZZZX0ZZZZ0080ZZZZ00@0000005EEE@1E
EED0oooo0P2ZZZX01P3oool000000?ooo`000000ZZZZ00000080ZZZZ00<0EEEE0?ooo`2ZZZX0403o
ool:0=7=ZA00oooo0P2ZZZX01P000000oooo0:ZZZP2ZZZX0oooo0:ZZZP80oooo0`0000001@3oool0
EEEE0?ooo`1EEED0oooo0080ZZZZ0P3oool0202ZZZX0oooo0?ooo`1EEED0oooo05EEE@3oool0EEEE
0P0000020?ooo`030:ZZZP3oool0ZZZZ0080oooo00<000000:ZZZP2ZZZX0403oool:0=7=ZA00oooo
0P2ZZZX01`000000oooo0?ooo`2ZZZX0oooo05EEE@2ZZZX00`1EEED01P3oool0EEEE0:ZZZP1EEED0
00000:ZZZPD0oooo0140EEEE0:ZZZP000000EEEE0:ZZZP1EEED0ZZZZ05EEE@2ZZZX0EEEE0:ZZZP1E
EED0oooo0:ZZZP000000oooo000000020:ZZZQ00oooo2P3AcJT@0?ooo`050:ZZZP3oool0oooo0?oo
o`1EEED0102ZZZX00`1EEED0ZZZZ000000030?ooo`80EEEE0`0000000`3oool0EEEE000000020000
000305EEE@3oool0oooo0080oooo00<000000?ooo`1EEED0102ZZZX01@1EEED0oooo0?ooo`1EEED0
ZZZZ0100oooo303AcJT000/0dLfY4@3oool00`000000ZZZZ0?ooo`020?ooo`<0ZZZZ0`3oool00`2Z
ZZX000000:ZZZP0205EEE@050?ooo`2ZZZX0oooo0?ooo`1EEED00`3oool01@1EEED000000:ZZZP00
0000EEEE00<0oooo0`2ZZZX00`3oool0EEEE0?ooo`020:ZZZQ40oooo2P3AcJTA0?ooo`@000000P3o
ool00`1EEED0ZZZZ0:ZZZP0305EEE@<0ZZZZ00@000000:ZZZP000000oooo0P0000001@3oool00000
0:ZZZP000000oooo0080ZZZZ0P1EEED40:ZZZP<0oooo0P0000000`2ZZZX0oooo0?ooo`0?0?ooo`X0
dLfY4@3oool01P000000oooo0?ooo`3oool0ZZZZ000000<0oooo00@000000?ooo`1EEED0ZZZZ1@1E
EED00`000000ZZZZ0000000200000080EEEE00<0000005EEE@2ZZZX01@3oool00`2ZZZX000000:ZZ
ZP030?ooo`030:ZZZP3oool0oooo00l0oooo2P3AcJTA0?ooo`030000003oool0oooo008000000`1E
EED00`3oool0ZZZZ0:ZZZP020?ooo`0505EEE@2ZZZX0EEEE0?ooo`0000001@1EEED0103oool0EEEE
05EEE@1EEED20?ooo`070:ZZZP3oool0oooo05EEE@2ZZZX0EEEE000000030?ooo`030:ZZZP3oool0
oooo00l0oooo2P3AcJTA0?ooo`8000001`1EEED200000080EEEE00<0ZZZZ05EEE@3oool00`3oool0
102ZZZX000000?ooo`0000020?ooo`0305EEE@2ZZZX0EEEE0080000000<0oooo05EEE@1EEED00`1E
EED0103oool0EEEE0000002ZZZXA0?ooo``0dLfY000;0=7=ZA80oooo0P2ZZZX01@000000oooo05EE
E@3oool0EEEE0080oooo0P1EEED01P2ZZZX0oooo05EEE@000000oooo05EEE@H0oooo00H0000005EE
E@3oool0ZZZZ0?ooo`1EEED20?ooo`0405EEE@3oool0EEEE0?ooo`<0ZZZZ4P3oool:0=7=ZA80oooo
0P2ZZZX01@000000oooo0000002ZZZX0000000D0ZZZZ0P0000020?ooo`030:ZZZP1EEED0EEEE0080
EEEE00<0ZZZZ0?ooo`3oool00P0000030:ZZZP070000002ZZZX000000:ZZZP000000oooo05EEE@02
0:ZZZQ80oooo2P3AcJTB0?ooo`80ZZZZ00D0EEEE0?ooo`3oool0ZZZZ05EEE@030:ZZZP0605EEE@2Z
ZZX0EEEE05EEE@3oool0ZZZZ0P1EEED20?ooo`0405EEE@2ZZZX0ZZZZ0?ooo`80EEEE1@2ZZZX00`1E
EED0oooo0?ooo`020?ooo`80ZZZZ4P3oool:0=7=ZA80oooo0P2ZZZX01`000000oooo0000002ZZZX0
EEEE0000001EEED00`0000001P1EEED000000:ZZZP3oool000000:ZZZP80oooo00H0ZZZZ05EEE@3o
ool0ZZZZ0?ooo`1EEED3000000060:ZZZP000000EEEE05EEE@000000oooo0`2ZZZXB0?ooo`X0dLfY
4P3oool01@2ZZZX0000005EEE@3oool0EEEE0080ZZZZ00<0EEEE0000000000000P1EEED00`3oool0
EEEE0:ZZZP030:ZZZP80EEEE102ZZZX00`1EEED0oooo05EEE@0200000080EEEE00@0ZZZZ05EEE@1E
EED0oooo0P0000000`2ZZZX0oooo0?ooo`0@0?ooo``0dLfY000;0=7=ZA<0oooo00X0ZZZZ0?ooo`00
0000ZZZZ05EEE@2ZZZX0EEEE0:ZZZP1EEED0oooo0P0000000`2ZZZX0oooo05EEE@050?ooo`80EEEE
00@0oooo0:ZZZP00000000000P1EEED00`2ZZZX0EEEE0:ZZZP020:ZZZP030000003oool0ZZZZ01<0
oooo2P3AcJTC0?ooo`80ZZZZ00X0EEEE0:ZZZP3oool0ZZZZ05EEE@000000ZZZZ0000002ZZZX00000
0P2ZZZX00`1EEED00000000000030000000@0:ZZZP1EEED0ZZZZ0:ZZZP000000ZZZZ0000002ZZZX0
000005EEE@2ZZZX0oooo0:ZZZP1EEED0oooo0:ZZZQ<0oooo2P3AcJTC0?ooo`80ZZZZ0`1EEED0102Z
ZZX000000:ZZZP3oool20:ZZZP0305EEE@2ZZZX0EEEE0080EEEE1@3oool205EEE@030000001EEED0
ZZZZ00<0oooo00<000000:ZZZP2ZZZX00P1EEED00`000000ZZZZ0?ooo`0B0?ooo`X0dLfY4`3oool0
1`2ZZZX0oooo0?ooo`3oool0EEEE0000003oool01@2ZZZX20000000305EEE@2ZZZX0oooo00<0oooo
0P1EEED2000000@0ZZZZ0P3oool200000080oooo00<000000:ZZZP3oool04P3oool:0=7=ZA<0oooo
00@0ZZZZ0?ooo`3oool0oooo0`1EEED00`3oool000000?ooo`0205EEE@0<0:ZZZP1EEED0000005EE
E@000000oooo0:ZZZP000000ZZZZ0000001EEED0ZZZZ0P1EEED00`3oool000000?ooo`0305EEE@80
oooo00<0EEEE0:ZZZP3oool04P3oool<0=7=Z@002`3AcJTD0?ooo`@0000000H0oooo0000002ZZZX0
00000:ZZZP1EEED50?ooo`0305EEE@3oool0EEEE0080EEEE0P3oool02@2ZZZX0oooo05EEE@2ZZZX0
000005EEE@000000oooo05EEE@02000000030:ZZZP3oool0oooo0180oooo2P3AcJTD0?ooo`<00000
00T0ZZZZ000000000000EEEE0000002ZZZX0000005EEE@2ZZZX00P0000020:ZZZP030000002ZZZX0
ZZZZ00@0000000<0EEEE0000002ZZZX010000000103oool000000000002ZZZXD0?ooo`X0dLfY503o
ool01P1EEED0ZZZZ000000000000ZZZZ0?ooo`<0000000@0oooo0:ZZZP2ZZZX0EEEE0P0000001`1E
EED0000005EEE@1EEED0ZZZZ0000001EEED00P2ZZZX0203oool0ZZZZ0000001EEED0oooo0:ZZZP1E
EED000000P2ZZZXD0?ooo`X0dLfY503oool02@1EEED0000005EEE@3oool0ZZZZ05EEE@2ZZZX0oooo
0:ZZZP020?ooo`0305EEE@3oool0ZZZZ00D0oooo0P2ZZZX00`3oool0ZZZZ0?ooo`030?ooo`070000
001EEED0ZZZZ0:ZZZP1EEED000000:ZZZP0D0?ooo`X0dLfY503oool2000000<0EEEE00D0oooo0000
00000000EEEE0?ooo`0305EEE@80oooo00<0ZZZZ0000001EEED00P2ZZZX01@3oool0EEEE05EEE@1E
EED0oooo0080000000L0EEEE0?ooo`1EEED0oooo05EEE@000000ZZZZ01@0oooo303AcJT000/0dLfY
5@3oool20:ZZZP8000000`1EEED00`2ZZZX0oooo0?ooo`020:ZZZP030?ooo`000000oooo0080ZZZZ
00<0oooo0:ZZZP3oool00P2ZZZX20?ooo`80EEEE00@0oooo05EEE@000000EEEE0P2ZZZXE0?ooo`X0
dLfY5@3oool20:ZZZP080000003oool0oooo0:ZZZP1EEED0oooo05EEE@2ZZZX20?ooo`030:ZZZP1E
EED0EEEE0080ZZZZ00P0EEEE0:ZZZP2ZZZX0oooo05EEE@2ZZZX0EEEE0?ooo`80EEEE0P3oool00`1E
EED0ZZZZ0:ZZZP0E0?ooo`X0dLfY5@3oool01@2ZZZX000000?ooo`000000oooo0080000000<0ZZZZ
0?ooo`0000000P1EEED0102ZZZX0oooo0?ooo`2ZZZX20?ooo`80ZZZZ00<0EEEE0?ooo`0000000P3o
ool01`000000ZZZZ0?ooo`000000EEEE0000002ZZZX05@3oool:0=7=ZAD0oooo00D0ZZZZ0000003o
ool0oooo000000020?ooo`050:ZZZP1EEED0oooo0:ZZZP3oool00P1EEED01P3oool0EEEE0?ooo`3o
ool0ZZZZ05EEE@<0oooo0P1EEED00`3oool0ZZZZ000000020?ooo`030000002ZZZX0oooo01@0oooo
2P3AcJTE0?ooo`040:ZZZP000000EEEE0?ooo`D0EEEE0P3oool205EEE@030?ooo`1EEED0EEEE0080
EEEE00<0ZZZZ05EEE@1EEED00P3oool505EEE@040?ooo`00000000000:ZZZQD0oooo303AcJT000/0
dLfY5P3oool20:ZZZP0605EEE@3oool0oooo05EEE@3oool0ZZZZ0`0000020?ooo`@0EEEE00P0ZZZZ
0?ooo`000000oooo0000002ZZZX0oooo05EEE@80oooo00<0EEEE0?ooo`2ZZZX05P3oool:0=7=ZAH0
oooo0P2ZZZX01@1EEED0ZZZZ0?ooo`3oool0EEEE0080oooo00<0ZZZZ05EEE@2ZZZX00P0000001`2Z
ZZX00000000000000000ZZZZ05EEE@2ZZZX00P3oool01`1EEED0oooo0:ZZZP2ZZZX0EEEE0?ooo`2Z
ZZX05P3oool:0=7=ZAH0oooo00L0ZZZZ0000003oool0oooo0:ZZZP1EEED000000080ZZZZ00<00000
05EEE@2ZZZX00`1EEED01@2ZZZX0EEEE0:ZZZP2ZZZX0EEEE00<0ZZZZ00<0oooo05EEE@3oool00P3o
ool00`1EEED0ZZZZ0?ooo`0E0?ooo`X0dLfY5P3oool0102ZZZX0000005EEE@2ZZZX200000080EEEE
00<0ZZZZ05EEE@0000000P1EEED2000000040:ZZZP000000oooo05EEE@80000000H0ZZZZ05EEE@3o
ool000000?ooo`2ZZZX205EEE@030:ZZZP3oool0oooo01@0oooo2P3AcJTF0?ooo`080:ZZZP3oool0
oooo0?ooo`1EEED0oooo05EEE@3oool205EEE@050?ooo`1EEED0EEEE0:ZZZP3oool00P2ZZZX205EE
E@070?ooo`000000EEEE0?ooo`1EEED0oooo05EEE@020?ooo`0305EEE@2ZZZX0oooo01D0oooo303A
cJT000/0dLfY5`3oool01P2ZZZX0EEEE05EEE@3oool0EEEE0?ooo`80EEEE00/0ZZZZ0000003oool0
oooo0000003oool0ZZZZ0000001EEED0oooo0000000505EEE@030?ooo`1EEED0EEEE01P0oooo2P3A
cJTG0?ooo`060:ZZZP1EEED0oooo0000002ZZZX0oooo0P0000030:ZZZP060000002ZZZX0EEEE05EE
E@2ZZZX000000P2ZZZX400000080ZZZZ00<0oooo05EEE@3oool05`3oool:0=7=ZAL0oooo00D0ZZZZ
0000003oool0ZZZZ0?ooo`0205EEE@80000000<0ZZZZ0000002ZZZX01@1EEED01P000000ZZZZ0000
00000000EEEE0:ZZZP<0oooo00<000000?ooo`3oool05P3oool:0=7=ZAL0oooo00H0ZZZZ0000003o
ool0oooo0000002ZZZX205EEE@80ZZZZ00@000000:ZZZP1EEED0oooo0P1EEED2000000040:ZZZP1E
EED0EEEE05EEE@8000000P3oool00`000000oooo0?ooo`0F0?ooo`X0dLfY5`3oool0102ZZZX0EEEE
0?ooo`3oool305EEE@80oooo00@0ZZZZ05EEE@3oool0oooo0P2ZZZX0103oool0000005EEE@2ZZZX2
0?ooo`<0EEEE0P3oool00`1EEED0oooo0?ooo`0F0?ooo``0dLfY000;0=7=ZAP0oooo0P2ZZZX01`3o
ool0ZZZZ0?ooo`000000EEEE0?ooo`2ZZZX00P1EEED00`2ZZZX0oooo0?ooo`020:ZZZP0505EEE@2Z
ZZX0oooo05EEE@0000000P2ZZZX00`000000ZZZZ0:ZZZP0H0?ooo`X0dLfY603oool20:ZZZP060000
003oool0oooo0:ZZZP1EEED0ZZZZ0P0000000`2ZZZX0000000000002000000030:ZZZP0000000000
0080EEEE00@0ZZZZ0000003oool0EEEE0P2ZZZXH0?ooo`X0dLfY603oool01@2ZZZX0EEEE00000000
0000oooo00@0ZZZZ00@0EEEE0?ooo`2ZZZX0oooo0P2ZZZX00`3oool0EEEE0:ZZZP040:ZZZP040000
001EEED0EEEE0:ZZZQP0oooo2P3AcJTH0?ooo`040:ZZZP1EEED0EEEE0:ZZZP80EEEE00@0ZZZZ05EE
E@3oool0EEEE0P3oool03P000000EEEE0?ooo`2ZZZX0EEEE0?ooo`1EEED0ZZZZ05EEE@3oool0ZZZZ
0000001EEED0ZZZZ603oool:0=7=ZAP0oooo00T0ZZZZ0000001EEED0oooo05EEE@3oool0EEEE0000
001EEED00P2ZZZX010000000oooo0000000000020:ZZZP0605EEE@000000EEEE0?ooo`1EEED0oooo
0P0000000`2ZZZX0oooo0?ooo`0F0?ooo``0dLfY000;0=7=ZAT0oooo00T0ZZZZ05EEE@1EEED0EEEE
0?ooo`2ZZZX0EEEE0:ZZZP0000000P1EEED01@3oool0EEEE05EEE@2ZZZX0000000<0ZZZZ00D0oooo
05EEE@1EEED0oooo0:ZZZP0I0?ooo`X0dLfY6@3oool20:ZZZP0305EEE@3oool00000008000000P2Z
ZZX00`000000ZZZZ0:ZZZP020:ZZZP030000002ZZZX0ZZZZ00<0000000@0ZZZZ05EEE@3oool0ZZZZ
6@3oool:0=7=ZAT0oooo00/0ZZZZ0?ooo`1EEED0ZZZZ0000003oool000000?ooo`2ZZZX000000:ZZ
ZP020?ooo`<0ZZZZ00H0oooo0:ZZZP3oool000000:ZZZP1EEED20:ZZZQT0oooo2P3AcJTI0?ooo`80
ZZZZ0P0000000`1EEED0oooo0?ooo`020?ooo`0605EEE@000000ZZZZ0:ZZZP000000EEEE0P3oool0
1@1EEED0oooo05EEE@3oool000000080ZZZZ6@3oool:0=7=ZAT0oooo00<0ZZZZ0?ooo`3oool00P1E
EED30:ZZZP050?ooo`2ZZZX0oooo0:ZZZP1EEED00`3oool30:ZZZP0505EEE@3oool0oooo05EEE@2Z
ZZX06@3oool<0=7=Z@002`3AcJTJ0?ooo`060:ZZZP1EEED000000000003oool0EEEE0P2ZZZX00`1E
EED0oooo0?ooo`020?ooo`<0ZZZZ0P3oool20000000305EEE@3oool0oooo01T0oooo2P3AcJTJ0?oo
o`030:ZZZP1EEED0ZZZZ00<0000000<0ZZZZ0?ooo`0000001@0000000`3oool0ZZZZ000000020000
00030?ooo`1EEED0oooo01X0oooo2P3AcJTJ0?ooo`0E0:ZZZP1EEED000000?ooo`2ZZZX0EEEE0000
003oool0EEEE0000001EEED0ZZZZ0000001EEED0oooo0000003oool0ZZZZ0?ooo`2ZZZX0EEEE01/0
oooo2P3AcJTJ0?ooo`040:ZZZP1EEED0EEEE0:ZZZP80oooo00<0ZZZZ05EEE@3oool00P3oool0102Z
ZZX0oooo0:ZZZP1EEED20:ZZZP040?ooo`2ZZZX0000005EEEA/0oooo2P3AcJTJ0?ooo`060:ZZZP1E
EED0oooo0?ooo`1EEED0oooo0P1EEED00`2ZZZX0EEEE0?ooo`0205EEE@030?ooo`1EEED0EEEE0080
EEEE0P3oool00`1EEED0oooo0?ooo`0I0?ooo``0dLfY000;0=7=ZA/0oooo1@2ZZZX01@1EEED00000
0?ooo`1EEED0oooo0080EEEE0P00000205EEE@@0ZZZZ6`3oool:0=7=ZA/0oooo00L0ZZZZ05EEE@00
0000oooo0000003oool0000000H0ZZZZ00D000000?ooo`3oool0oooo000000020:ZZZQ/0oooo2P3A
cJTK0?ooo`080:ZZZP1EEED0oooo0000002ZZZX0oooo05EEE@2ZZZX205EEE@080?ooo`1EEED00000
05EEE@3oool0ZZZZ0000003oool20:ZZZQ/0oooo2P3AcJTK0?ooo`80ZZZZ00@000000?ooo`2ZZZX0
EEEE0P2ZZZX20000000805EEE@000000EEEE0:ZZZP1EEED000000?ooo`0000020:ZZZQ/0oooo2P3A
cJTK0?ooo`050:ZZZP000000EEEE0?ooo`1EEED00P2ZZZX205EEE@80oooo0P1EEED20:ZZZP0505EE
E@3oool0EEEE0000002ZZZX06`3oool<0=7=Z@002`3AcJTL0?ooo`030:ZZZP00000000000080EEEE
00@000000:ZZZP1EEED0oooo0P1EEED0102ZZZX0000005EEE@1EEED2000001d0oooo2P3AcJTL0?oo
o`040:ZZZP00000000000?ooo`d000007@3oool:0=7=ZA`0oooo00@0ZZZZ05EEE@000000ZZZZ0P1E
EED20:ZZZP030?ooo`2ZZZX0ZZZZ00<0EEEE00<0oooo0000001EEED07@3oool:0=7=ZA`0oooo00T0
ZZZZ05EEE@000000ZZZZ0?ooo`000000ZZZZ0000001EEED00P0000001P2ZZZX000000?ooo`1EEED0
000005EEEAd0oooo2P3AcJTL0?ooo`040:ZZZP00000000000?ooo`80EEEE0P3oool205EEE@80oooo
0`1EEED2000001d0oooo303AcJT000/0dLfY7@3oool0102ZZZX0EEEE0?ooo`1EEED30?ooo`090000
001EEED0oooo0:ZZZP3oool0EEEE0?ooo`1EEED0ZZZZ01d0oooo2P3AcJTM0?ooo`030:ZZZP1EEED0
00000080ZZZZ00<000000:ZZZP2ZZZX01@2ZZZX00`3oool0EEEE0:ZZZP0M0?ooo`X0dLfY7@3oool2
0:ZZZP050000003oool000000?ooo`2ZZZX00P3oool0102ZZZX000000000003oool30:ZZZQd0oooo
2P3AcJTM0?ooo`80ZZZZ00L000000?ooo`000000ZZZZ0?ooo`2ZZZX0EEEE0080oooo00<000000?oo
o`2ZZZX00P2ZZZXM0?ooo`X0dLfY7@3oool0202ZZZX0EEEE0?ooo`3oool0EEEE0:ZZZP1EEED0oooo
101EEED20?ooo`0305EEE@2ZZZX0oooo01`0oooo303AcJT000/0dLfY7P3oool01P2ZZZX0EEEE0:ZZ
ZP1EEED000000?ooo`80ZZZZ00<0oooo0:ZZZP1EEED00`2ZZZXN0?ooo`X0dLfY7P3oool0102ZZZX0
EEEE05EEE@00000505EEE@030:ZZZP000000EEEE0080ZZZZ7P3oool:0=7=ZAh0oooo00<0ZZZZ0?oo
o`3oool00P3oool01@1EEED0ZZZZ05EEE@1EEED000000080oooo00<000000:ZZZP3oool07@3oool:
0=7=ZAh0oooo00D0ZZZZ0?ooo`3oool0oooo0000000205EEE@030:ZZZP1EEED000000080oooo00<0
00000:ZZZP3oool07@3oool:0=7=ZAh0oooo00@0ZZZZ0000001EEED0oooo0P1EEED20?ooo`80EEEE
00@0oooo05EEE@000000ZZZZ7P3oool<0=7=Z@002`3AcJTO0?ooo`080:ZZZP000000EEEE05EEE@00
0000EEEE0?ooo`00000205EEE@030000003oool0oooo01h0oooo2P3AcJTO0?ooo`050:ZZZP000000
00000:ZZZP0000000P2ZZZX010000000ZZZZ00000000000P0?ooo`X0dLfY7`3oool20:ZZZP030?oo
o`000000EEEE0080oooo0P1EEED00`3oool0ZZZZ0?ooo`0O0?ooo`X0dLfY7`3oool30:ZZZP040?oo
o`000000ZZZZ05EEE@8000000P2ZZZXP0?ooo`X0dLfY7`3oool00`2ZZZX00000000000050?ooo`03
05EEE@00000000000200oooo303AcJT000/0dLfY803oool00`2ZZZX0EEEE0:ZZZP0205EEE@050?oo
o`1EEED0EEEE05EEE@2ZZZX0803oool:0=7=ZB00oooo00D0ZZZZ05EEE@1EEED000000:ZZZP020000
0080EEEE00<0ZZZZ0?ooo`3oool07P3oool:0=7=ZB00oooo00<0ZZZZ0000001EEED0103oool00`2Z
ZZX000000:ZZZP0P0?ooo`X0dLfY803oool01P2ZZZX000000?ooo`3oool0EEEE00000080oooo00<0
00000:ZZZP3oool07`3oool:0=7=ZB00oooo00<0ZZZZ05EEE@3oool01@3oool00`1EEED0ZZZZ0?oo
o`0O0?ooo``0dLfY000;0=7=ZB40oooo00H0ZZZZ0000001EEED0EEEE0?ooo`1EEED20:ZZZR40oooo
2P3AcJTQ0?ooo`030:ZZZP3oool0ZZZZ0080EEEE0`2ZZZXQ0?ooo`X0dLfY8@3oool20:ZZZP060000
002ZZZX000000000001EEED0ZZZZ8@3oool:0=7=ZB40oooo00D0ZZZZ0000001EEED0oooo0:ZZZP02
05EEE@030:ZZZP3oool0oooo01l0oooo2P3AcJTQ0?ooo`040:ZZZP000000EEEE0:ZZZP80EEEE00<0
00000:ZZZP3oool0803oool<0=7=Z@002`3AcJTR0?ooo`050:ZZZP000000oooo0:ZZZP0000008`3o
ool:0=7=ZB80oooo00D0ZZZZ0000002ZZZX0ZZZZ0000000S0?ooo`X0dLfY8P3oool01@2ZZZX00000
0?ooo`1EEED0000002<0oooo2P3AcJTR0?ooo`050:ZZZP000000oooo0?ooo`0000008`3oool:0=7=
ZB80oooo00D0ZZZZ0000003oool0ZZZZ0000000S0?ooo``0dLfY000;0=7=ZB<0oooo00@0ZZZZ0000
001EEED0ZZZZ8`3oool:0=7=ZB<0oooo00@0ZZZZ0000001EEED0ZZZZ8`3oool:0=7=ZB<0oooo00@0
ZZZZ0000001EEED0ZZZZ8`3oool:0=7=ZB<0oooo00@0ZZZZ0000001EEED0ZZZZ8`3oool:0=7=ZB<0
oooo00@0ZZZZ0000001EEED0ZZZZ8`3oool<0=7=Z@002`3AcJTT0?ooo`030:ZZZP3oool0oooo02<0
oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0
oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0
oooo303AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0
dLfY/P3AcJT00?l0dLfY/P3AcJT000/0dLfY00@0oooo05EEE@2ZZZX0ZZZZ0P1EEED010000000oooo
05EEE@3oool20:ZZZP0605EEE@2ZZZX0EEEE05EEE@2ZZZX000000P3oool605EEE@070:ZZZP1EEED0
ZZZZ0?ooo`1EEED0ZZZZ05EEE@020:ZZZP0605EEE@000000oooo05EEE@3oool0ZZZZ0`1EEED0103o
ool0ZZZZ05EEE@00000505EEE@050:ZZZP3oool0oooo05EEE@2ZZZX00P1EEED0102ZZZX0EEEE0:ZZ
ZP2ZZZX205EEE@040?ooo`1EEED0EEEE000000<0ZZZZ00<0oooo0=7=Z@3AcJT0203AcJT0103oool0
EEEE0?ooo`2ZZZX205EEE@060000001EEED0EEEE0:ZZZP3oool000000P2ZZZX01@3oool0ZZZZ0?oo
o`1EEED0ZZZZ0080EEEE0P2ZZZX305EEE@030:ZZZP1EEED0EEEE0080oooo00D0EEEE0:ZZZP1EEED0
00000:ZZZP0205EEE@80ZZZZ00<0EEEE0:ZZZP3oool00P3oool00`2ZZZX0EEEE0000000205EEE@@0
ZZZZ00<0EEEE0:ZZZP0000000`3oool20:ZZZP030000003oool0EEEE00@0EEEE00D0oooo0:ZZZP3o
ool0ZZZZ0?ooo`0:0=7=Z@090?ooo`2ZZZX0ZZZZ0?ooo`1EEED000000:ZZZP3oool0EEEE00800000
1@3oool20:ZZZP80oooo00@0ZZZZ0?ooo`000000ZZZZ103oool2000000040?ooo`2ZZZX0oooo0000
0080oooo00D0ZZZZ0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0oooo0P000000
0`3oool0ZZZZ0?ooo`020?ooo`80ZZZZ103oool00`000000oooo05EEE@020?ooo`030000002ZZZX0
oooo0080ZZZZ00<0oooo0=7=Z@3AcJT0203AcJT0103oool0ZZZZ0:ZZZP3oool20:ZZZP80000000X0
ZZZZ0?ooo`2ZZZX0ZZZZ0000002ZZZX0EEEE0:ZZZP000000ZZZZ0P3oool20000000305EEE@3oool0
oooo0080EEEE00H0oooo0:ZZZP1EEED0000005EEE@2ZZZX205EEE@80ZZZZ00X0EEEE0:ZZZP2ZZZX0
EEEE0:ZZZP1EEED0000005EEE@000000oooo0P1EEED0103oool0EEEE05EEE@0000040?ooo`030000
001EEED0EEEE00H0ZZZZ00D000000?ooo`2ZZZX0EEEE0?ooo`020:ZZZP030?ooo`3AcJT0dLfY00P0
dLfY00@0oooo0:ZZZP2ZZZX0EEEE0P3oool00`1EEED0oooo05EEE@030:ZZZP80EEEE00@000000?oo
o`3oool0ZZZZ0P3oool01@1EEED0oooo05EEE@1EEED0oooo0080EEEE0`3oool00`1EEED0ZZZZ0?oo
o`020:ZZZP030?ooo`1EEED0EEEE0080oooo00@0ZZZZ0?ooo`1EEED0EEEE103oool0101EEED0oooo
0:ZZZP1EEED40?ooo`0605EEE@3oool0ZZZZ0000001EEED0oooo0P2ZZZX01`3oool0EEEE0?ooo`1E
EED0oooo0:ZZZP1EEED00P2ZZZX00`3oool0dLfY0=7=Z@0:0=7=Z@002`3AcJT01P3oool0ZZZZ05EE
E@000000ZZZZ0?ooo`80EEEE00@0000005EEE@1EEED0EEEE0P3oool20:ZZZP080?ooo`000000EEEE
05EEE@2ZZZX0oooo0:ZZZP3oool205EEE@80000000D0ZZZZ00000000000000000:ZZZP020?ooo`04
0:ZZZP00000000000:ZZZP80oooo00L0ZZZZ05EEE@000000000005EEE@000000oooo0080EEEE0P2Z
ZZX0103oool0000005EEE@1EEED20?ooo`0305EEE@2ZZZX0oooo00<0EEEE0P0000001P1EEED0ZZZZ
0?ooo`2ZZZX0000005EEE@80oooo2P3AcJT02@3oool0ZZZZ05EEE@000000ZZZZ0?ooo`1EEED0ZZZZ
0?ooo`0305EEE@070000001EEED0EEEE05EEE@000000oooo0:ZZZP020?ooo`030:ZZZP3oool0ZZZZ
0080ZZZZ00<0000005EEE@3oool00`3oool02P000000EEEE0?ooo`2ZZZX0EEEE0?ooo`2ZZZX00000
05EEE@0000030?ooo`030000001EEED0oooo0080ZZZZ0P3oool20:ZZZP040?ooo`2ZZZX0ZZZZ0000
00<0EEEE00D0oooo05EEE@1EEED0ZZZZ0?ooo`020:ZZZP040?ooo`1EEED0000005EEE@80oooo2P3A
cJT0103oool0ZZZZ0?ooo`3oool20:ZZZP080000001EEED0oooo0?ooo`000000oooo05EEE@3oool2
05EEE@0:0000003oool0oooo0?ooo`2ZZZX0oooo0000003oool0ZZZZ00000080ZZZZ0P3oool01000
0000oooo0?ooo`3oool20:ZZZP80EEEE00T0ZZZZ0000003oool0oooo0:ZZZP000000oooo0000002Z
ZZX00P0000000`2ZZZX0oooo000000040?ooo`080:ZZZP000000EEEE05EEE@3oool0EEEE0?ooo`00
00020?ooo`0305EEE@2ZZZX0ZZZZ00D0oooo2P3AcJT0303oool0ZZZZ0?ooo`3oool0EEEE0000002Z
ZZX0oooo05EEE@3oool0000005EEE@80oooo00X0ZZZZ0?ooo`3oool0000005EEE@2ZZZX0EEEE0?oo
o`2ZZZX0oooo100000001@3oool0ZZZZ0:ZZZP3oool0ZZZZ0080oooo0P2ZZZX0103oool0ZZZZ0:ZZ
ZP3oool40:ZZZP030?ooo`0000000000008000000P2ZZZX01P3oool0ZZZZ0:ZZZP1EEED000000?oo
o`80ZZZZ00<0oooo0000001EEED00P000000101EEED0oooo05EEE@0000050?ooo`X0dLfY00D0oooo
0:ZZZP3oool0oooo0000000305EEE@030000002ZZZX0ZZZZ0080000000L0EEEE0:ZZZP3oool0oooo
05EEE@000000EEEE00<0000000/0EEEE0?ooo`1EEED0EEEE0?ooo`1EEED0oooo05EEE@3oool0ZZZZ
000000020?ooo`0:05EEE@3oool0oooo0:ZZZP000000ZZZZ0?ooo`1EEED0oooo05EEE@80oooo00<0
EEEE0?ooo`3oool00P00000205EEE@090000003oool0oooo0?ooo`2ZZZX0EEEE0:ZZZP000000ZZZZ
00800000101EEED40?ooo``0dLfY000;0=7=Z@<0oooo0`2ZZZX205EEE@80000000<0ZZZZ05EEE@00
00000P1EEED20:ZZZP040000001EEED0EEEE05EEE@80ZZZZ00d0oooo05EEE@000000oooo0000001E
EED0ZZZZ05EEE@2ZZZX0oooo05EEE@2ZZZX0oooo0080EEEE00L0oooo05EEE@1EEED0oooo0000001E
EED0ZZZZ0080000000<0oooo0000001EEED00`2ZZZX305EEE@030?ooo`2ZZZX0000000@0EEEE00<0
ZZZZ0000000000000P1EEED00`2ZZZX0EEEE0:ZZZP030?ooo`X0dLfY0`3oool01`2ZZZX0EEEE05EE
E@1EEED0ZZZZ0?ooo`1EEED00P2ZZZX505EEE@050?ooo`2ZZZX0ZZZZ05EEE@3oool00`2ZZZX01P1E
EED0ZZZZ05EEE@3oool0ZZZZ05EEE@80oooo00T0ZZZZ0?ooo`000000EEEE0:ZZZP000000oooo0:ZZ
ZP3oool00P1EEED01@2ZZZX0000005EEE@3oool0EEEE00<0ZZZZ00<0oooo05EEE@2ZZZX00P2ZZZX0
101EEED0000005EEE@1EEED40:ZZZP030?ooo`2ZZZX0EEEE0080EEEE00@0ZZZZ0?ooo`3oool0oooo
2P3AcJT30?ooo`040:ZZZP000000EEEE05EEE@80oooo00<0EEEE0:ZZZP1EEED00`3oool0101EEED0
00000?ooo`3oool30:ZZZP80oooo0P00000205EEE@80oooo00@0EEEE0:ZZZP3oool0EEEE0P000000
2P3oool0ZZZZ0000003oool0EEEE0?ooo`000000EEEE0?ooo`00000205EEE@8000000P3oool0102Z
ZZX0oooo0:ZZZP3oool20000000305EEE@3oool0oooo0080EEEE00@0ZZZZ0?ooo`3oool0oooo0`1E
EED0102ZZZX0oooo0?ooo`3oool:0=7=Z@<0oooo00D0ZZZZ0000001EEED000000?ooo`0200000004
05EEE@000000ZZZZ0:ZZZP80oooo00D0ZZZZ0?ooo`2ZZZX0oooo0:ZZZP03000000050:ZZZP000000
ZZZZ0000002ZZZX00`3oool02`2ZZZX0oooo0?ooo`2ZZZX0EEEE0?ooo`2ZZZX0EEEE0?ooo`2ZZZX0
EEEE0080oooo00D0ZZZZ00000000000000000:ZZZP04000000030?ooo`2ZZZX0oooo0080ZZZZ00D0
oooo0:ZZZP3oool0000005EEE@02000000050?ooo`000000EEEE05EEE@2ZZZX00`3oool:0=7=Z@<0
oooo0P2ZZZX30?ooo`80EEEE00P0ZZZZ0?ooo`2ZZZX0ZZZZ0?ooo`1EEED0ZZZZ05EEE@<000000100
EEEE0?ooo`3oool0oooo05EEE@3oool0EEEE0?ooo`1EEED0oooo05EEE@3oool0EEEE0000003oool0
EEEE0P3oool01`000000EEEE0?ooo`1EEED0oooo05EEE@3oool00`1EEED01@3oool0EEEE0?ooo`1E
EED0ZZZZ0080000000l0oooo0:ZZZP1EEED0oooo0:ZZZP000000oooo0:ZZZP000000EEEE0?ooo`00
0000oooo05EEE@2ZZZX00`3oool<0=7=Z@002`3AcJT40?ooo`0;05EEE@000000oooo0:ZZZP1EEED0
ZZZZ05EEE@000000EEEE0?ooo`2ZZZX00P1EEED00`000000oooo0?ooo`020?ooo`060:ZZZP3oool0
oooo0000001EEED000000`1EEED20000000:0:ZZZP00000000000?ooo`2ZZZX000000?ooo`2ZZZX0
00000?ooo`80EEEE00@0oooo0000001EEED000000P3oool00`2ZZZX0oooo05EEE@020?ooo`<0EEEE
00@0ZZZZ0?ooo`00000000000`1EEED20:ZZZP030000002ZZZX0oooo00<0oooo2P3AcJT40?ooo`03
05EEE@3oool0ZZZZ0080oooo0P2ZZZX00`000000ZZZZ0?ooo`0205EEE@030:ZZZP3oool0oooo0080
ZZZZ00@0EEEE0000001EEED000000P3oool04P2ZZZX0EEEE0000001EEED000000?ooo`000000ZZZZ
0000001EEED0oooo0000001EEED000000?ooo`000000EEEE00000080ZZZZ0P3oool01P000000EEEE
0000001EEED0oooo0:ZZZP80oooo00L0ZZZZ0?ooo`1EEED0oooo0:ZZZP000000ZZZZ00<0oooo00<0
ZZZZ0?ooo`2ZZZX0103oool:0=7=Z@@0oooo102ZZZX01P1EEED0oooo0?ooo`2ZZZX0oooo000000@0
ZZZZ0P1EEED02`2ZZZX0000005EEE@3oool000000?ooo`1EEED0oooo0000001EEED0oooo00<00000
00H0oooo0:ZZZP000000EEEE0:ZZZP1EEED200000080oooo00<0EEEE0?ooo`3oool00P3oool01000
0000EEEE05EEE@00000305EEE@80ZZZZ00<0oooo0:ZZZP0000000P2ZZZX01@3oool0EEEE05EEE@2Z
ZZX0oooo0080ZZZZ103oool:0=7=Z@@0oooo0P2ZZZX00`1EEED0ZZZZ0:ZZZP020:ZZZP070?ooo`1E
EED0ZZZZ05EEE@3oool0ZZZZ000000020:ZZZP060?ooo`000000oooo0000003oool0EEEE0P3oool0
1@1EEED000000:ZZZP2ZZZX000000080ZZZZ00T000000?ooo`2ZZZX000000?ooo`2ZZZX000000?oo
o`2ZZZX00P0000000`3oool0ZZZZ05EEE@030?ooo`0;0000001EEED0ZZZZ0:ZZZP3oool0ZZZZ0000
001EEED0ZZZZ05EEE@3oool0102ZZZX00`3oool0ZZZZ0:ZZZP040?ooo`X0dLfY103oool00`2ZZZX0
00000?ooo`020?ooo`070:ZZZP000000ZZZZ05EEE@000000oooo0:ZZZP020?ooo`0305EEE@2ZZZX0
oooo008000000P1EEED01@3oool0EEEE05EEE@000000EEEE0080000000@0ZZZZ0?ooo`1EEED0oooo
0P1EEED01P3oool0ZZZZ0?ooo`2ZZZX0EEEE000000<0EEEE0P3oool01`1EEED00000000000000000
oooo0:ZZZP1EEED00P3oool01`2ZZZX0oooo0000003oool0ZZZZ0000001EEED00`3oool00`000000
ZZZZ0?ooo`030?ooo``0dLfY000;0=7=Z@D0oooo0`2ZZZX010000000EEEE05EEE@0000030?ooo`07
0:ZZZP000000ZZZZ0:ZZZP3oool000000?ooo`0400000080EEEE00<0ZZZZ05EEE@2ZZZX00`1EEED0
1P2ZZZX0EEEE000000000000EEEE0:ZZZP<0EEEE00<0ZZZZ05EEE@1EEED00P1EEED20000000605EE
E@000000oooo05EEE@3oool0ZZZZ0P0000040?ooo`070000001EEED0EEEE0000002ZZZX0EEEE0:ZZ
ZP050?ooo`X0dLfY1@3oool20:ZZZP050?ooo`2ZZZX0oooo0:ZZZP0000000`1EEED00`3oool0EEEE
0?ooo`020:ZZZP030000001EEED0EEEE008000000P2ZZZX00`3oool0EEEE05EEE@020000000605EE
E@00000000000000003oool0ZZZZ0`0000001@1EEED000000000001EEED000000080oooo00<0ZZZZ
0000000000000P1EEED0103oool0ZZZZ0:ZZZP2ZZZX505EEE@070000002ZZZX0ZZZZ0:ZZZP3oool0
EEEE0:ZZZP050?ooo`X0dLfY1@3oool20:ZZZP80oooo00/0ZZZZ0?ooo`2ZZZX0oooo0:ZZZP3oool0
ZZZZ0000001EEED000000:ZZZP0205EEE@@0oooo0P0000040?ooo`80000000<0oooo05EEE@1EEED0
0`1EEED20000000405EEE@3oool0oooo0?ooo`800000103oool205EEE@030:ZZZP000000EEEE0080
000000@0oooo0:ZZZP2ZZZX0ZZZZ103oool00`000000ZZZZ0?ooo`040?ooo`X0dLfY1@3oool01P2Z
ZZX0oooo0:ZZZP2ZZZX0oooo0:ZZZP@0EEEE00<0oooo0:ZZZP1EEED01`3oool02P000000oooo0:ZZ
ZP000000EEEE0?ooo`1EEED0oooo0000001EEED4000000030:ZZZP000000oooo0080oooo00D0EEEE
0:ZZZP2ZZZX0oooo000000040?ooo`060000003oool0oooo05EEE@2ZZZX0oooo0P1EEED00`000000
EEEE0:ZZZP030:ZZZP030000002ZZZX0oooo00@0oooo2P3AcJT50?ooo`030:ZZZP1EEED0ZZZZ00<0
ZZZZ0P0000001@2ZZZX0EEEE0:ZZZP3oool000000080oooo00L0EEEE0?ooo`1EEED0ZZZZ0000003o
ool000000080ZZZZ00D000000:ZZZP00000000000?ooo`0305EEE@050?ooo`1EEED0oooo0?ooo`00
00000P2ZZZX01@000000oooo0:ZZZP000000oooo0080000000<0EEEE0?ooo`3oool0103oool205EE
E@050:ZZZP00000000000:ZZZP3oool00P2ZZZX00`000000ZZZZ0?ooo`040?ooo``0dLfY000;0=7=
Z@H0oooo00L0EEEE0000002ZZZX0oooo0:ZZZP1EEED0000000<0EEEE00@0ZZZZ05EEE@1EEED0EEEE
0P0000020:ZZZP040000002ZZZX0ZZZZ0:ZZZP80000000L0EEEE0:ZZZP2ZZZX0ZZZZ0?ooo`2ZZZX0
00000080ZZZZ00L0oooo0:ZZZP2ZZZX0ZZZZ05EEE@000000oooo00<0ZZZZ00<000000:ZZZP2ZZZX0
0P00000305EEE@030:ZZZP000000EEEE00<0EEEE0`2ZZZX00`000000ZZZZ0?ooo`050?ooo`X0dLfY
1P3oool405EEE@080000003oool0ZZZZ0:ZZZP3oool0EEEE0000002ZZZX205EEE@030:ZZZP3oool0
ZZZZ0080ZZZZ0P1EEED00`000000oooo0:ZZZP060:ZZZP80EEEE00D0ZZZZ05EEE@2ZZZX0ZZZZ05EE
E@030:ZZZP080000001EEED0EEEE0:ZZZP1EEED0ZZZZ0?ooo`00000205EEE@80000000L0ZZZZ0?oo
o`2ZZZX0ZZZZ0?ooo`000000ZZZZ0080EEEE00<0ZZZZ0?ooo`3oool0103oool:0=7=Z@H0oooo00X0
EEEE0000001EEED000000:ZZZP3oool0ZZZZ0000001EEED0ZZZZ0`3oool02`000000EEEE00000000
0000ZZZZ0000003oool0ZZZZ0?ooo`1EEED000000080oooo00D000000?ooo`1EEED0000005EEE@02
00000080oooo00P0000005EEE@3oool0000005EEE@3oool0EEEE0?ooo`H0000000H0oooo05EEE@3o
ool0oooo05EEE@0000020?ooo`050:ZZZP1EEED0EEEE0000002ZZZX01P3oool:0=7=Z@H0oooo00H0
EEEE0000001EEED000000?ooo`1EEED20:ZZZP040?ooo`000000EEEE0?ooo`80EEEE00D0ZZZZ0000
003oool000000?ooo`0300000080ZZZZ00@0oooo000000000000oooo1@2ZZZX20?ooo`80000000/0
oooo0:ZZZP2ZZZX000000?ooo`000000oooo0000003oool000000?ooo`0205EEE@0<0?ooo`1EEED0
ZZZZ0?ooo`2ZZZX0oooo05EEE@3oool0000005EEE@000000ZZZZ1P3oool:0=7=Z@H0oooo00L0EEEE
0000003oool0EEEE0:ZZZP1EEED0ZZZZ00<0EEEE00@0ZZZZ05EEE@3oool0EEEE0`3oool0102ZZZX0
EEEE0?ooo`2ZZZX20?ooo`050:ZZZP1EEED0ZZZZ0?ooo`1EEED00P3oool205EEE@040?ooo`1EEED0
EEEE0?ooo`80EEEE00D0ZZZZ0?ooo`3oool0EEEE0?ooo`0205EEE@80oooo0P1EEED00`3oool0ZZZZ
0:ZZZP0305EEE@070?ooo`1EEED0ZZZZ05EEE@3oool000000:ZZZP060?ooo``0dLfY000;0=7=Z@H0
oooo00L0ZZZZ05EEE@1EEED0EEEE0000002ZZZX0EEEE0080000000T0oooo0:ZZZP1EEED0oooo0:ZZ
ZP1EEED0ZZZZ05EEE@2ZZZX0101EEED00`000000oooo05EEE@0305EEE@040000001EEED000000:ZZ
ZPH0EEEE00<0oooo05EEE@1EEED00`1EEED01@000000EEEE0:ZZZP1EEED0ZZZZ0080oooo00L0ZZZZ
05EEE@00000000000?ooo`2ZZZX0000000<0EEEE1`3oool:0=7=Z@H0oooo00@0ZZZZ05EEE@3oool0
oooo0P1EEED01@000000EEEE05EEE@2ZZZX0oooo00<0ZZZZ0`1EEED20?ooo`040:ZZZP3oool0ZZZZ
0:ZZZP80EEEE00<000000:ZZZP0000000P1EEED00`3oool0ZZZZ05EEE@020000000:0:ZZZP000000
EEEE05EEE@000000ZZZZ05EEE@2ZZZX0oooo0:ZZZP80EEEE0`2ZZZX00`000000oooo05EEE@0505EE
E@030:ZZZP3oool0EEEE00L0oooo2P3AcJT60?ooo`@0ZZZZ00D0EEEE0000002ZZZX0oooo05EEE@02
0000000:05EEE@3oool0EEEE0?ooo`2ZZZX0EEEE0:ZZZP3oool0EEEE000000<0oooo0P0000030?oo
o`0405EEE@3oool0ZZZZ05EEE@<0oooo00L0EEEE0000003oool0EEEE0?ooo`000000EEEE0080oooo
00D0EEEE0:ZZZP2ZZZX0EEEE0?ooo`02000000070?ooo`1EEED0oooo0?ooo`000000EEEE0?ooo`02
0:ZZZPL0oooo2P3AcJT60?ooo`<0ZZZZ00H0EEEE0:ZZZP2ZZZX0000005EEE@0000020:ZZZP<00000
00<0oooo05EEE@2ZZZX00P2ZZZX205EEE@030:ZZZP3oool0ZZZZ00<0oooo0100000005EEE@1EEED0
EEEE0000001EEED0ZZZZ0000003oool000000?ooo`2ZZZX0oooo0:ZZZP3oool0EEEE0`2ZZZX01@1E
EED00000000000000000oooo0080ZZZZ00<0000005EEE@3oool00P2ZZZX00`3oool0ZZZZ0:ZZZP07
0?ooo`X0dLfY1P3oool30:ZZZP0;0000002ZZZX0ZZZZ0000001EEED0000005EEE@000000EEEE0?oo
o`1EEED00`3oool00`1EEED000000000000405EEE@040:ZZZP1EEED0oooo05EEE@80oooo00`0EEEE
0?ooo`3oool0oooo05EEE@3oool000000:ZZZP1EEED0oooo05EEE@2ZZZX2000000@0oooo00<0EEEE
0?ooo`3oool00`0000001@1EEED0oooo0:ZZZP2ZZZX0EEEE0080ZZZZ1`3oool<0=7=Z@002`3AcJT8
0?ooo`040:ZZZP000000ZZZZ0?ooo`80EEEE00P0ZZZZ05EEE@3oool0EEEE0:ZZZP1EEED000000:ZZ
ZP<000001@1EEED20:ZZZP80EEEE00H0000005EEE@2ZZZX0oooo05EEE@3oool305EEE@030:ZZZP1E
EED0EEEE00<0EEEE0140000005EEE@000000ZZZZ0000001EEED0ZZZZ05EEE@3oool0EEEE0:ZZZP1E
EED0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP080?ooo`X0dLfY203oool20:ZZZP80oooo00<0ZZZZ05EEE@1E
EED00`0000000`2ZZZX0oooo05EEE@0205EEE@050?ooo`2ZZZX0ZZZZ0000002ZZZX00`3oool01000
0000oooo0?ooo`00000405EEE@040000003oool0oooo05EEE@<0oooo00<0ZZZZ0?ooo`2ZZZX00P2Z
ZZX205EEE@050:ZZZP3oool0ZZZZ05EEE@0000000`1EEED30?ooo`0305EEE@2ZZZX0oooo00L0oooo
2P3AcJT80?ooo`80ZZZZ0`3oool00`1EEED0oooo000000030?ooo`0405EEE@3oool0000000000080
oooo00H0EEEE0?ooo`3oool0ZZZZ0?ooo`1EEED20?ooo`80ZZZZ1@3oool0102ZZZX0oooo05EEE@1E
EED30?ooo`030000001EEED0oooo00<0000000<0ZZZZ05EEE@3oool00P3oool0101EEED0oooo05EE
E@2ZZZX20?ooo`030000002ZZZX0oooo00L0oooo2P3AcJT80?ooo`040:ZZZP3oool0ZZZZ0:ZZZP<0
oooo00@0ZZZZ0?ooo`2ZZZX00000103oool0102ZZZX0oooo0:ZZZP3oool20:ZZZP030000001EEED0
ZZZZ0080ZZZZ0P000000103oool0ZZZZ0000001EEED30:ZZZP0805EEE@000000ZZZZ0:ZZZP000000
ZZZZ0?ooo`1EEED40?ooo`040000001EEED0oooo0:ZZZP80oooo0`2ZZZX00`000000ZZZZ0?ooo`07
0?ooo`X0dLfY203oool01@2ZZZX0oooo0000001EEED0ZZZZ00@0oooo00<0EEEE0?ooo`3oool01@3o
ool305EEE@<0000000<0ZZZZ0?ooo`1EEED00P2ZZZX01`1EEED0oooo0:ZZZP3oool0EEEE0?ooo`2Z
ZZX00P00000205EEE@030000001EEED0oooo00P0oooo00D0ZZZZ0?ooo`3oool0000005EEE@020000
00030:ZZZP3oool0oooo00H0oooo303AcJT000/0dLfY2@3oool305EEE@0:0:ZZZP3oool0ZZZZ0000
002ZZZX0oooo0:ZZZP3oool000000?ooo`80000000<0oooo05EEE@2ZZZX00P2ZZZX01@3oool0ZZZZ
0:ZZZP3oool0ZZZZ008000000P1EEED2000000050:ZZZP3oool0oooo0:ZZZP3oool00P2ZZZX03`3o
ool0EEEE0?ooo`1EEED000000?ooo`1EEED0oooo0:ZZZP000000ZZZZ0?ooo`2ZZZX0oooo00000002
05EEE@030:ZZZP3oool0oooo00L0oooo2P3AcJT90?ooo`@0EEEE00<0ZZZZ0?ooo`1EEED00P2ZZZX2
05EEE@040:ZZZP3oool0ZZZZ00000080EEEE00<0ZZZZ0?ooo`3oool00P3oool305EEE@040?ooo`1E
EED0oooo0:ZZZP@0EEEE1@3oool00`000000EEEE05EEE@020:ZZZP040?ooo`1EEED0EEEE05EEE@<0
ZZZZ00<0oooo0:ZZZP1EEED00P1EEED00`2ZZZX0oooo0?ooo`070?ooo`X0dLfY2@3oool0101EEED0
000005EEE@1EEED20?ooo`0305EEE@2ZZZX0EEEE0080ZZZZ0P3oool010000000oooo0?ooo`3oool2
0:ZZZP80EEEE00<0oooo05EEE@1EEED00P0000001`1EEED0oooo05EEE@1EEED0ZZZZ0000001EEED0
0P3oool205EEE@030:ZZZP1EEED0oooo0080oooo00<000000?ooo`3oool00P2ZZZX00`1EEED0ZZZZ
0?ooo`020?ooo`80EEEE00<000000:ZZZP3oool0203oool:0=7=Z@T0oooo00H0EEEE0000001EEED0
00000?ooo`00000205EEE@060?ooo`2ZZZX0EEEE0:ZZZP1EEED0ZZZZ0`3oool00`1EEED000000:ZZ
ZP020:ZZZP050?ooo`2ZZZX0oooo05EEE@2ZZZX00P3oool01@2ZZZX0oooo0?ooo`2ZZZX0oooo0080
ZZZZ0P0000000`2ZZZX0oooo0?ooo`020:ZZZP0605EEE@2ZZZX0EEEE0:ZZZP3oool0EEEE0P000000
1@3oool0000005EEE@000000ZZZZ00T0oooo2P3AcJT90?ooo`0305EEE@2ZZZX0oooo0080EEEE00<0
00000?ooo`1EEED01@000000102ZZZX000000000002ZZZX30?ooo`030:ZZZP1EEED000000080EEEE
00D000000?ooo`1EEED0EEEE0?ooo`0305EEE@070?ooo`1EEED0ZZZZ05EEE@3oool0EEEE0:ZZZP02
000000030:ZZZP000000ZZZZ008000000`1EEED010000000EEEE0:ZZZP3oool20:ZZZPT0oooo303A
cJT000/0dLfY2P3oool01@2ZZZX0EEEE0:ZZZP2ZZZX0oooo0080EEEE0P3oool00`1EEED0ZZZZ05EE
E@0305EEE@080:ZZZP3oool0ZZZZ0:ZZZP3oool000000:ZZZP1EEED20:ZZZP030?ooo`2ZZZX00000
0080oooo00D0ZZZZ05EEE@1EEED000000?ooo`020:ZZZP0305EEE@2ZZZX0EEEE00D0EEEE00T0oooo
0000001EEED0ZZZZ0?ooo`2ZZZX0000005EEE@2ZZZX02P3oool:0=7=Z@X0oooo00<0ZZZZ05EEE@1E
EED00`1EEED010000000ZZZZ0?ooo`3oool30:ZZZP060?ooo`000000EEEE05EEE@2ZZZX0EEEE1P2Z
ZZX40?ooo`0405EEE@2ZZZX0ZZZZ05EEE@D0ZZZZ00<0EEEE0000003oool00P2ZZZX40?ooo`070000
001EEED0EEEE05EEE@000000EEEE0:ZZZP0:0?ooo`X0dLfY2P3oool01P2ZZZX0oooo0?ooo`2ZZZX0
oooo0:ZZZP<0EEEE0P000000103oool000000?ooo`3oool2000000030?ooo`00000000000080ZZZZ
00<0oooo0:ZZZP1EEED0103oool020000000ZZZZ0?ooo`000000ZZZZ0000001EEED0oooo0P000000
0`3oool00000000000020?ooo`070000001EEED0EEEE05EEE@2ZZZX0oooo0:ZZZP020?ooo`030:ZZ
ZP3oool0oooo00P0oooo2P3AcJT:0?ooo`070:ZZZP3oool0oooo05EEE@000000EEEE000000020:ZZ
ZP030?ooo`2ZZZX0ZZZZ00D0EEEE0P0000020?ooo`0305EEE@2ZZZX0oooo00D0oooo00@0ZZZZ0?oo
o`2ZZZX000000P3oool00`1EEED0000005EEE@0405EEE@030:ZZZP000000oooo0080ZZZZ00@00000
05EEE@000000EEEE0P3oool00`2ZZZX0oooo0?ooo`080?ooo`X0dLfY2P3oool01P2ZZZX0oooo05EE
E@1EEED0oooo0:ZZZP80oooo00D000000:ZZZP1EEED0EEEE000000020:ZZZP80000000@0oooo0:ZZ
ZP3oool000000`3oool205EEE@030?ooo`2ZZZX0EEEE00<0oooo00D0EEEE0000003oool000000?oo
o`02000000030:ZZZP3oool000000080EEEE00H0ZZZZ0000001EEED0oooo05EEE@3oool205EEE@03
0?ooo`2ZZZX0oooo00T0oooo303AcJT000/0dLfY2`3oool01`2ZZZX0EEEE05EEE@1EEED0ZZZZ0?oo
o`0000000P1EEED01P3oool0ZZZZ0:ZZZP2ZZZX0oooo000000@0EEEE00@000000?ooo`2ZZZX00000
0P1EEED0203oool0000005EEE@1EEED000000:ZZZP3oool000000`1EEED2000000050?ooo`2ZZZX0
ZZZZ0:ZZZP3oool00`1EEED00`3oool0000005EEE@0205EEE@030:ZZZP3oool0oooo00T0oooo2P3A
cJT;0?ooo`80ZZZZ00@0oooo0:ZZZP3oool0ZZZZ101EEED020000000EEEE05EEE@1EEED0oooo0:ZZ
ZP1EEED0ZZZZ0P3oool00`2ZZZX000000:ZZZP050?ooo`80ZZZZ00@000000:ZZZP3oool0oooo0P1E
EED20?ooo`<0EEEE00D0000005EEE@1EEED0EEEE000000030:ZZZP030?ooo`1EEED0ZZZZ00/0oooo
2P3AcJT;0?ooo`80ZZZZ0P3oool0102ZZZX0oooo0:ZZZP3oool20:ZZZP030?ooo`000000oooo00@0
oooo00<0EEEE0:ZZZP3oool00`0000000`3oool0EEEE0?ooo`0205EEE@030?ooo`00000000000080
oooo00@0ZZZZ0?ooo`3oool000000`3oool01P000000oooo05EEE@2ZZZX0oooo0:ZZZP@0oooo00<0
00000:ZZZP3oool02P3oool:0=7=Z@/0oooo00T0ZZZZ0?ooo`2ZZZX0ZZZZ0?ooo`2ZZZX0EEEE0:ZZ
ZP1EEED00P3oool00`2ZZZX0oooo0:ZZZP030:ZZZP030?ooo`1EEED0EEEE0080ZZZZ00<0000005EE
E@1EEED0101EEED00`000000ZZZZ0?ooo`0205EEE@80ZZZZ00<0oooo0:ZZZP2ZZZX00P2ZZZX01@3o
ool0ZZZZ05EEE@2ZZZX0EEEE00@0ZZZZ00<000000:ZZZP3oool02P3oool:0=7=Z@/0oooo00D0ZZZZ
05EEE@2ZZZX000000?ooo`0205EEE@0:0?ooo`2ZZZX0ZZZZ0:ZZZP3oool0EEEE0:ZZZP1EEED0ZZZZ
05EEE@<0oooo1000000205EEE@030:ZZZP1EEED0000000<000000P3oool02`2ZZZX0EEEE0?ooo`1E
EED0ZZZZ05EEE@3oool0ZZZZ0?ooo`2ZZZX0oooo0080EEEE0P0000000`2ZZZX000000:ZZZP0;0?oo
o``0dLfY000;0=7=Z@`0oooo00<0EEEE0:ZZZP2ZZZX00P1EEED2000000H0EEEE00<0000005EEE@3o
ool00`2ZZZX00`000000ZZZZ05EEE@020?ooo`030000001EEED0oooo0080EEEE00<0ZZZZ0000002Z
ZZX00P2ZZZX20?ooo`030000001EEED0EEEE0080EEEE00@0000005EEE@00000000000P1EEED30:ZZ
ZP`0oooo2P3AcJT<0?ooo`@0EEEE00<000000:ZZZP2ZZZX00P2ZZZX00`1EEED0ZZZZ05EEE@030?oo
o`070:ZZZP3oool0oooo0?ooo`2ZZZX0oooo0000000605EEE@030000003oool0oooo0080oooo0P2Z
ZZX40?ooo`030:ZZZP1EEED0oooo0080ZZZZ00<0oooo0000002ZZZX00P1EEED00`2ZZZX0oooo0?oo
o`0:0?ooo`X0dLfY303oool01`1EEED0000005EEE@000000ZZZZ0?ooo`2ZZZX00P0000020:ZZZP80
EEEE0P2ZZZX00`1EEED0ZZZZ0?ooo`020?ooo`030000003oool0oooo0080oooo00D0EEEE0?ooo`3o
ool0oooo000000030?ooo`050:ZZZP1EEED0ZZZZ0:ZZZP1EEED00`2ZZZX01@1EEED000000:ZZZP3o
ool0ZZZZ0080EEEE00<000000:ZZZP3oool02`3oool:0=7=Z@`0oooo00@0EEEE0000001EEED00000
0`3oool0102ZZZX0000005EEE@2ZZZX205EEE@030:ZZZP000000EEEE0080ZZZZ00L0oooo0000002Z
ZZX0ZZZZ0?ooo`2ZZZX0oooo00H0ZZZZ00<0oooo0:ZZZP1EEED00P1EEED01@2ZZZX0EEEE05EEE@2Z
ZZX0EEEE0080ZZZZ00L0oooo05EEE@3oool0000005EEE@000000ZZZZ00`0oooo2P3AcJT<0?ooo`07
05EEE@000000oooo0000002ZZZX000000:ZZZP020?ooo`040:ZZZP3oool0000005EEE@80oooo00P0
ZZZZ000000000000ZZZZ05EEE@2ZZZX0oooo0:ZZZP80oooo00P0ZZZZ0?ooo`1EEED0oooo0:ZZZP3o
ool0ZZZZ00000080ZZZZ0P3oool0101EEED000000?ooo`2ZZZX20?ooo`030:ZZZP1EEED0ZZZZ0080
oooo00<000000:ZZZP3oool02`3oool<0=7=Z@002`3AcJT=0?ooo`080:ZZZP1EEED0EEEE0000003o
ool0ZZZZ0?ooo`00000505EEE@0;0:ZZZP1EEED0ZZZZ0:ZZZP3oool0000005EEE@000000EEEE0:ZZ
ZP0000000P2ZZZX01`3oool0000005EEE@2ZZZX0oooo0:ZZZP3oool01`1EEED01@000000oooo0:ZZ
ZP2ZZZX000000080EEEE00<0ZZZZ0?ooo`3oool02`3oool:0=7=Z@d0oooo00<0ZZZZ05EEE@1EEED0
0P2ZZZX00`1EEED0ZZZZ0:ZZZP0405EEE@030?ooo`1EEED0EEEE00D0ZZZZ0P1EEED010000000EEEE
05EEE@00000205EEE@050:ZZZP3oool0ZZZZ0:ZZZP3oool00P1EEED00`3oool0EEEE05EEE@0205EE
E@080?ooo`2ZZZX0EEEE0?ooo`2ZZZX0000005EEE@2ZZZX=0?ooo`X0dLfY3@3oool00`2ZZZX0oooo
0?ooo`020:ZZZP060000001EEED0oooo0?ooo`2ZZZX0oooo0P0000000`2ZZZX0EEEE05EEE@030:ZZ
ZP030?ooo`00000000000080oooo00H0EEEE0?ooo`3oool000000?ooo`0000020:ZZZP80EEEE1000
00001@2ZZZX0oooo0?ooo`1EEED000000080ZZZZ0P3oool00`2ZZZX0oooo0?ooo`0;0?ooo`X0dLfY
3@3oool00`2ZZZX0oooo0?ooo`0205EEE@050:ZZZP3oool000000?ooo`1EEED00`3oool01`2ZZZX0
oooo0?ooo`2ZZZX000000:ZZZP3oool00P2ZZZX0101EEED0oooo0?ooo`1EEED20:ZZZP80oooo00<0
00000:ZZZP3oool0103oool205EEE@060?ooo`1EEED0oooo0:ZZZP000000EEEE0P3oool00`2ZZZX0
oooo0?ooo`0;0?ooo`X0dLfY3@3oool0102ZZZX0oooo05EEE@00000205EEE@<0ZZZZ00L0oooo0000
002ZZZX0EEEE0?ooo`1EEED0ZZZZ00@0oooo00<0EEEE0000002ZZZX00P1EEED20:ZZZP0305EEE@3o
ool0oooo0080oooo00@0ZZZZ05EEE@3oool0EEEE0P2ZZZX0103oool0ZZZZ0000002ZZZX205EEE@04
0000003oool0oooo0:ZZZPd0oooo303AcJT000/0dLfY3P3oool30:ZZZP<0EEEE00<0oooo05EEE@1E
EED00`2ZZZX2000000<0EEEE0`2ZZZX01P000000EEEE0000002ZZZX0EEEE00000080ZZZZ00H00000
05EEE@1EEED0EEEE0000003oool20:ZZZP040?ooo`1EEED0EEEE00000080EEEE00@000000:ZZZP1E
EED0ZZZZ3P3oool:0=7=Z@h0oooo0P2ZZZX20?ooo`030:ZZZP1EEED0EEEE00@0000000@0EEEE0?oo
o`2ZZZX000000P1EEED02@000000ZZZZ0:ZZZP2ZZZX0EEEE0?ooo`2ZZZX0EEEE0?ooo`030:ZZZP<0
EEEE0P2ZZZX00`1EEED0000005EEE@0200000080EEEE00D0ZZZZ0?ooo`3oool0EEEE0:ZZZP0>0?oo
o`X0dLfY3P3oool20:ZZZP030?ooo`2ZZZX0oooo0080EEEE00P000000?ooo`3oool0ZZZZ05EEE@2Z
ZZX0oooo0:ZZZP80oooo00@0EEEE0000003oool0oooo0P0000001P1EEED000000?ooo`3oool00000
0:ZZZP80oooo00X0ZZZZ0?ooo`3oool0EEEE0:ZZZP000000oooo0000003oool0EEEE0`3oool00`00
0000ZZZZ0?ooo`0=0?ooo`X0dLfY3P3oool0102ZZZX0oooo0:ZZZP2ZZZX20?ooo`0705EEE@2ZZZX0
ZZZZ0:ZZZP000000EEEE0:ZZZP0200000080ZZZZ0P1EEED00`3oool0EEEE0?ooo`030?ooo`030000
003oool0EEEE00<0ZZZZ00H0oooo0000002ZZZX0EEEE0000003oool20:ZZZP<0oooo0P2ZZZX00`00
0000ZZZZ0?ooo`0=0?ooo`X0dLfY3P3oool00`2ZZZX0oooo000000020000000505EEE@2ZZZX0oooo
0?ooo`2ZZZX00P1EEED00`3oool0EEEE0000000405EEE@030?ooo`2ZZZX0EEEE00<0EEEE0P3oool0
1@1EEED0oooo05EEE@1EEED0oooo00@0EEEE103oool00`1EEED000000?ooo`02000000030:ZZZP3o
ool0oooo00`0oooo303AcJT000/0dLfY3`3oool01P1EEED000000:ZZZP3oool0ZZZZ05EEE@800000
0`1EEED01@000000oooo05EEE@3oool0ZZZZ00<0EEEE00@0ZZZZ05EEE@000000ZZZZ1@1EEED0102Z
ZZX0oooo05EEE@3oool405EEE@80000000H0EEEE0:ZZZP3oool0ZZZZ0000002ZZZX?0?ooo`X0dLfY
3`3oool405EEE@80ZZZZ00D0EEEE0:ZZZP2ZZZX0EEEE0:ZZZP020?ooo`0505EEE@2ZZZX0oooo0?oo
o`0000000P1EEED0102ZZZX0oooo0?ooo`2ZZZX205EEE@030000002ZZZX0oooo0080ZZZZ0P3oool0
1`2ZZZX0EEEE0:ZZZP2ZZZX0EEEE0?ooo`2ZZZX00`1EEED00`2ZZZX0oooo0?ooo`0=0?ooo`X0dLfY
3`3oool0101EEED0000005EEE@1EEED20?ooo`0405EEE@2ZZZX0ZZZZ05EEE@800000103oool30:ZZ
ZP0605EEE@3oool0ZZZZ0:ZZZP3oool0EEEE0P2ZZZX30?ooo`050:ZZZP3oool000000000001EEED0
0P2ZZZX00`1EEED0oooo0?ooo`0205EEE@030000002ZZZX0oooo00h0oooo2P3AcJT?0?ooo`0505EE
E@00000000000000003oool00P0000001@1EEED0ZZZZ0:ZZZP2ZZZX0oooo0080ZZZZ0`3oool20:ZZ
ZPD0oooo00@0EEEE0:ZZZP2ZZZX0ZZZZ0P3oool00`1EEED0ZZZZ0?ooo`020:ZZZP090000001EEED0
00000000003oool0000005EEE@000000ZZZZ00l0oooo2P3AcJT?0?ooo`0305EEE@2ZZZX000000080
oooo00H0EEEE0:ZZZP2ZZZX0ZZZZ05EEE@00000205EEE@030?ooo`2ZZZX0ZZZZ0080000000@0EEEE
0?ooo`000000EEEE0P00000205EEE@040000003oool0ZZZZ0:ZZZP80EEEE0P00000205EEE@80ZZZZ
00@0EEEE0?ooo`3oool0oooo0P2ZZZX?0?ooo``0dLfY000;0=7=ZA00oooo0`2ZZZX205EEE@800000
00L0ZZZZ05EEE@1EEED0EEEE0?ooo`1EEED0000000@0EEEE00D000000?ooo`1EEED0EEEE0?ooo`05
05EEE@040000001EEED0oooo00000080EEEE0`00000205EEE@030:ZZZP1EEED0ZZZZ0100oooo2P3A
cJT@0?ooo`030:ZZZP000000EEEE00<0EEEE00<000000:ZZZP3oool0103oool20:ZZZP030?ooo`00
0000EEEE00D0EEEE00<0ZZZZ05EEE@0000000`2ZZZX60?ooo`030000001EEED0EEEE00<0EEEE00<0
ZZZZ0?ooo`3oool03P3oool:0=7=ZA00oooo00<0ZZZZ0?ooo`3oool00`2ZZZX205EEE@80ZZZZ1P3o
ool01@2ZZZX0oooo05EEE@3oool0EEEE0080oooo00@0ZZZZ0?ooo`2ZZZX0EEEE0P3oool00`1EEED0
oooo0?ooo`020:ZZZP80EEEE00<0ZZZZ0?ooo`2ZZZX00P3oool00`2ZZZX0oooo0?ooo`0>0?ooo`X0
dLfY403oool00`2ZZZX0oooo0?ooo`0305EEE@040000002ZZZX0ZZZZ0:ZZZP@0oooo0P2ZZZX00`1E
EED0oooo0?ooo`060?ooo`0605EEE@2ZZZX0ZZZZ0?ooo`000000oooo0`2ZZZX01@3oool0000005EE
E@000000EEEE0080oooo00<0ZZZZ0?ooo`3oool03P3oool:0=7=ZA00oooo00@0ZZZZ05EEE@1EEED0
oooo0P1EEED00`3oool0ZZZZ0:ZZZP0305EEE@030?ooo`1EEED0EEEE0080ZZZZ00P0EEEE00000000
0000oooo05EEE@000000ZZZZ05EEE@80ZZZZ101EEED01@3oool0EEEE0:ZZZP2ZZZX0oooo0080EEEE
00@0oooo05EEE@3oool0ZZZZ403oool<0=7=Z@002`3AcJTA0?ooo`0405EEE@000000ZZZZ0:ZZZP<0
EEEE0P0000020?ooo`80EEEE1@2ZZZX010000000EEEE0000000000050:ZZZP0405EEE@3oool0oooo
05EEE@80000000L0ZZZZ05EEE@1EEED0oooo0:ZZZP000000ZZZZ0140oooo2P3AcJTA0?ooo`0605EE
E@2ZZZX0oooo0:ZZZP3oool0ZZZZ1`1EEED00`000000EEEE05EEE@020?ooo`0605EEE@3oool0ZZZZ
05EEE@2ZZZX0oooo0P1EEED00`000000EEEE05EEE@0405EEE@050000002ZZZX0oooo0:ZZZP3oool0
0P2ZZZXA0?ooo`X0dLfY4@3oool01`000000ZZZZ0?ooo`3oool0ZZZZ0?ooo`2ZZZX00P3oool00`00
0000oooo0:ZZZP0205EEE@80oooo00D0ZZZZ05EEE@000000EEEE0?ooo`02000000030:ZZZP3oool0
oooo0080EEEE00<0ZZZZ0?ooo`2ZZZX00P3oool00`2ZZZX0oooo0:ZZZP020?ooo`80ZZZZ4@3oool:
0=7=ZA40oooo00X000000?ooo`2ZZZX0ZZZZ0?ooo`2ZZZX0000005EEE@000000EEEE0P2ZZZX00`1E
EED0000005EEE@0:0?ooo`80000000<0EEEE0:ZZZP2ZZZX00P00000205EEE@060:ZZZP3oool0ZZZZ
0:ZZZP3oool0ZZZZ4@3oool:0=7=ZA40oooo00@0000005EEE@2ZZZX0oooo0P2ZZZX01@1EEED0ZZZZ
05EEE@1EEED0ZZZZ00<0EEEE00@0ZZZZ05EEE@1EEED0ZZZZ0P3oool00`1EEED0oooo05EEE@0505EE
E@060000002ZZZX0000005EEE@2ZZZX0EEEE102ZZZX00`1EEED0ZZZZ0?ooo`0@0?ooo``0dLfY000;
0=7=ZA80oooo00@0ZZZZ05EEE@2ZZZX000000P1EEED00`000000oooo0?ooo`030?ooo`0305EEE@3o
ool0ZZZZ0080ZZZZ0P3oool00`2ZZZX0oooo0:ZZZP020:ZZZP80EEEE1@3oool01`000000EEEE05EE
E@000000ZZZZ05EEE@2ZZZX04P3oool:0=7=ZA80oooo00@0ZZZZ05EEE@2ZZZX0oooo0P1EEED01000
0000EEEE05EEE@00000205EEE@030:ZZZP3oool0oooo0080ZZZZ103oool01@1EEED0ZZZZ0?ooo`3o
ool0ZZZZ0080EEEE00@0000005EEE@1EEED000000P1EEED20?ooo`0305EEE@2ZZZX0oooo0140oooo
2P3AcJTB0?ooo`80ZZZZ00H0oooo0:ZZZP1EEED0oooo0:ZZZP3oool30:ZZZP<000000P3oool01P2Z
ZZX0EEEE0?ooo`2ZZZX0EEEE0:ZZZP<0oooo0P0000001`1EEED0ZZZZ05EEE@3oool0ZZZZ0000001E
EED0102ZZZXB0?ooo`X0dLfY4P3oool20:ZZZP0;0?ooo`1EEED0ZZZZ0?ooo`000000EEEE0000003o
ool000000:ZZZP3oool02`1EEED20?ooo`030:ZZZP000000oooo0080EEEE00@000000:ZZZP2ZZZX0
EEEE0`2ZZZXB0?ooo`X0dLfY4P3oool20:ZZZP0605EEE@000000ZZZZ0?ooo`1EEED000000P2ZZZX0
1`3oool0EEEE0:ZZZP2ZZZX0EEEE0:ZZZP1EEED00P3oool01`1EEED0oooo0?ooo`2ZZZX0EEEE0?oo
o`2ZZZX00P1EEED0102ZZZX0oooo0000001EEED20:ZZZP040000002ZZZX0ZZZZ0:ZZZQ80oooo303A
cJT000/0dLfY4`3oool00`2ZZZX000000:ZZZP020:ZZZPH0EEEE00<0000005EEE@1EEED00`1EEED0
0`2ZZZX0000005EEE@0305EEE@80000000@0EEEE0000001EEED000000P1EEED01@3oool0ZZZZ0:ZZ
ZP1EEED0ZZZZ01<0oooo2P3AcJTC0?ooo`030:ZZZP000000EEEE0080ZZZZ00H0EEEE0:ZZZP2ZZZX0
EEEE0?ooo`2ZZZX405EEE@D0oooo00<0ZZZZ05EEE@1EEED00P1EEED20:ZZZP0605EEE@3oool0ZZZZ
05EEE@3oool0ZZZZ0P1EEED00`2ZZZX0oooo0?ooo`0A0?ooo`X0dLfY4`3oool00`2ZZZX0oooo0?oo
o`020:ZZZP030000001EEED0oooo0080ZZZZ00`0oooo05EEE@2ZZZX0ZZZZ05EEE@000000EEEE0:ZZ
ZP000000EEEE0:ZZZP1EEED20:ZZZP0705EEE@3oool0oooo0:ZZZP3oool0EEEE000000020:ZZZP80
oooo00<0ZZZZ0?ooo`3oool04@3oool:0=7=ZA<0oooo00<0ZZZZ0?ooo`3oool00P1EEED01`2ZZZX0
oooo0:ZZZP2ZZZX0oooo0:ZZZP3oool0300000000`3oool0ZZZZ05EEE@020:ZZZP040?ooo`2ZZZX0
000005EEE@80oooo00<0ZZZZ0?ooo`3oool04@3oool:0=7=ZA<0oooo00D0ZZZZ0?ooo`1EEED0ZZZZ
05EEE@020?ooo`80ZZZZ0`1EEED0102ZZZX0000005EEE@1EEED20?ooo`0605EEE@3oool0oooo05EE
E@000000ZZZZ0P1EEED00`000000ZZZZ000000020?ooo`0505EEE@2ZZZX0EEEE0?ooo`2ZZZX04`3o
ool<0=7=Z@002`3AcJTD0?ooo`<0EEEE00<000000:ZZZP3oool00P0000001@3oool0ZZZZ0000002Z
ZZX0oooo00<0ZZZZ0P1EEED30:ZZZP090?ooo`2ZZZX000000:ZZZP1EEED0000005EEE@3oool0ZZZZ
00<0EEEE00<0ZZZZ0?ooo`3oool04P3oool:0=7=ZA@0oooo00D0EEEE0:ZZZP3oool0oooo0:ZZZP02
05EEE@070:ZZZP3oool0oooo0:ZZZP3oool0EEEE0:ZZZP060?ooo`040:ZZZP1EEED0ZZZZ0:ZZZP80
oooo00@0ZZZZ05EEE@1EEED0ZZZZ0P3oool20:ZZZQ@0oooo2P3AcJTD0?ooo`050000002ZZZX0oooo
0:ZZZP3oool00`1EEED01@000000ZZZZ0:ZZZP3oool0ZZZZ0080oooo00P0EEEE0:ZZZP3oool0EEEE
0:ZZZP3oool0ZZZZ0?ooo`80ZZZZ0P1EEED00`3oool0EEEE0?ooo`020?ooo`80ZZZZ503oool:0=7=
ZA@0oooo00@000000?ooo`2ZZZX0ZZZZ0P3oool0102ZZZX0oooo05EEE@1EEED>0:ZZZP0305EEE@3o
ool0oooo00<0oooo0P2ZZZX00`3oool0ZZZZ0?ooo`0C0?ooo`X0dLfY503oool00`000000oooo0000
0002000000080:ZZZP1EEED000000?ooo`1EEED0oooo0:ZZZP3oool205EEE@80oooo00@0EEEE0?oo
o`3oool0EEEE0`3oool02P1EEED0oooo0000003oool0ZZZZ0000001EEED000000?ooo`2ZZZXD0?oo
o``0dLfY000;0=7=ZAD0oooo00T0ZZZZ05EEE@2ZZZX0oooo0:ZZZP1EEED0ZZZZ05EEE@3oool00P1E
EED02P2ZZZX0oooo0:ZZZP3oool0ZZZZ0000003oool0ZZZZ0?ooo`2ZZZX205EEE@090?ooo`1EEED0
ZZZZ05EEE@2ZZZX0oooo0000001EEED0ZZZZ01D0oooo2P3AcJTE0?ooo`040:ZZZP1EEED0ZZZZ0:ZZ
ZP80oooo0P2ZZZX00`3oool0ZZZZ0:ZZZP0:0?ooo`0305EEE@2ZZZX0oooo0080ZZZZ0P3oool0102Z
ZZX0oooo05EEE@2ZZZXE0?ooo`X0dLfY5@3oool20:ZZZP040?ooo`2ZZZX0ZZZZ05EEE@<0oooo00L0
000005EEE@3oool0ZZZZ0000002ZZZX0oooo0080ZZZZ00D0oooo0:ZZZP3oool0oooo000000030?oo
o`0305EEE@2ZZZX0ZZZZ00<0ZZZZ5@3oool:0=7=ZAD0oooo0P2ZZZX00`3oool0EEEE0:ZZZP020:ZZ
ZP060?ooo`2ZZZX000000?ooo`2ZZZX0oooo0P2ZZZX01P000000EEEE0:ZZZP000000oooo0:ZZZP80
000000<0ZZZZ0?ooo`2ZZZX00P2ZZZX0101EEED0ZZZZ0:ZZZP2ZZZXE0?ooo`X0dLfY5@3oool20:ZZ
ZP040?ooo`1EEED0oooo0:ZZZP80EEEE0P0000000`3oool0EEEE05EEE@020000000305EEE@2ZZZX0
000000<0EEEE00@0oooo00000000000000000P1EEED00`3oool0EEEE000000020:ZZZQD0oooo303A
cJT000/0dLfY5P3oool02`2ZZZX0EEEE05EEE@000000oooo0:ZZZP000000ZZZZ0000002ZZZX00000
00<0EEEE00<0oooo0000001EEED00P1EEED01@000000oooo0000002ZZZX0oooo0080ZZZZ00@00000
05EEE@1EEED0ZZZZ5P3oool:0=7=ZAH0oooo00<0ZZZZ0000001EEED01P1EEED;0?ooo`040:ZZZP1E
EED0EEEE0:ZZZPD0EEEE00<0ZZZZ0?ooo`3oool0503oool:0=7=ZAH0oooo00<0ZZZZ0?ooo`3oool0
0`2ZZZX0101EEED000000?ooo`3oool205EEE@050?ooo`2ZZZX0oooo0?ooo`2ZZZX00`1EEED20?oo
o`050000001EEED0ZZZZ0?ooo`2ZZZX00P3oool00`2ZZZX0oooo0?ooo`0D0?ooo`X0dLfY5P3oool0
0`2ZZZX0oooo0?ooo`0305EEE@060:ZZZP3oool0oooo0?ooo`000000EEEE0P3oool20:ZZZP030?oo
o`2ZZZX0EEEE008000000P3oool010000000EEEE0000001EEED20?ooo`030:ZZZP3oool0oooo01@0
oooo2P3AcJTF0?ooo`050:ZZZP1EEED0EEEE05EEE@3oool00P2ZZZX01P3oool0EEEE0:ZZZP1EEED0
000005EEE@80oooo00P0ZZZZ0?ooo`2ZZZX0000005EEE@2ZZZX0EEEE0?ooo`80ZZZZ00D0oooo05EE
E@1EEED0oooo0:ZZZP0F0?ooo``0dLfY000;0=7=ZAL0oooo00D0ZZZZ05EEE@000000ZZZZ0?ooo`02
05EEE@030000003oool0EEEE00<0EEEE0P00000405EEE@080?ooo`000000EEEE0:ZZZP3oool0ZZZZ
0000001EEEDH0?ooo`X0dLfY5`3oool01`2ZZZX0EEEE05EEE@2ZZZX0EEEE0?ooo`0000003P1EEED2
000000@0EEEE603oool:0=7=ZAL0oooo00D0ZZZZ05EEE@000000EEEE000000020?ooo`060:ZZZP1E
EED000000000002ZZZX0oooo0P2ZZZX0303oool0ZZZZ000000000000oooo0:ZZZP3oool0ZZZZ0000
001EEED0000005EEEAP0oooo2P3AcJTG0?ooo`030:ZZZP1EEED000000080000000@0EEEE0?ooo`3o
ool0EEEE0P0000030:ZZZP0305EEE@2ZZZX0EEEE00800000103oool010000000EEEE0000001EEEDH
0?ooo`X0dLfY5`3oool0202ZZZX0EEEE0000003oool000000?ooo`2ZZZX0oooo0P1EEED04@000000
ZZZZ0?ooo`3oool0EEEE0?ooo`2ZZZX0000005EEE@000000oooo0:ZZZP1EEED000000?ooo`000000
EEEE01P0oooo303AcJT000/0dLfY603oool01P2ZZZX0EEEE05EEE@1EEED0ZZZZ0?ooo`<0EEEE0P3o
ool02`2ZZZX000000:ZZZP2ZZZX0EEEE0?ooo`1EEED0000005EEE@3oool0000000<0EEEE00<0ZZZZ
0?ooo`3oool05P3oool:0=7=ZAP0oooo00@0ZZZZ05EEE@2ZZZX0oooo0P1EEED02@3oool0ZZZZ0?oo
o`2ZZZX0oooo05EEE@3oool0ZZZZ05EEE@020:ZZZP030?ooo`2ZZZX0oooo0080EEEE0P3oool00`1E
EED0ZZZZ0?ooo`0G0?ooo`X0dLfY603oool20:ZZZP030?ooo`2ZZZX000000080EEEE0P3oool30000
00060?ooo`00000000000?ooo`000000oooo101EEED40:ZZZQP0oooo2P3AcJTH0?ooo`80ZZZZ00T0
oooo05EEE@2ZZZX0oooo0000003oool0ZZZZ05EEE@3oool00P2ZZZX0103oool0ZZZZ0?ooo`1EEED2
0:ZZZP040000003oool0ZZZZ05EEE@<0ZZZZ603oool:0=7=ZAP0oooo0P2ZZZX01P1EEED0ZZZZ0:ZZ
ZP000000ZZZZ05EEE@80oooo00H0EEEE0?ooo`3oool0EEEE0?ooo`0000030?ooo`030:ZZZP000000
oooo00@0ZZZZ603oool<0=7=Z@002`3AcJTI0?ooo`<0ZZZZ0P1EEED20000000605EEE@0000000000
05EEE@000000ZZZZ0P1EEED010000000EEEE00000000000205EEE@030:ZZZP1EEED0ZZZZ01T0oooo
2P3AcJTI0?ooo`050:ZZZP000000EEEE0?ooo`2ZZZX01@1EEED01@2ZZZX0oooo0?ooo`2ZZZX00000
0080EEEE00@0000005EEE@2ZZZX0ZZZZ0P1EEED00`2ZZZX0oooo0?ooo`0G0?ooo`X0dLfY6@3oool0
0`2ZZZX0oooo0?ooo`020:ZZZP030?ooo`2ZZZX000000080oooo00@000000?ooo`3oool000000P3o
ool00`000000ZZZZ0?ooo`020:ZZZP80oooo00<0ZZZZ0?ooo`3oool05`3oool:0=7=ZAT0oooo00H0
ZZZZ0?ooo`3oool0000005EEE@2ZZZX20?ooo`050:ZZZP1EEED0ZZZZ0:ZZZP1EEED00`2ZZZX20?oo
o`030:ZZZP1EEED0EEEE0080oooo00<0ZZZZ0?ooo`3oool05`3oool:0=7=ZAT0oooo00H0ZZZZ0?oo
o`1EEED0EEEE0?ooo`2ZZZX2000000050:ZZZP1EEED0oooo0?ooo`1EEED00P3oool02@2ZZZX00000
0?ooo`2ZZZX0oooo0000001EEED0oooo0:ZZZP0I0?ooo``0dLfY000;0=7=ZAX0oooo00@0ZZZZ05EE
E@1EEED000000P2ZZZX0103oool0ZZZZ0:ZZZP3oool200000080oooo00D0ZZZZ0?ooo`3oool0ZZZZ
0000000205EEEA/0oooo2P3AcJTJ0?ooo`030:ZZZP1EEED0EEEE0080EEEE0`3oool505EEE@040:ZZ
ZP3oool0oooo0:ZZZP@0EEEE6`3oool:0=7=ZAX0oooo00<0ZZZZ05EEE@1EEED00P1EEED00`2ZZZX0
EEEE05EEE@0205EEE@040:ZZZP3oool0EEEE0?ooo`80EEEE00D0oooo05EEE@1EEED0000005EEE@0K
0?ooo`X0dLfY6P3oool00`2ZZZX0EEEE05EEE@040000000:0?ooo`1EEED0ZZZZ0000001EEED0ZZZZ
0000003oool000000?ooo`<0000000<0EEEE0?ooo`3oool06@3oool:0=7=ZAX0oooo00L0ZZZZ05EE
E@3oool000000?ooo`000000ZZZZ0080oooo00@0000005EEE@3oool000000P3oool01P2ZZZX0EEEE
0?ooo`000000ZZZZ05EEEA/0oooo303AcJT000/0dLfY6`3oool30:ZZZP030000001EEED0EEEE0080
000000H0EEEE0:ZZZP1EEED0EEEE0:ZZZP00000205EEE@040000002ZZZX0EEEE0:ZZZQ/0oooo2P3A
cJTK0?ooo`040:ZZZP3oool0ZZZZ0:ZZZP<0oooo0P2ZZZX00`3oool0ZZZZ0:ZZZP040?ooo`80ZZZZ
00<0EEEE0:ZZZP3oool06P3oool:0=7=ZA/0oooo0P2ZZZX00`3oool0ZZZZ05EEE@0200000080oooo
0P1EEED0103oool0EEEE0000000000020:ZZZP030?ooo`2ZZZX0ZZZZ01/0oooo2P3AcJTK0?ooo`80
ZZZZ00<0oooo05EEE@2ZZZX00P2ZZZX20?ooo`80ZZZZ00<0oooo05EEE@2ZZZX00P2ZZZX0101EEED0
oooo0:ZZZP2ZZZXK0?ooo`X0dLfY6`3oool0202ZZZX000000?ooo`3oool0EEEE0:ZZZP1EEED0ZZZZ
0P1EEED01@3oool0EEEE0:ZZZP1EEED0ZZZZ00<0oooo0P2ZZZXK0?ooo``0dLfY000;0=7=ZA`0oooo
00D0ZZZZ05EEE@1EEED0EEEE000000020:ZZZP070000001EEED0EEEE0000003oool0ZZZZ00000003
05EEEAd0oooo2P3AcJTL0?ooo`030:ZZZP1EEED0ZZZZ00@0ZZZZ00D0EEEE0?ooo`2ZZZX0EEEE0?oo
o`020:ZZZP030?ooo`2ZZZX0EEEE01d0oooo2P3AcJTL0?ooo`030:ZZZP000000ZZZZ0080oooo00H0
ZZZZ000000000000oooo0:ZZZP0000020:ZZZP80oooo00<0ZZZZ0000003oool0703oool:0=7=ZA`0
oooo00<0ZZZZ0000003oool00`2ZZZX2000000040:ZZZP3oool000000?ooo`<0ZZZZ00<0oooo0000
003oool0703oool:0=7=ZA`0oooo00X0ZZZZ0000001EEED0oooo0:ZZZP3oool0EEEE0:ZZZP3oool0
00000P2ZZZX01@3oool0ZZZZ0:ZZZP1EEED0000001d0oooo303AcJT000/0dLfY7@3oool00`2ZZZX0
EEEE0:ZZZP0205EEE@030000002ZZZX0ZZZZ0080ZZZZ0`1EEED00`2ZZZX0EEEE0:ZZZP0M0?ooo`X0
dLfY7@3oool0102ZZZX0EEEE05EEE@2ZZZX205EEE@040:ZZZP3oool0oooo0:ZZZP80EEEE00@0ZZZZ
05EEE@1EEED0ZZZZ7@3oool:0=7=ZAd0oooo00D0ZZZZ05EEE@1EEED0oooo000000020?ooo`800000
00L0oooo000000000000oooo0000001EEED0ZZZZ01d0oooo2P3AcJTM0?ooo`0:0:ZZZP1EEED0EEEE
0000001EEED0oooo0:ZZZP000000EEEE0:ZZZP80EEEE0P0000000`1EEED0ZZZZ0?ooo`0L0?ooo`X0
dLfY7@3oool01`2ZZZX0EEEE0?ooo`2ZZZX0oooo05EEE@0000000P3oool2000000050?ooo`2ZZZX0
000005EEE@2ZZZX07@3oool<0=7=Z@002`3AcJTN0?ooo`040:ZZZP000000ZZZZ0?ooo`D0EEEE00D0
ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP0N0?ooo`X0dLfY7P3oool01@2ZZZX0oooo0:ZZZP3oool0ZZZZ00@0
oooo00D0EEEE0?ooo`2ZZZX0EEEE0:ZZZP0N0?ooo`X0dLfY7P3oool20:ZZZP050?ooo`000000oooo
0?ooo`0000000`3oool010000000oooo0:ZZZP2ZZZXN0?ooo`X0dLfY7P3oool20:ZZZP040?ooo`1E
EED0oooo0?ooo`80ZZZZ0P3oool0101EEED0oooo0:ZZZP2ZZZXN0?ooo`X0dLfY7P3oool20:ZZZP80
EEEE0P2ZZZX0101EEED0ZZZZ0:ZZZP3oool205EEE@80ZZZZ7P3oool<0=7=Z@002`3AcJTO0?ooo`04
0:ZZZP1EEED0ZZZZ000000@0EEEE0P2ZZZX00`1EEED0oooo0?ooo`0N0?ooo`X0dLfY7`3oool00`2Z
ZZX0EEEE0:ZZZP060?ooo`030:ZZZP1EEED0oooo01l0oooo2P3AcJTO0?ooo`060:ZZZP000000ZZZZ
05EEE@3oool0ZZZZ0`3oool00`2ZZZX000000?ooo`0O0?ooo`X0dLfY7`3oool01@2ZZZX000000?oo
o`2ZZZX0oooo0080ZZZZ00@0oooo0:ZZZP3oool00000803oool:0=7=ZAl0oooo00@0ZZZZ0000003o
ool0ZZZZ0P1EEED01@3oool0EEEE0000003oool000000200oooo303AcJT000/0dLfY803oool00`2Z
ZZX0EEEE0:ZZZP040:ZZZP030000001EEED0ZZZZ0200oooo2P3AcJTP0?ooo`030:ZZZP1EEED0EEEE
00H0EEEE00<0ZZZZ0?ooo`3oool07P3oool:0=7=ZB00oooo00H0ZZZZ05EEE@1EEED000000:ZZZP3o
ool20000000305EEE@2ZZZX0oooo01l0oooo2P3AcJTP0?ooo`050:ZZZP1EEED0EEEE05EEE@000000
0P1EEED00`000000EEEE0:ZZZP0P0?ooo`X0dLfY803oool0102ZZZX0EEEE0?ooo`3oool205EEE@04
0?ooo`2ZZZX0EEEE0:ZZZR00oooo303AcJT000/0dLfY8@3oool00`2ZZZX0EEEE05EEE@0405EEE@03
0:ZZZP3oool0oooo01l0oooo2P3AcJTQ0?ooo`040:ZZZP3oool0ZZZZ0?ooo`80ZZZZ00<0EEEE0:ZZ
ZP3oool0803oool:0=7=ZB40oooo0P2ZZZX0103oool0EEEE05EEE@3oool20:ZZZR40oooo2P3AcJTQ
0?ooo`80ZZZZ00@0oooo0:ZZZP2ZZZX0oooo0P2ZZZXQ0?ooo`X0dLfY8@3oool0102ZZZX000000000
001EEED200000080ZZZZ8@3oool<0=7=Z@002`3AcJTR0?ooo`050:ZZZP1EEED0ZZZZ0000001EEED0
8`3oool:0=7=ZB80oooo00D0ZZZZ05EEE@3oool0ZZZZ05EEE@0S0?ooo`X0dLfY8P3oool01@2ZZZX0
00000?ooo`2ZZZX0000002<0oooo2P3AcJTR0?ooo`050:ZZZP000000ZZZZ0?ooo`0000008`3oool:
0=7=ZB80oooo00D0ZZZZ0000003oool0EEEE0000000S0?ooo``0dLfY000;0=7=ZB<0oooo00@0ZZZZ
05EEE@1EEED0ZZZZ8`3oool:0=7=ZB<0oooo00@0ZZZZ05EEE@1EEED0ZZZZ8`3oool:0=7=ZB<0oooo
00@0ZZZZ0000001EEED0ZZZZ8`3oool:0=7=ZB<0oooo00@0ZZZZ0000001EEED0ZZZZ8`3oool:0=7=
ZB<0oooo00@0ZZZZ0000001EEED0ZZZZ8`3oool<0=7=Z@002`3AcJTT0?ooo`030:ZZZP3oool0oooo
02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo
02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo
02<0oooo303AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT0
0?l0dLfY/P3AcJT000/0dLfY00D0oooo0:ZZZP000000000005EEE@040?ooo`0505EEE@3oool00000
0:ZZZP1EEED01P2ZZZX0201EEED000000000001EEED0oooo05EEE@000000EEEE0`2ZZZX3000000<0
oooo00<0ZZZZ0?ooo`3oool00P0000030:ZZZP80EEEE00@0oooo05EEE@3oool0EEEE0P0000050:ZZ
ZP070000002ZZZX0EEEE05EEE@000000oooo000000050?ooo`80000000<0ZZZZ0?ooo`3AcJT02@3A
cJT01@3oool0ZZZZ0:ZZZP3oool0ZZZZ0080oooo0P2ZZZX30?ooo`@0ZZZZ00P0oooo05EEE@1EEED0
ZZZZ0000003oool0EEEE0:ZZZP80000000<0oooo05EEE@2ZZZX00P0000001@1EEED0000005EEE@2Z
ZZX000000080ZZZZ00<0000005EEE@1EEED0100000000`2ZZZX0EEEE000000030000000705EEE@3o
ool0oooo0:ZZZP1EEED0ZZZZ0?ooo`030:ZZZP0405EEE@3oool0oooo05EEE@80ZZZZ00@000000?oo
o`3oool0oooo0P2ZZZX00`3oool0dLfY0=7=Z@080=7=Z@040?ooo`2ZZZX0EEEE05EEE@80ZZZZ0P00
00000`2ZZZX000000?ooo`0205EEE@050?ooo`2ZZZX0ZZZZ05EEE@0000000`1EEED01@2ZZZX0EEEE
05EEE@1EEED0ZZZZ00<0000000`0EEEE0000002ZZZX0EEEE0?ooo`2ZZZX0oooo05EEE@000000oooo
05EEE@3oool205EEE@040000001EEED0ZZZZ00000080ZZZZ0`1EEED01@2ZZZX0oooo05EEE@1EEED0
ZZZZ0080EEEE00/0ZZZZ0?ooo`1EEED0EEEE0?ooo`000000ZZZZ0000001EEED0ZZZZ0000000205EE
E@030:ZZZP3oool0dLfY00T0dLfY00D0oooo05EEE@3oool0oooo0:ZZZP020?ooo`030:ZZZP3oool0
00000080EEEE00<0oooo0000001EEED00P3oool00`2ZZZX0EEEE0?ooo`0605EEE@<0oooo00<0EEEE
0:ZZZP3oool00P1EEED01@000000ZZZZ0:ZZZP3oool0ZZZZ00@0EEEE00<0ZZZZ05EEE@3oool00P3o
ool205EEE@030?ooo`1EEED0EEEE0080oooo0P1EEED20?ooo`0305EEE@000000EEEE0080EEEE00H0
ZZZZ0?ooo`2ZZZX0ZZZZ0?ooo`0000020?ooo`030:ZZZP3oool0dLfY00T0dLfY00@0oooo05EEE@3o
ool000000`3oool02@1EEED0ZZZZ0:ZZZP000000ZZZZ0000002ZZZX0EEEE0:ZZZP0205EEE@050000
002ZZZX000000?ooo`000000103oool01@000000EEEE05EEE@2ZZZX0EEEE0080oooo1P1EEED20?oo
o`0305EEE@2ZZZX0EEEE00<000000`3oool01P000000oooo0?ooo`2ZZZX000000?ooo`<0EEEE0`2Z
ZZX010000000ZZZZ0:ZZZP1EEED20?ooo`0505EEE@000000oooo0:ZZZP3oool0303AcJT000/0dLfY
00@0oooo0:ZZZP1EEED0EEEE10000000103oool0EEEE05EEE@1EEED20:ZZZP0405EEE@000000oooo
0:ZZZP<0oooo00<0000005EEE@1EEED00P1EEED30:ZZZP<0oooo00@0EEEE00000000000000000P3o
ool01@000000oooo0000001EEED0000000<0oooo00P0ZZZZ0000001EEED0EEEE0?ooo`1EEED00000
0:ZZZPD0oooo00<0EEEE0:ZZZP2ZZZX00P1EEED01P000000oooo0000003oool000000:ZZZP80EEEE
0P3oool:0=7=Z@040?ooo`2ZZZX0EEEE0?ooo`80EEEE00<0ZZZZ0000000000000P1EEED00`2ZZZX0
00000000000305EEE@050?ooo`2ZZZX0ZZZZ0000003oool00P1EEED30:ZZZP<0EEEE00D0oooo05EE
E@1EEED0oooo05EEE@040:ZZZP80oooo0P1EEED00`3oool0EEEE0000000205EEE@80ZZZZ00<0oooo
05EEE@3oool0102ZZZX0201EEED0000005EEE@000000EEEE0:ZZZP1EEED0ZZZZ0P0000001@2ZZZX0
EEEE0000003oool0EEEE0080oooo2P3AcJT0103oool0ZZZZ05EEE@1EEED20:ZZZP0:0000003oool0
ZZZZ0000002ZZZX0EEEE0:ZZZP1EEED000000?ooo`80ZZZZ0P1EEED01P000000ZZZZ0000002ZZZX0
00000:ZZZP80000000d0ZZZZ0?ooo`2ZZZX0ZZZZ0000002ZZZX0EEEE0000003oool0ZZZZ0000001E
EED0ZZZZ0080000000<0ZZZZ0?ooo`0000000P000000102ZZZX000000:ZZZP0000020:ZZZP80EEEE
0P2ZZZX00`1EEED0000005EEE@0205EEE@040:ZZZP3oool0ZZZZ0?ooo`<0ZZZZ0P1EEED20?ooo`X0
dLfY00D0oooo0:ZZZP1EEED0ZZZZ0000000205EEE@070000002ZZZX0EEEE0?ooo`2ZZZX0oooo0000
000305EEE@030:ZZZP3oool0EEEE0080oooo0P1EEED20?ooo`0305EEE@3oool0EEEE0080oooo00D0
ZZZZ05EEE@3oool0ZZZZ0000000205EEE@050000002ZZZX0oooo05EEE@2ZZZX00P3oool00`1EEED0
oooo05EEE@030?ooo`0405EEE@3oool0EEEE05EEE@80oooo00@0EEEE0000001EEED000000P2ZZZX0
103oool000000:ZZZP00000205EEE@80ZZZZ00<0EEEE0?ooo`3oool02P3AcJT0103oool0ZZZZ05EE
E@0000040?ooo`0805EEE@3oool0EEEE0000001EEED0oooo05EEE@3oool20000000<0?ooo`1EEED0
EEEE0:ZZZP000000EEEE0000002ZZZX0EEEE0000001EEED0ZZZZ103oool0101EEED0oooo0:ZZZP2Z
ZZX40?ooo`0;0000003oool0ZZZZ0?ooo`000000EEEE0:ZZZP000000ZZZZ0000002ZZZX00P1EEED2
0?ooo`040000002ZZZX0EEEE0?ooo`8000000`1EEED40?ooo`040000001EEED0oooo0?ooo``0dLfY
000;0=7=Z@<0oooo00@0ZZZZ0000001EEED000000P1EEED50?ooo`030:ZZZP000000EEEE00800000
00@0oooo0000001EEED0oooo0`1EEED0303oool000000000003oool0EEEE0?ooo`2ZZZX0oooo0000
001EEED0oooo00000080EEEE00D0oooo0:ZZZP000000EEEE0?ooo`02000000030?ooo`1EEED0EEEE
0080oooo00X0EEEE0000003oool000000?ooo`1EEED0oooo0:ZZZP3oool0ZZZZ0P3oool0102ZZZX0
EEEE05EEE@3oool205EEE@040:ZZZP3oool0oooo0?ooo`X0dLfY0`3oool20:ZZZP0505EEE@2ZZZX0
ZZZZ05EEE@0000000`3oool205EEE@070:ZZZP00000000000000001EEED000000?ooo`030:ZZZP06
0?ooo`000000ZZZZ0:ZZZP1EEED00000102ZZZX00`3oool0ZZZZ000000020?ooo`80ZZZZ00<0EEEE
0000001EEED00P2ZZZX01@000000oooo0:ZZZP3oool0ZZZZ0080oooo00<0EEEE0000003oool00P00
000205EEE@030000003oool0oooo0080EEEE0P2ZZZX205EEE@040:ZZZP3oool0oooo0?ooo`X0dLfY
0`3oool0102ZZZX000000:ZZZP1EEED20?ooo`0405EEE@000000ZZZZ05EEE@80oooo0P1EEED01`00
0000EEEE05EEE@000000EEEE0000002ZZZX01@00000205EEE@040000002ZZZX000000:ZZZP@0oooo
0P0000020:ZZZP80EEEE1@000000101EEED0000005EEE@00000205EEE@030000001EEED0oooo0080
oooo00@0EEEE0:ZZZP000000EEEE0P3oool010000000ZZZZ05EEE@2ZZZX30?ooo`X0dLfY0`3oool0
0`2ZZZX0EEEE05EEE@020?ooo`030:ZZZP1EEED0oooo0080EEEE00P0oooo0000001EEED0EEEE0?oo
o`1EEED0ZZZZ05EEE@@0oooo00<000000:ZZZP3oool00P1EEED0103oool0EEEE05EEE@3oool20:ZZ
ZP80oooo0P2ZZZX01@3oool0EEEE05EEE@3oool0EEEE00<0oooo00<000000?ooo`3oool00P3oool2
0:ZZZP0605EEE@3oool0EEEE0?ooo`000000oooo0P1EEED0103oool0EEEE0:ZZZP3oool305EEE@04
0:ZZZP3oool0oooo0?ooo`X0dLfY0`3oool01@2ZZZX0oooo0000002ZZZX0000000@0oooo0`1EEED0
0`3oool0ZZZZ0:ZZZP02000000060?ooo`000000oooo0:ZZZP3oool000000P1EEED00`3oool00000
00000002000000060:ZZZP000000000005EEE@2ZZZX000000P2ZZZX4000000040:ZZZP1EEED0EEEE
000000<0oooo100000020:ZZZP040000001EEED0EEEE000000@0oooo00D000000:ZZZP000000EEEE
0:ZZZP030?ooo``0dLfY000;0=7=Z@@0oooo00D0ZZZZ0000003oool0EEEE0?ooo`03000000<0oooo
00H0000005EEE@1EEED0ZZZZ05EEE@3oool305EEE@030000001EEED0EEEE00@0EEEE00<0oooo0000
003oool00P2ZZZX205EEE@030:ZZZP000000oooo008000000P1EEED01@2ZZZX0EEEE05EEE@1EEED0
000000<0EEEE00<0000005EEE@2ZZZX00P1EEED010000000oooo0?ooo`3oool200000080oooo00@0
EEEE000000000000ZZZZ103oool:0=7=Z@@0oooo0P2ZZZX0103oool0ZZZZ0?ooo`2ZZZX205EEE@03
0:ZZZP000000EEEE0080ZZZZ00@0EEEE0?ooo`1EEED000000P2ZZZX2000000050:ZZZP1EEED0ZZZZ
05EEE@2ZZZX00P0000020?ooo`0405EEE@000000ZZZZ0?ooo`8000000`3oool00`000000ZZZZ0?oo
o`030:ZZZP080000002ZZZX0ZZZZ0:ZZZP3oool0EEEE0?ooo`1EEED20:ZZZP0305EEE@000000ZZZZ
0080EEEE00@0ZZZZ0?ooo`2ZZZX0oooo0P2ZZZX40?ooo`X0dLfY103oool01P2ZZZX0EEEE05EEE@00
0000ZZZZ05EEE@80ZZZZ00<000000:ZZZP1EEED00P2ZZZX010000000ZZZZ0:ZZZP0000020:ZZZP03
05EEE@000000000000<0000000<0EEEE0?ooo`2ZZZX00P00000505EEE@<000000P3oool00`1EEED0
0000000000030000000405EEE@2ZZZX0ZZZZ0?ooo`80ZZZZ00@0oooo0:ZZZP000000EEEE102ZZZX0
1P1EEED0ZZZZ0000003oool0EEEE0:ZZZP@0oooo2P3AcJT40?ooo`0605EEE@3oool000000:ZZZP3o
ool0EEEE0P2ZZZX00`1EEED0ZZZZ0:ZZZP020?ooo`0905EEE@3oool0ZZZZ0?ooo`000000ZZZZ0000
002ZZZX0000000<0oooo00@0EEEE0:ZZZP2ZZZX0oooo0`1EEED00`3oool0EEEE05EEE@0205EEE@04
0?ooo`2ZZZX0ZZZZ05EEE@80oooo00`0ZZZZ0000002ZZZX0oooo0:ZZZP000000oooo0:ZZZP3oool0
EEEE0?ooo`0000020:ZZZP030?ooo`2ZZZX0ZZZZ0080oooo00@0ZZZZ0?ooo`3oool0ZZZZ103oool:
0=7=Z@@0oooo00D0EEEE0000002ZZZX000000:ZZZP0305EEE@030:ZZZP3oool0ZZZZ00@0EEEE00L0
ZZZZ05EEE@1EEED0ZZZZ0000001EEED0ZZZZ0080oooo0P1EEED03P2ZZZX0EEEE0:ZZZP1EEED0ZZZZ
0000003oool0ZZZZ0000002ZZZX0EEEE0:ZZZP1EEED0ZZZZ0P1EEED01P3oool0EEEE0:ZZZP1EEED0
00000:ZZZP80EEEE00<0ZZZZ05EEE@3oool00P1EEED00`2ZZZX0oooo05EEE@0205EEE@060000002Z
ZZX000000?ooo`000000ZZZZ103oool<0=7=Z@002`3AcJT50?ooo`030:ZZZP3oool0EEEE00800000
0P1EEED01@2ZZZX0EEEE05EEE@1EEED0ZZZZ0080000000L0oooo0000001EEED0EEEE0:ZZZP3oool0
ZZZZ00D0oooo0P1EEED30?ooo`0705EEE@2ZZZX0oooo0000003oool0EEEE0:ZZZP020?ooo`060:ZZ
ZP3oool0oooo0:ZZZP3oool000000P1EEED20?ooo`8000000P2ZZZX505EEE@80000000<0EEEE0:ZZ
ZP2ZZZX01@3oool:0=7=Z@D0oooo00@0ZZZZ0000003oool000000P2ZZZX01P000000oooo0:ZZZP2Z
ZZX0EEEE0:ZZZP80EEEE00<0oooo0:ZZZP2ZZZX00P2ZZZX30?ooo`040:ZZZP1EEED0EEEE05EEE@<0
ZZZZ0P1EEED00`2ZZZX0oooo05EEE@030:ZZZP<0EEEE00<0oooo0:ZZZP3oool00P3oool00`000000
ZZZZ0:ZZZP020?ooo`0305EEE@2ZZZX0ZZZZ00<0ZZZZ00<0EEEE0000002ZZZX00P0000000`3oool0
ZZZZ0:ZZZP050?ooo`X0dLfY1@3oool01@2ZZZX0oooo0:ZZZP3oool0ZZZZ00<0000000H0ZZZZ05EE
E@3oool0EEEE0:ZZZP0000040?ooo`030:ZZZP3oool0oooo0080EEEE0P3oool20:ZZZP040000001E
EED0EEEE0:ZZZP80oooo00<0ZZZZ0000001EEED00P0000001@2ZZZX0oooo0000001EEED000000080
oooo00L0ZZZZ0?ooo`3oool0EEEE0?ooo`000000ZZZZ00<0EEEE00@0ZZZZ00000000000000000P3o
ool30:ZZZPD0oooo2P3AcJT50?ooo`040:ZZZP000000ZZZZ0:ZZZPD0EEEE0P2ZZZX01`3oool0EEEE
0?ooo`2ZZZX0oooo05EEE@3oool00P0000001@3oool0EEEE0:ZZZP3oool0ZZZZ0080000000@0ZZZZ
0000001EEED0EEEE0P3oool02@1EEED000000000002ZZZX0oooo0000002ZZZX0EEEE0:ZZZP020?oo
o`80000000/0oooo05EEE@1EEED0ZZZZ0?ooo`1EEED0oooo05EEE@2ZZZX0EEEE0000000205EEE@05
0?ooo`2ZZZX0ZZZZ05EEE@2ZZZX01@3oool:0=7=Z@D0oooo00@0ZZZZ0?ooo`000000EEEE0`3oool0
0`1EEED0000005EEE@040?ooo`0505EEE@3oool0EEEE05EEE@3oool00P1EEED20:ZZZP030000003o
ool0oooo00<0oooo00@000000?ooo`1EEED00000103oool01P2ZZZX0oooo0?ooo`000000ZZZZ0000
0080EEEE00<0oooo05EEE@1EEED00P1EEED30?ooo`80EEEE00<0000005EEE@3oool00P3oool0101E
EED0000005EEE@2ZZZX50?ooo``0dLfY000;0=7=Z@H0oooo00@0EEEE0000001EEED000000P1EEED0
0`3oool0ZZZZ0:ZZZP020?ooo`0405EEE@000000000000000080EEEE0`3oool2000000<0oooo00/0
00000:ZZZP00000000000:ZZZP3oool0EEEE0:ZZZP1EEED000000:ZZZP040?ooo`8000000P3oool0
10000000EEEE05EEE@3oool3000000050?ooo`1EEED0ZZZZ0:ZZZP3oool00P1EEED0103oool0EEEE
0000002ZZZX60?ooo`X0dLfY1P3oool00`1EEED0ZZZZ05EEE@030:ZZZP060000003oool0oooo0?oo
o`2ZZZX0EEEE0`3oool01`2ZZZX0EEEE05EEE@2ZZZX0EEEE0:ZZZP1EEED00P0000000`3oool00000
0000000205EEE@80ZZZZ00@000000:ZZZP000000EEEE0P0000000`3oool000000?ooo`0305EEE@04
0:ZZZP3oool0EEEE0:ZZZP@0oooo0P2ZZZX20?ooo`0505EEE@2ZZZX0ZZZZ0:ZZZP1EEED00P2ZZZX6
0?ooo`X0dLfY1P3oool00`1EEED0000005EEE@020000000805EEE@00000000000:ZZZP000000EEEE
0:ZZZP1EEED20:ZZZP0505EEE@00000000000000003oool00P2ZZZX0103oool000000000003oool2
05EEE@030:ZZZP3oool0oooo0080oooo00@0ZZZZ05EEE@1EEED0ZZZZ0`000000302ZZZX000000?oo
o`000000ZZZZ0000001EEED000000:ZZZP1EEED0oooo05EEE@80ZZZZ0P0000001P1EEED000000:ZZ
ZP1EEED000000:ZZZPH0oooo2P3AcJT60?ooo`<0EEEE0P3oool205EEE@030?ooo`2ZZZX0ZZZZ00@0
oooo00P0ZZZZ05EEE@3oool000000?ooo`1EEED0oooo0:ZZZP<0EEEE00@0ZZZZ0000001EEED00000
1@3oool00`1EEED000000:ZZZP0205EEE@090?ooo`2ZZZX0EEEE05EEE@3oool0EEEE0?ooo`1EEED0
ZZZZ0080oooo00P000000?ooo`3oool0ZZZZ0?ooo`2ZZZX0EEEE0?ooo`<0EEEE00<0ZZZZ0?ooo`3o
ool0103oool:0=7=Z@H0oooo00<0EEEE0000003oool00`3oool00`1EEED0ZZZZ05EEE@060?ooo`04
0000003oool0oooo0?ooo`80EEEE00<0ZZZZ0000002ZZZX00P000000101EEED0ZZZZ000000000002
0:ZZZP80000000@0ZZZZ05EEE@1EEED00000102ZZZX0101EEED0oooo0?ooo`3oool2000000D0oooo
00<0EEEE0:ZZZP3oool0103oool00`000000ZZZZ0?ooo`050?ooo``0dLfY000;0=7=Z@H0oooo0P2Z
ZZX00`000000oooo05EEE@030?ooo`80ZZZZ0P0000000`1EEED000000?ooo`0205EEE@060000003o
ool0000005EEE@000000oooo0P0000001@3oool0EEEE0:ZZZP2ZZZX0EEEE0080oooo0P1EEED00`2Z
ZZX0EEEE00000006000000040?ooo`000000EEEE05EEE@8000000P1EEED00`000000EEEE0:ZZZP03
0?ooo`0405EEE@00000000000:ZZZPL0oooo2P3AcJT60?ooo`<0ZZZZ00H0oooo0:ZZZP3oool0oooo
05EEE@0000020?ooo`0505EEE@2ZZZX0EEEE0:ZZZP1EEED00P3oool0101EEED0ZZZZ05EEE@1EEED2
0:ZZZP0405EEE@3oool0EEEE05EEE@80oooo00<0ZZZZ0000003oool01@1EEED01P2ZZZX0EEEE05EE
E@000000ZZZZ05EEE@80oooo0`1EEED01@2ZZZX000000?ooo`3oool000000080EEEE00<0oooo0:ZZ
ZP3oool00P2ZZZX70?ooo`X0dLfY1P3oool20:ZZZP0305EEE@000000000000<0EEEE0P3oool00`00
0000ZZZZ0?ooo`020:ZZZP050?ooo`2ZZZX000000000001EEED00P2ZZZX0101EEED000000000002Z
ZZX205EEE@D0oooo00<0ZZZZ05EEE@1EEED00`0000030:ZZZP0@05EEE@00000000000:ZZZP3oool0
EEEE0:ZZZP3oool0EEEE0000002ZZZX0oooo05EEE@3oool0EEEE00000080EEEE00<0ZZZZ0?ooo`3o
ool01@3oool:0=7=Z@H0oooo00D0ZZZZ05EEE@3oool000000:ZZZP020?ooo`080:ZZZP000000EEEE
05EEE@000000ZZZZ0?ooo`0000020?ooo`0405EEE@000000EEEE00000080ZZZZ00<0oooo0:ZZZP00
00000P2ZZZX00`000000EEEE0?ooo`0205EEE@0;0?ooo`2ZZZX0ZZZZ05EEE@2ZZZX0oooo05EEE@2Z
ZZX0000005EEE@0000000`3oool010000000oooo0:ZZZP3oool205EEE@050000002ZZZX0ZZZZ0?oo
o`2ZZZX00P3oool00`1EEED0oooo0?ooo`050?ooo`X0dLfY1P3oool0102ZZZX0EEEE05EEE@2ZZZX2
0000000405EEE@3oool0EEEE00000080EEEE00L000000:ZZZP1EEED000000?ooo`000000ZZZZ0080
EEEE00<0ZZZZ05EEE@1EEED00P3oool01@1EEED0ZZZZ0000002ZZZX0EEEE00@0ZZZZ00@0EEEE0000
003oool0EEEE0P2ZZZX02@3oool0EEEE0:ZZZP000000oooo0000001EEED0ZZZZ0000000205EEE@04
0:ZZZP1EEED0oooo0:ZZZP<000000P1EEED70?ooo``0dLfY000;0=7=Z@P0oooo00<0ZZZZ0?ooo`1E
EED00P0000000`1EEED0000005EEE@020:ZZZP050?ooo`2ZZZX0ZZZZ0:ZZZP1EEED00P0000001@3o
ool0EEEE05EEE@3oool0EEEE00<000000P3oool010000000EEEE0000000000020?ooo`050000001E
EED0000005EEE@0000000P1EEED01`3oool0000005EEE@1EEED0ZZZZ05EEE@2ZZZX00P3oool20:ZZ
ZP050000001EEED000000000001EEED00P2ZZZX80?ooo`X0dLfY203oool01@2ZZZX000000?ooo`00
0000ZZZZ0080oooo00@0ZZZZ000000000000EEEE0`3oool02@2ZZZX000000?ooo`3oool0EEEE0?oo
o`1EEED0oooo05EEE@020:ZZZP030?ooo`1EEED0EEEE0080ZZZZ0P1EEED0103oool0ZZZZ05EEE@1E
EED70?ooo`040:ZZZP3oool0oooo0?ooo`80EEEE00@0000005EEE@3oool0oooo0P0000000`3oool0
ZZZZ0:ZZZP080?ooo`X0dLfY203oool03@2ZZZX0oooo0?ooo`2ZZZX0oooo0:ZZZP3oool000000:ZZ
ZP000000oooo0000001EEED00P3oool02P1EEED0oooo0000001EEED000000:ZZZP1EEED0ZZZZ05EE
E@2ZZZX80?ooo`<0ZZZZ0P1EEED01@000000ZZZZ0000003oool0EEEE0080oooo0P0000001@3oool0
00000:ZZZP2ZZZX0oooo00<0ZZZZ00<0oooo0:ZZZP2ZZZX0203oool:0=7=Z@P0oooo00h0ZZZZ0000
002ZZZX0ZZZZ05EEE@2ZZZX0EEEE0:ZZZP000000ZZZZ0?ooo`2ZZZX0EEEE0?ooo`80ZZZZ0P3oool0
0`1EEED0ZZZZ0?ooo`020?ooo`80ZZZZ00@0oooo0:ZZZP1EEED0oooo0P1EEED00`2ZZZX0oooo0:ZZ
ZP040?ooo`0;0:ZZZP1EEED0oooo0?ooo`1EEED0ZZZZ0?ooo`1EEED0ZZZZ0?ooo`1EEED00P000000
0`1EEED0ZZZZ0?ooo`020:ZZZP0305EEE@2ZZZX0oooo00L0oooo2P3AcJT80?ooo`030:ZZZP000000
oooo0080ZZZZ00<0000005EEE@2ZZZX00`2ZZZX305EEE@030:ZZZP000000oooo00@0oooo10000002
0:ZZZP0305EEE@000000ZZZZ0080EEEE00<0ZZZZ0000000000000`0000050?ooo`070:ZZZP1EEED0
EEEE05EEE@2ZZZX0EEEE0:ZZZP0205EEE@80000000@0ZZZZ0?ooo`1EEED0ZZZZ203oool<0=7=Z@00
2`3AcJT90?ooo`0405EEE@000000EEEE00000080EEEE00`0oooo000000000000oooo0000002ZZZX0
oooo05EEE@3oool0000005EEE@2ZZZX205EEE@030000001EEED0EEEE00@0000000<0oooo05EEE@00
00000`000000203oool0EEEE0000002ZZZX0EEEE0:ZZZP1EEED000000P1EEED20?ooo`050000003o
ool0oooo0000002ZZZX00P1EEED0103oool0EEEE0000002ZZZX90?ooo`X0dLfY2@3oool00`1EEED0
ZZZZ05EEE@020:ZZZP090000001EEED0oooo0?ooo`1EEED0oooo05EEE@3oool000000080EEEE00H0
ZZZZ05EEE@1EEED0EEEE0000003oool2000000030:ZZZP3oool0ZZZZ00D0ZZZZ0P0000000`3oool0
00000:ZZZP0205EEE@070:ZZZP1EEED0oooo0000003oool000000?ooo`0205EEE@030?ooo`2ZZZX0
00000080ZZZZ00<0EEEE0:ZZZP2ZZZX02@3oool:0=7=Z@T0oooo00@0EEEE0000002ZZZX000000P3o
ool01@2ZZZX000000000001EEED0ZZZZ00<0EEEE00<0ZZZZ05EEE@0000000P2ZZZX0101EEED00000
0?ooo`00000:05EEE@80oooo00<0000005EEE@2ZZZX00P00000405EEE@80ZZZZ00<0EEEE00000000
00000`3oool010000000ZZZZ0000002ZZZX90?ooo`X0dLfY2@3oool305EEE@80oooo00<0ZZZZ05EE
E@1EEED00`3oool0102ZZZX0oooo0000001EEED20:ZZZP060?ooo`2ZZZX000000:ZZZP000000ZZZZ
0P3oool0102ZZZX0oooo0?ooo`1EEED50?ooo`050000002ZZZX0oooo0:ZZZP1EEED00P2ZZZX20000
00050?ooo`2ZZZX0oooo0?ooo`2ZZZX00P1EEED00`2ZZZX0oooo05EEE@0205EEE@030:ZZZP3oool0
oooo00L0oooo2P3AcJT90?ooo`80EEEE0P0000001`1EEED0oooo05EEE@1EEED0oooo0:ZZZP3oool0
0P2ZZZX02P3oool000000000003oool000000?ooo`1EEED0ZZZZ05EEE@2ZZZX205EEE@060?ooo`2Z
ZZX0ZZZZ05EEE@2ZZZX0oooo101EEED01@2ZZZX000000?ooo`000000oooo0080000000L0oooo0:ZZ
ZP2ZZZX0oooo0:ZZZP3oool0EEEE0080oooo00D0EEEE000000000000EEEE0:ZZZP090?ooo``0dLfY
000;0=7=Z@X0oooo00<0ZZZZ05EEE@2ZZZX00`00000205EEE@80ZZZZ00@0EEEE0000002ZZZX0ZZZZ
0P0000020?ooo`80000000<0EEEE0?ooo`1EEED00P0000000`2ZZZX0EEEE0:ZZZP020:ZZZP050000
001EEED0EEEE05EEE@0000000P3oool300000080ZZZZ0P0000020:ZZZP030?ooo`1EEED0oooo0080
00000P1EEED00`2ZZZX0oooo0?ooo`080?ooo`X0dLfY2P3oool00`2ZZZX0EEEE0000000205EEE@05
0:ZZZP00000000000?ooo`0000000`2ZZZX205EEE@<0ZZZZ00P0oooo05EEE@1EEED0EEEE0:ZZZP3o
ool0ZZZZ05EEE@80ZZZZ00D0EEEE0?ooo`3oool0ZZZZ0000000205EEE@040000002ZZZX0EEEE0:ZZ
ZP80EEEE0`2ZZZX01@000000oooo0?ooo`000000ZZZZ0080EEEE00<0oooo05EEE@2ZZZX02P3oool:
0=7=Z@X0oooo01P0ZZZZ05EEE@1EEED0ZZZZ05EEE@2ZZZX0EEEE0:ZZZP000000oooo0000002ZZZX0
000005EEE@000000EEEE0:ZZZP000000EEEE0:ZZZP1EEED0oooo0:ZZZP3oool30:ZZZP040000002Z
ZZX0ZZZZ0?ooo`80ZZZZ00<0EEEE0:ZZZP2ZZZX00P0000002@1EEED0000005EEE@000000ZZZZ0000
003oool000000:ZZZP0305EEE@040:ZZZP1EEED0EEEE0:ZZZPX0oooo2P3AcJT:0?ooo`0<0:ZZZP1E
EED0ZZZZ0000001EEED0oooo0:ZZZP000000ZZZZ0000002ZZZX0oooo0P00000205EEE@040?ooo`2Z
ZZX0ZZZZ00000080oooo0P2ZZZX00`3oool0ZZZZ05EEE@020:ZZZP0605EEE@2ZZZX0ZZZZ05EEE@3o
ool000000P2ZZZX405EEE@070000003oool0oooo0000002ZZZX0oooo0:ZZZP0205EEE@040000002Z
ZZX0EEEE0:ZZZPX0oooo2P3AcJT:0?ooo`030:ZZZP1EEED0oooo00@0oooo00<0EEEE0:ZZZP1EEED0
0P3oool02@000000oooo0:ZZZP1EEED0oooo0:ZZZP1EEED000000:ZZZP05000000040?ooo`2ZZZX0
00000?ooo`80000000X0oooo0:ZZZP000000EEEE0:ZZZP3oool0EEEE0:ZZZP3oool000000P3oool0
0`1EEED0ZZZZ05EEE@040?ooo`030000001EEED0ZZZZ00X0oooo303AcJT000/0dLfY2`3oool00`2Z
ZZX0oooo05EEE@0200000080EEEE00P0oooo0:ZZZP1EEED000000?ooo`000000oooo05EEE@<00000
00@0EEEE0?ooo`1EEED0EEEE0P3oool01P1EEED0oooo0:ZZZP1EEED000000?ooo`80EEEE00<0oooo
05EEE@3oool00P000000201EEED0oooo0?ooo`3oool0000005EEE@2ZZZX0oooo0P1EEED200000003
05EEE@2ZZZX0ZZZZ00/0oooo2P3AcJT;0?ooo`060:ZZZP000000oooo0000002ZZZX000000P1EEED4
0:ZZZP090?ooo`2ZZZX0ZZZZ0?ooo`1EEED0ZZZZ0000001EEED0ZZZZ00<0oooo102ZZZX30?ooo`05
0:ZZZP1EEED000000:ZZZP1EEED0202ZZZX00`1EEED0oooo00000002000000030?ooo`2ZZZX0ZZZZ
00/0oooo2P3AcJT;0?ooo`040:ZZZP3oool0ZZZZ0?ooo`80ZZZZ00<0oooo0000002ZZZX00`2ZZZX0
101EEED0ZZZZ0:ZZZP0000020?ooo`060:ZZZP1EEED000000:ZZZP000000EEEE0P0000001@1EEED0
000005EEE@000000ZZZZ0080EEEE0P2ZZZX20?ooo`80ZZZZ00L0EEEE0:ZZZP2ZZZX0EEEE0:ZZZP00
0000oooo0080ZZZZ00@0oooo0:ZZZP2ZZZX0ZZZZ2`3oool:0=7=Z@/0oooo00@0ZZZZ0000002ZZZX0
ZZZZ0P1EEED00`000000oooo0000000205EEE@80oooo00<0EEEE0:ZZZP1EEED00`1EEED0102ZZZX0
oooo0000000000030?ooo`030:ZZZP3oool0oooo008000000P2ZZZX305EEE@050?ooo`2ZZZX0EEEE
0000003oool00P1EEED01@000000oooo05EEE@1EEED0oooo0080ZZZZ00<0EEEE0:ZZZP3oool02P3o
ool:0=7=Z@/0oooo00H0ZZZZ05EEE@000000ZZZZ0000002ZZZX20?ooo`030:ZZZP000000ZZZZ00<0
EEEE0`3oool00`1EEED0oooo0000000205EEE@030:ZZZP000000oooo0080EEEE00P0oooo05EEE@2Z
ZZX0EEEE0:ZZZP000000oooo0:ZZZP<0oooo0`1EEED02`2ZZZX0EEEE0:ZZZP3oool0EEEE0:ZZZP00
0000ZZZZ0000001EEED0ZZZZ00/0oooo303AcJT000/0dLfY303oool01@1EEED0000005EEE@000000
EEEE00<0oooo00L0ZZZZ05EEE@1EEED0EEEE0:ZZZP000000EEEE008000000P1EEED01@000000EEEE
05EEE@2ZZZX000000080oooo00<0000005EEE@1EEED0101EEED2000000030?ooo`000000ZZZZ00<0
EEEE00<0ZZZZ0?ooo`3oool00P1EEED0103oool0EEEE0000002ZZZX<0?ooo`X0dLfY303oool00`1E
EED0ZZZZ05EEE@020:ZZZP<0EEEE0P0000000`1EEED000000?ooo`020?ooo`0:05EEE@2ZZZX0oooo
0000001EEED000000?ooo`000000oooo0:ZZZP80oooo00<0EEEE0?ooo`0000000P0000020?ooo`04
05EEE@000000oooo0?ooo`80EEEE0P00000305EEE@80ZZZZ00<0EEEE0:ZZZP2ZZZX0303oool:0=7=
Z@`0oooo00X0EEEE0000001EEED0oooo05EEE@000000EEEE0000003oool0ZZZZ0`3oool00`2ZZZX0
0000000000020?ooo`0<0:ZZZP3oool000000?ooo`2ZZZX0oooo05EEE@000000oooo0:ZZZP3oool0
00000P2ZZZX20?ooo`0@0000001EEED0ZZZZ0?ooo`1EEED0oooo0:ZZZP1EEED0000005EEE@2ZZZX0
EEEE0:ZZZP1EEED000000:ZZZP`0oooo2P3AcJT<0?ooo`<0EEEE0P3oool0102ZZZX0EEEE0:ZZZP3o
ool20:ZZZP0905EEE@00000000000:ZZZP1EEED0oooo0000003oool000000080ZZZZ00H000000:ZZ
ZP3oool0oooo0:ZZZP0000020:ZZZP060000003oool000000?ooo`1EEED0oooo0P0000001@1EEED0
ZZZZ0:ZZZP1EEED0ZZZZ0080EEEE00D0oooo05EEE@1EEED0EEEE0:ZZZP0<0?ooo`X0dLfY303oool0
1@1EEED0oooo0000002ZZZX0000000<0oooo0P1EEED00`3oool0EEEE0?ooo`030?ooo`030:ZZZP1E
EED000000080ZZZZ00H0oooo0000001EEED0oooo0:ZZZP1EEED20?ooo`040:ZZZP3oool0000005EE
E@L0oooo00<0EEEE0:ZZZP3oool00P3oool01@000000ZZZZ0000003oool0ZZZZ00`0oooo303AcJT0
00/0dLfY3@3oool01@2ZZZX0EEEE0:ZZZP000000oooo00<0000000L0EEEE0:ZZZP3oool0oooo0:ZZ
ZP3oool0000000@0EEEE00D000000?ooo`3oool0ZZZZ0?ooo`020:ZZZP80oooo00@000000?ooo`1E
EED0EEEE0P0000020:ZZZP80oooo00<0ZZZZ05EEE@3oool01000000205EEE@030:ZZZP3oool0oooo
00/0oooo2P3AcJT=0?ooo`050:ZZZP1EEED0000005EEE@2ZZZX00P3oool01`000000ZZZZ0:ZZZP2Z
ZZX000000?ooo`1EEED0102ZZZX0101EEED0000005EEE@00000205EEE@060?ooo`1EEED0ZZZZ05EE
E@000000EEEE102ZZZX00`000000oooo000000030:ZZZP<0oooo0P1EEED00`3oool0EEEE0:ZZZP0=
0?ooo`X0dLfY3@3oool00`2ZZZX0EEEE0:ZZZP030:ZZZP050000001EEED0ZZZZ0:ZZZP0000000P2Z
ZZX2000000030?ooo`2ZZZX0EEEE0080ZZZZ0`0000020:ZZZP<000000P2ZZZX01@1EEED0ZZZZ0:ZZ
ZP000000oooo00H0ZZZZ00@000000:ZZZP2ZZZX0ZZZZ0P1EEED00`2ZZZX0oooo0?ooo`0;0?ooo`X0
dLfY3@3oool0102ZZZX0EEEE0:ZZZP00000205EEE@80000000D0EEEE0?ooo`3oool000000?ooo`02
05EEE@050?ooo`1EEED0EEEE0000001EEED00P3oool0201EEED0oooo0?ooo`1EEED0ZZZZ0?ooo`1E
EED0ZZZZ0P1EEED02P3oool0EEEE05EEE@3oool000000:ZZZP3oool0EEEE0:ZZZP00000205EEE@04
0000002ZZZX0EEEE0:ZZZPd0oooo2P3AcJT=0?ooo`050:ZZZP1EEED000000000001EEED00P3oool0
3`2ZZZX00000000000000000ZZZZ0000003oool000000:ZZZP000000oooo0000001EEED0oooo0:ZZ
ZP040?ooo`030:ZZZP3oool0EEEE0080oooo1@0000001@2ZZZX00000000000000000EEEE0080oooo
0P00000205EEE@030:ZZZP3oool0oooo00/0oooo303AcJT000/0dLfY3P3oool00`2ZZZX0oooo05EE
E@020000000305EEE@2ZZZX0ZZZZ00@0oooo00@0EEEE0000001EEED0oooo0P1EEED0103oool00000
0?ooo`0000020?ooo`<0000000<0oooo05EEE@1EEED00P3oool00`000000ZZZZ0?ooo`030?ooo`03
0:ZZZP000000EEEE0080000000<0EEEE0:ZZZP2ZZZX03P3oool:0=7=Z@h0oooo00@0ZZZZ0000003o
ool000000`2ZZZX00`3oool0EEEE0?ooo`0205EEE@030:ZZZP3oool0ZZZZ0080oooo00P000000?oo
o`2ZZZX0ZZZZ05EEE@3oool0000005EEE@80ZZZZ00<0oooo0000003oool00`3oool01`2ZZZX0EEEE
05EEE@2ZZZX0EEEE0?ooo`0000000P2ZZZX010000000oooo0:ZZZP2ZZZX>0?ooo`X0dLfY3P3oool0
1@2ZZZX0oooo0?ooo`3oool0EEEE0080ZZZZ0`0000020?ooo`040000001EEED0EEEE0:ZZZP80oooo
00<0EEEE0:ZZZP1EEED01P2ZZZX01`1EEED0ZZZZ0?ooo`2ZZZX0000005EEE@0000000P3oool00`2Z
ZZX00000000000020:ZZZP0305EEE@2ZZZX0oooo0080ZZZZ3P3oool:0=7=Z@h0oooo00L0ZZZZ0000
002ZZZX0oooo05EEE@2ZZZX000000080oooo00H0ZZZZ0000002ZZZX0EEEE0?ooo`0000020?ooo`80
00000P1EEED40?ooo`80EEEE0P0000020?ooo`050:ZZZP3oool0oooo0:ZZZP0000000`3oool00`1E
EED0ZZZZ05EEE@020:ZZZP0305EEE@2ZZZX0oooo00d0oooo2P3AcJT>0?ooo`030:ZZZP3oool00000
00<0oooo0P1EEED00`2ZZZX0EEEE0:ZZZP020:ZZZP050000002ZZZX0EEEE05EEE@0000000P3oool0
0`2ZZZX000000?ooo`02000000<0oooo0`1EEED00`2ZZZX00000000000020:ZZZP0305EEE@2ZZZX0
EEEE00<0oooo00@0EEEE0000001EEED0ZZZZ3P3oool<0=7=Z@002`3AcJT?0?ooo`0605EEE@000000
oooo0000001EEED0ZZZZ1@3oool20:ZZZPL0EEEE00D000000?ooo`00000000000:ZZZP0205EEE@05
0?ooo`1EEED0EEEE0000002ZZZX01P3oool205EEE@040000001EEED000000:ZZZPl0oooo2P3AcJT?
0?ooo`0305EEE@2ZZZX0ZZZZ0080ZZZZ00<0EEEE0?ooo`0000000P2ZZZX00`3oool0EEEE0?ooo`02
05EEE@<0ZZZZ0P0000020:ZZZP0=05EEE@2ZZZX000000000002ZZZX0EEEE0:ZZZP1EEED000000?oo
o`2ZZZX0oooo0:ZZZP02000000050?ooo`2ZZZX0ZZZZ0:ZZZP1EEED00P2ZZZX?0?ooo`X0dLfY3`3o
ool0101EEED000000000001EEED20?ooo`80EEEE00L0ZZZZ0000001EEED0ZZZZ05EEE@3oool00000
0080oooo00D0000005EEE@000000oooo000000020?ooo`80EEEE0P000000203oool0000005EEE@1E
EED0ZZZZ05EEE@000000oooo0P1EEED01P2ZZZX0oooo05EEE@2ZZZX000000:ZZZPl0oooo2P3AcJT?
0?ooo`<0EEEE0P3oool205EEE@050?ooo`1EEED0EEEE0:ZZZP0000000P1EEED20:ZZZP0605EEE@2Z
ZZX0EEEE0?ooo`1EEED000000P1EEED0103oool0EEEE0:ZZZP1EEED20:ZZZP80EEEE00L000000:ZZ
ZP1EEED0EEEE0?ooo`1EEED0ZZZZ0080oooo0P1EEED00`2ZZZX0oooo0?ooo`0=0?ooo`X0dLfY3`3o
ool00`1EEED000000?ooo`030?ooo`0405EEE@2ZZZX0ZZZZ0:ZZZP80EEEE1@2ZZZX20000000405EE
E@2ZZZX0EEEE05EEE@80ZZZZ0P0000030:ZZZP0405EEE@2ZZZX0ZZZZ05EEE@<0ZZZZ00<0EEEE0?oo
o`3oool00P3oool00`000000ZZZZ0?ooo`0>0?ooo``0dLfY000;0=7=ZA00oooo00L0ZZZZ05EEE@2Z
ZZX000000?ooo`000000EEEE0080000000<0EEEE0?ooo`0000000P1EEED010000000ZZZZ0?ooo`3o
ool20:ZZZP030?ooo`2ZZZX0ZZZZ00@0oooo00<0000005EEE@0000000P000000101EEED000000?oo
o`1EEED3000000030:ZZZP1EEED0ZZZZ0100oooo2P3AcJT@0?ooo`0;0:ZZZP3oool0000005EEE@2Z
ZZX000000:ZZZP1EEED000000?ooo`2ZZZX0103oool305EEE@060000001EEED0ZZZZ0?ooo`1EEED0
ZZZZ0P1EEED02`000000oooo0?ooo`2ZZZX0oooo0:ZZZP3oool000000?ooo`2ZZZX000000080EEEE
00<0000005EEE@2ZZZX0403oool:0=7=ZA00oooo00<0ZZZZ05EEE@1EEED00P2ZZZX405EEE@80oooo
00<0EEEE0:ZZZP2ZZZX00P0000001@3oool0ZZZZ05EEE@1EEED0oooo0080EEEE00<0oooo0:ZZZP3o
ool00P0000020:ZZZP0305EEE@2ZZZX0oooo00@0EEEE0P2ZZZX205EEE@030:ZZZP3oool0oooo00h0
oooo2P3AcJT@0?ooo`<0ZZZZ00@0000005EEE@3oool0ZZZZ0P3oool2000000050?ooo`000000oooo
0:ZZZP1EEED00P2ZZZX205EEE@040:ZZZP3oool0EEEE05EEE@80ZZZZ00D000000:ZZZP3oool00000
0?ooo`0200000080oooo00L0ZZZZ0?ooo`1EEED000000:ZZZP1EEED0ZZZZ0100oooo2P3AcJT@0?oo
o`050:ZZZP3oool000000:ZZZP0000000P3oool01@000000oooo000000000000oooo00<0000000<0
EEEE0:ZZZP2ZZZX00P1EEED0103oool0EEEE05EEE@1EEED20:ZZZP0405EEE@00000000000:ZZZP80
oooo00<000000?ooo`3oool00P3oool20:ZZZP030000001EEED0ZZZZ0100oooo303AcJT000/0dLfY
4@3oool00`2ZZZX0oooo05EEE@0200000080EEEE00@0ZZZZ05EEE@1EEED000000P1EEED00`000000
oooo0?ooo`020?ooo`040:ZZZP3oool0oooo0:ZZZP<0oooo0P0000001P1EEED0oooo0000002ZZZX0
EEEE0:ZZZP80EEEE0P0000000`1EEED0oooo0:ZZZP0A0?ooo`X0dLfY4@3oool01@2ZZZX000000?oo
o`000000ZZZZ0080oooo0P1EEED20?ooo`050000001EEED0oooo0:ZZZP1EEED00P0000002P3oool0
EEEE0000003oool0ZZZZ0000001EEED000000?ooo`1EEED20?ooo`030:ZZZP1EEED0EEEE0080oooo
00D0ZZZZ0000003oool000000:ZZZP0A0?ooo`X0dLfY4@3oool0102ZZZX0oooo0:ZZZP3oool40:ZZ
ZP0;0000001EEED0EEEE0?ooo`1EEED0ZZZZ05EEE@2ZZZX000000?ooo`1EEED00P3oool00`1EEED0
0000000000030:ZZZP0705EEE@2ZZZX0EEEE05EEE@000000ZZZZ000000020:ZZZP040?ooo`2ZZZX0
oooo0:ZZZQ40oooo2P3AcJTA0?ooo`0405EEE@000000ZZZZ0?ooo`80EEEE00<0000005EEE@1EEED0
0P1EEED0103oool0EEEE05EEE@2ZZZX20?ooo`060:ZZZP3oool0EEEE05EEE@3oool0ZZZZ0P3oool3
05EEE@030000001EEED0ZZZZ00D0EEEE0P2ZZZX00`000000ZZZZ0?ooo`0@0?ooo`X0dLfY4@3oool0
201EEED000000?ooo`000000ZZZZ0000001EEED0ZZZZ0P0000020:ZZZP80EEEE00D0oooo05EEE@1E
EED0oooo000000020?ooo`050000003oool0EEEE05EEE@2ZZZX00`1EEED20:ZZZP040000002ZZZX0
EEEE00000080ZZZZ00<0oooo0000002ZZZX04@3oool<0=7=Z@002`3AcJTB0?ooo`80ZZZZ00<00000
0?ooo`1EEED0103oool0101EEED0oooo0?ooo`3oool80000000405EEE@000000000005EEE@80oooo
0P1EEED01`2ZZZX0oooo0?ooo`3oool0EEEE0?ooo`0000000P2ZZZXB0?ooo`X0dLfY4P3oool20:ZZ
ZP80oooo00@0ZZZZ0000003oool0oooo0P0000001`3oool0EEEE0:ZZZP2ZZZX0000005EEE@3oool0
0P2ZZZX01@1EEED0ZZZZ0?ooo`1EEED000000080ZZZZ00<0EEEE0?ooo`000000103oool00`2ZZZX0
oooo0:ZZZP020:ZZZQ80oooo2P3AcJTB0?ooo`80ZZZZ00<0EEEE0000000000000`1EEED010000000
ZZZZ05EEE@2ZZZX200000080EEEE00<0oooo0:ZZZP0000000P2ZZZX305EEE@060:ZZZP000000ZZZZ
0000002ZZZX000000`1EEED20000000305EEE@2ZZZX0ZZZZ0180oooo2P3AcJTB0?ooo`040:ZZZP1E
EED0oooo00000080ZZZZ00<0oooo0:ZZZP1EEED00P1EEED00`2ZZZX0EEEE0000000205EEE@030:ZZ
ZP3oool0ZZZZ0080oooo0`1EEED00`3oool0EEEE0:ZZZP0205EEE@090000002ZZZX0oooo0?ooo`2Z
ZZX000000?ooo`1EEED0ZZZZ0180oooo2P3AcJTB0?ooo`040:ZZZP1EEED0000005EEE@<0oooo00D0
EEEE0:ZZZP1EEED000000:ZZZP040?ooo`0605EEE@2ZZZX0EEEE05EEE@2ZZZX0EEEE103oool01@2Z
ZZX0EEEE05EEE@2ZZZX0EEEE00<0oooo00@0EEEE0?ooo`1EEED0ZZZZ4P3oool<0=7=Z@002`3AcJTC
0?ooo`050:ZZZP1EEED0ZZZZ0000003oool00P0000020?ooo`<0EEEE00H0oooo0000001EEED0EEEE
0000001EEED30000000305EEE@000000EEEE00<0EEEE0P3oool4000000030:ZZZP1EEED0ZZZZ01<0
oooo2P3AcJTC0?ooo`040:ZZZP3oool0000005EEE@80ZZZZ00<000000:ZZZP1EEED01@1EEED30?oo
o`80ZZZZ0`3oool02@1EEED0000005EEE@1EEED0ZZZZ05EEE@2ZZZX000000:ZZZP0205EEE@030000
001EEED0ZZZZ01<0oooo2P3AcJTC0?ooo`0:0:ZZZP1EEED0ZZZZ0:ZZZP1EEED0ZZZZ05EEE@3oool0
EEEE0:ZZZP80000000D0EEEE0?ooo`3oool000000:ZZZP02000000050:ZZZP1EEED0oooo0?ooo`1E
EED00P0000001P2ZZZX0EEEE05EEE@1EEED0ZZZZ05EEE@80ZZZZ00<0EEEE0:ZZZP3oool04P3oool:
0=7=ZA<0oooo0`2ZZZX01`000000EEEE05EEE@000000ZZZZ0?ooo`2ZZZX00P3oool0301EEED0ZZZZ
0?ooo`2ZZZX000000:ZZZP3oool0000005EEE@3oool0ZZZZ05EEE@80oooo00@0ZZZZ0?ooo`2ZZZX0
00000P1EEED010000000ZZZZ05EEE@2ZZZXC0?ooo`X0dLfY4`3oool00`2ZZZX000000?ooo`040?oo
o`0305EEE@3oool0EEEE0080000000<0EEEE0000002ZZZX00P3oool20:ZZZP050?ooo`1EEED0ZZZZ
0000002ZZZX00P0000020?ooo`0305EEE@3oool0oooo00<0oooo00<0EEEE0:ZZZP3oool04P3oool<
0=7=Z@002`3AcJTD0?ooo`030:ZZZP3oool0EEEE0080000000<0EEEE0:ZZZP1EEED00P1EEED01000
0000EEEE05EEE@2ZZZX2000000030?ooo`1EEED000000080ZZZZ0P1EEED01P000000EEEE0000001E
EED0000005EEE@80000000<0EEEE0?ooo`2ZZZX0503oool:0=7=ZA@0oooo00L0ZZZZ0000003oool0
00000:ZZZP000000oooo0080ZZZZ00H0oooo0:ZZZP1EEED000000:ZZZP0000060:ZZZP040000002Z
ZZX0ZZZZ0?ooo`80ZZZZ00L0oooo0000002ZZZX000000?ooo`000000ZZZZ01@0oooo2P3AcJTD0?oo
o`090:ZZZP3oool0oooo0:ZZZP3oool0EEEE0?ooo`000000EEEE008000000`3oool205EEE@800000
00D0EEEE0?ooo`3oool0oooo05EEE@020000000605EEE@000000000005EEE@3oool0ZZZZ0P3oool0
0`2ZZZX0oooo0?ooo`0B0?ooo`X0dLfY503oool02@1EEED000000:ZZZP3oool0EEEE0:ZZZP000000
ZZZZ05EEE@020:ZZZP050?ooo`2ZZZX0oooo0?ooo`0000000P1EEED2000000030?ooo`2ZZZX0EEEE
0080ZZZZ00D000000:ZZZP1EEED0ZZZZ05EEE@020:ZZZP030000002ZZZX0oooo01<0oooo2P3AcJTD
0?ooo`80EEEE0`0000001P2ZZZX0oooo0?ooo`3oool0EEEE00000080ZZZZ00@000000?ooo`3oool0
ZZZZ0`3oool01@000000ZZZZ0?ooo`000000EEEE0080oooo00L0EEEE0:ZZZP000000ZZZZ0000001E
EED0ZZZZ01@0oooo303AcJT000/0dLfY5@3oool20:ZZZP050000003oool0EEEE0?ooo`0000000P1E
EED00`000000oooo0?ooo`02000000@0EEEE0P000000103oool000000000001EEED2000000040?oo
o`1EEED0oooo00000080ZZZZ5@3oool:0=7=ZAD0oooo0P2ZZZX20?ooo`<0ZZZZ00L000000:ZZZP3o
ool0ZZZZ05EEE@3oool000000080EEEE00L0000005EEE@000000oooo05EEE@2ZZZX0oooo00<0ZZZZ
00<0oooo0:ZZZP3oool00`2ZZZXE0?ooo`X0dLfY5@3oool20:ZZZP040?ooo`1EEED0EEEE0:ZZZP<0
EEEE00L0ZZZZ0000002ZZZX0EEEE0:ZZZP1EEED0oooo0080EEEE00D0000005EEE@2ZZZX0EEEE0:ZZ
ZP0705EEE@80ZZZZ5@3oool:0=7=ZAD0oooo00L0ZZZZ05EEE@3oool000000:ZZZP3oool0EEEE00<0
oooo00<0ZZZZ05EEE@0000000P2ZZZX20?ooo`040:ZZZP3oool0000005EEE@<0oooo00P0ZZZZ05EE
E@3oool0ZZZZ0000003oool0EEEE0:ZZZQD0oooo2P3AcJTE0?ooo`040:ZZZP1EEED0oooo0:ZZZP80
0000101EEED20?ooo`060:ZZZP3oool0EEEE0000003oool0EEEE0P2ZZZX00`3oool0ZZZZ05EEE@03
05EEE@060:ZZZP000000ZZZZ0000001EEED0ZZZZ5@3oool<0=7=Z@002`3AcJTF0?ooo`060:ZZZP1E
EED0ZZZZ0000003oool000000P3oool00`1EEED0oooo00000003000000040?ooo`2ZZZX0000005EE
E@<0000000<0EEEE0?ooo`1EEED00`0000000`2ZZZX0EEEE0:ZZZP0F0?ooo`X0dLfY5P3oool01P2Z
ZZX0oooo0000001EEED0ZZZZ0?ooo`<0ZZZZ00@000000:ZZZP1EEED0oooo0P1EEED01P3oool0EEEE
05EEE@1EEED0ZZZZ00000080ZZZZ00L0EEEE0?ooo`1EEED0EEEE0000001EEED0ZZZZ01H0oooo2P3A
cJTF0?ooo`070:ZZZP1EEED0EEEE0:ZZZP1EEED0000005EEE@020?ooo`0505EEE@000000EEEE05EE
E@2ZZZX00P1EEED00`2ZZZX0oooo05EEE@02000000<0oooo00<0000005EEE@2ZZZX00P1EEED00`2Z
ZZX0oooo0?ooo`0D0?ooo`X0dLfY5P3oool30:ZZZP090000001EEED0oooo0?ooo`000000ZZZZ0?oo
o`000000oooo0080EEEE00D0oooo05EEE@1EEED0EEEE0?ooo`02000000090:ZZZP000000ZZZZ0?oo
o`1EEED000000:ZZZP1EEED0ZZZZ01H0oooo2P3AcJTF0?ooo`090:ZZZP1EEED000000000001EEED0
oooo05EEE@2ZZZX0oooo0080000000<0ZZZZ0?ooo`3oool00P0000020?ooo`050:ZZZP000000ZZZZ
0?ooo`2ZZZX00P3oool30000000305EEE@2ZZZX0oooo01D0oooo303AcJT000/0dLfY5`3oool01P2Z
ZZX0EEEE0000003oool0000005EEE@80oooo00`000000?ooo`000000ZZZZ05EEE@3oool0000005EE
E@2ZZZX000000?ooo`1EEED20?ooo`0505EEE@000000EEEE0000001EEED0603oool:0=7=ZAL0oooo
00<0ZZZZ05EEE@2ZZZX00`2ZZZX01P000000EEEE0?ooo`2ZZZX0oooo00000080ZZZZ00P0EEEE0:ZZ
ZP000000oooo0:ZZZP000000EEEE00000080ZZZZ00<0EEEE0:ZZZP1EEED0603oool:0=7=ZAL0oooo
00D0ZZZZ05EEE@000000ZZZZ0?ooo`02000000060?ooo`000000ZZZZ05EEE@3oool0ZZZZ0P3oool0
0`2ZZZX0EEEE05EEE@020:ZZZP070?ooo`000000EEEE0?ooo`1EEED0000005EEE@0H0?ooo`X0dLfY
5`3oool01`2ZZZX0EEEE05EEE@1EEED0oooo05EEE@2ZZZX00P1EEED03@3oool0ZZZZ0?ooo`2ZZZX0
EEEE0000002ZZZX0oooo0:ZZZP3oool0ZZZZ05EEE@2ZZZX00P3oool305EEEAP0oooo2P3AcJTG0?oo
o`030:ZZZP1EEED0000000@0oooo0`1EEED02`2ZZZX0oooo0?ooo`3oool0EEEE0?ooo`1EEED0ZZZZ
05EEE@2ZZZX0EEEE00@0oooo00<0000005EEE@3oool05`3oool<0=7=Z@002`3AcJTH0?ooo`80ZZZZ
00<000000?ooo`3oool00P3oool00`1EEED000000:ZZZP020:ZZZP80EEEE0`2ZZZX01`000000oooo
0?ooo`3oool0EEEE0?ooo`0000000P2ZZZXH0?ooo`X0dLfY603oool20:ZZZP<0oooo0P1EEED01@3o
ool000000?ooo`1EEED0oooo0080ZZZZ00@0oooo05EEE@3oool000000`1EEED00`2ZZZX0oooo0:ZZ
ZP020:ZZZQP0oooo2P3AcJTH0?ooo`80ZZZZ00D0EEEE0000002ZZZX0EEEE0:ZZZP02000000030:ZZ
ZP000000EEEE00<0EEEE0P2ZZZX2000000050:ZZZP1EEED0ZZZZ0000001EEED00P2ZZZXH0?ooo`X0
dLfY603oool01P2ZZZX0EEEE0?ooo`000000oooo0:ZZZP80oooo00@0ZZZZ0000001EEED000000P2Z
ZZX00`000000EEEE000000020:ZZZP070?ooo`2ZZZX0ZZZZ0000003oool0EEEE0:ZZZP0H0?ooo`X0
dLfY603oool01P2ZZZX0EEEE0000002ZZZX000000:ZZZP80EEEE00@0ZZZZ0?ooo`00000000000P3o
ool02@000000oooo0?ooo`2ZZZX0oooo05EEE@2ZZZX000000:ZZZP0205EEE@030:ZZZP3oool0oooo
01H0oooo303AcJT000/0dLfY6@3oool01@2ZZZX0EEEE0:ZZZP000000oooo00800000102ZZZX00`1E
EED0ZZZZ0:ZZZP030:ZZZP80000000D0oooo0000002ZZZX0EEEE0:ZZZP0I0?ooo`X0dLfY6@3oool0
2P2ZZZX0oooo0000001EEED0ZZZZ0000002ZZZX0EEEE0:ZZZP0000040:ZZZP0:05EEE@2ZZZX0EEEE
05EEE@000000ZZZZ05EEE@000000EEEE0:ZZZQT0oooo2P3AcJTI0?ooo`030:ZZZP1EEED0ZZZZ0080
ZZZZ0P0000001@1EEED0000005EEE@3oool0EEEE0080oooo00<0EEEE0000001EEED00P0000030:ZZ
ZP0305EEE@2ZZZX0oooo01P0oooo2P3AcJTI0?ooo`<0ZZZZ0`1EEED0102ZZZX0000005EEE@2ZZZX4
05EEE@040?ooo`1EEED0000000000080EEEE00@000000:ZZZP1EEED0ZZZZ6@3oool:0=7=ZAT0oooo
00D0ZZZZ0?ooo`000000ZZZZ000000020?ooo`050000002ZZZX000000000002ZZZX00`0000002@2Z
ZZX000000?ooo`3oool000000:ZZZP000000EEEE0:ZZZP0I0?ooo``0dLfY000;0=7=ZAX0oooo00L0
ZZZZ05EEE@1EEED0oooo0000001EEED0ZZZZ0080000000`0ZZZZ0?ooo`1EEED0ZZZZ05EEE@000000
ZZZZ05EEE@000000oooo0000001EEEDK0?ooo`X0dLfY6P3oool00`2ZZZX0EEEE05EEE@020:ZZZP80
000000<0oooo0:ZZZP2ZZZX0102ZZZX00`3oool000000:ZZZP030:ZZZP0305EEE@3oool0oooo01T0
oooo2P3AcJTJ0?ooo`090:ZZZP1EEED0ZZZZ0000002ZZZX0EEEE0:ZZZP000000oooo0080ZZZZ00L0
00000:ZZZP3oool000000:ZZZP1EEED0ZZZZ0080000000<0EEEE0?ooo`3oool06@3oool:0=7=ZAX0
oooo00H0ZZZZ05EEE@1EEED0EEEE0?ooo`2ZZZX705EEE@030?ooo`1EEED0EEEE0080oooo0`1EEEDK
0?ooo`X0dLfY6P3oool00`2ZZZX0EEEE0000000200000080oooo0P2ZZZX20?ooo`060:ZZZP3oool0
EEEE0:ZZZP3oool0EEEE0P00000205EEEA/0oooo303AcJT000/0dLfY6`3oool00`2ZZZX000000000
00020?ooo`0405EEE@2ZZZX0ZZZZ05EEE@80oooo0P1EEED01@2ZZZX0EEEE05EEE@3oool000000080
ZZZZ6`3oool:0=7=ZA/0oooo0P2ZZZX30?ooo`030000002ZZZX0ZZZZ00H0ZZZZ00@000000:ZZZP3o
ool0oooo0P2ZZZXK0?ooo`X0dLfY6`3oool00`2ZZZX0EEEE0?ooo`0305EEE@050000003oool00000
0:ZZZP3oool00`000000101EEED0ZZZZ05EEE@3oool20:ZZZQ/0oooo2P3AcJTK0?ooo`040:ZZZP3o
ool0oooo00000080oooo00<0EEEE0:ZZZP3oool00P2ZZZX02@3oool0ZZZZ05EEE@3oool0ZZZZ0000
003oool0EEEE0:ZZZP0K0?ooo`X0dLfY6`3oool0102ZZZX0oooo0000001EEED30?ooo`0405EEE@2Z
ZZX0oooo00000080ZZZZ0`3oool0101EEED0000005EEE@2ZZZXK0?ooo``0dLfY000;0=7=ZA`0oooo
0P2ZZZX00`3oool00000000000020?ooo`040000001EEED0000000000080oooo00@0000005EEE@3o
ool0ZZZZ7@3oool:0=7=ZA`0oooo0P2ZZZX30000000<0:ZZZP000000EEEE05EEE@000000EEEE0000
002ZZZX000000?ooo`000000ZZZZ7@3oool:0=7=ZA`0oooo0P2ZZZX01P3oool0EEEE0000001EEED0
ZZZZ0?ooo`80000000L0oooo05EEE@1EEED000000:ZZZP3oool0ZZZZ01d0oooo2P3AcJTL0?ooo`05
0:ZZZP1EEED000000:ZZZP3oool00P1EEED0103oool0EEEE05EEE@3oool205EEE@040?ooo`2ZZZX0
000005EEEAd0oooo2P3AcJTL0?ooo`080:ZZZP1EEED0EEEE0:ZZZP000000EEEE0000003oool20:ZZ
ZP030?ooo`2ZZZX0EEEE008000000P1EEEDM0?ooo``0dLfY000;0=7=ZAd0oooo00<0ZZZZ05EEE@1E
EED0100000000`3oool0EEEE000000040000000305EEE@2ZZZX0oooo01`0oooo2P3AcJTM0?ooo`03
0:ZZZP1EEED0EEEE0080ZZZZ00@0EEEE0:ZZZP3oool000001@2ZZZX00`1EEED0ZZZZ0?ooo`0L0?oo
o`X0dLfY7@3oool01P2ZZZX0EEEE05EEE@3oool0EEEE0?ooo`@0000000H0oooo05EEE@3oool00000
05EEE@2ZZZXM0?ooo`X0dLfY7@3oool0202ZZZX0EEEE05EEE@1EEED0oooo05EEE@2ZZZX0oooo0P2Z
ZZX20?ooo`<0EEEE00<0ZZZZ0?ooo`3oool06`3oool:0=7=ZAd0oooo00<0ZZZZ05EEE@0000000P2Z
ZZX205EEE@030?ooo`1EEED0EEEE00<0ZZZZ00<0oooo05EEE@2ZZZX07@3oool<0=7=Z@002`3AcJTN
0?ooo`060:ZZZP000000oooo05EEE@000000EEEE0P3oool0101EEED0000005EEE@3oool20:ZZZQh0
oooo2P3AcJTN0?ooo`80ZZZZ0`3oool20:ZZZP0305EEE@2ZZZX0ZZZZ0080oooo0P2ZZZXN0?ooo`X0
dLfY7P3oool01P2ZZZX0EEEE05EEE@1EEED0000005EEE@80000000@0EEEE0:ZZZP1EEED0EEEE0P2Z
ZZXN0?ooo`X0dLfY7P3oool01P2ZZZX0oooo0?ooo`000000oooo0:ZZZP80oooo0P2ZZZX010000000
oooo05EEE@2ZZZXN0?ooo`X0dLfY7P3oool01P2ZZZX000000?ooo`2ZZZX0oooo00000080oooo00H0
00000?ooo`2ZZZX0oooo05EEE@2ZZZXN0?ooo``0dLfY000;0=7=ZAl0oooo0P2ZZZX0103oool00000
05EEE@3oool205EEE@030000003oool0ZZZZ0200oooo2P3AcJTO0?ooo`80ZZZZ0`0000020:ZZZP04
0000003oool000000:ZZZR00oooo2P3AcJTO0?ooo`80ZZZZ00@0oooo0000002ZZZX0EEEE0P2ZZZX0
0`1EEED0oooo0:ZZZP0P0?ooo`X0dLfY7`3oool02`2ZZZX0EEEE0000002ZZZX0oooo0:ZZZP1EEED0
oooo0:ZZZP000000EEEE0200oooo2P3AcJTO0?ooo`030:ZZZP1EEED0oooo0080EEEE00H0oooo0:ZZ
ZP1EEED000000?ooo`1EEEDP0?ooo``0dLfY000;0=7=ZB00oooo00@0ZZZZ05EEE@3oool0EEEE0P3o
ool0101EEED0000005EEE@2ZZZXP0?ooo`X0dLfY803oool00`2ZZZX0EEEE05EEE@050:ZZZP0305EE
E@2ZZZX0oooo01l0oooo2P3AcJTP0?ooo`0:0:ZZZP1EEED0oooo0:ZZZP1EEED0oooo0:ZZZP000000
EEEE0:ZZZR00oooo2P3AcJTP0?ooo`060:ZZZP1EEED0EEEE05EEE@2ZZZX0oooo0`1EEED00`2ZZZX0
oooo0?ooo`0N0?ooo`X0dLfY803oool02P2ZZZX0EEEE0?ooo`3oool0ZZZZ0000003oool0000005EE
E@2ZZZXP0?ooo``0dLfY000;0=7=ZB40oooo00<0ZZZZ0000001EEED00`1EEED20:ZZZR40oooo2P3A
cJTQ0?ooo`80ZZZZ00@0oooo0:ZZZP3oool0oooo0P2ZZZXQ0?ooo`X0dLfY8@3oool01P2ZZZX0EEEE
0000002ZZZX0EEEE00000080ZZZZ8@3oool:0=7=ZB40oooo00<0ZZZZ0?ooo`3oool00P1EEED00`3o
ool0EEEE0:ZZZP0Q0?ooo`X0dLfY8@3oool0202ZZZX0EEEE0000003oool0EEEE0000001EEED0ZZZZ
8@3oool<0=7=Z@002`3AcJTR0?ooo`80ZZZZ00<0000005EEE@2ZZZX08`3oool:0=7=ZB80oooo0P2Z
ZZX00`3oool000000:ZZZP0S0?ooo`X0dLfY8P3oool20:ZZZP0305EEE@000000ZZZZ02<0oooo2P3A
cJTR0?ooo`050:ZZZP1EEED0ZZZZ0000001EEED08`3oool:0=7=ZB80oooo00D0ZZZZ05EEE@3oool0
000005EEE@0S0?ooo``0dLfY000;0=7=ZB<0oooo0P2ZZZX00`1EEED0ZZZZ0?ooo`0R0?ooo`X0dLfY
8`3oool20:ZZZP0305EEE@2ZZZX0oooo0280oooo2P3AcJTS0?ooo`80ZZZZ00<0EEEE0:ZZZP3oool0
8P3oool:0=7=ZB<0oooo00@0ZZZZ05EEE@1EEED0ZZZZ8`3oool:0=7=ZB<0oooo00@0ZZZZ05EEE@1E
EED0ZZZZ8`3oool<0=7=Z@002`3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`03
0:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`03
0:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo303AcJT00?l0dLfY
/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY
/P3AcJT000/0dLfY00<0oooo0:ZZZP2ZZZX00P3oool0202ZZZX0EEEE0000003oool0ZZZZ05EEE@3o
ool0EEEE103oool305EEE@040000003oool0EEEE0?ooo`80EEEE00H0oooo00000000000000000?oo
o`1EEED200000080ZZZZ0P3oool0102ZZZX0oooo0000000000020?ooo`<0000000<0oooo05EEE@1E
EED00P1EEED00`3oool0ZZZZ05EEE@0205EEE@@0oooo00H0EEEE0?ooo`1EEED0ZZZZ0?ooo`000002
0:ZZZP80oooo0P2ZZZX00`3oool0dLfY0=7=Z@080=7=Z@030?ooo`2ZZZX0ZZZZ0080oooo00@0ZZZZ
05EEE@00000000000P1EEED01P3oool0ZZZZ0:ZZZP1EEED0oooo0:ZZZP80oooo00@000000?ooo`2Z
ZZX0oooo0P1EEED200000080oooo00@0EEEE0?ooo`1EEED0ZZZZ0P1EEED0102ZZZX0EEEE0000002Z
ZZX205EEE@80ZZZZ00l0oooo05EEE@000000oooo0:ZZZP000000EEEE0:ZZZP3oool0ZZZZ05EEE@00
0000oooo0000002ZZZX00P1EEED0102ZZZX000000?ooo`1EEED30000000405EEE@2ZZZX0oooo0?oo
o`80ZZZZ00<0oooo0=7=Z@3AcJT0203AcJT00`3oool0ZZZZ0:ZZZP020?ooo`@0ZZZZ0P1EEED01`00
0000ZZZZ05EEE@3oool0EEEE0000001EEED01@2ZZZX01P000000ZZZZ0000001EEED0oooo05EEE@80
oooo0P1EEED02@2ZZZX0oooo0000002ZZZX0EEEE0000001EEED0ZZZZ05EEE@030?ooo`0605EEE@3o
ool0oooo0000002ZZZX000001@2ZZZX0101EEED000000?ooo`3oool205EEE@030000001EEED00000
0080ZZZZ00@0oooo0:ZZZP3oool0oooo0P2ZZZX00`3oool0dLfY0=7=Z@080=7=Z@030?ooo`2ZZZX0
00000080oooo0P2ZZZX00`3oool0EEEE0?ooo`0205EEE@030?ooo`2ZZZX0oooo0080oooo00X00000
0:ZZZP3oool0oooo0000001EEED0000005EEE@2ZZZX0oooo0P0000001@3oool0ZZZZ0?ooo`3oool0
EEEE00H0oooo00@0EEEE0?ooo`3oool0ZZZZ0P3oool01`000000EEEE0:ZZZP1EEED0oooo05EEE@00
00000P3oool01`2ZZZX0EEEE0?ooo`2ZZZX0oooo0:ZZZP3oool00P1EEED00`3oool0EEEE0?ooo`02
0:ZZZP0505EEE@3oool000000:ZZZP3oool02P3AcJT01@3oool0ZZZZ0000001EEED000000080oooo
00<0EEEE0?ooo`0000000P0000001P1EEED000000000003oool0EEEE0:ZZZP80oooo00D0ZZZZ0?oo
o`3oool0EEEE0?ooo`0205EEE@80oooo1@0000001@1EEED0ZZZZ0000003oool0ZZZZ00<0000000<0
oooo0000000000000`3oool00`1EEED0oooo05EEE@020?ooo`060:ZZZP3oool0oooo0000001EEED0
ZZZZ1P0000002@3oool0EEEE05EEE@3oool0000005EEE@000000ZZZZ0?ooo`0<0=7=Z@002`3AcJT0
0`3oool0ZZZZ0?ooo`040?ooo`040:ZZZP0000000000000000H0oooo00H000000?ooo`000000ZZZZ
0?ooo`1EEED20?ooo`0705EEE@000000EEEE0000001EEED000000?ooo`0205EEE@030:ZZZP3oool0
000000<0oooo0P1EEED01`3oool0000005EEE@000000EEEE0?ooo`1EEED00P3oool01P1EEED0oooo
000000000000oooo000000@0oooo00D0EEEE0?ooo`000000ZZZZ000000020:ZZZP030?ooo`000000
oooo00<0oooo2P3AcJT00`3oool0ZZZZ0?ooo`030?ooo`040:ZZZP3oool000000?ooo`80ZZZZ0P1E
EED00`2ZZZX0EEEE05EEE@030:ZZZP040000001EEED0oooo0?ooo`80ZZZZ00D0EEEE0?ooo`000000
00000?ooo`020:ZZZP090000002ZZZX000000?ooo`2ZZZX0000005EEE@000000ZZZZ0080oooo00@0
00000:ZZZP3oool0EEEE0`2ZZZX00`3oool0EEEE05EEE@030:ZZZP0405EEE@000000ZZZZ05EEE@@0
ZZZZ00D000000?ooo`2ZZZX0oooo000000040?ooo`X0dLfY00<0oooo0:ZZZP3oool00`3oool02@1E
EED000000:ZZZP3oool0EEEE0?ooo`000000EEEE0?ooo`0205EEE@080000001EEED0ZZZZ0000002Z
ZZX0EEEE0000001EEED20:ZZZPD0oooo00@0EEEE0000002ZZZX0ZZZZ0P1EEED20:ZZZP030000001E
EED0oooo0080oooo00l0EEEE0?ooo`2ZZZX0ZZZZ05EEE@000000EEEE0:ZZZP000000ZZZZ05EEE@3o
ool0EEEE0:ZZZP3oool00P1EEED0203oool0EEEE0000002ZZZX000000:ZZZP3oool00000103oool:
0=7=Z@040?ooo`2ZZZX0EEEE05EEE@D0oooo0P1EEED01P000000oooo0:ZZZP1EEED0oooo000000D0
ZZZZ00D000000?ooo`1EEED0oooo0:ZZZP0205EEE@80ZZZZ00L0EEEE0:ZZZP000000oooo0000001E
EED0ZZZZ00<00000102ZZZX205EEE@030:ZZZP3oool0EEEE0080000000@0ZZZZ05EEE@2ZZZX0ZZZZ
0P0000000`2ZZZX0EEEE0:ZZZP0200000080EEEE0P3oool00`000000oooo0?ooo`0205EEE@80oooo
2P3AcJT00`3oool0ZZZZ05EEE@0200000080ZZZZ0P0000000`3oool0000005EEE@020000000305EE
E@2ZZZX0000000<0oooo00H000000?ooo`2ZZZX000000:ZZZP3oool4000000040?ooo`2ZZZX0ZZZZ
00000080oooo00P000000:ZZZP3oool0EEEE0000002ZZZX000000?ooo`<0000000D0ZZZZ0?ooo`2Z
ZZX000000:ZZZP040?ooo`80000000D0oooo05EEE@000000ZZZZ05EEE@04000000050?ooo`2ZZZX0
EEEE0000001EEED00P3oool<0=7=Z@002`3AcJT30?ooo`80ZZZZ103oool010000000oooo0000002Z
ZZX205EEE@040?ooo`1EEED0EEEE0?ooo`80EEEE1@3oool205EEE@040:ZZZP3oool0000005EEE@@0
oooo0P2ZZZX40?ooo`8000000P3oool00`1EEED0oooo0?ooo`040?ooo`80EEEE00@0oooo05EEE@1E
EED0ZZZZ0P1EEED0102ZZZX000000?ooo`2ZZZX40?ooo`80ZZZZ0`3oool:0=7=Z@<0oooo0P2ZZZX3
0?ooo`040:ZZZP000000EEEE05EEE@<0oooo00<0EEEE0?ooo`0000000P1EEED0303oool0ZZZZ0?oo
o`3oool0EEEE0?ooo`000000oooo0000001EEED0000005EEE@80oooo00<0EEEE0:ZZZP0000000P2Z
ZZX30?ooo`0305EEE@000000EEEE0080oooo00L0ZZZZ0?ooo`1EEED0EEEE0?ooo`2ZZZX0oooo0080
EEEE00<0ZZZZ0?ooo`1EEED00`3oool205EEE@80ZZZZ0`3oool20:ZZZP<0oooo2P3AcJT30?ooo`80
ZZZZ0`3oool01`1EEED000000?ooo`000000oooo0:ZZZP1EEED00P000000102ZZZX0EEEE05EEE@2Z
ZZX205EEE@050:ZZZP000000EEEE0000003oool02@2ZZZX00`3oool0ZZZZ000000050:ZZZP0505EE
E@3oool0000005EEE@0000000`1EEED00`2ZZZX0EEEE05EEE@0200000080EEEE00<0ZZZZ00000000
00000P3oool0101EEED0oooo0?ooo`3oool20:ZZZP<0oooo2P3AcJT30?ooo`040:ZZZP000000oooo
05EEE@80oooo0`1EEED02`3oool0ZZZZ05EEE@3oool0000005EEE@3oool0ZZZZ05EEE@2ZZZX0oooo
00<0ZZZZ0P1EEED30?ooo`030:ZZZP3oool0ZZZZ0080ZZZZ0P3oool01@2ZZZX0oooo0:ZZZP3oool0
000000<0oooo0P1EEED30:ZZZP0;0?ooo`2ZZZX0ZZZZ0:ZZZP3oool0EEEE0000002ZZZX0EEEE0:ZZ
ZP0000000P1EEED50?ooo`0305EEE@2ZZZX0oooo0080oooo2P3AcJT30?ooo`030:ZZZP0000000000
0080000000T0oooo05EEE@2ZZZX0oooo05EEE@000000ZZZZ0?ooo`1EEED00P0000001`3oool0EEEE
0:ZZZP2ZZZX0oooo0:ZZZP3oool00P0000000`2ZZZX0EEEE05EEE@020:ZZZP0305EEE@2ZZZX0oooo
0080000000@0oooo05EEE@1EEED0ZZZZ0`1EEED0102ZZZX000000000003oool40:ZZZP040000003o
ool000000?ooo`80EEEE00L0ZZZZ0000001EEED0oooo0:ZZZP1EEED0oooo00<0000000<0EEEE0:ZZ
ZP3oool00P3oool<0=7=Z@002`3AcJT90?ooo`040:ZZZP000000ZZZZ0?ooo`80ZZZZ303oool0101E
EED0ZZZZ0?ooo`1EEED50?ooo`030:ZZZP3oool0oooo00<0oooo0P1EEED20?ooo`0305EEE@3oool0
oooo00@0oooo00@0EEEE0?ooo`3oool0EEEE0P3oool20:ZZZP030?ooo`2ZZZX0000000<0oooo00<0
00000?ooo`2ZZZX0103oool:0=7=Z@X0oooo0P000000103oool000000?ooo`1EEED20?ooo`800000
00D0oooo0000001EEED0EEEE000000020:ZZZP050?ooo`2ZZZX0ZZZZ0?ooo`0000000`3oool00`00
0000oooo05EEE@0200000080oooo00P000000?ooo`2ZZZX0EEEE0?ooo`000000ZZZZ00000080EEEE
00D000000?ooo`00000000000:ZZZP030?ooo`050000003oool000000000002ZZZX00P3oool00`00
0000oooo0:ZZZP040?ooo`X0dLfY2@3oool40:ZZZP80oooo0`0000020:ZZZP050000002ZZZX0ZZZZ
0:ZZZP1EEED00`2ZZZX01`000000EEEE05EEE@000000ZZZZ05EEE@0000000P3oool01@000000oooo
0000001EEED0ZZZZ00<0EEEE0P2ZZZX0101EEED0ZZZZ05EEE@0000020:ZZZP060000002ZZZX0ZZZZ
05EEE@000000EEEE0P3oool0101EEED0ZZZZ0:ZZZP1EEED20?ooo`030000003oool0ZZZZ00@0oooo
2P3AcJT40?ooo`090:ZZZP000000ZZZZ0:ZZZP1EEED0ZZZZ0?ooo`2ZZZX000000080oooo0P2ZZZX2
000000060?ooo`2ZZZX0ZZZZ0:ZZZP3oool0ZZZZ0`3oool305EEE@040000003oool0ZZZZ0:ZZZP@0
oooo00@0EEEE0:ZZZP3oool0oooo0`1EEED01@3oool0EEEE0?ooo`2ZZZX0EEEE0080ZZZZ0P3oool2
000000040:ZZZP1EEED0oooo0?ooo`80ZZZZ00L0oooo0:ZZZP1EEED0ZZZZ0?ooo`000000ZZZZ00@0
oooo2P3AcJT40?ooo`0:0:ZZZP00000000000000003oool0ZZZZ0?ooo`1EEED0000005EEE@80ZZZZ
0P0000000`3oool000000:ZZZP020?ooo`0805EEE@2ZZZX0oooo0000003oool0ZZZZ0?ooo`2ZZZX2
0?ooo`030:ZZZP3oool0EEEE00<0EEEE0P2ZZZX0203oool0ZZZZ0:ZZZP3oool0EEEE0?ooo`000000
oooo0P2ZZZX20?ooo`030:ZZZP000000oooo0080000000<0oooo0:ZZZP1EEED00P1EEED01`3oool0
ZZZZ0?ooo`000000EEEE0000002ZZZX0103oool<0=7=Z@002`3AcJT50?ooo`80ZZZZ0P3oool305EE
E@80oooo00<0ZZZZ05EEE@3oool0103oool305EEE@0;0?ooo`1EEED0EEEE05EEE@000000oooo0000
001EEED0oooo05EEE@2ZZZX00P3oool0101EEED0oooo0000001EEED20?ooo`080000003oool0ZZZZ
05EEE@2ZZZX0EEEE0?ooo`2ZZZX205EEE@D0oooo00@0EEEE0:ZZZP3oool0oooo0P1EEED30?ooo`80
ZZZZ1@3oool:0=7=Z@D0oooo0P2ZZZX20?ooo`D0EEEE00H0oooo05EEE@1EEED0ZZZZ0000003oool3
0:ZZZP0705EEE@2ZZZX000000?ooo`000000oooo05EEE@020?ooo`<0EEEE1@3oool305EEE@080?oo
o`1EEED0ZZZZ0000001EEED000000:ZZZP3oool20:ZZZP80oooo00<000000:ZZZP1EEED00P3oool0
101EEED0oooo05EEE@1EEED30?ooo`80ZZZZ1@3oool:0=7=Z@D0oooo0P2ZZZX20?ooo`80EEEE00P0
00000:ZZZP1EEED0ZZZZ05EEE@3oool000000:ZZZP80EEEE0P2ZZZX0101EEED000000000001EEED4
0?ooo`0705EEE@00000000000000002ZZZX0oooo05EEE@020:ZZZP<000000P3oool00`1EEED0oooo
0?ooo`02000000@0ZZZZ00<0EEEE0:ZZZP3oool00P3oool01@2ZZZX0EEEE0?ooo`000000EEEE00<0
oooo0P2ZZZX50?ooo`X0dLfY1@3oool00`2ZZZX0oooo000000020?ooo`80000000<0oooo05EEE@3o
ool00P3oool0102ZZZX0oooo0?ooo`2ZZZX20?ooo`0305EEE@2ZZZX0EEEE0080oooo00T0000005EE
E@3oool0EEEE0?ooo`2ZZZX0oooo05EEE@3oool00`1EEED0102ZZZX0oooo0?ooo`3oool205EEE@03
0?ooo`2ZZZX0EEEE0080ZZZZ0P3oool0101EEED0oooo0?ooo`2ZZZX30?ooo`0305EEE@3oool00000
0080000000@0oooo0000002ZZZX0ZZZZ1@3oool:0=7=Z@D0oooo00<0ZZZZ0000000000000`3oool0
1`000000oooo0?ooo`000000oooo0000003oool00P2ZZZX40?ooo`060:ZZZP3oool0oooo0000002Z
ZZX0oooo100000001@3oool0ZZZZ0?ooo`3oool0ZZZZ00D000000P3oool010000000EEEE0?ooo`2Z
ZZX40?ooo`80ZZZZ0P0000000`2ZZZX000000?ooo`02000000<0oooo00<000000:ZZZP2ZZZX01@3o
ool<0=7=Z@002`3AcJT80?ooo`030000003oool0EEEE00@0oooo00@0ZZZZ0?ooo`2ZZZX0EEEE0P3o
ool01@1EEED0oooo0:ZZZP2ZZZX000000080EEEE0`0000030?ooo`0605EEE@00000000000?ooo`00
0000EEEE0P3oool00`1EEED000000000000305EEE@070000002ZZZX0oooo0?ooo`1EEED000000?oo
o`0205EEE@030?ooo`2ZZZX0oooo00<0oooo00D0EEEE0?ooo`000000oooo0:ZZZP060?ooo`X0dLfY
203oool010000000oooo05EEE@3oool200000080oooo00P0EEEE0000001EEED0000005EEE@2ZZZX0
EEEE00000080ZZZZ00D0000005EEE@3oool0oooo05EEE@0200000080oooo00<000000?ooo`3oool0
0P0000001P3oool000000:ZZZP1EEED0oooo00000080EEEE0P2ZZZX205EEE@060:ZZZP1EEED00000
05EEE@3oool0EEEE0P3oool020000000oooo0?ooo`1EEED0oooo0000003oool0ZZZZ1P3oool:0=7=
Z@P0oooo00L000000?ooo`1EEED0oooo0:ZZZP000000ZZZZ0080oooo00<000000:ZZZP0000000P1E
EED02P000000EEEE0:ZZZP2ZZZX0oooo0000001EEED0ZZZZ0?ooo`1EEED20:ZZZP8000000P2ZZZX0
2P000000EEEE0:ZZZP2ZZZX0EEEE0?ooo`2ZZZX0oooo0000001EEED20:ZZZP0605EEE@000000EEEE
0:ZZZP000000ZZZZ0P3oool02P1EEED0ZZZZ0000001EEED0oooo05EEE@3oool000000?ooo`2ZZZX6
0?ooo`X0dLfY1P3oool01@1EEED000000?ooo`1EEED0ZZZZ0080EEEE103oool00`2ZZZX0EEEE0:ZZ
ZP030?ooo`<0ZZZZ0P3oool00`1EEED00000000000020:ZZZP0505EEE@3oool0oooo0?ooo`1EEED0
0P3oool00`1EEED0ZZZZ0?ooo`02000000<0oooo0P2ZZZX30?ooo`80ZZZZ00<0EEEE0?ooo`3oool0
0`3oool205EEE@050:ZZZP000000oooo0000002ZZZX01P3oool:0=7=Z@H0oooo00<0EEEE00000000
00000`0000001`3oool0EEEE05EEE@3oool000000?ooo`2ZZZX01P3oool01@2ZZZX000000000002Z
ZZX0oooo00<0000000<0EEEE0:ZZZP3oool00`3oool01@000000EEEE0000001EEED000000080oooo
0P0000000`2ZZZX0oooo0?ooo`040?ooo`040:ZZZP00000000000:ZZZP<0EEEE1@0000000`2ZZZX0
oooo0?ooo`040?ooo``0dLfY000;0=7=Z@H0oooo00`0ZZZZ05EEE@3oool0ZZZZ0?ooo`2ZZZX0EEEE
0:ZZZP1EEED0000005EEE@3oool20:ZZZP0=05EEE@3oool0oooo0?ooo`2ZZZX0oooo0000003oool0
000005EEE@000000oooo05EEE@03000000060?ooo`1EEED000000?ooo`000000EEEE0P0000001P1E
EED000000?ooo`000000oooo0:ZZZP<0oooo0`2ZZZX02`3oool0EEEE05EEE@1EEED0ZZZZ05EEE@2Z
ZZX0oooo05EEE@3oool0EEEE00L0oooo2P3AcJT60?ooo`070:ZZZP1EEED0oooo0:ZZZP3oool0ZZZZ
0?ooo`0405EEE@80000000<0oooo0:ZZZP3oool00P3oool00`1EEED00000000000020:ZZZP080?oo
o`1EEED000000:ZZZP3oool0EEEE0000002ZZZX20000000:05EEE@3oool0ZZZZ0?ooo`1EEED0oooo
05EEE@2ZZZX0oooo00000080EEEE0P3oool00`2ZZZX0oooo0000000205EEE@090000001EEED0EEEE
05EEE@2ZZZX0oooo05EEE@3oool0EEEE00L0oooo2P3AcJT60?ooo`070:ZZZP1EEED0oooo0:ZZZP3o
ool0ZZZZ05EEE@02000000<0ZZZZ00@0EEEE0000003oool0EEEE0P3oool20000000305EEE@2ZZZX0
ZZZZ0080oooo00<0EEEE0000001EEED00P2ZZZX00`000000EEEE0:ZZZP0205EEE@040000003oool0
oooo0?ooo`80ZZZZ00H0oooo000000000000EEEE0?ooo`1EEED20000000405EEE@2ZZZX0ZZZZ0:ZZ
ZP80000000H0EEEE0:ZZZP3oool0EEEE0?ooo`1EEED70?ooo`X0dLfY1P3oool20:ZZZP060000001E
EED0oooo0:ZZZP3oool0ZZZZ0`0000000`2ZZZX0oooo0:ZZZP040?ooo`030000003oool0oooo0080
oooo00<0EEEE0000002ZZZX00P3oool205EEE@80oooo0P1EEED30?ooo`030000001EEED0oooo00<0
oooo00<000000?ooo`3oool00P3oool01P2ZZZX0oooo0?ooo`000000oooo000000<0ZZZZ0P3oool0
0`000000ZZZZ0?ooo`060?ooo`X0dLfY1P3oool20:ZZZP<000000P3oool01@1EEED0oooo0000002Z
ZZX0000000P0oooo00D0EEEE0000002ZZZX0oooo000000020:ZZZP030000003oool0oooo00<0oooo
0P0000000`2ZZZX00000000000020?ooo`800000203oool20:ZZZP80oooo0P1EEED01@3oool00000
05EEE@000000ZZZZ00L0oooo303AcJT000/0dLfY203oool01`2ZZZX0oooo0000003oool0ZZZZ0?oo
o`1EEED00P2ZZZX305EEE@80oooo0P2ZZZX01@1EEED00000000000000000EEEE0080oooo00@00000
0:ZZZP000000EEEE1@3oool00`000000ZZZZ05EEE@030?ooo`040000002ZZZX0000005EEE@80ZZZZ
00P0oooo05EEE@1EEED0EEEE0?ooo`2ZZZX0000005EEE@<0oooo00<000000?ooo`2ZZZX0203oool:
0=7=Z@P0oooo00D0ZZZZ0?ooo`000000oooo0:ZZZP020?ooo`060:ZZZP000000oooo05EEE@2ZZZX0
00000P2ZZZX01@3oool0EEEE000000000000oooo0080ZZZZ0P0000003P1EEED0ZZZZ0?ooo`000000
ZZZZ05EEE@000000EEEE0:ZZZP1EEED0ZZZZ0000002ZZZX000000P3oool00`000000EEEE0:ZZZP02
0:ZZZP0505EEE@2ZZZX0EEEE05EEE@0000001@3oool00`000000oooo0:ZZZP080?ooo`X0dLfY203o
ool01P2ZZZX0oooo0000003oool0ZZZZ0?ooo`80EEEE00H0oooo05EEE@3oool000000?ooo`1EEED2
0:ZZZP8000001`2ZZZX00`000000EEEE05EEE@020?ooo`0305EEE@2ZZZX0000000@0ZZZZ00<0EEEE
0:ZZZP2ZZZX00P0000020:ZZZP0305EEE@000000000000<0oooo0P1EEED30?ooo`030000003oool0
ZZZZ00P0oooo2P3AcJT80?ooo`040:ZZZP3oool000000:ZZZP80EEEE00D0ZZZZ0?ooo`2ZZZX0ZZZZ
05EEE@020:ZZZP0805EEE@3oool0ZZZZ0?ooo`2ZZZX0oooo0:ZZZP3oool20:ZZZP80oooo0`1EEED0
1`3oool0ZZZZ05EEE@2ZZZX0EEEE0?ooo`0000001P2ZZZX30?ooo`80EEEE00<0ZZZZ05EEE@3oool0
0`2ZZZX205EEE@040:ZZZP000000ZZZZ0:ZZZPP0oooo2P3AcJT80?ooo`030:ZZZP00000000000080
oooo1@0000001P3oool0EEEE0000003oool000000?ooo`80000000<0EEEE0?ooo`2ZZZX00`3oool0
1@2ZZZX000000?ooo`000000EEEE00@0000000<0ZZZZ05EEE@3oool0103oool4000000040?ooo`00
0000EEEE0?ooo`80000000<0oooo0000000000000P3oool00`000000ZZZZ0:ZZZP080?ooo``0dLfY
000;0=7=Z@T0oooo00<0EEEE0?ooo`1EEED00`3oool01@1EEED000000?ooo`3oool0EEEE00D0oooo
00<0EEEE0000000000000`3oool205EEE@80000000@0oooo0000003oool0oooo0P0000001P1EEED0
oooo0?ooo`3oool0EEEE00000080EEEE00<0oooo0:ZZZP3oool00P3oool01@1EEED0oooo05EEE@00
0000EEEE0080oooo00@0ZZZZ05EEE@3oool0ZZZZ2@3oool:0=7=Z@T0oooo00<0EEEE0?ooo`1EEED0
103oool01`2ZZZX0EEEE05EEE@1EEED000000?ooo`1EEED00P3oool00`1EEED00000000000020?oo
o`80ZZZZ00l0oooo0:ZZZP2ZZZX0EEEE0000002ZZZX0EEEE0?ooo`2ZZZX0oooo0000002ZZZX0oooo
0:ZZZP0000000P1EEED01@3oool0000005EEE@3oool0ZZZZ0080EEEE00<000000:ZZZP3oool00P3o
ool0102ZZZX0EEEE0?ooo`2ZZZX90?ooo`X0dLfY2@3oool00`1EEED0oooo05EEE@040?ooo`060000
003oool0EEEE0:ZZZP1EEED0oooo0`00000305EEE@050:ZZZP000000000005EEE@0000000P1EEED4
0?ooo`040000001EEED000000:ZZZP8000000P1EEED00`000000EEEE00000002000000070?ooo`2Z
ZZX0ZZZZ05EEE@3oool0000005EEE@020?ooo`040:ZZZP1EEED0oooo0:ZZZPT0oooo2P3AcJT90?oo
o`0405EEE@000000oooo05EEE@<0oooo00<000000:ZZZP3oool00P2ZZZX00`3oool0ZZZZ0?ooo`03
0?ooo`040:ZZZP3oool0oooo0:ZZZP80EEEE00<0oooo0:ZZZP2ZZZX00P3oool00`2ZZZX0oooo0?oo
o`0205EEE@050:ZZZP3oool0oooo0:ZZZP0000000P3oool01@000000ZZZZ0?ooo`3oool0ZZZZ0080
oooo0P0000040?ooo`030000002ZZZX0oooo00P0oooo2P3AcJT90?ooo`0305EEE@00000000000080
000000<0oooo05EEE@2ZZZX00`0000000`2ZZZX000000?ooo`02000000090?ooo`2ZZZX000000:ZZ
ZP1EEED0ZZZZ0?ooo`000000oooo00<0000000D0EEEE000000000000oooo000000020:ZZZP0505EE
E@3oool000000000003oool00P0000000`3oool000000:ZZZP020000000405EEE@2ZZZX0EEEE0?oo
o`@0000000<0ZZZZ0?ooo`3oool01`3oool<0=7=Z@002`3AcJT:0?ooo`030:ZZZP3oool0000000<0
oooo00<0EEEE0:ZZZP2ZZZX00P1EEED01P2ZZZX0oooo0000001EEED0ZZZZ05EEE@H0oooo00P0EEEE
0000001EEED0EEEE0?ooo`1EEED0ZZZZ05EEE@L0oooo00X0ZZZZ05EEE@1EEED0oooo0:ZZZP3oool0
EEEE0:ZZZP000000EEEE1@3oool00`2ZZZX0oooo0?ooo`080?ooo`X0dLfY2P3oool00`2ZZZX0oooo
000000020?ooo`030000003oool0ZZZZ0080EEEE00X0oooo0:ZZZP3oool000000?ooo`2ZZZX00000
05EEE@2ZZZX0EEEE0`2ZZZX01P000000ZZZZ0?ooo`3oool0ZZZZ0?ooo`80000000`0ZZZZ0?ooo`2Z
ZZX0EEEE0?ooo`1EEED000000:ZZZP3oool0ZZZZ0?ooo`2ZZZX305EEE@030:ZZZP3oool0oooo00@0
oooo00<0ZZZZ0?ooo`3oool0203oool:0=7=Z@X0oooo00<0ZZZZ0?ooo`0000000P3oool01@000000
EEEE05EEE@1EEED0000000<0EEEE00<0ZZZZ0000001EEED00P3oool205EEE@040:ZZZP1EEED00000
05EEE@H0oooo00D0EEEE0000002ZZZX0ZZZZ05EEE@030?ooo`0305EEE@000000EEEE0080EEEE0P00
000305EEE@D0oooo00<0ZZZZ0?ooo`3oool0203oool:0=7=Z@X0oooo00@0ZZZZ05EEE@3oool0ZZZZ
0P3oool20:ZZZP0405EEE@2ZZZX0ZZZZ05EEE@<0ZZZZ00@0oooo0:ZZZP2ZZZX0ZZZZ0`3oool01@00
0000oooo05EEE@2ZZZX0oooo0080ZZZZ0P3oool010000000ZZZZ0?ooo`3oool30:ZZZP040?ooo`2Z
ZZX0oooo0:ZZZP80EEEE00<0ZZZZ05EEE@3oool00P2ZZZX01@3oool0ZZZZ05EEE@1EEED0ZZZZ00X0
oooo2P3AcJT:0?ooo`070:ZZZP1EEED0EEEE0000002ZZZX0oooo0:ZZZP020000000405EEE@2ZZZX0
EEEE05EEE@<0000000@0oooo000000000000ZZZZ0P3oool3000000050:ZZZP3oool0ZZZZ0:ZZZP3o
ool00P0000001P2ZZZX0oooo0:ZZZP3oool000000?ooo`80000000D0ZZZZ05EEE@1EEED0ZZZZ05EE
E@02000000030:ZZZP3oool0ZZZZ0080000000<0EEEE0:ZZZP3oool02@3oool<0=7=Z@002`3AcJT;
0?ooo`060:ZZZP3oool0EEEE0:ZZZP1EEED000000P3oool20:ZZZP80oooo0`1EEED01P3oool00000
05EEE@2ZZZX0EEEE0:ZZZP80EEEE0P0000000`1EEED0oooo0000000305EEE@040?ooo`1EEED0ZZZZ
0?ooo`8000000P1EEED30?ooo`80ZZZZ00D0oooo0:ZZZP000000oooo0:ZZZP0205EEE@030:ZZZP3o
ool0oooo00T0oooo2P3AcJT;0?ooo`040:ZZZP3oool0EEEE0:ZZZP80EEEE00/0oooo05EEE@3oool0
EEEE0:ZZZP1EEED000000:ZZZP000000oooo000000020:ZZZP060?ooo`000000EEEE0?ooo`1EEED0
ZZZZ0P3oool0102ZZZX0EEEE0?ooo`1EEED20?ooo`090:ZZZP00000000000:ZZZP000000ZZZZ0?oo
o`1EEED0ZZZZ0080oooo00D0EEEE0000001EEED0oooo0:ZZZP0205EEE@030:ZZZP3oool0oooo00T0
oooo2P3AcJT;0?ooo`040:ZZZP3oool0EEEE0:ZZZP@0EEEE00@0ZZZZ05EEE@1EEED0ZZZZ0P1EEED4
0?ooo`0405EEE@000000EEEE05EEE@P0oooo00@0EEEE0:ZZZP000000EEEE103oool205EEE@090:ZZ
ZP1EEED0ZZZZ0:ZZZP1EEED0ZZZZ05EEE@3oool0ZZZZ0080EEEE00<0ZZZZ0?ooo`3oool02@3oool:
0=7=Z@/0oooo00<0ZZZZ0?ooo`0000000P3oool00`000000ZZZZ0?ooo`020:ZZZP030?ooo`2ZZZX0
00000080oooo00@0ZZZZ0?ooo`2ZZZX0EEEE0P2ZZZX205EEE@<0oooo00<000000?ooo`1EEED00P1E
EED20:ZZZP0305EEE@3oool0oooo00@0oooo00@0ZZZZ0?ooo`3oool0ZZZZ0P3oool2000000040?oo
o`000000ZZZZ0:ZZZP/0oooo2P3AcJT;0?ooo`030:ZZZP000000000000<0oooo00D000000?ooo`1E
EED0ZZZZ0?ooo`020:ZZZP0<0000001EEED0EEEE05EEE@3oool000000?ooo`1EEED0ZZZZ05EEE@3o
ool000000P3oool00`000000EEEE05EEE@020:ZZZP070?ooo`000000EEEE05EEE@3oool0EEEE0000
00020:ZZZP80oooo00<0EEEE0?ooo`0000000`3oool00`000000ZZZZ0:ZZZP0;0?ooo``0dLfY000;
0=7=Z@`0oooo0P2ZZZX20?ooo`0305EEE@000000oooo00@0oooo0P0000000`3oool0ZZZZ0:ZZZP02
0?ooo`0<0:ZZZP00000000000?ooo`000000EEEE0?ooo`000000EEEE0000003oool000000P2ZZZX0
1P3oool0EEEE0:ZZZP000000oooo000000<0oooo00<0ZZZZ0?ooo`3oool00P1EEED20?ooo`80ZZZZ
303oool:0=7=Z@`0oooo0P2ZZZX20?ooo`80EEEE00X0ZZZZ000000000000oooo05EEE@2ZZZX00000
0:ZZZP3oool000000P3oool01@2ZZZX0oooo05EEE@3oool0ZZZZ00@0oooo00h0ZZZZ0?ooo`1EEED0
EEEE0:ZZZP3oool0ZZZZ0000003oool0ZZZZ0000003oool0EEEE0?ooo`80000000<0ZZZZ0?ooo`1E
EED00P3oool20:ZZZP`0oooo2P3AcJT<0?ooo`80ZZZZ0P3oool0101EEED0ZZZZ0:ZZZP0000020:ZZ
ZP040?ooo`1EEED0oooo000000<0oooo00<0000005EEE@1EEED02P3oool00`000000EEEE00000003
0?ooo`050000003oool0oooo0?ooo`2ZZZX00P0000000`2ZZZX0000005EEE@020?ooo`80ZZZZ303o
ool:0=7=Z@`0oooo00@0EEEE0000003oool0EEEE0P2ZZZX0103oool000000000003oool20:ZZZP03
05EEE@000000oooo0080oooo102ZZZX0203oool0ZZZZ05EEE@1EEED0ZZZZ05EEE@2ZZZX0oooo102Z
ZZX20?ooo`050:ZZZP000000EEEE05EEE@2ZZZX00P3oool020000000oooo05EEE@2ZZZX000000?oo
o`000000ZZZZ303oool:0=7=Z@`0oooo00<0EEEE0000000000000P000000101EEED0oooo05EEE@1E
EED40:ZZZP80000000<0ZZZZ0000000000000P3oool01@2ZZZX0oooo0:ZZZP1EEED0oooo0080EEEE
00D0ZZZZ0?ooo`2ZZZX0ZZZZ0?ooo`02000000030:ZZZP000000000000@0ZZZZ00<0oooo05EEE@3o
ool01@0000000`2ZZZX0oooo0?ooo`0:0?ooo``0dLfY000;0=7=Z@d0oooo00<0ZZZZ05EEE@1EEED0
0P2ZZZX01P1EEED000000?ooo`000000EEEE0?ooo`8000000`1EEED00`000000ZZZZ0:ZZZP020:ZZ
ZP030?ooo`2ZZZX0EEEE0080ZZZZ00P0oooo0:ZZZP2ZZZX0oooo0:ZZZP000000oooo05EEE@@00000
00X0EEEE0000001EEED0000005EEE@3oool0ZZZZ0?ooo`1EEED0ZZZZ3@3oool:0=7=Z@d0oooo00<0
ZZZZ05EEE@1EEED00P2ZZZX02@3oool0000005EEE@3oool0000005EEE@000000oooo05EEE@030?oo
o`040000001EEED000000?ooo`<0EEEE0180000005EEE@3oool0oooo0000003oool000000?ooo`00
0000oooo05EEE@3oool000000:ZZZP000000oooo05EEE@0000020?ooo`040:ZZZP3oool0EEEE0:ZZ
ZPd0oooo2P3AcJT=0?ooo`030:ZZZP1EEED0EEEE00<0ZZZZ00<0EEEE0?ooo`1EEED00`2ZZZX20000
00040:ZZZP1EEED0ZZZZ000000`0ZZZZ00@000000:ZZZP000000ZZZZ0P0000030:ZZZP<0EEEE00H0
ZZZZ0?ooo`2ZZZX0oooo05EEE@2ZZZX=0?ooo`X0dLfY3@3oool01@2ZZZX0EEEE0?ooo`3oool00000
00@0oooo00@0ZZZZ0?ooo`3oool0EEEE0P2ZZZX01@000000oooo0?ooo`3oool0ZZZZ0080000000<0
oooo05EEE@2ZZZX00P3oool00`000000ZZZZ0?ooo`020?ooo`80ZZZZ0P1EEED20?ooo`030:ZZZP3o
ool0EEEE00@0oooo0P1EEED00`2ZZZX0oooo0?ooo`0;0?ooo`X0dLfY3@3oool01P2ZZZX0EEEE05EE
E@000000oooo0:ZZZP80000000D0ZZZZ0?ooo`1EEED0oooo0:ZZZP020?ooo`80EEEE0P2ZZZX205EE
E@030:ZZZP00000000000080000000<0oooo05EEE@1EEED00P2ZZZX205EEE@070?ooo`2ZZZX0ZZZZ
0?ooo`1EEED0oooo0:ZZZP0200000080ZZZZ0P0000000`1EEED0ZZZZ0?ooo`0<0?ooo``0dLfY000;
0=7=Z@h0oooo0P2ZZZX20?ooo`80ZZZZ00H000000?ooo`2ZZZX0EEEE0?ooo`1EEED20?ooo`050000
002ZZZX0oooo0?ooo`2ZZZX0103oool01@2ZZZX0oooo0?ooo`3oool0ZZZZ0080oooo00<0ZZZZ05EE
E@3oool00P1EEED01@3oool0ZZZZ0:ZZZP3oool0EEEE0080ZZZZ0P3oool20:ZZZPh0oooo2P3AcJT>
0?ooo`80ZZZZ0P3oool00`2ZZZX0EEEE0000000205EEE@8000000`1EEED300000080EEEE00P0oooo
05EEE@000000oooo0:ZZZP000000ZZZZ0?ooo`80EEEE0`00000305EEE@070000003oool0EEEE05EE
E@2ZZZX0EEEE0:ZZZP020?ooo`80ZZZZ3P3oool:0=7=Z@h0oooo0P2ZZZX20?ooo`0:0:ZZZP3oool0
ZZZZ0:ZZZP000000EEEE0000001EEED0000005EEE@80oooo00L0ZZZZ000000000000ZZZZ0000001E
EED0000000<0EEEE00D0ZZZZ000000000000ZZZZ0?ooo`0205EEE@050000001EEED0000005EEE@00
00000P2ZZZX0103oool0ZZZZ0?ooo`3oool20:ZZZPh0oooo2P3AcJT>0?ooo`030:ZZZP3oool00000
00<0EEEE0`3oool00`000000oooo0:ZZZP030?ooo`80EEEE00L0oooo05EEE@2ZZZX0ZZZZ05EEE@3o
ool0ZZZZ0080EEEE00<0ZZZZ05EEE@1EEED00P1EEED01P000000oooo0:ZZZP2ZZZX0oooo0:ZZZP<0
oooo0P1EEED0102ZZZX000000:ZZZP2ZZZX>0?ooo`X0dLfY3P3oool00`2ZZZX00000000000020?oo
o`070000003oool000000?ooo`2ZZZX0oooo000000020?ooo`0505EEE@3oool0oooo0?ooo`1EEED0
0P3oool010000000EEEE0000000000020?ooo`0305EEE@2ZZZX0oooo00@0oooo00@000000?ooo`2Z
ZZX0oooo0`0000020?ooo`030000002ZZZX0ZZZZ00h0oooo303AcJT000/0dLfY4`3oool20:ZZZP05
0000002ZZZX000000?ooo`1EEED00P3oool205EEE@060000003oool0oooo0:ZZZP1EEED0ZZZZ0P3o
ool00`2ZZZX0EEEE0:ZZZP020?ooo`030000001EEED0oooo0080oooo00/0EEEE0?ooo`000000ZZZZ
0000003oool0ZZZZ0?ooo`000000oooo0:ZZZP0?0?ooo`X0dLfY4`3oool00`2ZZZX000000?ooo`02
0000000605EEE@000000EEEE0000003oool000000`2ZZZX00`3oool000000:ZZZP020?ooo`0<0:ZZ
ZP1EEED0oooo0:ZZZP3oool0ZZZZ0000002ZZZX000000:ZZZP000000EEEE0P0000001`3oool0ZZZZ
0:ZZZP3oool000000?ooo`2ZZZX03`3oool:0=7=ZA<0oooo00T0ZZZZ0000002ZZZX0000005EEE@3o
ool0EEEE0000001EEED00P3oool010000000EEEE00000000000305EEE@030:ZZZP1EEED0oooo00@0
00000P3oool00`1EEED0000005EEE@020?ooo`080000002ZZZX0EEEE0:ZZZP3oool000000?ooo`2Z
ZZX?0?ooo`X0dLfY3`3oool0101EEED000000?ooo`1EEED40?ooo`030000001EEED0ZZZZ0080EEEE
0`0000000`1EEED0oooo0?ooo`020:ZZZP80oooo0P2ZZZX20?ooo`0805EEE@00000000000?ooo`1E
EED0oooo0:ZZZP1EEED50?ooo`0405EEE@3oool000000:ZZZPl0oooo2P3AcJT?0?ooo`0305EEE@00
00000000008000000P1EEED30:ZZZP0305EEE@3oool0EEEE00<0oooo00<0ZZZZ0000000000000`00
00000`1EEED0000000000002000000<0oooo101EEED30:ZZZP0305EEE@3oool0000000<0000000<0
ZZZZ0?ooo`3oool03@3oool<0=7=Z@002`3AcJT@0?ooo`80ZZZZ103oool0102ZZZX0oooo0000002Z
ZZX205EEE@050?ooo`1EEED0oooo0000001EEED00`3oool02`000000oooo0?ooo`2ZZZX0oooo05EE
E@000000oooo05EEE@2ZZZX0EEEE0080ZZZZ0P0000000`2ZZZX0oooo0?ooo`020?ooo`80ZZZZ403o
ool:0=7=ZA00oooo0P2ZZZX30?ooo`060:ZZZP00000000000:ZZZP3oool000000P1EEED2000000<0
EEEE00D0oooo0000003oool0oooo0000000305EEE@040:ZZZP00000000000?ooo`80EEEE00D0oooo
0:ZZZP3oool000000:ZZZP030?ooo`80ZZZZ403oool:0=7=ZA00oooo0P2ZZZX30?ooo`0305EEE@3o
ool0oooo0080000000<0ZZZZ05EEE@1EEED00P1EEED0103oool0000005EEE@00000205EEE@040000
001EEED0ZZZZ05EEE@8000000P1EEED00`000000EEEE0?ooo`03000000030?ooo`1EEED0oooo0080
oooo0P2ZZZX@0?ooo`X0dLfY403oool00`2ZZZX0EEEE0?ooo`020:ZZZP030?ooo`1EEED0000000@0
oooo00H0EEEE0000003oool0ZZZZ05EEE@2ZZZX50?ooo`070000002ZZZX0EEEE0:ZZZP3oool00000
05EEE@050?ooo`0705EEE@3oool0oooo0:ZZZP3oool0EEEE0:ZZZP0@0?ooo`X0dLfY403oool0102Z
ZZX0000005EEE@0000020?ooo`030:ZZZP3oool000000080ZZZZ1P0000001@3oool0EEEE05EEE@2Z
ZZX000000080EEEE00<0oooo00000000000010000000203oool0ZZZZ000000000000ZZZZ0?ooo`2Z
ZZX000000P1EEED00`2ZZZX0oooo0?ooo`0>0?ooo``0dLfY000;0=7=ZA<0oooo00L000000?ooo`3o
ool0oooo0000002ZZZX0oooo0080ZZZZ0P3oool03P1EEED0000005EEE@2ZZZX0oooo0000003oool0
EEEE0000003oool0ZZZZ05EEE@000000EEEE0P3oool00`2ZZZX0oooo0?ooo`020:ZZZP<0oooo00<0
00000?ooo`2ZZZX04@3oool:0=7=ZA<0oooo00P000000?ooo`3oool0ZZZZ0000001EEED0oooo0:ZZ
ZP80EEEE0P2ZZZX405EEE@@00000101EEED20:ZZZP070000001EEED0ZZZZ0?ooo`1EEED000000:ZZ
ZP020?ooo`030000003oool0ZZZZ0140oooo2P3AcJTC0?ooo`040000003oool0oooo05EEE@80ZZZZ
00X0EEEE0?ooo`3oool0EEEE0:ZZZP1EEED0oooo0:ZZZP000000EEEE0P2ZZZX01@1EEED0ZZZZ0:ZZ
ZP000000ZZZZ0080EEEE00D0ZZZZ05EEE@3oool0ZZZZ05EEE@020:ZZZP0605EEE@3oool0oooo0000
003oool0ZZZZ4@3oool:0=7=ZA40oooo00H0ZZZZ0?ooo`00000000000?ooo`2ZZZX305EEE@080?oo
o`1EEED0000005EEE@3oool0ZZZZ0?ooo`2ZZZX605EEE@040:ZZZP3oool0EEEE0?ooo`H0EEEE0P2Z
ZZX20?ooo`030000003oool0ZZZZ0140oooo2P3AcJTA0?ooo`030:ZZZP000000000000<0oooo0P00
00020?ooo`050000001EEED0ZZZZ05EEE@2ZZZX00P1EEED01P3oool0EEEE0000003oool0EEEE0?oo
o`@0EEEE00<0ZZZZ0000000000000P3oool2000000<0oooo0P0000000`2ZZZX0oooo0?ooo`0?0?oo
o``0dLfY000;0=7=ZA80oooo0P2ZZZX30?ooo`80EEEE0P3oool0502ZZZX0oooo0:ZZZP1EEED0oooo
05EEE@2ZZZX0oooo05EEE@000000oooo05EEE@3oool0ZZZZ05EEE@3oool0EEEE0:ZZZP1EEED0ZZZZ
0P3oool205EEE@80oooo0`2ZZZXB0?ooo`X0dLfY4P3oool20:ZZZP<0oooo00H0EEEE0?ooo`3oool0
EEEE0?ooo`1EEED20:ZZZP030?ooo`1EEED0ZZZZ00<0000000D0oooo000000000000ZZZZ05EEE@03
0:ZZZP030000003oool0ZZZZ0080oooo00<0EEEE0?ooo`3oool00`2ZZZXB0?ooo`X0dLfY4P3oool2
0:ZZZP<0oooo00l0EEEE0000003oool0EEEE0:ZZZP1EEED0oooo05EEE@2ZZZX0EEEE0:ZZZP000000
ZZZZ0?ooo`0000000`2ZZZX00`1EEED0oooo05EEE@020?ooo`80ZZZZ00<0oooo0000001EEED00P3o
ool30:ZZZQ80oooo2P3AcJTB0?ooo`80ZZZZ00@0oooo05EEE@3oool000000`1EEED00`000000oooo
0?ooo`020?ooo`0605EEE@2ZZZX0oooo0?ooo`1EEED0ZZZZ0P3oool00`2ZZZX0EEEE0?ooo`020?oo
o`0305EEE@000000EEEE0080EEEE00@0ZZZZ0?ooo`1EEED000000P2ZZZXB0?ooo`X0dLfY4P3oool2
0:ZZZP0705EEE@000000000005EEE@3oool000000?ooo`02000000030:ZZZP3oool0ZZZZ00@00000
00<0ZZZZ0000000000000`0000020?ooo`050:ZZZP000000000005EEE@0000000P3oool300000080
ZZZZ4P3oool<0=7=Z@002`3AcJTC0?ooo`050:ZZZP3oool000000?ooo`1EEED0103oool0102ZZZX0
00000000003oool2000000060:ZZZP000000oooo05EEE@000000ZZZZ0P000000103oool000000000
002ZZZX60?ooo`030000003oool0ZZZZ01<0oooo2P3AcJTC0?ooo`070:ZZZP3oool000000?ooo`1E
EED0oooo0:ZZZP0205EEE@030000003oool0EEEE0080oooo00d0EEEE0000001EEED0EEEE0000001E
EED0000005EEE@3oool0000005EEE@3oool000000080EEEE00L0ZZZZ0?ooo`3oool0oooo0000003o
ool0ZZZZ01<0oooo2P3AcJTC0?ooo`090:ZZZP3oool000000?ooo`1EEED0oooo05EEE@000000ZZZZ
00<0oooo00D0ZZZZ0000002ZZZX0000005EEE@020:ZZZP0505EEE@000000ZZZZ0000001EEED00P3o
ool0101EEED0ZZZZ0:ZZZP1EEED30?ooo`030000003oool0ZZZZ01<0oooo2P3AcJTC0?ooo`060:ZZ
ZP1EEED0oooo0?ooo`000000EEEE0P0000000`1EEED0oooo0?ooo`030?ooo`0805EEE@2ZZZX0EEEE
0?ooo`2ZZZX0EEEE0:ZZZP1EEED50?ooo`0405EEE@000000000005EEE@<0oooo00<0EEEE0:ZZZP3o
ool04P3oool:0=7=ZA<0oooo00X0ZZZZ0000001EEED000000?ooo`2ZZZX0000005EEE@3oool00000
0`3oool5000000030?ooo`000000oooo008000000`3oool010000000oooo05EEE@0000020:ZZZP04
0000001EEED0EEEE0:ZZZQ<0oooo303AcJT000/0dLfY503oool02P1EEED0oooo05EEE@3oool0ZZZZ
05EEE@2ZZZX0EEEE0000001EEED3000000<0EEEE0P3oool00`1EEED0000005EEE@03000000D0EEEE
0P2ZZZX00`1EEED0oooo0:ZZZP0D0?ooo`X0dLfY503oool01@1EEED0oooo05EEE@3oool0ZZZZ00<0
EEEE00<0oooo05EEE@2ZZZX00P3oool01@000000EEEE0000003oool0ZZZZ00<0000000<0oooo0000
002ZZZX01@1EEED20:ZZZP0305EEE@3oool0ZZZZ01@0oooo2P3AcJTD0?ooo`0605EEE@3oool0EEEE
0?ooo`2ZZZX0EEEE0P0000030:ZZZP80000000D0EEEE0?ooo`1EEED0ZZZZ0000000305EEE@030000
002ZZZX0ZZZZ0080ZZZZ00<0000005EEE@1EEED00P2ZZZX00`1EEED0oooo0:ZZZP0D0?ooo`X0dLfY
503oool00`2ZZZX0oooo0000000205EEE@030000001EEED000000080ZZZZ00<0EEEE0000003oool0
0`2ZZZX20?ooo`<0ZZZZ00d0oooo0:ZZZP1EEED0ZZZZ05EEE@000000oooo0000001EEED0ZZZZ0000
003oool0ZZZZ01@0oooo2P3AcJTD0?ooo`030:ZZZP00000000000080oooo00<000000:ZZZP000000
1@000000203oool0ZZZZ0:ZZZP3oool000000:ZZZP000000oooo10000000103oool0000000000000
00020?ooo`80000000<0ZZZZ0?ooo`3oool04P3oool<0=7=Z@002`3AcJTE0?ooo`030:ZZZP3oool0
000000<0oooo00<0EEEE0:ZZZP2ZZZX0103oool00`000000ZZZZ000000020:ZZZP0905EEE@3oool0
oooo05EEE@3oool0ZZZZ0000001EEED0ZZZZ00@0oooo00<0ZZZZ0?ooo`3oool04`3oool:0=7=ZAD0
oooo00<0ZZZZ0?ooo`0000000`3oool02P1EEED0oooo0?ooo`1EEED0ZZZZ0000003oool0ZZZZ05EE
E@00000205EEE@090:ZZZP3oool000000:ZZZP1EEED0oooo0000001EEED0ZZZZ00@0oooo00<0ZZZZ
0?ooo`3oool04`3oool:0=7=ZAD0oooo00<0ZZZZ0?ooo`0000000`3oool205EEE@<0oooo00D00000
0?ooo`2ZZZX0ZZZZ0?ooo`020:ZZZP0405EEE@3oool0000005EEE@80oooo0P1EEED00`2ZZZX0oooo
0?ooo`020?ooo`030:ZZZP3oool0oooo01<0oooo2P3AcJTE0?ooo`80ZZZZ00D0oooo0:ZZZP2ZZZX0
EEEE0:ZZZP030?ooo`0305EEE@3oool0000000D0oooo0P0000000`3oool0ZZZZ0?ooo`020?ooo`05
0:ZZZP1EEED0ZZZZ0:ZZZP0000000P2ZZZXE0?ooo`X0dLfY5@3oool20:ZZZP0305EEE@0000000000
0080ZZZZ0P3oool0101EEED000000000001EEED2000000050?ooo`00000000000000001EEED00P00
00001@1EEED0oooo0:ZZZP2ZZZX0oooo00<000000P2ZZZXE0?ooo``0dLfY000;0=7=ZAH0oooo00@0
ZZZZ0?ooo`1EEED0ZZZZ0P3oool01P1EEED0000005EEE@3oool000000?ooo`<0EEEE00T0000005EE
E@3oool0oooo0000003oool0EEEE0000001EEED00P3oool0102ZZZX0EEEE05EEE@2ZZZXF0?ooo`X0
dLfY5P3oool0102ZZZX0oooo05EEE@2ZZZX20?ooo`0305EEE@000000EEEE0080EEEE103oool02@1E
EED0oooo0:ZZZP3oool0EEEE0:ZZZP1EEED0000005EEE@020?ooo`040:ZZZP1EEED0EEEE0:ZZZQH0
oooo2P3AcJTF0?ooo`040:ZZZP3oool0EEEE0:ZZZP<0oooo00<000000?ooo`1EEED00P2ZZZX30000
00030?ooo`000000ZZZZ0080ZZZZ0P3oool01@000000EEEE0?ooo`3oool0ZZZZ0080EEEE00<0ZZZZ
0?ooo`3oool0503oool:0=7=ZAH0oooo00<0ZZZZ05EEE@3oool00`2ZZZX0101EEED0ZZZZ0000003o
ool305EEE@030:ZZZP1EEED0ZZZZ0080ZZZZ0P1EEED00`3oool000000:ZZZP020:ZZZP050?ooo`2Z
ZZX0oooo05EEE@2ZZZX05P3oool:0=7=ZAH0oooo00@0ZZZZ0000001EEED000000`3oool00`000000
ZZZZ05EEE@02000000<0EEEE00<0ZZZZ05EEE@2ZZZX00`0000001P2ZZZX000000:ZZZP3oool0ZZZZ
00000080EEEE00<0ZZZZ0?ooo`3oool0503oool<0=7=Z@002`3AcJTG0?ooo`030:ZZZP3oool0oooo
00<0oooo00@0EEEE0000002ZZZX0EEEE0`0000000`1EEED0oooo000000020000000405EEE@2ZZZX0
000005EEE@80oooo00<000000?ooo`3oool0603oool:0=7=ZAL0oooo00<0ZZZZ0?ooo`3oool00P3o
ool2000000030:ZZZP3oool0EEEE0080EEEE103oool01P000000EEEE05EEE@1EEED0ZZZZ00000080
oooo00<000000?ooo`3oool0603oool:0=7=ZAL0oooo00<0ZZZZ0?ooo`3oool00P3oool010000000
EEEE05EEE@1EEED20000000605EEE@3oool0oooo0:ZZZP3oool0EEEE0P00000305EEE@80oooo00<0
00000?ooo`3oool0603oool:0=7=ZAL0oooo00D0ZZZZ05EEE@000000000005EEE@030:ZZZP050000
003oool0oooo0:ZZZP0000000P3oool200000080oooo102ZZZX0101EEED0oooo0000001EEEDH0?oo
o`X0dLfY5`3oool00`2ZZZX0EEEE0000000300000080oooo00<0EEEE0000002ZZZX00P3oool01`2Z
ZZX000000?ooo`000000ZZZZ0000002ZZZX00P3oool40000000305EEE@3oool0oooo01H0oooo303A
cJT000/0dLfY603oool0202ZZZX0EEEE05EEE@2ZZZX0EEEE0000002ZZZX0oooo102ZZZX205EEE@0<
0:ZZZP1EEED0ZZZZ0:ZZZP3oool0ZZZZ0000003oool0ZZZZ0?ooo`1EEED0ZZZZ603oool:0=7=ZAP0
oooo00@0ZZZZ05EEE@1EEED0ZZZZ0P1EEED01`3oool000000:ZZZP1EEED000000?ooo`0000000P3o
ool02`000000EEEE0:ZZZP000000oooo05EEE@3oool0ZZZZ0?ooo`1EEED0ZZZZ01P0oooo2P3AcJTH
0?ooo`040:ZZZP1EEED0EEEE0:ZZZP80EEEE00H0ZZZZ05EEE@2ZZZX0ZZZZ05EEE@2ZZZX20?ooo`0<
0:ZZZP1EEED0ZZZZ0:ZZZP1EEED0ZZZZ05EEE@3oool0ZZZZ0?ooo`1EEED0ZZZZ603oool:0=7=ZAP0
oooo0P2ZZZX00`3oool0EEEE0:ZZZP030?ooo`80EEEE00@000000?ooo`1EEED0EEEE0P3oool205EE
E@060000003oool0oooo0?ooo`1EEED000000P2ZZZXH0?ooo`X0dLfY603oool20:ZZZP0805EEE@00
0000oooo0000002ZZZX0EEEE0?ooo`00000205EEE@050000003oool0EEEE0?ooo`0000000P3oool0
0`2ZZZX000000000000200000080ZZZZ603oool<0=7=Z@002`3AcJTI0?ooo`80ZZZZ0P3oool205EE
E@80oooo0P2ZZZX00`3oool0EEEE0?ooo`020?ooo`030:ZZZP3oool000000080EEEE0P3oool20:ZZ
ZQT0oooo2P3AcJTI0?ooo`80ZZZZ0P3oool0101EEED0oooo0000003oool405EEE@080000001EEED0
oooo05EEE@3oool0ZZZZ0?ooo`1EEED20?ooo`80ZZZZ6@3oool:0=7=ZAT0oooo0P2ZZZX20?ooo`03
05EEE@000000ZZZZ0080000000<0ZZZZ0?ooo`3oool00P3oool01P2ZZZX000000000002ZZZX00000
05EEE@80oooo0P2ZZZXI0?ooo`X0dLfY6@3oool01P2ZZZX0EEEE0?ooo`3oool0ZZZZ00000080EEEE
00<000000:ZZZP1EEED00P00000205EEE@050000001EEED0oooo0000002ZZZX00P3oool00`1EEED0
ZZZZ0?ooo`0H0?ooo`X0dLfY6@3oool00`2ZZZX0000005EEE@0200000080oooo0P1EEED20?ooo`80
EEEE00@0oooo05EEE@1EEED0EEEE0P3oool200000080EEEE00<0ZZZZ0?ooo`3oool05`3oool<0=7=
Z@002`3AcJTJ0?ooo`090:ZZZP1EEED0EEEE0:ZZZP3oool0EEEE0000001EEED0000000@0EEEE00P0
oooo05EEE@000000ZZZZ0?ooo`2ZZZX0oooo05EEEA/0oooo2P3AcJTJ0?ooo`040:ZZZP1EEED0EEEE
0:ZZZP80oooo00@0ZZZZ0?ooo`000000ZZZZ0P3oool00`2ZZZX0EEEE0?ooo`020:ZZZP040?ooo`2Z
ZZX0oooo05EEEA/0oooo2P3AcJTJ0?ooo`060:ZZZP1EEED0EEEE0:ZZZP3oool0ZZZZ0`1EEED40:ZZ
ZP080?ooo`1EEED0EEEE0:ZZZP3oool0ZZZZ0?ooo`1EEEDK0?ooo`X0dLfY6P3oool01P2ZZZX0EEEE
0?ooo`3oool0EEEE0:ZZZP80EEEE00H0ZZZZ0?ooo`2ZZZX0EEEE0?ooo`00000405EEE@030?ooo`00
0000EEEE01/0oooo2P3AcJTJ0?ooo`070:ZZZP1EEED000000000001EEED000000?ooo`0400000007
0?ooo`000000oooo0000003oool0000005EEE@020000000305EEE@3oool0oooo01T0oooo303AcJT0
00/0dLfY6`3oool20:ZZZP80oooo0P2ZZZX0101EEED0oooo0:ZZZP3oool20:ZZZP030000001EEED0
ZZZZ00<0oooo0P2ZZZXK0?ooo`X0dLfY6`3oool20:ZZZP80oooo00@0ZZZZ05EEE@1EEED0ZZZZ103o
ool00`000000EEEE05EEE@030?ooo`80ZZZZ6`3oool:0=7=ZA/0oooo0P2ZZZX20?ooo`060:ZZZP3o
ool0ZZZZ0:ZZZP000000ZZZZ0P0000020:ZZZP@0oooo0P2ZZZXK0?ooo`X0dLfY6`3oool0102ZZZX0
00000?ooo`2ZZZX20?ooo`0305EEE@000000oooo0080ZZZZ0P3oool01@1EEED0oooo0:ZZZP2ZZZX0
oooo0080ZZZZ6`3oool:0=7=ZA/0oooo00L0ZZZZ0000001EEED000000:ZZZP000000oooo0080ZZZZ
00T0oooo0000002ZZZX000000?ooo`000000EEEE0000001EEED00P2ZZZXK0?ooo``0dLfY000;0=7=
ZA`0oooo00@0ZZZZ05EEE@3oool0ZZZZ0P3oool00`2ZZZX0000005EEE@02000000<0oooo00<0EEEE
0?ooo`1EEED07@3oool:0=7=ZA`0oooo00@0ZZZZ05EEE@3oool0ZZZZ0P3oool0101EEED0ZZZZ05EE
E@0000020:ZZZP80oooo00<0EEEE0?ooo`1EEED07@3oool:0=7=ZA`0oooo00@0ZZZZ05EEE@3oool0
ZZZZ0P3oool205EEE@040:ZZZP3oool0EEEE05EEE@80oooo00<0EEEE0?ooo`1EEED07@3oool:0=7=
ZA`0oooo0P2ZZZX20?ooo`090000001EEED0ZZZZ0:ZZZP000000oooo0:ZZZP3oool0EEEE00800000
00<0oooo0:ZZZP3oool0703oool:0=7=ZA`0oooo0P2ZZZX30000000405EEE@00000000000?ooo`<0
000000D0EEEE00000000000000000:ZZZP0M0?ooo``0dLfY000;0=7=ZAd0oooo0P2ZZZX40?ooo`04
0:ZZZP3oool000000:ZZZP<0oooo0`2ZZZXM0?ooo`X0dLfY7@3oool20:ZZZP<0oooo0P2ZZZX00`3o
ool000000:ZZZP030?ooo`<0ZZZZ7@3oool:0=7=ZAd0oooo0P2ZZZX30?ooo`0405EEE@3oool0oooo
000000@0oooo0`2ZZZXM0?ooo`X0dLfY7@3oool01P2ZZZX0EEEE0?ooo`000000EEEE0?ooo`80ZZZZ
00@0EEEE0:ZZZP1EEED0EEEE0P0000000`1EEED0ZZZZ0?ooo`0L0?ooo`X0dLfY7@3oool0102ZZZX0
EEEE0000001EEED20000000:0?ooo`00000000000?ooo`1EEED0000005EEE@000000EEEE0:ZZZQd0
oooo303AcJT000/0dLfY7P3oool00`2ZZZX0oooo000000030?ooo`030000002ZZZX0oooo0080oooo
00<000000?ooo`2ZZZX07P3oool:0=7=ZAh0oooo00<0ZZZZ0?ooo`0000000P3oool0102ZZZX00000
0?ooo`2ZZZX20?ooo`030000003oool0ZZZZ01h0oooo2P3AcJTN0?ooo`030:ZZZP3oool000000080
oooo00@0EEEE0:ZZZP2ZZZX0EEEE0P3oool00`000000oooo0:ZZZP0N0?ooo`X0dLfY7P3oool0102Z
ZZX000000?ooo`1EEED20?ooo`80ZZZZ0P3oool0101EEED0oooo0:ZZZP2ZZZXN0?ooo`X0dLfY7P3o
ool0102ZZZX0000005EEE@1EEED2000000030?ooo`000000000000<0EEEE0P2ZZZXN0?ooo``0dLfY
000;0=7=ZAl0oooo0`2ZZZX20?ooo`80EEEE0P3oool20:ZZZR00oooo2P3AcJTO0?ooo`<0ZZZZ0P3o
ool205EEE@80oooo0P2ZZZXP0?ooo`X0dLfY7`3oool30:ZZZP80oooo0P1EEED20?ooo`80ZZZZ803o
ool:0=7=ZAl0oooo0P2ZZZX02@3oool0ZZZZ05EEE@000000ZZZZ05EEE@000000oooo0:ZZZP0P0?oo
o`X0dLfY7`3oool20:ZZZP060000002ZZZX0EEEE0000002ZZZX0EEEE0P0000000`2ZZZX0oooo0?oo
o`0N0?ooo``0dLfY000;0=7=ZB00oooo00D0ZZZZ0?ooo`000000oooo05EEE@040?ooo`030:ZZZP3o
ool0oooo01h0oooo2P3AcJTP0?ooo`050:ZZZP3oool000000?ooo`1EEED0103oool00`2ZZZX0oooo
0?ooo`0N0?ooo`X0dLfY803oool01@2ZZZX0oooo0000003oool0EEEE00@0oooo00<0ZZZZ0?ooo`3o
ool07P3oool:0=7=ZB00oooo00X0ZZZZ05EEE@3oool0oooo0:ZZZP1EEED0oooo0000001EEED0ZZZZ
803oool:0=7=ZB00oooo00X0ZZZZ05EEE@3oool0oooo0:ZZZP1EEED0oooo0000001EEED0ZZZZ803o
ool<0=7=Z@002`3AcJTQ0?ooo`050:ZZZP3oool0EEEE0?ooo`2ZZZX00P1EEED00`2ZZZX0oooo0?oo
o`0O0?ooo`X0dLfY8@3oool01@2ZZZX0oooo05EEE@3oool0ZZZZ0080EEEE00<0ZZZZ0?ooo`3oool0
7`3oool:0=7=ZB40oooo00D0ZZZZ0?ooo`1EEED0oooo0:ZZZP0205EEE@030:ZZZP3oool0oooo01l0
oooo2P3AcJTQ0?ooo`030:ZZZP000000oooo0080ZZZZ00<0oooo0:ZZZP2ZZZX08@3oool:0=7=ZB40
oooo00<0ZZZZ0000003oool00P2ZZZX00`3oool0ZZZZ0:ZZZP0Q0?ooo``0dLfY000;0=7=ZB80oooo
00<0ZZZZ0?ooo`0000009@3oool:0=7=ZB80oooo00<0ZZZZ0?ooo`0000009@3oool:0=7=ZB80oooo
00<0ZZZZ0?ooo`0000009@3oool:0=7=ZB80oooo0P2ZZZX00`000000oooo0:ZZZP0S0?ooo`X0dLfY
8P3oool20:ZZZP030000003oool0ZZZZ02<0oooo303AcJT000/0dLfY8`3oool0102ZZZX0oooo05EE
E@2ZZZXS0?ooo`X0dLfY8`3oool0102ZZZX0oooo05EEE@2ZZZXS0?ooo`X0dLfY8`3oool0102ZZZX0
oooo05EEE@2ZZZXS0?ooo`X0dLfY8`3oool20:ZZZP0305EEE@2ZZZX0oooo0280oooo2P3AcJTS0?oo
o`80ZZZZ00<0EEEE0:ZZZP3oool08P3oool<0=7=Z@002`3AcJTT0?ooo`030:ZZZP3oool0oooo02<0
oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0
oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0
oooo303AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0
dLfY/P3AcJT000/0dLfY00`0oooo0:ZZZP2ZZZX0000005EEE@3oool0ZZZZ0?ooo`1EEED0ZZZZ05EE
E@2ZZZX305EEE@070:ZZZP00000000000:ZZZP1EEED000000?ooo`040:ZZZP80EEEE00<0ZZZZ05EE
E@1EEED00`1EEED20000000405EEE@2ZZZX000000?ooo`D0EEEE00<0ZZZZ05EEE@1EEED00P2ZZZX0
1@1EEED0ZZZZ0?ooo`3oool0EEEE0080ZZZZ00<000000?ooo`1EEED00P1EEED02@2ZZZX0EEEE0?oo
o`1EEED0oooo0000003oool0EEEE000000020:ZZZP030?ooo`3AcJT0dLfY00P0dLfY00@0oooo0:ZZ
ZP2ZZZX0oooo0`1EEED0103oool0EEEE0000003oool30:ZZZP0305EEE@2ZZZX0ZZZZ0080EEEE00D0
000005EEE@2ZZZX0EEEE0000000205EEE@80ZZZZ0P1EEED01@2ZZZX0EEEE0:ZZZP1EEED0ZZZZ00@0
000000H0ZZZZ05EEE@2ZZZX0EEEE0:ZZZP1EEED20:ZZZPD0EEEE00<0ZZZZ05EEE@0000000P1EEED2
0:ZZZP0405EEE@2ZZZX0EEEE0:ZZZP80oooo00H0EEEE0?ooo`3oool0EEEE0:ZZZP3oool20:ZZZP03
0?ooo`3AcJT0dLfY00P0dLfY00@0oooo0:ZZZP1EEED0oooo0P2ZZZX0103oool000000:ZZZP000002
05EEE@<000000P1EEED20000000305EEE@000000ZZZZ00<0ZZZZ0P0000000`2ZZZX0EEEE0?ooo`02
05EEE@030?ooo`1EEED0000000D0ZZZZ00H0EEEE0?ooo`3oool0EEEE0?ooo`1EEED20:ZZZP030000
002ZZZX000000080ZZZZ00H0000005EEE@000000oooo05EEE@3oool300000080EEEE00X000000:ZZ
ZP000000oooo0:ZZZP000000oooo05EEE@2ZZZX0oooo2P3AcJT01`3oool0ZZZZ0:ZZZP2ZZZX0oooo
0:ZZZP3oool00P1EEED00`2ZZZX0EEEE0?ooo`020000000B05EEE@2ZZZX0ZZZZ0000001EEED0oooo
0000001EEED000000?ooo`1EEED0ZZZZ05EEE@2ZZZX0EEEE0:ZZZP000000ZZZZ0P3oool01P1EEED0
ZZZZ0?ooo`3oool0ZZZZ05EEE@<0oooo00L000000:ZZZP000000ZZZZ05EEE@2ZZZX0EEEE00800000
00D0EEEE0?ooo`3oool0EEEE0?ooo`020:ZZZP0605EEE@000000oooo0?ooo`1EEED0oooo0P1EEED0
0`3oool0ZZZZ05EEE@030:ZZZP030?ooo`3AcJT0dLfY00P0dLfY00D0oooo0:ZZZP2ZZZX0EEEE0:ZZ
ZP040?ooo`80EEEE0P0000020?ooo`80EEEE00D0oooo0000003oool0EEEE0?ooo`0405EEE@030?oo
o`000000ZZZZ0080ZZZZ0P1EEED0103oool0000005EEE@2ZZZX205EEE@80oooo00L0EEEE0:ZZZP2Z
ZZX0ZZZZ05EEE@000000oooo0080EEEE00H0oooo05EEE@3oool0EEEE0?ooo`00000305EEE@<0oooo
00<0000005EEE@0000000P3oool0102ZZZX0oooo0000001EEED20:ZZZP030?ooo`3AcJT0dLfY00X0
dLfY000;0=7=Z@080?ooo`2ZZZX0ZZZZ0?ooo`1EEED000000?ooo`1EEED2000000040:ZZZP3oool0
000000000080ZZZZ00@0EEEE0?ooo`00000000000P2ZZZX01@000000EEEE05EEE@1EEED0oooo00<0
EEEE00D0oooo05EEE@000000EEEE0:ZZZP020?ooo`0705EEE@3oool0EEEE05EEE@000000EEEE0?oo
o`0705EEE@030000002ZZZX0ZZZZ008000000100oooo05EEE@000000ZZZZ0000002ZZZX0oooo0:ZZ
ZP1EEED0000005EEE@3oool0000005EEE@3oool0ZZZZ0P3oool:0=7=Z@050?ooo`2ZZZX0ZZZZ0000
003oool00P1EEED01@000000ZZZZ05EEE@000000ZZZZ0080EEEE00@0ZZZZ0000002ZZZX0EEEE0P2Z
ZZX00`1EEED0ZZZZ05EEE@020:ZZZP0505EEE@2ZZZX000000:ZZZP1EEED00`2ZZZX010000000EEEE
0000001EEED20000000:0?ooo`000000ZZZZ05EEE@2ZZZX0EEEE0:ZZZP000000ZZZZ05EEE@80ZZZZ
00<0EEEE0:ZZZP2ZZZX01P2ZZZX00`1EEED0ZZZZ0:ZZZP02000000030:ZZZP000000EEEE0080EEEE
00@000000:ZZZP3oool0oooo2P3AcJT03`3oool0ZZZZ0:ZZZP000000EEEE0:ZZZP000000ZZZZ0?oo
o`000000oooo05EEE@000000EEEE000000020:ZZZP040000001EEED000000?ooo`80000000L0oooo
05EEE@3oool0oooo0:ZZZP000000ZZZZ0080000000D0ZZZZ0000001EEED0oooo0:ZZZP020?ooo`05
0:ZZZP000000ZZZZ0:ZZZP0000000`2ZZZX0101EEED0oooo05EEE@3oool2000000050?ooo`000000
EEEE0000002ZZZX00P0000000`1EEED0000005EEE@030?ooo`030:ZZZP000000ZZZZ0080000000<0
ZZZZ0?ooo`3oool02P3AcJT0103oool0ZZZZ0?ooo`3oool20:ZZZP030?ooo`2ZZZX0ZZZZ00@0EEEE
0P0000001@2ZZZX0oooo0?ooo`1EEED0oooo00@0EEEE0P3oool00`2ZZZX0oooo05EEE@020:ZZZP80
000000<0ZZZZ05EEE@2ZZZX00`2ZZZX010000000ZZZZ0000000000020:ZZZP030000003oool0ZZZZ
0080oooo00L0ZZZZ05EEE@1EEED0ZZZZ0?ooo`1EEED000000080oooo0`00000205EEE@040?ooo`2Z
ZZX0ZZZZ05EEE@80ZZZZ103oool:0=7=Z@090?ooo`2ZZZX0oooo0?ooo`000000ZZZZ05EEE@000000
EEEE0080ZZZZ00/0EEEE0000003oool0oooo05EEE@3oool0EEEE0000003oool0EEEE0?ooo`020:ZZ
ZP040?ooo`2ZZZX000000:ZZZP80oooo00<0ZZZZ0?ooo`1EEED00P1EEED01@3oool0EEEE05EEE@3o
ool000000080EEEE00<0oooo0:ZZZP3oool00P2ZZZX00`000000ZZZZ0?ooo`020:ZZZP<0oooo00<0
000005EEE@3oool00`3oool205EEE@030:ZZZP1EEED0EEEE0080000000<0ZZZZ05EEE@3oool00`3o
ool<0=7=Z@002`3AcJT30?ooo`80ZZZZ00<0000005EEE@3oool00P3oool00`1EEED0000005EEE@02
05EEE@800000102ZZZX205EEE@040?ooo`2ZZZX0EEEE0?ooo`80000000D0EEEE0:ZZZP2ZZZX0EEEE
0?ooo`020:ZZZP090?ooo`1EEED0ZZZZ0:ZZZP3oool0EEEE0?ooo`2ZZZX0EEEE0080000000@0oooo
05EEE@2ZZZX0ZZZZ0P1EEED00`000000ZZZZ0:ZZZP02000000050:ZZZP1EEED0EEEE0?ooo`000000
0P1EEED20?ooo`0405EEE@000000ZZZZ0:ZZZP<0oooo2P3AcJT30?ooo`090:ZZZP000000000005EE
E@000000ZZZZ0000002ZZZX000000080ZZZZ00@0EEEE0:ZZZP2ZZZX0ZZZZ0`1EEED00`3oool0EEEE
0?ooo`020?ooo`<0EEEE0P3oool0101EEED0ZZZZ00000000000205EEE@060000001EEED000000000
002ZZZX000000P3oool00`2ZZZX0EEEE0:ZZZP030?ooo`0305EEE@3oool0EEEE00<0EEEE00H0ZZZZ
0000001EEED0ZZZZ05EEE@0000030:ZZZP030000001EEED000000080ZZZZ0`3oool:0=7=Z@<0oooo
00T0ZZZZ00000000000000000?ooo`2ZZZX000000:ZZZP3oool00P2ZZZX2000000030:ZZZP000000
EEEE0080EEEE00@0ZZZZ05EEE@2ZZZX0oooo0P1EEED01`3oool000000:ZZZP000000oooo0:ZZZP00
00000P2ZZZX00`000000ZZZZ0:ZZZP02000000050:ZZZP1EEED000000:ZZZP1EEED00P3oool0101E
EED0oooo0?ooo`1EEED20:ZZZP80EEEE00D000000:ZZZP2ZZZX000000:ZZZP020?ooo`060:ZZZP3o
ool0ZZZZ0?ooo`1EEED000000P2ZZZX30?ooo`X0dLfY0`3oool20:ZZZP070?ooo`1EEED0oooo0:ZZ
ZP1EEED0oooo0:ZZZP030000000305EEE@00000000000080000000@0EEEE0000002ZZZX000000P1E
EED01@3oool0ZZZZ0000003oool0ZZZZ0080EEEE00D0ZZZZ05EEE@1EEED0EEEE0?ooo`0205EEE@08
0:ZZZP1EEED0EEEE0:ZZZP3oool0EEEE0:ZZZP00000305EEE@030:ZZZP000000ZZZZ00L0000000P0
EEEE0:ZZZP3oool0oooo0:ZZZP3oool0ZZZZ0?ooo`80ZZZZ0`3oool:0=7=Z@<0oooo0P2ZZZX305EE
E@<0oooo00<0ZZZZ05EEE@1EEED00`1EEED20:ZZZP80oooo0P1EEED01`000000oooo05EEE@1EEED0
oooo05EEE@3oool00P00000205EEE@060?ooo`2ZZZX0oooo0?ooo`2ZZZX0oooo0`1EEED010000000
oooo0?ooo`3oool205EEE@040?ooo`2ZZZX0EEEE05EEE@80oooo00<0ZZZZ0?ooo`1EEED0101EEED0
102ZZZX0oooo0?ooo`3oool305EEE@80ZZZZ0`3oool<0=7=Z@002`3AcJT40?ooo`060:ZZZP3oool0
EEEE0000003oool0EEEE0P2ZZZX200000080ZZZZ00<0EEEE0:ZZZP3oool00P2ZZZX00`3oool00000
05EEE@0205EEE@030?ooo`1EEED0oooo0080EEEE00<0ZZZZ0000003oool00P3oool01P000000ZZZZ
0?ooo`1EEED0oooo000000<0EEEE00<0ZZZZ05EEE@0000000P1EEED00`2ZZZX000000?ooo`020:ZZ
ZP80oooo00@0EEEE0?ooo`2ZZZX000000`2ZZZX01P1EEED0oooo0000001EEED0oooo0:ZZZP@0oooo
2P3AcJT40?ooo`80ZZZZ00L0EEEE0:ZZZP3oool0oooo05EEE@3oool000000080ZZZZ0P3oool01@00
0000ZZZZ0000002ZZZX0000000@0EEEE0P2ZZZX01`1EEED000000:ZZZP3oool0EEEE0000001EEED0
0P000000101EEED0000000000000000205EEE@040:ZZZP000000EEEE0:ZZZPD0EEEE0`0000020:ZZ
ZP030?ooo`1EEED0ZZZZ0080ZZZZ00@0oooo05EEE@2ZZZX0oooo102ZZZX40?ooo`X0dLfY103oool0
1P2ZZZX0EEEE0000002ZZZX0000005EEE@<0oooo00D0EEEE0?ooo`3oool0EEEE0:ZZZP0205EEE@05
0000002ZZZX0EEEE0000002ZZZX00P0000020:ZZZP070?ooo`2ZZZX0ZZZZ0000001EEED000000?oo
o`02000000030?ooo`000000EEEE0080000000<0ZZZZ0?ooo`0000000P2ZZZX010000000ZZZZ05EE
E@1EEED20:ZZZP80EEEE00D0oooo05EEE@1EEED0oooo05EEE@030?ooo`0605EEE@000000ZZZZ0?oo
o`1EEED0ZZZZ103oool:0=7=Z@H0oooo0`2ZZZX30?ooo`070:ZZZP000000ZZZZ0000001EEED0oooo
05EEE@02000000090?ooo`1EEED0EEEE0:ZZZP000000oooo0:ZZZP1EEED0oooo00<0ZZZZ0140oooo
0000003oool0oooo0000003oool000000?ooo`2ZZZX0oooo0:ZZZP3oool000000:ZZZP1EEED00000
0:ZZZP0205EEE@060?ooo`000000000005EEE@000000EEEE0P2ZZZX01@000000ZZZZ0?ooo`3oool0
EEEE0080ZZZZ0P3oool00`2ZZZX0oooo0?ooo`020?ooo`X0dLfY1`3oool205EEE@030000001EEED0
EEEE0080oooo00@0EEEE0?ooo`1EEED0ZZZZ103oool205EEE@040:ZZZP3oool0ZZZZ0?ooo`<0ZZZZ
00H0oooo05EEE@3oool0oooo0000001EEED200000080oooo00T0EEEE0000002ZZZX0ZZZZ05EEE@3o
ool0ZZZZ0?ooo`2ZZZX00P1EEED50?ooo`0405EEE@3oool0EEEE0?ooo`<0EEEE00H0000005EEE@1E
EED0EEEE0?ooo`2ZZZX40?ooo``0dLfY000;0=7=Z@@0oooo0P2ZZZX0203oool0ZZZZ05EEE@3oool0
EEEE0?ooo`1EEED0ZZZZ0P3oool20:ZZZP@0EEEE0P2ZZZX010000000oooo05EEE@1EEED20:ZZZP03
05EEE@2ZZZX0oooo0080EEEE0P0000003`3oool000000000001EEED0oooo0:ZZZP1EEED0ZZZZ0000
001EEED0ZZZZ0?ooo`000000oooo0:ZZZP0405EEE@050000002ZZZX0oooo0?ooo`2ZZZX00P3oool3
05EEE@030:ZZZP000000ZZZZ00D0oooo2P3AcJT40?ooo`<0ZZZZ00D000000:ZZZP1EEED0EEEE0000
00020:ZZZP040?ooo`000000EEEE05EEE@<0oooo00<0EEEE0:ZZZP1EEED00`2ZZZX00`1EEED0oooo
05EEE@020:ZZZP<000000P1EEED00`000000EEEE05EEE@020000000305EEE@2ZZZX0EEEE00<0EEEE
102ZZZX0201EEED000000?ooo`3oool0ZZZZ05EEE@2ZZZX0oooo0P2ZZZX010000000EEEE05EEE@2Z
ZZX2000000030:ZZZP3oool0oooo00<0oooo2P3AcJT40?ooo`80ZZZZ00P0000005EEE@2ZZZX00000
0:ZZZP000000ZZZZ00000080ZZZZ0P0000001@1EEED0oooo000000000000oooo0080000000<0oooo
05EEE@1EEED00`3oool010000000EEEE0000002ZZZX4000000040?ooo`000000EEEE0:ZZZP80oooo
0P1EEED20?ooo`030000001EEED0oooo0080000000<0oooo05EEE@2ZZZX00P000000102ZZZX00000
0000000000030:ZZZP0305EEE@000000ZZZZ00D0oooo2P3AcJT40?ooo`030:ZZZP1EEED0ZZZZ0080
oooo0`2ZZZX0101EEED0ZZZZ05EEE@2ZZZX20000000<05EEE@2ZZZX0EEEE0:ZZZP3oool0ZZZZ0?oo
o`000000ZZZZ0?ooo`1EEED0ZZZZ0P3oool0102ZZZX0oooo0000000000020:ZZZP040000001EEED0
oooo0:ZZZP80oooo00/0ZZZZ0000003oool0EEEE0000003oool0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP02
05EEE@030000002ZZZX0EEEE00D0ZZZZ0`3oool00`1EEED0oooo0?ooo`030?ooo`X0dLfY103oool0
0`2ZZZX0EEEE05EEE@020:ZZZP0705EEE@2ZZZX0ZZZZ0:ZZZP1EEED0oooo0:ZZZP020?ooo`060000
003oool0oooo0000003oool0ZZZZ0P3oool00`2ZZZX0oooo05EEE@0205EEE@0;0:ZZZP3oool00000
0?ooo`000000oooo05EEE@000000oooo0000003oool0101EEED40?ooo`030:ZZZP3oool000000080
oooo0P0000001@3oool0EEEE0?ooo`1EEED0oooo0080ZZZZ00D0EEEE0:ZZZP2ZZZX0oooo05EEE@05
0?ooo``0dLfY000;0=7=Z@H0oooo00@0ZZZZ0?ooo`1EEED000000`3oool01@2ZZZX0EEEE0?ooo`2Z
ZZX0EEEE0080ZZZZ00<0oooo05EEE@1EEED01@1EEED0102ZZZX0oooo05EEE@00000405EEE@800000
1P1EEED0103oool0ZZZZ05EEE@3oool205EEE@040:ZZZP1EEED0EEEE05EEE@80ZZZZ00H0EEEE0:ZZ
ZP1EEED0EEEE0:ZZZP1EEED20?ooo`80EEEE00<0oooo0:ZZZP3oool01@3oool:0=7=Z@H0oooo00D0
ZZZZ0000001EEED0EEEE0000000505EEE@040:ZZZP000000oooo05EEE@80ZZZZ00@000000:ZZZP1E
EED0oooo0P1EEED00`2ZZZX000000:ZZZP030:ZZZP040?ooo`1EEED0ZZZZ0:ZZZP80EEEE102ZZZX0
0`000000oooo05EEE@020?ooo`80EEEE00D000000:ZZZP2ZZZX0EEEE0?ooo`020:ZZZP<0EEEE00<0
ZZZZ05EEE@0000000P1EEED00`000000ZZZZ0?ooo`050?ooo`X0dLfY1P3oool01@2ZZZX000000000
00000000EEEE0080ZZZZ10000000101EEED000000:ZZZP0000020:ZZZP80000000P0oooo00000000
0000oooo0:ZZZP1EEED000000:ZZZP80000000H0ZZZZ05EEE@2ZZZX0ZZZZ0?ooo`0000020:ZZZP04
05EEE@2ZZZX0oooo00000080oooo00P000000:ZZZP2ZZZX0ZZZZ0?ooo`2ZZZX000000:ZZZPD00000
00<0ZZZZ05EEE@1EEED00P0000000`2ZZZX0oooo0?ooo`040?ooo`X0dLfY203oool01@1EEED0ZZZZ
0:ZZZP2ZZZX0oooo00<0ZZZZ00D0EEEE0?ooo`2ZZZX0oooo0:ZZZP02000000040:ZZZP3oool0ZZZZ
05EEE@H0ZZZZ00D0000005EEE@3oool0EEEE000000020?ooo`030000002ZZZX0ZZZZ0080ZZZZ00@0
EEEE0:ZZZP1EEED0ZZZZ0P3oool20000000605EEE@3oool0ZZZZ0000001EEED0oooo0P2ZZZX01`1E
EED0ZZZZ0:ZZZP2ZZZX0EEEE0?ooo`2ZZZX01P3oool:0=7=Z@P0oooo00<0EEEE0:ZZZP0000001@1E
EED00`000000oooo05EEE@020000000605EEE@3oool0oooo05EEE@3oool0EEEE0P2ZZZX00`1EEED0
oooo0:ZZZP020?ooo`0305EEE@2ZZZX0ZZZZ0080ZZZZ00H0EEEE0?ooo`3oool0EEEE0?ooo`1EEED2
0:ZZZP050000003oool0EEEE05EEE@3oool00P1EEED010000000EEEE05EEE@00000305EEE@070000
001EEED000000000001EEED0oooo0:ZZZP060?ooo``0dLfY000;0=7=Z@H0oooo0P2ZZZX030000000
ZZZZ05EEE@1EEED0ZZZZ0000001EEED000000?ooo`2ZZZX0oooo0:ZZZP80EEEE0P3oool205EEE@09
0000002ZZZX0ZZZZ0:ZZZP000000ZZZZ05EEE@2ZZZX0EEEE00H0ZZZZ00L0EEEE0?ooo`000000ZZZZ
0?ooo`2ZZZX0000000<0EEEE00L0oooo05EEE@2ZZZX0ZZZZ0?ooo`000000oooo0080EEEE00L00000
0:ZZZP1EEED0EEEE0?ooo`000000ZZZZ00L0oooo2P3AcJT60?ooo`H0ZZZZ00H0EEEE0?ooo`1EEED0
000005EEE@3oool2000000060:ZZZP3oool0ZZZZ0:ZZZP1EEED0ZZZZ0P1EEED50:ZZZP80000000P0
EEEE0:ZZZP1EEED0EEEE0:ZZZP000000ZZZZ0?ooo`80ZZZZ00@0000005EEE@000000ZZZZ0P1EEED0
0`2ZZZX0oooo0:ZZZP02000000060?ooo`1EEED0EEEE05EEE@3oool0EEEE0P2ZZZX00`1EEED0ZZZZ
0:ZZZP070?ooo`X0dLfY1P3oool20:ZZZP0405EEE@000000ZZZZ0:ZZZPD0000000<0oooo05EEE@2Z
ZZX00P0000000`3oool0000000000002000000<0oooo00h0EEEE0:ZZZP3oool0ZZZZ0000001EEED0
00000:ZZZP1EEED000000:ZZZP3oool0000005EEE@<0oooo00D0ZZZZ00000000000000000?ooo`02
000000030:ZZZP1EEED0000000@0000000H0oooo0:ZZZP2ZZZX0oooo05EEE@2ZZZX70?ooo`X0dLfY
1P3oool0102ZZZX0EEEE0?ooo`2ZZZX20?ooo`80ZZZZ00<0EEEE0?ooo`0000000P1EEED0103oool0
ZZZZ05EEE@1EEED30?ooo`030:ZZZP3oool0000000D000000P1EEED0103oool0000005EEE@1EEED6
000000050?ooo`2ZZZX0oooo0?ooo`2ZZZX00P1EEED00`2ZZZX0oooo05EEE@02000000040:ZZZP1E
EED0ZZZZ0:ZZZP@0oooo00<0EEEE0?ooo`3oool01@3oool:0=7=Z@H0oooo00@0ZZZZ05EEE@3oool0
00000P2ZZZX02@1EEED0oooo0?ooo`1EEED0oooo0:ZZZP000000oooo05EEE@020:ZZZP060?ooo`1E
EED0EEEE0?ooo`2ZZZX0oooo0P2ZZZX30?ooo`D0EEEE0`3oool30:ZZZP030?ooo`2ZZZX000000080
EEEE0`2ZZZX01P1EEED0oooo000000000000oooo05EEE@80oooo00H0EEEE0:ZZZP2ZZZX0EEEE0?oo
o`1EEED70?ooo``0dLfY000;0=7=Z@L0oooo0P2ZZZX01`000000EEEE05EEE@3oool0EEEE0:ZZZP1E
EED00P3oool01@000000EEEE000000000000ZZZZ0080EEEE00@0oooo0:ZZZP3oool0oooo0P2ZZZX0
1P000000EEEE05EEE@1EEED0oooo0:ZZZP80oooo0`1EEED30:ZZZP80oooo00<0EEEE0?ooo`1EEED0
0P2ZZZX00`000000ZZZZ05EEE@02000000050?ooo`2ZZZX0ZZZZ05EEE@3oool00P1EEED30:ZZZPL0
oooo2P3AcJT70?ooo`80ZZZZ0`0000001`2ZZZX0000005EEE@3oool0ZZZZ05EEE@2ZZZX0103oool0
0`1EEED0ZZZZ0:ZZZP0205EEE@80ZZZZ0P3oool0102ZZZX0oooo0?ooo`2ZZZX2000000040:ZZZP1E
EED0oooo0:ZZZP80oooo00@0ZZZZ0?ooo`1EEED0oooo0P2ZZZX0201EEED0oooo0?ooo`1EEED0oooo
0:ZZZP000000ZZZZ0P1EEED500000080ZZZZ1`3oool:0=7=Z@L0oooo0P2ZZZX00`000000EEEE0:ZZ
ZP0600000080ZZZZ00@000000?ooo`3oool000000P3oool00`000000EEEE0000000205EEE@<0oooo
00H0EEEE0?ooo`00000000000?ooo`1EEED20?ooo`030:ZZZP1EEED0EEEE0080EEEE00<000000?oo
o`3oool0103oool20:ZZZPH0000000<0ZZZZ05EEE@0000000P2ZZZX70?ooo`X0dLfY1`3oool30:ZZ
ZP0905EEE@3oool0oooo0?ooo`2ZZZX0EEEE0?ooo`1EEED0ZZZZ00<0000000@0oooo0:ZZZP000000
00000P3oool00`1EEED000000?ooo`020000000;05EEE@3oool0EEEE0000003oool0EEEE0?ooo`1E
EED0000005EEE@3oool00P0000000`3oool0ZZZZ00000002000000070?ooo`00000000000000002Z
ZZX000000?ooo`020:ZZZP040?ooo`2ZZZX0oooo05EEE@<0ZZZZ1`3oool:0=7=Z@L0oooo0P2ZZZX3
05EEE@<0oooo0P1EEED00`3oool0000005EEE@020?ooo`050:ZZZP3oool0oooo05EEE@2ZZZX00`3o
ool00`2ZZZX0oooo0?ooo`020?ooo`0405EEE@3oool0EEEE05EEE@@0oooo00@0ZZZZ0?ooo`3oool0
oooo0P1EEED20?ooo`040:ZZZP3oool0EEEE05EEE@80000000@0EEEE0?ooo`3oool0oooo0`1EEED3
0:ZZZPL0oooo303AcJT000/0dLfY2@3oool00`2ZZZX000000?ooo`0205EEE@040?ooo`1EEED00000
000000<0EEEE0P2ZZZX205EEE@030?ooo`1EEED000000080EEEE00<0oooo0:ZZZP1EEED00P1EEED0
1@3oool0ZZZZ05EEE@3oool000000080EEEE00T0ZZZZ0?ooo`1EEED0EEEE0000002ZZZX0oooo05EE
E@3oool00P2ZZZX305EEE@80000000L0EEEE0?ooo`1EEED0ZZZZ0?ooo`000000ZZZZ00T0oooo2P3A
cJT90?ooo`060:ZZZP000000ZZZZ0000002ZZZX0EEEE102ZZZX00`1EEED0ZZZZ0:ZZZP020?ooo`0=
0:ZZZP000000oooo05EEE@3oool0EEEE0?ooo`2ZZZX0EEEE0:ZZZP1EEED0oooo0:ZZZP020?ooo`80
ZZZZ0P1EEED02@3oool0EEEE05EEE@1EEED0ZZZZ0000002ZZZX000000?ooo`020:ZZZP0305EEE@2Z
ZZX000000080ZZZZ00H0EEEE0:ZZZP2ZZZX0ZZZZ0000002ZZZX90?ooo`X0dLfY2@3oool01@2ZZZX0
0000000000000000oooo00<0ZZZZ00<0EEEE0?ooo`0000000`0000000`2ZZZX000000:ZZZP020:ZZ
ZP080000001EEED0EEEE0?ooo`2ZZZX0EEEE0000001EEED20000000305EEE@2ZZZX0EEEE0080ZZZZ
0P1EEED01P000000ZZZZ0:ZZZP2ZZZX000000?ooo`@0000000L0oooo0:ZZZP2ZZZX0EEEE0:ZZZP3o
ool0EEEE0080000000<0ZZZZ0?ooo`3oool01`3oool:0=7=Z@T0oooo00<0EEEE0?ooo`1EEED00`3o
ool205EEE@070:ZZZP1EEED0oooo0000001EEED0000005EEE@020:ZZZP80oooo0P1EEED01@2ZZZX0
EEEE0?ooo`000000EEEE0080ZZZZ00@0oooo0:ZZZP3oool000000P3oool01@2ZZZX0EEEE05EEE@3o
ool0000000<0ZZZZ00P0000005EEE@000000oooo05EEE@2ZZZX0EEEE0:ZZZP80oooo0P1EEED00`3o
ool0ZZZZ0?ooo`080?ooo`X0dLfY2@3oool0101EEED0oooo05EEE@2ZZZX205EEE@030:ZZZP3oool0
EEEE00<0ZZZZ0`3oool010000000EEEE05EEE@2ZZZX205EEE@050?ooo`1EEED0ZZZZ0:ZZZP1EEED0
103oool01P1EEED0ZZZZ0:ZZZP1EEED0oooo05EEE@80ZZZZ0P1EEED010000000oooo0?ooo`3oool3
0:ZZZP0305EEE@3oool0ZZZZ0080EEEE00@0ZZZZ05EEE@3oool0ZZZZ2@3oool<0=7=Z@002`3AcJT9
0?ooo`<0ZZZZ0P1EEED01`3oool0ZZZZ0?ooo`2ZZZX0oooo0000003oool00P00000205EEE@030000
003oool0ZZZZ0080ZZZZ0`1EEED0203oool0ZZZZ0:ZZZP3oool000000:ZZZP1EEED0oooo0`1EEED0
0`2ZZZX0EEEE0:ZZZP020000000=05EEE@3oool000000000002ZZZX000000?ooo`1EEED0oooo0000
003oool0EEEE000000020:ZZZPX0oooo2P3AcJT90?ooo`@0ZZZZ0P1EEED0103oool0ZZZZ0:ZZZP3o
ool30:ZZZP8000000P2ZZZX01P000000EEEE0000002ZZZX0000005EEE@<0ZZZZ00<000000:ZZZP1E
EED00P0000020:ZZZP0305EEE@000000ZZZZ0080EEEE0`2ZZZX01P1EEED000000:ZZZP000000ZZZZ
0?ooo`80ZZZZ00@0oooo05EEE@1EEED0oooo0P2ZZZX:0?ooo`X0dLfY2@3oool20:ZZZP0405EEE@00
0000ZZZZ00000080oooo00<0ZZZZ0000000000000P00000205EEE@060:ZZZP3oool0oooo0:ZZZP1E
EED0ZZZZ0P1EEED010000000ZZZZ0?ooo`1EEED20000000405EEE@2ZZZX0ZZZZ00000080EEEE102Z
ZZX0103oool0ZZZZ0000001EEED4000000080:ZZZP3oool0EEEE0000002ZZZX0oooo05EEE@2ZZZX:
0?ooo`X0dLfY2@3oool40:ZZZP0605EEE@3oool0000005EEE@2ZZZX0EEEE0`0000001@3oool0EEEE
05EEE@3oool0000000@0EEEE0`2ZZZX01P000000oooo05EEE@2ZZZX0oooo00000080ZZZZ00<0oooo
05EEE@1EEED00`1EEED03P3oool0EEEE05EEE@3oool0000005EEE@000000EEEE0:ZZZP1EEED0ZZZZ
0?ooo`1EEED0oooo0P2ZZZX:0?ooo`X0dLfY2@3oool30:ZZZP030000002ZZZX0oooo0080oooo1@1E
EED20000000305EEE@3oool0EEEE0080EEEE0P3oool305EEE@D0oooo0`1EEED30?ooo`80EEEE0P3o
ool00`1EEED000000000000405EEE@80oooo00@0ZZZZ0?ooo`2ZZZX0EEEE0P2ZZZX:0?ooo``0dLfY
000;0=7=Z@/0oooo00D0ZZZZ0000003oool0ZZZZ05EEE@020:ZZZP0405EEE@00000000000?ooo`80
EEEE0P2ZZZX305EEE@8000000P3oool00`2ZZZX000000?ooo`0205EEE@030?ooo`1EEED0ZZZZ0080
oooo0P0000000`3oool0EEEE000000030:ZZZP0505EEE@3oool0EEEE0000001EEED00P2ZZZX00`1E
EED0ZZZZ0?ooo`020:ZZZP/0oooo2P3AcJT;0?ooo`80ZZZZ00<0EEEE0000001EEED00P3oool205EE
E@<0oooo00H000000:ZZZP1EEED0ZZZZ0000002ZZZX205EEE@030?ooo`1EEED0ZZZZ0080000000D0
EEEE0:ZZZP00000000000:ZZZP0405EEE@8000000P1EEED20:ZZZP<0oooo0`1EEED0103oool0EEEE
0000001EEED20:ZZZP/0oooo2P3AcJT;0?ooo`0;0:ZZZP1EEED0oooo0000003oool0ZZZZ05EEE@3o
ool0ZZZZ0?ooo`2ZZZX00P000000202ZZZX0oooo0000001EEED0000005EEE@2ZZZX0oooo0P1EEED0
1P000000EEEE0000002ZZZX0EEEE00000080EEEE00D0oooo0:ZZZP1EEED0oooo05EEE@020?ooo`80
ZZZZ00L000000:ZZZP000000ZZZZ0?ooo`000000ZZZZ0080000000<0oooo0:ZZZP2ZZZX02`3oool:
0=7=Z@/0oooo00@0ZZZZ0?ooo`2ZZZX0oooo0`2ZZZX01`1EEED00000000000000000oooo0:ZZZP3o
ool00P1EEED01@2ZZZX0oooo0000001EEED0ZZZZ0080oooo00H0EEEE0:ZZZP3oool0oooo0:ZZZP00
00020?ooo`80EEEE00<0000005EEE@2ZZZX00P1EEED30?ooo`060000001EEED0000005EEE@3oool0
ZZZZ0P3oool00`2ZZZX0EEEE0:ZZZP0;0?ooo`X0dLfY2`3oool01P2ZZZX0oooo05EEE@000000ZZZZ
05EEE@<0oooo00@0EEEE0:ZZZP2ZZZX0oooo0P1EEED00`2ZZZX0oooo0:ZZZP0405EEE@030?ooo`00
0000oooo00D0oooo00@0EEEE0000001EEED0EEEE0P3oool010000000EEEE05EEE@3oool20:ZZZP<0
oooo0P1EEED01@2ZZZX0000005EEE@1EEED0ZZZZ00/0oooo303AcJT000/0dLfY303oool20:ZZZP06
0000001EEED0oooo05EEE@3oool0EEEE0P2ZZZX01P000000oooo0:ZZZP3oool0EEEE0:ZZZP<00000
00H0EEEE000000000000ZZZZ05EEE@00000205EEE@030?ooo`000000000000<000000`2ZZZX0103o
ool0ZZZZ0000000000020:ZZZP0605EEE@3oool0oooo0?ooo`1EEED000000P2ZZZX<0?ooo`X0dLfY
303oool0102ZZZX000000000001EEED200000080EEEE00<0ZZZZ05EEE@0000000P2ZZZX010000000
ZZZZ0:ZZZP2ZZZX300000080EEEE00H0oooo05EEE@1EEED0ZZZZ05EEE@2ZZZX205EEE@030:ZZZP00
000000000080ZZZZ0P0000020:ZZZP030000001EEED000000080EEEE00<0ZZZZ0000001EEED00P00
00000`2ZZZX0oooo0?ooo`0:0?ooo`X0dLfY303oool01P2ZZZX00000000000000000EEEE0:ZZZP80
00000P3oool205EEE@<0oooo00T0000005EEE@3oool000000:ZZZP000000ZZZZ05EEE@3oool00P00
00000`3oool0ZZZZ0:ZZZP03000000030?ooo`1EEED0000000<0oooo0P1EEED20?ooo`80000000<0
ZZZZ05EEE@1EEED00P0000000`2ZZZX0oooo0?ooo`0:0?ooo`X0dLfY303oool20:ZZZP0405EEE@2Z
ZZX0oooo0?ooo`80ZZZZ00P0EEEE0000003oool0oooo0:ZZZP1EEED0ZZZZ05EEE@80000000D0EEEE
0000003oool0oooo05EEE@040:ZZZP0;0000003oool0oooo0:ZZZP1EEED000000:ZZZP1EEED00000
05EEE@2ZZZX00P3oool200000080ZZZZ0`3oool00`1EEED0ZZZZ0:ZZZP0<0?ooo`X0dLfY303oool2
0:ZZZP<0EEEE103oool01P2ZZZX0oooo0?ooo`3oool0EEEE0:ZZZP80000000L0oooo0:ZZZP000000
oooo0:ZZZP3oool000000080oooo00@0000005EEE@2ZZZX0oooo0P2ZZZX00`3oool0000000000002
05EEE@<0oooo00<0ZZZZ0000003oool00P3oool305EEE@80ZZZZ303oool<0=7=Z@002`3AcJT<0?oo
o`80ZZZZ00<0oooo05EEE@0000000P1EEED00`2ZZZX0oooo0:ZZZP020:ZZZP0A0000001EEED0ZZZZ
0?ooo`2ZZZX0EEEE0?ooo`1EEED0ZZZZ0?ooo`000000ZZZZ0000003oool0ZZZZ05EEE@3oool00P2Z
ZZX01`3oool0EEEE0?ooo`3oool0000005EEE@0000001@2ZZZX01P1EEED0oooo0000001EEED0oooo
0:ZZZPd0oooo2P3AcJT<0?ooo`<0ZZZZ00@0EEEE0:ZZZP2ZZZX0EEEE0P2ZZZX200000080oooo00P0
EEEE0?ooo`2ZZZX0oooo0:ZZZP1EEED000000?ooo`80ZZZZ0P1EEED0102ZZZX0EEEE0000002ZZZX2
0?ooo`0305EEE@2ZZZX0ZZZZ0080ZZZZ00<0EEEE0?ooo`1EEED00P0000020:ZZZP0305EEE@3oool0
ZZZZ00<0ZZZZ3@3oool:0=7=Z@`0oooo0P2ZZZX00`1EEED000000:ZZZP020?ooo`<0000000X0ZZZZ
0000002ZZZX000000:ZZZP000000EEEE0000001EEED000000P3oool00`2ZZZX0000005EEE@020000
00070:ZZZP3oool0oooo0000001EEED000000?ooo`03000000<0ZZZZ00@000000:ZZZP000000oooo
0P2ZZZX00`3oool0EEEE0:ZZZP0=0?ooo`X0dLfY303oool00`2ZZZX0oooo0?ooo`040:ZZZP80EEEE
1@00000205EEE@040?ooo`000000EEEE0:ZZZP80000000<0ZZZZ0?ooo`2ZZZX00P3oool01P2ZZZX0
00000000002ZZZX0EEEE00000080EEEE00@0oooo000000000000ZZZZ0P0000000`2ZZZX0EEEE0:ZZ
ZP020:ZZZP0305EEE@3oool0oooo00d0oooo2P3AcJT<0?ooo`050:ZZZP3oool0oooo0?ooo`1EEED0
0P0000000`1EEED0ZZZZ0?ooo`040?ooo`@0EEEE00D0000005EEE@1EEED000000?ooo`0205EEE@09
0000001EEED0ZZZZ0000001EEED0ZZZZ0000001EEED0ZZZZ0080EEEE1@3oool205EEE@040000001E
EED0EEEE05EEE@l0oooo303AcJT000/0dLfY3P3oool20:ZZZP070000001EEED0oooo0000002ZZZX0
00000:ZZZP0305EEE@80000000D0oooo000000000000oooo0:ZZZP020?ooo`070000002ZZZX0ZZZZ
0000001EEED0oooo0:ZZZP030000000305EEE@000000EEEE00<0EEEE00L0ZZZZ0000002ZZZX00000
0?ooo`1EEED000000080ZZZZ3P3oool:0=7=Z@h0oooo0P2ZZZX20?ooo`<0EEEE0P0000000`1EEED0
000005EEE@0205EEE@070?ooo`2ZZZX0ZZZZ0000001EEED000000?ooo`020:ZZZP060000002ZZZX0
ZZZZ0000001EEED000000P2ZZZX405EEE@040000001EEED00000000000@0EEEE00<0oooo0:ZZZP2Z
ZZX03P3oool:0=7=Z@h0oooo00D0ZZZZ05EEE@3oool0000005EEE@04000000030?ooo`000000ZZZZ
00<0000000X0oooo000000000000ZZZZ0000002ZZZX0EEEE0?ooo`000000EEEE0P000000102ZZZX0
00000000003oool3000000030:ZZZP000000ZZZZ0080000000D0ZZZZ0000001EEED000000?ooo`02
0:ZZZPh0oooo2P3AcJT>0?ooo`<0ZZZZ00P0oooo0:ZZZP3oool0EEEE0:ZZZP000000ZZZZ000000<0
EEEE00@0000005EEE@000000oooo0P000000102ZZZX0oooo05EEE@2ZZZX20?ooo`80000000<0ZZZZ
0000001EEED00P1EEED02P000000EEEE0000002ZZZX000000:ZZZP1EEED0oooo0:ZZZP1EEED30:ZZ
ZPh0oooo2P3AcJT>0?ooo`80ZZZZ00@0EEEE0:ZZZP3oool0ZZZZ0P3oool00`000000EEEE00000002
0?ooo`0>05EEE@3oool0oooo0:ZZZP1EEED0ZZZZ0?ooo`1EEED0ZZZZ0?ooo`1EEED0ZZZZ0000003o
ool30:ZZZP030?ooo`2ZZZX0EEEE0080oooo00<0000005EEE@0000000P3oool0102ZZZX0oooo0000
001EEED20:ZZZPh0oooo303AcJT000/0dLfY3`3oool02@2ZZZX0oooo05EEE@000000oooo05EEE@3o
ool0ZZZZ05EEE@030:ZZZP070?ooo`1EEED0ZZZZ0?ooo`2ZZZX0EEEE000000020:ZZZP030?ooo`2Z
ZZX0ZZZZ008000000P1EEED01@3oool0ZZZZ05EEE@3oool0EEEE00@0ZZZZ0`3oool010000000EEEE
0?ooo`2ZZZX?0?ooo`X0dLfY3`3oool01`2ZZZX0000005EEE@1EEED0000005EEE@3oool01`2ZZZX0
1@000000ZZZZ0:ZZZP2ZZZX0EEEE0080oooo00D0ZZZZ05EEE@3oool0oooo05EEE@030:ZZZP040000
001EEED0ZZZZ05EEE@80ZZZZ00D0EEEE0:ZZZP3oool0EEEE0000000205EEE@030000002ZZZX0oooo
00h0oooo2P3AcJT?0?ooo`040:ZZZP000000EEEE00000080oooo00l000000:ZZZP3oool0oooo0000
001EEED0000005EEE@000000EEEE0000001EEED0ZZZZ05EEE@0000000P3oool01P000000ZZZZ0:ZZ
ZP1EEED0000005EEE@D000000P3oool0102ZZZX000000:ZZZP3oool3000000030:ZZZP3oool0oooo
00d0oooo2P3AcJTA0?ooo`80ZZZZ00D0EEEE0?ooo`1EEED0EEEE0:ZZZP0205EEE@040:ZZZP000000
ZZZZ05EEE@8000000P2ZZZX2000000040?ooo`2ZZZX0000000000080ZZZZ0P00000205EEE@050000
001EEED0EEEE05EEE@2ZZZX00P1EEED01P3oool0EEEE0:ZZZP2ZZZX0oooo0:ZZZPl0oooo2P3AcJTA
0?ooo`040000002ZZZX0000000000080EEEE00D0ZZZZ05EEE@1EEED000000:ZZZP040?ooo`800000
0P3oool20:ZZZP050?ooo`1EEED000000000002ZZZX00`3oool01@2ZZZX0000005EEE@1EEED0ZZZZ
00<0EEEE00D000000:ZZZP1EEED0oooo0:ZZZP0?0?ooo``0dLfY000;0=7=Z@l0oooo0P2ZZZX00`3o
ool0ZZZZ05EEE@020:ZZZP050000002ZZZX0ZZZZ0?ooo`000000101EEED01@2ZZZX0oooo0000003o
ool0ZZZZ0080oooo00D0ZZZZ0?ooo`000000oooo0:ZZZP0205EEE@080000001EEED0ZZZZ0?ooo`2Z
ZZX0EEEE0000002ZZZX205EEE@030:ZZZP000000ZZZZ0100oooo2P3AcJT?0?ooo`80ZZZZ00H0EEEE
0:ZZZP2ZZZX0EEEE0:ZZZP0000020?ooo`070:ZZZP000000EEEE05EEE@3oool0ZZZZ000000020:ZZ
ZP060000002ZZZX0ZZZZ05EEE@2ZZZX0EEEE102ZZZX20?ooo`0605EEE@3oool0ZZZZ0?ooo`2ZZZX0
00001P2ZZZX@0?ooo`X0dLfY3`3oool20:ZZZP030?ooo`000000ZZZZ0080EEEE1@3oool02P1EEED0
oooo0000003oool0EEEE0?ooo`000000oooo05EEE@00000205EEE@80000000@0oooo05EEE@3oool0
00000P1EEED00`000000oooo0?ooo`020?ooo`0605EEE@000000ZZZZ0000001EEED0ZZZZ403oool:
0=7=Z@l0oooo00@0ZZZZ05EEE@1EEED0EEEE0`3oool505EEE@040?ooo`00000000000?ooo`<00000
00D0EEEE0?ooo`2ZZZX000000?ooo`030000000505EEE@3oool000000000003oool00`1EEED00`3o
ool0EEEE0?ooo`020?ooo`0305EEE@3oool0EEEE0100oooo2P3AcJT?0?ooo`050:ZZZP1EEED0EEEE
0000002ZZZX00P1EEED0203oool0ZZZZ0?ooo`000000ZZZZ0000001EEED000000P1EEED01@000000
oooo05EEE@000000oooo0080000000<0EEEE0?ooo`0000000P1EEED01@000000EEEE0000002ZZZX0
000000<0oooo00H0EEEE0:ZZZP2ZZZX000000?ooo`1EEED@0?ooo``0dLfY000;0=7=ZA40oooo00D0
ZZZZ0?ooo`1EEED000000?ooo`0305EEE@060:ZZZP1EEED0oooo05EEE@3oool0EEEE0`3oool00`00
0000ZZZZ000000020:ZZZP@0oooo00H0EEEE0?ooo`3oool0oooo05EEE@2ZZZX305EEE@050?ooo`1E
EED0EEEE0?ooo`2ZZZX04@3oool:0=7=ZA40oooo1@2ZZZX0103oool0ZZZZ0:ZZZP1EEED200000006
0?ooo`1EEED0oooo0:ZZZP3oool0ZZZZ0P1EEED0202ZZZX0000005EEE@1EEED0ZZZZ0?ooo`2ZZZX0
oooo0P1EEED00`000000EEEE05EEE@020:ZZZP030?ooo`2ZZZX0ZZZZ00<0ZZZZ4@3oool:0=7=ZA40
oooo00L0ZZZZ05EEE@3oool000000?ooo`2ZZZX0EEEE00<0oooo00L0ZZZZ0?ooo`000000oooo0:ZZ
ZP3oool000000080ZZZZ0P0000020:ZZZP050000003oool0ZZZZ0?ooo`0000000P2ZZZX00`000000
oooo0?ooo`020:ZZZP050?ooo`000000oooo05EEE@2ZZZX04@3oool:0=7=ZA@0oooo0P2ZZZX01@1E
EED0oooo0000002ZZZX0oooo008000000P2ZZZX01P3oool000000000003oool0000005EEE@H00000
0P2ZZZX0101EEED000000:ZZZP2ZZZX20000000305EEE@2ZZZX0ZZZZ0080oooo00<0ZZZZ0?ooo`3o
ool03`3oool:0=7=ZA<0oooo0`1EEED01@000000EEEE05EEE@1EEED0oooo00<0EEEE0P3oool205EE
E@050000002ZZZX0EEEE05EEE@2ZZZX00`1EEED20?ooo`<0EEEE00<0oooo05EEE@1EEED00P000000
1@1EEED0oooo05EEE@3oool0ZZZZ0140oooo303AcJT000/0dLfY4@3oool20:ZZZP030000002ZZZX0
EEEE00<0EEEE100000001@1EEED000000000003oool0EEEE00<0000000L0oooo000000000000EEEE
0?ooo`1EEED000000080EEEE00D000000:ZZZP000000EEEE0?ooo`0205EEE@030?ooo`000000ZZZZ
0180oooo2P3AcJTA0?ooo`80ZZZZ00L000000:ZZZP000000ZZZZ05EEE@2ZZZX0EEEE0080ZZZZ00<0
EEEE0000001EEED00`1EEED01P2ZZZX0EEEE0?ooo`2ZZZX0EEEE0:ZZZP80EEEE00<0ZZZZ05EEE@00
00000`2ZZZX0201EEED0ZZZZ05EEE@2ZZZX000000:ZZZP000000ZZZZ4P3oool:0=7=ZA40oooo0P2Z
ZZX01P000000EEEE0000001EEED000000:ZZZP80000000D0ZZZZ0000001EEED000000:ZZZP020000
00030?ooo`000000000000D0000000D0EEEE0000001EEED0EEEE0:ZZZP0200000080ZZZZ00D0EEEE
00000000000000000:ZZZP0B0?ooo`X0dLfY4@3oool0202ZZZX0EEEE0?ooo`3oool000000:ZZZP1E
EED000000P3oool00`1EEED0ZZZZ0:ZZZP0205EEE@060?ooo`000000000005EEE@3oool000000P1E
EED040000000oooo0:ZZZP1EEED0ZZZZ0000001EEED0ZZZZ0?ooo`000000EEEE0:ZZZP000000ZZZZ
0?ooo`1EEEDB0?ooo`X0dLfY4@3oool00`2ZZZX0EEEE0?ooo`020:ZZZP0505EEE@2ZZZX0ZZZZ0?oo
o`1EEED00P3oool405EEE@060?ooo`1EEED000000?ooo`2ZZZX000000P3oool00`1EEED0000005EE
E@0205EEE@040?ooo`2ZZZX0oooo0:ZZZP80EEEE00@0ZZZZ05EEE@3oool0EEEE4P3oool<0=7=Z@00
2`3AcJTB0?ooo`80ZZZZ00D0000005EEE@1EEED000000:ZZZP020?ooo`80ZZZZ00<0oooo0000002Z
ZZX00P1EEED01P2ZZZX0EEEE0000003oool0EEEE0?ooo`80EEEE00T0oooo0000003oool0EEEE0:ZZ
ZP1EEED0oooo0:ZZZP3oool00P1EEED30:ZZZQ80oooo2P3AcJTB0?ooo`80ZZZZ00D0oooo0:ZZZP1E
EED0oooo05EEE@020?ooo`040000003oool0EEEE0:ZZZP8000000`2ZZZX205EEE@040:ZZZP3oool0
ZZZZ00000080ZZZZ0P1EEED00`000000EEEE0?ooo`0305EEE@@0ZZZZ4P3oool:0=7=ZA80oooo0P2Z
ZZX0103oool000000:ZZZP3oool40000000405EEE@2ZZZX0EEEE05EEE@<0000000@0ZZZZ0000003o
ool0ZZZZ0`000000102ZZZX0EEEE0:ZZZP3oool400000080ZZZZ00@0000005EEE@2ZZZX0ZZZZ4P3o
ool:0=7=ZA80oooo0P2ZZZX0201EEED0oooo0000001EEED000000?ooo`2ZZZX0EEEE0`0000030:ZZ
ZP0405EEE@000000ZZZZ0:ZZZP8000000P2ZZZX01@3oool00000000000000000EEEE0080oooo00@0
00000:ZZZP000000oooo0`2ZZZXB0?ooo`X0dLfY4P3oool20:ZZZP0405EEE@000000ZZZZ0:ZZZP80
oooo0P2ZZZX00`1EEED0oooo05EEE@020:ZZZP090?ooo`2ZZZX0ZZZZ05EEE@000000ZZZZ05EEE@3o
ool0ZZZZ0080EEEE00<0oooo0:ZZZP2ZZZX0103oool00`2ZZZX000000:ZZZP020:ZZZQ80oooo303A
cJT000/0dLfY503oool00`2ZZZX000000?ooo`0205EEE@80ZZZZ00H0EEEE0?ooo`3oool0oooo0000
002ZZZX305EEE@80000000@0EEEE0000001EEED0ZZZZ103oool0201EEED0ZZZZ0:ZZZP1EEED0ZZZZ
0?ooo`000000ZZZZ503oool:0=7=ZA@0oooo0P2ZZZX305EEE@050?ooo`2ZZZX0ZZZZ0?ooo`1EEED0
0P3oool505EEE@030:ZZZP1EEED0EEEE0080EEEE0P3oool205EEE@80ZZZZ00@0oooo05EEE@000000
EEEE0P2ZZZXD0?ooo`X0dLfY503oool01@2ZZZX0EEEE0?ooo`000000EEEE00<0000000P0oooo0000
00000000oooo05EEE@000000ZZZZ05EEE@8000000P1EEED00`000000EEEE000000020000000905EE
E@00000000000000001EEED000000?ooo`1EEED0ZZZZ01@0oooo2P3AcJTD0?ooo`0405EEE@3oool0
oooo0:ZZZP80EEEE01H0000005EEE@1EEED0ZZZZ05EEE@3oool0ZZZZ0?ooo`000000EEEE0:ZZZP3o
ool0EEEE0:ZZZP3oool0ZZZZ0?ooo`1EEED0ZZZZ0000001EEED0oooo0P1EEED0102ZZZX0oooo0?oo
o`2ZZZXD0?ooo`X0dLfY503oool00`1EEED0oooo05EEE@020:ZZZP0605EEE@3oool0oooo05EEE@3o
ool0ZZZZ0`3oool01P000000EEEE0?ooo`3oool0EEEE0:ZZZP<0oooo00@0ZZZZ0?ooo`1EEED0oooo
0P1EEED01@2ZZZX0000005EEE@3oool0ZZZZ01@0oooo303AcJT000/0dLfY503oool30:ZZZP80EEEE
00H0oooo05EEE@3oool000000?ooo`1EEED2000000030?ooo`1EEED0ZZZZ00@0ZZZZ00H0oooo0000
00000000EEEE0?ooo`1EEED30?ooo`0405EEE@000000ZZZZ0:ZZZQD0oooo2P3AcJTD0?ooo`80ZZZZ
00D0000005EEE@1EEED000000:ZZZP02000000@0EEEE00P0000005EEE@3oool0oooo05EEE@3oool0
EEEE000000@0EEEE00D0ZZZZ0000002ZZZX0000005EEE@02000000030:ZZZP3oool0oooo01<0oooo
2P3AcJTD0?ooo`80ZZZZ00H0000005EEE@000000oooo05EEE@2ZZZX20000000405EEE@000000ZZZZ
0:ZZZP80EEEE0P2ZZZX205EEE@80ZZZZ00<0000005EEE@0000000`2ZZZX01@3oool0000000000000
0000ZZZZ01D0oooo2P3AcJTD0?ooo`<0ZZZZ00@0EEEE0:ZZZP000000EEEE0P2ZZZX01`1EEED0ZZZZ
0000002ZZZX0oooo05EEE@2ZZZX00P0000002`2ZZZX0EEEE0?ooo`2ZZZX000000:ZZZP1EEED00000
0:ZZZP1EEED0000000@0ZZZZ5@3oool:0=7=ZA@0oooo0`2ZZZX305EEE@80oooo0P1EEED300000003
0:ZZZP1EEED0oooo00<0oooo00H000000:ZZZP000000ZZZZ0000001EEED30?ooo`<0EEEE0P2ZZZXE
0?ooo``0dLfY000;0=7=ZAD0oooo0P2ZZZX205EEE@030000001EEED0EEEE0080ZZZZ100000030:ZZ
ZP030?ooo`2ZZZX0EEEE00@000000P2ZZZX01@1EEED0oooo0000001EEED0oooo0080ZZZZ5@3oool:
0=7=ZAD0oooo0`2ZZZX00`1EEED0ZZZZ0:ZZZP020?ooo`070:ZZZP000000ZZZZ0?ooo`000000ZZZZ
0000000205EEE@040000003oool000000?ooo`80000000H0ZZZZ05EEE@3oool0oooo0:ZZZP1EEED3
0:ZZZQD0oooo2P3AcJTE0?ooo`80ZZZZ00L0oooo0000002ZZZX0EEEE0?ooo`2ZZZX0EEEE00<0oooo
00@0ZZZZ0000002ZZZX0oooo102ZZZX0103oool000000?ooo`1EEED20?ooo`040000002ZZZX00000
05EEE@80ZZZZ5@3oool:0=7=ZAD0oooo00@0ZZZZ0?ooo`2ZZZX0ZZZZ0`1EEED00`000000ZZZZ05EE
E@0205EEE@0=0?ooo`2ZZZX0oooo05EEE@000000oooo0:ZZZP3oool0EEEE0:ZZZP1EEED0ZZZZ0?oo
o`0305EEE@040:ZZZP3oool0oooo0:ZZZQD0oooo2P3AcJTE0?ooo`050:ZZZP3oool0EEEE0?ooo`1E
EED00P0000000`1EEED0oooo05EEE@020:ZZZP030000003oool0oooo00<0oooo00P0EEEE0000002Z
ZZX0000005EEE@3oool0EEEE00000080EEEE0`3oool00`2ZZZX0oooo0?ooo`0C0?ooo``0dLfY000;
0=7=ZAL0oooo0P2ZZZX00`000000EEEE0?ooo`020:ZZZP090000003oool0EEEE05EEE@2ZZZX0oooo
0000001EEED0oooo00<0EEEE0P0000001@2ZZZX000000?ooo`1EEED000000080ZZZZ5`3oool:0=7=
ZAL0oooo0P2ZZZX20?ooo`0705EEE@3oool0ZZZZ0:ZZZP3oool0ZZZZ05EEE@020?ooo`070000001E
EED0oooo0:ZZZP1EEED0ZZZZ0?ooo`020:ZZZP<0EEEE00<0oooo0:ZZZP2ZZZX05`3oool:0=7=ZAL0
oooo00L0ZZZZ05EEE@3oool000000?ooo`000000EEEE00<0oooo00@0ZZZZ05EEE@1EEED000000`1E
EED02`2ZZZX0oooo0000003oool0EEEE0:ZZZP3oool000000?ooo`1EEED0ZZZZ01L0oooo2P3AcJTG
0?ooo`80ZZZZ00@0oooo0:ZZZP3oool0ZZZZ0`0000001@3oool0EEEE0:ZZZP3oool0EEEE0080oooo
0P1EEED0203oool00000000000000000ZZZZ0?ooo`2ZZZX0oooo0P2ZZZXG0?ooo`X0dLfY5`3oool2
0:ZZZP0305EEE@2ZZZX0oooo00<0oooo0P1EEED80:ZZZP80EEEE0P3oool0102ZZZX0oooo0000001E
EED20:ZZZQL0oooo303AcJT000/0dLfY5`3oool20:ZZZP060?ooo`1EEED000000?ooo`1EEED0oooo
0P1EEED00`3oool0EEEE05EEE@020:ZZZP80EEEE00X0oooo05EEE@2ZZZX0oooo05EEE@3oool00000
05EEE@3oool0ZZZZ603oool:0=7=ZAL0oooo0P2ZZZX01@000000EEEE05EEE@1EEED0ZZZZ00<0EEEE
00<0ZZZZ0000001EEED00P2ZZZX00`1EEED0ZZZZ0:ZZZP0305EEE@060:ZZZP000000EEEE05EEE@00
0000ZZZZ603oool:0=7=ZAL0oooo0P2ZZZX00`000000EEEE000000020:ZZZP060000001EEED0EEEE
0000002ZZZX000000P2ZZZX010000000ZZZZ0000001EEED2000000030:ZZZP1EEED0000000800000
00<0ZZZZ0?ooo`3oool05P3oool:0=7=ZAL0oooo00L0ZZZZ0?ooo`3oool0ZZZZ0?ooo`1EEED0oooo
008000000`3oool00`1EEED0oooo0:ZZZP0205EEE@80oooo00@0EEEE0000003oool0EEEE703oool:
0=7=ZAL0oooo00T0ZZZZ0?ooo`3oool000000:ZZZP1EEED0000005EEE@3oool0301EEED200000003
0:ZZZP1EEED0oooo01T0oooo303AcJT000/0dLfY603oool20:ZZZP030?ooo`2ZZZX0EEEE0080ZZZZ
0P1EEED010000000ZZZZ0000003oool40000000705EEE@000000ZZZZ0:ZZZP1EEED0ZZZZ00000002
0:ZZZQP0oooo2P3AcJTH0?ooo`80ZZZZ00<0EEEE0:ZZZP2ZZZX0101EEED0103oool0EEEE0:ZZZP3o
ool20:ZZZP80oooo00@0EEEE0?ooo`1EEED0EEEE1@2ZZZXH0?ooo`X0dLfY603oool20:ZZZP030?oo
o`000000ZZZZ0080oooo0P2ZZZX3000000070?ooo`00000000000?ooo`000000ZZZZ000000020?oo
o`030:ZZZP000000EEEE0080ZZZZ603oool:0=7=ZAP0oooo00<0ZZZZ05EEE@2ZZZX00`3oool01000
0000ZZZZ05EEE@3oool20:ZZZP050000003oool0ZZZZ0:ZZZP3oool00P1EEED00`000000oooo05EE
E@020?ooo`0305EEE@2ZZZX0oooo01L0oooo2P3AcJTH0?ooo`050:ZZZP1EEED0EEEE0000002ZZZX0
0P1EEED20?ooo`0405EEE@3oool0EEEE0?ooo`80EEEE00@0oooo05EEE@3oool0oooo0P1EEED01@2Z
ZZX000000?ooo`1EEED0ZZZZ01P0oooo303AcJT000/0dLfY6P3oool01@2ZZZX0oooo05EEE@000000
oooo00<0EEEE0P00000205EEE@030000003oool0EEEE0080EEEE00D0oooo0000001EEED0oooo0:ZZ
ZP0J0?ooo`X0dLfY6P3oool50:ZZZP80EEEE0P000000102ZZZX0EEEE0:ZZZP2ZZZX20000000305EE
E@3oool0ZZZZ00@0ZZZZ6P3oool:0=7=ZAX0oooo00H0ZZZZ05EEE@000000000005EEE@2ZZZX20000
00060?ooo`000000ZZZZ0:ZZZP000000oooo0`0000001@1EEED000000?ooo`1EEED0ZZZZ01X0oooo
2P3AcJTL0?ooo`050:ZZZP3oool0EEEE0:ZZZP3oool00`000000301EEED0ZZZZ0000003oool00000
0?ooo`000000EEEE0?ooo`1EEED0oooo0:ZZZQX0oooo2P3AcJTM0?ooo`80EEEE0`0000020?ooo`04
0:ZZZP3oool0oooo0:ZZZP<000000`1EEED00`3oool0ZZZZ0?ooo`0I0?ooo``0dLfY000;0=7=ZAX0
oooo0P2ZZZX0103oool0ZZZZ05EEE@3oool205EEE@80000000@0ZZZZ0000000000000000101EEED0
0`2ZZZX000000:ZZZP0K0?ooo`X0dLfY6P3oool40:ZZZP030000001EEED0ZZZZ00@0ZZZZ00<00000
0:ZZZP2ZZZX00`2ZZZX010000000ZZZZ0000002ZZZXK0?ooo`X0dLfY6P3oool20:ZZZP050000001E
EED000000:ZZZP3oool00`0000001@3oool000000000002ZZZX000000080oooo00@0000005EEE@00
0000ZZZZ6`3oool:0=7=ZAX0oooo00D0ZZZZ05EEE@3oool0ZZZZ05EEE@0200000080ZZZZ00@00000
0?ooo`2ZZZX000000P2ZZZX20000000405EEE@2ZZZX0oooo05EEEA/0oooo2P3AcJTJ0?ooo`030:ZZ
ZP1EEED0EEEE0080ZZZZ00D0EEEE0:ZZZP1EEED0EEEE0000000205EEE@050000001EEED0EEEE0:ZZ
ZP1EEED00P2ZZZX00`3oool0EEEE0?ooo`0J0?ooo``0dLfY000;0=7=ZA/0oooo0P2ZZZX03@000000
EEEE0?ooo`000000ZZZZ05EEE@2ZZZX0EEEE0?ooo`2ZZZX0oooo0:ZZZP0000000P1EEED00`000000
ZZZZ0:ZZZP0K0?ooo`X0dLfY6`3oool20:ZZZP030?ooo`2ZZZX0EEEE00@0oooo00@0ZZZZ05EEE@3o
ool0EEEE0P3oool00`1EEED0ZZZZ0?ooo`020:ZZZQ/0oooo2P3AcJTK0?ooo`030:ZZZP1EEED0oooo
008000000P1EEED01P3oool000000?ooo`3oool000000?ooo`80EEEE00<0ZZZZ0000003oool00P2Z
ZZXK0?ooo`X0dLfY6`3oool30:ZZZP0>05EEE@000000EEEE0?ooo`1EEED0oooo0:ZZZP000000oooo
05EEE@3oool0EEEE0000001EEED30:ZZZQ/0oooo2P3AcJTK0?ooo`80ZZZZ00P0EEEE0000003oool0
ZZZZ0?ooo`2ZZZX0EEEE0?ooo`80EEEE00H0ZZZZ0?ooo`2ZZZX0ZZZZ0000001EEED20:ZZZQ/0oooo
303AcJT000/0dLfY703oool20:ZZZP040000002ZZZX0EEEE05EEE@80ZZZZ00@0000005EEE@2ZZZX0
ZZZZ0P1EEED00`3oool000000:ZZZP0M0?ooo`X0dLfY703oool30:ZZZP040000001EEED0EEEE05EE
E@80ZZZZ00<0EEEE0:ZZZP3oool00`1EEED20:ZZZQd0oooo2P3AcJTL0?ooo`80ZZZZ00D0EEEE0000
00000000oooo0:ZZZP0205EEE@080?ooo`1EEED0ZZZZ0?ooo`000000oooo05EEE@2ZZZXM0?ooo`X0
dLfY703oool0102ZZZX0EEEE0?ooo`1EEED20:ZZZP0605EEE@2ZZZX0oooo0000002ZZZX0oooo0P2Z
ZZX00`1EEED0oooo05EEE@0M0?ooo`X0dLfY703oool0102ZZZX0EEEE0?ooo`0000030:ZZZP050000
003oool0oooo0000003oool00P2ZZZX00`1EEED0oooo05EEE@0M0?ooo``0dLfY000;0=7=ZAd0oooo
0P2ZZZX02@000000EEEE05EEE@3oool0ZZZZ0000003oool0ZZZZ0?ooo`0205EEE@<0ZZZZ7@3oool:
0=7=ZAd0oooo0P2ZZZX01`000000EEEE05EEE@2ZZZX000000?ooo`2ZZZX00P00000205EEE@030000
002ZZZX0ZZZZ01d0oooo2P3AcJTM0?ooo`80ZZZZ00@0000005EEE@000000ZZZZ0P0000001P2ZZZX0
000005EEE@000000EEEE00000080ZZZZ7@3oool:0=7=ZAd0oooo0P2ZZZX01@3oool0ZZZZ0?ooo`3o
ool000000080ZZZZ0P0000000`3oool0ZZZZ0:ZZZP020:ZZZQd0oooo2P3AcJTM0?ooo`80ZZZZ0`1E
EED00`000000ZZZZ0:ZZZP020:ZZZP<0EEEE0`2ZZZXM0?ooo``0dLfY000;0=7=ZAl0oooo00<0ZZZZ
0000003oool00P1EEED01`000000oooo05EEE@2ZZZX0oooo0000002ZZZX07`3oool:0=7=ZAl0oooo
00H0ZZZZ0000002ZZZX0ZZZZ05EEE@3oool205EEE@040000002ZZZX000000:ZZZQl0oooo2P3AcJTO
0?ooo`040:ZZZP00000000000:ZZZP@0000000@0EEEE000000000000ZZZZ7`3oool:0=7=ZAl0oooo
00`0EEEE0?ooo`2ZZZX0EEEE0:ZZZP3oool0EEEE0:ZZZP000000ZZZZ0?ooo`2ZZZXO0?ooo`X0dLfY
7`3oool00`1EEED0oooo05EEE@030:ZZZP060000002ZZZX0ZZZZ05EEE@3oool0ZZZZ7`3oool<0=7=
Z@002`3AcJTO0?ooo`<0ZZZZ0P1EEED010000000oooo05EEE@0000020:ZZZR00oooo2P3AcJTO0?oo
o`<0ZZZZ00@0EEEE0?ooo`1EEED0EEEE0P3oool20:ZZZR00oooo2P3AcJTO0?ooo`80ZZZZ00<0EEEE
0000000000000`0000000`3oool0EEEE0:ZZZP0P0?ooo`X0dLfY7`3oool30:ZZZP80EEEE0P3oool2
05EEE@80ZZZZ803oool:0=7=ZAl0oooo0`2ZZZX01P000000ZZZZ05EEE@1EEED0ZZZZ05EEE@80ZZZZ
803oool<0=7=Z@002`3AcJTP0?ooo`80ZZZZ0P1EEED010000000oooo05EEE@3oool20:ZZZR00oooo
2P3AcJTP0?ooo`80ZZZZ0P1EEED010000000EEEE05EEE@0000020:ZZZR00oooo2P3AcJTP0?ooo`80
ZZZZ1P0000020:ZZZR00oooo2P3AcJTP0?ooo`030:ZZZP3oool0EEEE00H0oooo00<0ZZZZ0?ooo`3o
ool07P3oool:0=7=ZB00oooo00L0ZZZZ0?ooo`1EEED000000?ooo`2ZZZX000000080oooo00<0ZZZZ
0?ooo`3oool07P3oool<0=7=Z@002`3AcJTR0?ooo`80ZZZZ00@0oooo0:ZZZP2ZZZX0ZZZZ8P3oool:
0=7=ZB80oooo00<0ZZZZ0000000000000P0000000`2ZZZX0oooo0?ooo`0P0?ooo`X0dLfY8P3oool0
1P2ZZZX000000:ZZZP1EEED000000:ZZZR80oooo2P3AcJTR0?ooo`H0ZZZZ8P3oool:0=7=ZB80oooo
0P2ZZZX205EEE@80ZZZZ8P3oool<0=7=Z@002`3AcJTR0?ooo`80ZZZZ0P3oool00`2ZZZX0oooo0?oo
o`0Q0?ooo`X0dLfY8P3oool50:ZZZR<0oooo2P3AcJTR0?ooo`80ZZZZ0P1EEED00`2ZZZX0oooo0?oo
o`0Q0?ooo`X0dLfY8P3oool00`2ZZZX0oooo0:ZZZP0U0?ooo`X0dLfY8P3oool00`2ZZZX0oooo05EE
E@0U0?ooo``0dLfY000;0=7=ZB<0oooo00@0ZZZZ0000002ZZZX0ZZZZ8`3oool:0=7=ZB<0oooo00@0
ZZZZ0000002ZZZX0ZZZZ8`3oool:0=7=ZB<0oooo00@0ZZZZ0000002ZZZX0ZZZZ8`3oool:0=7=ZB<0
oooo00@0ZZZZ0?ooo`1EEED0ZZZZ8`3oool:0=7=ZB<0oooo00@0ZZZZ0?ooo`1EEED0ZZZZ8`3oool<
0=7=Z@002`3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo
02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo
02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo303AcJT00?l0dLfY/P3AcJT00?l0dLfY
/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT000/0dLfY00D0oooo0:ZZZP2Z
ZZX000000?ooo`020000000505EEE@2ZZZX0oooo0?ooo`2ZZZX00P000000103oool000000:ZZZP1E
EED2000000050:ZZZP000000EEEE0000002ZZZX00P1EEED010000000oooo0:ZZZP3oool20:ZZZP05
05EEE@000000EEEE0?ooo`2ZZZX00`1EEED00`2ZZZX000000?ooo`020:ZZZP040000001EEED0EEEE
0:ZZZP80EEEE100000001`1EEED0ZZZZ0?ooo`3oool0000005EEE@2ZZZX00P3oool01P2ZZZX0EEEE
0:ZZZP000000ZZZZ00000080ZZZZ00<0oooo0=7=Z@3AcJT0203AcJT01@3oool0ZZZZ0:ZZZP000000
oooo0080ZZZZ00<0000005EEE@2ZZZX00P1EEED00`2ZZZX0oooo0:ZZZP0305EEE@070000001EEED0
ZZZZ0:ZZZP3oool0EEEE0000000205EEE@050000001EEED0oooo0?ooo`1EEED00P00000605EEE@80
000000D0ZZZZ0?ooo`3oool0EEEE0000000205EEE@060000001EEED0oooo0:ZZZP000000EEEE0P00
00001@1EEED0oooo0:ZZZP3oool0000000@0EEEE0P0000000`2ZZZX0EEEE000000020:ZZZP030?oo
o`3AcJT0dLfY00P0dLfY00@0oooo0:ZZZP2ZZZX0ZZZZ0P3oool01@2ZZZX0oooo05EEE@1EEED0oooo
0080ZZZZ00@0oooo0000001EEED0oooo1P2ZZZX01`1EEED0000005EEE@1EEED0oooo0:ZZZP000000
101EEED30?ooo`030:ZZZP3oool000000080EEEE00D0ZZZZ05EEE@00000000000?ooo`0205EEE@03
0000001EEED0ZZZZ00@0ZZZZ00D000000?ooo`3oool000000?ooo`020:ZZZP060?ooo`1EEED0EEEE
0?ooo`2ZZZX0oooo102ZZZX00`3oool0dLfY0=7=Z@080=7=Z@040?ooo`2ZZZX0ZZZZ0?ooo`80EEEE
00@0ZZZZ000000000000oooo0P1EEED0203oool0EEEE0?ooo`1EEED0oooo05EEE@3oool0ZZZZ0`00
00000`2ZZZX0000005EEE@030:ZZZP0:05EEE@3oool0ZZZZ0?ooo`1EEED0oooo0000002ZZZX0oooo
00000080EEEE00@0oooo0000003oool0EEEE0P2ZZZX205EEE@080000002ZZZX000000000001EEED0
ZZZZ0?ooo`1EEED30?ooo`@0EEEE00@0oooo00000000000000000P1EEED0103oool0ZZZZ0:ZZZP3o
ool:0=7=Z@030?ooo`2ZZZX0ZZZZ00<0EEEE00H0ZZZZ000000000000oooo05EEE@3oool200000006
05EEE@3oool0EEEE0000001EEED00000101EEED00`2ZZZX000000000000200000080EEEE00D00000
05EEE@000000000005EEE@020000000505EEE@000000000005EEE@3oool00P1EEED4000000080:ZZ
ZP000000EEEE05EEE@2ZZZX0000005EEE@00000305EEE@050000001EEED0oooo05EEE@3oool00P00
000205EEE@050:ZZZP1EEED0ZZZZ0:ZZZP3oool0303AcJT000/0dLfY00H0oooo0:ZZZP2ZZZX00000
05EEE@2ZZZX3000000070:ZZZP000000EEEE0:ZZZP000000oooo000000030:ZZZP0305EEE@2ZZZX0
000000800000102ZZZX205EEE@060:ZZZP3oool0EEEE0?ooo`1EEED0ZZZZ0P3oool20:ZZZP040?oo
o`1EEED000000:ZZZP80EEEE102ZZZX3000000030:ZZZP1EEED0ZZZZ0080ZZZZ00L000000?ooo`00
0000oooo05EEE@000000EEEE008000000P2ZZZX2000000030:ZZZP3oool0oooo00X0dLfY00D0oooo
0:ZZZP2ZZZX000000?ooo`020:ZZZP<0000000H0EEEE000000000000ZZZZ0?ooo`00000205EEE@04
0000001EEED0oooo0?ooo`<0EEEE00P0000005EEE@00000000000:ZZZP3oool0EEEE000000P0EEEE
0P0000000`3oool0ZZZZ05EEE@03000000<0EEEE00<0oooo0:ZZZP1EEED00P0000000`1EEED0ZZZZ
0?ooo`020:ZZZP030000001EEED0oooo008000000P2ZZZX2000000030:ZZZP3oool0oooo00X0dLfY
00@0oooo0:ZZZP2ZZZX0oooo0P1EEED0203oool0ZZZZ0000002ZZZX000000?ooo`000000oooo0P2Z
ZZX00`1EEED0oooo0:ZZZP020:ZZZP070?ooo`2ZZZX000000000001EEED0ZZZZ05EEE@020?ooo`0:
0000002ZZZX0EEEE05EEE@3oool0000005EEE@2ZZZX000000:ZZZP<0EEEE00<000000?ooo`2ZZZX0
0`1EEED00`000000ZZZZ0:ZZZP020?ooo`<0ZZZZ0P1EEED02P2ZZZX0oooo0000003oool000000:ZZ
ZP000000ZZZZ0?ooo`1EEED20?ooo`030:ZZZP3oool0oooo00X0dLfY00@0oooo0:ZZZP2ZZZX0oooo
0P1EEED20?ooo`040000001EEED0000005EEE@80000000H0ZZZZ0000001EEED0EEEE0?ooo`1EEED2
000000040?ooo`2ZZZX0ZZZZ0:ZZZP@0000000<0ZZZZ05EEE@3oool00P1EEED00`000000oooo0:ZZ
ZP020000000405EEE@3oool0oooo0:ZZZP@000000P2ZZZX20?ooo`090000003oool0EEEE0?ooo`00
0000EEEE0?ooo`2ZZZX000000080EEEE0`0000001P3oool0ZZZZ05EEE@000000oooo0:ZZZP80oooo
2P3AcJT01P3oool0ZZZZ0:ZZZP1EEED0oooo00000080oooo00<000000:ZZZP0000000P2ZZZX0201E
EED0oooo05EEE@1EEED0000005EEE@3oool000000P2ZZZX0101EEED0oooo0?ooo`3oool300000080
EEEE00<0ZZZZ05EEE@2ZZZX0101EEED01`000000EEEE0:ZZZP000000EEEE0000003oool00P000002
0?ooo`0=0000002ZZZX0ZZZZ0:ZZZP3oool0EEEE0:ZZZP1EEED000000?ooo`1EEED000000:ZZZP03
000000030?ooo`1EEED000000080EEEE00<0ZZZZ0?ooo`3oool0303AcJT000/0dLfY0`3oool20:ZZ
ZPH0000000<0ZZZZ0000003oool00P3oool30000000:05EEE@3oool0000005EEE@3oool000000:ZZ
ZP000000EEEE0?ooo`80ZZZZ00<000000:ZZZP1EEED01@2ZZZX010000000EEEE0:ZZZP3oool20:ZZ
ZP050?ooo`1EEED0ZZZZ0:ZZZP0000000P1EEED20000000305EEE@000000oooo008000000P3oool0
10000000ZZZZ0000001EEED20000000405EEE@000000ZZZZ0:ZZZP<0oooo2P3AcJT30?ooo`060:ZZ
ZP000000ZZZZ0000003oool000000`2ZZZX20?ooo`030:ZZZP00000000000080oooo00D0EEEE0000
003oool000000?ooo`0200000080EEEE0P2ZZZX00`1EEED0000005EEE@030000000305EEE@000000
0000008000000`1EEED0102ZZZX0000005EEE@1EEED4000000040?ooo`2ZZZX0EEEE0?ooo`<00000
00<0ZZZZ0?ooo`2ZZZX00`2ZZZX00`000000oooo05EEE@030:ZZZP<0oooo2P3AcJT30?ooo`030:ZZ
ZP000000EEEE0080ZZZZ0P0000001@2ZZZX0EEEE05EEE@3oool0000000<0oooo00D0ZZZZ0?ooo`2Z
ZZX0oooo0:ZZZP0205EEE@80oooo00@0ZZZZ05EEE@1EEED0EEEE102ZZZX205EEE@030000001EEED0
ZZZZ00<0ZZZZ0`1EEED00`2ZZZX000000?ooo`0205EEE@0:0:ZZZP3oool000000?ooo`2ZZZX00000
0?ooo`1EEED000000?ooo`80EEEE00@0ZZZZ0?ooo`000000ZZZZ0P1EEED20:ZZZP<0oooo2P3AcJT3
0?ooo`070:ZZZP000000EEEE05EEE@000000oooo000000020?ooo`040:ZZZP000000oooo0?ooo`80
EEEE0P3oool20:ZZZP0405EEE@3oool0oooo0?ooo`80000000D0EEEE0?ooo`3oool0EEEE0:ZZZP03
0000000605EEE@00000000000:ZZZP000000ZZZZ0`3oool2000000070:ZZZP3oool0oooo0?ooo`1E
EED0ZZZZ05EEE@020?ooo`060000001EEED0ZZZZ0?ooo`000000EEEE0P3oool01@1EEED0oooo0000
00000000EEEE0080ZZZZ0`3oool:0=7=Z@<0oooo0P2ZZZX01@1EEED000000?ooo`1EEED0000000@0
EEEE00H0ZZZZ0?ooo`1EEED0EEEE0000002ZZZX3000000D0ZZZZ00<0EEEE0000000000000`1EEED0
1P3oool0EEEE000000000000EEEE0?ooo`80EEEE0`0000020:ZZZP030000002ZZZX0ZZZZ00<00000
0P2ZZZX01`000000EEEE05EEE@1EEED0ZZZZ05EEE@3oool00P1EEED01@000000EEEE0?ooo`000000
EEEE0080ZZZZ0`3oool<0=7=Z@002`3AcJT40?ooo`040:ZZZP00000000000:ZZZP80000000T0ZZZZ
000000000000oooo0000002ZZZX0EEEE0000003oool00P2ZZZX3000000030?ooo`2ZZZX0oooo00<0
000000@0EEEE0:ZZZP3oool0oooo0`2ZZZX00`3oool0ZZZZ000000020?ooo`050000001EEED00000
0?ooo`0000000P2ZZZX02@3oool00000000000000000EEEE0:ZZZP3oool0ZZZZ05EEE@0200000004
0?ooo`2ZZZX000000:ZZZP80000000@0ZZZZ000000000000ZZZZ103oool:0=7=Z@@0oooo0P2ZZZX2
05EEE@060?ooo`2ZZZX0oooo0:ZZZP000000oooo102ZZZX01`1EEED0ZZZZ0:ZZZP000000oooo0000
002ZZZX00`0000020:ZZZP80000000@0EEEE0000001EEED000000P1EEED00`000000EEEE00000002
05EEE@030000002ZZZX0000000<0000000<0ZZZZ0?ooo`3oool00P0000000`2ZZZX0EEEE0:ZZZP03
0:ZZZP080?ooo`2ZZZX0ZZZZ0?ooo`2ZZZX0oooo05EEE@0000020:ZZZP@0oooo2P3AcJT40?ooo`80
ZZZZ00L000000?ooo`000000ZZZZ05EEE@000000EEEE0080ZZZZ00H000000?ooo`1EEED0ZZZZ0000
003oool205EEE@070000001EEED0EEEE0:ZZZP000000EEEE0000000605EEE@8000001P1EEED01000
0000EEEE0000003oool505EEE@050?ooo`000000ZZZZ0:ZZZP3oool00`2ZZZX01`1EEED0000005EE
E@3oool000000?ooo`0000000P2ZZZX40?ooo`X0dLfY103oool20:ZZZP<0EEEE00<000000?ooo`2Z
ZZX00P000000103oool0ZZZZ05EEE@1EEED200000080oooo00<0EEEE0000001EEED00P000000103o
ool000000:ZZZP3oool20:ZZZP80oooo00`0ZZZZ0000001EEED0ZZZZ05EEE@3oool0ZZZZ0000003o
ool0ZZZZ0000003oool20000000505EEE@000000EEEE0?ooo`1EEED00P00000205EEE@050:ZZZP3o
ool000000000002ZZZX00P3oool205EEE@030000002ZZZX0ZZZZ00@0oooo2P3AcJT40?ooo`040:ZZ
ZP1EEED0EEEE05EEE@80000000<0oooo05EEE@1EEED00P00000605EEE@050:ZZZP000000ZZZZ0:ZZ
ZP3oool00`0000000`1EEED0ZZZZ05EEE@020000000305EEE@000000oooo0080000000H0EEEE0000
00000000oooo0:ZZZP1EEED3000000060?ooo`2ZZZX0EEEE0000002ZZZX0oooo0P1EEED00`2ZZZX0
EEEE000000030000000405EEE@3oool0oooo000000<0EEEE00<0ZZZZ0?ooo`3oool00P3oool<0=7=
Z@002`3AcJT50?ooo`80ZZZZ00<000000:ZZZP0000000P1EEED01@2ZZZX00000000000000000ZZZZ
00<0000000H0EEEE0:ZZZP1EEED000000:ZZZP3oool205EEE@030000003oool0EEEE00@0000000@0
ZZZZ05EEE@3oool0ZZZZ100000000`1EEED0oooo0?ooo`0205EEE@050?ooo`2ZZZX0ZZZZ05EEE@2Z
ZZX0100000001@2ZZZX00000000000000000ZZZZ0080EEEE00<0oooo0:ZZZP0000000P2ZZZX50?oo
o`X0dLfY1@3oool30:ZZZP0:05EEE@3oool0ZZZZ0000003oool0ZZZZ0?ooo`000000oooo0:ZZZP80
00000P2ZZZX0201EEED0ZZZZ0?ooo`3oool0ZZZZ0000002ZZZX0oooo0P1EEED20000000305EEE@00
000000000080000000T0EEEE000000000000000005EEE@3oool0ZZZZ0000002ZZZX00P3oool01000
0000EEEE0:ZZZP3oool2000000050:ZZZP3oool0EEEE0?ooo`2ZZZX00P0000000`2ZZZX0oooo05EE
E@030:ZZZPD0oooo2P3AcJT50?ooo`030:ZZZP1EEED0EEEE0080EEEE0P0000000`1EEED0oooo05EE
E@0205EEE@030:ZZZP3oool0000000<0ZZZZ00D0oooo0:ZZZP2ZZZX0oooo000000090:ZZZP030?oo
o`2ZZZX0ZZZZ00D0ZZZZ0P0000060:ZZZP030?ooo`000000oooo00@0EEEE00@0oooo000000000000
00000`1EEED20:ZZZPD0oooo2P3AcJT50?ooo`070:ZZZP1EEED0EEEE05EEE@000000EEEE0?ooo`02
05EEE@060?ooo`1EEED0ZZZZ0:ZZZP000000ZZZZ0`0000001@2ZZZX000000000001EEED0oooo0080
ZZZZ00@0oooo0000003oool000000P1EEED20:ZZZP0705EEE@3oool000000?ooo`000000oooo0:ZZ
ZP020?ooo`<0000000H0ZZZZ00000000000000000:ZZZP0000020:ZZZP0705EEE@3oool0EEEE05EE
E@3oool0EEEE0?ooo`0205EEE@80ZZZZ1@3oool:0=7=Z@D0oooo0P2ZZZX01@1EEED0ZZZZ0:ZZZP2Z
ZZX000000080EEEE0P2ZZZX02@000000ZZZZ0000002ZZZX0oooo05EEE@3oool000000?ooo`020000
000705EEE@3oool000000000003oool0EEEE0?ooo`0205EEE@070000003oool0EEEE05EEE@3oool0
EEEE0?ooo`0200000080EEEE0P0000000`3oool000000?ooo`0205EEE@040:ZZZP000000EEEE0000
0080ZZZZ0P1EEED01@000000ZZZZ0000002ZZZX0EEEE0080ZZZZ1@3oool<0=7=Z@002`3AcJT60?oo
o`030:ZZZP000000000000<0ZZZZ00D0oooo0:ZZZP000000ZZZZ0?ooo`02000000060:ZZZP3oool0
oooo0:ZZZP1EEED000000`3oool00`000000ZZZZ05EEE@0205EEE@0I0?ooo`1EEED000000000003o
ool0000005EEE@3oool0EEEE0?ooo`1EEED0ZZZZ0000003oool000000?ooo`000000EEEE0:ZZZP3o
ool000000:ZZZP000000ZZZZ0?ooo`02000000@0ZZZZ00@0EEEE000000000000ZZZZ1P3oool:0=7=
Z@H0oooo00<0ZZZZ0000002ZZZX00P2ZZZX00`3oool0ZZZZ0:ZZZP02000000<0oooo00D000000:ZZ
ZP2ZZZX0000005EEE@020:ZZZP0305EEE@2ZZZX0oooo0080EEEE00H000000:ZZZP00000000000?oo
o`0000020?ooo`80000000L0ZZZZ05EEE@1EEED0EEEE0?ooo`2ZZZX0EEEE0080ZZZZ00L0EEEE0000
002ZZZX0oooo0000003oool0ZZZZ0080oooo00T000000:ZZZP1EEED0oooo0:ZZZP1EEED0ZZZZ0000
002ZZZX01P3oool:0=7=Z@H0oooo00<0ZZZZ000000000000102ZZZX01`000000oooo0000001EEED0
00000:ZZZP3oool0101EEED30?ooo`050000003oool0ZZZZ0?ooo`2ZZZX0103oool205EEE@030?oo
o`2ZZZX0oooo00<0oooo00@0ZZZZ0?ooo`000000ZZZZ0P3oool405EEE@030?ooo`2ZZZX0EEEE0080
EEEE00<0oooo0000002ZZZX00P2ZZZX3000000030:ZZZP3oool0oooo00@0oooo2P3AcJT60?ooo`05
0:ZZZP000000ZZZZ0?ooo`0000000`1EEED020000000ZZZZ0:ZZZP2ZZZX0oooo05EEE@2ZZZX0EEEE
0`3oool00`000000oooo05EEE@020?ooo`<0EEEE00@0oooo0000002ZZZX0oooo0`2ZZZX01@3oool0
EEEE05EEE@1EEED0oooo0080EEEE0P0000001P3oool0ZZZZ0?ooo`1EEED0oooo05EEE@80oooo00H0
ZZZZ000000000000EEEE0000001EEED2000000030:ZZZP000000ZZZZ00H0oooo2P3AcJT60?ooo`07
0:ZZZP1EEED0EEEE0:ZZZP000000oooo05EEE@040000000305EEE@3oool0ZZZZ008000000`1EEED0
0`000000EEEE0000000305EEE@050000001EEED000000?ooo`0000000P1EEED00`000000EEEE0000
000405EEE@80000000<0ZZZZ0000001EEED00P1EEED00`000000ZZZZ0:ZZZP020?ooo`D0000000<0
oooo0000003oool00P1EEED00`2ZZZX0oooo0?ooo`040?ooo``0dLfY000;0=7=Z@H0oooo0P2ZZZX0
101EEED0oooo0:ZZZP2ZZZX20?ooo`0305EEE@000000oooo0080EEEE00<000000:ZZZP1EEED00`00
00020:ZZZP040000001EEED0000000000080oooo0`0000000`1EEED0ZZZZ00000002000000080?oo
o`00000000000000001EEED0000005EEE@2ZZZX30000000605EEE@000000000005EEE@000000oooo
0P1EEED20?ooo`<0ZZZZ00<0EEEE0:ZZZP3oool01P3oool:0=7=Z@H0oooo0`2ZZZX00`1EEED0oooo
0000000205EEE@080:ZZZP000000oooo0?ooo`000000ZZZZ0?ooo`1EEED200000080ZZZZ00l0EEEE
0000002ZZZX0000005EEE@2ZZZX000000:ZZZP000000ZZZZ0000003oool0ZZZZ0000002ZZZX00P00
00000`1EEED000000?ooo`0200000080ZZZZ00L0EEEE0000001EEED000000:ZZZP000000ZZZZ0080
oooo00H0ZZZZ05EEE@2ZZZX000000?ooo`0000020:ZZZPL0oooo2P3AcJT60?ooo`@0ZZZZ0P3oool0
0`2ZZZX0oooo05EEE@030000000305EEE@2ZZZX0000000<0ZZZZ00<000000?ooo`2ZZZX01@1EEED0
1`3oool0EEEE05EEE@3oool0000005EEE@3oool00P1EEED20?ooo`80EEEE00@0oooo05EEE@2ZZZX0
oooo0P0000040:ZZZP0305EEE@00000000000080EEEE00@0oooo0:ZZZP3oool0oooo0`2ZZZX70?oo
o`X0dLfY1P3oool30:ZZZP<0EEEE00@0ZZZZ000000000000oooo0P1EEED01@3oool0EEEE00000000
0000ZZZZ00<0oooo00L0000005EEE@000000000005EEE@000000EEEE0080oooo00H0ZZZZ0?ooo`3o
ool0ZZZZ05EEE@3oool305EEE@040000001EEED0EEEE000000<0oooo00@0ZZZZ000000000000EEEE
0P3oool00`1EEED0oooo0000000200000080EEEE00<0oooo0:ZZZP2ZZZX01`3oool:0=7=Z@H0oooo
0P2ZZZX200000080oooo00H0000005EEE@2ZZZX0EEEE0:ZZZP00000205EEE@030?ooo`0000000000
0080000000@0EEEE0:ZZZP000000ZZZZ0`1EEED01@000000oooo05EEE@1EEED0ZZZZ0080EEEE00@0
00000?ooo`000000ZZZZ0`1EEED01@000000ZZZZ05EEE@000000EEEE0080000000P0oooo05EEE@1E
EED000000:ZZZP000000ZZZZ05EEE@<0oooo00<0ZZZZ0000002ZZZX01`3oool<0=7=Z@002`3AcJT8
0?ooo`030:ZZZP000000000000800000101EEED40?ooo`090000002ZZZX0EEEE0000002ZZZX00000
0:ZZZP000000ZZZZ00<000000P3oool02`000000EEEE000000000000ZZZZ0?ooo`000000ZZZZ0000
002ZZZX0000000<0ZZZZ00<0000005EEE@2ZZZX00P0000020?ooo`030:ZZZP1EEED0oooo0080EEEE
00<0ZZZZ0000000000000P2ZZZX80?ooo`X0dLfY203oool30:ZZZP@0EEEE00X0ZZZZ05EEE@1EEED0
EEEE0?ooo`2ZZZX0EEEE0000002ZZZX000000`2ZZZX0103oool0000005EEE@1EEED40:ZZZP040000
003oool0ZZZZ00000080ZZZZ00<0000005EEE@000000102ZZZX30000000305EEE@000000oooo00P0
EEEE0`2ZZZX80?ooo`X0dLfY203oool01P2ZZZX0EEEE0:ZZZP1EEED0oooo05EEE@80oooo0P2ZZZX2
0?ooo`0505EEE@2ZZZX0ZZZZ0?ooo`2ZZZX00P0000001@2ZZZX0EEEE0:ZZZP3oool000000080ZZZZ
0P1EEED20:ZZZP0405EEE@000000ZZZZ0:ZZZP80oooo00<0ZZZZ0000002ZZZX00P0000001@2ZZZX0
oooo0:ZZZP2ZZZX0000000<0oooo0P2ZZZX0103oool0EEEE05EEE@1EEED30:ZZZPP0oooo2P3AcJT8
0?ooo`030:ZZZP1EEED000000080oooo0`1EEED200000080EEEE00@0oooo0:ZZZP000000EEEE0P00
0000202ZZZX000000?ooo`2ZZZX0000005EEE@000000EEEE1@3oool01P2ZZZX0EEEE0000001EEED0
00000:ZZZP80000000H0ZZZZ000000000000oooo0000002ZZZX305EEE@030:ZZZP000000EEEE00<0
EEEE00@0oooo0000002ZZZX0ZZZZ203oool:0=7=Z@P0oooo00<0ZZZZ05EEE@1EEED00P1EEED20?oo
o`040000001EEED0ZZZZ000000@0EEEE00<0000005EEE@0000000P0000001`2ZZZX0oooo05EEE@1E
EED0oooo0:ZZZP1EEED00P0000002@2ZZZX000000000002ZZZX0oooo0000001EEED0oooo05EEE@03
0000000805EEE@3oool0EEEE05EEE@2ZZZX0EEEE0000002ZZZX205EEE@80oooo00<0ZZZZ05EEE@1E
EED00P2ZZZX80?ooo``0dLfY000;0=7=Z@T0oooo00<0ZZZZ05EEE@2ZZZX00`0000020?ooo`0305EE
E@2ZZZX000000080EEEE0`000000102ZZZX000000?ooo`1EEED2000000050:ZZZP1EEED0ZZZZ0:ZZ
ZP1EEED00P2ZZZX01@1EEED000000:ZZZP1EEED0ZZZZ0080000000@0EEEE0?ooo`2ZZZX0ZZZZ0`00
000205EEE@040000002ZZZX000000?ooo`<000000P2ZZZX00`1EEED0ZZZZ0?ooo`080?ooo`X0dLfY
2@3oool00`2ZZZX000000:ZZZP03000000040:ZZZP1EEED000000?ooo`80000000<0ZZZZ05EEE@2Z
ZZX01@2ZZZX2000000070:ZZZP1EEED0EEEE0?ooo`2ZZZX000000?ooo`020:ZZZP80EEEE0`000000
0`3oool0ZZZZ000000020:ZZZP070?ooo`1EEED0ZZZZ0:ZZZP000000oooo0000000205EEE@800000
00@0EEEE0:ZZZP000000ZZZZ2@3oool:0=7=Z@T0oooo00<0ZZZZ0000001EEED00P2ZZZX200000080
ZZZZ00<000000?ooo`1EEED00P1EEED02@3oool0EEEE0?ooo`1EEED0oooo0000001EEED0ZZZZ05EE
E@020?ooo`030:ZZZP1EEED0EEEE00<0EEEE0P3oool20:ZZZP0505EEE@3oool0oooo0:ZZZP3oool0
101EEED0202ZZZX0oooo0000001EEED0ZZZZ0?ooo`000000ZZZZ0P1EEED00`000000ZZZZ0?ooo`08
0?ooo`X0dLfY2@3oool02`2ZZZX0000005EEE@1EEED000000?ooo`000000oooo05EEE@2ZZZX0EEEE
0080ZZZZ00<0oooo05EEE@2ZZZX0103oool20:ZZZP8000000P3oool00`1EEED0oooo05EEE@0205EE
E@030?ooo`000000ZZZZ0080ZZZZ00P000000?ooo`1EEED0oooo0:ZZZP1EEED0oooo0:ZZZP80EEEE
00D0ZZZZ0?ooo`3oool0EEEE0?ooo`020000000305EEE@000000ZZZZ00T0oooo2P3AcJT90?ooo`03
0:ZZZP000000ZZZZ0080EEEE0P0000001P2ZZZX0oooo0:ZZZP1EEED0oooo00000080EEEE00@0ZZZZ
05EEE@2ZZZX0EEEE0P0000020:ZZZP80000000D0oooo05EEE@2ZZZX0ZZZZ05EEE@0300000080ZZZZ
0P0000001`1EEED0000005EEE@2ZZZX0000005EEE@0000000P1EEED30:ZZZP0305EEE@000000EEEE
0080ZZZZ00<000000:ZZZP3oool0203oool<0=7=Z@002`3AcJT:0?ooo`80ZZZZ00<0000005EEE@2Z
ZZX00P0000000`1EEED000000?ooo`0200000080ZZZZ0`000000302ZZZX0oooo0:ZZZP000000EEEE
0000003oool000000:ZZZP000000oooo0:ZZZP80oooo00L000000:ZZZP000000ZZZZ0000002ZZZX0
EEEE00<0000000@0ZZZZ0000002ZZZX0oooo0`0000020:ZZZP0405EEE@000000ZZZZ0:ZZZPX0oooo
2P3AcJT:0?ooo`80ZZZZ00@000000?ooo`00000000000P1EEED01@000000ZZZZ0:ZZZP000000EEEE
0080ZZZZ0P1EEED20:ZZZP80oooo00T0ZZZZ000000000000EEEE0?ooo`2ZZZX000000?ooo`1EEED0
0P0000000`2ZZZX0oooo0?ooo`020:ZZZP030000001EEED0ZZZZ0080EEEE00<000000?ooo`2ZZZX0
0P0000001@1EEED0oooo0000003oool000000080ZZZZ2P3oool:0=7=Z@X0oooo0P2ZZZX0101EEED0
ZZZZ0:ZZZP1EEED20000000305EEE@2ZZZX0ZZZZ0080ZZZZ00<0oooo05EEE@1EEED00`1EEED30:ZZ
ZP80EEEE1P2ZZZX205EEE@<0ZZZZ0P1EEED00`2ZZZX0EEEE05EEE@050:ZZZP80EEEE00D000000:ZZ
ZP2ZZZX0ZZZZ0?ooo`020:ZZZPX0oooo2P3AcJT:0?ooo`80ZZZZ00<0EEEE0000003oool00P1EEED0
2@3oool000000?ooo`1EEED0oooo05EEE@2ZZZX0oooo0:ZZZP0305EEE@80oooo00L0EEEE0?ooo`3o
ool0000005EEE@2ZZZX000000080EEEE1@3oool205EEE@050000002ZZZX0oooo0?ooo`1EEED00`3o
ool01`000000oooo05EEE@1EEED0oooo0000003oool00P2ZZZX:0?ooo`X0dLfY2P3oool20:ZZZP03
05EEE@3oool000000080oooo00@0EEEE0:ZZZP00000000000P2ZZZX305EEE@80ZZZZ100000070:ZZ
ZP040000002ZZZX0ZZZZ0:ZZZP80000000<0EEEE0:ZZZP1EEED00`1EEED20:ZZZP0305EEE@000000
ZZZZ0080oooo00@0EEEE0000003oool0EEEE0P2ZZZX:0?ooo``0dLfY000;0=7=Z@/0oooo00H0ZZZZ
05EEE@2ZZZX0oooo0:ZZZP1EEED20:ZZZP0305EEE@000000ZZZZ0080000000D0ZZZZ000000000000
ZZZZ05EEE@0200000080ZZZZ00D0EEEE0:ZZZP000000EEEE0:ZZZP020000000305EEE@2ZZZX0ZZZZ
008000000P2ZZZX200000080ZZZZ00@000000:ZZZP000000EEEE0P2ZZZX00`1EEED0ZZZZ0?ooo`03
0:ZZZP/0oooo2P3AcJT;0?ooo`<0ZZZZ0P1EEED0102ZZZX000000000002ZZZX205EEE@0=0000001E
EED0oooo0000002ZZZX0EEEE0:ZZZP1EEED0ZZZZ0000002ZZZX000000?ooo`02000000040:ZZZP00
00000000000000<0ZZZZ0`1EEED2000000040?ooo`000000000005EEE@80ZZZZ0P0000000`2ZZZX0
oooo05EEE@030:ZZZP/0oooo2P3AcJT;0?ooo`030:ZZZP1EEED0EEEE0080EEEE0P0000000`1EEED0
oooo0:ZZZP030?ooo`0905EEE@000000ZZZZ05EEE@000000EEEE0:ZZZP1EEED0ZZZZ00P0EEEE00<0
ZZZZ0000002ZZZX0101EEED00`000000EEEE05EEE@040?ooo`0305EEE@000000000000<0EEEE0P2Z
ZZX;0?ooo`X0dLfY2`3oool01@2ZZZX0EEEE05EEE@1EEED0000000D0EEEE0P0000030?ooo`80EEEE
00@0oooo05EEE@1EEED0EEEE0P00000205EEE@040?ooo`2ZZZX0EEEE05EEE@80000000H0oooo05EE
E@1EEED0000005EEE@2ZZZX20?ooo`040:ZZZP00000000000?ooo`80EEEE00<0oooo05EEE@3oool0
0P1EEED20:ZZZP/0oooo2P3AcJT;0?ooo`030:ZZZP000000ZZZZ0080000000D0EEEE000000000000
000005EEE@020:ZZZP0305EEE@2ZZZX0EEEE0080ZZZZ0`1EEED0103oool0ZZZZ0:ZZZP3oool205EE
E@030?ooo`1EEED0EEEE0080ZZZZ101EEED01@2ZZZX0EEEE05EEE@2ZZZX0EEEE0080ZZZZ00<0oooo
0000000000000`1EEED010000000ZZZZ0:ZZZP2ZZZX;0?ooo``0dLfY000;0=7=Z@`0oooo0P2ZZZX3
0000000505EEE@00000000000:ZZZP0000000P2ZZZX00`000000ZZZZ0?ooo`020:ZZZP0305EEE@2Z
ZZX000000080ZZZZ0P1EEED20000000305EEE@2ZZZX0ZZZZ00<0ZZZZ00P0EEEE0?ooo`2ZZZX00000
0:ZZZP000000oooo0:ZZZPH0000000@0EEEE0000002ZZZX0ZZZZ303oool:0=7=Z@`0oooo00@0ZZZZ
0000002ZZZX0ZZZZ0`000000102ZZZX0000005EEE@00000205EEE@060?ooo`1EEED0EEEE05EEE@2Z
ZZX000000P2ZZZX01P000000ZZZZ0?ooo`000000EEEE0?ooo`8000000P2ZZZX01P000000ZZZZ05EE
E@1EEED0ZZZZ0?ooo`80EEEE00/0000005EEE@2ZZZX0ZZZZ0000002ZZZX0000005EEE@2ZZZX00000
0:ZZZP0<0?ooo`X0dLfY303oool00`2ZZZX00000000000040:ZZZP030000002ZZZX0oooo00800000
00d0oooo05EEE@1EEED0000005EEE@2ZZZX0EEEE0000002ZZZX0EEEE0:ZZZP1EEED0000000@0EEEE
00/0ZZZZ0000001EEED0ZZZZ0?ooo`000000ZZZZ05EEE@3oool0ZZZZ000000020?ooo`040000002Z
ZZX0ZZZZ0:ZZZP<0000000<0ZZZZ0?ooo`3oool02P3oool:0=7=Z@`0oooo00@0ZZZZ0000002ZZZX0
oooo0P00000205EEE@030000002ZZZX0EEEE00<0oooo00D0EEEE000000000000ZZZZ0000000305EE
E@040000001EEED0oooo0?ooo`@0EEEE0P0000000`2ZZZX0oooo000000040?ooo`0305EEE@2ZZZX0
000000<0EEEE0P0000000`2ZZZX000000:ZZZP0<0?ooo`X0dLfY303oool20:ZZZP0505EEE@000000
oooo0000002ZZZX00P1EEED20?ooo`<0000000D0oooo05EEE@000000EEEE0000000205EEE@050?oo
o`000000EEEE05EEE@0000000P1EEED01P3oool0EEEE000000000000EEEE0?ooo`80EEEE0P000000
2P1EEED0oooo0?ooo`000000EEEE0:ZZZP1EEED0oooo0000001EEED20:ZZZP`0oooo303AcJT000/0
dLfY3@3oool40:ZZZP030000002ZZZX0000000<000000P1EEED00`2ZZZX00000000000020:ZZZP80
000000@0ZZZZ05EEE@3oool0EEEE0P0000000`1EEED0000005EEE@020:ZZZP040000002ZZZX00000
00000080ZZZZ00X0EEEE00000000000000000:ZZZP000000ZZZZ0000002ZZZX0EEEE0P2ZZZX=0?oo
o`X0dLfY3@3oool20:ZZZP040000003oool0ZZZZ00000080ZZZZ10000000103oool0ZZZZ00000000
00020:ZZZP80oooo00H0ZZZZ0?ooo`3oool0ZZZZ0000003oool20:ZZZP80oooo0P2ZZZX300000003
0?ooo`0000000000008000000P2ZZZX010000000ZZZZ0?ooo`0000020:ZZZPd0oooo2P3AcJT=0?oo
o`80ZZZZ00@0oooo05EEE@3oool0oooo0P2ZZZX010000000ZZZZ0:ZZZP0000020:ZZZP030?ooo`2Z
ZZX0000000<0ZZZZ00P0000005EEE@000000000005EEE@000000EEEE000000<0ZZZZ00<000000:ZZ
ZP3oool00P2ZZZX00`000000oooo0:ZZZP02000000050:ZZZP3oool0EEEE05EEE@3oool00P2ZZZX=
0?ooo`X0dLfY3@3oool20:ZZZP030000001EEED0ZZZZ0080oooo00P0000005EEE@000000ZZZZ0000
002ZZZX0000005EEE@80ZZZZ00D0oooo0:ZZZP2ZZZX0ZZZZ0?ooo`0205EEE@030000001EEED0ZZZZ
0080ZZZZ0P3oool02P2ZZZX0EEEE05EEE@1EEED0ZZZZ0000001EEED0000005EEE@0000020?ooo`80
EEEE00<0oooo0:ZZZP2ZZZX03@3oool:0=7=Z@d0oooo102ZZZX605EEE@80oooo00H0EEEE0?ooo`00
0000EEEE0000003oool305EEE@80oooo00<0ZZZZ05EEE@3oool00`1EEED0202ZZZX0oooo0000003o
ool000000?ooo`1EEED0oooo0`1EEED01P3oool0EEEE05EEE@000000ZZZZ00000080ZZZZ3@3oool<
0=7=Z@002`3AcJT>0?ooo`80ZZZZ00@000000?ooo`000000EEEE0P2ZZZX00`1EEED0ZZZZ0:ZZZP02
0:ZZZP040000002ZZZX0ZZZZ0?ooo`80EEEE00@0ZZZZ000000000000ZZZZ0P0000001`3oool0ZZZZ
05EEE@000000oooo0:ZZZP3oool00P0000030:ZZZP0705EEE@2ZZZX0EEEE05EEE@000000ZZZZ0000
00020:ZZZPh0oooo2P3AcJT>0?ooo`<0ZZZZ00L0EEEE0:ZZZP3oool0EEEE0000001EEED000000080
EEEE102ZZZX50?ooo`80000000<0ZZZZ0000002ZZZX0103oool30:ZZZP030?ooo`1EEED0EEEE0080
EEEE00D000000?ooo`3oool0ZZZZ05EEE@030:ZZZPh0oooo2P3AcJT>0?ooo`080:ZZZP1EEED0ZZZZ
05EEE@3oool0EEEE0:ZZZP3oool205EEE@040?ooo`2ZZZX0oooo0?ooo`D0ZZZZ00D0oooo0000001E
EED0EEEE0000000205EEE@030?ooo`2ZZZX0oooo0080ZZZZ0P3oool20:ZZZP80oooo00H0EEEE0?oo
o`3oool0EEEE0?ooo`1EEED30:ZZZPh0oooo2P3AcJT>0?ooo`050:ZZZP1EEED0000005EEE@3oool0
0`1EEED010000000ZZZZ0?ooo`1EEED2000000060:ZZZP3oool0oooo0?ooo`1EEED0oooo0P1EEED0
0`2ZZZX0000005EEE@020?ooo`0;05EEE@3oool0oooo0?ooo`2ZZZX000000?ooo`1EEED0oooo0:ZZ
ZP0000000`1EEED20?ooo`030000002ZZZX0ZZZZ00h0oooo2P3AcJT>0?ooo`80ZZZZ00L0EEEE0000
002ZZZX0ZZZZ0000001EEED000000080EEEE00D000000:ZZZP000000EEEE0:ZZZP020000000405EE
E@000000EEEE05EEE@80000000@0EEEE000000000000EEEE0P0000000`2ZZZX0EEEE000000020000
000505EEE@000000000005EEE@0000000`2ZZZX00`1EEED0ZZZZ0:ZZZP0>0?ooo``0dLfY000;0=7=
Z@l0oooo00<0ZZZZ0000001EEED00`2ZZZX01`3oool0ZZZZ05EEE@2ZZZX0EEEE0?ooo`0000000P1E
EED0102ZZZX000000000000000030:ZZZP0305EEE@2ZZZX0EEEE00<0000000@0ZZZZ05EEE@2ZZZX0
00000P1EEED0102ZZZX0EEEE0:ZZZP3oool30:ZZZP80000000<0ZZZZ0?ooo`3oool03@3oool:0=7=
Z@l0oooo00H0ZZZZ0000001EEED000000?ooo`00000305EEE@800000102ZZZX04P3oool0ZZZZ0?oo
o`000000ZZZZ05EEE@000000oooo05EEE@2ZZZX000000?ooo`000000oooo0:ZZZP000000ZZZZ0?oo
o`8000000`1EEED01P2ZZZX0oooo0000002ZZZX000000:ZZZPl0oooo2P3AcJT?0?ooo`030:ZZZP00
0000EEEE0080ZZZZ00<0oooo0000002ZZZX00P1EEED0103oool0ZZZZ0000002ZZZX20?ooo`<0EEEE
00@000000?ooo`2ZZZX0EEEE0P3oool305EEE@<0oooo00@000000?ooo`3oool0EEEE0P2ZZZX20000
0080ZZZZ00<0EEEE0000002ZZZX03`3oool:0=7=Z@l0oooo01D0ZZZZ000000000000EEEE0000001E
EED000000?ooo`1EEED0oooo05EEE@000000oooo05EEE@3oool0EEEE0?ooo`1EEED0000005EEE@3o
ool00P0000000`3oool000000000000305EEE@<0oooo00<0000005EEE@3oool00P3oool00`000000
oooo0000000205EEE@030000002ZZZX0oooo00h0oooo2P3AcJT?0?ooo`040:ZZZP1EEED0oooo0:ZZ
ZP<0000000<0EEEE0000002ZZZX00P2ZZZX00`3oool00000000000030000000305EEE@000000ZZZZ
00@0ZZZZ00<0EEEE0000003oool00P0000000`1EEED0oooo0:ZZZP030:ZZZP0505EEE@000000oooo
0000002ZZZX00P1EEED00`2ZZZX0oooo0?ooo`0=0?ooo``0dLfY000;0=7=ZA00oooo0P2ZZZX01000
0000EEEE0000003oool20000000805EEE@2ZZZX0oooo0000002ZZZX000000:ZZZP1EEED200000006
05EEE@00000000000?ooo`000000ZZZZ0P0000020:ZZZP060000002ZZZX000000000002ZZZX0EEEE
0P000000103oool0000005EEE@0000020:ZZZQ00oooo2P3AcJT@0?ooo`0<0:ZZZP00000000000?oo
o`2ZZZX000000?ooo`000000ZZZZ0000002ZZZX000000P1EEED02`3oool0ZZZZ0:ZZZP3oool00000
0:ZZZP1EEED0oooo0:ZZZP000000oooo0080ZZZZ00L0oooo05EEE@1EEED000000?ooo`000000ZZZZ
0080oooo0P000000103oool000000:ZZZP2ZZZX@0?ooo`X0dLfY403oool00`2ZZZX0oooo05EEE@02
0:ZZZP0405EEE@00000000000:ZZZP80EEEE00@0oooo0000001EEED0oooo0`0000000`3oool00000
0:ZZZP050000000405EEE@3oool0EEEE05EEE@80oooo00D0EEEE0:ZZZP1EEED0000005EEE@020:ZZ
ZP0305EEE@2ZZZX0ZZZZ0100oooo2P3AcJT@0?ooo`040:ZZZP3oool0EEEE000000<0EEEE00P0oooo
0000003oool0000005EEE@3oool000000?ooo`80ZZZZ1P0000000`2ZZZX000000:ZZZP020?ooo`07
0000001EEED0EEEE05EEE@3oool000000?ooo`0205EEE@030?ooo`000000EEEE0080ZZZZ403oool:
0=7=ZA00oooo0P2ZZZX0101EEED0000005EEE@0000030:ZZZP030000002ZZZX0ZZZZ00H0EEEE00H0
00000:ZZZP3oool0oooo0:ZZZP00000205EEE@050000001EEED0EEEE0000002ZZZX00P0000001`2Z
ZZX000000:ZZZP000000EEEE0000001EEED00P2ZZZX@0?ooo``0dLfY000;0=7=ZA40oooo00P0ZZZZ
000000000000ZZZZ0000001EEED0oooo05EEE@80ZZZZ00@0000005EEE@000000EEEE0P000000202Z
ZZX0oooo0000001EEED0ZZZZ0000003oool0ZZZZ0P0000001P1EEED00000000000000000EEEE0:ZZ
ZP<0EEEE100000000`2ZZZX0oooo0?ooo`0?0?ooo`X0dLfY4@3oool30:ZZZP80oooo00P000000?oo
o`1EEED0oooo0000002ZZZX0EEEE00000080ZZZZ0P3oool010000000oooo05EEE@1EEED50?ooo`03
0:ZZZP00000000000080ZZZZ00H0oooo05EEE@2ZZZX000000?ooo`1EEED30:ZZZQ40oooo2P3AcJTA
0?ooo`030:ZZZP1EEED0EEEE0080EEEE0P0000000`1EEED0ZZZZ0:ZZZP0205EEE@030?ooo`000000
ZZZZ00<0ZZZZ00@0EEEE0:ZZZP3oool0EEEE102ZZZX00`000000oooo0:ZZZP0205EEE@040:ZZZP1E
EED00000000000@0EEEE00<0ZZZZ0?ooo`3oool03`3oool:0=7=ZA40oooo00D0ZZZZ05EEE@1EEED0
oooo0000000405EEE@<000000`3oool00`1EEED0oooo0:ZZZP050:ZZZP030?ooo`1EEED0oooo0080
oooo00<0ZZZZ0000003oool00P1EEED00`3oool0EEEE0000000305EEE@030:ZZZP3oool0oooo00l0
oooo2P3AcJTA0?ooo`060:ZZZP1EEED0EEEE0:ZZZP1EEED0oooo0P2ZZZX01P3oool0ZZZZ0:ZZZP3o
ool0000005EEE@80ZZZZ00<0000005EEE@3oool00`3oool03@2ZZZX000000:ZZZP000000EEEE0000
001EEED0ZZZZ05EEE@3oool0ZZZZ05EEE@3oool0101EEED00`2ZZZX0oooo0?ooo`0?0?ooo``0dLfY
000;0=7=ZA80oooo0P2ZZZX01P000000ZZZZ0?ooo`2ZZZX0000005EEE@80oooo00<0EEEE00000000
00000P3oool010000000EEEE0:ZZZP3oool30:ZZZP030000003oool0000000<0000000<0oooo0:ZZ
ZP1EEED00P0000000`3oool0ZZZZ0:ZZZP020:ZZZQ80oooo2P3AcJTB0?ooo`80ZZZZ00<0000005EE
E@3oool00P1EEED00`3oool0ZZZZ00000002000000<0EEEE0P3oool04P000000EEEE000000000000
ZZZZ0?ooo`1EEED0ZZZZ05EEE@000000ZZZZ0000002ZZZX0oooo05EEE@000000oooo05EEE@<0ZZZZ
4P3oool:0=7=ZA80oooo102ZZZX02@3oool0ZZZZ0:ZZZP3oool0000005EEE@2ZZZX0oooo05EEE@02
0?ooo`0605EEE@3oool0oooo05EEE@2ZZZX0oooo0P1EEED00`3oool0EEEE05EEE@020?ooo`80EEEE
00@0oooo0:ZZZP3oool0oooo102ZZZXB0?ooo`X0dLfY4P3oool20:ZZZP050?ooo`1EEED0EEEE0000
002ZZZX01000000205EEE@030:ZZZP000000000000<0000000<0oooo0000003oool00P0000000`2Z
ZZX0EEEE05EEE@04000000040:ZZZP1EEED0EEEE05EEE@<0ZZZZ4P3oool:0=7=ZA80oooo0P2ZZZX0
0`1EEED0ZZZZ05EEE@0305EEE@80oooo00X0000005EEE@00000000000:ZZZP000000oooo0:ZZZP3o
ool0EEEE0P2ZZZX01@000000ZZZZ000000000000EEEE0080oooo1@1EEED40:ZZZQ80oooo303AcJT0
00/0dLfY4`3oool01@2ZZZX000000000001EEED0ZZZZ0080000000P0EEEE0:ZZZP00000000000:ZZ
ZP000000oooo00000080ZZZZ0P3oool20:ZZZP040000003oool000000:ZZZP80000000L0ZZZZ0000
0000000000000:ZZZP1EEED000000080ZZZZ4`3oool:0=7=ZA<0oooo00H0ZZZZ000000000000oooo
05EEE@0000030:ZZZP80000000H0ZZZZ05EEE@1EEED0EEEE0000002ZZZX2000000030:ZZZP3oool0
EEEE0080EEEE00X0ZZZZ0000002ZZZX0ZZZZ0?ooo`2ZZZX000000:ZZZP3oool000000P2ZZZXC0?oo
o`X0dLfY4`3oool0102ZZZX0oooo0?ooo`1EEED20?ooo`0;0:ZZZP000000EEEE05EEE@3oool0EEEE
0?ooo`2ZZZX000000:ZZZP3oool00P0000001P3oool000000000002ZZZX0000005EEE@80oooo00@0
EEEE0000002ZZZX0oooo0P1EEED00`3oool0ZZZZ0:ZZZP0C0?ooo`X0dLfY4`3oool01@2ZZZX0oooo
0000001EEED0ZZZZ0080oooo00L000000?ooo`3oool0000005EEE@3oool0ZZZZ0080EEEE00T0ZZZZ
0000003oool0ZZZZ0?ooo`1EEED0ZZZZ0?ooo`1EEED00P000000103oool000000?ooo`3oool205EE
E@030000002ZZZX0ZZZZ01<0oooo2P3AcJTC0?ooo`060:ZZZP1EEED0EEEE0?ooo`1EEED0oooo0P00
00000`1EEED000000:ZZZP030:ZZZP0505EEE@3oool0oooo0000001EEED00P3oool00`1EEED0ZZZZ
0:ZZZP020:ZZZP<0EEEE00D000000?ooo`000000oooo05EEE@020:ZZZQ<0oooo303AcJT000/0dLfY
503oool00`2ZZZX0EEEE0:ZZZP020:ZZZP0705EEE@2ZZZX0ZZZZ0000002ZZZX000000?ooo`020000
00030:ZZZP3oool0oooo0080oooo00L0ZZZZ000000000000ZZZZ0000002ZZZX000000080ZZZZ00H0
EEEE0:ZZZP3oool0ZZZZ05EEE@2ZZZXD0?ooo`X0dLfY503oool30:ZZZP80EEEE00<000000:ZZZP3o
ool00`2ZZZX01P1EEED000000:ZZZP2ZZZX0oooo00000080oooo00@0EEEE0:ZZZP00000000000`2Z
ZZX20?ooo`030000001EEED0EEEE00<0ZZZZ503oool:0=7=ZA@0oooo00X0ZZZZ05EEE@2ZZZX0EEEE
0?ooo`1EEED0ZZZZ05EEE@3oool000000P2ZZZX00`1EEED0000005EEE@040:ZZZP80000000@0EEEE
0:ZZZP2ZZZX000000P1EEED01`3oool0EEEE0?ooo`1EEED0ZZZZ05EEE@2ZZZX0503oool:0=7=ZA@0
oooo00D0ZZZZ05EEE@000000EEEE0?ooo`0305EEE@060:ZZZP000000EEEE0?ooo`1EEED0oooo0P2Z
ZZX01@000000oooo0:ZZZP000000oooo00<0EEEE00<000000?ooo`1EEED00P1EEED20?ooo`030000
001EEED0ZZZZ01@0oooo2P3AcJTD0?ooo`050:ZZZP000000ZZZZ05EEE@0000000P1EEED01P000000
EEEE0:ZZZP2ZZZX0oooo0:ZZZP<000000P2ZZZX01@000000ZZZZ0000002ZZZX0oooo0080ZZZZ00@0
oooo0000002ZZZX0EEEE0P0000000`2ZZZX000000:ZZZP0D0?ooo``0dLfY000;0=7=ZAD0oooo0P2Z
ZZX2000000030:ZZZP00000000000080EEEE00@0oooo0:ZZZP2ZZZX0ZZZZ1P3oool20:ZZZP040000
003oool0EEEE0:ZZZP80000000<0ZZZZ0000000000000P2ZZZXE0?ooo`X0dLfY5@3oool20:ZZZP04
0000001EEED0EEEE0?ooo`80ZZZZ00<0oooo0:ZZZP1EEED00P0000001P3oool0ZZZZ0000003oool0
ZZZZ05EEE@80000000<0EEEE0:ZZZP3oool00P2ZZZX00`000000EEEE05EEE@030:ZZZQD0oooo2P3A
cJTE0?ooo`80ZZZZ0P0000020?ooo`050:ZZZP1EEED0ZZZZ0:ZZZP0000000`2ZZZX4000000<0ZZZZ
00P0oooo0:ZZZP2ZZZX0EEEE0:ZZZP000000oooo000000<0ZZZZ5@3oool:0=7=ZAD0oooo0P2ZZZX0
1`000000EEEE05EEE@3oool000000:ZZZP3oool00`2ZZZX00`000000oooo0?ooo`0205EEE@030?oo
o`2ZZZX0000000<0ZZZZ0P3oool010000000EEEE05EEE@1EEED30:ZZZQD0oooo2P3AcJTE0?ooo`80
ZZZZ0`1EEED00`000000ZZZZ0?ooo`0405EEE@030000002ZZZX0ZZZZ0080oooo00D0ZZZZ0?ooo`00
0000EEEE0000000305EEE@030:ZZZP000000EEEE0080EEEE0P2ZZZXE0?ooo``0dLfY000;0=7=ZAH0
oooo00T0ZZZZ05EEE@2ZZZX0ZZZZ0000002ZZZX0oooo0000003oool00P2ZZZX80?ooo`070:ZZZP00
0000oooo0000003oool0ZZZZ000000040:ZZZQH0oooo2P3AcJTF0?ooo`030:ZZZP00000000000080
oooo00H0ZZZZ0?ooo`2ZZZX0000005EEE@00000205EEE@040?ooo`2ZZZX000000?ooo`80EEEE00<0
00000:ZZZP0000000`2ZZZX00`000000oooo000000020:ZZZQH0oooo2P3AcJTF0?ooo`030:ZZZP3o
ool0EEEE0080ZZZZ101EEED00`3oool0ZZZZ0:ZZZP050:ZZZP030?ooo`2ZZZX0ZZZZ00<0EEEE00D0
000005EEE@2ZZZX0ZZZZ05EEE@020:ZZZQH0oooo2P3AcJTF0?ooo`040:ZZZP3oool0EEEE00000080
EEEE103oool01@2ZZZX0oooo0?ooo`1EEED0000000<0EEEE00<0oooo0:ZZZP2ZZZX00P3oool205EE
E@030?ooo`000000EEEE0080ZZZZ5P3oool:0=7=ZAH0oooo00H0ZZZZ0000002ZZZX0ZZZZ05EEE@2Z
ZZX20000000505EEE@2ZZZX0ZZZZ0000001EEED0103oool01P1EEED000000:ZZZP000000EEEE0000
0080ZZZZ00<000000:ZZZP2ZZZX00P2ZZZXF0?ooo``0dLfY000;0=7=ZAL0oooo0P2ZZZX010000000
EEEE0:ZZZP2ZZZX2000000/0EEEE00<0ZZZZ0000000000000P2ZZZX2000000030:ZZZP3oool0oooo
01H0oooo2P3AcJTG0?ooo`80ZZZZ00<0000005EEE@2ZZZX00P3oool0202ZZZX00000000000000000
EEEE0000003oool0ZZZZ100000020:ZZZP060?ooo`000000ZZZZ0:ZZZP000000ZZZZ603oool:0=7=
ZAL0oooo0P2ZZZX2000000D0ZZZZ00<0oooo000000000000100000000`2ZZZX000000?ooo`050:ZZ
ZP80000000<0ZZZZ0?ooo`3oool05P3oool:0=7=ZAL0oooo0P2ZZZX2000000050?ooo`1EEED00000
05EEE@3oool00`1EEED20:ZZZP030?ooo`2ZZZX0000000@0EEEE0P000000103oool0ZZZZ0000002Z
ZZXH0?ooo`X0dLfY5`3oool20:ZZZP0605EEE@3oool0ZZZZ0000002ZZZX0EEEE0`0000001P2ZZZX0
00000:ZZZP2ZZZX0000005EEE@<0000000@0EEEE0:ZZZP000000ZZZZ0P1EEED00`2ZZZX0oooo0?oo
o`0F0?ooo``0dLfY000;0=7=ZAP0oooo0`2ZZZX0103oool0ZZZZ0?ooo`00000<0:ZZZP050000003o
ool0ZZZZ0?ooo`1EEED00P2ZZZXH0?ooo`X0dLfY603oool20:ZZZP060000001EEED0ZZZZ0000003o
ool000000`1EEED00`000000oooo05EEE@02000000<0EEEE00@0oooo0000003oool0EEEE0`2ZZZXH
0?ooo`X0dLfY603oool40:ZZZP050?ooo`2ZZZX0oooo0:ZZZP3oool00P0000000`3oool000000?oo
o`020?ooo`060000003oool0ZZZZ0?ooo`2ZZZX0oooo102ZZZXH0?ooo`X0dLfY603oool20:ZZZP07
0?ooo`1EEED0EEEE0000002ZZZX0000005EEE@020?ooo`80EEEE00P0oooo05EEE@000000oooo05EE
E@000000ZZZZ00000080EEEE0`2ZZZXH0?ooo`X0dLfY603oool30:ZZZP030000003oool0000000@0
ZZZZ00<000000?ooo`1EEED00P3oool50:ZZZP040000003oool0000000000080ZZZZ603oool<0=7=
Z@002`3AcJTI0?ooo`80ZZZZ0`0000030?ooo`040:ZZZP000000ZZZZ000000@0ZZZZ00H0oooo0:ZZ
ZP3oool0000005EEE@0000020:ZZZQT0oooo2P3AcJTI0?ooo`030:ZZZP000000000000<0ZZZZ00<0
000005EEE@2ZZZX00P0000001@1EEED0ZZZZ000000000000ZZZZ0080EEEE0P2ZZZX0103oool00000
0:ZZZP2ZZZXI0?ooo`X0dLfY6@3oool0102ZZZX0oooo0?ooo`1EEED20?ooo`050:ZZZP3oool00000
0:ZZZP1EEED00P2ZZZX00`1EEED0oooo000000040?ooo`0405EEE@3oool0ZZZZ0:ZZZQT0oooo2P3A
cJTI0?ooo`080:ZZZP3oool0000005EEE@2ZZZX0oooo0000003oool205EEE@040?ooo`2ZZZX00000
0?ooo`80EEEE0`3oool00`2ZZZX0EEEE000000020:ZZZQT0oooo2P3AcJTI0?ooo`80ZZZZ101EEED0
0`3oool0EEEE0?ooo`0305EEE@060000001EEED0EEEE0?ooo`1EEED0oooo0P1EEED010000000EEEE
0:ZZZP2ZZZXI0?ooo``0dLfY000;0=7=ZAX0oooo102ZZZX2000000<0ZZZZ00@000000?ooo`2ZZZX0
00000`2ZZZX2000000030:ZZZP1EEED0ZZZZ01/0oooo2P3AcJTJ0?ooo`<0ZZZZ00D0EEEE00000000
0000oooo000000020:ZZZP0505EEE@000000ZZZZ05EEE@0000000P3oool010000000EEEE0000002Z
ZZXK0?ooo`X0dLfY6P3oool20:ZZZP80EEEE00<0ZZZZ0000000000000P2ZZZX01`1EEED0000005EE
E@1EEED0oooo0:ZZZP0000000P2ZZZX00`1EEED000000:ZZZP0K0?ooo`X0dLfY6P3oool20:ZZZP08
05EEE@000000EEEE0?ooo`1EEED000000?ooo`1EEED20000000605EEE@000000000005EEE@000000
EEEE0P0000000`2ZZZX0oooo0?ooo`0I0?ooo`X0dLfY6P3oool40:ZZZP0405EEE@2ZZZX000000:ZZ
ZP80EEEE0P00000205EEE@070:ZZZP000000EEEE05EEE@2ZZZX000000:ZZZP0K0?ooo``0dLfY000;
0=7=ZA/0oooo0P2ZZZX00`000000ZZZZ000000040:ZZZP80EEEE00L0ZZZZ0000002ZZZX0ZZZZ0?oo
o`2ZZZX000000080ZZZZ6`3oool:0=7=ZA/0oooo0P2ZZZX01P000000EEEE0?ooo`2ZZZX000000?oo
o`80EEEE00D0000005EEE@00000000000:ZZZP0205EEE@030000002ZZZX0ZZZZ01/0oooo2P3AcJTK
0?ooo`80ZZZZ0`0000020?ooo`<0EEEE00<0000005EEE@1EEED00`3oool200000080ZZZZ6`3oool:
0=7=ZA/0oooo0P2ZZZX010000000EEEE05EEE@3oool2000000@0ZZZZ00<0oooo0000003oool00P1E
EED00`000000ZZZZ0:ZZZP0K0?ooo`X0dLfY6`3oool20:ZZZP0605EEE@2ZZZX0EEEE0?ooo`2ZZZX0
00001P2ZZZX0103oool0EEEE0:ZZZP1EEED20:ZZZQ/0oooo303AcJT000/0dLfY703oool20:ZZZP07
05EEE@3oool0ZZZZ0:ZZZP1EEED0oooo05EEE@020?ooo`0605EEE@2ZZZX0ZZZZ0:ZZZP1EEED0ZZZZ
7@3oool:0=7=ZA`0oooo0`2ZZZX01@1EEED0oooo0?ooo`2ZZZX000000080EEEE00@000000:ZZZP3o
ool0oooo0`2ZZZXM0?ooo`X0dLfY703oool20:ZZZP@0EEEE00<0ZZZZ0000001EEED00`00000405EE
E@030:ZZZP3oool0oooo01/0oooo2P3AcJTL0?ooo`80ZZZZ0P1EEED00`3oool000000?ooo`0205EE
E@050?ooo`1EEED0EEEE0000003oool00P1EEED00`2ZZZX0oooo0?ooo`0K0?ooo`X0dLfY703oool2
0:ZZZP80000000@0EEEE0000002ZZZX0ZZZZ0P3oool01`2ZZZX000000000001EEED0ZZZZ0000002Z
ZZX07@3oool<0=7=Z@002`3AcJTM0?ooo`80ZZZZ00<0000005EEE@0000000`0000001@3oool00000
000000000000EEEE00<0ZZZZ7@3oool:0=7=ZAd0oooo0`2ZZZX01P1EEED0ZZZZ0000002ZZZX0EEEE
000000<0ZZZZ00@0EEEE0000002ZZZX0ZZZZ7@3oool:0=7=ZAd0oooo0P2ZZZX200000080ZZZZ00@0
oooo0:ZZZP1EEED0oooo0P2ZZZX200000080ZZZZ7@3oool:0=7=ZAd0oooo0`2ZZZX00`000000oooo
05EEE@020000000405EEE@00000000000?ooo`8000000P2ZZZXM0?ooo`X0dLfY7@3oool20:ZZZP06
05EEE@00000000000?ooo`1EEED000000P1EEED00`3oool00000000000030:ZZZQd0oooo303AcJT0
00/0dLfY7P3oool00`2ZZZX00000000000030000000405EEE@2ZZZX000000:ZZZP8000000P2ZZZXN
0?ooo`X0dLfY7P3oool20:ZZZP040000001EEED0oooo00000080EEEE00@000000?ooo`1EEED00000
0P2ZZZXN0?ooo`X0dLfY7P3oool60:ZZZP80EEEE00<0ZZZZ0?ooo`2ZZZX00`2ZZZXN0?ooo`X0dLfY
7P3oool20:ZZZP040?ooo`1EEED0EEEE00000080ZZZZ00@0000005EEE@1EEED0oooo0P2ZZZXN0?oo
o`X0dLfY7P3oool0202ZZZX0EEEE05EEE@1EEED0000005EEE@3oool00000101EEED20:ZZZQh0oooo
303AcJT000/0dLfY7`3oool40:ZZZP050?ooo`1EEED000000?ooo`0000000P2ZZZXP0?ooo`X0dLfY
7`3oool30:ZZZP<0EEEE00<0000005EEE@2ZZZX00P2ZZZXP0?ooo`X0dLfY7`3oool20:ZZZP@0EEEE
00D0000005EEE@2ZZZX0EEEE0:ZZZP0P0?ooo`X0dLfY7`3oool20:ZZZP0905EEE@3oool0EEEE05EE
E@3oool0EEEE0000001EEED0ZZZZ0200oooo2P3AcJTO0?ooo`@0ZZZZ00D0000005EEE@2ZZZX00000
05EEE@020:ZZZR00oooo303AcJT000/0dLfY803oool20:ZZZP060000001EEED0ZZZZ0:ZZZP1EEED0
00000P2ZZZXP0?ooo`X0dLfY803oool30:ZZZP80EEEE00<0000005EEE@0000000P2ZZZXP0?ooo`X0
dLfY803oool20:ZZZP80EEEE0P000000101EEED000000:ZZZP2ZZZXP0?ooo`X0dLfY803oool20:ZZ
ZP0405EEE@000000000005EEE@8000000P2ZZZXP0?ooo`X0dLfY803oool20:ZZZP0605EEE@3oool0
00000:ZZZP3oool0EEEE0P2ZZZXP0?ooo``0dLfY000;0=7=ZB40oooo00D0ZZZZ05EEE@2ZZZX0ZZZZ
0?ooo`030:ZZZR40oooo2P3AcJTQ0?ooo`80ZZZZ00@0000005EEE@1EEED000000P2ZZZXQ0?ooo`X0
dLfY8@3oool20:ZZZP040000001EEED0000000000080ZZZZ8@3oool:0=7=ZB40oooo0P2ZZZX01000
0000EEEE05EEE@0000020:ZZZR40oooo2P3AcJTQ0?ooo`050:ZZZP000000ZZZZ0?ooo`0000000`2Z
ZZXQ0?ooo``0dLfY000;0=7=ZB80oooo0P2ZZZX2000000030:ZZZP3oool0oooo0240oooo2P3AcJTR
0?ooo`D0ZZZZ8`3oool:0=7=ZB80oooo0P2ZZZX205EEE@030:ZZZP3oool0oooo0240oooo2P3AcJTR
0?ooo`80ZZZZ0P1EEED00`2ZZZX0oooo0?ooo`0Q0?ooo`X0dLfY8P3oool20:ZZZP80EEEE00<0ZZZZ
0?ooo`3oool08@3oool<0=7=Z@002`3AcJTS0?ooo`040:ZZZP1EEED0ZZZZ0:ZZZR<0oooo2P3AcJTS
0?ooo`040:ZZZP000000ZZZZ0:ZZZR<0oooo2P3AcJTS0?ooo`040:ZZZP000000ZZZZ0:ZZZR<0oooo
2P3AcJTS0?ooo`040:ZZZP000000ZZZZ0:ZZZR<0oooo2P3AcJTS0?ooo`040:ZZZP000000ZZZZ0:ZZ
ZR<0oooo303AcJT000/0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0
oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0
oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo``0dLfY003o0=7=ZK80dLfY
003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY000;0=7=Z@030?oo
o`2ZZZX0ZZZZ0080oooo00<0EEEE0?ooo`0000000P2ZZZX205EEE@<0ZZZZ00L000000?ooo`3oool0
oooo0000003oool0EEEE00H0oooo00<000000?ooo`0000001@3oool0102ZZZX0oooo0?ooo`2ZZZX2
0?ooo`0405EEE@000000oooo000000@0oooo00<0EEEE0?ooo`1EEED00P000000103oool000000?oo
o`3oool20:ZZZP<0EEEE0P2ZZZX00`000000EEEE05EEE@020?ooo`80ZZZZ00<0oooo0=7=Z@3AcJT0
203AcJT0103oool0ZZZZ0:ZZZP3oool20:ZZZP8000000P3oool205EEE@030000002ZZZX0ZZZZ00<0
oooo00<0000005EEE@1EEED00P1EEED01P000000oooo0?ooo`1EEED0oooo05EEE@<0ZZZZ00D00000
0:ZZZP000000oooo000000020?ooo`80ZZZZ00L000000:ZZZP2ZZZX0ZZZZ05EEE@3oool0ZZZZ0080
oooo1@1EEED010000000ZZZZ0?ooo`3oool20:ZZZP<0EEEE0P3oool2000000030:ZZZP000000oooo
0080ZZZZ00<0oooo0=7=Z@3AcJT0203AcJT00`3oool0ZZZZ0:ZZZP0305EEE@<0ZZZZ0P1EEED00`2Z
ZZX000000?ooo`020?ooo`030000001EEED0EEEE00<0ZZZZ00<0EEEE0:ZZZP3oool00`2ZZZX01@3o
ool0EEEE0:ZZZP1EEED0ZZZZ0080EEEE00/000000?ooo`1EEED000000?ooo`1EEED0ZZZZ05EEE@2Z
ZZX0EEEE000000030:ZZZP030?ooo`2ZZZX0EEEE00<0ZZZZ00<0EEEE0000000000000`3oool0101E
EED0ZZZZ05EEE@1EEED30:ZZZP<0EEEE0P2ZZZX00`3oool0dLfY0=7=Z@080=7=Z@060?ooo`2ZZZX0
ZZZZ0000001EEED000000P3oool010000000oooo0:ZZZP2ZZZX200000080ZZZZ00D0EEEE0000002Z
ZZX0000005EEE@02000000<0oooo00@0ZZZZ0?ooo`000000oooo0`0000020:ZZZP040?ooo`1EEED0
oooo0?ooo`80ZZZZ0`000000103oool000000?ooo`1EEED30?ooo`80000000<0oooo0000002ZZZX0
0`1EEED00`2ZZZX000000?ooo`030:ZZZP060000003oool000000000003oool000000P2ZZZX00`3o
ool0dLfY0=7=Z@080=7=Z@040?ooo`2ZZZX0ZZZZ05EEE@80ZZZZ00H0EEEE0:ZZZP2ZZZX0000005EE
E@2ZZZX2000000<0ZZZZ00D0EEEE0?ooo`3oool0ZZZZ05EEE@020?ooo`040000001EEED0oooo05EE
E@@0oooo00<000000?ooo`0000000P2ZZZX01@1EEED0ZZZZ0?ooo`3oool0000000<0oooo00@00000
05EEE@3oool0EEEE0P0000000`3oool0EEEE0:ZZZP020?ooo`070000002ZZZX0ZZZZ0:ZZZP000000
EEEE0:ZZZP0205EEE@@0ZZZZ00D0000005EEE@2ZZZX0ZZZZ0?ooo`0<0=7=Z@002`3AcJT01`3oool0
ZZZZ0:ZZZP3oool000000?ooo`0000000`2ZZZX01@3oool0EEEE0?ooo`3oool0ZZZZ0080EEEE0P2Z
ZZX01@1EEED0ZZZZ0:ZZZP2ZZZX0oooo00@0EEEE00<0ZZZZ05EEE@0000000`3oool305EEE@030?oo
o`1EEED0oooo00<0oooo00<0000005EEE@1EEED01@1EEED20:ZZZP80EEEE00<0ZZZZ05EEE@1EEED0
0P2ZZZX00`3oool0ZZZZ05EEE@020?ooo`80ZZZZ0P3oool00`000000oooo0:ZZZP020?ooo`X0dLfY
00@0oooo0:ZZZP2ZZZX0oooo0P0000001P3oool000000000003oool000000?ooo`<0000000<0ZZZZ
0000000000001P2ZZZX01@000000oooo0:ZZZP2ZZZX0oooo0080ZZZZ00D0oooo05EEE@000000EEEE
0?ooo`0205EEE@050?ooo`000000000005EEE@3oool00P2ZZZX01@1EEED0ZZZZ0:ZZZP3oool00000
00H0ZZZZ1@0000020?ooo`030000002ZZZX0000000@0000000@0oooo0:ZZZP3oool0oooo2P3AcJT0
1`3oool0ZZZZ0:ZZZP1EEED0ZZZZ05EEE@3oool00P2ZZZX01P000000ZZZZ05EEE@000000ZZZZ0000
00<0EEEE00<0oooo0:ZZZP1EEED00P2ZZZX30?ooo`0405EEE@3oool0000005EEE@<0ZZZZ0P1EEED0
1P2ZZZX0000005EEE@2ZZZX0000005EEE@<0ZZZZ0P1EEED0103oool0EEEE0?ooo`3oool50:ZZZP03
0?ooo`2ZZZX0EEEE008000000P2ZZZX00`1EEED0ZZZZ05EEE@020:ZZZP050?ooo`1EEED0000005EE
E@2ZZZX00P3oool:0=7=Z@040?ooo`2ZZZX0ZZZZ0?ooo`<0EEEE00L000000:ZZZP3oool0oooo0:ZZ
ZP000000oooo0080ZZZZ00@0oooo0:ZZZP2ZZZX0oooo0P1EEED01`3oool000000:ZZZP2ZZZX00000
05EEE@2ZZZX0101EEED01P3oool0ZZZZ0:ZZZP2ZZZX000000:ZZZP80oooo00L0EEEE0?ooo`1EEED0
EEEE0:ZZZP1EEED000000080ZZZZ00P0EEEE0?ooo`1EEED000000?ooo`2ZZZX0EEEE0?ooo`80ZZZZ
00<0oooo0:ZZZP2ZZZX00P3oool01`2ZZZX000000?ooo`1EEED000000?ooo`2ZZZX00P3oool:0=7=
Z@060?ooo`2ZZZX0ZZZZ0?ooo`1EEED000000P1EEED010000000ZZZZ0:ZZZP2ZZZX205EEE@050?oo
o`2ZZZX0ZZZZ0000003oool0101EEED01P2ZZZX000000?ooo`1EEED0oooo000000@0ZZZZ00H0EEEE
0:ZZZP2ZZZX0EEEE0?ooo`2ZZZX205EEE@030:ZZZP000000ZZZZ0080ZZZZ00D0oooo0000003oool0
00000:ZZZP0205EEE@050000001EEED0oooo0?ooo`2ZZZX00P3oool01P1EEED0oooo0:ZZZP2ZZZX0
EEEE00000080EEEE00@0000005EEE@3oool0ZZZZ0P3oool<0=7=Z@002`3AcJT30?ooo`@0ZZZZ00D0
EEEE0?ooo`1EEED0oooo0:ZZZP030000000605EEE@2ZZZX0oooo0?ooo`2ZZZX0oooo0P1EEED0102Z
ZZX0oooo0:ZZZP3oool20:ZZZP080?ooo`000000EEEE0?ooo`1EEED000000?ooo`1EEED20?ooo`05
0000001EEED0oooo0?ooo`0000000P3oool30:ZZZP80oooo0P1EEED01@3oool0ZZZZ0?ooo`3oool0
ZZZZ00<0000000L0oooo0:ZZZP3oool000000?ooo`1EEED0oooo00<0ZZZZ0`3oool:0=7=Z@<0oooo
1@2ZZZX01@1EEED0oooo0?ooo`000000ZZZZ0080EEEE00<0oooo0000002ZZZX00P2ZZZX00`1EEED0
ZZZZ000000020:ZZZP030000001EEED0EEEE0080ZZZZ00T0oooo0:ZZZP3oool000000?ooo`2ZZZX0
oooo0000002ZZZX00P0000001P3oool000000?ooo`2ZZZX0oooo05EEE@8000000P2ZZZX00`000000
ZZZZ000000020:ZZZP<000000P1EEED01@3oool000000?ooo`000000EEEE00D0ZZZZ0`3oool:0=7=
Z@<0oooo00<0ZZZZ05EEE@1EEED00P1EEED01@000000EEEE0?ooo`1EEED0oooo008000000P2ZZZX0
1`1EEED000000000002ZZZX0000005EEE@2ZZZX0101EEED20:ZZZP80oooo0P2ZZZX20000000305EE
E@2ZZZX0000000<0ZZZZ0P3oool00`2ZZZX0EEEE05EEE@0305EEE@040000001EEED0000005EEE@80
000000<0EEEE0:ZZZP2ZZZX00P000000203oool0EEEE0?ooo`2ZZZX0000005EEE@000000EEEE0P2Z
ZZX30?ooo`X0dLfY0`3oool00`2ZZZX0EEEE05EEE@030:ZZZP0305EEE@3oool0000000@0ZZZZ00P0
oooo05EEE@3oool0oooo05EEE@2ZZZX000000?ooo`80000000H0oooo000000000000oooo0000002Z
ZZX405EEE@030:ZZZP000000EEEE00<0EEEE00H0ZZZZ0000003oool0EEEE0000003oool200000004
0?ooo`000000ZZZZ05EEE@80oooo00<000000?ooo`1EEED00P2ZZZX2000000030?ooo`000000ZZZZ
0080ZZZZ00<0EEEE0:ZZZP2ZZZX00`3oool:0=7=Z@<0oooo00@0ZZZZ05EEE@000000EEEE0P000000
0`2ZZZX0EEEE05EEE@020:ZZZP80EEEE0`3oool00`000000oooo0?ooo`0405EEE@030000001EEED0
oooo00<0EEEE00D0ZZZZ05EEE@000000000005EEE@030000000305EEE@2ZZZX0EEEE00L0EEEE00P0
ZZZZ05EEE@3oool0oooo0000003oool0EEEE0?ooo`80EEEE00<0ZZZZ05EEE@1EEED00P1EEED20000
000405EEE@000000ZZZZ0:ZZZP<0oooo303AcJT000/0dLfY103oool01@2ZZZX0oooo0?ooo`2ZZZX0
EEEE00<0oooo00@0EEEE0:ZZZP1EEED0ZZZZ103oool00`1EEED0oooo0:ZZZP030000000305EEE@3o
ool0oooo0080EEEE0P2ZZZX00`1EEED0000005EEE@020:ZZZP0305EEE@3oool0EEEE0080ZZZZ0P1E
EED20?ooo`0705EEE@000000000005EEE@2ZZZX0oooo05EEE@040?ooo`80EEEE00L0ZZZZ05EEE@3o
ool0oooo0000001EEED0ZZZZ0080oooo00<0ZZZZ0?ooo`3oool00P3oool:0=7=Z@@0oooo00<0ZZZZ
0?ooo`1EEED00P3oool205EEE@060000002ZZZX0ZZZZ0:ZZZP000000oooo0`0000020?ooo`0305EE
E@0000000000008000000P3oool01@2ZZZX0oooo000000000000ZZZZ0080000000<0oooo05EEE@00
00000P2ZZZX2000000030?ooo`2ZZZX0oooo0080oooo0`0000000`1EEED0oooo0000000200000003
05EEE@3oool0ZZZZ0080ZZZZ00@0oooo0000001EEED00000103oool00`2ZZZX0oooo0?ooo`020?oo
o`X0dLfY103oool20:ZZZP040000001EEED0ZZZZ0:ZZZP80000000L0EEEE0000003oool0EEEE0?oo
o`2ZZZX000000080ZZZZ0P1EEED60:ZZZP@0oooo00<0ZZZZ05EEE@1EEED00P2ZZZX00`1EEED0ZZZZ
0:ZZZP040?ooo`D0ZZZZ0`1EEED20:ZZZP050000001EEED0oooo05EEE@3oool0100000000`1EEED0
ZZZZ05EEE@030:ZZZP@0oooo2P3AcJT40?ooo`80ZZZZ00H0oooo0:ZZZP2ZZZX000000?ooo`1EEED2
0?ooo`050:ZZZP1EEED0oooo0:ZZZP0000000`2ZZZX00`3oool0EEEE0?ooo`0205EEE@80ZZZZ0P1E
EED0103oool0ZZZZ05EEE@2ZZZX205EEE@060?ooo`1EEED0oooo05EEE@2ZZZX0oooo0P1EEED20:ZZ
ZP80EEEE00<0oooo0000003oool00`2ZZZX200000080oooo00@0ZZZZ0?ooo`1EEED0EEEE0P3oool5
0:ZZZP@0oooo2P3AcJT40?ooo`80ZZZZ00L000000:ZZZP3oool0000005EEE@2ZZZX0EEEE00<0oooo
00L000000:ZZZP1EEED0EEEE0000001EEED0oooo00@0ZZZZ00<0EEEE0:ZZZP2ZZZX00`2ZZZX00`3o
ool0EEEE0?ooo`0205EEE@030?ooo`1EEED0oooo00@0ZZZZ00<0000005EEE@2ZZZX00`2ZZZX00`3o
ool0EEEE0?ooo`0305EEE@8000000`3oool01P2ZZZX0EEEE0000003oool0ZZZZ05EEE@80ZZZZ103o
ool<0=7=Z@002`3AcJT40?ooo`@0ZZZZ00<0oooo0000002ZZZX00`3oool00`1EEED0oooo0?ooo`03
0?ooo`050000003oool0ZZZZ0:ZZZP0000001P2ZZZX20?ooo`040:ZZZP000000oooo05EEE@80oooo
00<0EEEE0:ZZZP3oool00`2ZZZX01@1EEED0ZZZZ0:ZZZP2ZZZX000000080ZZZZ1P3oool02`2ZZZX0
EEEE0?ooo`000000oooo0:ZZZP1EEED0oooo0:ZZZP1EEED0ZZZZ00D0oooo2P3AcJT40?ooo`<0ZZZZ
00<0oooo0000002ZZZX00P2ZZZX02`000000EEEE000000000000oooo05EEE@000000ZZZZ0000003o
ool0ZZZZ00<0EEEE00d0oooo000000000000000005EEE@2ZZZX0EEEE0000001EEED0ZZZZ0?ooo`1E
EED0ZZZZ008000000`1EEED00`000000ZZZZ0000000405EEE@070:ZZZP3oool0ZZZZ0:ZZZP000000
ZZZZ0?ooo`020000000305EEE@000000ZZZZ0080ZZZZ00@000000?ooo`1EEED0ZZZZ1@3oool:0=7=
Z@@0oooo0`2ZZZX01@1EEED0oooo0:ZZZP2ZZZX000000080ZZZZ00@000000?ooo`3oool000001P2Z
ZZX:0?ooo`80EEEE00@0oooo05EEE@1EEED0EEEE1@3oool00`1EEED0oooo05EEE@020?ooo`<0ZZZZ
00<0EEEE0:ZZZP2ZZZX00P3oool200000080ZZZZ00@000000:ZZZP1EEED0oooo0P1EEED00`2ZZZX0
oooo0?ooo`030?ooo`X0dLfY103oool20:ZZZP80oooo00@0ZZZZ0000003oool000000`3oool01P00
0000EEEE05EEE@3oool0EEEE0?ooo`80ZZZZ1`3oool20000000405EEE@000000oooo0?ooo`800000
00X0oooo05EEE@000000EEEE0?ooo`000000oooo05EEE@3oool000000P3oool01@000000ZZZZ0:ZZ
ZP3oool0EEEE0080oooo0P1EEED30?ooo`040000003oool0ZZZZ0:ZZZP80oooo00<0ZZZZ0?ooo`3o
ool00`3oool:0=7=Z@@0oooo0P2ZZZX205EEE@070000002ZZZX0000005EEE@2ZZZX000000:ZZZP02
05EEE@<0ZZZZ00<000000?ooo`3oool00P2ZZZX01@3oool0ZZZZ0?ooo`1EEED000000080EEEE00<0
000005EEE@2ZZZX0101EEED02`3oool0EEEE000000000000EEEE0000001EEED0oooo0:ZZZP3oool0
ZZZZ00<0oooo0`2ZZZX01@3oool0EEEE0:ZZZP2ZZZX000000080EEEE00H000000?ooo`000000EEEE
0?ooo`2ZZZX50?ooo``0dLfY000;0=7=Z@H0oooo00T0ZZZZ0?ooo`000000oooo05EEE@2ZZZX0EEEE
0?ooo`0000000`3oool01`000000oooo0?ooo`000000EEEE0?ooo`1EEED01P3oool305EEE@80ZZZZ
00@0oooo0:ZZZP2ZZZX0oooo0`1EEED20?ooo`080:ZZZP3oool0oooo0?ooo`1EEED0000005EEE@00
00020?ooo`80000000<0oooo0000000000000P3oool01P2ZZZX0EEEE000000000000oooo0:ZZZPH0
oooo2P3AcJT60?ooo`060:ZZZP3oool000000?ooo`000000oooo0`1EEED20?ooo`040:ZZZP1EEED0
oooo05EEE@<0ZZZZ0`3oool02@2ZZZX0EEEE0:ZZZP2ZZZX0oooo0000002ZZZX000000?ooo`020:ZZ
ZP040?ooo`2ZZZX0ZZZZ000000<0ZZZZ00<0EEEE0:ZZZP2ZZZX00`3oool20:ZZZP060000003oool0
EEEE0:ZZZP3oool000000P1EEED00`000000oooo00000002000000030?ooo`2ZZZX0oooo00D0oooo
2P3AcJT60?ooo`040:ZZZP1EEED000000?ooo`<0EEEE00<000000:ZZZP2ZZZX00`1EEED20?ooo`80
00001@1EEED00`000000oooo05EEE@020:ZZZP050000003oool0EEEE05EEE@2ZZZX00P1EEED01000
0000ZZZZ0000001EEED20?ooo`0305EEE@2ZZZX0EEEE0080EEEE0P0000020?ooo`<0EEEE00<00000
0:ZZZP0000000`1EEED0103oool0000005EEE@2ZZZX60?ooo`X0dLfY1P3oool00`2ZZZX0EEEE0?oo
o`0205EEE@050000003oool0EEEE05EEE@3oool00P2ZZZX01`000000oooo0000003oool0EEEE0?oo
o`000000102ZZZX205EEE@030?ooo`1EEED0ZZZZ00<0oooo00H000000?ooo`1EEED0ZZZZ05EEE@3o
ool205EEE@@0ZZZZ00P000000?ooo`1EEED0oooo05EEE@3oool000000?ooo`80ZZZZ0`1EEED01P00
0000EEEE0000003oool0EEEE0:ZZZPH0oooo2P3AcJT60?ooo`0:0:ZZZP1EEED0000005EEE@3oool0
EEEE0:ZZZP1EEED000000?ooo`80EEEE00@0oooo05EEE@1EEED0EEEE0P2ZZZX00`000000ZZZZ0:ZZ
ZP020?ooo`8000000P3oool205EEE@80ZZZZ00@0EEEE0:ZZZP1EEED0EEEE0P3oool20000000505EE
E@3oool0EEEE0:ZZZP0000000P2ZZZX305EEE@80oooo00<0EEEE0:ZZZP0000000`1EEED01@3oool0
EEEE0000001EEED0ZZZZ00H0oooo303AcJT000/0dLfY1P3oool20:ZZZP0905EEE@2ZZZX0ZZZZ0:ZZ
ZP000000oooo0000003oool0EEEE0080ZZZZ0P0000020:ZZZP030000003oool0oooo0080oooo00<0
ZZZZ0000003oool00P3oool00`000000ZZZZ0:ZZZP020?ooo`070:ZZZP3oool000000?ooo`000000
oooo000000050?ooo`<0ZZZZ00<0oooo0000002ZZZX00`1EEED00`000000oooo0?ooo`020:ZZZP80
EEEE00<0ZZZZ0?ooo`3oool01@3oool:0=7=Z@H0oooo0P2ZZZX205EEE@030?ooo`000000ZZZZ0080
ZZZZ00D000000?ooo`3oool0oooo000000020:ZZZP80oooo0P1EEED20?ooo`0705EEE@3oool0oooo
0?ooo`000000EEEE000000020?ooo`060:ZZZP3oool0000005EEE@000000ZZZZ0P3oool00`2ZZZX0
oooo0?ooo`0205EEE@80oooo0P2ZZZX010000000oooo0:ZZZP3oool40:ZZZP050000003oool0EEEE
05EEE@2ZZZX01`3oool:0=7=Z@H0oooo0`2ZZZX01@000000EEEE0:ZZZP1EEED0ZZZZ0080EEEE00H0
ZZZZ05EEE@2ZZZX000000:ZZZP0000040:ZZZP0:05EEE@00000000000:ZZZP000000oooo05EEE@3o
ool0000005EEE@80ZZZZ00<0EEEE0000003oool00P1EEED010000000ZZZZ0:ZZZP0000050:ZZZP<0
000000X0ZZZZ0?ooo`2ZZZX0ZZZZ05EEE@2ZZZX000000:ZZZP1EEED000000P2ZZZX70?ooo`X0dLfY
1P3oool30:ZZZP80oooo0P0000000`2ZZZX0000005EEE@020?ooo`80EEEE00@0oooo0000001EEED0
EEEE0`2ZZZX0103oool0EEEE0?ooo`2ZZZX205EEE@060000002ZZZX0ZZZZ0?ooo`000000ZZZZ0P00
000205EEE@030:ZZZP3oool0oooo0080oooo0P2ZZZX205EEE@040000002ZZZX0EEEE05EEE@80oooo
0P0000020:ZZZP030000003oool000000080ZZZZ1`3oool:0=7=Z@H0oooo0`2ZZZX04@000000ZZZZ
0:ZZZP2ZZZX0oooo05EEE@000000oooo05EEE@2ZZZX0EEEE0:ZZZP1EEED0oooo05EEE@3oool0EEEE
0080ZZZZ00@0EEEE0?ooo`1EEED0ZZZZ101EEED00`2ZZZX0000005EEE@0505EEE@050?ooo`000000
ZZZZ0?ooo`1EEED00`3oool01P1EEED0oooo05EEE@2ZZZX000000?ooo`80EEEE00D0oooo0:ZZZP2Z
ZZX0ZZZZ05EEE@020:ZZZPL0oooo303AcJT000/0dLfY1`3oool30:ZZZP040?ooo`2ZZZX0EEEE05EE
E@80oooo00D000000?ooo`2ZZZX0ZZZZ05EEE@020?ooo`030:ZZZP000000oooo008000000P2ZZZX0
1@000000EEEE05EEE@1EEED0ZZZZ00@0oooo00L0ZZZZ05EEE@1EEED0oooo0000002ZZZX0oooo0080
000000<0oooo0000002ZZZX00P3oool010000000ZZZZ0:ZZZP3oool2000000050?ooo`1EEED0ZZZZ
0:ZZZP3oool00`2ZZZX70?ooo`X0dLfY1`3oool40:ZZZP0305EEE@0000000000008000000P3oool0
0`000000ZZZZ0?ooo`050:ZZZP0305EEE@2ZZZX0oooo0080EEEE00D000000:ZZZP2ZZZX000000:ZZ
ZP020?ooo`@0ZZZZ00<0000005EEE@1EEED01@2ZZZX00`1EEED0ZZZZ0:ZZZP020:ZZZP040000002Z
ZZX0oooo05EEE@<0000000<0EEEE0:ZZZP2ZZZX00P2ZZZX70?ooo`X0dLfY1`3oool20:ZZZP0405EE
E@2ZZZX0000005EEE@80ZZZZ00P0EEEE0?ooo`3oool000000:ZZZP000000oooo05EEE@80oooo00<0
ZZZZ05EEE@3oool00P2ZZZX205EEE@050000002ZZZX0ZZZZ0:ZZZP3oool00P2ZZZX00`000000ZZZZ
0000000205EEE@030:ZZZP000000oooo0080ZZZZ00@0oooo05EEE@1EEED0oooo0P2ZZZX00`000000
oooo0?ooo`030:ZZZP040?ooo`000000ZZZZ05EEE@80ZZZZ1`3oool:0=7=Z@L0oooo0P2ZZZX01`00
0000EEEE0?ooo`3oool0EEEE0?ooo`1EEED0100000000`1EEED0ZZZZ0:ZZZP020:ZZZP80oooo00L0
EEEE0?ooo`3oool0oooo0:ZZZP3oool0EEEE0080oooo0P1EEED01@3oool0EEEE05EEE@3oool0EEEE
0080oooo00@0000005EEE@3oool0oooo102ZZZX3000000040?ooo`000000EEEE0?ooo`80EEEE00<0
oooo05EEE@3oool00P2ZZZX70?ooo`X0dLfY1`3oool20:ZZZP80EEEE00L0000005EEE@000000oooo
0000002ZZZX0EEEE0080oooo101EEED02`000000oooo0?ooo`2ZZZX0EEEE0000003oool000000:ZZ
ZP1EEED0ZZZZ0080EEEE00P0oooo05EEE@000000EEEE0:ZZZP000000oooo00000080ZZZZ0P3oool0
1@000000ZZZZ05EEE@1EEED000000080oooo0P2ZZZX20?ooo`050000001EEED0000005EEE@3oool0
0P2ZZZX70?ooo``0dLfY000;0=7=Z@T0oooo00`0ZZZZ05EEE@2ZZZX0oooo0:ZZZP3oool000000?oo
o`1EEED0oooo0000003oool305EEE@060?ooo`000000ZZZZ0:ZZZP1EEED0ZZZZ0`3oool00`1EEED0
oooo0?ooo`040?ooo`0605EEE@3oool0EEEE0?ooo`2ZZZX0EEEE0P2ZZZX00`000000oooo0:ZZZP02
05EEE@040?ooo`000000oooo000000<0oooo0`2ZZZX00`1EEED0ZZZZ0?ooo`080?ooo`X0dLfY2@3o
ool0102ZZZX0EEEE0:ZZZP3oool30000000505EEE@00000000000000002ZZZX00`00000205EEE@80
000000<0ZZZZ0?ooo`0000000`1EEED01@2ZZZX0oooo0:ZZZP000000oooo00@0EEEE00<000000?oo
o`0000000P00000205EEE@H0000000<0oooo05EEE@0000000P000000103oool0ZZZZ05EEE@2ZZZX9
0?ooo`X0dLfY2@3oool0102ZZZX0EEEE0:ZZZP1EEED20?ooo`0405EEE@000000ZZZZ00000080EEEE
00@0ZZZZ05EEE@000000EEEE0P0000001`3oool0EEEE05EEE@3oool0EEEE0?ooo`1EEED00P000000
2`1EEED00000000000000000EEEE0?ooo`1EEED0oooo05EEE@000000oooo008000000`1EEED01P2Z
ZZX0000005EEE@000000ZZZZ000000<0oooo00@000000:ZZZP1EEED0ZZZZ2@3oool:0=7=Z@T0oooo
00@0ZZZZ05EEE@1EEED0EEEE0P2ZZZX01@3oool0ZZZZ0:ZZZP2ZZZX000000080ZZZZ0`3oool205EE
E@060?ooo`2ZZZX0EEEE0?ooo`000000EEEE0P2ZZZX01`000000ZZZZ0?ooo`000000EEEE0:ZZZP1E
EED00P3oool01@1EEED0oooo0?ooo`3oool0EEEE00<0oooo00<0ZZZZ0000000000000`2ZZZX0103o
ool0ZZZZ0:ZZZP2ZZZX205EEE@030:ZZZP3oool0oooo00L0oooo2P3AcJT90?ooo`040:ZZZP1EEED0
000005EEE@80000000H0oooo0:ZZZP00000000000?ooo`2ZZZX30?ooo`040000003oool0EEEE0:ZZ
ZP80oooo00<0ZZZZ0000001EEED00`0000002`1EEED000000000003oool0000005EEE@3oool0ZZZZ
0?ooo`000000ZZZZ0080oooo00<0000005EEE@3oool00`3oool010000000ZZZZ0:ZZZP3oool20000
000405EEE@000000EEEE0:ZZZPT0oooo303AcJT000/0dLfY2@3oool30:ZZZP80oooo00<0EEEE0?oo
o`0000000P2ZZZX01`1EEED0oooo05EEE@2ZZZX0oooo0000002ZZZX00P3oool00`1EEED0oooo0?oo
o`02000000P0oooo00H000000?ooo`3oool0oooo0:ZZZP3oool20:ZZZP030000003oool0ZZZZ00<0
EEEE0P2ZZZX00`000000EEEE05EEE@020?ooo`80ZZZZ2P3oool:0=7=Z@T0oooo0`2ZZZX020000000
ZZZZ0:ZZZP1EEED0ZZZZ0000001EEED0ZZZZ0P0000001P3oool000000?ooo`3oool000000?ooo`80
00001@2ZZZX0103oool000000000003oool50:ZZZP80000000d0oooo0000003oool0oooo0000003o
ool0000005EEE@2ZZZX0EEEE0?ooo`2ZZZX000000080ZZZZ00<0oooo0:ZZZP2ZZZX02P3oool:0=7=
Z@T0oooo0`2ZZZX205EEE@030000001EEED0ZZZZ0080ZZZZ00<000000?ooo`2ZZZX00P2ZZZX01P00
0000EEEE0000001EEED0ZZZZ000000<0EEEE00<000000:ZZZP0000000P2ZZZX00`000000ZZZZ0000
000305EEE@060000001EEED0EEEE0?ooo`1EEED000000`2ZZZX01@1EEED000000:ZZZP1EEED0ZZZZ
008000000P1EEED20:ZZZPX0oooo2P3AcJT90?ooo`<0ZZZZ00<0oooo05EEE@3oool0103oool01@1E
EED0oooo0?ooo`1EEED0oooo008000000`3oool02@2ZZZX0EEEE0:ZZZP3oool0EEEE0:ZZZP3oool0
EEEE000000020?ooo`0505EEE@3oool0000005EEE@2ZZZX00P3oool40000000605EEE@3oool0EEEE
05EEE@3oool0EEEE0`3oool0101EEED0ZZZZ0:ZZZP2ZZZX:0?ooo`X0dLfY2@3oool30:ZZZP050000
002ZZZX0oooo05EEE@3oool00P1EEED0303oool0EEEE05EEE@2ZZZX0oooo0000002ZZZX0000005EE
E@3oool0000005EEE@<0ZZZZ00H0EEEE0?ooo`1EEED0EEEE0?ooo`1EEED20:ZZZP80EEEE00<00000
05EEE@1EEED00P2ZZZX01`000000EEEE0:ZZZP1EEED000000?ooo`1EEED00P3oool010000000oooo
0:ZZZP1EEED20:ZZZPX0oooo303AcJT000/0dLfY2`3oool0102ZZZX0EEEE05EEE@2ZZZX205EEE@80
000000T0EEEE0?ooo`3oool0ZZZZ0000001EEED000000?ooo`0000000P3oool00`1EEED0ZZZZ0:ZZ
ZP090:ZZZP030?ooo`1EEED0oooo00@0000000H0EEEE0?ooo`2ZZZX0oooo0:ZZZP1EEED200000004
05EEE@2ZZZX0ZZZZ05EEE@80ZZZZ2`3oool:0=7=Z@/0oooo00<0ZZZZ05EEE@1EEED00P1EEED01`3o
ool0ZZZZ0?ooo`3oool0ZZZZ05EEE@0000000P3oool30:ZZZP80000000@0oooo05EEE@2ZZZX0EEEE
1@2ZZZX01P000000EEEE0:ZZZP000000oooo000000@0ZZZZ00@0oooo000000000000EEEE0`3oool0
0`1EEED0oooo05EEE@0205EEE@80ZZZZ2`3oool:0=7=Z@/0oooo0P2ZZZX010000000oooo0000002Z
ZZX20?ooo`0305EEE@00000000000080000000@0ZZZZ0000002ZZZX0oooo1P2ZZZX0103oool0ZZZZ
0000001EEED70:ZZZP80oooo00@0ZZZZ0000002ZZZX0EEEE0P0000001@3oool0EEEE0?ooo`000000
ZZZZ0080oooo00<000000:ZZZP2ZZZX02`3oool:0=7=Z@/0oooo00P0ZZZZ0000001EEED0oooo05EE
E@2ZZZX0EEEE0:ZZZP@0EEEE00H0ZZZZ0?ooo`1EEED0oooo0000001EEED30:ZZZP050000002ZZZX0
ZZZZ0:ZZZP3oool00P2ZZZX00`1EEED0ZZZZ000000040:ZZZP050000003oool0EEEE0?ooo`2ZZZX0
0P1EEED00`2ZZZX0EEEE0:ZZZP020:ZZZP0305EEE@3oool0EEEE0080ZZZZ2`3oool:0=7=Z@/0oooo
00@0ZZZZ0000001EEED0ZZZZ0P000000103oool0EEEE05EEE@2ZZZX20?ooo`030:ZZZP1EEED0oooo
0080EEEE0`2ZZZX30000000505EEE@2ZZZX0ZZZZ05EEE@2ZZZX00`000000203oool0ZZZZ0:ZZZP3o
ool0EEEE0000003oool0EEEE0`3oool305EEE@050?ooo`000000ZZZZ0:ZZZP1EEED00P2ZZZX;0?oo
o``0dLfY000;0=7=Z@`0oooo102ZZZX00`1EEED0000005EEE@020?ooo`80000000T0ZZZZ05EEE@3o
ool0EEEE0:ZZZP1EEED0oooo05EEE@2ZZZX01@3oool00`2ZZZX0oooo05EEE@020?ooo`070:ZZZP1E
EED0oooo05EEE@2ZZZX000000?ooo`0205EEE@80000000H0ZZZZ0?ooo`1EEED0oooo05EEE@3oool3
0:ZZZP`0oooo2P3AcJT<0?ooo`D0ZZZZ103oool00`2ZZZX0EEEE0:ZZZP05000000030?ooo`1EEED0
ZZZZ0080oooo1P0000020?ooo`80EEEE00<0oooo000000000000100000000`1EEED0ZZZZ0?ooo`02
0?ooo`0305EEE@2ZZZX0ZZZZ00<0ZZZZ303oool:0=7=Z@`0oooo00H0ZZZZ05EEE@1EEED0EEEE0?oo
o`00000205EEE@030000003oool0EEEE0080ZZZZ00@0EEEE0?ooo`3oool0oooo0P1EEED00`3oool0
ZZZZ0:ZZZP020?ooo`040:ZZZP1EEED0oooo0?ooo`80ZZZZ00<0oooo05EEE@1EEED00P3oool205EE
E@040:ZZZP000000EEEE0?ooo`@0EEEE00D0oooo0000001EEED0EEEE0:ZZZP0<0?ooo`X0dLfY303o
ool00`2ZZZX0EEEE0?ooo`030?ooo`0305EEE@3oool0ZZZZ0080ZZZZ0`3oool0201EEED0ZZZZ0?oo
o`1EEED0oooo05EEE@3oool0EEEE0P2ZZZX20?ooo`030:ZZZP3oool0EEEE00<0oooo00@0EEEE0:ZZ
ZP2ZZZX000000P3oool40:ZZZP080?ooo`1EEED0ZZZZ0?ooo`000000oooo05EEE@2ZZZX<0?ooo`X0
dLfY303oool01P2ZZZX0EEEE0000001EEED0oooo00000080oooo00<0000005EEE@3oool00`1EEED2
0:ZZZP80000000@0EEEE0:ZZZP2ZZZX0EEEE0P2ZZZX01P1EEED0oooo0:ZZZP2ZZZX0EEEE0:ZZZP80
EEEE00@000000:ZZZP2ZZZX0ZZZZ0P1EEED010000000oooo05EEE@0000020?ooo`0605EEE@3oool0
EEEE0000001EEED0ZZZZ303oool<0=7=Z@002`3AcJT<0?ooo`80ZZZZ0P3oool0102ZZZX000000?oo
o`3oool205EEE@040:ZZZP3oool0oooo00000080ZZZZ00<0EEEE0:ZZZP2ZZZX00`3oool01@000000
ZZZZ0?ooo`3oool0ZZZZ00<0oooo0`2ZZZX0203oool0ZZZZ0:ZZZP000000oooo05EEE@2ZZZX0EEEE
0`3oool01@1EEED0ZZZZ0?ooo`3oool0ZZZZ00d0oooo2P3AcJT<0?ooo`80ZZZZ00L0oooo05EEE@3o
ool000000:ZZZP3oool0ZZZZ0080oooo00<0000005EEE@2ZZZX00`1EEED30:ZZZP0:0?ooo`000000
ZZZZ0000002ZZZX0EEEE0000002ZZZX000000?ooo`<0ZZZZ0`1EEED00`2ZZZX0EEEE000000020?oo
o`030000003oool0ZZZZ00@0oooo00<0ZZZZ0?ooo`3oool02`3oool:0=7=Z@`0oooo0`2ZZZX00`00
0000EEEE0:ZZZP030:ZZZP80000000<0EEEE0?ooo`1EEED0100000030?ooo`0605EEE@0000000000
05EEE@2ZZZX000000P1EEED30?ooo`050000002ZZZX000000:ZZZP1EEED00P3oool2000000<0ZZZZ
00<0000005EEE@2ZZZX00P2ZZZX=0?ooo`X0dLfY303oool30:ZZZP030?ooo`1EEED000000080oooo
00H0EEEE0?ooo`3oool0oooo0000001EEED20:ZZZP80oooo00L000000?ooo`3oool0oooo05EEE@00
0000oooo00<000000P3oool200000080oooo0P2ZZZX00`1EEED0000005EEE@050?ooo`030000001E
EED000000080ZZZZ3@3oool:0=7=Z@`0oooo0`2ZZZX00`000000ZZZZ0:ZZZP0205EEE@050:ZZZP1E
EED000000:ZZZP1EEED0103oool00`000000ZZZZ0000000205EEE@8000000P2ZZZX00`000000EEEE
05EEE@0205EEE@0;0:ZZZP000000ZZZZ0?ooo`2ZZZX0oooo05EEE@3oool0000005EEE@2ZZZX00P1E
EED20:ZZZP0305EEE@2ZZZX0ZZZZ00d0oooo303AcJT000/0dLfY3P3oool20:ZZZP80oooo00P00000
05EEE@1EEED0ZZZZ0000003oool0EEEE0?ooo`80EEEE0`3oool00`2ZZZX0EEEE05EEE@050:ZZZP04
0000001EEED0EEEE0:ZZZP80oooo00P0ZZZZ05EEE@2ZZZX0oooo05EEE@3oool000000:ZZZP80EEEE
00<000000?ooo`3oool00P2ZZZX>0?ooo`X0dLfY3P3oool20:ZZZP070?ooo`000000000005EEE@2Z
ZZX0EEEE000000030?ooo`030:ZZZP3oool0ZZZZ0080oooo00L0ZZZZ0?ooo`000000oooo0000002Z
ZZX0oooo00<000001P3oool00`2ZZZX0oooo0?ooo`02000000<0EEEE0P0000000`3oool0ZZZZ0:ZZ
ZP0>0?ooo`X0dLfY3P3oool20:ZZZP80EEEE0P3oool00`1EEED0000005EEE@0205EEE@80ZZZZ00@0
EEEE0:ZZZP000000ZZZZ0`1EEED20:ZZZP0405EEE@2ZZZX0ZZZZ0:ZZZP<0EEEE00@0ZZZZ00000000
0000EEEE0P2ZZZX0101EEED0ZZZZ05EEE@0000030?ooo`040000001EEED0ZZZZ0:ZZZPh0oooo2P3A
cJT>0?ooo`040:ZZZP000000oooo00000080EEEE00H0oooo05EEE@3oool0ZZZZ0?ooo`2ZZZX20?oo
o`040:ZZZP1EEED0oooo05EEE@80ZZZZ00<0oooo0000002ZZZX00P0000000`3oool0ZZZZ0:ZZZP02
0?ooo`0:05EEE@2ZZZX0oooo0?ooo`2ZZZX0oooo05EEE@3oool0EEEE0?ooo`80EEEE0P3oool20:ZZ
ZPh0oooo2P3AcJT>0?ooo`030:ZZZP000000EEEE00@0ZZZZ00D0EEEE0000001EEED0oooo05EEE@02
0:ZZZP030?ooo`1EEED000000080000000<0oooo0:ZZZP2ZZZX00P3oool20:ZZZP040?ooo`000000
EEEE00000080EEEE00L0ZZZZ0000001EEED0oooo05EEE@000000EEEE00@0ZZZZ00<0EEEE0:ZZZP2Z
ZZX03P3oool<0=7=Z@002`3AcJT?0?ooo`090:ZZZP3oool000000?ooo`1EEED0oooo05EEE@3oool0
00000080oooo00<0EEEE0:ZZZP3oool00P3oool30:ZZZP<0000000<0EEEE0000002ZZZX00P2ZZZX4
0?ooo`0=0:ZZZP3oool0oooo0?ooo`000000oooo05EEE@2ZZZX0EEEE0?ooo`000000oooo0:ZZZP0?
0?ooo`X0dLfY3`3oool02P2ZZZX0oooo0000003oool000000?ooo`2ZZZX0EEEE0:ZZZP0000040?oo
o`090:ZZZP000000ZZZZ0:ZZZP1EEED0ZZZZ0000003oool0ZZZZ0080000000D0EEEE0:ZZZP3oool0
00000:ZZZP020?ooo`0<0:ZZZP3oool000000000001EEED0ZZZZ0?ooo`000000oooo0000003oool0
ZZZZ3`3oool:0=7=Z@l0oooo00<0ZZZZ05EEE@3oool00`3oool00`000000EEEE0:ZZZP040:ZZZP03
0000003oool0EEEE00<0EEEE0P3oool205EEE@030?ooo`1EEED0EEEE00<0EEEE00@0oooo0:ZZZP2Z
ZZX0EEEE0`2ZZZX00`1EEED000000?ooo`020?ooo`030000001EEED0ZZZZ00l0oooo2P3AcJT?0?oo
o`030:ZZZP1EEED0ZZZZ0080ZZZZ00<0000005EEE@1EEED00`3oool010000000ZZZZ0?ooo`2ZZZX2
05EEE@80000000H0ZZZZ0000002ZZZX0oooo0000001EEED200000080EEEE0`2ZZZX0101EEED0oooo
0?ooo`2ZZZX205EEE@<0ZZZZ0P1EEED00`2ZZZX0oooo0?ooo`0=0?ooo`X0dLfY3`3oool01@2ZZZX0
EEEE05EEE@1EEED0000000<0EEEE00<0ZZZZ05EEE@1EEED00P3oool00`2ZZZX0EEEE0?ooo`020:ZZ
ZP0405EEE@000000EEEE0:ZZZP@0EEEE00<0ZZZZ05EEE@3oool00P1EEED01@3oool0EEEE05EEE@1E
EED0oooo0080EEEE0P000000101EEED0000005EEE@2ZZZX?0?ooo``0dLfY000;0=7=Z@l0oooo0P2Z
ZZX0301EEED0ZZZZ0:ZZZP3oool000000?ooo`1EEED0oooo05EEE@3oool0ZZZZ05EEE@80ZZZZ0P00
00001P1EEED000000?ooo`2ZZZX0EEEE0?ooo`80EEEE00<0000005EEE@2ZZZX00`2ZZZX205EEE@04
0?ooo`000000oooo000000<0ZZZZ00<0EEEE0:ZZZP3oool03`3oool:0=7=Z@l0oooo0P2ZZZX205EE
E@080?ooo`2ZZZX0oooo0?ooo`000000EEEE0:ZZZP3oool4000000050:ZZZP3oool0oooo0000001E
EED00P3oool00`1EEED000000?ooo`020?ooo`80000000H0ZZZZ0000002ZZZX0ZZZZ05EEE@000002
0?ooo`050000003oool0EEEE05EEE@2ZZZX0403oool:0=7=Z@l0oooo0P2ZZZX20000000505EEE@00
0000ZZZZ0:ZZZP1EEED00P2ZZZX00`3oool0EEEE05EEE@06000000@0EEEE1P0000000`3oool0EEEE
05EEE@050:ZZZP030000001EEED000000080ZZZZ403oool:0=7=Z@l0oooo0`2ZZZX02P3oool0ZZZZ
0?ooo`000000oooo05EEE@000000ZZZZ0?ooo`1EEED20?ooo`0805EEE@3oool0EEEE05EEE@2ZZZX0
oooo05EEE@0000020?ooo`80EEEE00@0ZZZZ05EEE@3oool0oooo0P1EEED01@2ZZZX000000?ooo`3o
ool000000080ZZZZ00<0oooo0:ZZZP2ZZZX0403oool:0=7=Z@l0oooo0P2ZZZX00`1EEED000000:ZZ
ZP0200000080oooo00@0ZZZZ05EEE@2ZZZX0ZZZZ0`1EEED0203oool0ZZZZ0:ZZZP2ZZZX0EEEE0:ZZ
ZP000000EEEE102ZZZX205EEE@050000002ZZZX0000005EEE@2ZZZX00P3oool010000000oooo0:ZZ
ZP0000020:ZZZQ00oooo303AcJT000/0dLfY4@3oool00`2ZZZX0oooo0?ooo`030:ZZZP80EEEE00@0
oooo0:ZZZP3oool0oooo0P2ZZZX01@000000oooo05EEE@1EEED0ZZZZ0080oooo00<0ZZZZ05EEE@1E
EED00P3oool20:ZZZP050000003oool000000?ooo`1EEED00`2ZZZX30?ooo`030:ZZZP3oool0oooo
00l0oooo2P3AcJTA0?ooo`060:ZZZP3oool0oooo0:ZZZP1EEED00000103oool00`000000ZZZZ0?oo
o`020?ooo`8000000P3oool20:ZZZP030?ooo`1EEED00000008000000P3oool00`1EEED000000:ZZ
ZP020?ooo`8000000P1EEED20?ooo`030:ZZZP3oool0oooo00l0oooo2P3AcJTA0?ooo`<0ZZZZ00T0
EEEE0?ooo`3oool0oooo0000002ZZZX0EEEE0000001EEED00`2ZZZX00`1EEED0oooo0:ZZZP050:ZZ
ZP030?ooo`1EEED0ZZZZ0080ZZZZ00D0oooo0000003oool0ZZZZ000000030?ooo`0405EEE@2ZZZX0
ZZZZ0:ZZZQ40oooo2P3AcJTA0?ooo`040:ZZZP000000EEEE0?ooo`80EEEE00@0oooo0:ZZZP1EEED0
EEEE0P3oool0102ZZZX0EEEE05EEE@1EEED30:ZZZP0;0?ooo`2ZZZX0ZZZZ05EEE@2ZZZX0EEEE0?oo
o`1EEED0ZZZZ05EEE@3oool00P1EEED0202ZZZX0EEEE05EEE@1EEED0oooo05EEE@000000ZZZZ4@3o
ool:0=7=ZA40oooo00@0ZZZZ0000001EEED0ZZZZ0P00000205EEE@040?ooo`00000000000?ooo`<0
EEEE00@0oooo05EEE@1EEED0EEEE0P3oool305EEE@030?ooo`2ZZZX0EEEE0080EEEE00@0000005EE
E@3oool0EEEE0`000000102ZZZX0EEEE0000002ZZZXA0?ooo``0dLfY000;0=7=ZA40oooo0P2ZZZX0
1`1EEED0ZZZZ0?ooo`2ZZZX0oooo0000003oool00P1EEED20:ZZZP050?ooo`000000ZZZZ0?ooo`2Z
ZZX0103oool01P1EEED0oooo0:ZZZP2ZZZX0oooo0:ZZZP80EEEE00T000000?ooo`000000oooo0:ZZ
ZP3oool0ZZZZ05EEE@2ZZZX04P3oool:0=7=ZA40oooo0P2ZZZX01P1EEED0oooo0?ooo`000000oooo
0:ZZZP8000000P2ZZZX01@3oool000000:ZZZP1EEED000000080oooo00T0ZZZZ0?ooo`3oool0oooo
0000001EEED0ZZZZ0000003oool00P2ZZZX2000000070:ZZZP00000000000?ooo`2ZZZX0EEEE0:ZZ
ZP0B0?ooo`X0dLfY4@3oool20:ZZZP0605EEE@000000EEEE05EEE@000000EEEE0P3oool01`000000
EEEE05EEE@3oool0ZZZZ0000001EEED00`3oool01@1EEED0oooo05EEE@1EEED000000080oooo0P1E
EED01@000000oooo0?ooo`1EEED000000080EEEE00<0ZZZZ05EEE@2ZZZX04P3oool:0=7=ZA40oooo
0P2ZZZX00`1EEED0000005EEE@0205EEE@@0oooo00H0000005EEE@000000ZZZZ0?ooo`1EEED20:ZZ
ZP80oooo00L0ZZZZ0?ooo`1EEED0oooo05EEE@000000EEEE0080oooo00@000000?ooo`3oool00000
0P1EEED00`3oool0EEEE0:ZZZP0B0?ooo`X0dLfY4@3oool20:ZZZP<0EEEE00H0oooo05EEE@1EEED0
EEEE0000003oool305EEE@030000002ZZZX0ZZZZ0080ZZZZ00<000000:ZZZP2ZZZX00`2ZZZX305EE
E@030:ZZZP3oool0ZZZZ00<0EEEE00D0oooo05EEE@000000EEEE0:ZZZP0B0?ooo``0dLfY000;0=7=
ZA80oooo0P2ZZZX30?ooo`0305EEE@3oool0000000<0ZZZZ0P3oool00`1EEED0000005EEE@050?oo
o`030:ZZZP1EEED0000000<0oooo0`2ZZZX00`000000oooo05EEE@020?ooo`<0ZZZZ4P3oool:0=7=
ZA80oooo0P2ZZZX00`3oool000000:ZZZP07000000080:ZZZP3oool0oooo0000002ZZZX000000:ZZ
ZP3oool3000000030?ooo`2ZZZX0ZZZZ00<0000000<0oooo0000000000000P2ZZZX010000000ZZZZ
0:ZZZP2ZZZXB0?ooo`X0dLfY4P3oool20:ZZZP<0EEEE00X0ZZZZ05EEE@000000000005EEE@2ZZZX0
EEEE0000001EEED0oooo0P000000101EEED0ZZZZ0000001EEED2000000050?ooo`1EEED0000005EE
E@3oool00P1EEED00`000000EEEE05EEE@0205EEE@<0ZZZZ4P3oool:0=7=ZA80oooo0P2ZZZX01@00
0000oooo0?ooo`2ZZZX000000080ZZZZ00@0EEEE0:ZZZP2ZZZX0ZZZZ0`3oool00`1EEED000000?oo
o`0300000080oooo00<0EEEE0:ZZZP2ZZZX00`1EEED00`2ZZZX00000000000020?ooo`<0ZZZZ4P3o
ool:0=7=ZA80oooo0P2ZZZX00`1EEED000000:ZZZP030:ZZZP030?ooo`000000EEEE00<0EEEE1@3o
ool00`1EEED0oooo05EEE@020?ooo`@0EEEE00<000000:ZZZP2ZZZX00`2ZZZX010000000ZZZZ0:ZZ
ZP2ZZZXB0?ooo``0dLfY000;0=7=ZA@0oooo00@0ZZZZ05EEE@1EEED0ZZZZ0P1EEED2000000<0ZZZZ
00D0EEEE0?ooo`3oool000000?ooo`02000000040?ooo`000000oooo0?ooo`<0ZZZZ00<0EEEE0000
000000000P1EEED0102ZZZX0EEEE05EEE@2ZZZXD0?ooo`X0dLfY503oool00`2ZZZX0EEEE05EEE@02
05EEE@030?ooo`00000000000080oooo00@000000?ooo`3oool000000P2ZZZX200000080ZZZZ00H0
00000?ooo`00000000000?ooo`1EEED2000000030?ooo`1EEED0EEEE0080EEEE00<0ZZZZ0?ooo`3o
ool04P3oool:0=7=ZA@0oooo0P2ZZZX010000000oooo0?ooo`00000205EEE@050000001EEED0ZZZZ
0:ZZZP0000000P3oool00`1EEED0ZZZZ0000000205EEE@090?ooo`000000ZZZZ0:ZZZP1EEED00000
05EEE@2ZZZX000000080oooo00<000000:ZZZP2ZZZX0503oool:0=7=ZA@0oooo00@0ZZZZ0000003o
ool0oooo0P0000000`2ZZZX0oooo0?ooo`020?ooo`0605EEE@2ZZZX0ZZZZ0?ooo`000000ZZZZ0P00
00000`3oool0ZZZZ0:ZZZP030?ooo`030:ZZZP3oool0ZZZZ008000000P3oool00`000000ZZZZ0?oo
o`0C0?ooo`X0dLfY503oool00`2ZZZX0000005EEE@030:ZZZP060000002ZZZX000000:ZZZP000000
EEEE0P0000001@1EEED0ZZZZ000000000000ZZZZ00D0000000@0ZZZZ0000002ZZZX0EEEE0`2ZZZX0
0`1EEED000000:ZZZP0D0?ooo``0dLfY000;0=7=ZA@0oooo0`2ZZZX01P3oool0ZZZZ05EEE@000000
EEEE0:ZZZP80oooo0P2ZZZX305EEE@050:ZZZP1EEED0EEEE0:ZZZP1EEED00P2ZZZX30?ooo`0305EE
E@3oool0EEEE00@0ZZZZ5@3oool:0=7=ZA@0oooo1P2ZZZX01@000000oooo0?ooo`2ZZZX000000080
ZZZZ00@0EEEE000000000000oooo0`000000201EEED0ZZZZ05EEE@000000ZZZZ0000003oool0EEEE
1@2ZZZXE0?ooo`X0dLfY503oool20:ZZZP0405EEE@000000EEEE05EEE@80ZZZZ00@000000:ZZZP1E
EED0ZZZZ0P1EEED0102ZZZX000000?ooo`1EEED200000080EEEE00<0ZZZZ05EEE@2ZZZX00`2ZZZX4
05EEE@030:ZZZP3oool0oooo01<0oooo2P3AcJTD0?ooo`80ZZZZ00@0EEEE0:ZZZP1EEED0ZZZZ0P3o
ool02P1EEED000000?ooo`000000EEEE0000003oool000000?ooo`2ZZZX300000080EEEE00@0oooo
0000003oool0oooo0P2ZZZX305EEE@030:ZZZP3oool0oooo01<0oooo2P3AcJTD0?ooo`80ZZZZ0`1E
EED02P000000oooo0:ZZZP000000ZZZZ0000002ZZZX0EEEE0:ZZZP1EEED400000080ZZZZ00H0EEEE
0?ooo`000000ZZZZ0?ooo`2ZZZX20000000405EEE@000000EEEE0:ZZZQD0oooo303AcJT000/0dLfY
5@3oool20:ZZZP80oooo00@0ZZZZ0000003oool0oooo0P1EEED0303oool0EEEE0?ooo`3oool0EEEE
0?ooo`2ZZZX0EEEE0:ZZZP3oool0EEEE0?ooo`80EEEE0P3oool0101EEED0ZZZZ0?ooo`3oool20:ZZ
ZQD0oooo2P3AcJTE0?ooo`80ZZZZ00@0oooo05EEE@3oool000000P1EEED2000000040?ooo`2ZZZX0
ZZZZ00000080EEEE00<0ZZZZ05EEE@2ZZZX00P2ZZZX00`3oool000000000000205EEE@80oooo00@0
EEEE0?ooo`2ZZZX0ZZZZ5@3oool:0=7=ZAD0oooo0`2ZZZX01`000000EEEE0:ZZZP1EEED0ZZZZ0000
003oool00`1EEED20:ZZZP0305EEE@000000ZZZZ00<0EEEE0P3oool01P000000ZZZZ05EEE@2ZZZX0
EEEE000000<0ZZZZ5@3oool:0=7=ZAD0oooo0`2ZZZX00`3oool0EEEE0?ooo`020?ooo`050000002Z
ZZX0ZZZZ05EEE@3oool00P1EEED20?ooo`80EEEE00D0oooo05EEE@2ZZZX0ZZZZ000000030?ooo`03
05EEE@3oool0ZZZZ0080ZZZZ5@3oool:0=7=ZAD0oooo0P2ZZZX01@1EEED000000:ZZZP000000EEEE
0080ZZZZ00<0oooo05EEE@1EEED00P1EEED01@2ZZZX0EEEE0:ZZZP2ZZZX000000080EEEE00<00000
0?ooo`2ZZZX00P1EEED00`3oool0ZZZZ000000030:ZZZQD0oooo303AcJT000/0dLfY5`3oool20:ZZ
ZP80oooo00T0000005EEE@1EEED0ZZZZ0?ooo`2ZZZX000000:ZZZP3oool00P1EEED01P3oool0ZZZZ
0000002ZZZX000000:ZZZP80EEEE00<000000?ooo`3oool00P2ZZZXG0?ooo`X0dLfY5`3oool20:ZZ
ZP030?ooo`000000000000<0000000H0oooo000000000000EEEE0:ZZZP3oool20:ZZZP040?ooo`00
000000000?ooo`80000000@0EEEE000000000000oooo0P2ZZZXG0?ooo`X0dLfY5`3oool20:ZZZP80
EEEE00<0ZZZZ05EEE@0000000P2ZZZX00`000000oooo0?ooo`0405EEE@80oooo00<000000:ZZZP2Z
ZZX00P0000000`2ZZZX0000005EEE@020:ZZZQL0oooo2P3AcJTG0?ooo`030:ZZZP000000EEEE0080
EEEE0P2ZZZX30?ooo`050:ZZZP3oool0EEEE0?ooo`2ZZZX00P1EEED0102ZZZX0oooo0?ooo`3oool2
0:ZZZP0505EEE@3oool0EEEE0000002ZZZX05`3oool:0=7=ZAL0oooo00L0ZZZZ0000001EEED0ZZZZ
0000003oool0ZZZZ00<0EEEE00<0000005EEE@2ZZZX00`2ZZZX20000000405EEE@000000EEEE0:ZZ
ZP80000000@0ZZZZ05EEE@000000ZZZZ5`3oool<0=7=Z@002`3AcJTG0?ooo`80ZZZZ00H0oooo0000
003oool0ZZZZ0?ooo`1EEED2000000040:ZZZP3oool0oooo00000080oooo0P2ZZZX02@000000oooo
05EEE@3oool0EEEE0?ooo`000000oooo0:ZZZP0H0?ooo`X0dLfY5`3oool20:ZZZP040?ooo`000000
oooo0?ooo`80000000<0ZZZZ0000001EEED00P2ZZZX20?ooo`80ZZZZ00<0EEEE0000003oool00`00
0000103oool000000?ooo`2ZZZXH0?ooo`X0dLfY5`3oool20:ZZZP0405EEE@3oool0oooo000000@0
ZZZZ00<0000005EEE@1EEED00`1EEED2000000090:ZZZP1EEED0ZZZZ0:ZZZP1EEED0oooo0000001E
EED0ZZZZ01P0oooo2P3AcJTG0?ooo`80ZZZZ00@0EEEE0000003oool0EEEE1@3oool0102ZZZX0EEEE
0?ooo`3oool205EEE@P0oooo00<0EEEE0:ZZZP3oool05`3oool:0=7=ZAL0oooo0P2ZZZX405EEE@03
0000001EEED0ZZZZ00<0ZZZZ00D000000:ZZZP000000000005EEE@030:ZZZP0705EEE@000000oooo
05EEE@000000EEEE0:ZZZP0H0?ooo``0dLfY000;0=7=ZAP0oooo0P2ZZZX0101EEED0ZZZZ0:ZZZP3o
ool20000000705EEE@3oool0ZZZZ0000002ZZZX0EEEE000000020?ooo`0405EEE@3oool000000?oo
o`80ZZZZ00<0EEEE0:ZZZP2ZZZX0603oool:0=7=ZAP0oooo0P2ZZZX205EEE@030000002ZZZX0ZZZZ
0080000000<0oooo0:ZZZP3oool01@3oool200000080ZZZZ00<0oooo05EEE@1EEED00P2ZZZXH0?oo
o`X0dLfY603oool20:ZZZP80000000H0ZZZZ05EEE@2ZZZX0ZZZZ05EEE@2ZZZX605EEE@040:ZZZP1E
EED0ZZZZ0:ZZZP80EEEE00@000000:ZZZP2ZZZX0ZZZZ603oool:0=7=ZAP0oooo0P2ZZZX01`000000
oooo0000001EEED0ZZZZ0000003oool00P000000101EEED0ZZZZ05EEE@1EEED2000000030?ooo`1E
EED0ZZZZ0080EEEE00@0oooo0:ZZZP2ZZZX0ZZZZ603oool:0=7=ZAP0oooo0P2ZZZX0101EEED00000
0:ZZZP2ZZZX205EEE@060000001EEED0ZZZZ0000002ZZZX0oooo0P000000101EEED000000000001E
EED20:ZZZP040000002ZZZX0ZZZZ0:ZZZQP0oooo303AcJT000/0dLfY6P3oool00`2ZZZX0oooo0?oo
o`030:ZZZP80EEEE00@0ZZZZ05EEE@1EEED0oooo101EEED30:ZZZP80oooo00<0ZZZZ0?ooo`3oool0
603oool:0=7=ZAX0oooo00P0ZZZZ0?ooo`1EEED0ZZZZ05EEE@2ZZZX0000005EEE@H0oooo00D0EEEE
000000000000EEEE0:ZZZP020?ooo`030:ZZZP3oool0oooo01P0oooo2P3AcJTJ0?ooo`80ZZZZ0P1E
EED3000000040:ZZZP3oool0ZZZZ05EEE@80ZZZZ00<0oooo0:ZZZP0000000P000000101EEED0ZZZZ
0:ZZZP2ZZZXJ0?ooo`X0dLfY6P3oool01@2ZZZX000000?ooo`000000EEEE0080oooo00l0000005EE
E@2ZZZX000000?ooo`2ZZZX0oooo0000003oool0000005EEE@000000oooo0000002ZZZX06P3oool:
0=7=ZAX0oooo00@0ZZZZ0000002ZZZX0ZZZZ0P1EEED20000000605EEE@2ZZZX0oooo05EEE@2ZZZX0
oooo0`0000001@1EEED0ZZZZ05EEE@000000ZZZZ01X0oooo303AcJT000/0dLfY6P3oool40:ZZZP<0
oooo00<000000?ooo`1EEED00P2ZZZX02@1EEED0oooo0000003oool0ZZZZ0?ooo`2ZZZX0EEEE0:ZZ
ZP0K0?ooo`X0dLfY6P3oool30:ZZZP80oooo00<0EEEE0000003oool01`3oool200000080oooo00<0
EEEE0:ZZZP3oool06P3oool:0=7=ZAX0oooo0`2ZZZX010000000EEEE0000001EEED30?ooo`80ZZZZ
0`3oool01P1EEED0oooo05EEE@000000EEEE0:ZZZQ/0oooo2P3AcJTJ0?ooo`80ZZZZ00<0EEEE0:ZZ
ZP2ZZZX00P1EEED01P2ZZZX000000000003oool0EEEE00000080ZZZZ00H0EEEE0:ZZZP2ZZZX0ZZZZ
05EEE@2ZZZXK0?ooo`X0dLfY6P3oool20:ZZZP80000000<0EEEE0:ZZZP2ZZZX00P1EEED01P000000
ZZZZ05EEE@000000ZZZZ05EEE@80ZZZZ00@0EEEE0000001EEED0ZZZZ6`3oool<0=7=Z@002`3AcJTK
0?ooo`80ZZZZ0P3oool205EEE@040?ooo`000000oooo0:ZZZP80oooo00<000000?ooo`1EEED00`3o
ool20:ZZZQ/0oooo2P3AcJTK0?ooo`80ZZZZ00P0oooo0000002ZZZX0ZZZZ0000002ZZZX000000:ZZ
ZP@000000P2ZZZX010000000oooo0:ZZZP2ZZZXK0?ooo`X0dLfY6`3oool20:ZZZP80EEEE00<00000
0?ooo`3oool00P3oool00`1EEED0oooo0?ooo`030?ooo`<0EEEE0P2ZZZXK0?ooo`X0dLfY6`3oool3
0:ZZZP030?ooo`2ZZZX0ZZZZ0080ZZZZ00D000000?ooo`3oool000000?ooo`030:ZZZP040?ooo`2Z
ZZX0ZZZZ0:ZZZQ/0oooo2P3AcJTK0?ooo`80ZZZZ00@0EEEE0:ZZZP3oool0ZZZZ0P3oool02P2ZZZX0
EEEE0000002ZZZX0EEEE0?ooo`2ZZZX0oooo0:ZZZP1EEED20:ZZZQ/0oooo303AcJT000/0dLfY703o
ool20:ZZZP0505EEE@2ZZZX0ZZZZ05EEE@0000000P1EEED01@3oool0EEEE05EEE@1EEED0ZZZZ0080
EEEE00<0ZZZZ0?ooo`3oool06`3oool:0=7=ZA`0oooo0P2ZZZX405EEE@80ZZZZ0P1EEED20:ZZZP@0
EEEE00<0ZZZZ0?ooo`3oool06`3oool:0=7=ZA`0oooo0`2ZZZX20?ooo`030000002ZZZX0EEEE00@0
EEEE00<000000?ooo`0000000P2ZZZXM0?ooo`X0dLfY703oool20:ZZZP0?0000003oool0oooo05EE
E@2ZZZX0EEEE0:ZZZP3oool0EEEE0000001EEED0oooo05EEE@000000ZZZZ01d0oooo2P3AcJTL0?oo
o`80ZZZZ00D000000?ooo`1EEED0ZZZZ000000060:ZZZP80EEEE00<000000:ZZZP3oool0703oool<
0=7=Z@002`3AcJTM0?ooo`<0ZZZZ00<0oooo0:ZZZP3oool00P0000001@3oool0000005EEE@2ZZZX0
oooo00<0ZZZZ7@3oool:0=7=ZAd0oooo1@2ZZZX00`3oool0ZZZZ0:ZZZP080:ZZZQd0oooo2P3AcJTM
0?ooo`80ZZZZ00<0EEEE0000001EEED01@2ZZZX0103oool0EEEE0000001EEED20:ZZZQd0oooo2P3A
cJTM0?ooo`80ZZZZ00<0oooo0000001EEED00P3oool00`1EEED000000?ooo`0205EEE@040000001E
EED0ZZZZ0:ZZZQd0oooo2P3AcJTM0?ooo`80ZZZZ00H0oooo000000000000EEEE0?ooo`2ZZZX20?oo
o`0405EEE@000000000005EEE@80ZZZZ7@3oool<0=7=Z@002`3AcJTO0?ooo`080:ZZZP1EEED0ZZZZ
0?ooo`1EEED0ZZZZ0?ooo`1EEED20:ZZZP0305EEE@2ZZZX0oooo01h0oooo2P3AcJTO0?ooo`050:ZZ
ZP1EEED0ZZZZ0000002ZZZX00P3oool01@2ZZZX0oooo0:ZZZP1EEED0ZZZZ01l0oooo2P3AcJTO0?oo
o`0<0:ZZZP1EEED0ZZZZ0000002ZZZX0EEEE0000002ZZZX0EEEE0:ZZZP1EEED0ZZZZ7`3oool:0=7=
ZAl0oooo00<0ZZZZ0?ooo`0000000P2ZZZX01`3oool0ZZZZ0:ZZZP1EEED000000?ooo`2ZZZX07`3o
ool:0=7=ZAl0oooo00<0ZZZZ0?ooo`0000000P1EEED20:ZZZP80EEEE00<000000?ooo`2ZZZX07`3o
ool<0=7=Z@002`3AcJTO0?ooo`<0ZZZZ0P3oool0102ZZZX000000?ooo`3oool20:ZZZR00oooo2P3A
cJTO0?ooo`<0ZZZZ0P000000102ZZZX000000000003oool20:ZZZR00oooo2P3AcJTO0?ooo`<0ZZZZ
00H0oooo0000002ZZZX0ZZZZ0000001EEED20:ZZZR00oooo2P3AcJTO0?ooo`80ZZZZ00<000000?oo
o`1EEED00P3oool0101EEED0oooo0000002ZZZXP0?ooo`X0dLfY7`3oool20:ZZZP80000000<0oooo
0:ZZZP3oool00P3oool00`000000ZZZZ0?ooo`0O0?ooo``0dLfY000;0=7=ZB00oooo0P2ZZZX20000
000405EEE@3oool000000?ooo`80ZZZZ803oool:0=7=ZB00oooo0P2ZZZX20000000405EEE@3oool0
00000?ooo`80ZZZZ803oool:0=7=ZB00oooo0P2ZZZX010000000EEEE05EEE@3oool205EEE@80ZZZZ
803oool:0=7=ZB00oooo0P2ZZZX00`000000oooo0?ooo`020?ooo`0305EEE@2ZZZX0ZZZZ0200oooo
2P3AcJTP0?ooo`80ZZZZ00H0EEEE0?ooo`1EEED000000?ooo`1EEED20:ZZZR00oooo303AcJT000/0
dLfY8P3oool20:ZZZP040?ooo`2ZZZX0ZZZZ0:ZZZR80oooo2P3AcJTR0?ooo`80ZZZZ00@0oooo0:ZZ
ZP2ZZZX0ZZZZ8P3oool:0=7=ZB80oooo00<0ZZZZ05EEE@1EEED00P1EEED00`2ZZZX0oooo0?ooo`0P
0?ooo`X0dLfY8P3oool01P2ZZZX0oooo05EEE@1EEED0oooo0:ZZZR80oooo2P3AcJTR0?ooo`060:ZZ
ZP3oool000000:ZZZP3oool0ZZZZ8P3oool<0=7=Z@002`3AcJTR0?ooo`80ZZZZ0P3oool00`2ZZZX0
oooo0?ooo`0Q0?ooo`X0dLfY8P3oool20:ZZZP80oooo00<0ZZZZ0?ooo`3oool08@3oool:0=7=ZB80
oooo1@2ZZZXS0?ooo`X0dLfY8P3oool20:ZZZP80000000<0ZZZZ0?ooo`3oool08@3oool:0=7=ZB80
oooo0P2ZZZX2000000030:ZZZP3oool0oooo0240oooo303AcJT000/0dLfY8`3oool0102ZZZX0EEEE
0:ZZZP2ZZZXS0?ooo`X0dLfY8`3oool0102ZZZX0EEEE0:ZZZP2ZZZXS0?ooo`X0dLfY8`3oool0102Z
ZZX0EEEE0:ZZZP2ZZZXS0?ooo`X0dLfY8`3oool0102ZZZX0EEEE0:ZZZP2ZZZXS0?ooo`X0dLfY8`3o
ool0102ZZZX0EEEE0:ZZZP2ZZZXS0?ooo``0dLfY000;0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3o
ool:0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool:0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3o
ool:0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3oool:0=7=ZB@0oooo00<0ZZZZ0?ooo`3oool08`3o
ool<0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3AcJVb0=7=Z@00o`3A
cJVb0=7=Z@002`3AcJT02`3oool0ZZZZ0:ZZZP3oool000000:ZZZP000000oooo0:ZZZP1EEED00000
0080oooo0P2ZZZX01@000000oooo0?ooo`2ZZZX0EEEE00<0oooo00D0EEEE0?ooo`3oool0oooo05EE
E@020?ooo`<0000000l0oooo0:ZZZP3oool0oooo05EEE@3oool000000?ooo`000000oooo0000003o
ool0000005EEE@2ZZZX01P3oool0101EEED0ZZZZ0?ooo`3oool30:ZZZP80oooo0P000000102ZZZX0
oooo0:ZZZP2ZZZX20?ooo`80ZZZZ00<0oooo0=7=Z@3AcJT0203AcJT00`3oool0ZZZZ0:ZZZP0205EE
E@040:ZZZP000000ZZZZ00000080ZZZZ00@0oooo0:ZZZP000000oooo0P1EEED00`000000ZZZZ0:ZZ
ZP020:ZZZP040000001EEED0EEEE05EEE@<0ZZZZ0P3oool20:ZZZP050?ooo`00000000000:ZZZP3o
ool00P0000000`3oool0ZZZZ0?ooo`020?ooo`80ZZZZ0`1EEED00`2ZZZX000000:ZZZP030:ZZZP<0
EEEE00T0oooo0000003oool0oooo0:ZZZP3oool000000:ZZZP3oool00P2ZZZX0101EEED0ZZZZ0:ZZ
ZP3oool:0=7=Z@040?ooo`2ZZZX0ZZZZ0?ooo`80ZZZZ00<0oooo05EEE@1EEED01@3oool00`1EEED0
oooo05EEE@0205EEE@030000003oool0EEEE0080000000L0ZZZZ05EEE@000000oooo0000003oool0
EEEE0080oooo00<000000:ZZZP3oool00`3oool2000000030?ooo`000000EEEE00@0oooo00@0EEEE
0:ZZZP2ZZZX000000P1EEED020000000EEEE0000001EEED0000005EEE@3oool000000`3oool205EE
E@040?ooo`2ZZZX000000?ooo`80ZZZZ00<0oooo0=7=Z@3AcJT0203AcJT0103oool0ZZZZ0:ZZZP2Z
ZZX20?ooo`0405EEE@000000EEEE000000D0ZZZZ0P3oool02@2ZZZX0EEEE0:ZZZP1EEED000000:ZZ
ZP1EEED0ZZZZ05EEE@03000000<0oooo00<0000005EEE@3oool00P3oool01@2ZZZX0oooo0?ooo`1E
EED0000000<0oooo0`000000101EEED0ZZZZ0000002ZZZX2000000030:ZZZP1EEED0ZZZZ0080oooo
1@2ZZZX01P000000EEEE000000000000oooo05EEE@<0ZZZZ00<0oooo0=7=Z@3AcJT0203AcJT00`3o
ool0ZZZZ0:ZZZP020?ooo`050000003oool0EEEE0000003oool00P2ZZZX01`000000oooo0?ooo`00
0000EEEE0000003oool00`0000030?ooo`030000001EEED000000080oooo00D0ZZZZ0?ooo`1EEED0
EEEE0?ooo`02000000030?ooo`000000oooo0080EEEE00@0oooo0:ZZZP3oool0oooo0`0000001`3o
ool000000?ooo`000000EEEE0000003oool00P1EEED40?ooo`80ZZZZ0P0000000`1EEED0oooo0000
00020?ooo`80ZZZZ00<0oooo0=7=Z@3AcJT02P3AcJT000/0dLfY00@0oooo0:ZZZP3oool000000`3o
ool0101EEED0oooo0:ZZZP1EEED30?ooo`050:ZZZP3oool0oooo05EEE@3oool01@1EEED20?ooo`05
05EEE@000000oooo05EEE@3oool00`2ZZZX205EEE@040?ooo`000000EEEE0?ooo`<0ZZZZ00D0oooo
05EEE@3oool0000005EEE@020?ooo`050000001EEED0EEEE0000001EEED00`3oool00`000000ZZZZ
0?ooo`020?ooo`80EEEE00@0oooo05EEE@2ZZZX0oooo0P0000030?ooo`X0dLfY00<0oooo0:ZZZP3o
ool00P000000203oool0ZZZZ0:ZZZP1EEED0oooo0:ZZZP3oool0ZZZZ0P1EEED0202ZZZX0EEEE0:ZZ
ZP2ZZZX0EEEE0:ZZZP1EEED0ZZZZ0P0000000`3oool0000000000002000000040:ZZZP0000000000
00000080ZZZZ0P0000020:ZZZP<0000000<0ZZZZ0000000000000P0000002`3oool000000?ooo`2Z
ZZX0EEEE0:ZZZP1EEED0ZZZZ0000001EEED000000080EEEE00D0ZZZZ0?ooo`2ZZZX0oooo05EEE@02
0:ZZZP030?ooo`000000000000<0oooo2P3AcJT01@3oool0ZZZZ0?ooo`3oool0ZZZZ00<0EEEE103o
ool2000000030:ZZZP1EEED0oooo0080ZZZZ0P1EEED02P3oool0EEEE05EEE@3oool0000005EEE@3o
ool0EEEE0:ZZZP0000020?ooo`0305EEE@3oool0oooo00<0oooo00H0ZZZZ05EEE@3oool0oooo0000
002ZZZX20?ooo`050:ZZZP000000oooo0:ZZZP1EEED00P3oool00`1EEED0ZZZZ05EEE@020?ooo`03
0:ZZZP000000oooo0080oooo00<0EEEE0?ooo`1EEED00`1EEED40?ooo`X0dLfY00@0oooo0:ZZZP3o
ool0oooo0P0000001`3oool0ZZZZ05EEE@3oool0EEEE0000001EEED00P000000101EEED000000?oo
o`0000020:ZZZP0705EEE@3oool0oooo0:ZZZP3oool000000?ooo`02000000050:ZZZP0000000000
0?ooo`2ZZZX00P3oool0102ZZZX0oooo0:ZZZP3oool20000000:0:ZZZP000000oooo0?ooo`000000
oooo0:ZZZP000000oooo05EEE@80ZZZZ00@0000005EEE@000000EEEE10000000101EEED0ZZZZ05EE
E@2ZZZX2000000030:ZZZP3oool0oooo0080oooo2P3AcJT00`3oool0ZZZZ0?ooo`020?ooo`050000
001EEED000000:ZZZP0000000P1EEED40?ooo`050000003oool0oooo05EEE@0000000P3oool00`00
0000EEEE0?ooo`0205EEE@030?ooo`1EEED000000080000000<0oooo05EEE@3oool00P2ZZZX00`3o
ool000000?ooo`030000000605EEE@3oool0EEEE05EEE@3oool0EEEE0`3oool00`2ZZZX0EEEE0?oo
o`02000000<0oooo00T0000005EEE@1EEED0oooo0:ZZZP000000oooo0000001EEED0103oool<0=7=
Z@002`3AcJT30?ooo`030:ZZZP000000ZZZZ0080oooo00<000000:ZZZP0000000P2ZZZX00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<0000005EEE@3oool00`2ZZZX30?oo
o`80ZZZZ00@0oooo0000002ZZZX000000P3oool40:ZZZP80oooo00T000000?ooo`2ZZZX0oooo0000
002ZZZX0oooo0000001EEED00`3oool02`000000ZZZZ0:ZZZP000000oooo0000003oool000000:ZZ
ZP3oool0ZZZZ00<0oooo2P3AcJT30?ooo`050:ZZZP000000ZZZZ0000002ZZZX00P1EEED00`000000
oooo0:ZZZP020:ZZZP050000003oool0000005EEE@0000000`2ZZZX0103oool0ZZZZ05EEE@1EEED2
0:ZZZP0705EEE@2ZZZX0ZZZZ0:ZZZP000000ZZZZ0?ooo`020:ZZZP070?ooo`00000000000:ZZZP3o
ool0ZZZZ05EEE@030:ZZZP0305EEE@2ZZZX0oooo00<0ZZZZ00D0000005EEE@000000oooo00000002
0:ZZZP80oooo00<000000?ooo`1EEED00`2ZZZX00`3oool0ZZZZ0?ooo`020?ooo`X0dLfY0`3oool2
0:ZZZP0305EEE@3oool0EEEE0080ZZZZ0P3oool01@2ZZZX0oooo0?ooo`1EEED0ZZZZ00<0oooo00<0
EEEE0?ooo`1EEED00`3oool01`000000EEEE000000000000oooo05EEE@2ZZZX0103oool01@1EEED0
oooo0?ooo`3oool0ZZZZ0080oooo0P000000201EEED000000?ooo`3oool0000005EEE@3oool0ZZZZ
0`3oool20:ZZZPH0oooo00H0ZZZZ05EEE@2ZZZX0EEEE0?ooo`2ZZZX30?ooo`X0dLfY0`3oool30:ZZ
ZP060?ooo`2ZZZX0ZZZZ05EEE@000000ZZZZ0P1EEED0102ZZZX0oooo0000003oool20:ZZZP0305EE
E@3oool0oooo00@0oooo00P000000?ooo`3oool0oooo0:ZZZP000000EEEE0:ZZZPD0oooo00<0EEEE
0000003oool00P3oool2000000<0oooo00<0ZZZZ0?ooo`3oool0102ZZZX01P000000ZZZZ0:ZZZP1E
EED000000:ZZZP800000102ZZZX00`3oool0ZZZZ0?ooo`020?ooo`X0dLfY0`3oool02P2ZZZX00000
0000003oool0ZZZZ0?ooo`2ZZZX000000?ooo`1EEED20?ooo`0:05EEE@000000oooo0:ZZZP3oool0
00000?ooo`1EEED0oooo05EEE@80ZZZZ00@0oooo05EEE@3oool0EEEE103oool010000000ZZZZ0?oo
o`0000030?ooo`050000001EEED0oooo05EEE@3oool00P2ZZZX02@1EEED0oooo05EEE@3oool00000
0?ooo`2ZZZX0oooo000000050?ooo`040000002ZZZX0oooo0:ZZZP80000000<0oooo0:ZZZP3oool0
0P3oool<0=7=Z@002`3AcJT40?ooo`80ZZZZ0P3oool00`1EEED000000?ooo`030?ooo`040000003o
ool0000000000080oooo0`2ZZZX30?ooo`8000000P3oool02@2ZZZX0oooo0?ooo`3oool000000:ZZ
ZP1EEED0oooo0:ZZZP040?ooo`030:ZZZP3oool0ZZZZ008000000`3oool20:ZZZP<0oooo10000000
203oool0ZZZZ0?ooo`3oool0ZZZZ05EEE@3oool0EEEE0P2ZZZX40?ooo`X0dLfY103oool30:ZZZP0>
05EEE@2ZZZX000000?ooo`1EEED0oooo0:ZZZP3oool0000005EEE@2ZZZX0EEEE0000002ZZZX20?oo
o`040:ZZZP3oool0000000000080oooo0P0000001P2ZZZX0oooo0000003oool0ZZZZ05EEE@80ZZZZ
00<0oooo0000003oool00`0000001P2ZZZX0oooo000000000000oooo0:ZZZP<0oooo00@0000005EE
E@1EEED0EEEE0P3oool01P2ZZZX0oooo05EEE@3oool000000:ZZZP80EEEE0P2ZZZX40?ooo`X0dLfY
103oool0102ZZZX0000005EEE@3oool205EEE@80oooo00@0EEEE0000002ZZZX0ZZZZ103oool20000
00050:ZZZP1EEED0oooo0?ooo`2ZZZX00`3oool00`000000ZZZZ0?ooo`030?ooo`80EEEE103oool2
000000040?ooo`000000oooo05EEE@<0oooo00<0ZZZZ0000001EEED0103oool00`000000ZZZZ0000
00030?ooo`060000001EEED0oooo0?ooo`000000ZZZZ103oool:0=7=Z@@0oooo00<0ZZZZ0000002Z
ZZX00P3oool01P1EEED0ZZZZ0?ooo`000000ZZZZ0?ooo`80ZZZZ0P0000001P1EEED0oooo0:ZZZP2Z
ZZX0oooo05EEE@<0oooo100000000`1EEED0ZZZZ0?ooo`040?ooo`80ZZZZ00<0EEEE000000000000
0P0000030?ooo`0705EEE@3oool0ZZZZ0:ZZZP000000EEEE000000020:ZZZP80oooo00<0ZZZZ0?oo
o`3oool00P2ZZZX20?ooo`030:ZZZP000000ZZZZ00@0oooo2P3AcJT40?ooo`<0ZZZZ0P3oool00`2Z
ZZX0oooo05EEE@04000000<0oooo0`2ZZZX01@000000oooo000000000000EEEE00@000001@3oool0
0`1EEED000000?ooo`040?ooo`80000000<0oooo0000001EEED00P0000000`1EEED000000:ZZZP02
0:ZZZP<0oooo0`0000000`3oool0EEEE0?ooo`030?ooo`<0ZZZZ103oool<0=7=Z@002`3AcJT50?oo
o`80ZZZZ00<000000:ZZZP1EEED00P2ZZZX01@000000oooo05EEE@000000oooo0080ZZZZ00<0oooo
0:ZZZP3oool00P3oool01@1EEED0oooo0?ooo`000000ZZZZ0080oooo00D0EEEE0?ooo`3oool0oooo
05EEE@020:ZZZP0305EEE@3oool0oooo00@0oooo0P0000020?ooo`0905EEE@3oool0oooo0?ooo`2Z
ZZX0oooo0:ZZZP000000oooo0080EEEE0P3oool40:ZZZP030000002ZZZX0ZZZZ00D0oooo2P3AcJT5
0?ooo`<0ZZZZ0P0000001P3oool000000000003oool0EEEE0:ZZZP80000000@0EEEE0?ooo`3oool0
oooo0`2ZZZX205EEE@090:ZZZP3oool0ZZZZ0:ZZZP000000ZZZZ0?ooo`2ZZZX000000080oooo0P00
00000`3oool0ZZZZ000000050:ZZZP0405EEE@2ZZZX0oooo0:ZZZP<0oooo00T0EEEE0?ooo`000000
ZZZZ05EEE@3oool0EEEE0000003oool00P0000030:ZZZPD0oooo2P3AcJT50?ooo`040:ZZZP1EEED0
000000000080oooo00L0ZZZZ0000002ZZZX0oooo05EEE@000000oooo0080000000H0oooo0:ZZZP3o
ool0ZZZZ05EEE@2ZZZX20?ooo`0305EEE@2ZZZX0oooo0080ZZZZ00P0EEEE0?ooo`000000oooo0:ZZ
ZP000000ZZZZ05EEE@80ZZZZ00<0oooo0:ZZZP3oool00P3oool01@2ZZZX0EEEE0:ZZZP3oool0ZZZZ
00D0000000<0ZZZZ0?ooo`2ZZZX00P2ZZZX0103oool0ZZZZ0000000000020:ZZZPD0oooo2P3AcJT5
0?ooo`030:ZZZP1EEED000000080ZZZZ100000000`3oool0000005EEE@020:ZZZP030000001EEED0
ZZZZ0080oooo00<0ZZZZ0000002ZZZX00P0000020?ooo`80000000@0ZZZZ0?ooo`2ZZZX0oooo102Z
ZZX010000000oooo0?ooo`3oool4000000060:ZZZP000000oooo0:ZZZP3oool000000P2ZZZX00`1E
EED0ZZZZ0?ooo`0400000080ZZZZ00<000000:ZZZP2ZZZX01@3oool:0=7=Z@D0oooo00<0ZZZZ0000
000000000P0000001@3oool0ZZZZ05EEE@1EEED0000000D0oooo0P2ZZZX020000000oooo0?ooo`3o
ool0000005EEE@000000oooo1P0000000`3oool0000000000005000000040?ooo`1EEED0EEEE0:ZZ
ZP80oooo0P0000000`2ZZZX0oooo0?ooo`040?ooo`060000001EEED0EEEE0:ZZZP3oool0ZZZZ0P00
00020:ZZZPD0oooo303AcJT000/0dLfY1`3oool020000000oooo0000002ZZZX0oooo05EEE@2ZZZX0
00000P2ZZZX205EEE@030?ooo`2ZZZX000000080000000D0EEEE0?ooo`3oool0EEEE0?ooo`020000
00<0EEEE00<0ZZZZ05EEE@3oool00P1EEED010000000EEEE05EEE@2ZZZX2000000060:ZZZP1EEED0
oooo0?ooo`1EEED0ZZZZ0P0000020?ooo`0605EEE@3oool0ZZZZ0:ZZZP000000ZZZZ0P3oool20:ZZ
ZP030?ooo`000000ZZZZ00H0oooo2P3AcJT70?ooo`050000002ZZZX000000:ZZZP0000000P1EEED0
1`000000oooo0000001EEED0ZZZZ0000002ZZZX00P000000102ZZZX0oooo0000000000020?ooo`06
0:ZZZP3oool0oooo0?ooo`2ZZZX00000103oool20:ZZZP030?ooo`000000oooo0080ZZZZ00@0oooo
000000000000oooo1@000000202ZZZX0EEEE0000002ZZZX0000005EEE@2ZZZX000000`2ZZZX00`00
0000ZZZZ0?ooo`050?ooo`X0dLfY1`3oool01P000000oooo0:ZZZP2ZZZX0oooo0:ZZZP80EEEE00D0
oooo0:ZZZP3oool0oooo000000020?ooo`060:ZZZP000000ZZZZ0?ooo`1EEED0oooo0P1EEED30:ZZ
ZP050000001EEED0oooo0?ooo`2ZZZX00P3oool01@000000ZZZZ0000002ZZZX0EEEE00@0oooo0`2Z
ZZX20?ooo`050000003oool0EEEE0:ZZZP0000000P1EEED20?ooo`050:ZZZP3oool0oooo0000002Z
ZZX01P3oool:0=7=Z@L0oooo0`0000000`3oool000000?ooo`020000000305EEE@2ZZZX000000080
ZZZZ00@0oooo0000001EEED0EEEE0P000000103oool0ZZZZ0000002ZZZX2000000<0oooo00<0ZZZZ
0?ooo`3oool00P2ZZZX20?ooo`80000000@0ZZZZ05EEE@2ZZZX0oooo0P00000205EEE@030000002Z
ZZX0ZZZZ00<0ZZZZ1@0000001@3oool0EEEE000000000000ZZZZ00H0oooo2P3AcJT70?ooo`040000
003oool0oooo000000@0EEEE1P3oool01`2ZZZX0oooo0?ooo`1EEED0oooo0:ZZZP0000000P2ZZZX3
0?ooo`030000003oool000000080oooo00T000000:ZZZP000000oooo0000003oool0ZZZZ05EEE@00
00000P3oool0101EEED000000?ooo`2ZZZX60?ooo`@0EEEE00D000000:ZZZP3oool000000:ZZZP06
0?ooo``0dLfY000;0=7=Z@H0oooo0`2ZZZX02@3oool000000:ZZZP1EEED0oooo05EEE@2ZZZX0EEEE
000000030:ZZZP070?ooo`1EEED0ZZZZ0:ZZZP000000EEEE000000030:ZZZP80EEEE00D0ZZZZ0?oo
o`1EEED0oooo0000000205EEE@030:ZZZP1EEED0ZZZZ0080ZZZZ00@0oooo0000001EEED000000P2Z
ZZX00`1EEED0oooo0?ooo`030:ZZZP0805EEE@2ZZZX0EEEE0?ooo`000000ZZZZ0000003oool20:ZZ
ZPL0oooo2P3AcJT60?ooo`@0ZZZZ00D0EEEE0:ZZZP00000000000?ooo`020:ZZZP0405EEE@2ZZZX0
ZZZZ000000<0oooo102ZZZX20?ooo`070:ZZZP00000000000:ZZZP000000EEEE0000000205EEE@03
0?ooo`2ZZZX000000080ZZZZ0P3oool40:ZZZP030000003oool0oooo00<0ZZZZ00L000000:ZZZP3o
ool0oooo0000003oool0ZZZZ0080EEEE0P2ZZZX70?ooo`X0dLfY1P3oool40:ZZZP<0oooo00H0ZZZZ
0000003oool0oooo0000001EEED30:ZZZP040?ooo`2ZZZX0EEEE05EEE@<0000000D0oooo0:ZZZP1E
EED000000?ooo`0205EEE@030?ooo`000000EEEE0080oooo00H000000?ooo`2ZZZX0oooo0:ZZZP00
000305EEE@80oooo00D0ZZZZ0?ooo`2ZZZX0EEEE0:ZZZP020?ooo`030000002ZZZX0oooo00<0oooo
0P2ZZZX70?ooo`X0dLfY1P3oool30:ZZZP0305EEE@3oool0oooo0080000000`0oooo0000002ZZZX0
000005EEE@000000EEEE0?ooo`2ZZZX0oooo0:ZZZP1EEED20?ooo`040000001EEED0000005EEE@80
oooo0P2ZZZX2000000080:ZZZP3oool0oooo0?ooo`2ZZZX0000005EEE@2ZZZX20?ooo`0405EEE@2Z
ZZX000000:ZZZP80oooo00@0000005EEE@2ZZZX0ZZZZ0P3oool200000080oooo0`2ZZZX70?ooo`X0
dLfY1P3oool30:ZZZP80oooo00D000000?ooo`000000000005EEE@030?ooo`0305EEE@3oool0oooo
0080ZZZZ00@0000005EEE@3oool0ZZZZ0P00000205EEE@050000003oool0ZZZZ0:ZZZP3oool00P2Z
ZZX20?ooo`090000003oool0EEEE0000001EEED0ZZZZ0?ooo`1EEED000000080ZZZZ0P3oool00`1E
EED0oooo0?ooo`020?ooo`@000000P3oool20:ZZZPL0oooo303AcJT000/0dLfY203oool30:ZZZP04
0?ooo`000000ZZZZ0:ZZZP80oooo00L0ZZZZ0000002ZZZX0oooo0:ZZZP000000oooo0080EEEE0P3o
ool0101EEED0oooo05EEE@2ZZZX20?ooo`8000000P3oool2000000<0oooo00D0EEEE0?ooo`3oool0
oooo0000000205EEE@030?ooo`000000ZZZZ0080ZZZZ0P0000000`3oool0ZZZZ0:ZZZP020:ZZZP04
0?ooo`2ZZZX0ZZZZ0:ZZZPP0oooo2P3AcJT80?ooo`<0ZZZZ0P0000001@1EEED000000:ZZZP3oool0
EEEE008000000P2ZZZX00`3oool0ZZZZ0:ZZZP030:ZZZP030000003oool0EEEE0080ZZZZ0`3oool2
000000070?ooo`2ZZZX0oooo0:ZZZP000000EEEE0?ooo`020:ZZZP070000002ZZZX0ZZZZ0000003o
ool0ZZZZ05EEE@02000000050:ZZZP3oool000000000001EEED00P0000030:ZZZPP0oooo2P3AcJT8
0?ooo`050:ZZZP3oool000000?ooo`0000000P3oool00`1EEED0oooo0?ooo`020:ZZZP0305EEE@3o
ool0oooo0080oooo00<0ZZZZ0000003oool00P2ZZZX01@3oool0EEEE0:ZZZP1EEED0000000@0oooo
0P1EEED00`2ZZZX0EEEE0?ooo`020:ZZZP050?ooo`1EEED0ZZZZ0?ooo`1EEED00P3oool010000000
ZZZZ0:ZZZP1EEED40?ooo`030:ZZZP3oool000000080ZZZZ203oool:0=7=Z@P0oooo00@0ZZZZ0?oo
o`3oool000000P3oool010000000oooo05EEE@3oool2000000030:ZZZP3oool00000008000000`2Z
ZZX00`000000ZZZZ0:ZZZP020?ooo`80ZZZZ00<0oooo0:ZZZP2ZZZX00P3oool00`2ZZZX0oooo05EE
E@060:ZZZP<0000000@0oooo00000000000000000P1EEED200000080oooo00@000000?ooo`2ZZZX0
ZZZZ203oool:0=7=Z@P0oooo00@0ZZZZ0000001EEED0oooo0P00000205EEE@<0ZZZZ00@0EEEE0000
0000000000000P2ZZZX01`3oool0ZZZZ0?ooo`000000EEEE0?ooo`1EEED00P3oool00`1EEED00000
00000002000000<0oooo00P0EEEE0?ooo`1EEED000000?ooo`000000oooo0:ZZZP<0000000<0oooo
05EEE@2ZZZX00`2ZZZX01@1EEED0000005EEE@3oool0EEEE0080ZZZZ203oool<0=7=Z@002`3AcJT:
0?ooo`050000002ZZZX0oooo0?ooo`2ZZZX00P3oool40:ZZZP050000003oool0oooo05EEE@000000
0P3oool00`1EEED000000:ZZZP030?ooo`030000003oool0EEEE00D0oooo0P2ZZZX01P000000oooo
0?ooo`3oool0000005EEE@80oooo00D0000005EEE@2ZZZX0ZZZZ05EEE@020?ooo`060:ZZZP3oool0
00000:ZZZP000000ZZZZ2@3oool:0=7=Z@X0oooo00X000000:ZZZP000000ZZZZ05EEE@2ZZZX0oooo
0000001EEED0oooo0`0000001P2ZZZX0EEEE0:ZZZP2ZZZX0EEEE0:ZZZP80000000<0oooo0:ZZZP3o
ool00P0000020:ZZZP050000002ZZZX0oooo0:ZZZP3oool00P0000001P2ZZZX0EEEE0:ZZZP2ZZZX0
EEEE0:ZZZP<0000000<0oooo05EEE@2ZZZX00P3oool01P1EEED0ZZZZ0:ZZZP2ZZZX000000:ZZZPT0
oooo2P3AcJT:0?ooo`030:ZZZP1EEED0oooo0080oooo0P1EEED20?ooo`050:ZZZP1EEED0EEEE0000
003oool00P2ZZZX20?ooo`080:ZZZP3oool0oooo05EEE@3oool000000?ooo`1EEED20?ooo`0505EE
E@2ZZZX000000?ooo`1EEED0103oool02@000000ZZZZ0:ZZZP2ZZZX0000005EEE@3oool0ZZZZ0?oo
o`0205EEE@<0oooo00@0000005EEE@2ZZZX0ZZZZ2@3oool:0=7=Z@X0oooo0P2ZZZX0203oool0ZZZZ
0:ZZZP2ZZZX0oooo0:ZZZP000000EEEE0`3oool00`000000oooo0?ooo`030?ooo`0405EEE@000000
ZZZZ0:ZZZP80oooo00@0ZZZZ0000002ZZZX0ZZZZ0P3oool01`2ZZZX0oooo0000001EEED0ZZZZ0?oo
o`2ZZZX00P3oool01@000000oooo0?ooo`2ZZZX0EEEE0080000000<0oooo0:ZZZP2ZZZX01@2ZZZX9
0?ooo`X0dLfY2P3oool2000000030?ooo`2ZZZX000000080EEEE00@000000:ZZZP000000oooo0P1E
EED01`2ZZZX0oooo0?ooo`1EEED000000:ZZZP1EEED01@000000103oool000000?ooo`3oool30000
00060?ooo`000000EEEE0?ooo`000000EEEE0`3oool305EEE@030000002ZZZX000000080EEEE00<0
00000:ZZZP0000000P0000000`2ZZZX0oooo0?ooo`070?ooo``0dLfY000;0=7=Z@X0oooo00<0ZZZZ
0?ooo`1EEED00`1EEED02P3oool0ZZZZ0:ZZZP3oool0EEEE0?ooo`000000oooo05EEE@3oool20:ZZ
ZP050000002ZZZX0oooo05EEE@2ZZZX00P3oool40:ZZZP0505EEE@3oool0ZZZZ0:ZZZP3oool0102Z
ZZX02`3oool0EEEE000000000000oooo05EEE@3oool0ZZZZ05EEE@3oool0ZZZZ0080EEEE00<00000
0?ooo`2ZZZX02P3oool:0=7=Z@X0oooo00D0ZZZZ0?ooo`00000000000?ooo`0305EEE@050000003o
ool0ZZZZ0?ooo`0000001@2ZZZX20?ooo`060000003oool0ZZZZ0000001EEED0oooo0P1EEED00`3o
ool00000000000020:ZZZP030000003oool0ZZZZ00@0ZZZZ00<0oooo0000003oool00P3oool01@00
0000EEEE05EEE@2ZZZX0oooo0080000000<0oooo0:ZZZP3oool02@3oool:0=7=Z@X0oooo00<0ZZZZ
0?ooo`3oool00`3oool205EEE@80oooo00D0ZZZZ0?ooo`000000ZZZZ000000020?ooo`0305EEE@3o
ool0oooo0080ZZZZ0P1EEED01P3oool000000?ooo`3oool000000?ooo`80EEEE00D0oooo0:ZZZP3o
ool0oooo05EEE@020?ooo`030000001EEED0000000@0oooo0`1EEED20?ooo`0305EEE@3oool0ZZZZ
00X0oooo2P3AcJT:0?ooo`040:ZZZP3oool0000000000080ZZZZ0P0000000`3oool0ZZZZ0?ooo`02
000000040?ooo`1EEED0oooo0?ooo`<0ZZZZ00<0EEEE0:ZZZP2ZZZX00P2ZZZX01@3oool000000000
003oool0EEEE00<0ZZZZ00@0EEEE0:ZZZP3oool0ZZZZ0P3oool01`1EEED0oooo000000000000oooo
0:ZZZP3oool00`0000001@2ZZZX0000005EEE@3oool0ZZZZ00X0oooo2P3AcJT:0?ooo`060:ZZZP3o
ool0ZZZZ0?ooo`2ZZZX0EEEE0P3oool00`1EEED000000?ooo`040?ooo`090:ZZZP000000000005EE
E@3oool0EEEE0000001EEED0ZZZZ0080000000l0EEEE000000000000EEEE0:ZZZP1EEED0000005EE
E@3oool0EEEE0000003oool0ZZZZ0?ooo`0000000P3oool20000000305EEE@000000oooo0080ZZZZ
0`3oool00`2ZZZX0oooo0?ooo`080?ooo``0dLfY000;0=7=Z@/0oooo0P2ZZZX01P000000ZZZZ05EE
E@1EEED0oooo0:ZZZP<0000000@0oooo00000000000000000`3oool205EEE@070?ooo`000000ZZZZ
0:ZZZP000000ZZZZ0?ooo`02000000030:ZZZP000000EEEE0080EEEE00<0ZZZZ0?ooo`2ZZZX00P00
00020?ooo`<0000000<0ZZZZ0000001EEED00P2ZZZX00`000000ZZZZ0:ZZZP0;0?ooo`X0dLfY2`3o
ool30:ZZZP80000000<0oooo0000003oool00P3oool20:ZZZP<0000000D0EEEE0000001EEED0EEEE
000000020:ZZZP0405EEE@2ZZZX000000?ooo`8000000P1EEED0102ZZZX0oooo0000001EEED60000
0080ZZZZ0`3oool010000000oooo0000000000030:ZZZP/0oooo2P3AcJT;0?ooo`030:ZZZP1EEED0
00000080ZZZZ01<000000:ZZZP000000EEEE0000003oool000000:ZZZP3oool0EEEE0?ooo`1EEED0
000005EEE@2ZZZX000000?ooo`2ZZZX0000000@0oooo00D000000:ZZZP3oool0EEEE0:ZZZP0305EE
E@060?ooo`1EEED0oooo0?ooo`000000oooo0P1EEED01P000000oooo0000001EEED0ZZZZ00000080
ZZZZ2`3oool:0=7=Z@/0oooo00<0ZZZZ05EEE@0000000P2ZZZX00`000000ZZZZ0?ooo`040:ZZZP05
0?ooo`2ZZZX000000000002ZZZX00P3oool30:ZZZP040000003oool0oooo00000080oooo00H0ZZZZ
0000002ZZZX000000:ZZZP3oool20:ZZZP800000102ZZZX01@3oool0ZZZZ0?ooo`1EEED000000080
ZZZZ00<000000:ZZZP2ZZZX02`3oool:0=7=Z@/0oooo00<0ZZZZ0000000000000P00000205EEE@05
0000002ZZZX0000005EEE@3oool00P2ZZZX20?ooo`@0000000@0oooo000000000000ZZZZ0P3oool0
0`000000oooo05EEE@02000000050?ooo`00000000000?ooo`0000000P3oool02P2ZZZX000000?oo
o`1EEED0oooo0:ZZZP000000oooo05EEE@2ZZZX200000080ZZZZ2`3oool<0=7=Z@002`3AcJT=0?oo
o`030000003oool000000080ZZZZ103oool010000000oooo0?ooo`0000020:ZZZP@000000P3oool0
101EEED0ZZZZ0:ZZZP3oool20:ZZZP80oooo0`0000001@3oool0ZZZZ0?ooo`000000oooo00800000
00@0oooo0000003oool0oooo0`2ZZZX00`3oool000000:ZZZP0<0?ooo`X0dLfY3@3oool00`000000
ZZZZ000000030:ZZZP090?ooo`2ZZZX0oooo0000002ZZZX000000:ZZZP000000EEEE008000000P3o
ool00`2ZZZX000000:ZZZP020:ZZZP050000002ZZZX0EEEE0000002ZZZX00P3oool00`000000oooo
05EEE@020:ZZZP080000002ZZZX000000?ooo`2ZZZX0oooo0:ZZZP0000030:ZZZP030000002ZZZX0
oooo00/0oooo2P3AcJT=0?ooo`030000003oool0EEEE0080ZZZZ00<0oooo05EEE@3oool00P2ZZZX2
0?ooo`@0EEEE0P2ZZZX30?ooo`0305EEE@3oool0oooo0080oooo00@0ZZZZ0?ooo`3oool000000P2Z
ZZX01@3oool0EEEE05EEE@1EEED0oooo00<0ZZZZ0P1EEED20?ooo`050:ZZZP1EEED0oooo0000002Z
ZZX0303oool:0=7=Z@d0oooo0`0000000`3oool0ZZZZ0:ZZZP020?ooo`070:ZZZP3oool0ZZZZ0:ZZ
ZP000000ZZZZ0?ooo`020:ZZZP060?ooo`000000EEEE0000002ZZZX0oooo0P2ZZZX0103oool0ZZZZ
0000001EEED20?ooo`060:ZZZP3oool0oooo05EEE@000000ZZZZ0P3oool01`2ZZZX0oooo0?ooo`2Z
ZZX000000?ooo`1EEED00P0000000`2ZZZX0oooo0?ooo`0:0?ooo`X0dLfY3@3oool00`000000oooo
0?ooo`0200000080oooo00@0ZZZZ05EEE@000000ZZZZ0P3oool01`000000oooo0?ooo`000000oooo
0:ZZZP3oool00P1EEED010000000oooo0?ooo`00000205EEE@040?ooo`2ZZZX0oooo00000080oooo
00L0EEEE0?ooo`3oool0oooo0000001EEED0ZZZZ0080oooo0P000000102ZZZX0oooo0000002ZZZX<
0?ooo``0dLfY000;0=7=Z@d0oooo00@0ZZZZ0?ooo`000000oooo0`2ZZZX01P3oool0ZZZZ0:ZZZP3o
ool000000:ZZZP80oooo00<0ZZZZ0000003oool00P3oool01P2ZZZX0EEEE0?ooo`3oool0EEEE0?oo
o`80ZZZZ00@0oooo0:ZZZP3oool000000`3oool00`2ZZZX00000000000050:ZZZP80oooo00<00000
0?ooo`2ZZZX03@3oool:0=7=Z@d0oooo00@0ZZZZ0?ooo`00000000000`2ZZZX20?ooo`070:ZZZP00
000000000000002ZZZX0000005EEE@02000000<0oooo00H0000005EEE@2ZZZX0000005EEE@000002
0?ooo`060:ZZZP00000000000:ZZZP000000oooo0P000000103oool0ZZZZ0?ooo`1EEED20:ZZZP05
0?ooo`00000000000?ooo`2ZZZX03@3oool:0=7=Z@d0oooo00@0ZZZZ0?ooo`1EEED0ZZZZ101EEED2
0?ooo`030:ZZZP3oool00000008000000P2ZZZX00`1EEED0oooo0?ooo`020?ooo`050000003oool0
oooo0000001EEED00`3oool00`1EEED0ZZZZ0?ooo`03000000030?ooo`2ZZZX0oooo0080oooo0`1E
EED0102ZZZX0oooo0?ooo`2ZZZX=0?ooo`X0dLfY3@3oool00`2ZZZX0oooo0:ZZZP02000000030?oo
o`2ZZZX0ZZZZ00@0ZZZZ00P0EEEE000000000000ZZZZ0?ooo`1EEED000000:ZZZP80oooo00@0EEEE
0?ooo`000000EEEE0P3oool20:ZZZP0305EEE@3oool000000080000000<0EEEE0:ZZZP2ZZZX00P2Z
ZZX00`1EEED0ZZZZ0?ooo`0200000080oooo00<0ZZZZ0?ooo`3oool02`3oool:0=7=Z@d0oooo00<0
ZZZZ0?ooo`1EEED00P3oool00`1EEED000000?ooo`020000000305EEE@3oool0EEEE00D0oooo00@0
00000?ooo`2ZZZX0EEEE103oool20:ZZZP030?ooo`000000oooo00<0oooo0P1EEED0203oool0EEEE
000000000000ZZZZ0000001EEED000000`3oool00`2ZZZX0oooo0?ooo`0;0?ooo``0dLfY000;0=7=
Z@h0oooo102ZZZX01@000000oooo0?ooo`2ZZZX000000080oooo00T0000005EEE@000000EEEE0:ZZ
ZP3oool0000005EEE@2ZZZX00P1EEED00`3oool0000005EEE@020:ZZZP0305EEE@2ZZZX0oooo0080
ZZZZ00<000000:ZZZP0000000P3oool01P000000ZZZZ0:ZZZP3oool000000?ooo`<0ZZZZ3P3oool:
0=7=Z@h0oooo0`2ZZZX20000000405EEE@2ZZZX00000000000<0ZZZZ0P3oool0102ZZZX0EEEE0?oo
o`2ZZZX2000000060:ZZZP000000oooo05EEE@000000ZZZZ0`000000103oool0EEEE0000003oool3
0:ZZZP@0000000<0EEEE0000000000000`2ZZZX>0?ooo`X0dLfY3P3oool00`2ZZZX0oooo00000003
000000040?ooo`2ZZZX0ZZZZ0?ooo`@0ZZZZ0P3oool00`2ZZZX000000?ooo`02000000@0oooo0P00
0000103oool000000:ZZZP3oool50:ZZZP030?ooo`2ZZZX0ZZZZ00<0000000@0EEEE0000002ZZZX0
ZZZZ3P3oool:0=7=Z@h0oooo00<0ZZZZ0?ooo`3oool00`3oool00`000000ZZZZ0:ZZZP020:ZZZP07
0000003oool000000?ooo`1EEED0oooo000000040:ZZZP040000001EEED0ZZZZ0?ooo`80ZZZZ00<0
EEEE0?ooo`1EEED00P000000103oool000000:ZZZP0000030:ZZZP80oooo00@000000?ooo`2ZZZX0
ZZZZ3P3oool:0=7=Z@h0oooo00H0ZZZZ0000001EEED0EEEE0000002ZZZX20?ooo`D0000000X0EEEE
0?ooo`1EEED000000?ooo`000000EEEE0000002ZZZX0oooo0P2ZZZX205EEE@070000003oool00000
05EEE@3oool0EEEE0?ooo`02000000080?ooo`000000oooo0?ooo`2ZZZX000000?ooo`1EEED20:ZZ
ZPh0oooo303AcJT000/0dLfY403oool200000080oooo0P2ZZZX0101EEED0oooo0?ooo`3oool20:ZZ
ZP80EEEE00<0oooo0:ZZZP1EEED00P1EEED01@000000oooo0?ooo`000000oooo0080EEEE0P3oool0
101EEED0ZZZZ0:ZZZP0000030?ooo`0305EEE@2ZZZX0oooo0080oooo00<0ZZZZ0000002ZZZX03`3o
ool:0=7=ZA00oooo00X000000:ZZZP000000ZZZZ0?ooo`1EEED000000?ooo`2ZZZX0oooo0P2ZZZX3
05EEE@070?ooo`2ZZZX0EEEE0?ooo`1EEED0ZZZZ0000000305EEE@060:ZZZP000000EEEE05EEE@3o
ool0ZZZZ0P3oool00`2ZZZX0oooo0000000205EEE@050:ZZZP000000ZZZZ0000002ZZZX03`3oool:
0=7=ZA00oooo0P2ZZZX0103oool0EEEE0?ooo`2ZZZX30?ooo`030:ZZZP3oool0ZZZZ00<0oooo00<0
EEEE0?ooo`3oool01@3oool010000000oooo0?ooo`2ZZZX30?ooo`030:ZZZP3oool0ZZZZ00<0oooo
0P2ZZZX00`1EEED0oooo05EEE@020:ZZZPl0oooo2P3AcJT@0?ooo`80ZZZZ00L0oooo0:ZZZP000000
EEEE0000003oool0ZZZZ00<0oooo00H000000:ZZZP3oool0000005EEE@0000020:ZZZP030?ooo`00
0000ZZZZ0080000000`0EEEE0:ZZZP3oool0ZZZZ0000003oool0EEEE0?ooo`2ZZZX0oooo0000001E
EED20:ZZZP040?ooo`2ZZZX0ZZZZ0:ZZZPl0oooo2P3AcJT@0?ooo`80000000H0oooo0:ZZZP2ZZZX0
ZZZZ0000001EEED20:ZZZP0:0?ooo`00000000000000003oool0ZZZZ0?ooo`000000oooo0:ZZZP80
oooo00H0ZZZZ000000000000oooo0:ZZZP3oool3000000<0ZZZZ00H0oooo0000002ZZZX0oooo0:ZZ
ZP3oool2000000030:ZZZP3oool0oooo00d0oooo303AcJT000/0dLfY403oool02@2ZZZX0000005EE
E@1EEED0ZZZZ0000002ZZZX0EEEE0?ooo`020:ZZZP80oooo00@0000005EEE@1EEED0ZZZZ0P1EEED4
0?ooo`030:ZZZP1EEED0ZZZZ0080EEEE00<000000?ooo`3oool00P2ZZZX0103oool0ZZZZ0:ZZZP00
000305EEE@030?ooo`2ZZZX0oooo00l0oooo2P3AcJT@0?ooo`050:ZZZP00000000000000002ZZZX0
0P1EEED01@2ZZZX00000000000000000ZZZZ00<0EEEE00<0ZZZZ0000002ZZZX00P2ZZZX01`000000
EEEE0:ZZZP000000ZZZZ0000003oool00P1EEED20:ZZZP@000000P1EEED01@3oool000000000003o
ool0ZZZZ0100oooo2P3AcJT@0?ooo`030:ZZZP1EEED0oooo0080EEEE102ZZZX70?ooo`030000003o
ool0EEEE00H0oooo00<0000005EEE@3oool00`3oool0102ZZZX0oooo0:ZZZP3oool20:ZZZP050?oo
o`1EEED0oooo0?ooo`2ZZZX0403oool:0=7=ZA00oooo00<0ZZZZ05EEE@0000000P0000001@2ZZZX0
oooo000000000000oooo00800000103oool00`2ZZZX00000000000040?ooo`030:ZZZP000000ZZZZ
00<0oooo00D0ZZZZ0000002ZZZX0oooo000000020?ooo`80ZZZZ0P0000000`3oool0ZZZZ0?ooo`0?
0?ooo`X0dLfY403oool01@2ZZZX0oooo0:ZZZP3oool0ZZZZ0080000000H0oooo0:ZZZP3oool0ZZZZ
0000001EEED2000000030:ZZZP000000000000D0000000@0EEEE000000000000ZZZZ1@0000000`3o
ool0ZZZZ00000002000000050:ZZZP3oool0ZZZZ0?ooo`2ZZZX0403oool<0=7=Z@002`3AcJTA0?oo
o`80ZZZZ00d000000:ZZZP1EEED0oooo05EEE@2ZZZX000000:ZZZP3oool0ZZZZ0?ooo`1EEED0oooo
0080EEEE00<0ZZZZ0000003oool00P0000001`2ZZZX0EEEE05EEE@000000EEEE0?ooo`2ZZZX00P3o
ool01`000000ZZZZ05EEE@3oool0EEEE0:ZZZP0000000P2ZZZXA0?ooo`X0dLfY4@3oool30:ZZZP80
000000`0oooo05EEE@000000oooo0000003oool0000005EEE@2ZZZX0000005EEE@3oool20000000=
0:ZZZP1EEED0000005EEE@3oool0EEEE0000002ZZZX0EEEE0:ZZZP3oool0EEEE0?ooo`0200000003
0?ooo`000000000000<0ZZZZ4@3oool:0=7=ZA40oooo00@0ZZZZ05EEE@000000ZZZZ0P3oool0102Z
ZZX000000:ZZZP1EEED200000080EEEE0P3oool010000000oooo0:ZZZP3oool20:ZZZP80000000X0
oooo05EEE@1EEED0EEEE0:ZZZP000000EEEE0:ZZZP000000ZZZZ0P3oool20000000305EEE@2ZZZX0
oooo0100oooo2P3AcJTA0?ooo`030:ZZZP1EEED000000080ZZZZ0P0000020?ooo`040:ZZZP1EEED0
00000:ZZZP<000000P1EEED40?ooo`030:ZZZP1EEED000000080000000<0ZZZZ0000001EEED00`3o
ool200000080ZZZZ00<0000005EEE@2ZZZX04@3oool:0=7=ZA40oooo00H0ZZZZ000000000000ZZZZ
0000003oool205EEE@080000003oool0ZZZZ0?ooo`000000ZZZZ0?ooo`2ZZZX2000000030?ooo`00
0000oooo0080oooo00@000000:ZZZP3oool0ZZZZ0P0000001P2ZZZX0oooo0000001EEED0ZZZZ0?oo
o`@0000000<0ZZZZ0?ooo`3oool03`3oool<0=7=Z@002`3AcJTB0?ooo`80ZZZZ0P3oool030000000
ZZZZ0000003oool0000005EEE@2ZZZX0oooo05EEE@2ZZZX0oooo00000080ZZZZ0140oooo0:ZZZP2Z
ZZX0oooo0000003oool0000005EEE@3oool0000005EEE@2ZZZX0oooo0000002ZZZX000000?ooo`03
0:ZZZQ80oooo2P3AcJTB0?ooo`80ZZZZ00@0EEEE0:ZZZP1EEED0oooo0P0000000`3oool0ZZZZ0:ZZ
ZP020:ZZZP80EEEE00<0ZZZZ0000000000000P2ZZZX01@000000oooo0:ZZZP1EEED000000080ZZZZ
00<0oooo0:ZZZP3oool00P0000000`2ZZZX0EEEE0:ZZZP030:ZZZQ80oooo2P3AcJTB0?ooo`80ZZZZ
00<0oooo0:ZZZP3oool00P3oool01@2ZZZX0oooo0000002ZZZX0EEEE0080000000<0oooo0000002Z
ZZX0103oool00`2ZZZX000000?ooo`020000000505EEE@2ZZZX000000000002ZZZX00`3oool40:ZZ
ZQ80oooo2P3AcJTB0?ooo`<0ZZZZ00<0EEEE0?ooo`3oool00P0000002@3oool0ZZZZ0000003oool0
EEEE0?ooo`1EEED000000:ZZZP04000000050?ooo`000000EEEE0000001EEED00P3oool0102ZZZX0
oooo0000000000020?ooo`0405EEE@2ZZZX0ZZZZ0:ZZZQ80oooo2P3AcJTB0?ooo`80ZZZZ0`3oool0
0`000000oooo00000002000000040:ZZZP3oool0oooo05EEE@80oooo0P000000102ZZZX000000000
002ZZZX50?ooo`@0000000@0oooo0000003oool0oooo0`2ZZZXB0?ooo``0dLfY000;0=7=ZA<0oooo
00H0ZZZZ000000000000oooo0:ZZZP3oool205EEE@030:ZZZP3oool0EEEE0080oooo0P2ZZZX30?oo
o`030:ZZZP3oool0ZZZZ0080ZZZZ00L000000?ooo`1EEED0EEEE0:ZZZP3oool0EEEE00<0oooo00<0
00000?ooo`2ZZZX04`3oool:0=7=ZA<0oooo00@0ZZZZ00000000000000000`2ZZZX00`3oool0ZZZZ
0:ZZZP020?ooo`0605EEE@000000ZZZZ0:ZZZP1EEED0oooo0P1EEED0103oool0ZZZZ0000002ZZZX3
0?ooo`@0ZZZZ00D0oooo000000000000oooo0:ZZZP0C0?ooo`X0dLfY4`3oool0102ZZZX0oooo05EE
E@00000205EEE@080000003oool0oooo05EEE@3oool0EEEE0?ooo`1EEED60?ooo`070:ZZZP3oool0
EEEE0:ZZZP1EEED0oooo000000020?ooo`070000001EEED0EEEE0000001EEED0oooo0:ZZZP0C0?oo
o`X0dLfY4`3oool00`2ZZZX0oooo0:ZZZP02000000040:ZZZP1EEED0oooo0?ooo`80ZZZZ00<0oooo
0000002ZZZX00P3oool02@000000oooo000000000000EEEE0?ooo`2ZZZX000000?ooo`020:ZZZP80
oooo00L0EEEE0:ZZZP00000000000:ZZZP3oool0ZZZZ01<0oooo2P3AcJTC0?ooo`030:ZZZP3oool0
EEEE0080oooo0P2ZZZX00`3oool0EEEE0?ooo`020?ooo`090000002ZZZX0ZZZZ0?ooo`000000ZZZZ
0?ooo`000000oooo0080ZZZZ00@0EEEE0?ooo`3oool0ZZZZ0P1EEED20:ZZZP050000003oool0EEEE
0?ooo`2ZZZX04`3oool<0=7=Z@002`3AcJTD0?ooo`@0ZZZZ0P0000020:ZZZP0605EEE@000000oooo
0?ooo`000000ZZZZ0P0000001@3oool0ZZZZ0000003oool0ZZZZ0080000000@0oooo0000001EEED0
ZZZZ0`000000103oool0ZZZZ0:ZZZP2ZZZXD0?ooo`X0dLfY503oool30:ZZZP8000000140EEEE0000
002ZZZX0ZZZZ0?ooo`2ZZZX0EEEE0000003oool0ZZZZ05EEE@2ZZZX0000005EEE@2ZZZX0oooo0000
00020:ZZZP80oooo00<0ZZZZ0000001EEED00P0000030:ZZZQ@0oooo2P3AcJTD0?ooo`050:ZZZP3o
ool000000:ZZZP0000000`3oool20:ZZZP040?ooo`1EEED0ZZZZ0:ZZZPH0oooo0P2ZZZX010000000
oooo0:ZZZP1EEED30?ooo`050000003oool000000?ooo`2ZZZX0503oool:0=7=ZA@0oooo00<0ZZZZ
0?ooo`3oool00P3oool00`2ZZZX000000:ZZZP020:ZZZP040000003oool0000005EEE@80oooo0P00
00000`3oool0EEEE05EEE@03000000070:ZZZP000000ZZZZ0000002ZZZX0oooo000000020?ooo`03
0:ZZZP3oool0oooo0180oooo2P3AcJTD0?ooo`040:ZZZP000000EEEE05EEE@80000000<0ZZZZ05EE
E@0000000P0000000`3oool0ZZZZ0?ooo`020?ooo`0305EEE@000000oooo0080oooo00<0ZZZZ0000
000000000P00000205EEE@80000000@0oooo05EEE@000000ZZZZ503oool<0=7=Z@002`3AcJTE0?oo
o`80ZZZZ00X0EEEE0?ooo`3oool0ZZZZ0000003oool0ZZZZ0?ooo`1EEED000000P2ZZZX200000005
0:ZZZP000000oooo0:ZZZP0000000P3oool0102ZZZX0oooo0000001EEED20?ooo`<0ZZZZ5@3oool:
0=7=ZAD0oooo0P2ZZZX00`1EEED0ZZZZ05EEE@020000000405EEE@3oool000000:ZZZP80oooo0P2Z
ZZX010000000EEEE0:ZZZP2ZZZX20?ooo`0705EEE@000000oooo05EEE@000000ZZZZ05EEE@040:ZZ
ZQD0oooo2P3AcJTE0?ooo`80ZZZZ103oool205EEE@030?ooo`2ZZZX0ZZZZ00X0oooo0P2ZZZX00`3o
ool0EEEE05EEE@030?ooo`030000002ZZZX0ZZZZ01D0oooo2P3AcJTE0?ooo`@0ZZZZ00<0oooo05EE
E@1EEED00`2ZZZX305EEE@80oooo0P0000000`3oool0000005EEE@0205EEE@<0ZZZZ00D0EEEE0?oo
o`3oool0ZZZZ000000020:ZZZQD0oooo2P3AcJTE0?ooo`@0ZZZZ00@0oooo00000000000000000P1E
EED5000000030?ooo`000000000000<000000`1EEED0103oool000000?ooo`3oool40:ZZZQD0oooo
303AcJT000/0dLfY5P3oool0102ZZZX0000005EEE@1EEED20:ZZZP050?ooo`2ZZZX000000:ZZZP1E
EED00P3oool00`1EEED0ZZZZ0:ZZZP0205EEE@040?ooo`1EEED0EEEE000000<0ZZZZ0`1EEED00`3o
ool0ZZZZ0?ooo`0E0?ooo`X0dLfY5P3oool01@2ZZZX00000000000000000ZZZZ00<0EEEE0P000000
1P2ZZZX00000000000000000ZZZZ05EEE@<0000000<0ZZZZ0?ooo`0000000`1EEED01@3oool00000
0000003oool0ZZZZ01H0oooo2P3AcJTF0?ooo`070:ZZZP1EEED0oooo0?ooo`1EEED0oooo05EEE@0=
0?ooo`040:ZZZP3oool0oooo05EEE@D0oooo00<0ZZZZ0?ooo`3oool0503oool:0=7=ZAH0oooo00<0
ZZZZ05EEE@0000000P0000030?ooo`040:ZZZP000000ZZZZ0?ooo`80000000`0oooo000000000000
00000?ooo`2ZZZX0oooo0:ZZZP3oool0ZZZZ0?ooo`2ZZZX2000000030?ooo`2ZZZX0oooo01D0oooo
2P3AcJTF0?ooo`090:ZZZP3oool0ZZZZ0?ooo`2ZZZX0EEEE0000003oool000000080oooo00<00000
0?ooo`0000000P3oool010000000ZZZZ0000003oool200000080oooo00H0EEEE0:ZZZP3oool0ZZZZ
0?ooo`2ZZZXF0?ooo``0dLfY000;0=7=ZAL0oooo00D0ZZZZ0?ooo`000000ZZZZ000000020?ooo`08
05EEE@000000ZZZZ0:ZZZP3oool0EEEE0?ooo`00000205EEE@<0ZZZZ00H0EEEE0?ooo`2ZZZX00000
0?ooo`00000I0?ooo`X0dLfY5`3oool0102ZZZX0oooo0000002ZZZX2000000L0ZZZZ0P1EEED01@2Z
ZZX0EEEE0:ZZZP2ZZZX0oooo00<0ZZZZ00<000000:ZZZP0000006@3oool:0=7=ZAL0oooo00<0ZZZZ
0?ooo`0000000P1EEED00`3oool0ZZZZ0?ooo`0=0?ooo`80ZZZZ00<0EEEE0?ooo`0000006@3oool:
0=7=ZAL0oooo00H0ZZZZ0?ooo`000000EEEE0000002ZZZX20000000305EEE@000000oooo00800000
00D0oooo00000000000000000?ooo`08000001T0oooo2P3AcJTG0?ooo`050:ZZZP3oool000000:ZZ
ZP3oool00P000000102ZZZX0EEEE0?ooo`0000050?ooo`80000000<0oooo0000002ZZZX00P000002
0?ooo`030000003oool0oooo01L0oooo303AcJT000/0dLfY603oool20:ZZZP80oooo00@0ZZZZ0000
001EEED0EEEE0P2ZZZX01P1EEED000000?ooo`3oool0000005EEE@80ZZZZ00D0oooo05EEE@000000
00000?ooo`030:ZZZQP0oooo2P3AcJTH0?ooo`80ZZZZ00@0EEEE0:ZZZP2ZZZX0oooo0P0000001@3o
ool0ZZZZ05EEE@000000oooo00<0000000H0ZZZZ0?ooo`2ZZZX000000?ooo`1EEED40:ZZZQP0oooo
2P3AcJTH0?ooo`80ZZZZ00<0oooo0000002ZZZX00`3oool00`1EEED0oooo0?ooo`060?ooo`0605EE
E@3oool0oooo0?ooo`2ZZZX000000`2ZZZXH0?ooo`X0dLfY603oool30:ZZZP0505EEE@2ZZZX0oooo
05EEE@0000000P3oool200000080oooo00H000000?ooo`3oool0oooo0:ZZZP1EEED20?ooo`0405EE
E@2ZZZX0ZZZZ0:ZZZQP0oooo2P3AcJTH0?ooo`80ZZZZ0P3oool020000000oooo0?ooo`1EEED00000
0?ooo`000000EEEE0P3oool01@1EEED0oooo0?ooo`000000ZZZZ00@0oooo0`2ZZZXH0?ooo``0dLfY
000;0=7=ZAT0oooo00P0ZZZZ000000000000oooo0:ZZZP1EEED000000?ooo`<0ZZZZ00H0oooo0:ZZ
ZP2ZZZX000000:ZZZP3oool205EEE@050:ZZZP3oool000000?ooo`2ZZZX06@3oool:0=7=ZAT0oooo
00@0ZZZZ000000000000oooo0P2ZZZX01@1EEED0oooo0?ooo`1EEED000000080oooo00@000000:ZZ
ZP3oool0oooo0`2ZZZX2000000030?ooo`2ZZZX0oooo01P0oooo2P3AcJTI0?ooo`030:ZZZP3oool0
EEEE00D0EEEE0P3oool0101EEED0oooo0?ooo`1EEED20?ooo`@0EEEE00@0ZZZZ05EEE@3oool0ZZZZ
6@3oool:0=7=ZAT0oooo00@0ZZZZ0?ooo`2ZZZX000000P1EEED4000000@0oooo0`0000001`3oool0
EEEE05EEE@000000ZZZZ0?ooo`2ZZZX06@3oool:0=7=ZAT0oooo00X0ZZZZ0?ooo`1EEED000000?oo
o`1EEED000000?ooo`2ZZZX0oooo100000020:ZZZP030?ooo`000000EEEE0080oooo00<0EEEE0?oo
o`2ZZZX06@3oool<0=7=Z@002`3AcJTJ0?ooo`060:ZZZP3oool0ZZZZ0000003oool0ZZZZ0P3oool0
0`1EEED0ZZZZ0?ooo`020:ZZZPD0oooo0P00000L0?ooo`X0dLfY6P3oool0202ZZZX0oooo0:ZZZP2Z
ZZX0000005EEE@3oool0EEEE1@3oool01`000000EEEE0?ooo`2ZZZX000000:ZZZP000000703oool:
0=7=ZAX0oooo00`0ZZZZ0?ooo`1EEED0ZZZZ0?ooo`2ZZZX0oooo05EEE@3oool0EEEE0?ooo`2ZZZX3
05EEE@030?ooo`1EEED0oooo0080ZZZZ703oool:0=7=ZAX0oooo00D0ZZZZ0?ooo`2ZZZX0ZZZZ0?oo
o`03000000H0oooo0P0000020?ooo`80ZZZZ703oool:0=7=ZAX0oooo00@0ZZZZ0?ooo`0000000000
0P3oool0102ZZZX000000:ZZZP3oool20:ZZZP030?ooo`1EEED000000080ZZZZ00<0oooo00000000
0000703oool<0=7=Z@002`3AcJTK0?ooo`80ZZZZ00@0EEEE0?ooo`1EEED0EEEE0P0000000`2ZZZX0
oooo0?ooo`020:ZZZP050000001EEED0oooo0?ooo`1EEED00P2ZZZXK0?ooo`X0dLfY6`3oool20:ZZ
ZP0305EEE@2ZZZX0ZZZZ008000001P3oool20000000305EEE@2ZZZX0EEEE0080ZZZZ6`3oool:0=7=
ZA/0oooo00<0ZZZZ0000003oool00P1EEED00`000000EEEE000000020?ooo`080:ZZZP3oool00000
05EEE@000000oooo05EEE@3oool20:ZZZQ/0oooo2P3AcJTK0?ooo`030:ZZZP000000ZZZZ0080ZZZZ
00<0EEEE00000000000010000000102ZZZX0000005EEE@3oool40:ZZZQ/0oooo2P3AcJTK0?ooo`@0
ZZZZ0P3oool0102ZZZX000000000001EEED20000000405EEE@2ZZZX0oooo0?ooo`@0ZZZZ6`3oool<
0=7=Z@002`3AcJTL0?ooo`D0ZZZZ00H0EEEE0000003oool0oooo0:ZZZP3oool205EEE@040:ZZZP00
0000ZZZZ0:ZZZQd0oooo2P3AcJTL0?ooo`<0ZZZZ100000001@1EEED000000:ZZZP1EEED0oooo0080
00000`2ZZZXM0?ooo`X0dLfY703oool20:ZZZP0705EEE@000000ZZZZ0?ooo`2ZZZX0oooo05EEE@04
0?ooo`040:ZZZP000000EEEE0:ZZZQd0oooo2P3AcJTL0?ooo`80ZZZZ00@0EEEE0:ZZZP2ZZZX00000
0P3oool200000080oooo00D000000:ZZZP000000EEEE0:ZZZP0M0?ooo`X0dLfY703oool20:ZZZP80
000000X0ZZZZ0000002ZZZX0ZZZZ05EEE@3oool0ZZZZ0?ooo`000000ZZZZ0P0000000`2ZZZX0oooo
0?ooo`0K0?ooo``0dLfY000;0=7=ZAd0oooo00D0ZZZZ0?ooo`3oool0ZZZZ000000020:ZZZP80oooo
0P2ZZZX01@000000ZZZZ0000003oool0ZZZZ01d0oooo2P3AcJTM0?ooo`040:ZZZP3oool0ZZZZ0:ZZ
ZP8000000P2ZZZX0201EEED0ZZZZ0:ZZZP000000ZZZZ0000003oool0ZZZZ7@3oool:0=7=ZAd0oooo
00D0ZZZZ0?ooo`3oool0oooo0:ZZZP030?ooo`0805EEE@3oool0ZZZZ0:ZZZP3oool000000?ooo`2Z
ZZXM0?ooo`X0dLfY7@3oool0102ZZZX0oooo0000001EEED3000000090?ooo`00000000000:ZZZP00
0000EEEE0000003oool0ZZZZ01d0oooo2P3AcJTM0?ooo`050:ZZZP3oool0oooo0:ZZZP3oool00P1E
EED02@3oool0000005EEE@000000oooo0:ZZZP000000oooo0:ZZZP0M0?ooo``0dLfY000;0=7=ZAh0
oooo0P2ZZZX20?ooo`030:ZZZP3oool0oooo0080oooo00<000000?ooo`3oool00P2ZZZXN0?ooo`X0
dLfY7P3oool20:ZZZP0405EEE@2ZZZX0ZZZZ0?ooo`80000000@0oooo05EEE@2ZZZX0EEEE0P2ZZZXN
0?ooo`X0dLfY7P3oool20:ZZZP040?ooo`2ZZZX0oooo0?ooo`80EEEE0P3oool0102ZZZX0oooo0:ZZ
ZP2ZZZXN0?ooo`X0dLfY7P3oool30:ZZZP0305EEE@00000000000080oooo00<000000?ooo`1EEED0
0`2ZZZXN0?ooo`X0dLfY7P3oool20:ZZZP80oooo0P0000020?ooo`040000003oool0oooo0?ooo`80
ZZZZ7P3oool<0=7=Z@002`3AcJTO0?ooo`<0ZZZZ00@0oooo0:ZZZP3oool00000102ZZZXP0?ooo`X0
dLfY7`3oool30:ZZZPD000000`2ZZZXP0?ooo`X0dLfY7`3oool20:ZZZP80oooo00L0ZZZZ0?ooo`00
0000ZZZZ0000003oool0ZZZZ0200oooo2P3AcJTO0?ooo`80ZZZZ00<0oooo0000000000000`000002
0?ooo`030:ZZZP3oool0oooo01h0oooo2P3AcJTO0?ooo`80ZZZZ00D000000?ooo`1EEED0oooo0000
000205EEE@030000002ZZZX0oooo01l0oooo303AcJT000/0dLfY803oool0102ZZZX0oooo0:ZZZP00
00020?ooo`80000000<0oooo0:ZZZP3oool07`3oool:0=7=ZB00oooo00D0ZZZZ0?ooo`2ZZZX0ZZZZ
000000020:ZZZP030000003oool0ZZZZ0200oooo2P3AcJTP0?ooo`040:ZZZP3oool0EEEE00000080
oooo00@000000:ZZZP3oool0ZZZZ803oool:0=7=ZB00oooo00<0ZZZZ0?ooo`2ZZZX01@2ZZZX00`3o
ool0ZZZZ0?ooo`0O0?ooo`X0dLfY803oool0102ZZZX0oooo0000000000020?ooo`80000000<0oooo
0:ZZZP3oool07`3oool<0=7=Z@002`3AcJTQ0?ooo`80ZZZZ00@0EEEE0?ooo`3oool0EEEE0P2ZZZXQ
0?ooo`X0dLfY8@3oool20:ZZZP0405EEE@2ZZZX0ZZZZ05EEE@80ZZZZ8@3oool:0=7=ZB40oooo00<0
ZZZZ0000003oool00`3oool20:ZZZR40oooo2P3AcJTQ0?ooo`040:ZZZP000000ZZZZ000000@0ZZZZ
8@3oool:0=7=ZB40oooo0`2ZZZX00`3oool0ZZZZ0:ZZZP020:ZZZR40oooo303AcJT000/0dLfY8P3o
ool20:ZZZP030000002ZZZX0ZZZZ02<0oooo2P3AcJTR0?ooo`80ZZZZ00<000000:ZZZP2ZZZX08`3o
ool:0=7=ZB80oooo0P2ZZZX00`000000EEEE0:ZZZP0S0?ooo`X0dLfY8P3oool20:ZZZP030000001E
EED0ZZZZ02<0oooo2P3AcJTR0?ooo`80ZZZZ0P0000000`2ZZZX0oooo0?ooo`0Q0?ooo``0dLfY000;
0=7=ZB<0oooo00@0ZZZZ0000003oool0ZZZZ8`3oool:0=7=ZB<0oooo00@0ZZZZ0000003oool0ZZZZ
8`3oool:0=7=ZB<0oooo00@0ZZZZ0000003oool0ZZZZ8`3oool:0=7=ZB<0oooo00@0ZZZZ0000003o
ool0ZZZZ8`3oool:0=7=ZB<0oooo00@0ZZZZ0000003oool0ZZZZ8`3oool<0=7=Z@002`3AcJTT0?oo
o`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?oo
o`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?ooo`030:ZZZP3oool0oooo02<0oooo2P3AcJTT0?oo
o`030:ZZZP3oool0oooo02<0oooo303AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT00?l0dLfY/P3A
cJT00?l0dLfY/P3AcJT00?l0dLfY/P3AcJT000/0dLfY00H0oooo0:ZZZP2ZZZX0oooo0:ZZZP3oool3
0:ZZZP030000002ZZZX0oooo00<0oooo00@0ZZZZ0?ooo`3oool0ZZZZ0P3oool06P2ZZZX0oooo05EE
E@2ZZZX0oooo0000002ZZZX0EEEE0?ooo`2ZZZX0oooo05EEE@3oool0000005EEE@2ZZZX0oooo05EE
E@2ZZZX0oooo05EEE@000000ZZZZ0?ooo`000000ZZZZ0P3oool01`2ZZZX0EEEE0?ooo`2ZZZX0EEEE
0?ooo`2ZZZX00P3oool00`2ZZZX0oooo0?ooo`020?ooo`040:ZZZP1EEED0ZZZZ0:ZZZP80oooo00D0
EEEE0?ooo`2ZZZX0ZZZZ0?ooo`0:0=7=Z@090?ooo`2ZZZX0EEEE05EEE@2ZZZX000000:ZZZP1EEED0
ZZZZ00800000101EEED02@000000EEEE05EEE@000000EEEE0?ooo`1EEED0000005EEE@020:ZZZP<0
EEEE0P0000000`2ZZZX0oooo0?ooo`0305EEE@030000001EEED0EEEE0080oooo0`00000305EEE@80
ZZZZ00<0EEEE0000001EEED00P1EEED00`000000EEEE05EEE@0305EEE@050000001EEED000000000
002ZZZX00P1EEED01P000000ZZZZ05EEE@1EEED0ZZZZ0?ooo`X0dLfY00<0oooo0:ZZZP2ZZZX00P3o
ool00`1EEED0ZZZZ0:ZZZP020:ZZZP8000000P2ZZZX20?ooo`030:ZZZP1EEED0ZZZZ00800000102Z
ZZX0101EEED000000:ZZZP1EEED30:ZZZP030?ooo`1EEED0oooo00D0oooo00<0EEEE0?ooo`3oool0
102ZZZX00`3oool0EEEE0:ZZZP030:ZZZP0305EEE@000000ZZZZ0080ZZZZ00@0EEEE0?ooo`2ZZZX0
ZZZZ0P0000040:ZZZP0305EEE@2ZZZX0oooo0080ZZZZ00<0oooo0=7=Z@3AcJT0203AcJT0103oool0
ZZZZ0000001EEED20?ooo`8000000`1EEED02P2ZZZX0EEEE0000002ZZZX0oooo0000001EEED0oooo
0:ZZZP00000205EEE@030:ZZZP1EEED0EEEE0080EEEE00H0ZZZZ0?ooo`1EEED0oooo0:ZZZP3oool2
05EEE@80oooo0P1EEED0103oool0ZZZZ0?ooo`1EEED20?ooo`@0EEEE00P0ZZZZ05EEE@1EEED0oooo
0:ZZZP3oool0EEEE00000080ZZZZ00L000000?ooo`2ZZZX0EEEE0:ZZZP1EEED000000080oooo0P1E
EED00`000000ZZZZ0?ooo`0:0=7=Z@040?ooo`2ZZZX0ZZZZ0?ooo`8000000P2ZZZX30?ooo`0505EE
E@000000oooo0:ZZZP1EEED00P3oool01@1EEED0ZZZZ0:ZZZP000000oooo0080ZZZZ00H0oooo0:ZZ
ZP2ZZZX0EEEE0000003oool30:ZZZP060000001EEED0oooo0?ooo`1EEED0oooo0P2ZZZX20?ooo`06
0000001EEED0ZZZZ0:ZZZP3oool0ZZZZ0P3oool00`000000ZZZZ0:ZZZP0205EEE@80oooo00@0ZZZZ
0?ooo`1EEED0EEEE0`3oool01@2ZZZX000000000002ZZZX0oooo0080ZZZZ00<0oooo0=7=Z@3AcJT0
2P3AcJT000/0dLfY00@0oooo0:ZZZP3oool0oooo0`2ZZZX20?ooo`80EEEE103oool0101EEED0oooo
0?ooo`3oool20:ZZZP80oooo00T0ZZZZ0?ooo`000000oooo05EEE@2ZZZX0oooo0:ZZZP0000000P3o
ool01P1EEED0ZZZZ0:ZZZP3oool0ZZZZ05EEE@80oooo00<000000:ZZZP3oool00P1EEED200000004
0?ooo`1EEED0oooo0?ooo`80ZZZZ0`3oool00`1EEED0oooo0?ooo`020?ooo`0305EEE@2ZZZX0oooo
0080oooo00<0ZZZZ05EEE@3oool00`3oool:0=7=Z@080?ooo`2ZZZX0oooo05EEE@000000EEEE0:ZZ
ZP3oool4000000040:ZZZP1EEED0oooo05EEE@80ZZZZ0`1EEED00`3oool0EEEE05EEE@0205EEE@03
0?ooo`1EEED0ZZZZ00<0EEEE0P0000001P1EEED000000?ooo`1EEED0000005EEE@80000000@0ZZZZ
05EEE@1EEED0ZZZZ101EEED010000000EEEE0?ooo`3oool205EEE@80ZZZZ00@0EEEE0?ooo`1EEED0
ZZZZ100000020?ooo`0305EEE@2ZZZX0EEEE00<0oooo2P3AcJT0103oool0ZZZZ0?ooo`3oool20:ZZ
ZP8000000P2ZZZX010000000oooo0?ooo`3oool20:ZZZP080?ooo`2ZZZX0EEEE05EEE@2ZZZX00000
0:ZZZP0000020:ZZZP040?ooo`000000oooo0:ZZZP80oooo0P2ZZZX00`3oool0ZZZZ0?ooo`050:ZZ
ZP80oooo00<0ZZZZ05EEE@0000001@2ZZZX010000000oooo05EEE@1EEED20?ooo`80ZZZZ00<0oooo
0:ZZZP3oool00P000000102ZZZX000000:ZZZP2ZZZX50?ooo`X0dLfY00@0oooo0:ZZZP3oool00000
0P3oool205EEE@80oooo00<0EEEE0000003oool00`1EEED20:ZZZP080000001EEED0ZZZZ0?ooo`1E
EED0000005EEE@3oool205EEE@8000000`3oool30:ZZZP030?ooo`2ZZZX0ZZZZ0080ZZZZ00l0oooo
05EEE@3oool000000:ZZZP1EEED0ZZZZ0?ooo`1EEED0000005EEE@3oool0000005EEE@0000000P2Z
ZZX00`000000EEEE05EEE@020000000405EEE@2ZZZX0oooo05EEE@80oooo00<0EEEE0000003oool0
0P3oool:0=7=Z@070?ooo`2ZZZX0oooo0?ooo`2ZZZX0EEEE0:ZZZP030?ooo`80EEEE0`3oool0102Z
ZZX0000005EEE@3oool2000000<0oooo00@0ZZZZ0?ooo`00000000000`2ZZZX3000000030:ZZZP1E
EED0oooo0080EEEE00@0oooo000000000000oooo0P2ZZZX3000000030?ooo`2ZZZX0oooo0080oooo
0P0000020?ooo`050000002ZZZX0oooo0?ooo`0000000P1EEED40?ooo`0305EEE@3oool0oooo00<0
oooo303AcJT000/0dLfY0`3oool20:ZZZP0505EEE@3oool0oooo0:ZZZP1EEED0103oool00`1EEED0
ZZZZ0?ooo`030?ooo`030:ZZZP3oool0oooo00<0ZZZZ00T0000005EEE@3oool0oooo0:ZZZP1EEED0
ZZZZ05EEE@3oool00P2ZZZX01`3oool0ZZZZ0:ZZZP1EEED0ZZZZ0?ooo`2ZZZX00P3oool00`1EEED0
ZZZZ0:ZZZP020:ZZZP80oooo00@0ZZZZ0?ooo`3oool0ZZZZ0P3oool00`1EEED0oooo0?ooo`020?oo
o`070000002ZZZX0oooo0?ooo`1EEED0oooo0:ZZZP030?ooo`X0dLfY0`3oool01P2ZZZX0EEEE0000
001EEED000000:ZZZP<0EEEE0`0000030:ZZZP0505EEE@2ZZZX0ZZZZ05EEE@2ZZZX00P3oool01000
0000ZZZZ05EEE@0000020:ZZZP@0EEEE00<000000?ooo`1EEED00P00000205EEE@030000002ZZZX0
ZZZZ0080EEEE00D0ZZZZ0000003oool0EEEE0:ZZZP0205EEE@030:ZZZP1EEED0ZZZZ0080ZZZZ0P00
00001@2ZZZX0EEEE05EEE@1EEED0ZZZZ00<0000000<0oooo0:ZZZP3oool00P3oool:0=7=Z@<0oooo
0P2ZZZX00`3oool0ZZZZ000000030?ooo`<0ZZZZ0P3oool00`2ZZZX0oooo0:ZZZP030?ooo`@0ZZZZ
00<0EEEE0?ooo`1EEED00P3oool01@1EEED0oooo0?ooo`2ZZZX0oooo0080EEEE00<0oooo0:ZZZP3o
ool0103oool00`000000oooo0:ZZZP020:ZZZP050000002ZZZX0oooo05EEE@3oool0102ZZZX02@3o
ool0ZZZZ0?ooo`2ZZZX0oooo0000003oool000000:ZZZP020?ooo`040:ZZZP3oool0oooo0?ooo`X0
dLfY0`3oool00`2ZZZX0EEEE0?ooo`0200000080EEEE0P0000000`2ZZZX0oooo05EEE@0305EEE@03
0:ZZZP1EEED000000080000000H0oooo000000000000000005EEE@3oool205EEE@<0oooo0P2ZZZX2
0?ooo`030:ZZZP3oool0oooo0080oooo101EEED30000000:0?ooo`00000000000000001EEED0ZZZZ
0?ooo`1EEED0000005EEE@80oooo0P0000000`3oool0EEEE000000030?ooo`040:ZZZP3oool0oooo
0?ooo`X0dLfY0`3oool0202ZZZX000000?ooo`2ZZZX000000?ooo`1EEED000001@3oool0102ZZZX0
00000000003oool2000000<0oooo00H0EEEE0?ooo`2ZZZX0oooo05EEE@2ZZZX30000000505EEE@3o
ool000000:ZZZP3oool00`0000000`1EEED0ZZZZ05EEE@020:ZZZP80EEEE00<0oooo0:ZZZP3oool0
0P000000103oool000000:ZZZP2ZZZX50?ooo`040000001EEED0oooo000000<0oooo00@0ZZZZ0?oo
o`3oool0oooo303AcJT000/0dLfY103oool01@2ZZZX0EEEE0?ooo`3oool0EEEE00D0000000<0oooo
05EEE@1EEED00`3oool0102ZZZX0oooo0:ZZZP1EEED30:ZZZP0405EEE@3oool0oooo0?ooo`80ZZZZ
0P1EEED20?ooo`0405EEE@3oool0oooo05EEE@80ZZZZ0`3oool205EEE@@0ZZZZ103oool205EEE@80
oooo00@000000?ooo`00000000000P1EEED20?ooo`0305EEE@2ZZZX0oooo00<0oooo2P3AcJT40?oo
o`070:ZZZP1EEED0ZZZZ0:ZZZP000000EEEE0000000205EEE@030:ZZZP1EEED0EEEE00<0EEEE0P00
000205EEE@80oooo00D0EEEE0:ZZZP1EEED0ZZZZ0000000205EEE@80ZZZZ00H0EEEE0000003oool0
oooo0000001EEED30:ZZZP0705EEE@000000ZZZZ05EEE@000000EEEE0?ooo`0305EEE@030:ZZZP00
0000EEEE00@0EEEE00L0ZZZZ05EEE@1EEED0000005EEE@000000ZZZZ0080EEEE00<0ZZZZ0?ooo`3o
ool00P3oool:0=7=Z@@0oooo00<0ZZZZ0000000000000P0000020:ZZZP80oooo00@0ZZZZ0?ooo`3o
ool0ZZZZ0P3oool20:ZZZP070?ooo`2ZZZX0000005EEE@000000EEEE0:ZZZP040?ooo`80ZZZZ00<0
oooo0:ZZZP2ZZZX00P2ZZZX0103oool0ZZZZ0:ZZZP1EEED20?ooo`080000002ZZZX0oooo0000001E
EED0oooo0:ZZZP3oool20:ZZZP80oooo0P2ZZZX01P3oool0ZZZZ0?ooo`3oool0ZZZZ0?ooo`800000
00<0EEEE0000002ZZZX0103oool:0=7=Z@@0oooo00@0ZZZZ0000002ZZZX0ZZZZ0P1EEED20:ZZZP04
0000001EEED0ZZZZ00000080oooo00@0ZZZZ0?ooo`1EEED0oooo0`1EEED01@3oool0EEEE0?ooo`1E
EED0ZZZZ00D0EEEE00@000000?ooo`00000000001@1EEED01@2ZZZX000000?ooo`1EEED0oooo00<0
EEEE00D0oooo05EEE@3oool0ZZZZ05EEE@020?ooo`030:ZZZP1EEED0EEEE0080ZZZZ0P1EEED0102Z
ZZX0EEEE0000002ZZZX40?ooo`X0dLfY103oool30:ZZZP040?ooo`1EEED0ZZZZ05EEE@L0oooo00<0
EEEE0:ZZZP2ZZZX00P2ZZZX0203oool0EEEE05EEE@3oool0ZZZZ0?ooo`1EEED00000102ZZZX20000
00030?ooo`000000ZZZZ00<0ZZZZ00D0000005EEE@3oool0ZZZZ0000000205EEE@030?ooo`2ZZZX0
ZZZZ0080ZZZZ00<0EEEE0:ZZZP3oool01@3oool305EEE@80oooo0P2ZZZX40?ooo``0dLfY000;0=7=
Z@@0oooo00<0ZZZZ0?ooo`3oool00`3oool0201EEED000000000001EEED0oooo05EEE@2ZZZX0EEEE
0`3oool30:ZZZP80oooo00@0EEEE0:ZZZP2ZZZX0ZZZZ0`3oool00`2ZZZX00000000000020?ooo`08
0000001EEED0ZZZZ0?ooo`2ZZZX0oooo0:ZZZP3oool20:ZZZP80oooo00<0EEEE0:ZZZP2ZZZX0103o
ool0202ZZZX0oooo0?ooo`1EEED0oooo0000001EEED000000P3oool00`1EEED0oooo0?ooo`040?oo
o`X0dLfY103oool01P2ZZZX0oooo0:ZZZP000000EEEE0:ZZZPH0EEEE0`2ZZZX205EEE@80ZZZZ0P3o
ool205EEE@040000002ZZZX000000:ZZZP<0EEEE00@0000005EEE@3oool0oooo101EEED02@000000
ZZZZ0000001EEED000000:ZZZP1EEED0oooo05EEE@020:ZZZP80EEEE0`2ZZZX0103oool0EEEE05EE
E@00000205EEE@040?ooo`1EEED0000005EEE@H0oooo2P3AcJT40?ooo`040:ZZZP3oool0oooo0:ZZ
ZP8000000100EEEE0?ooo`3oool0oooo0:ZZZP000000EEEE0:ZZZP1EEED0000005EEE@000000ZZZZ
0?ooo`000000oooo0P2ZZZX00`3oool00000000000020?ooo`@0ZZZZ00@000000:ZZZP3oool0ZZZZ
0P3oool300000080ZZZZ00@0oooo0000002ZZZX0ZZZZ0`0000000`1EEED0000005EEE@020:ZZZP<0
oooo00D0EEEE0?ooo`000000ZZZZ000000060?ooo`X0dLfY103oool0302ZZZX0oooo05EEE@000000
EEEE0000001EEED000000?ooo`1EEED000000?ooo`80ZZZZ0P3oool01@000000oooo0000003oool0
000000<0EEEE00@0oooo0:ZZZP3oool000000P3oool01P1EEED0oooo05EEE@1EEED0oooo00000080
oooo00<0EEEE0?ooo`2ZZZX00P1EEED01@2ZZZX0EEEE0000003oool0000000@0oooo0P2ZZZX20000
0080EEEE00@0000005EEE@3oool0EEEE0P0000060?ooo`X0dLfY103oool00`2ZZZX0oooo0?ooo`02
0:ZZZP070000001EEED0EEEE05EEE@3oool0EEEE0?ooo`0205EEE@030?ooo`000000000000800000
00L0ZZZZ0000002ZZZX0ZZZZ0?ooo`1EEED0oooo00@0000000D0EEEE0:ZZZP000000oooo0:ZZZP03
000000030?ooo`000000oooo0080oooo0P2ZZZX00`000000oooo00000003000000050?ooo`1EEED0
EEEE0?ooo`1EEED00P3oool205EEE@030000002ZZZX0ZZZZ00L0oooo303AcJT000/0dLfY203oool0
101EEED0oooo0000003oool50:ZZZP80oooo00@0EEEE0?ooo`3oool0oooo102ZZZX20?ooo`<0ZZZZ
0P3oool00`1EEED0000000000002000000@0oooo0P2ZZZX20?ooo`@0ZZZZ0`3oool01@1EEED0oooo
0000002ZZZX0oooo0080ZZZZ00<0EEEE0?ooo`0000000P1EEED00`3oool0ZZZZ0?ooo`050?ooo`X0
dLfY1`3oool0201EEED0000005EEE@000000ZZZZ0000002ZZZX0EEEE1@2ZZZX00`1EEED0000005EE
E@0200000080EEEE00@0ZZZZ05EEE@1EEED000001P1EEED00`2ZZZX0EEEE05EEE@0305EEE@040000
001EEED0EEEE0:ZZZP80EEEE00D0000005EEE@1EEED0000005EEE@040:ZZZP80EEEE0`2ZZZX30000
000305EEE@2ZZZX0oooo00D0oooo2P3AcJT70?ooo`80EEEE00@000000?ooo`3oool0EEEE0P3oool0
1@000000ZZZZ0:ZZZP3oool0ZZZZ0080oooo00@0ZZZZ0000002ZZZX0EEEE0P2ZZZX200000080oooo
0P1EEED20:ZZZP040000001EEED0ZZZZ0:ZZZP80EEEE00<0ZZZZ0?ooo`0000000`2ZZZX01`1EEED0
ZZZZ0000002ZZZX0oooo05EEE@2ZZZX00P3oool00`2ZZZX0EEEE0?ooo`040?ooo`<0EEEE00<0ZZZZ
0?ooo`3oool0103oool:0=7=Z@L0oooo00D0EEEE0?ooo`00000000000?ooo`0300000080ZZZZ00@0
oooo05EEE@1EEED0oooo0P1EEED01@000000EEEE0:ZZZP000000oooo0080EEEE0P3oool010000000
oooo0000002ZZZX2000000090:ZZZP1EEED0oooo0000001EEED0oooo05EEE@000000oooo0080ZZZZ
201EEED02`2ZZZX0EEEE000000000000EEEE0?ooo`000000ZZZZ0?ooo`1EEED0ZZZZ00H0oooo2P3A
cJT70?ooo`080000003oool0oooo05EEE@2ZZZX0EEEE0?ooo`2ZZZX20?ooo`L0EEEE103oool0202Z
ZZX0oooo05EEE@1EEED0oooo0:ZZZP1EEED0oooo0P0000000`3oool0ZZZZ0:ZZZP020?ooo`0505EE
E@3oool0oooo0?ooo`0000000P3oool605EEE@080000003oool0oooo0:ZZZP3oool0EEEE0:ZZZP1E
EED20?ooo`030000002ZZZX0oooo00D0oooo303AcJT000/0dLfY1P3oool20:ZZZP050?ooo`2ZZZX0
00000:ZZZP3oool00P1EEED0103oool0ZZZZ0000000000040?ooo`030:ZZZP3oool0oooo00<0oooo
0P1EEED01P3oool0ZZZZ0:ZZZP2ZZZX0EEEE0:ZZZP80EEEE00@0oooo0:ZZZP2ZZZX0oooo0P1EEED2
0?ooo`030:ZZZP3oool0oooo00D0oooo0P0000000`2ZZZX0oooo05EEE@0205EEE@050:ZZZP000000
EEEE0?ooo`2ZZZX01`3oool:0=7=Z@H0oooo0P2ZZZX01`1EEED0ZZZZ0:ZZZP000000ZZZZ05EEE@00
00001@1EEED010000000EEEE0?ooo`2ZZZX405EEE@030?ooo`1EEED0EEEE00D0ZZZZ00@0000005EE
E@2ZZZX0EEEE0`2ZZZX405EEE@050?ooo`1EEED0EEEE05EEE@3oool01`1EEED01@000000EEEE05EE
E@000000ZZZZ0080EEEE00<0ZZZZ0?ooo`3oool01@3oool:0=7=Z@H0oooo102ZZZX00`1EEED00000
05EEE@020?ooo`80ZZZZ00L0EEEE0000002ZZZX0ZZZZ0?ooo`2ZZZX000000080ZZZZ00L000000:ZZ
ZP2ZZZX0oooo0000002ZZZX0EEEE00<0oooo00H0EEEE0:ZZZP3oool0ZZZZ0?ooo`1EEED200000003
0?ooo`000000ZZZZ00<0ZZZZ00<0oooo0:ZZZP3oool00P2ZZZX2000000070:ZZZP1EEED0oooo0?oo
o`2ZZZX0000005EEE@030:ZZZPL0oooo2P3AcJT60?ooo`80ZZZZ00T0000005EEE@3oool0EEEE0000
002ZZZX0oooo05EEE@0000000P3oool02P000000oooo05EEE@2ZZZX0oooo05EEE@000000ZZZZ0?oo
o`0000020:ZZZP0405EEE@3oool0EEEE0:ZZZP@0000000@0oooo05EEE@3oool0oooo0`2ZZZX00`3o
ool000000000000205EEE@060:ZZZP1EEED0oooo0000003oool0EEEE0P000000203oool0ZZZZ0?oo
o`1EEED0oooo05EEE@000000ZZZZ1`3oool:0=7=Z@H0oooo102ZZZX200000080ZZZZ0`3oool00`2Z
ZZX0EEEE05EEE@0205EEE@040:ZZZP1EEED0ZZZZ0:ZZZP<0oooo0P2ZZZX0103oool0EEEE05EEE@1E
EED40:ZZZP<0EEEE00<000000:ZZZP2ZZZX00P3oool01`1EEED0ZZZZ0:ZZZP1EEED0ZZZZ05EEE@00
00000`1EEED30?ooo`050:ZZZP00000000000000003oool00P2ZZZX70?ooo``0dLfY000;0=7=Z@L0
oooo00`0ZZZZ0?ooo`1EEED0ZZZZ05EEE@3oool0ZZZZ05EEE@3oool0EEEE0000001EEED50?ooo`03
05EEE@3oool0ZZZZ00@0ZZZZ00P0oooo0:ZZZP3oool0oooo0:ZZZP3oool0EEEE0:ZZZP80oooo102Z
ZZX0103oool0ZZZZ0?ooo`3oool205EEE@@0oooo0`1EEED01@3oool0EEEE0:ZZZP2ZZZX0EEEE0080
ZZZZ00<0oooo0:ZZZP3oool01P3oool:0=7=Z@L0oooo00h0ZZZZ0?ooo`2ZZZX0000005EEE@2ZZZX0
oooo0000001EEED0000005EEE@000000EEEE00000080oooo0P1EEED01@3oool0ZZZZ05EEE@2ZZZX0
oooo00@0EEEE00D000000:ZZZP2ZZZX0EEEE0:ZZZP0505EEE@050?ooo`2ZZZX0EEEE0:ZZZP3oool0
0P1EEED20?ooo`80EEEE00D0000005EEE@000000EEEE000000020?ooo`0505EEE@000000EEEE0?oo
o`2ZZZX01`3oool:0=7=Z@L0oooo00L0ZZZZ0?ooo`2ZZZX0oooo05EEE@2ZZZX0oooo0080ZZZZ00H0
00000?ooo`1EEED0EEEE0000002ZZZX205EEE@040?ooo`000000EEEE0?ooo`80ZZZZ00X0oooo0:ZZ
ZP2ZZZX0ZZZZ0?ooo`1EEED000000?ooo`1EEED0oooo0P2ZZZX020000000oooo0:ZZZP000000oooo
05EEE@000000oooo0P1EEED01P2ZZZX0000005EEE@1EEED0ZZZZ00000080ZZZZ00<0oooo05EEE@1E
EED00`3oool00`2ZZZX0oooo0?ooo`050?ooo`X0dLfY1`3oool00`2ZZZX0oooo05EEE@020?ooo`80
000000<0EEEE0:ZZZP2ZZZX00`1EEED00`3oool0EEEE000000020?ooo`040000003oool0oooo0:ZZ
ZP8000000`1EEED5000000040:ZZZP1EEED0EEEE0:ZZZP8000000P3oool01`2ZZZX000000?ooo`1E
EED0000005EEE@3oool00`1EEED20:ZZZP0305EEE@00000000000080oooo00<000000?ooo`2ZZZX0
1`3oool:0=7=Z@L0oooo00H0ZZZZ0?ooo`3oool0ZZZZ05EEE@2ZZZX30?ooo`0305EEE@0000000000
0080ZZZZ0P000000101EEED000000000001EEED30?ooo`050:ZZZP1EEED0EEEE0:ZZZP1EEED01000
00001@1EEED0ZZZZ05EEE@3oool0ZZZZ00@0oooo0P0000000`3oool00000000000020:ZZZP030000
001EEED0EEEE00@0oooo00D0EEEE0:ZZZP3oool0oooo0:ZZZP070?ooo``0dLfY000;0=7=Z@X0oooo
00<0EEEE0?ooo`3oool00P000000101EEED000000000003oool400000080ZZZZ00H0EEEE0000003o
ool000000?ooo`2ZZZX20?ooo`090:ZZZP1EEED0oooo0?ooo`2ZZZX0oooo05EEE@2ZZZX0oooo0080
ZZZZ00L0oooo0000003oool0ZZZZ05EEE@2ZZZX0EEEE00@0000000@0oooo05EEE@000000oooo0P00
0000102ZZZX0oooo05EEE@2ZZZX90?ooo`X0dLfY2P3oool01`1EEED0000005EEE@000000ZZZZ05EE
E@2ZZZX00`1EEED00`3oool0000005EEE@0205EEE@040:ZZZP000000EEEE05EEE@80ZZZZ0P3oool3
05EEE@80ZZZZ0`1EEED0103oool000000:ZZZP2ZZZX205EEE@80ZZZZ00D0EEEE0?ooo`1EEED00000
0?ooo`0205EEE@040000002ZZZX0EEEE0:ZZZP<0000000<0EEEE0:ZZZP3oool0203oool:0=7=Z@X0
oooo0P2ZZZX01`000000EEEE0:ZZZP000000ZZZZ0?ooo`2ZZZX00P1EEED00`3oool0000000000002
05EEE@80oooo00@000000?ooo`2ZZZX0EEEE0P3oool200000080oooo00H0000005EEE@3oool0oooo
0000002ZZZX30?ooo`@0EEEE00@000000?ooo`1EEED0EEEE0`2ZZZX00`3oool0ZZZZ05EEE@040:ZZ
ZPT0oooo2P3AcJT:0?ooo`0605EEE@3oool000000?ooo`000000ZZZZ0P1EEED01@3oool0ZZZZ05EE
E@1EEED0000000@0oooo00X0ZZZZ05EEE@1EEED0oooo05EEE@000000EEEE0?ooo`1EEED0oooo101E
EED01`000000EEEE0?ooo`1EEED0oooo0:ZZZP0000000P3oool01@1EEED0000005EEE@3oool0ZZZZ
0080oooo00<0EEEE0?ooo`0000000`3oool00`1EEED0ZZZZ0?ooo`080?ooo`X0dLfY2P3oool01`00
0000oooo0:ZZZP000000oooo05EEE@0000001P3oool30000000605EEE@3oool0ZZZZ0:ZZZP3oool0
00000`3oool500000080oooo00D000000?ooo`2ZZZX000000?ooo`03000000<0oooo00P000000?oo
o`3oool0oooo0000001EEED0oooo00000080oooo00<000000:ZZZP3oool0203oool<0=7=Z@002`3A
cJT90?ooo`<0ZZZZ0P0000001`2ZZZX0oooo05EEE@000000ZZZZ05EEE@2ZZZX00P1EEED20?ooo`80
ZZZZ0P1EEED20?ooo`030000001EEED0ZZZZ0080ZZZZ0P3oool30:ZZZP0505EEE@2ZZZX0oooo0?oo
o`0000000P1EEED00`2ZZZX0oooo0:ZZZP0405EEE@030:ZZZP000000EEEE0080ZZZZ00@000000?oo
o`2ZZZX0ZZZZ2P3oool:0=7=Z@T0oooo0P2ZZZX01P1EEED0ZZZZ0:ZZZP000000EEEE00000080ZZZZ
00<0EEEE0?ooo`1EEED00P00000305EEE@040:ZZZP1EEED0ZZZZ00000080oooo00<0EEEE0000001E
EED01@1EEED00`3oool0EEEE000000030:ZZZP@0EEEE00@0000005EEE@3oool0EEEE0P2ZZZX01000
0000EEEE0000002ZZZX205EEE@030:ZZZP3oool0oooo00P0oooo2P3AcJT90?ooo`80ZZZZ00@00000
0:ZZZP1EEED0oooo0`0000040:ZZZP80oooo00<0ZZZZ05EEE@2ZZZX00P2ZZZX00`000000EEEE0?oo
o`020:ZZZP80EEEE0P3oool0101EEED0oooo0:ZZZP2ZZZX205EEE@080000003oool0ZZZZ0?ooo`1E
EED0ZZZZ0000003oool40:ZZZP0805EEE@00000000000?ooo`1EEED0ZZZZ0000002ZZZX:0?ooo`X0
dLfY2@3oool20:ZZZP070000002ZZZX0ZZZZ0?ooo`000000EEEE0?ooo`020000000;0:ZZZP1EEED0
oooo0:ZZZP000000EEEE0:ZZZP3oool0EEEE0:ZZZP3oool00P1EEED20?ooo`030000003oool0oooo
0080000000D0oooo05EEE@2ZZZX0oooo0:ZZZP020?ooo`050:ZZZP1EEED0000005EEE@3oool00P1E
EED2000000080?ooo`1EEED000000?ooo`2ZZZX0EEEE0000002ZZZX:0?ooo`X0dLfY2@3oool40:ZZ
ZP040?ooo`1EEED0ZZZZ05EEE@<0oooo00<000000:ZZZP3oool0102ZZZX00`000000oooo0:ZZZP04
0?ooo`D0ZZZZ00P0EEEE0?ooo`3oool000000?ooo`2ZZZX0oooo000000@0ZZZZ00<0oooo0:ZZZP3o
ool00`3oool305EEE@80oooo0P2ZZZX:0?ooo``0dLfY000;0=7=Z@/0oooo00L0ZZZZ0?ooo`1EEED0
00000?ooo`2ZZZX0EEEE00D0ZZZZ00<0oooo05EEE@1EEED00P2ZZZX01P1EEED0oooo0?ooo`000000
oooo0:ZZZPD0oooo0P2ZZZX40?ooo`80ZZZZ00@0oooo05EEE@1EEED0oooo0P2ZZZX0101EEED0ZZZZ
0:ZZZP3oool20:ZZZP040000001EEED0ZZZZ0:ZZZP/0oooo2P3AcJT;0?ooo`030:ZZZP1EEED00000
0080oooo00<0ZZZZ0000002ZZZX00`3oool505EEE@060000002ZZZX0ZZZZ05EEE@000000EEEE0P00
000405EEE@050:ZZZP000000EEEE0:ZZZP1EEED00P2ZZZX030000000EEEE05EEE@1EEED0000005EE
E@3oool0EEEE0?ooo`2ZZZX000000:ZZZP80oooo00<000000:ZZZP2ZZZX02`3oool:0=7=Z@/0oooo
00<0ZZZZ05EEE@3oool00P3oool205EEE@070?ooo`2ZZZX0ZZZZ0?ooo`000000EEEE000000050:ZZ
ZP030000002ZZZX0ZZZZ00@0oooo00D0ZZZZ0?ooo`2ZZZX0oooo0:ZZZP02000000<0ZZZZ00`0EEEE
0:ZZZP000000oooo0000003oool0EEEE0:ZZZP3oool0000005EEE@2ZZZX20?ooo`80ZZZZ2`3oool:
0=7=Z@/0oooo00T0ZZZZ05EEE@3oool0EEEE0000001EEED0oooo05EEE@2ZZZX00P0000020?ooo`80
ZZZZ00D0oooo05EEE@1EEED0oooo0000000305EEE@040:ZZZP1EEED0oooo0?ooo`@0EEEE00<0oooo
0000003oool00`1EEED20:ZZZP80oooo00T0000005EEE@2ZZZX0EEEE0?ooo`1EEED0000005EEE@3o
ool00P2ZZZX;0?ooo`X0dLfY2`3oool02P2ZZZX0oooo000000000000oooo0000001EEED0oooo0000
002ZZZX20?ooo`030000003oool0oooo00P0oooo00<0EEEE0?ooo`0000000P3oool0102ZZZX0oooo
0?ooo`2ZZZX40?ooo`030000003oool0oooo00<0oooo00H0ZZZZ0000003oool0EEEE0000003oool2
00000080ZZZZ2`3oool<0=7=Z@002`3AcJT=0?ooo`040:ZZZP1EEED0oooo0?ooo`80ZZZZ00<0EEEE
0?ooo`000000102ZZZX30?ooo`0505EEE@3oool0EEEE0000002ZZZX01P3oool01`2ZZZX000000?oo
o`3oool0EEEE0:ZZZP3oool00`2ZZZX01@3oool0ZZZZ0000002ZZZX0EEEE0080ZZZZ00<0oooo05EE
E@1EEED00P2ZZZX<0?ooo`X0dLfY3@3oool01P1EEED0000005EEE@000000ZZZZ00000080EEEE0P00
00020:ZZZP0305EEE@2ZZZX0EEEE00<0EEEE0P2ZZZX205EEE@@0ZZZZ0P1EEED00`2ZZZX0000005EE
E@0305EEE@040:ZZZP1EEED0ZZZZ0:ZZZP<0000000<0EEEE0000002ZZZX00`0000000`1EEED0ZZZZ
0?ooo`0;0?ooo`X0dLfY3@3oool01@1EEED0oooo0:ZZZP2ZZZX0EEEE0080oooo0`1EEED0103oool0
00000:ZZZP2ZZZX3000000040:ZZZP000000EEEE0?ooo`80ZZZZ0P3oool02@2ZZZX0oooo0?ooo`1E
EED0oooo0:ZZZP000000ZZZZ000000020:ZZZP050000003oool0EEEE05EEE@2ZZZX00P3oool20:ZZ
ZP80oooo00<0EEEE0:ZZZP3oool02`3oool:0=7=Z@d0oooo00L0EEEE0?ooo`000000oooo05EEE@3o
ool0ZZZZ0080EEEE0`3oool00`2ZZZX0EEEE0?ooo`0305EEE@050?ooo`000000oooo0000001EEED0
0P3oool205EEE@030?ooo`000000oooo0080EEEE00@0ZZZZ0?ooo`3oool0ZZZZ0`3oool00`1EEED0
oooo0:ZZZP030?ooo`040:ZZZP3oool0EEEE0:ZZZP`0oooo2P3AcJT=0?ooo`030000003oool0oooo
00<0EEEE103oool00`1EEED0ZZZZ0:ZZZP050?ooo`80ZZZZ00T0oooo0000002ZZZX000000?ooo`2Z
ZZX000000?ooo`2ZZZX01@3oool00`1EEED0ZZZZ0:ZZZP030?ooo`050:ZZZP3oool0EEEE0:ZZZP1E
EED00P3oool00`000000ZZZZ0?ooo`0;0?ooo``0dLfY000;0=7=Z@`0oooo0P2ZZZX01P1EEED0ZZZZ
0:ZZZP000000ZZZZ0?ooo`80EEEE00@0ZZZZ0?ooo`3oool0ZZZZ0P3oool40:ZZZP80EEEE1P3oool2
05EEE@030?ooo`2ZZZX0ZZZZ00<0oooo00@0ZZZZ0?ooo`2ZZZX0ZZZZ0P1EEED01`3oool0ZZZZ0?oo
o`2ZZZX0oooo05EEE@2ZZZX03@3oool:0=7=Z@`0oooo0P2ZZZX01@1EEED0ZZZZ0:ZZZP1EEED0ZZZZ
0080EEEE00<0ZZZZ05EEE@1EEED00P1EEED00`2ZZZX0EEEE0:ZZZP020:ZZZPP0EEEE00@0000005EE
E@1EEED0EEEE0`2ZZZX00`1EEED0000005EEE@0305EEE@80ZZZZ00@0EEEE0:ZZZP000000ZZZZ0P1E
EED00`2ZZZX0oooo0?ooo`0;0?ooo`X0dLfY303oool40:ZZZP040?ooo`2ZZZX0EEEE000000<0ZZZZ
00<0oooo0:ZZZP0000000P0000000`2ZZZX0oooo000000040:ZZZPD0oooo0P2ZZZX00`1EEED00000
0?ooo`02000000030:ZZZP000000ZZZZ00@0ZZZZ00<0000005EEE@3oool00P3oool20:ZZZPd0oooo
2P3AcJT<0?ooo`80ZZZZ00@0000005EEE@3oool0oooo0P0000000`2ZZZX0EEEE0?ooo`030?ooo`80
ZZZZ00@0oooo0000003oool0oooo0P1EEED20:ZZZP030?ooo`2ZZZX0ZZZZ00<0EEEE0P3oool01000
0000oooo0:ZZZP2ZZZX40?ooo`80EEEE0P0000020?ooo`0305EEE@000000ZZZZ00d0oooo2P3AcJT<
0?ooo`@0ZZZZ0P0000020:ZZZP<0oooo00@0EEEE000000000000EEEE1@3oool0102ZZZX0oooo0?oo
o`3oool20:ZZZP040?ooo`000000oooo0:ZZZPD0oooo00@0EEEE000000000000EEEE0`3oool20:ZZ
ZP80000000<0oooo0:ZZZP2ZZZX03@3oool<0=7=Z@002`3AcJT>0?ooo`80ZZZZ00@0oooo0:ZZZP3o
ool0oooo0P2ZZZX00`1EEED0ZZZZ0?ooo`020?ooo`0605EEE@2ZZZX0ZZZZ0:ZZZP3oool0ZZZZ0`3o
ool01@1EEED0oooo0?ooo`1EEED0oooo00@0ZZZZ00<0oooo05EEE@3oool00P3oool010000000EEEE
0:ZZZP2ZZZX20?ooo`0405EEE@3oool0ZZZZ0:ZZZPh0oooo2P3AcJT>0?ooo`030:ZZZP1EEED00000
0080oooo00L0ZZZZ0000002ZZZX0EEEE0?ooo`2ZZZX0EEEE00D0ZZZZ0P3oool00`2ZZZX0EEEE05EE
E@0305EEE@040000002ZZZX0oooo05EEE@@0ZZZZ00D0000005EEE@2ZZZX0oooo05EEE@030:ZZZP80
oooo00<000000:ZZZP2ZZZX03P3oool:0=7=Z@h0oooo00<0ZZZZ0?ooo`2ZZZX00P3oool00`1EEED0
ZZZZ05EEE@020:ZZZP0305EEE@3oool0ZZZZ0080EEEE00L0oooo0:ZZZP3oool0ZZZZ0000002ZZZX0
oooo0080ZZZZ00L0oooo0:ZZZP000000ZZZZ0?ooo`2ZZZX0oooo0080EEEE00D0ZZZZ0?ooo`1EEED0
EEEE0:ZZZP0305EEE@80oooo0`2ZZZX>0?ooo`X0dLfY3P3oool01P2ZZZX0EEEE0?ooo`1EEED0oooo
0:ZZZP8000001@3oool01@2ZZZX0oooo05EEE@3oool000000080oooo0P1EEED010000000oooo05EE
E@2ZZZX20?ooo`030000003oool0EEEE0080ZZZZ1@3oool00`000000EEEE0:ZZZP030?ooo`80ZZZZ
3P3oool:0=7=Z@h0oooo00@0ZZZZ0?ooo`000000ZZZZ0`3oool205EEE@<0oooo00<0000005EEE@3o
ool01`3oool010000000oooo0?ooo`2ZZZX50?ooo`80EEEE0`3oool010000000EEEE05EEE@1EEED2
0?ooo`8000000P2ZZZX>0?ooo``0dLfY000;0=7=ZA40oooo0P2ZZZX30?ooo`030:ZZZP1EEED0oooo
0080oooo00@0EEEE0000003oool0ZZZZ0P3oool20:ZZZP040?ooo`2ZZZX0ZZZZ0?ooo`80ZZZZ0P3o
ool0102ZZZX0oooo0:ZZZP1EEED30?ooo`0905EEE@2ZZZX0oooo0:ZZZP3oool0ZZZZ05EEE@3oool0
ZZZZ00l0oooo2P3AcJT@0?ooo`0405EEE@000000EEEE000000<0EEEE0P3oool00`2ZZZX0EEEE05EE
E@0305EEE@8000000P1EEED50:ZZZP0305EEE@000000EEEE00D0EEEE00<0ZZZZ0?ooo`3oool00P1E
EED01P2ZZZX0000005EEE@000000EEEE0:ZZZPl0oooo2P3AcJT@0?ooo`<0ZZZZ00<0oooo0:ZZZP1E
EED00P3oool00`1EEED0ZZZZ0:ZZZP030:ZZZP<0oooo0P2ZZZX20000000405EEE@00000000000:ZZ
ZP<0oooo0`2ZZZX01@000000ZZZZ05EEE@000000oooo0080EEEE00<0oooo0:ZZZP3oool00P2ZZZX?
0?ooo`X0dLfY403oool01@1EEED0oooo000000000000oooo00L0EEEE00<000000?ooo`1EEED00`1E
EED01@000000oooo0?ooo`1EEED0oooo00<0EEEE00@0oooo05EEE@3oool00000201EEED200000003
0?ooo`1EEED0ZZZZ00l0oooo2P3AcJT@0?ooo`040000003oool0ZZZZ00000080EEEE00<000000?oo
o`3oool00P3oool00`000000EEEE0?ooo`040?ooo`80ZZZZ00<000000?ooo`2ZZZX01P3oool00`1E
EED000000?ooo`030?ooo`080000001EEED0oooo0000002ZZZX0oooo0000002ZZZX?0?ooo``0dLfY
000;0=7=Z@l0oooo0P2ZZZX205EEE@030?ooo`2ZZZX0ZZZZ00H0oooo0P2ZZZX60?ooo`040:ZZZP3o
ool0oooo0:ZZZP@0oooo00@0ZZZZ0000003oool0EEEE0P3oool00`000000oooo0:ZZZP020?ooo`03
05EEE@3oool0ZZZZ0100oooo2P3AcJT?0?ooo`80ZZZZ00<0EEEE0:ZZZP2ZZZX00P1EEED300000003
05EEE@2ZZZX0ZZZZ0080ZZZZ00@0EEEE0:ZZZP000000ZZZZ1@1EEED01@000000ZZZZ0000002ZZZX0
EEEE00@0ZZZZ00H0EEEE0000001EEED0000005EEE@0000020:ZZZP0305EEE@2ZZZX0oooo00l0oooo
2P3AcJT?0?ooo`80ZZZZ00<0EEEE0000001EEED00P3oool200000080oooo0`0000001@3oool0EEEE
0?ooo`1EEED0oooo0080ZZZZ00`0oooo05EEE@2ZZZX000000?ooo`1EEED0oooo05EEE@3oool0EEEE
0000002ZZZX20?ooo`80000000<0oooo0:ZZZP1EEED00P0000000`2ZZZX0oooo0?ooo`0>0?ooo`X0
dLfY3`3oool20:ZZZP0305EEE@2ZZZX0ZZZZ0080EEEE00T0ZZZZ05EEE@2ZZZX0EEEE0:ZZZP1EEED0
oooo05EEE@3oool0102ZZZX0101EEED0oooo0000001EEED40:ZZZP090?ooo`1EEED0EEEE05EEE@3o
ool0EEEE0:ZZZP1EEED0ZZZZ0080EEEE0P2ZZZX00`000000ZZZZ0?ooo`0?0?ooo`X0dLfY3`3oool2
0:ZZZP060?ooo`2ZZZX0oooo05EEE@2ZZZX0EEEE1@3oool205EEE@D0oooo00@0ZZZZ0000003oool0
ZZZZ1@3oool00`1EEED000000?ooo`040?ooo`0405EEE@2ZZZX0EEEE0?ooo`<0ZZZZ403oool<0=7=
Z@002`3AcJTA0?ooo`040:ZZZP1EEED0oooo0?ooo`80EEEE0P0000001P3oool000000:ZZZP000000
oooo00000080EEEE0P0000020:ZZZP040?ooo`2ZZZX0oooo00000080EEEE00H000000?ooo`2ZZZX0
ZZZZ0000003oool200000080EEEE0P3oool00`1EEED0ZZZZ0?ooo`0@0?ooo`X0dLfY4@3oool00`2Z
ZZX0EEEE000000020?ooo`060:ZZZP000000000005EEE@3oool0EEEE0`2ZZZX205EEE@030000001E
EED0EEEE00@0EEEE00<0000005EEE@1EEED00`2ZZZX305EEE@80000000H0ZZZZ0?ooo`3oool00000
05EEE@2ZZZXA0?ooo`X0dLfY4@3oool01@2ZZZX0EEEE0000003oool000000080oooo00@000000?oo
o`000000EEEE0`2ZZZX0103oool0ZZZZ0:ZZZP3oool405EEE@<0ZZZZ00D0oooo0:ZZZP2ZZZX0oooo
05EEE@020?ooo`080000003oool0oooo0000003oool0000005EEE@2ZZZXA0?ooo`X0dLfY4@3oool0
1P2ZZZX0EEEE0?ooo`000000ZZZZ0?ooo`<0EEEE00<0oooo0:ZZZP0000000P1EEED01@000000oooo
0:ZZZP1EEED0oooo0080ZZZZ00<0oooo05EEE@2ZZZX00P3oool305EEE@030:ZZZP000000EEEE0080
EEEE00H0oooo0:ZZZP1EEED0oooo05EEE@2ZZZXA0?ooo`X0dLfY4@3oool00`2ZZZX0oooo00000002
0?ooo`070000001EEED0oooo0000002ZZZX000000:ZZZP0205EEE@040?ooo`1EEED0EEEE0?ooo`@0
EEEE00@0oooo05EEE@1EEED0oooo0P1EEED0203oool000000:ZZZP000000oooo05EEE@000000oooo
0P0000000`3oool0ZZZZ0?ooo`0@0?ooo``0dLfY000;0=7=ZA40oooo00<0ZZZZ0?ooo`1EEED00P3o
ool010000000EEEE0000003oool305EEE@030000002ZZZX0ZZZZ0080ZZZZ00H0EEEE0?ooo`3oool0
EEEE0?ooo`0000040:ZZZP080000003oool0EEEE0000003oool000000?ooo`0000020?ooo`0305EE
E@3oool0oooo0140oooo2P3AcJTA0?ooo`0:0:ZZZP3oool0EEEE0000001EEED000000:ZZZP000000
ZZZZ000000@0EEEE00<0oooo05EEE@1EEED01P2ZZZX705EEE@080000002ZZZX000000:ZZZP000000
EEEE0000001EEEDC0?ooo`X0dLfY4@3oool00`2ZZZX0oooo05EEE@0205EEE@80oooo0`1EEED01`3o
ool0ZZZZ0000002ZZZX0oooo0:ZZZP3oool01@2ZZZX20?ooo`<0ZZZZ00<000000:ZZZP3oool00`1E
EED20?ooo`<0EEEE4`3oool:0=7=ZA40oooo00@0ZZZZ0?ooo`1EEED0ZZZZ0P0000000`1EEED00000
0?ooo`0205EEE@040?ooo`2ZZZX0EEEE05EEE@80oooo0P1EEED010000000EEEE05EEE@2ZZZX20?oo
o`80EEEE00L0ZZZZ0000001EEED0EEEE0?ooo`000000oooo0080000000<0oooo05EEE@3oool04P3o
ool:0=7=ZA40oooo00<0ZZZZ0?ooo`0000000P3oool305EEE@<0oooo00@0ZZZZ05EEE@1EEED0ZZZZ
0P1EEED00`2ZZZX0EEEE0:ZZZP0205EEE@040:ZZZP1EEED0EEEE0:ZZZP80EEEE00L000000?ooo`2Z
ZZX0oooo05EEE@2ZZZX0EEEE0080oooo00<000000?ooo`3oool04@3oool<0=7=Z@002`3AcJTB0?oo
o`80ZZZZ00D0oooo0:ZZZP2ZZZX0EEEE0000000205EEE@070?ooo`2ZZZX0ZZZZ0000002ZZZX0oooo
000000020:ZZZP0505EEE@3oool0ZZZZ0:ZZZP0000000P3oool01P000000ZZZZ0:ZZZP3oool0ZZZZ
05EEE@8000001@2ZZZXB0?ooo`X0dLfY4P3oool20:ZZZP0905EEE@2ZZZX0ZZZZ05EEE@2ZZZX0EEEE
0?ooo`1EEED0000000<0EEEE00<0000005EEE@1EEED01P1EEED2000000@0EEEE00@0000005EEE@2Z
ZZX000000P2ZZZX00`1EEED0ZZZZ0:ZZZP0B0?ooo`X0dLfY4P3oool:0:ZZZP040?ooo`2ZZZX00000
0:ZZZP80oooo00D0EEEE000000000000EEEE000000030?ooo`040:ZZZP000000ZZZZ0?ooo`@0ZZZZ
00<0oooo0:ZZZP2ZZZX00`2ZZZXB0?ooo`X0dLfY4P3oool20:ZZZP80EEEE0P3oool010000000ZZZZ
05EEE@2ZZZX20000000905EEE@000000oooo0000001EEED0oooo05EEE@2ZZZX0oooo008000000P3o
ool02`1EEED000000?ooo`2ZZZX0EEEE0:ZZZP000000EEEE0?ooo`1EEED000000080ZZZZ4P3oool:
0=7=ZA80oooo0P2ZZZX0103oool0ZZZZ0000000000020:ZZZP80oooo0P0000000`2ZZZX0EEEE0000
000305EEE@030?ooo`000000EEEE0080EEEE0P0000000`2ZZZX000000?ooo`020?ooo`80ZZZZ0P00
00040:ZZZQ80oooo303AcJT000/0dLfY503oool01@2ZZZX0oooo05EEE@000000ZZZZ00<0EEEE00<0
oooo05EEE@1EEED00P2ZZZX0101EEED0oooo0?ooo`2ZZZX20?ooo`80EEEE0P2ZZZX205EEE@040?oo
o`1EEED0oooo05EEE@80ZZZZ00<0EEEE0?ooo`2ZZZX0503oool:0=7=ZA@0oooo00<0ZZZZ05EEE@00
00000P3oool0102ZZZX000000000002ZZZX20?ooo`080000001EEED0EEEE05EEE@000000EEEE0:ZZ
ZP00000405EEE@80oooo0P0000020:ZZZP80oooo00<0000005EEE@2ZZZX0503oool:0=7=ZA@0oooo
00<0ZZZZ0?ooo`3oool00P3oool00`2ZZZX0oooo0?ooo`030?ooo`090000002ZZZX0ZZZZ0?ooo`2Z
ZZX0EEEE0?ooo`2ZZZX0oooo00<0ZZZZ0P3oool01P1EEED0oooo0:ZZZP2ZZZX0oooo05EEE@80oooo
00<0ZZZZ0?ooo`3oool04P3oool:0=7=ZA@0oooo00<0ZZZZ05EEE@3oool00P1EEED00`3oool00000
0:ZZZP0205EEE@80oooo00@000000?ooo`3oool0ZZZZ0P000000102ZZZX0EEEE0?ooo`0000020?oo
o`0605EEE@000000ZZZZ05EEE@3oool0EEEE0P3oool00`1EEED0ZZZZ0?ooo`0C0?ooo`X0dLfY503o
ool0102ZZZX0oooo0000002ZZZX50?ooo`0305EEE@2ZZZX0ZZZZ0080EEEE00@0ZZZZ05EEE@3oool0
oooo101EEED20:ZZZP80EEEE00@0oooo05EEE@3oool0oooo0P0000000`3oool0ZZZZ0?ooo`0C0?oo
o``0dLfY000;0=7=ZA@0oooo00D0ZZZZ0?ooo`2ZZZX0ZZZZ05EEE@020:ZZZP0705EEE@3oool0oooo
0000002ZZZX0oooo000000030?ooo`0405EEE@3oool0oooo00000080oooo00H000000?ooo`3oool0
EEEE0?ooo`2ZZZX205EEE@030:ZZZP3oool0oooo01@0oooo2P3AcJTD0?ooo`060:ZZZP3oool0EEEE
0000001EEED000000`1EEED20000000705EEE@2ZZZX0ZZZZ05EEE@2ZZZX0000005EEE@040:ZZZP0:
05EEE@00000000000:ZZZP1EEED0ZZZZ0000001EEED0000005EEEAH0oooo2P3AcJTD0?ooo`080:ZZ
ZP3oool0ZZZZ0:ZZZP3oool0ZZZZ0?ooo`1EEED20:ZZZP80oooo00@0000005EEE@3oool0oooo0P2Z
ZZX20?ooo`0:05EEE@000000ZZZZ0?ooo`2ZZZX0oooo05EEE@3oool0ZZZZ0?ooo`80ZZZZ5P3oool:
0=7=ZA@0oooo00D0ZZZZ0?ooo`1EEED0oooo000000020?ooo`030:ZZZP000000EEEE0080oooo0P1E
EED00`2ZZZX0000000000002000000<0EEEE0P3oool0201EEED0oooo0:ZZZP000000oooo0000003o
ool0EEEE5P3oool:0=7=ZA@0oooo00H0ZZZZ0?ooo`000000oooo0:ZZZP00000205EEE@080000002Z
ZZX000000:ZZZP000000ZZZZ0000001EEED20?ooo`0>05EEE@2ZZZX0ZZZZ0000001EEED000000:ZZ
ZP3oool0EEEE0?ooo`000000ZZZZ0?ooo`00000F0?ooo``0dLfY000;0=7=ZAD0oooo0P2ZZZX00`3o
ool0EEEE0:ZZZP020?ooo`<0000000<0EEEE0:ZZZP0000000P0000020?ooo`<000000P2ZZZX30000
00030?ooo`2ZZZX0ZZZZ0080EEEE0P2ZZZXE0?ooo`X0dLfY5@3oool20:ZZZP0305EEE@2ZZZX0ZZZZ
0080EEEE00P0ZZZZ0000002ZZZX0ZZZZ05EEE@000000EEEE0:ZZZP8000000P2ZZZX010000000EEEE
0:ZZZP2ZZZX20000000505EEE@000000ZZZZ0:ZZZP1EEED00P2ZZZXE0?ooo`X0dLfY5@3oool40:ZZ
ZP<0oooo00<0000005EEE@3oool00P2ZZZX0101EEED0oooo0?ooo`2ZZZX30?ooo`0605EEE@2ZZZX0
oooo0?ooo`1EEED000000`3oool0102ZZZX000000:ZZZP2ZZZXE0?ooo`X0dLfY5@3oool20:ZZZP03
05EEE@2ZZZX0ZZZZ008000001P2ZZZX5000000<0ZZZZ00H0oooo0:ZZZP2ZZZX0EEEE0000003oool2
0:ZZZP030000002ZZZX0ZZZZ01D0oooo2P3AcJTE0?ooo`80ZZZZ00@0oooo0:ZZZP3oool0EEEE0P2Z
ZZX20?ooo`0605EEE@2ZZZX0oooo0:ZZZP1EEED0oooo0P1EEED20?ooo`080:ZZZP000000oooo0?oo
o`1EEED0ZZZZ05EEE@3oool40:ZZZQD0oooo303AcJT000/0dLfY5`3oool20:ZZZP060?ooo`000000
ZZZZ0?ooo`1EEED000000P3oool00`2ZZZX000000:ZZZP020?ooo`040:ZZZP000000ZZZZ0?ooo`80
000000D0EEEE0:ZZZP2ZZZX000000?ooo`020:ZZZQL0oooo2P3AcJTG0?ooo`030:ZZZP1EEED00000
0080oooo0P0000001P2ZZZX0EEEE0000002ZZZX0EEEE0?ooo`80EEEE00P0oooo05EEE@2ZZZX00000
05EEE@2ZZZX000000:ZZZP80oooo00<0000005EEE@2ZZZX05`3oool:0=7=ZAL0oooo00<0ZZZZ05EE
E@3oool00P3oool00`000000oooo000000030?ooo`0405EEE@2ZZZX0oooo05EEE@80ZZZZ0P3oool0
0`1EEED000000?ooo`040?ooo`0305EEE@2ZZZX0oooo01H0oooo2P3AcJTG0?ooo`030:ZZZP1EEED0
oooo0080000000<0oooo0000002ZZZX00P2ZZZX0101EEED0oooo05EEE@3oool405EEE@<0ZZZZ00L0
000005EEE@000000EEEE0?ooo`1EEED0ZZZZ01L0oooo2P3AcJTG0?ooo`030:ZZZP3oool000000080
oooo0P1EEED02@2ZZZX0EEEE0?ooo`000000EEEE0?ooo`000000ZZZZ0?ooo`02000000060?ooo`2Z
ZZX0ZZZZ05EEE@000000oooo0P0000000`3oool0ZZZZ0?ooo`0F0?ooo``0dLfY000;0=7=ZAL0oooo
00@0ZZZZ0?ooo`3oool000000P3oool0102ZZZX0EEEE0000002ZZZX305EEE@80oooo00@0EEEE0:ZZ
ZP1EEED0ZZZZ0P1EEED20:ZZZP030?ooo`1EEED0oooo01T0oooo2P3AcJTG0?ooo`050:ZZZP3oool0
EEEE0000001EEED00P2ZZZX00`000000EEEE000000030?ooo`0=0000003oool0oooo0000003oool0
000005EEE@000000ZZZZ0000001EEED0000005EEE@0I0?ooo`X0dLfY5`3oool00`2ZZZX0oooo05EE
E@030?ooo`0405EEE@3oool0ZZZZ00000080EEEE0P3oool01`000000oooo0:ZZZP1EEED0000005EE
E@3oool00P1EEED20?ooo`0305EEE@3oool0oooo01L0oooo2P3AcJTG0?ooo`060:ZZZP3oool0EEEE
0:ZZZP000000oooo101EEED01@000000oooo0?ooo`3oool000000080oooo00<0000005EEE@000000
0P1EEED0103oool000000?ooo`1EEEDI0?ooo`X0dLfY5`3oool00`2ZZZX0oooo000000020?ooo`04
0:ZZZP1EEED0EEEE05EEE@<0ZZZZ0P0000000`3oool000000:ZZZP020:ZZZP@0EEEE0P3oool00`00
0000oooo0?ooo`0G0?ooo``0dLfY000;0=7=ZAP0oooo0P2ZZZX02@1EEED000000?ooo`2ZZZX0oooo
0:ZZZP1EEED0ZZZZ000000050?ooo`040:ZZZP1EEED0EEEE0?ooo`80ZZZZ00@000000?ooo`2ZZZX0
ZZZZ603oool:0=7=ZAP0oooo0P2ZZZX01`1EEED0ZZZZ0000001EEED0ZZZZ0?ooo`1EEED00P000000
101EEED000000000001EEED200000080EEEE00D0ZZZZ05EEE@2ZZZX0ZZZZ05EEE@020:ZZZQP0oooo
2P3AcJTH0?ooo`80ZZZZ00l0oooo0:ZZZP2ZZZX0oooo05EEE@2ZZZX0oooo0000001EEED0ZZZZ0?oo
o`000000ZZZZ0?ooo`0000000P3oool00`1EEED0oooo0:ZZZP040:ZZZQP0oooo2P3AcJTH0?ooo`80
ZZZZ0P1EEED20?ooo`040000002ZZZX0EEEE05EEE@80oooo0P1EEED20?ooo`80EEEE00H0oooo0000
003oool0oooo05EEE@0000020:ZZZQP0oooo2P3AcJTH0?ooo`80ZZZZ00D0oooo0:ZZZP0000000000
0:ZZZP030000000505EEE@2ZZZX000000?ooo`2ZZZX00`0000020:ZZZP800000102ZZZXH0?ooo``0
dLfY000;0=7=ZAX0oooo00P0ZZZZ05EEE@2ZZZX0ZZZZ0?ooo`2ZZZX0oooo05EEE@80ZZZZ0P000000
2P2ZZZX0oooo05EEE@3oool000000?ooo`2ZZZX0oooo05EEE@2ZZZXJ0?ooo`X0dLfY6P3oool00`2Z
ZZX0EEEE0?ooo`020?ooo`80ZZZZ00<0oooo05EEE@0000000P1EEED2000000030?ooo`2ZZZX0ZZZZ
0080oooo00<0000005EEE@2ZZZX06P3oool:0=7=ZAX0oooo00<0ZZZZ0?ooo`3oool00P2ZZZX00`00
0000oooo0:ZZZP02000000030?ooo`2ZZZX000000080ZZZZ00<0oooo0:ZZZP2ZZZX00P2ZZZX00`3o
ool0ZZZZ0?ooo`0I0?ooo`X0dLfY6P3oool0202ZZZX0EEEE0?ooo`1EEED0oooo05EEE@3oool0EEEE
0`3oool02`1EEED0oooo0?ooo`1EEED0oooo0:ZZZP3oool0EEEE0?ooo`1EEED0ZZZZ01X0oooo2P3A
cJTJ0?ooo`0:0:ZZZP3oool000000:ZZZP3oool0EEEE0?ooo`2ZZZX0EEEE0?ooo`80000000<0oooo
0:ZZZP2ZZZX00`3oool0102ZZZX000000?ooo`2ZZZXJ0?ooo``0dLfY000;0=7=ZAX0oooo00<0ZZZZ
0?ooo`3oool00P1EEED20:ZZZP80oooo00<0EEEE0000001EEED00P1EEED00`3oool0ZZZZ05EEE@03
05EEEA`0oooo2P3AcJTJ0?ooo`070:ZZZP3oool000000000001EEED0ZZZZ05EEE@02000000@0ZZZZ
0P0000001@1EEED0000005EEE@000000EEEE01`0oooo2P3AcJTJ0?ooo`0:0:ZZZP3oool0oooo0:ZZ
ZP3oool0ZZZZ0000001EEED000000:ZZZP80oooo00@0ZZZZ0?ooo`1EEED000000P3oool20:ZZZQ`0
oooo2P3AcJTJ0?ooo`060:ZZZP3oool0oooo0?ooo`000000EEEE0P3oool01P000000oooo0?ooo`00
0000oooo00000080oooo0P0000000`3oool0EEEE0?ooo`0K0?ooo`X0dLfY6P3oool01P2ZZZX0oooo
0?ooo`3oool0ZZZZ0?ooo`<0EEEE102ZZZX305EEE@040000002ZZZX0oooo000001`0oooo303AcJT0
00/0dLfY6`3oool20:ZZZP040?ooo`1EEED0oooo0?ooo`80ZZZZ00@0oooo0:ZZZP1EEED0oooo0P2Z
ZZX0103oool0ZZZZ05EEE@3oool20:ZZZQ/0oooo2P3AcJTK0?ooo`050:ZZZP1EEED0EEEE0:ZZZP00
00001`1EEED00`2ZZZX0EEEE05EEE@020:ZZZP0305EEE@2ZZZX0ZZZZ01/0oooo2P3AcJTK0?ooo`04
0:ZZZP000000EEEE00000080EEEE00<0oooo0:ZZZP1EEED00`1EEED01P2ZZZX0oooo05EEE@2ZZZX0
000005EEE@80ZZZZ6`3oool:0=7=ZA/0oooo00@0ZZZZ0000001EEED0ZZZZ0`1EEED0103oool0EEEE
05EEE@3oool405EEE@80ZZZZ00<0EEEE0:ZZZP2ZZZX06`3oool:0=7=ZA/0oooo0P2ZZZX01P3oool0
ZZZZ05EEE@1EEED0ZZZZ05EEE@@0000000H0EEEE0:ZZZP1EEED0oooo0:ZZZP3oool20:ZZZQ/0oooo
303AcJT000/0dLfY703oool20:ZZZP060?ooo`1EEED0oooo0?ooo`2ZZZX000000P3oool01`000000
ZZZZ0?ooo`3oool0EEEE0?ooo`2ZZZX07@3oool:0=7=ZA`0oooo0P2ZZZX0101EEED0oooo0?ooo`3o
ool305EEE@030?ooo`1EEED0ZZZZ0080oooo00<0000005EEE@2ZZZX07@3oool:0=7=ZA`0oooo0P2Z
ZZX01`1EEED0oooo0000003oool0EEEE0000002ZZZX00P0000001P1EEED0oooo000000000000EEEE
0:ZZZQd0oooo2P3AcJTL0?ooo`80ZZZZ0P1EEED010000000ZZZZ0:ZZZP2ZZZX2000000070:ZZZP00
0000ZZZZ0000003oool0EEEE0:ZZZP0M0?ooo`X0dLfY703oool20:ZZZP030?ooo`000000oooo0080
oooo1@0000020?ooo`030000003oool0ZZZZ01d0oooo303AcJT000/0dLfY7@3oool00`2ZZZX0oooo
05EEE@020?ooo`030:ZZZP000000oooo008000000`3oool00`2ZZZX0oooo0:ZZZP0M0?ooo`X0dLfY
7@3oool01P2ZZZX0oooo000000000000EEEE0:ZZZP80oooo00P0EEEE0?ooo`000000EEEE0000001E
EED0oooo0:ZZZQd0oooo2P3AcJTM0?ooo`090:ZZZP3oool0EEEE05EEE@3oool000000?ooo`000000
ZZZZ00<0oooo0P1EEED00`3oool0ZZZZ0?ooo`0L0?ooo`X0dLfY7@3oool0102ZZZX0oooo0?ooo`2Z
ZZX20000000405EEE@3oool0EEEE05EEE@80000000@0ZZZZ05EEE@3oool0ZZZZ7@3oool:0=7=ZAd0
oooo00<0ZZZZ0?ooo`3oool00P3oool50:ZZZP0605EEE@3oool0oooo0000003oool0ZZZZ7@3oool<
0=7=Z@002`3AcJTP0?ooo`0705EEE@3oool0oooo0000001EEED0oooo000000020?ooo`0305EEE@2Z
ZZX0oooo01h0oooo2P3AcJTP0?ooo`0;05EEE@2ZZZX0EEEE0?ooo`000000EEEE0?ooo`000000ZZZZ
05EEE@2ZZZX07`3oool:0=7=ZB40oooo0P2ZZZX20?ooo`060000003oool0oooo0:ZZZP3oool0ZZZZ
7`3oool:0=7=ZB00oooo00@0000005EEE@3oool000000P1EEED01@000000oooo05EEE@000000ZZZZ
01l0oooo2P3AcJTR0?ooo`0305EEE@3oool000000080oooo00@0ZZZZ0?ooo`3oool0ZZZZ7`3oool<
0=7=Z@002`3AcJTO0?ooo`D0ZZZZ00@0EEEE0000002ZZZX0oooo0P2ZZZXP0?ooo`X0dLfY7`3oool2
0:ZZZP0905EEE@3oool0oooo0:ZZZP1EEED0oooo0000001EEED0ZZZZ0200oooo2P3AcJTO0?ooo`80
ZZZZ00H0oooo05EEE@000000oooo0:ZZZP0000020?ooo`030:ZZZP3oool0oooo01h0oooo2P3AcJTO
0?ooo`80ZZZZ00@0EEEE0?ooo`1EEED0ZZZZ0P1EEED00`3oool0EEEE0:ZZZP0P0?ooo`X0dLfY7`3o
ool20:ZZZP090?ooo`000000ZZZZ0000003oool0ZZZZ0000003oool0ZZZZ0200oooo303AcJT000/0
dLfY803oool01`2ZZZX0oooo05EEE@1EEED000000?ooo`1EEED00P3oool00`2ZZZX0oooo0?ooo`0N
0?ooo`X0dLfY803oool0102ZZZX0oooo00000000000205EEE@040000001EEED0oooo0:ZZZR00oooo
2P3AcJTP0?ooo`040:ZZZP3oool0ZZZZ0:ZZZP80EEEE0P2ZZZX00`3oool0ZZZZ0?ooo`0O0?ooo`X0
dLfY803oool02P2ZZZX0oooo0?ooo`3oool0EEEE0000003oool0EEEE0?ooo`2ZZZXP0?ooo`X0dLfY
803oool0102ZZZX0oooo0?ooo`3oool20:ZZZP040?ooo`000000oooo0:ZZZR00oooo303AcJT000/0
dLfY8`3oool20:ZZZP0305EEE@2ZZZX0ZZZZ0280oooo2P3AcJTS0?ooo`@0EEEE00<0ZZZZ0?ooo`3o
ool0803oool:0=7=ZB<0oooo0P0000000`1EEED000000:ZZZP0R0?ooo`X0dLfY8`3oool200000003
05EEE@000000ZZZZ0280oooo2P3AcJTT0?ooo`040000003oool0oooo0:ZZZR80oooo303AcJT000/0
dLfY8P3oool20:ZZZP030?ooo`1EEED0ZZZZ02<0oooo2P3AcJTR0?ooo`80ZZZZ00<0oooo05EEE@2Z
ZZX08`3oool:0=7=ZB80oooo0P2ZZZX00`3oool0EEEE0:ZZZP0S0?ooo`X0dLfY8P3oool20:ZZZP03
0?ooo`1EEED0ZZZZ02<0oooo2P3AcJTR0?ooo`80ZZZZ00<000000?ooo`2ZZZX08`3oool<0=7=Z@00
2`3AcJTS0?ooo`040:ZZZP1EEED0oooo0:ZZZR<0oooo2P3AcJTS0?ooo`040:ZZZP1EEED0oooo0:ZZ
ZR<0oooo2P3AcJTS0?ooo`040:ZZZP1EEED0oooo0:ZZZR<0oooo2P3AcJTS0?ooo`040:ZZZP1EEED0
oooo0:ZZZR<0oooo2P3AcJTS0?ooo`040:ZZZP000000oooo0:ZZZR<0oooo303AcJT000/0dLfY903o
ool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903o
ool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903oool00`2ZZZX0oooo0?ooo`0S0?ooo`X0dLfY903o
ool00`2ZZZX0oooo0?ooo`0S0?ooo``0dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80
dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80
dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80
dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80
dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80
dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80
dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80
dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80
dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80dLfY003o0=7=ZK80
dLfY0000\
\>"],
  ImageRangeCache->{{{0, 432.813}, {1744.75, 0}} -> {-0.125026, -0.520559, \
0.0121301, 0.0121301}, {{10.25, 86.625}, {1701.81, 1664}} -> {-16.1177, \
-60.0557, 1.37533, 1.37533}, {{94.25, 170.563}, {1701.81, 1664}} -> \
{-131.752, -60.1254, 1.37646, 1.37646}, {{178.188, 254.563}, {1701.81, 1664}} -> \
{-247.088, -60.0557, 1.37533, 1.37533}, {{262.188, 338.5}, {1701.81, 1664}} -> \
{-362.911, -60.1254, 1.37646, 1.37646}, {{346.125, 422.5}, {1701.81, 1664}} -> \
{-478.058, -60.0557, 1.37533, 1.37533}, {{10.25, 86.625}, {1660.25, 1622.44}} -> \
{-16.1177, -117.218, 1.37533, 1.37533}, {{94.25, 170.563}, {1660.25, \
1622.44}} -> {-131.752, -117.335, 1.37646, 1.37646}, {{178.188, 254.563}, \
{1660.25, 1622.44}} -> {-247.088, -117.218, 1.37533, 1.37533}, {{262.188, \
338.5}, {1660.25, 1622.44}} -> {-362.911, -117.335, 1.37646, 1.37646}, \
{{346.125, 422.5}, {1660.25, 1622.44}} -> {-478.058, -117.218, 1.37533, \
1.37533}, {{10.25, 86.625}, {1618.69, 1580.88}} -> {-16.1177, -174.38, \
1.37533, 1.37533}, {{94.25, 170.563}, {1618.69, 1580.88}} -> {-131.752, \
-174.544, 1.37646, 1.37646}, {{178.188, 254.563}, {1618.69, 1580.88}} -> \
{-247.088, -174.38, 1.37533, 1.37533}, {{262.188, 338.5}, {1618.69, 1580.88}} -> \
{-362.911, -174.544, 1.37646, 1.37646}, {{346.125, 422.5}, {1618.69, \
1580.88}} -> {-478.058, -174.38, 1.37533, 1.37533}, {{10.25, 86.625}, \
{1577.13, 1539.31}} -> {-16.1177, -231.543, 1.37533, 1.37533}, {{94.25, \
170.563}, {1577.13, 1539.31}} -> {-131.752, -231.753, 1.37646, 1.37646}, \
{{178.188, 254.563}, {1577.13, 1539.31}} -> {-247.088, -231.543, 1.37533, \
1.37533}, {{262.188, 338.5}, {1577.13, 1539.31}} -> {-362.911, -231.753, \
1.37646, 1.37646}, {{346.125, 422.5}, {1577.13, 1539.31}} -> {-478.058, \
-231.543, 1.37533, 1.37533}, {{10.25, 86.625}, {1535.56, 1497.75}} -> \
{-16.1177, -288.705, 1.37533, 1.37533}, {{94.25, 170.563}, {1535.56, \
1497.75}} -> {-131.752, -288.962, 1.37646, 1.37646}, {{178.188, 254.563}, \
{1535.56, 1497.75}} -> {-247.088, -288.705, 1.37533, 1.37533}, {{262.188, \
338.5}, {1535.56, 1497.75}} -> {-362.911, -288.962, 1.37646, 1.37646}, \
{{346.125, 422.5}, {1535.56, 1497.75}} -> {-478.058, -288.705, 1.37533, \
1.37533}, {{10.25, 86.625}, {1493.94, 1456.19}} -> {-16.2226, -346.494, \
1.3775, 1.3775}, {{94.25, 170.563}, {1493.94, 1456.19}} -> {-131.889, \
-346.494, 1.3775, 1.3775}, {{178.188, 254.563}, {1493.94, 1456.19}} -> \
{-247.556, -346.494, 1.3775, 1.3775}, {{262.188, 338.5}, {1493.94, 1456.19}} -> \
{-363.223, -346.494, 1.3775, 1.3775}, {{346.125, 422.5}, {1493.94, 1456.19}} -> \
{-478.89, -346.494, 1.3775, 1.3775}, {{10.25, 86.625}, {1452.38, 1414.63}} -> \
{-16.2226, -403.747, 1.3775, 1.3775}, {{94.25, 170.563}, {1452.38, 1414.63}} -> \
{-131.889, -403.747, 1.3775, 1.3775}, {{178.188, 254.563}, {1452.38, \
1414.63}} -> {-247.556, -403.747, 1.3775, 1.3775}, {{262.188, 338.5}, \
{1452.38, 1414.63}} -> {-363.223, -403.747, 1.3775, 1.3775}, {{346.125, \
422.5}, {1452.38, 1414.63}} -> {-478.89, -403.747, 1.3775, 1.3775}, {{10.25, \
86.625}, {1410.81, 1373.06}} -> {-16.2226, -460.999, 1.3775, 1.3775}, \
{{94.25, 170.563}, {1410.81, 1373.06}} -> {-131.889, -460.999, 1.3775, \
1.3775}, {{178.188, 254.563}, {1410.81, 1373.06}} -> {-247.556, -460.999, \
1.3775, 1.3775}, {{262.188, 338.5}, {1410.81, 1373.06}} -> {-363.223, \
-460.999, 1.3775, 1.3775}, {{346.125, 422.5}, {1410.81, 1373.06}} -> \
{-478.89, -460.999, 1.3775, 1.3775}, {{10.25, 86.625}, {1369.25, 1331.5}} -> \
{-16.2226, -518.251, 1.3775, 1.3775}, {{94.25, 170.563}, {1369.25, 1331.5}} -> \
{-131.889, -518.251, 1.3775, 1.3775}, {{178.188, 254.563}, {1369.25, 1331.5}} -> \
{-247.556, -518.251, 1.3775, 1.3775}, {{262.188, 338.5}, {1369.25, 1331.5}} -> \
{-363.223, -518.251, 1.3775, 1.3775}, {{346.125, 422.5}, {1369.25, 1331.5}} -> \
{-478.89, -518.251, 1.3775, 1.3775}, {{10.25, 86.625}, {1327.69, 1289.94}} -> \
{-16.2226, -575.503, 1.3775, 1.3775}, {{94.25, 170.563}, {1327.69, 1289.94}} -> \
{-131.889, -575.503, 1.3775, 1.3775}, {{178.188, 254.563}, {1327.69, \
1289.94}} -> {-247.556, -575.503, 1.3775, 1.3775}, {{262.188, 338.5}, \
{1327.69, 1289.94}} -> {-363.223, -575.503, 1.3775, 1.3775}, {{346.125, \
422.5}, {1327.69, 1289.94}} -> {-478.89, -575.503, 1.3775, 1.3775}, {{10.25, \
86.625}, {1286.13, 1248.31}} -> {-16.1177, -631.765, 1.37533, 1.37533}, \
{{94.25, 170.563}, {1286.13, 1248.31}} -> {-131.752, -632.302, 1.37646, \
1.37646}, {{178.188, 254.563}, {1286.13, 1248.31}} -> {-247.088, -631.765, \
1.37533, 1.37533}, {{262.188, 338.5}, {1286.13, 1248.31}} -> {-362.911, \
-632.302, 1.37646, 1.37646}, {{346.125, 422.5}, {1286.13, 1248.31}} -> \
{-478.058, -631.765, 1.37533, 1.37533}, {{10.25, 86.625}, {1244.56, 1206.75}} -> \
{-16.1177, -688.927, 1.37533, 1.37533}, {{94.25, 170.563}, {1244.56, \
1206.75}} -> {-131.752, -689.512, 1.37646, 1.37646}, {{178.188, 254.563}, \
{1244.56, 1206.75}} -> {-247.088, -688.927, 1.37533, 1.37533}, {{262.188, \
338.5}, {1244.56, 1206.75}} -> {-362.911, -689.512, 1.37646, 1.37646}, \
{{346.125, 422.5}, {1244.56, 1206.75}} -> {-478.058, -688.927, 1.37533, \
1.37533}, {{10.25, 86.625}, {1203, 1165.19}} -> {-16.1177, -746.089, 1.37533, \
1.37533}, {{94.25, 170.563}, {1203, 1165.19}} -> {-131.752, -746.721, \
1.37646, 1.37646}, {{178.188, 254.563}, {1203, 1165.19}} -> {-247.088, \
-746.089, 1.37533, 1.37533}, {{262.188, 338.5}, {1203, 1165.19}} -> \
{-362.911, -746.721, 1.37646, 1.37646}, {{346.125, 422.5}, {1203, 1165.19}} -> \
{-478.058, -746.089, 1.37533, 1.37533}, {{10.25, 86.625}, {1161.44, 1123.63}} -> \
{-16.1177, -803.251, 1.37533, 1.37533}, {{94.25, 170.563}, {1161.44, \
1123.63}} -> {-131.752, -803.93, 1.37646, 1.37646}, {{178.188, 254.563}, \
{1161.44, 1123.63}} -> {-247.088, -803.251, 1.37533, 1.37533}, {{262.188, \
338.5}, {1161.44, 1123.63}} -> {-362.911, -803.93, 1.37646, 1.37646}, \
{{346.125, 422.5}, {1161.44, 1123.63}} -> {-478.058, -803.251, 1.37533, \
1.37533}, {{10.25, 86.625}, {1119.88, 1082.06}} -> {-16.1177, -860.414, \
1.37533, 1.37533}, {{94.25, 170.563}, {1119.88, 1082.06}} -> {-131.752, \
-861.139, 1.37646, 1.37646}, {{178.188, 254.563}, {1119.88, 1082.06}} -> \
{-247.088, -860.414, 1.37533, 1.37533}, {{262.188, 338.5}, {1119.88, \
1082.06}} -> {-362.911, -861.139, 1.37646, 1.37646}, {{346.125, 422.5}, \
{1119.88, 1082.06}} -> {-478.058, -860.414, 1.37533, 1.37533}, {{10.25, \
86.625}, {1078.31, 1040.5}} -> {-16.1177, -917.576, 1.37533, 1.37533}, \
{{94.25, 170.563}, {1078.31, 1040.5}} -> {-131.752, -918.348, 1.37646, \
1.37646}, {{178.188, 254.563}, {1078.31, 1040.5}} -> {-247.088, -917.576, \
1.37533, 1.37533}, {{262.188, 338.5}, {1078.31, 1040.5}} -> {-362.911, \
-918.348, 1.37646, 1.37646}, {{346.125, 422.5}, {1078.31, 1040.5}} -> \
{-478.058, -917.576, 1.37533, 1.37533}, {{10.25, 86.625}, {1036.75, 998.938}} -> \
{-16.1177, -974.738, 1.37533, 1.37533}, {{94.25, 170.563}, {1036.75, \
998.938}} -> {-131.752, -975.557, 1.37646, 1.37646}, {{178.188, 254.563}, \
{1036.75, 998.938}} -> {-247.088, -974.738, 1.37533, 1.37533}, {{262.188, \
338.5}, {1036.75, 998.938}} -> {-362.911, -975.557, 1.37646, 1.37646}, \
{{346.125, 422.5}, {1036.75, 998.938}} -> {-478.058, -974.738, 1.37533, \
1.37533}, {{10.25, 86.625}, {995.188, 957.375}} -> {-16.1177, -1031.9, \
1.37533, 1.37533}, {{94.25, 170.563}, {995.188, 957.375}} -> {-131.752, \
-1032.77, 1.37646, 1.37646}, {{178.188, 254.563}, {995.188, 957.375}} -> \
{-247.088, -1031.9, 1.37533, 1.37533}, {{262.188, 338.5}, {995.188, 957.375}} -> \
{-362.911, -1032.77, 1.37646, 1.37646}, {{346.125, 422.5}, {995.188, \
957.375}} -> {-478.058, -1031.9, 1.37533, 1.37533}, {{10.25, 86.625}, \
{953.563, 915.813}} -> {-16.2226, -1090.86, 1.3775, 1.3775}, {{94.25, \
170.563}, {953.563, 915.813}} -> {-131.889, -1090.86, 1.3775, 1.3775}, \
{{178.188, 254.563}, {953.563, 915.813}} -> {-247.556, -1090.86, 1.3775, \
1.3775}, {{262.188, 338.5}, {953.563, 915.813}} -> {-363.223, -1090.86, \
1.3775, 1.3775}, {{346.125, 422.5}, {953.563, 915.813}} -> {-478.89, \
-1090.86, 1.3775, 1.3775}, {{10.25, 86.625}, {912, 874.25}} -> {-16.2226, \
-1148.11, 1.3775, 1.3775}, {{94.25, 170.563}, {912, 874.25}} -> {-131.889, \
-1148.11, 1.3775, 1.3775}, {{178.188, 254.563}, {912, 874.25}} -> {-247.556, \
-1148.11, 1.3775, 1.3775}, {{262.188, 338.5}, {912, 874.25}} -> {-363.223, \
-1148.11, 1.3775, 1.3775}, {{346.125, 422.5}, {912, 874.25}} -> {-478.89, \
-1148.11, 1.3775, 1.3775}, {{10.25, 86.625}, {870.438, 832.688}} -> \
{-16.2226, -1205.36, 1.3775, 1.3775}, {{94.25, 170.563}, {870.438, 832.688}} -> \
{-131.889, -1205.36, 1.3775, 1.3775}, {{178.188, 254.563}, {870.438, \
832.688}} -> {-247.556, -1205.36, 1.3775, 1.3775}, {{262.188, 338.5}, \
{870.438, 832.688}} -> {-363.223, -1205.36, 1.3775, 1.3775}, {{346.125, \
422.5}, {870.438, 832.688}} -> {-478.89, -1205.36, 1.3775, 1.3775}, {{10.25, \
86.625}, {828.875, 791.125}} -> {-16.2226, -1262.62, 1.3775, 1.3775}, \
{{94.25, 170.563}, {828.875, 791.125}} -> {-131.889, -1262.62, 1.3775, \
1.3775}, {{178.188, 254.563}, {828.875, 791.125}} -> {-247.556, -1262.62, \
1.3775, 1.3775}, {{262.188, 338.5}, {828.875, 791.125}} -> {-363.223, \
-1262.62, 1.3775, 1.3775}, {{346.125, 422.5}, {828.875, 791.125}} -> \
{-478.89, -1262.62, 1.3775, 1.3775}, {{10.25, 86.625}, {787.313, 749.563}} -> \
{-16.2226, -1319.87, 1.3775, 1.3775}, {{94.25, 170.563}, {787.313, 749.563}} -> \
{-131.889, -1319.87, 1.3775, 1.3775}, {{178.188, 254.563}, {787.313, \
749.563}} -> {-247.556, -1319.87, 1.3775, 1.3775}, {{262.188, 338.5}, \
{787.313, 749.563}} -> {-363.223, -1319.87, 1.3775, 1.3775}, {{346.125, \
422.5}, {787.313, 749.563}} -> {-478.89, -1319.87, 1.3775, 1.3775}, {{10.25, \
86.625}, {745.75, 707.938}} -> {-16.1177, -1374.96, 1.37533, 1.37533}, \
{{94.25, 170.563}, {745.75, 707.938}} -> {-131.752, -1376.11, 1.37646, \
1.37646}, {{178.188, 254.563}, {745.75, 707.938}} -> {-247.088, -1374.96, \
1.37533, 1.37533}, {{262.188, 338.5}, {745.75, 707.938}} -> {-362.911, \
-1376.11, 1.37646, 1.37646}, {{346.125, 422.5}, {745.75, 707.938}} -> \
{-478.058, -1374.96, 1.37533, 1.37533}, {{10.25, 86.625}, {704.188, 666.375}} -> \
{-16.1177, -1432.12, 1.37533, 1.37533}, {{94.25, 170.563}, {704.188, \
666.375}} -> {-131.752, -1433.32, 1.37646, 1.37646}, {{178.188, 254.563}, \
{704.188, 666.375}} -> {-247.088, -1432.12, 1.37533, 1.37533}, {{262.188, \
338.5}, {704.188, 666.375}} -> {-362.911, -1433.32, 1.37646, 1.37646}, \
{{346.125, 422.5}, {704.188, 666.375}} -> {-478.058, -1432.12, 1.37533, \
1.37533}, {{10.25, 86.625}, {662.625, 624.813}} -> {-16.1177, -1489.28, \
1.37533, 1.37533}, {{94.25, 170.563}, {662.625, 624.813}} -> {-131.752, \
-1490.53, 1.37646, 1.37646}, {{178.188, 254.563}, {662.625, 624.813}} -> \
{-247.088, -1489.28, 1.37533, 1.37533}, {{262.188, 338.5}, {662.625, \
624.813}} -> {-362.911, -1490.53, 1.37646, 1.37646}, {{346.125, 422.5}, \
{662.625, 624.813}} -> {-478.058, -1489.28, 1.37533, 1.37533}, {{10.25, \
86.625}, {621.063, 583.25}} -> {-16.1177, -1546.45, 1.37533, 1.37533}, \
{{94.25, 170.563}, {621.063, 583.25}} -> {-131.752, -1547.73, 1.37646, \
1.37646}, {{178.188, 254.563}, {621.063, 583.25}} -> {-247.088, -1546.45, \
1.37533, 1.37533}, {{262.188, 338.5}, {621.063, 583.25}} -> {-362.911, \
-1547.73, 1.37646, 1.37646}, {{346.125, 422.5}, {621.063, 583.25}} -> \
{-478.058, -1546.45, 1.37533, 1.37533}, {{10.25, 86.625}, {579.5, 541.688}} -> \
{-16.1177, -1603.61, 1.37533, 1.37533}, {{94.25, 170.563}, {579.5, 541.688}} -> \
{-131.752, -1604.94, 1.37646, 1.37646}, {{178.188, 254.563}, {579.5, \
541.688}} -> {-247.088, -1603.61, 1.37533, 1.37533}, {{262.188, 338.5}, \
{579.5, 541.688}} -> {-362.911, -1604.94, 1.37646, 1.37646}, {{346.125, \
422.5}, {579.5, 541.688}} -> {-478.058, -1603.61, 1.37533, 1.37533}, {{10.25, \
86.625}, {537.938, 500.125}} -> {-16.1177, -1660.77, 1.37533, 1.37533}, \
{{94.25, 170.563}, {537.938, 500.125}} -> {-131.752, -1662.15, 1.37646, \
1.37646}, {{178.188, 254.563}, {537.938, 500.125}} -> {-247.088, -1660.77, \
1.37533, 1.37533}, {{262.188, 338.5}, {537.938, 500.125}} -> {-362.911, \
-1662.15, 1.37646, 1.37646}, {{346.125, 422.5}, {537.938, 500.125}} -> \
{-478.058, -1660.77, 1.37533, 1.37533}, {{10.25, 86.625}, {496.375, 458.563}} -> \
{-16.1177, -1717.93, 1.37533, 1.37533}, {{94.25, 170.563}, {496.375, \
458.563}} -> {-131.752, -1719.36, 1.37646, 1.37646}, {{178.188, 254.563}, \
{496.375, 458.563}} -> {-247.088, -1717.93, 1.37533, 1.37533}, {{262.188, \
338.5}, {496.375, 458.563}} -> {-362.911, -1719.36, 1.37646, 1.37646}, \
{{346.125, 422.5}, {496.375, 458.563}} -> {-478.058, -1717.93, 1.37533, \
1.37533}, {{10.25, 86.625}, {454.813, 417}} -> {-16.1177, -1775.1, 1.37533, \
1.37533}, {{94.25, 170.563}, {454.813, 417}} -> {-131.752, -1776.57, 1.37646, \
1.37646}, {{178.188, 254.563}, {454.813, 417}} -> {-247.088, -1775.1, \
1.37533, 1.37533}, {{262.188, 338.5}, {454.813, 417}} -> {-362.911, -1776.57, \
1.37646, 1.37646}, {{346.125, 422.5}, {454.813, 417}} -> {-478.058, -1775.1, \
1.37533, 1.37533}, {{10.25, 86.625}, {413.188, 375.438}} -> {-16.2226, \
-1835.23, 1.3775, 1.3775}, {{94.25, 170.563}, {413.188, 375.438}} -> \
{-131.889, -1835.23, 1.3775, 1.3775}, {{178.188, 254.563}, {413.188, \
375.438}} -> {-247.556, -1835.23, 1.3775, 1.3775}, {{262.188, 338.5}, \
{413.188, 375.438}} -> {-363.223, -1835.23, 1.3775, 1.3775}, {{346.125, \
422.5}, {413.188, 375.438}} -> {-478.89, -1835.23, 1.3775, 1.3775}, {{10.25, \
86.625}, {371.625, 333.875}} -> {-16.2226, -1892.48, 1.3775, 1.3775}, \
{{94.25, 170.563}, {371.625, 333.875}} -> {-131.889, -1892.48, 1.3775, \
1.3775}, {{178.188, 254.563}, {371.625, 333.875}} -> {-247.556, -1892.48, \
1.3775, 1.3775}, {{262.188, 338.5}, {371.625, 333.875}} -> {-363.223, \
-1892.48, 1.3775, 1.3775}, {{346.125, 422.5}, {371.625, 333.875}} -> \
{-478.89, -1892.48, 1.3775, 1.3775}, {{10.25, 86.625}, {330.063, 292.313}} -> \
{-16.2226, -1949.73, 1.3775, 1.3775}, {{94.25, 170.563}, {330.063, 292.313}} -> \
{-131.889, -1949.73, 1.3775, 1.3775}, {{178.188, 254.563}, {330.063, \
292.313}} -> {-247.556, -1949.73, 1.3775, 1.3775}, {{262.188, 338.5}, \
{330.063, 292.313}} -> {-363.223, -1949.73, 1.3775, 1.3775}, {{346.125, \
422.5}, {330.063, 292.313}} -> {-478.89, -1949.73, 1.3775, 1.3775}, {{10.25, \
86.625}, {288.5, 250.75}} -> {-16.2226, -2006.98, 1.3775, 1.3775}, {{94.25, \
170.563}, {288.5, 250.75}} -> {-131.889, -2006.98, 1.3775, 1.3775}, \
{{178.188, 254.563}, {288.5, 250.75}} -> {-247.556, -2006.98, 1.3775, \
1.3775}, {{262.188, 338.5}, {288.5, 250.75}} -> {-363.223, -2006.98, 1.3775, \
1.3775}, {{346.125, 422.5}, {288.5, 250.75}} -> {-478.89, -2006.98, 1.3775, \
1.3775}, {{10.25, 86.625}, {246.938, 209.125}} -> {-16.1177, -2060.99, \
1.37533, 1.37533}, {{94.25, 170.563}, {246.938, 209.125}} -> {-131.752, \
-2062.7, 1.37646, 1.37646}, {{178.188, 254.563}, {246.938, 209.125}} -> \
{-247.088, -2060.99, 1.37533, 1.37533}, {{262.188, 338.5}, {246.938, \
209.125}} -> {-362.911, -2062.7, 1.37646, 1.37646}, {{346.125, 422.5}, \
{246.938, 209.125}} -> {-478.058, -2060.99, 1.37533, 1.37533}, {{10.25, \
86.625}, {205.375, 167.563}} -> {-16.1177, -2118.16, 1.37533, 1.37533}, \
{{94.25, 170.563}, {205.375, 167.563}} -> {-131.752, -2119.91, 1.37646, \
1.37646}, {{178.188, 254.563}, {205.375, 167.563}} -> {-247.088, -2118.16, \
1.37533, 1.37533}, {{262.188, 338.5}, {205.375, 167.563}} -> {-362.911, \
-2119.91, 1.37646, 1.37646}, {{346.125, 422.5}, {205.375, 167.563}} -> \
{-478.058, -2118.16, 1.37533, 1.37533}, {{10.25, 86.625}, {163.813, 126}} -> \
{-16.1177, -2175.32, 1.37533, 1.37533}, {{94.25, 170.563}, {163.813, 126}} -> \
{-131.752, -2177.12, 1.37646, 1.37646}, {{178.188, 254.563}, {163.813, 126}} -> \
{-247.088, -2175.32, 1.37533, 1.37533}, {{262.188, 338.5}, {163.813, 126}} -> \
{-362.911, -2177.12, 1.37646, 1.37646}, {{346.125, 422.5}, {163.813, 126}} -> \
{-478.058, -2175.32, 1.37533, 1.37533}, {{10.25, 86.625}, {122.25, 84.4375}} -> \
{-16.1177, -2232.48, 1.37533, 1.37533}, {{94.25, 170.563}, {122.25, 84.4375}} -> \
{-131.752, -2234.33, 1.37646, 1.37646}, {{178.188, 254.563}, {122.25, \
84.4375}} -> {-247.088, -2232.48, 1.37533, 1.37533}, {{262.188, 338.5}, \
{122.25, 84.4375}} -> {-362.911, -2234.33, 1.37646, 1.37646}, {{346.125, \
422.5}, {122.25, 84.4375}} -> {-478.058, -2232.48, 1.37533, 1.37533}, \
{{10.25, 86.625}, {80.6875, 42.875}} -> {-16.1177, -2289.64, 1.37533, \
1.37533}, {{94.25, 170.563}, {80.6875, 42.875}} -> {-131.752, -2291.54, \
1.37646, 1.37646}, {{178.188, 254.563}, {80.6875, 42.875}} -> {-247.088, \
-2289.64, 1.37533, 1.37533}, {{262.188, 338.5}, {80.6875, 42.875}} -> \
{-362.911, -2291.54, 1.37646, 1.37646}, {{346.125, 422.5}, {80.6875, 42.875}} -> \
{-478.058, -2289.64, 1.37533, 1.37533}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["REVERSIBLE AUTOMATA", "Section"],

Cell["\<\
A pattern having no predecessor under a given rule is called a Garden-of-Eden \
pattern [4]. Once it is attained, it is never entered into again in all \
future generations. One of the basic questions on CA concerns the \
reversibility of the global rule. In the following, we select all reversible \
dyadic CA up to generation 50:\
\>", "Text"],

Cell[BoxData[{
    \(ancestor[_, {}, _] := {}\), "\[IndentingNewLine]", 
    \(ancestor[b_, cS_, r_] := 
      Module[{t, ri, i, le, q}, \[IndentingNewLine]t = 
          Map[Flatten[Position[r, #]] &, 
            cS]; \[IndentingNewLine]t\[LeftDoubleBracket]1\
\[RightDoubleBracket] = \(t\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket] = \
{1}\); \ \[IndentingNewLine]Do[\[IndentingNewLine]ri = \(Take[
                  IntegerDigits[# - 1, b, 3], \(-2\)] &\)\  /@ \ 
              t\[LeftDoubleBracket]i - 
                  1\[RightDoubleBracket]; \[IndentingNewLine]t\
\[LeftDoubleBracket]i\[RightDoubleBracket] = 
            Select[t\[LeftDoubleBracket]i\[RightDoubleBracket], 
              MemberQ[ri, 
                  Take[IntegerDigits[# - 1, b, 3], 
                    2]] &], \[IndentingNewLine]{i, 2, 
            Length[t] - 
              1}]; \ \[IndentingNewLine]Do[\[IndentingNewLine]le = \(Take[
                  IntegerDigits[# - 1, b, 3], 2] &\)\  /@ \ 
              t\[LeftDoubleBracket]i + 
                  1\[RightDoubleBracket]; \[IndentingNewLine]t\
\[LeftDoubleBracket]i\[RightDoubleBracket] = 
            Select[t\[LeftDoubleBracket]i\[RightDoubleBracket], 
              MemberQ[le, Take[IntegerDigits[# - 1, b, 3], \(-2\)]] &], {i, 
            Length[t] - 1, 2, \(-1\)}]; \ \[IndentingNewLine]t = 
          Map[\(IntegerDigits[# - 1, b, 
                  3]\)\[LeftDoubleBracket]2\[RightDoubleBracket] &, 
            t, {2}]; \[IndentingNewLine]t = \(Union[#] &\)\  /@ \ 
            t; \[IndentingNewLine]q = 
          And\  @@ \ \((\(\((Length[#] == 1)\) &\)\  /@ \ 
                t)\); \[IndentingNewLine]If[q, 
          Flatten[t], {0}]]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(reversibleQ[b_, cS_, r_, gen_] := 
      Module[{t = 
            Nest[Flatten[ancestor[b, #, r]] &, cS, 
              gen]}, \[IndentingNewLine]\((\((Plus\  @@ \ t)\) == 
            1)\)]\)}], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(allRules = << allRules2;\)\), "\[IndentingNewLine]", 
    \(\(b = 2;\)\), "\[IndentingNewLine]", 
    \(\(gen = 50;\)\), "\[IndentingNewLine]", 
    \(\(cS = cellularSpace[110];\)\), "\[IndentingNewLine]", 
    \(\(r = 
        Select[allRules, \[IndentingNewLine]\((v = 
                evolve[b, cS, #, gen]; \[IndentingNewLine]reversibleQ[b, 
                Last[v], #, gen])\) &];\)\), "\[IndentingNewLine]", 
    \(\(g = 
        Map[showCA[b, cS, #, gen, 1, 1, 110, 2] &, 
          r];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Partition[g, 1]], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.45455 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0584416 0.952381 [
[ 0 0 0 0 ]
[ 1 2.45455 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 2.45455 L
0 2.45455 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0584416 0.97619 0.491342 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00874126 0.00874126 0.00874126 [
[.5 .46705 -11 0 ]
[.5 .46705 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .45455 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .46705 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(110) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .45455 L
0 .45455 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00874 translate
.96154 .43706 scale
110 string
110 50 8 [110 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFF000000FF00FF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF00FF00
000000FFFFFF0000FF00FF00000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFF
FFFF
FFFFFFFFFFFF00FFFFFF0000FF00FF00000000FFFFFF0000FF00FF00000000FFFFFF0000
FF00FF00000000FFFFFF0000FF00FF00000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFF
FFFF
FFFFFFFFFFFFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF00FF00000000FF
FFFF0000FF00FF00000000FFFFFF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFF00FFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF00FF00
000000FFFFFF0000FF00FF00000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFF000000FF00FF00000000FFFFFF0000FF00FF00000000FFFFFF0000
FF00FF00000000FFFFFF0000FF00FF00000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF00000000FFFFFF0000FF00FF00000000FF
FFFF0000FF00FF00000000FFFFFF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000FF00FF00
000000FFFFFF0000FF00FF00000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000
FF00FF00000000FFFFFF0000FF00FF00000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00000000FFFFFF0000FF00FF00000000FF
FFFF0000FF00FF00000000FFFFFF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF00000000FFFFFF0000FF00FF00
000000FFFFFF0000FF00FF00000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FF00FF00000000FFFFFF0000
FF00FF00000000FFFFFF0000FF00FF00000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FFFFFF0000FF00FF00000000FF
FFFF0000FF00FF00000000FFFFFF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00000000FFFFFF0000FF00FF00
000000FFFFFF0000FF00FF00000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF00000000FFFFFF0000
FF00FF00000000FFFFFF0000FF00FF00000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FF00FF00000000FF
FFFF0000FF00FF00000000FFFFFF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FFFFFF0000FF00FF00
000000FFFFFF0000FF00FF00000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00000000FFFFFF0000
FF00FF00000000FFFFFF0000FF00FF00000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF00000000FF
FFFF0000FF00FF00000000FFFFFF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FF00FF00
000000FFFFFF0000FF00FF00000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FFFFFF0000
FF00FF00000000FFFFFF0000FF00FF00000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00000000FF
FFFF0000FF00FF00000000FFFFFF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF00
000000FFFFFF0000FF00FF00000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000
FF00FF00000000FFFFFF0000FF00FF00000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FF
FFFF0000FF00FF00000000FFFFFF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF00
000000FFFFFF0000FF00FF00000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000
FF00FF00000000FFFFFF0000FF00FF00000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFF0000FF00FF00000000FFFFFF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00
000000FFFFFF0000FF00FF00000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FF00FF00000000FFFFFF0000FF00FF00000000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFF0000FF00FF00000000FFFFFF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFF0000FF00FF00000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFF00000000FFFFFF0000FF00FF00000000FF0000FF0000FF0000FF0000FF0000FF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FF00FF00000000FFFFFF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFF0000FF00FF00000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFF0000FF00FF00000000FF0000FF0000FF0000FF0000FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF00000000FFFFFF0000FF00FF0000FF0000FF0000FF0000FF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF00FF00000000FFFFFF0000FF0000FF0000FF0000FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF0000FF00FF00000000FF0000FF0000FF0000FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFF0000FF00FF0000FF0000FF0000FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFF00000000FFFFFF0000FF0000FF0000FF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF00FF00000000FF0000FF0000FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF0000FF0000FF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFF00000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.534632 0.97619 0.967532 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00874126 0.00874126 0.00874126 [
[.5 .46705 -11 0 ]
[.5 .46705 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .45455 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .46705 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(106) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .45455 L
0 .45455 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00874 translate
.96154 .43706 scale
110 string
110 50 8 [110 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFF000000FFFFFFFF00FF00FF00FF00000000FFFF0000FFFF0000FFFFFFFFFF00
FF0000000000000000FFFFFF0000FF000000FF0000FFFFFFFFFF0000000000FFFFFFFFFF
FF0000FF0000FFFFFFFF0000FF00FFFFFF000000FFFF0000FF00000000FF0000FFFFFFFF
FFFF
FFFFFFFFFFFF00FFFFFFFFFFFF0000FF00FF00FFFF00FF0000FFFFFFFF00FF0000000000
FF00FFFF00FFFF00FFFFFFFFFF00FF00FFFF0000FFFFFFFFFFFFFF00FFFF00FF00000000
0000FFFFFF00FF00000000FFFFFF00000000FFFF000000FFFFFF00FFFF0000FFFFFFFFFF
FFFF
FFFFFFFFFFFFFF00000000000000FFFFFF0000FF0000FF00FFFFFFFFFFFF0000FFFF00FF
FFFF000000FF0000FF0000000000FF00FF0000FFFFFFFFFFFFFFFFFF000000FF00FFFF00
FFFF00000000FF00FFFF00FF000000FFFF00FF0000FFFF00000000FF0000FFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFF00FFFF00FFFF00000000FFFFFF00FF00FF000000000000FFFFFFFF00
000000FFFF0000FFFFFF00FFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF000000
FF0000FFFF00FF00FF0000FF00FFFF000000FF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFF000000FF0000FFFF00FF000000FF00FF00FFFF00FFFF0000000000
FFFF00FF0000FFFFFFFFFF000000FF00FF00FF0000000000000000000000FF000000FFFF
0000FFFFFFFF0000FF00FFFFFF000000FFFF0000FF00000000FF0000FFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFF00FF0000FF00FFFF0000FF00FF0000FF0000FFFF00FF
FFFFFF0000FFFFFFFFFFFFFF00FFFFFF0000FF00FFFF00FFFF00FFFF00FFFFFF00FFFFFF
FF00FF00000000FFFFFF00000000FFFF000000FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FF00FFFFFF000000FFFFFF0000FFFFFF00FF0000FF
00000000FFFFFFFFFFFFFFFFFF00000000FFFFFF000000FF0000FF0000FF000000FF0000
0000FF00FFFF00FF000000FFFF00FF0000FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FF000000FFFF00000000FFFFFFFFFF0000FFFF
FF00FFFF00000000000000000000FFFF00FF000000FFFF0000FFFFFF00FF00FFFF0000FF
FF00FF00FF0000FF00FFFF000000FF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00FFFFFFFF00FFFF000000000000FFFFFF
FFFF000000FFFF00FFFF00FFFF00FF0000FF00FFFF000000FFFFFFFFFF0000FF0000FFFF
FFFF0000FF00FFFFFF000000FFFF0000FF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000000000FF0000FFFF00FFFF000000
000000FFFF000000FF0000FF0000FF00FFFFFF000000FFFF000000000000FFFFFF00FF00
000000FFFFFF00000000FFFF000000FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFF00FFFFFF00FF0000FF0000FFFF
00FFFF000000FFFF0000FFFFFF00FF00FF000000FFFF000000FFFF00FFFF00000000FF00
FFFF00FF000000FFFF00FF0000FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFF00000000FF00FFFFFF00FF00
00FF0000FFFF000000FFFFFFFFFF0000FF00FFFF000000FFFF000000FF0000FFFF00FF00
FF0000FF00FFFF000000FF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00000000FFFF00FF00FF000000FF00
FFFFFF00FF0000FFFF000000000000FFFFFF000000FFFF000000FFFF0000FFFFFFFF0000
FF00FFFFFF000000FFFF0000FF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF000000FF00FF00FFFF0000
FF000000FF00FFFFFFFF00FFFF00FFFFFFFFFF00FFFFFFFF00FFFFFFFF00FF00000000FF
FFFF00000000FFFF000000FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF0000FFFF0000FF00FF0000FF
FFFF00FFFFFF0000000000FF0000FF0000000000FF00000000FF00000000FF00FFFF00FF
000000FFFF00FF0000FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFFFF00FF00FF00FFFF
FFFFFF00000000FFFF00FFFFFF00FF00FFFF00FFFFFF00FFFF0000FFFF00FF00FF0000FF
00FFFF000000FF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF0000FF00FF00
00000000FFFF00FF0000FF000000FF00FF0000FF000000FF0000FFFFFFFF0000FF00FFFF
FF000000FFFF0000FF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FF00FF00
FFFF00FFFFFFFF0000FFFFFF00FFFFFF0000FFFFFF00FFFFFF00FF00000000FFFFFF0000
0000FFFF000000FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FF00FF00
FF0000FF00000000FFFFFFFFFF00000000FFFFFFFFFF00000000FF00FFFF00FF000000FF
FF00FF0000FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFF00FFFFFF0000
FF00FFFFFF00FFFF000000000000FFFF00FF0000000000FFFF00FF00FF0000FF00FFFF00
0000FF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FF000000FF
FFFF00000000FF0000FFFF00FFFF000000FF00FFFF00FFFFFFFF0000FF00FFFFFF000000
FFFF0000FF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00FFFF00
000000FFFF00FF00FFFFFFFF000000FFFF0000FF0000FF00000000FFFFFF00000000FFFF
000000FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00FF0000
FFFF00FF0000FF00FF00000000FFFF000000FFFFFF00FF00FFFF00FF000000FFFF00FF00
00FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FF00FF
FFFFFF0000FFFFFF0000FFFF00FF0000FFFF00000000FF00FF0000FF00FFFF000000FF00
FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00
00000000FFFFFFFFFF00FF0000FF00FFFFFFFF00FFFF0000FF00FFFFFF000000FFFF0000
FF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
00FFFF00FF0000000000FF00FFFFFF0000000000FF0000FFFFFF00000000FFFF000000FF
FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
00FF0000FF00FFFF00FFFFFF00000000FFFF00FFFFFF00FF000000FFFF00FF0000FFFF00
000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00
FFFFFF00FF00FF0000FF000000FFFF00FF0000FF000000FF00FFFF000000FF00FFFFFFFF
00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FF000000FF00FF00FFFFFF00FFFFFFFF0000FFFFFF00FFFFFF000000FFFF0000FF000000
00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFF00FFFFFF0000FF000000FF00000000FFFFFFFFFF00000000FFFF000000FFFFFF00FF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FF000000FFFFFF00FFFFFF00FFFF000000000000FFFF00FF0000FFFF00000000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFF0000FFFF00000000FF000000FF0000FFFF00FFFF000000FF00FFFFFFFF00FFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFF00FFFF0000FFFF0000FFFFFFFF000000FFFF0000FF00000000FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFF000000FFFFFFFF00FF00000000FFFF000000FFFFFF00FFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000000000FFFF0000000000FF00FFFF00FF0000FFFF00000000FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF00FFFF000000FFFF00FFFFFF000000FF00FFFFFFFF00FFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF0000FFFF000000FF000000FFFF0000FF00000000FF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF00FF0000FFFF0000FFFF000000FFFFFF00FFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FF00FFFFFFFF00FF0000FFFF00000000FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFF0000FF00000000FF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFF00FFFF0000FF00000000FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF000000FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000000000FFFF00000000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.01082 0.97619 1.44372 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00874126 0.00874126 0.00874126 [
[.5 .46705 -11 0 ]
[.5 .46705 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .45455 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .46705 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(105) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .45455 L
0 .45455 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00874 translate
.96154 .43706 scale
110 string
110 50 8 [110 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFF
FFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FF00FFFFFF00FF00FFFFFF00FF
00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF
00FF00FFFFFF00FF00FFFFFF00FF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFFFF000000FFFFFFFFFF000000FF000000
FFFFFFFFFF000000FF000000FFFFFFFFFF000000FFFFFFFFFF000000FF000000FFFFFFFF
FF000000FF000000FFFFFFFFFF000000FFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFF00FF
FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFF
FFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FF0000FF00FF0000FF0000FF00FF0000FFFF
FFFFFFFFFFFFFF0000FF00FF0000FF0000FF00FF0000FF0000FF00FF0000FFFFFFFFFFFF
FFFFFF0000FF00FF0000FF0000FF00FF0000FF0000FF00FF0000FFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF000000FF0000FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF0000FF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF0000FF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FF00FFFFFF
00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF
00FFFFFF00FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FFFFFFFF
FF000000FF000000FFFFFFFFFF000000FF000000FF000000FFFFFFFFFF000000FF000000
FFFFFFFFFF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFF
FFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FF
FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FF00
00FF00FF0000FFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFF0000FF00FF
0000FF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFF
00FF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FF
00FFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000
FF000000FF0000FF0000FF0000FF0000FF000000FF0000FF0000FF0000FF0000FF000000
FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF
FFFF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF
FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FF000000FF000000FFFFFFFFFF000000FF000000FF000000FFFFFFFFFF000000FF000000
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFF00FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF00FF0000FFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFF0000FF00FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF00FF00FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF0000FF0000FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FF000000FFFFFFFFFF000000FFFFFFFFFF000000FF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF00FF0000FF0000FF00FF0000FF0000FF00FF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFF00FF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF0000FF000000FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.48701 0.97619 1.91991 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00874126 0.00874126 0.00874126 [
[.5 .46705 -8 0 ]
[.5 .46705 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .45455 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .46705 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .45455 L
0 .45455 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00874 translate
.96154 .43706 scale
110 string
110 50 8 [110 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000FFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FF00FF
00FF00FF00FF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFF00FF
FFFF00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFF0000
0000FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFF00FF
00FFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFF0000
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFF00FF
00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FF00FF00FF00FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFF00FFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.9632 0.97619 2.3961 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00874126 0.00874126 0.00874126 [
[.5 .46705 -8 0 ]
[.5 .46705 8 12.875 ]
[ 0 0 0 0 ]
[ 1 .45455 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .46705 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(59) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .45455 L
0 .45455 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00874 translate
.96154 .43706 scale
110 string
110 50 8 [110 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000FFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000FFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
00000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
00000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{240.313, 589.813},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003`0002CB000`400?l00000o`00003ol03AcJT0
0?00dLfY003`0=7=Z@00l03AcJT00?00dLfY003`0=7=Z@00l03AcJT00?00dLfY003`0=7=Z@00l03A
cJT00?00dLfY003`0=7=Z@00l03AcJT00?00dLfY003`0=7=Z@00l03AcJT00?00dLfY000J0=7=Z@T0
oooo1@0000000`3oool00000000000020?ooo`L000001@3oool300000080oooo00<000000?ooo`3o
ool01`0000050?ooo`<000000P3oool200000080oooo1P0000050?ooo`@000000P3oool00`000000
oooo0?ooo`07000000D0oooo0`0000020?ooo`<000000P3oool300000080oooo100000000`3oool0
000000000002000000030?ooo`00000000000080000000<0oooo0000000000000P0000020?ooo`<0
00000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000080oooo0`0000020?ooo`@0
000000<0oooo0000000000000P0000000`3oool0000000000002000000030?ooo`00000000000080
00002P3ooolK0=7=Z@006P3AcJT90?ooo`D0000000<0oooo0000000000000P3oool7000000D0oooo
0`0000020?ooo`030000003oool0oooo00L000001@3oool300000080oooo0P0000020?ooo`H00000
1@3oool400000080oooo00<000000?ooo`3oool01`0000050?ooo`<000000P3oool300000080oooo
0`0000020?ooo`@0000000<0oooo0000000000000P0000000`3oool0000000000002000000030?oo
o`0000000000008000000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000080oooo
0`0000020?ooo`<000000P3oool4000000030?ooo`00000000000080000000<0oooo000000000000
0P0000000`3oool0000000000002000000X0oooo6`3AcJT001X0dLfY2P3oool2000000D0oooo0`00
00020?ooo`8000000P3oool6000000D0oooo100000020?ooo`030000003oool0oooo00L000001@3o
ool300000080oooo0P0000000`3oool0000000000005000000D0oooo100000000`3oool000000000
00020?ooo`L0000000<0oooo0000000000000P0000000`3oool0000000000002000000030?ooo`00
00000000008000000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000080oooo0`00
00020?ooo`<000000P3oool4000000030?ooo`00000000000080000000<0oooo0000000000000P00
00000`3oool000000000000200000080oooo0`0000020?ooo`<000000P3oool3000000`0oooo6`3A
cJT001X0dLfY303oool7000000D0oooo0`0000020?ooo`80000000<0oooo0000000000001@000005
0?ooo`@0000000<0oooo0000000000000P3oool7000000D0oooo0`0000020?ooo`030000003oool0
oooo00L000001@3oool300000080oooo0P0000020?ooo`<000000P3oool300000080oooo0`000002
0?ooo`<000000P3oool300000080oooo0`0000020?ooo`@0000000<0oooo0000000000000P000000
0`3oool0000000000002000000030?ooo`0000000000008000000P3oool300000080oooo0`000002
0?ooo`<000000P3oool300000080oooo0`0000020?ooo`<000003P3ooolK0=7=Z@006P3AcJT<0?oo
o`L000001@3oool300000080oooo0P0000000`3oool0000000000005000000D0oooo100000000`3o
ool00000000000020?ooo`L000001@3oool300000080oooo00<000000?ooo`3oool01`0000050?oo
o`<000000P3oool200000080oooo0`0000020?ooo`<000000P3oool300000080oooo0`0000020?oo
o`<000000P3oool300000080oooo100000000`3oool0000000000002000000030?ooo`0000000000
0080000000<0oooo0000000000000P0000020?ooo`<000000P3oool300000080oooo0`0000020?oo
o`<000000P3oool300000080oooo0`00000>0?oooa/0dLfY000J0=7=Z@h0oooo00<000000?ooo`3o
ool00P3oool7000000D0oooo0`0000020?ooo`030000003oool0oooo00L000001@3oool300000080
oooo0P0000020?ooo`H000001@3oool400000080oooo00<000000?ooo`3oool01`0000050?ooo`<0
00000P3oool300000080oooo0`0000020?ooo`@0000000<0oooo0000000000000P0000000`3oool0
000000000002000000030?ooo`0000000000008000000P3oool300000080oooo0`0000020?ooo`<0
00000P3oool300000080oooo0`0000020?ooo`<000000P3oool4000000030?ooo`00000000000080
000000<0oooo0000000000000P00000?0?oooa/0dLfY000J0=7=Z@h0oooo00<000000?ooo`3oool0
0P3oool7000000D0oooo0`0000020?ooo`030000003oool0oooo00L000001@3oool300000080oooo
0P0000020?ooo`H000001@3oool400000080oooo00<000000?ooo`3oool01`0000050?ooo`<00000
0P3oool300000080oooo0`0000020?ooo`@0000000<0oooo0000000000000P0000000`3oool00000
00000002000000030?ooo`0000000000008000000P3oool300000080oooo0`0000020?ooo`<00000
0P3oool300000080oooo0`0000020?ooo`<000000P3oool4000000030?ooo`000000000000800000
00<0oooo0000000000000P00000?0?oooa/0dLfY000J0=7=Z@l0oooo1@0000020?ooo`8000000P3o
ool6000000D0oooo100000020?ooo`030000003oool0oooo00L000001@3oool300000080oooo0P00
00000`3oool0000000000005000000D0oooo100000000`3oool00000000000020?ooo`L0000000<0
oooo0000000000000P0000000`3oool0000000000002000000030?ooo`0000000000008000000P3o
ool300000080oooo0`0000020?ooo`<000000P3oool300000080oooo0`0000020?ooo`<000000P3o
ool4000000030?ooo`00000000000080000000<0oooo0000000000000P0000000`3oool000000000
000200000080oooo0`0000020?ooo`<000004@3ooolK0=7=Z@006P3AcJT?0?ooo`D000000P3oool2
00000080oooo1P0000050?ooo`@000000P3oool00`000000oooo0?ooo`07000000D0oooo0`000002
0?ooo`80000000<0oooo0000000000001@0000050?ooo`@0000000<0oooo0000000000000P3oool7
000000030?ooo`00000000000080000000<0oooo0000000000000P0000000`3oool0000000000002
00000080oooo0`0000020?ooo`<000000P3oool300000080oooo0`0000020?ooo`<000000P3oool3
00000080oooo100000000`3oool0000000000002000000030?ooo`00000000000080000000<0oooo
0000000000000P0000020?ooo`<000000P3oool300000140oooo6`3AcJT001X0dLfY4@3oool20000
00D0oooo0`0000020?ooo`80000000<0oooo0000000000001@0000050?ooo`@0000000<0oooo0000
000000000P3oool7000000D0oooo0`0000020?ooo`030000003oool0oooo00L000001@3oool30000
0080oooo0P0000020?ooo`<000000P3oool300000080oooo0`0000020?ooo`<000000P3oool30000
0080oooo0`0000020?ooo`@0000000<0oooo0000000000000P0000000`3oool00000000000020000
00030?ooo`0000000000008000000P3oool300000080oooo0`0000020?ooo`<000000P3oool30000
0080oooo0`00000C0?oooa/0dLfY000J0=7=ZA<0oooo1`0000050?ooo`<000000P3oool00`000000
oooo0?ooo`07000000D0oooo0`0000020?ooo`8000000P3oool6000000D0oooo100000020?ooo`03
0000003oool0oooo00L000001@3oool300000080oooo0`0000020?ooo`<000000P3oool400000003
0?ooo`00000000000080000000<0oooo0000000000000P0000000`3oool000000000000200000080
oooo0`0000020?ooo`<000000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000080
oooo100000000`3oool0000000000002000001@0oooo6`3AcJT001X0dLfY4`3oool7000000D0oooo
0`0000020?ooo`030000003oool0oooo00L000001@3oool300000080oooo0P0000020?ooo`H00000
1@3oool400000080oooo00<000000?ooo`3oool01`0000050?ooo`<000000P3oool300000080oooo
0`0000020?ooo`@0000000<0oooo0000000000000P0000000`3oool0000000000002000000030?oo
o`0000000000008000000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000080oooo
0`0000020?ooo`<000000P3oool4000000030?ooo`000000000000800000503ooolK0=7=Z@006P3A
cJTD0?ooo`800000103oool6000000D0oooo100000020?ooo`030000003oool0oooo00L000001@3o
ool300000080oooo0P0000000`3oool0000000000005000000D0oooo100000000`3oool000000000
00020?ooo`L0000000<0oooo0000000000000P0000000`3oool0000000000002000000030?ooo`00
00000000008000000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000080oooo0`00
00020?ooo`<000000P3oool4000000030?ooo`00000000000080000000<0oooo0000000000000P00
00000`3oool000000000000200000080oooo0`00000F0?oooa/0dLfY000J0=7=ZA@0oooo0P000004
0?ooo`H000001@3oool400000080oooo00<000000?ooo`3oool01`0000050?ooo`<000000P3oool2
000000030?ooo`000000000000D000001@3oool4000000030?ooo`00000000000080oooo1`000000
0`3oool0000000000002000000030?ooo`00000000000080000000<0oooo0000000000000P000002
0?ooo`<000000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000080oooo0`000002
0?ooo`@0000000<0oooo0000000000000P0000000`3oool0000000000002000000030?ooo`000000
0000008000000P3oool3000001H0oooo6`3AcJT001X0dLfY5P3oool500000080oooo0P0000000`3o
ool0000000000005000000D0oooo100000000`3oool00000000000020?ooo`L000001@3oool30000
0080oooo00<000000?ooo`3oool01`0000050?ooo`<000000P3oool200000080oooo0`0000020?oo
o`<000000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000080oooo100000000`3o
ool0000000000002000000030?ooo`00000000000080000000<0oooo0000000000000P0000020?oo
o`<000000P3oool300000080oooo0`0000020?ooo`<00000603ooolK0=7=Z@006P3AcJTH0?ooo`80
00001@3oool300000080oooo00<000000?ooo`3oool01`0000050?ooo`<000000P3oool200000080
oooo1P0000050?ooo`@000000P3oool00`000000oooo0?ooo`07000000D0oooo0`0000020?ooo`<0
00000P3oool300000080oooo100000000`3oool0000000000002000000030?ooo`00000000000080
000000<0oooo0000000000000P0000020?ooo`<000000P3oool300000080oooo0`0000020?ooo`<0
00000P3oool300000080oooo0`0000020?ooo`@000006@3ooolK0=7=Z@006P3AcJTH0?ooo`800000
1@3oool300000080oooo00<000000?ooo`3oool01`0000050?ooo`<000000P3oool200000080oooo
1P0000050?ooo`@000000P3oool00`000000oooo0?ooo`07000000D0oooo0`0000020?ooo`<00000
0P3oool300000080oooo100000000`3oool0000000000002000000030?ooo`000000000000800000
00<0oooo0000000000000P0000020?ooo`<000000P3oool300000080oooo0`0000020?ooo`<00000
0P3oool300000080oooo0`0000020?ooo`@000006@3ooolK0=7=Z@006P3AcJTJ0?ooo`H000001@3o
ool400000080oooo00<000000?ooo`3oool01`0000050?ooo`<000000P3oool2000000030?ooo`00
0000000000D000001@3oool4000000030?ooo`00000000000080oooo1`0000000`3oool000000000
0002000000030?ooo`00000000000080000000<0oooo0000000000000P0000020?ooo`<000000P3o
ool300000080oooo0`0000020?ooo`<000000P3oool300000080oooo0`0000020?ooo`@0000000<0
oooo0000000000000P0000000`3oool0000000000002000000030?ooo`0000000000008000006`3o
oolK0=7=Z@006P3AcJTJ0?ooo`H000001@3oool400000080oooo00<000000?ooo`3oool01`000005
0?ooo`<000000P3oool2000000030?ooo`000000000000D000001@3oool4000000030?ooo`000000
00000080oooo1`0000000`3oool0000000000002000000030?ooo`00000000000080000000<0oooo
0000000000000P0000020?ooo`<000000P3oool300000080oooo0`0000020?ooo`<000000P3oool3
00000080oooo0`0000020?ooo`@0000000<0oooo0000000000000P0000000`3oool0000000000002
000000030?ooo`0000000000008000006`3ooolK0=7=Z@006P3AcJTK0?ooo`8000000`3oool70000
00D0oooo100000000`3oool00000000000020?ooo`L000001@3oool300000080oooo00<000000?oo
o`3oool01`0000050?ooo`<000000P3oool200000080oooo0`0000020?ooo`<000000P3oool30000
0080oooo0`0000020?ooo`<000000P3oool300000080oooo100000000`3oool00000000000020000
00030?ooo`00000000000080000000<0oooo0000000000000P0000020?ooo`<000000P3oool30000
0080oooo0`00000M0?oooa/0dLfY000J0=7=ZAd0oooo1@0000020?ooo`030000003oool0oooo00L0
00001@3oool300000080oooo0P0000020?ooo`H000001@3oool400000080oooo00<000000?ooo`3o
ool01`0000050?ooo`<000000P3oool300000080oooo0`0000020?ooo`@0000000<0oooo00000000
00000P0000000`3oool0000000000002000000030?ooo`0000000000008000000P3oool300000080
oooo0`0000020?ooo`<000000P3oool300000080oooo0`0000020?ooo`<000007`3ooolK0=7=Z@00
6P3AcJTM0?ooo`D000000P3oool00`000000oooo0?ooo`07000000D0oooo0`0000020?ooo`800000
0P3oool6000000D0oooo100000020?ooo`030000003oool0oooo00L000001@3oool300000080oooo
0`0000020?ooo`<000000P3oool4000000030?ooo`00000000000080000000<0oooo000000000000
0P0000000`3oool000000000000200000080oooo0`0000020?ooo`<000000P3oool300000080oooo
0`0000020?ooo`<000000P3oool3000001l0oooo6`3AcJT001X0dLfY7`3oool00`000000oooo0?oo
o`030?ooo`@000000P3oool00`000000oooo0?ooo`07000000D0oooo0`0000020?ooo`80000000<0
oooo0000000000001@0000050?ooo`@0000000<0oooo0000000000000P3oool7000000030?ooo`00
000000000080000000<0oooo0000000000000P0000000`3oool000000000000200000080oooo0`00
00020?ooo`<000000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000080oooo1000
00000`3oool0000000000002000000030?ooo`000000000000800000803ooolK0=7=Z@006P3AcJTO
0?ooo`030000003oool0oooo00<0oooo100000020?ooo`030000003oool0oooo00L000001@3oool3
00000080oooo0P0000000`3oool0000000000005000000D0oooo100000000`3oool0000000000002
0?ooo`L0000000<0oooo0000000000000P0000000`3oool0000000000002000000030?ooo`000000
0000008000000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000080oooo0`000002
0?ooo`<000000P3oool4000000030?ooo`00000000000080000000<0oooo0000000000000P00000P
0?oooa/0dLfY000J0=7=ZB00oooo1`0000050?ooo`@0000000<0oooo0000000000000P3oool70000
00D0oooo0`0000020?ooo`030000003oool0oooo00L000001@3oool300000080oooo0P0000020?oo
o`<000000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000080oooo0`0000020?oo
o`@0000000<0oooo0000000000000P0000000`3oool0000000000002000000030?ooo`0000000000
008000000P3oool300000080oooo0`00000R0?oooa/0dLfY000J0=7=ZB00oooo1`0000050?ooo`@0
000000<0oooo0000000000000P3oool7000000D0oooo0`0000020?ooo`030000003oool0oooo00L0
00001@3oool300000080oooo0P0000020?ooo`<000000P3oool300000080oooo0`0000020?ooo`<0
00000P3oool300000080oooo0`0000020?ooo`@0000000<0oooo0000000000000P0000000`3oool0
000000000002000000030?ooo`0000000000008000000P3oool300000080oooo0`00000R0?oooa/0
dLfY000J0=7=ZB80oooo0P0000030?ooo`L000001@3oool300000080oooo0P0000020?ooo`H00000
1@3oool400000080oooo00<000000?ooo`3oool01`0000050?ooo`<000000P3oool300000080oooo
0`0000020?ooo`@0000000<0oooo0000000000000P0000000`3oool0000000000002000000030?oo
o`0000000000008000000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000080oooo
0`00000T0?oooa/0dLfY000J0=7=ZB@0oooo1@0000020?ooo`030000003oool0oooo00L000001@3o
ool300000080oooo0P0000000`3oool0000000000005000000D0oooo100000000`3oool000000000
00020?ooo`L0000000<0oooo0000000000000P0000000`3oool0000000000002000000030?ooo`00
00000000008000000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000080oooo0`00
00020?ooo`<000000P3oool4000000030?ooo`0000000000008000009@3ooolK0=7=Z@006P3AcJTT
0?ooo`D000000P3oool00`000000oooo0?ooo`07000000D0oooo0`0000020?ooo`80000000<0oooo
0000000000001@0000050?ooo`@0000000<0oooo0000000000000P3oool7000000030?ooo`000000
00000080000000<0oooo0000000000000P0000000`3oool000000000000200000080oooo0`000002
0?ooo`<000000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000080oooo10000000
0`3oool0000000000002000002D0oooo6`3AcJT001X0dLfY9@3oool2000000D0oooo100000000`3o
ool00000000000020?ooo`L000001@3oool300000080oooo00<000000?ooo`3oool01`0000050?oo
o`<000000P3oool200000080oooo0`0000020?ooo`<000000P3oool300000080oooo0`0000020?oo
o`<000000P3oool300000080oooo100000000`3oool0000000000002000000030?ooo`0000000000
0080000000<0oooo0000000000000P0000020?ooo`<000009`3ooolK0=7=Z@006P3AcJTU0?ooo`80
00001@3oool4000000030?ooo`00000000000080oooo1`0000050?ooo`<000000P3oool00`000000
oooo0?ooo`07000000D0oooo0`0000020?ooo`8000000P3oool300000080oooo0`0000020?ooo`<0
00000P3oool300000080oooo0`0000020?ooo`<000000P3oool4000000030?ooo`00000000000080
000000<0oooo0000000000000P0000000`3oool000000000000200000080oooo0`00000W0?oooa/0
dLfY000J0=7=ZBL0oooo1`0000050?ooo`<000000P3oool200000080oooo1P0000050?ooo`@00000
0P3oool00`000000oooo0?ooo`07000000D0oooo0`0000020?ooo`<000000P3oool300000080oooo
100000000`3oool0000000000002000000030?ooo`00000000000080000000<0oooo000000000000
0P0000020?ooo`<000000P3oool300000080oooo0`0000020?ooo`<00000:@3ooolK0=7=Z@006P3A
cJTY0?ooo`8000000`3oool7000000D0oooo0`0000020?ooo`80000000<0oooo0000000000001@00
00050?ooo`@0000000<0oooo0000000000000P3oool7000000030?ooo`00000000000080000000<0
oooo0000000000000P0000000`3oool000000000000200000080oooo0`0000020?ooo`<000000P3o
ool300000080oooo0`0000020?ooo`<000000P3oool300000080oooo1000000Z0?oooa/0dLfY000J
0=7=ZBT0oooo0P0000030?ooo`L000001@3oool300000080oooo0P0000000`3oool0000000000005
000000D0oooo100000000`3oool00000000000020?ooo`L0000000<0oooo0000000000000P000000
0`3oool0000000000002000000030?ooo`0000000000008000000P3oool300000080oooo0`000002
0?ooo`<000000P3oool300000080oooo0`0000020?ooo`<000000P3oool4000002X0oooo6`3AcJT0
01X0dLfY:`3oool5000000030?ooo`00000000000080oooo1`0000050?ooo`<000000P3oool00`00
0000oooo0?ooo`07000000D0oooo0`0000020?ooo`8000000P3oool300000080oooo0`0000020?oo
o`<000000P3oool300000080oooo0`0000020?ooo`<000000P3oool4000000030?ooo`0000000000
0080000000<0oooo0000000000000P0000000`3oool0000000000002000002`0oooo6`3AcJT001X0
dLfY:`3oool5000000030?ooo`00000000000080oooo1`0000050?ooo`<000000P3oool00`000000
oooo0?ooo`07000000D0oooo0`0000020?ooo`8000000P3oool300000080oooo0`0000020?ooo`<0
00000P3oool300000080oooo0`0000020?ooo`<000000P3oool4000000030?ooo`00000000000080
000000<0oooo0000000000000P0000000`3oool0000000000002000002`0oooo6`3AcJT001X0dLfY
;03oool2000000D0oooo0`0000020?ooo`8000000P3oool6000000D0oooo100000020?ooo`030000
003oool0oooo00L000001@3oool300000080oooo0`0000020?ooo`<000000P3oool4000000030?oo
o`00000000000080000000<0oooo0000000000000P0000000`3oool000000000000200000080oooo
0`0000020?ooo`<000000P3oool3000002h0oooo6`3AcJT001X0dLfY;P3oool7000000D0oooo0`00
00020?ooo`80000000<0oooo0000000000001@0000050?ooo`@0000000<0oooo0000000000000P3o
ool7000000030?ooo`00000000000080000000<0oooo0000000000000P0000000`3oool000000000
000200000080oooo0`0000020?ooo`<000000P3oool300000080oooo0`0000020?ooo`<000000P3o
ool300000300oooo6`3AcJT001X0dLfY;P3oool7000000D0oooo0`0000020?ooo`80000000<0oooo
0000000000001@0000050?ooo`@0000000<0oooo0000000000000P3oool7000000030?ooo`000000
00000080000000<0oooo0000000000000P0000000`3oool000000000000200000080oooo0`000002
0?ooo`<000000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000300oooo6`3AcJT0
01X0dLfY<03oool00`000000oooo0?ooo`020?ooo`L000001@3oool300000080oooo00<000000?oo
o`3oool01`0000050?ooo`<000000P3oool200000080oooo0`0000020?ooo`<000000P3oool30000
0080oooo0`0000020?ooo`<000000P3oool300000080oooo100000000`3oool00000000000020000
00030?ooo`000000000000800000<@3ooolK0=7=Z@006P3AcJT`0?ooo`030000003oool0oooo0080
oooo1`0000050?ooo`<000000P3oool00`000000oooo0?ooo`07000000D0oooo0`0000020?ooo`80
00000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000080oooo0`0000020?ooo`<0
00000P3oool4000000030?ooo`00000000000080000000<0oooo0000000000000P00000a0?oooa/0
dLfY000J0=7=ZC40oooo1@0000020?ooo`8000000P3oool6000000D0oooo100000020?ooo`030000
003oool0oooo00L000001@3oool300000080oooo0`0000020?ooo`<000000P3oool4000000030?oo
o`00000000000080000000<0oooo0000000000000P0000000`3oool000000000000200000080oooo
0`0000020?ooo`<00000<`3ooolK0=7=Z@006P3AcJTa0?ooo`D000000P3oool200000080oooo1P00
00050?ooo`@000000P3oool00`000000oooo0?ooo`07000000D0oooo0`0000020?ooo`<000000P3o
ool300000080oooo100000000`3oool0000000000002000000030?ooo`00000000000080000000<0
oooo0000000000000P0000020?ooo`<000000P3oool3000003<0oooo6`3AcJT001X0dLfY<`3oool2
000000D0oooo0`0000020?ooo`80000000<0oooo0000000000001@0000050?ooo`@0000000<0oooo
0000000000000P3oool7000000030?ooo`00000000000080000000<0oooo0000000000000P000000
0`3oool000000000000200000080oooo0`0000020?ooo`<000000P3oool300000080oooo0`000002
0?ooo`<00000=@3ooolK0=7=Z@006P3AcJTe0?ooo`L000001@3oool300000080oooo00<000000?oo
o`3oool01`0000050?ooo`<000000P3oool200000080oooo0`0000020?ooo`<000000P3oool30000
0080oooo0`0000020?ooo`<000000P3oool300000080oooo100000000`3oool00000000000020000
03H0oooo6`3AcJT001X0dLfY=@3oool7000000D0oooo0`0000020?ooo`030000003oool0oooo00L0
00001@3oool300000080oooo0P0000020?ooo`<000000P3oool300000080oooo0`0000020?ooo`<0
00000P3oool300000080oooo0`0000020?ooo`@0000000<0oooo0000000000000P00000f0?oooa/0
dLfY000J0=7=ZCH0oooo0P0000040?ooo`H000001@3oool400000080oooo00<000000?ooo`3oool0
1`0000050?ooo`<000000P3oool300000080oooo0`0000020?ooo`@0000000<0oooo000000000000
0P0000000`3oool0000000000002000000030?ooo`0000000000008000000P3oool3000003P0oooo
6`3AcJT001X0dLfY=P3oool2000000@0oooo1P0000050?ooo`@000000P3oool00`000000oooo0?oo
o`07000000D0oooo0`0000020?ooo`<000000P3oool300000080oooo100000000`3oool000000000
0002000000030?ooo`00000000000080000000<0oooo0000000000000P0000020?ooo`<00000>03o
oolK0=7=Z@006P3AcJTh0?ooo`D000000P3oool2000000030?ooo`000000000000D000001@3oool4
000000030?ooo`00000000000080oooo1`0000000`3oool0000000000002000000030?ooo`000000
00000080000000<0oooo0000000000000P0000020?ooo`<000000P3oool300000080oooo0`000002
0?ooo`<00000>P3ooolK0=7=Z@006P3AcJTj0?ooo`8000001@3oool300000080oooo00<000000?oo
o`3oool01`0000050?ooo`<000000P3oool200000080oooo0`0000020?ooo`<000000P3oool30000
0080oooo0`0000020?ooo`<000000P3oool300000080oooo1000000k0?oooa/0dLfY000J0=7=ZCX0
oooo0P0000050?ooo`<000000P3oool00`000000oooo0?ooo`07000000D0oooo0`0000020?ooo`80
00000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000080oooo0`0000020?ooo`<0
00000P3oool4000003/0oooo6`3AcJT001X0dLfY?03oool6000000D0oooo100000020?ooo`030000
003oool0oooo00L000001@3oool300000080oooo0`0000020?ooo`<000000P3oool4000000030?oo
o`00000000000080000000<0oooo0000000000000P0000000`3oool0000000000002000003d0oooo
6`3AcJT001X0dLfY?03oool6000000D0oooo100000020?ooo`030000003oool0oooo00L000001@3o
ool300000080oooo0`0000020?ooo`<000000P3oool4000000030?ooo`00000000000080000000<0
oooo0000000000000P0000000`3oool0000000000002000003d0oooo6`3AcJT001X0dLfY?@3oool2
000000<0oooo1`0000050?ooo`@0000000<0oooo0000000000000P3oool7000000030?ooo`000000
00000080000000<0oooo0000000000000P0000000`3oool000000000000200000080oooo0`000002
0?ooo`<000000P3oool3000003l0oooo6`3AcJT001X0dLfY?`3oool500000080oooo00<000000?oo
o`3oool01`0000050?ooo`<000000P3oool200000080oooo0`0000020?ooo`<000000P3oool30000
0080oooo0`0000020?ooo`<000000P3oool300000440oooo6`3AcJT001X0dLfY?`3oool500000080
oooo00<000000?ooo`3oool01`0000050?ooo`<000000P3oool200000080oooo0`0000020?ooo`<0
00000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000440oooo6`3AcJT001X0dLfY
@@3oool00`000000oooo0?ooo`030?ooo`@000000P3oool00`000000oooo0?ooo`07000000D0oooo
0`0000020?ooo`<000000P3oool300000080oooo100000000`3oool0000000000002000000030?oo
o`000000000000800000@P3ooolK0=7=Z@006P3AcJU10?ooo`030000003oool0oooo00<0oooo1000
00020?ooo`030000003oool0oooo00L000001@3oool300000080oooo0`0000020?ooo`<000000P3o
ool4000000030?ooo`00000000000080000000<0oooo0000000000000P0000120?oooa/0dLfY000J
0=7=ZD80oooo1`0000050?ooo`@0000000<0oooo0000000000000P3oool7000000030?ooo`000000
00000080000000<0oooo0000000000000P0000000`3oool000000000000200000080oooo0`000002
0?ooo`<00000A03ooolK0=7=Z@006P3AcJU20?ooo`L000001@3oool4000000030?ooo`0000000000
0080oooo1`0000000`3oool0000000000002000000030?ooo`00000000000080000000<0oooo0000
000000000P0000020?ooo`<000000P3oool3000004@0oooo6`3AcJT001X0dLfYA03oool2000000<0
oooo1`0000050?ooo`<000000P3oool200000080oooo0`0000020?ooo`<000000P3oool300000080
oooo0`0000020?ooo`<00000AP3ooolK0=7=Z@006P3AcJU60?ooo`D000000P3oool00`000000oooo
0?ooo`07000000D0oooo0`0000020?ooo`<000000P3oool300000080oooo100000000`3oool00000
00000002000004L0oooo6`3AcJT001X0dLfYAP3oool500000080oooo00<000000?ooo`3oool01`00
00050?ooo`<000000P3oool300000080oooo0`0000020?ooo`@0000000<0oooo0000000000000P00
00170?oooa/0dLfY000J0=7=ZDL0oooo0P0000050?ooo`@0000000<0oooo0000000000000P3oool7
000000030?ooo`00000000000080000000<0oooo0000000000000P0000000`3oool0000000000002
00000080oooo0`0000190?oooa/0dLfY000J0=7=ZDL0oooo0P0000050?ooo`@0000000<0oooo0000
000000000P3oool7000000030?ooo`00000000000080000000<0oooo0000000000000P0000000`3o
ool000000000000200000080oooo0`0000190?oooa/0dLfY000J0=7=ZDT0oooo1`0000050?ooo`<0
00000P3oool200000080oooo0`0000020?ooo`<000000P3oool300000080oooo0`00001;0?oooa/0
dLfY000J0=7=ZD/0oooo0P0000030?ooo`L000001@3oool300000080oooo0`0000020?ooo`<00000
0P3oool4000004`0oooo6`3AcJT001X0dLfYB`3oool2000000<0oooo1`0000050?ooo`<000000P3o
ool300000080oooo0`0000020?ooo`@00000C03ooolK0=7=Z@006P3AcJU=0?ooo`D0000000<0oooo
0000000000000P3oool7000000030?ooo`00000000000080000000<0oooo0000000000000P000000
0`3oool0000000000002000004h0oooo6`3AcJT001X0dLfYC@3oool5000000030?ooo`0000000000
0080oooo1`0000000`3oool0000000000002000000030?ooo`00000000000080000000<0oooo0000
000000000P00001>0?oooa/0dLfY000J0=7=ZDh0oooo0P0000050?ooo`<000000P3oool200000080
oooo0`0000020?ooo`<000000P3oool300000500oooo6`3AcJT001X0dLfYD03oool7000000D0oooo
0`0000020?ooo`<000000P3oool300000580oooo6`3AcJT001X0dLfYD03oool7000000D0oooo0`00
00020?ooo`<000000P3oool300000580oooo6`3AcJT001X0dLfYDP3oool00`000000oooo0?ooo`02
0?ooo`L0000000<0oooo0000000000000P0000000`3oool0000000000002000005<0oooo6`3AcJT0
01X0dLfYDP3oool00`000000oooo0?ooo`020?ooo`L0000000<0oooo0000000000000P0000000`3o
ool0000000000002000005<0oooo6`3AcJT001X0dLfYD`3oool500000080oooo0P0000020?ooo`<0
00000P3oool3000005D0oooo6`3AcJT001X0dLfYD`3oool500000080oooo0P0000020?ooo`<00000
0P3oool3000005D0oooo6`3AcJT001X0dLfYE@3oool2000000D0oooo0`0000020?ooo`<00000E`3o
oolK0=7=Z@006P3AcJUG0?ooo`L0000000<0oooo0000000000000P00001H0?oooa/0dLfY000J0=7=
ZEL0oooo1`0000000`3oool0000000000002000005P0oooo6`3AcJT001X0dLfYF03oool2000000@0
oooo0`00001J0?oooa/0dLfY000J0=7=ZEP0oooo0P0000040?ooo`<00000FP3ooolK0=7=Z@006P3A
cJUJ0?ooo`D00000G03ooolK0=7=Z@006P3AcJUL0?ooo`800000G@3ooolK0=7=Z@006P3AcJUL0?oo
o`800000G@3ooolK0=7=Z@00l03AcJT00?00dLfY003`0=7=Z@00l03AcJT00?00dLfY003`0=7=Z@00
l03AcJT00?00dLfY001_0=7=Z@E0000000<0dLfY@000040000000d0000020=7=Z@900000LP3AcJT0
0740dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=00000
0=7=Z@3AcJT0K`3AcJT00740dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU0
00000080dLfY00=000000=7=Z@3AcJT0K`3AcJT00740dLfY00=000000=7=Z@3AcJT00`3AcJT01D00
0000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0K`3AcJT00740dLfY00=000000=7=
Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0K`3AcJT0
0700dLfY0T0000040=7=Z@900000103AcJT2@0000780dLfY003`0=7=Z@00l03AcJT00?00dLfY003`
0=7=Z@00l03AcJT00?00dLfY003`0=7=Z@00l03AcJT00?00dLfY003`0=7=Z@00l03AcJT00?00dLfY
003`0=7=Z@00l03AcJT00?00dLfY000J0=7=Z@T0oooo1@0000060?ooo`8000000P3oool200000003
0?ooo`00000000000080oooo1P0000040?ooo`<00000103oool3000000T0oooo00<000000?ooo`3o
ool03P0000050?ooo`<000000P3oool500000080oooo0`0000080?ooo`T000002P3oool400000003
0?ooo`0000000000008000001P3oool400000080oooo00<000000?ooo`3oool00`3oool5000000@0
oooo0`0000020?ooo`L0000000<0oooo0000000000000P00000:0?oooa/0dLfY000J0=7=Z@T0oooo
1@0000060?ooo`8000000P3oool2000000030?ooo`00000000000080oooo1P0000040?ooo`<00000
103oool3000000T0oooo00<000000?ooo`3oool03P0000050?ooo`<000000P3oool500000080oooo
0`0000080?ooo`T000002P3oool4000000030?ooo`0000000000008000001P3oool400000080oooo
00<000000?ooo`3oool00`3oool5000000@0oooo0`0000020?ooo`L0000000<0oooo000000000000
0P00000:0?oooa/0dLfY000J0=7=Z@X0oooo0P00000:0?ooo`@0000000<0oooo0000000000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@000001P3oool200000080oooo2000
00020?ooo`8000000`3oool2000000<0oooo0P0000080?ooo`8000000P3oool00`000000oooo0?oo
o`020?ooo`<00000303oool2000000<0oooo0P0000020?ooo`X000001@3oool2000000030?ooo`00
0000000000D000001@3oool7000000<0oooo1P0000050?ooo`030000003oool0oooo0080oooo0`00
000<0?oooa/0dLfY000J0=7=Z@`0oooo300000050?ooo`<000000P3oool300000080oooo0P00000:
0?ooo`<00000103oool2000000D0oooo1@0000000`3oool000000000000200000080oooo20000002
0?ooo`030000003oool0oooo00@000003`3oool500000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`L0000000<0oooo0000000000000`3oool200000080oooo1@000003
0?ooo`8000000P3oool3000000@0oooo1P0000020?ooo`<000003P3ooolK0=7=Z@006P3AcJT<0?oo
o``000001@3oool300000080oooo0`0000020?ooo`8000002P3oool3000000@0oooo0P0000050?oo
o`D0000000<0oooo0000000000000P0000020?ooo`P000000P3oool00`000000oooo0?ooo`040000
00l0oooo1@0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool70000
00030?ooo`000000000000<0oooo0P0000020?ooo`D000000`3oool200000080oooo0`0000040?oo
o`H000000P3oool3000000h0oooo6`3AcJT001X0dLfY3P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo1`0000050?ooo`030000003oool0oooo008000000P3oool:000000L0
oooo1P0000040?ooo`<000001@3oool2000000<0oooo0P0000020?ooo`030000003oool0oooo0080
00004`3oool00`000000oooo0?ooo`030?ooo`D000000P3oool4000000<0oooo0P0000000`3oool0
0000000000020?ooo`<000000P3oool2000000<0oooo1@0000020?ooo`030000003oool0oooo00D0
oooo0P0000030?ooo`@000003`3ooolK0=7=Z@006P3AcJT>0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool7000000D0oooo00<000000?ooo`3oool00P0000020?ooo`X00000
1`3oool6000000@0oooo0`0000050?ooo`8000000`3oool200000080oooo00<000000?ooo`3oool0
0P00000C0?ooo`030000003oool0oooo00<0oooo1@0000020?ooo`@000000`3oool2000000030?oo
o`00000000000080oooo0`0000020?ooo`8000000`3oool500000080oooo00<000000?ooo`3oool0
1@3oool2000000<0oooo1000000?0?oooa/0dLfY000J0=7=Z@l0oooo1@0000020?ooo`@000000`3o
ool2000000030?ooo`000000000000<000000P3oool200000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`P00000103oool00`000000oooo0?ooo`03000000T0oooo1@00
00020?ooo`030000003oool0oooo008000000P3ooolB00000080oooo1@0000030?ooo`@000001`3o
ool300000080oooo00<000000?ooo`3oool0103oool5000000<0oooo0`0000020?ooo`L000000P3o
ool300000140oooo6`3AcJT001X0dLfY3`3oool500000080oooo100000030?ooo`80000000<0oooo
0000000000000`0000020?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo200000040?ooo`030000003oool0oooo00<000002@3oool500000080oooo00<00000
0?ooo`3oool00P0000020?oooa8000000P3oool5000000<0oooo100000070?ooo`<000000P3oool0
0`000000oooo0?ooo`040?ooo`D000000`3oool300000080oooo1`0000020?ooo`<000004@3ooolK
0=7=Z@006P3AcJTA0?ooo`8000001@3oool2000000030?ooo`00000000000080000000<0oooo0000
000000000`3oool400000080oooo00<000000?ooo`3oool00`0000020?ooo`<00000103oool20000
00H0oooo1000000<0?ooo`030000003oool0oooo00<0oooo100000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`00
0000oooo0?ooo`050?ooo`8000000P3oool6000000D0oooo1`0000040?ooo`D000001@3oool20000
00<0oooo0`00000C0?oooa/0dLfY000J0=7=ZA<0oooo1`0000000`3oool00000000000050?ooo`D0
00001@3oool4000000D0oooo00<000000?ooo`3oool0100000000`3oool0000000000005000000l0
oooo1`0000050?ooo`D000000P3oool300000080oooo100000000`3oool000000000000300000080
oooo1`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@0000040?ooo`03
0000003oool0oooo00<00000103oool7000000030?ooo`000000000000800000503ooolK0=7=Z@00
6P3AcJTC0?ooo`L0000000<0oooo0000000000001@3oool5000000D0oooo100000050?ooo`030000
003oool0oooo00@0000000<0oooo0000000000001@00000?0?ooo`L000001@3oool500000080oooo
0`0000020?ooo`@0000000<0oooo0000000000000`0000020?ooo`L000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D00000103oool00`000000oooo0?ooo`03000000@0oooo
1`0000000`3oool0000000000002000001@0oooo6`3AcJT001X0dLfY503oool2000000@0oooo0`00
00020?ooo`D000000`3oool7000000P0oooo100000050?ooo`8000000`3ooolA000000<0oooo0P00
00020?ooo`D000000`3oool4000000D0oooo0P0000000`3oool00000000000030?ooo`@000000`3o
ool200000080oooo00<000000?ooo`3oool00`0000020?ooo`8000000`3oool500000080oooo0P00
00060?ooo`800000103oool3000001H0oooo6`3AcJT001X0dLfY503oool2000000@0oooo0`000002
0?ooo`D000000`3oool7000000P0oooo100000050?ooo`8000000`3ooolA000000<0oooo0P000002
0?ooo`D000000`3oool4000000D0oooo0P0000000`3oool00000000000030?ooo`@000000`3oool2
00000080oooo00<000000?ooo`3oool00`0000020?ooo`8000000`3oool500000080oooo0P000006
0?ooo`800000103oool3000001H0oooo6`3AcJT001X0dLfY5P3oool5000000D0oooo0P0000070?oo
o`8000000`3oool:000000T0oooo1@0000030?ooo`8000000`3oool2000000<0oooo0P0000020?oo
o`<000000P3oool2000000<0oooo1@0000090?ooo`<000000P3oool3000000L0oooo0`0000020?oo
o`8000001@3oool5000000<0oooo100000000`3oool000000000000500000080oooo0`00000H0?oo
oa/0dLfY000J0=7=ZAP0oooo0P0000080?ooo`T0000000<0oooo0000000000000P0000030?ooo`80
00000`3oool:000000@0oooo1@0000020?ooo`<000000P3oool300000080oooo00<000000?ooo`3o
ool0103oool5000000<0oooo2P0000050?ooo`8000000P3oool7000000D0oooo1P0000040?ooo`D0
00001@3oool2000000<0oooo1000000I0?oooa/0dLfY000J0=7=ZAP0oooo0P0000080?ooo`T00000
00<0oooo0000000000000P0000030?ooo`8000000`3oool:000000@0oooo1@0000020?ooo`<00000
0P3oool300000080oooo00<000000?ooo`3oool0103oool5000000<0oooo2P0000050?ooo`800000
0P3oool7000000D0oooo1P0000040?ooo`D000001@3oool2000000<0oooo1000000I0?oooa/0dLfY
000J0=7=ZAX0oooo2P0000030?ooo`8000001@3oool2000000030?ooo`00000000000080000000<0
oooo0000000000000P0000030?ooo`8000000`3oool5000000@0oooo0`0000050?ooo`8000000P3o
ool00`000000oooo0?ooo`05000000@0oooo1@0000030?ooo`8000000`3oool700000080oooo00<0
00000?ooo`3oool00P3oool2000000030?ooo`000000000000<00000103oool00`000000oooo0?oo
o`04000000<0oooo1`0000000`3oool0000000000002000001/0oooo6`3AcJT001X0dLfY6P3oool:
000000<0oooo0P0000050?ooo`80000000<0oooo0000000000000P0000000`3oool0000000000002
000000<0oooo0P0000030?ooo`D00000103oool3000000D0oooo0P0000020?ooo`030000003oool0
oooo00D00000103oool5000000<0oooo0P0000030?ooo`L000000P3oool00`000000oooo0?ooo`02
0?ooo`80000000<0oooo0000000000000`0000040?ooo`030000003oool0oooo00@000000`3oool7
000000030?ooo`0000000000008000006`3ooolK0=7=Z@006P3AcJTK0?ooo`8000000`3oool20000
00L0oooo1`0000000`3oool00000000000050?ooo`8000000P3oool300000080oooo0`0000030?oo
o`H00000203oool300000080oooo0P0000030?ooo`D00000103oool500000080oooo0`0000030?oo
o`8000000P3oool00`000000oooo0?ooo`04000000030?ooo`000000000000<0oooo1@0000020?oo
o`8000001`3oool00`000000oooo0?ooo`020?ooo`<000007@3ooolK0=7=Z@006P3AcJTM0?ooo`D0
00000P3oool7000000<0oooo0P0000000`3oool00000000000020?ooo`D000000P3oool00`000000
oooo0?ooo`030?ooo`8000000P3oool3000000@0oooo2P0000050?ooo`D000000`3oool5000000@0
oooo0`0000070?ooo`<000000P3oool2000000D0oooo1@0000030?ooo`@000000P3oool600000080
oooo0`00000O0?oooa/0dLfY000J0=7=ZAd0oooo1@0000020?ooo`L000000`3oool2000000030?oo
o`00000000000080oooo1@0000020?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`<00000
103oool:000000D0oooo1@0000030?ooo`D00000103oool3000000L0oooo0`0000020?ooo`800000
1@3oool5000000<0oooo100000020?ooo`H000000P3oool3000001l0oooo6`3AcJT001X0dLfY7`3o
ool00`000000oooo0?ooo`030?ooo`800000103oool5000000030?ooo`00000000000080oooo00<0
00000?ooo`3oool00P3oool300000080oooo1@0000020?ooo`030000003oool0oooo00D0oooo0P00
00030?ooo`8000002@3oool00`000000oooo0?ooo`050?ooo`8000001`3oool00`000000oooo0?oo
o`07000000D0oooo1`0000030?ooo`D000001@3oool2000000<0oooo1000000P0?oooa/0dLfY000J
0=7=ZAl0oooo00<000000?ooo`3oool00`3oool2000000@0oooo1@0000000`3oool0000000000002
0?ooo`030000003oool0oooo0080oooo0`0000020?ooo`D000000P3oool00`000000oooo0?ooo`05
0?ooo`8000000`3oool2000000T0oooo00<000000?ooo`3oool01@3oool2000000L0oooo00<00000
0?ooo`3oool01`0000050?ooo`L000000`3oool5000000D0oooo0P0000030?ooo`@00000803ooolK
0=7=Z@006P3AcJTP0?ooo`L000000P3oool3000000@0oooo0`0000020?ooo`030000003oool0oooo
00@000001@3oool00`000000oooo0?ooo`030?ooo`T000000P3oool300000080oooo200000020?oo
o`L0000000<0oooo0000000000001@0000020?ooo`8000000`3oool2000000030?ooo`0000000000
00@000000`3oool2000000030?ooo`0000000000008000000`3oool700000080oooo0`00000R0?oo
oa/0dLfY000J0=7=ZB00oooo1`0000020?ooo`<00000103oool300000080oooo00<000000?ooo`3o
ool0100000050?ooo`030000003oool0oooo00<0oooo2@0000020?ooo`<000000P3oool800000080
oooo1`0000000`3oool000000000000500000080oooo0P0000030?ooo`80000000<0oooo00000000
0000100000030?ooo`80000000<0oooo0000000000000P0000030?ooo`L000000P3oool300000280
oooo6`3AcJT001X0dLfY8P3oool2000000<0oooo100000060?ooo`8000000P3oool00`000000oooo
0?ooo`02000000P0oooo1`0000040?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`030000
003oool0oooo0080oooo0P0000050?ooo`030000003oool0oooo0080oooo0`0000040?ooo`030000
003oool0oooo0080000000<0oooo0000000000000P0000000`3oool00000000000040?ooo`D00000
00<0oooo0000000000001`3oool2000000<0oooo0`00000T0?oooa/0dLfY000J0=7=ZB@0oooo1@00
000:0?ooo`<000000P3oool200000080oooo200000030?ooo`8000000P3oool300000080oooo1@00
00020?ooo`030000003oool0oooo00@0000000<0oooo0000000000000`0000020?ooo`<000001`3o
ool4000000030?ooo`000000000000D0oooo1@0000040?ooo`<000000P3oool7000000030?ooo`00
00000000008000009@3ooolK0=7=Z@006P3AcJTT0?ooo`D000002P3oool300000080oooo0P000002
0?ooo`P000000`3oool200000080oooo0`0000020?ooo`D000000P3oool00`000000oooo0?ooo`04
000000030?ooo`000000000000<000000P3oool3000000L0oooo100000000`3oool0000000000005
0?ooo`D00000103oool300000080oooo1`0000000`3oool0000000000002000002D0oooo6`3AcJT0
01X0dLfY9@3oool2000000h0oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01@3oool4000000D0oooo00<000000?ooo`3oool00`3oool40000
00D0oooo0P0000050?ooo`030000003oool0oooo00L000001@3oool7000000<0oooo1@0000050?oo
o`800000103oool3000002L0oooo6`3AcJT001X0dLfY9@3oool2000000h0oooo00<000000?ooo`3o
ool00P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool4000000D0
oooo00<000000?ooo`3oool00`3oool4000000D0oooo0P0000050?ooo`030000003oool0oooo00L0
00001@3oool7000000<0oooo1@0000050?ooo`800000103oool3000002L0oooo6`3AcJT001X0dLfY
9`3oool?00000080oooo0P0000020?ooo`030000003oool0oooo00<000000P3oool7000000P0oooo
1`0000090?ooo`H000000P3oool2000000<0oooo0P0000020?ooo`D000000`3oool200000080oooo
0`0000030?ooo`L000000P3oool3000002T0oooo6`3AcJT001X0dLfY:@3oool2000000<0oooo0P00
00030?ooo`8000001@3oool300000080oooo0P0000050?ooo`030000003oool0oooo0080oooo2P00
00030?ooo`8000000P3oool8000000@0oooo00<000000?ooo`3oool00P0000020?ooo`<000000P3o
ool00`000000oooo0?ooo`020?ooo`D000000P3oool00`000000oooo0?ooo`050?ooo`8000000`3o
ool4000002X0oooo6`3AcJT001X0dLfY:@3oool2000000<0oooo0P0000030?ooo`8000001@3oool3
00000080oooo0P0000050?ooo`030000003oool0oooo0080oooo2P0000030?ooo`8000000P3oool8
000000@0oooo00<000000?ooo`3oool00P0000020?ooo`<000000P3oool00`000000oooo0?ooo`02
0?ooo`D000000P3oool00`000000oooo0?ooo`050?ooo`8000000`3oool4000002X0oooo6`3AcJT0
01X0dLfY:`3oool5000000030?ooo`00000000000080000000<0oooo000000000000100000050?oo
o`H000000P3oool4000000<0oooo0P0000030?ooo`D000000P3oool2000000<0oooo0P0000060?oo
o`@000000P3oool00`000000oooo0?ooo`030?ooo`D00000103oool300000080oooo1`0000000`3o
ool0000000000002000002`0oooo6`3AcJT001X0dLfY:`3oool5000000030?ooo`00000000000080
000000<0oooo000000000000100000050?ooo`H000000P3oool4000000<0oooo0P0000030?ooo`D0
00000P3oool2000000<0oooo0P0000060?ooo`@000000P3oool00`000000oooo0?ooo`030?ooo`D0
0000103oool300000080oooo1`0000000`3oool0000000000002000002`0oooo6`3AcJT001X0dLfY
;03oool2000000D0oooo0P0000000`3oool00000000000040?ooo`H00000103oool00`000000oooo
0?ooo`02000000L0oooo1@0000030?ooo`@0000000<0oooo0000000000000P0000000`3oool00000
00000005000000D0oooo1`0000030?ooo`H000001@3oool00`000000oooo0?ooo`020?ooo`<00000
;P3ooolK0=7=Z@006P3AcJT^0?ooo`L0000000<0oooo0000000000000P3oool3000000@0oooo00<0
00000?ooo`3oool00`0000020?ooo`8000000P3oool6000000@0oooo1@0000050?ooo`80000000<0
oooo0000000000000`3oool200000080oooo1@0000030?ooo`8000000P3oool3000000@0oooo1P00
00020?ooo`<00000<03ooolK0=7=Z@006P3AcJT^0?ooo`L0000000<0oooo0000000000000P3oool3
000000@0oooo00<000000?ooo`3oool00`0000020?ooo`8000000P3oool6000000@0oooo1@000005
0?ooo`80000000<0oooo0000000000000`3oool200000080oooo1@0000030?ooo`8000000P3oool3
000000@0oooo1P0000020?ooo`<00000<03ooolK0=7=Z@006P3AcJT`0?ooo`030000003oool0oooo
0080oooo0`0000020?ooo`8000001P3oool4000000D0oooo0`0000040?ooo`030000003oool0oooo
00<00000103oool7000000030?ooo`00000000000080oooo0`0000020?ooo`8000000`3oool50000
0080oooo00<000000?ooo`3oool01@3oool2000000<0oooo1000000a0?oooa/0dLfY000J0=7=ZC00
oooo00<000000?ooo`3oool00P3oool300000080oooo0P0000060?ooo`@000001@3oool3000000@0
oooo00<000000?ooo`3oool00`0000040?ooo`L0000000<0oooo0000000000000P3oool300000080
oooo0P0000030?ooo`D000000P3oool00`000000oooo0?ooo`050?ooo`8000000`3oool400000340
oooo6`3AcJT001X0dLfY<@3oool5000000H0oooo200000090?ooo`030000003oool0oooo00<00000
0P3oool2000000L0oooo00<000000?ooo`3oool00P3oool300000080oooo00<000000?ooo`3oool0
103oool5000000<0oooo0`0000020?ooo`L000000P3oool3000003<0oooo6`3AcJT001X0dLfY<@3o
ool5000000H0oooo200000090?ooo`030000003oool0oooo00<000000P3oool2000000L0oooo00<0
00000?ooo`3oool00P3oool300000080oooo00<000000?ooo`3oool0103oool5000000<0oooo0`00
00020?ooo`L000000P3oool3000003<0oooo6`3AcJT001X0dLfY<`3oool2000000P0oooo0P000003
0?ooo`8000000P3oool800000080oooo0P0000050?ooo`P000000P3oool3000000D0oooo1`000004
0?ooo`D000001@3oool2000000<0oooo0`00000e0?oooa/0dLfY000J0=7=ZCD0oooo2P0000020?oo
o`<000000P3oool00`000000oooo0?ooo`020?ooo`8000001@3oool6000000@0oooo0P0000050?oo
o`030000003oool0oooo00D00000103oool00`000000oooo0?ooo`03000000@0oooo1`0000000`3o
ool0000000000002000003H0oooo6`3AcJT001X0dLfY=@3oool:00000080oooo0`0000020?ooo`03
0000003oool0oooo0080oooo0P0000050?ooo`H00000103oool2000000D0oooo00<000000?ooo`3o
ool01@0000040?ooo`030000003oool0oooo00<00000103oool7000000030?ooo`00000000000080
0000=P3ooolK0=7=Z@006P3AcJTf0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`800000
0P3oool00`000000oooo0?ooo`04000000030?ooo`000000000000<00000103oool00`000000oooo
0?ooo`04000000030?ooo`000000000000<000000P3oool2000000<0oooo1@0000020?ooo`800000
1P3oool2000000@0oooo0`00000h0?oooa/0dLfY000J0=7=ZCH0oooo0P0000040?ooo`030000003o
ool0oooo00<0oooo0P0000020?ooo`030000003oool0oooo00@0000000<0oooo0000000000000`00
00040?ooo`030000003oool0oooo00@0000000<0oooo0000000000000`0000020?ooo`8000000`3o
ool500000080oooo0P0000060?ooo`800000103oool3000003P0oooo6`3AcJT001X0dLfY>03oool5
00000080oooo1@0000020?ooo`030000003oool0oooo008000001@3oool2000000H0oooo10000005
0?ooo`8000001@3oool5000000<0oooo100000000`3oool000000000000500000080oooo0`00000j
0?oooa/0dLfY000J0=7=ZCX0oooo0P0000050?ooo`030000003oool0oooo00<0oooo100000020?oo
o`D0000000<0oooo0000000000001@0000090?ooo`H00000103oool5000000D0oooo0P0000030?oo
o`@00000>`3ooolK0=7=Z@006P3AcJTj0?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`@0
00000P3oool5000000030?ooo`000000000000D000002@3oool6000000@0oooo1@0000050?ooo`80
00000`3oool4000003/0oooo6`3AcJT001X0dLfY?03oool600000080oooo1@0000050?ooo`800000
1@3oool2000000<0oooo2P0000040?ooo`030000003oool0oooo00@000000`3oool7000000030?oo
o`000000000000800000?@3ooolK0=7=Z@006P3AcJTl0?ooo`H000000P3oool5000000D0oooo0P00
00050?ooo`8000000`3oool:000000@0oooo00<000000?ooo`3oool0100000030?ooo`L0000000<0
oooo0000000000000P00000m0?oooa/0dLfY000J0=7=ZCd0oooo0P0000030?ooo`@000000`3oool7
00000080oooo1@0000000`3oool0000000000002000000<0oooo0P0000030?ooo`D000000P3oool2
000000L0oooo00<000000?ooo`3oool00P3oool3000003l0oooo6`3AcJT001X0dLfY?`3oool50000
00L0oooo0P0000030?ooo`<00000103oool3000000L0oooo1@0000030?ooo`@000000P3oool60000
0080oooo0`0000110?oooa/0dLfY000J0=7=ZCl0oooo1@0000070?ooo`8000000`3oool3000000@0
oooo0`0000070?ooo`D000000`3oool400000080oooo1P0000020?ooo`<00000@@3ooolK0=7=Z@00
6P3AcJU10?ooo`030000003oool0oooo00T0oooo1@0000060?ooo`8000000P3oool7000000<0oooo
1@0000050?ooo`8000000`3oool400000480oooo6`3AcJT001X0dLfY@@3oool00`000000oooo0?oo
o`090?ooo`D000001P3oool200000080oooo1`0000030?ooo`D000001@3oool2000000<0oooo1000
00120?oooa/0dLfY000J0=7=ZD80oooo300000040?ooo`P000000P3oool2000000<0oooo0P000000
0`3oool0000000000002000000<0oooo1`0000020?ooo`<00000A03ooolK0=7=Z@006P3AcJU20?oo
o``00000103oool800000080oooo0P0000030?ooo`80000000<0oooo0000000000000P0000030?oo
o`L000000P3oool3000004@0oooo6`3AcJT001X0dLfYA03oool2000000<0oooo0P0000030?ooo`D0
0000103oool00`000000oooo0?ooo`040?ooo`D0000000<0oooo0000000000001`3oool2000000<0
oooo0`0000160?oooa/0dLfY000J0=7=ZDH0oooo1@0000020?ooo`<000000`3oool500000080oooo
1@0000040?ooo`<000000P3oool7000000030?ooo`000000000000800000A`3ooolK0=7=Z@006P3A
cJU60?ooo`D000000P3oool3000000<0oooo1@0000020?ooo`D00000103oool300000080oooo1`00
00000`3oool0000000000002000004L0oooo6`3AcJT001X0dLfYA`3oool2000000D0oooo0P000002
0?ooo`<000000`3oool4000000<0oooo1@0000050?ooo`800000103oool3000004T0oooo6`3AcJT0
01X0dLfYA`3oool2000000D0oooo0P0000020?ooo`<000000`3oool4000000<0oooo1@0000050?oo
o`800000103oool3000004T0oooo6`3AcJT001X0dLfYB@3oool700000080oooo00<000000?ooo`3o
ool01@3oool200000080oooo0`0000030?ooo`L000000P3oool3000004/0oooo6`3AcJT001X0dLfY
B`3oool2000000<0oooo0`0000020?ooo`L000000P3oool00`000000oooo0?ooo`050?ooo`800000
0`3oool4000004`0oooo6`3AcJT001X0dLfYB`3oool2000000<0oooo0`0000020?ooo`L000000P3o
ool00`000000oooo0?ooo`050?ooo`8000000`3oool4000004`0oooo6`3AcJT001X0dLfYC@3oool5
000000D0oooo00<000000?ooo`3oool00P3oool300000080oooo1`0000000`3oool0000000000002
000004h0oooo6`3AcJT001X0dLfYC@3oool5000000D0oooo00<000000?ooo`3oool00P3oool30000
0080oooo1`0000000`3oool0000000000002000004h0oooo6`3AcJT001X0dLfYCP3oool2000000P0
oooo1P0000050?ooo`030000003oool0oooo0080oooo0`00001@0?oooa/0dLfY000J0=7=ZE00oooo
2P0000040?ooo`H000000P3oool300000580oooo6`3AcJT001X0dLfYD03oool:000000@0oooo1P00
00020?ooo`<00000DP3ooolK0=7=Z@006P3AcJUB0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool2000000<0oooo1000001C0?oooa/0dLfY000J0=7=ZE80oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`050?ooo`8000000`3oool4000005<0oooo6`3AcJT001X0
dLfYD`3oool500000080oooo1`0000020?ooo`<00000E@3ooolK0=7=Z@006P3AcJUC0?ooo`D00000
0P3oool700000080oooo0`00001E0?oooa/0dLfY000J0=7=ZED0oooo0P0000050?ooo`8000000`3o
ool3000005L0oooo6`3AcJT001X0dLfYE`3oool7000000030?ooo`000000000000800000F03ooolK
0=7=Z@006P3AcJUG0?ooo`L0000000<0oooo0000000000000P00001H0?oooa/0dLfY000J0=7=ZEP0
oooo0P0000040?ooo`<00000FP3ooolK0=7=Z@006P3AcJUH0?ooo`800000103oool3000005X0oooo
6`3AcJT001X0dLfYFP3oool5000005`0oooo6`3AcJT001X0dLfYG03oool2000005d0oooo6`3AcJT0
01X0dLfYG03oool2000005d0oooo6`3AcJT00?00dLfY003`0=7=Z@00l03AcJT00?00dLfY003`0=7=
Z@00l03AcJT00?00dLfY003`0=7=Z@00K`3AcJT5@0000080dLfY0T0000030=7=Z@=00000LP3AcJT0
0740dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=0
00000=7=Z@3AcJT0K`3AcJT00740dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003A
cJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0K`3AcJT00740dLfY00E000000=7=Z@3AcJT0dLfY
@00000020=7=Z@03@000003AcJT0dLfY00=00000LP3AcJT00740dLfY00E000000=7=Z@3AcJT0dLfY
@00000020=7=Z@05@000003AcJT0dLfY0=7=ZD000000L`3AcJT00700dLfY0T0000040=7=Z@900000
103AcJT3@0000740dLfY003`0=7=Z@00l03AcJT00?00dLfY003`0=7=Z@00l03AcJT00?00dLfY003`
0=7=Z@00l03AcJT00?00dLfY003`0=7=Z@00l03AcJT00?00dLfY003`0=7=Z@00l03AcJT00?00dLfY
000J0=7=Z@T0oooo1@00000F0?ooo`D00000<@3oool500000380oooo1@00000F0?ooo`D000002P3o
oolK0=7=Z@006P3AcJT90?ooo`D000005P3oool500000340oooo1@00000b0?ooo`D000005P3oool5
000000X0oooo6`3AcJT001X0dLfY2P3oool2000001T0oooo0P00000e0?ooo`800000=03oool20000
01T0oooo0P00000<0?oooa/0dLfY000J0=7=Z@`0oooo0`0000020?ooo`<000000P3oool400000003
0?ooo`00000000000080000000<0oooo0000000000000P0000000`3oool00000000000020?ooo`<0
00000P3oool300000080oooo0`0000020?ooo`@0000000<0oooo0000000000000P0000000`3oool0
000000000002000000030?ooo`0000000000008000000P3oool300000080oooo0`0000020?ooo`<0
00000P3oool2000000030?ooo`00000000000080000000<0oooo0000000000000P0000000`3oool0
00000000000200000080oooo0`0000020?ooo`<000000P3oool300000080oooo0`0000020?ooo`<0
00000P3oool300000080oooo100000000`3oool00000000000020?ooo`<000000P3oool300000080
oooo0`0000020?ooo`<000000P3oool3000000h0oooo6`3AcJT001X0dLfY303oool300000080oooo
0`0000020?ooo`@0000000<0oooo0000000000000P0000000`3oool0000000000002000000030?oo
o`00000000000080oooo0`0000020?ooo`<000000P3oool300000080oooo100000000`3oool00000
00000002000000030?ooo`00000000000080000000<0oooo0000000000000P0000020?ooo`<00000
0P3oool300000080oooo0`0000020?ooo`80000000<0oooo0000000000000P0000000`3oool00000
00000002000000030?ooo`0000000000008000000P3oool300000080oooo0`0000020?ooo`<00000
0P3oool300000080oooo0`0000020?ooo`<000000P3oool4000000030?ooo`00000000000080oooo
0`0000020?ooo`<000000P3oool300000080oooo0`0000020?ooo`<000003P3ooolK0=7=Z@006P3A
cJT>0?ooo`030000003oool0oooo008000001@3oool2000000030?ooo`000000000000D0oooo0P00
00000`3oool00000000000020?ooo`8000001@3oool00`000000oooo0?ooo`02000000D0oooo0P00
00000`3oool00000000000050?ooo`80000000<0oooo0000000000001@3oool200000080oooo00<0
00000?ooo`3oool00`3oool200000080oooo0P0000000`3oool00000000000050?ooo`80000000<0
oooo0000000000001@3oool200000080oooo00<000000?ooo`3oool00`3oool200000080oooo0P00
00050?ooo`030000003oool0oooo008000001@3oool2000000030?ooo`00000000000080oooo00<0
00000?ooo`3oool00`3oool200000080oooo0P0000050?ooo`030000003oool0oooo008000003`3o
oolK0=7=Z@006P3AcJT>0?ooo`030000003oool0oooo008000001@3oool2000000030?ooo`000000
000000D0oooo0P0000000`3oool00000000000020?ooo`8000001@3oool00`000000oooo0?ooo`02
000000D0oooo0P0000000`3oool00000000000050?ooo`80000000<0oooo0000000000001@3oool2
00000080oooo00<000000?ooo`3oool00`3oool200000080oooo0P0000000`3oool0000000000005
0?ooo`80000000<0oooo0000000000001@3oool200000080oooo00<000000?ooo`3oool00`3oool2
00000080oooo0P0000050?ooo`030000003oool0oooo008000001@3oool2000000030?ooo`000000
00000080oooo00<000000?ooo`3oool00`3oool200000080oooo0P0000050?ooo`030000003oool0
oooo008000003`3ooolK0=7=Z@006P3AcJT?0?ooo`D000000P3oool5000000T0oooo1@0000080?oo
o`D000000P3oool5000000T0oooo1@0000020?ooo`D00000203oool5000000T0oooo1@0000020?oo
o`D00000203oool500000080oooo1@0000090?ooo`D00000203oool500000080oooo1@00000A0?oo
oa/0dLfY000J0=7=Z@l0oooo1@0000020?ooo`D000002@3oool5000000P0oooo1@0000020?ooo`D0
00002@3oool500000080oooo1@0000080?ooo`D000002@3oool500000080oooo1@0000080?ooo`D0
00000P3oool5000000T0oooo1@0000080?ooo`D000000P3oool500000140oooo6`3AcJT001X0dLfY
4@3oool2000000D0oooo0P00000;0?ooo`800000303oool2000000D0oooo0P00000;0?ooo`800000
1@3oool2000000`0oooo0P00000;0?ooo`8000001@3oool2000000`0oooo0P0000050?ooo`030000
003oool0oooo00X0oooo0P00000<0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?oooa/0dLfY
000J0=7=ZA<0oooo0`0000020?ooo`80000000<0oooo0000000000000P0000000`3oool000000000
0002000000030?ooo`00000000000080oooo0`0000020?ooo`<000000P3oool2000000030?ooo`00
00000000008000003`3oool4000000030?ooo`00000000000080oooo0`0000020?ooo`<000000P3o
ool2000000030?ooo`00000000000080000000<0oooo0000000000000P0000000`3oool000000000
00020?ooo`<00000403oool300000080oooo00<000000?ooo`3oool00`0000020?ooo`@0000000<0
oooo0000000000000P3oool300000080oooo0`0000020?ooo`80000000<0oooo0000000000000P00
000D0?oooa/0dLfY000J0=7=ZA<0oooo0`0000020?ooo`80000000<0oooo0000000000000P000000
0`3oool0000000000002000000030?ooo`00000000000080oooo0`0000020?ooo`<000000P3oool2
000000030?ooo`0000000000008000003`3oool4000000030?ooo`00000000000080oooo0`000002
0?ooo`<000000P3oool2000000030?ooo`00000000000080000000<0oooo0000000000000P000000
0`3oool00000000000020?ooo`<00000403oool300000080oooo00<000000?ooo`3oool00`000002
0?ooo`@0000000<0oooo0000000000000P3oool300000080oooo0`0000020?ooo`80000000<0oooo
0000000000000P00000D0?oooa/0dLfY000J0=7=ZA@0oooo0P0000020?ooo`80000000<0oooo0000
000000001@3oool2000000030?ooo`00000000000080oooo0P0000050?ooo`030000003oool0oooo
0080000000<0oooo0000000000004`3oool2000000030?ooo`00000000000080oooo00<000000?oo
o`3oool00`3oool200000080oooo0P0000000`3oool00000000000050?ooo`80000000<0oooo0000
000000000P3oool200000180oooo0P0000020?ooo`030000003oool0oooo008000001@3oool20000
00030?ooo`00000000000080oooo00<000000?ooo`3oool00`3oool200000080oooo0P0000000`3o
ool000000000000F0?oooa/0dLfY000J0=7=ZA@0oooo0P0000020?ooo`80000000<0oooo00000000
00001@3oool2000000030?ooo`00000000000080oooo0P0000050?ooo`030000003oool0oooo0080
000000<0oooo0000000000004`3oool2000000030?ooo`00000000000080oooo00<000000?ooo`3o
ool00`3oool200000080oooo0P0000000`3oool00000000000050?ooo`80000000<0oooo00000000
00000P3oool200000180oooo0P0000020?ooo`030000003oool0oooo008000001@3oool200000003
0?ooo`00000000000080oooo00<000000?ooo`3oool00`3oool200000080oooo0P0000000`3oool0
00000000000F0?oooa/0dLfY000J0=7=ZAH0oooo1@0000090?ooo`D00000203oool5000001L0oooo
1@0000080?ooo`D000002@3oool5000001H0oooo1@0000090?ooo`D00000203oool5000001P0oooo
6`3AcJT001X0dLfY603oool2000000/0oooo0P00000<0?ooo`8000006@3oool2000000`0oooo0P00
000;0?ooo`8000006P3oool00`000000oooo0?ooo`0:0?ooo`800000303oool2000001T0oooo6`3A
cJT001X0dLfY603oool2000000/0oooo0P00000<0?ooo`8000006@3oool2000000`0oooo0P00000;
0?ooo`8000006P3oool00`000000oooo0?ooo`0:0?ooo`800000303oool2000001T0oooo6`3AcJT0
01X0dLfY6P3oool300000080oooo0`0000020?ooo`D000000P3oool300000080oooo0`00000M0?oo
o`<000000P3oool300000080oooo1@0000020?ooo`<000000P3oool3000001d0oooo100000000`3o
ool000000000000200000080oooo1@0000000`3oool0000000000002000000030?ooo`0000000000
008000006`3ooolK0=7=Z@006P3AcJTJ0?ooo`<000000P3oool300000080oooo1@0000020?ooo`<0
00000P3oool3000001d0oooo0`0000020?ooo`<000000P3oool500000080oooo0`0000020?ooo`<0
00007@3oool4000000030?ooo`0000000000008000000P3oool5000000030?ooo`00000000000080
000000<0oooo0000000000000P00000K0?oooa/0dLfY000J0=7=ZA/0oooo0P0000020?ooo`030000
003oool0oooo00<0oooo0P0000050?ooo`8000000P3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo008000001@3oool2000000D0oooo00<000000?ooo`3oool00P00000P0?ooo`800000
00<0oooo0000000000001@3oool2000000D0oooo0P0000000`3oool000000000000M0?oooa/0dLfY
000J0=7=ZAd0oooo1@0000020?ooo`D000000P3oool5000002<0oooo1@0000020?ooo`D000000P3o
ool5000002@0oooo1@0000020?ooo`D0000000<0oooo0000000000000`00000O0?oooa/0dLfY000J
0=7=ZAd0oooo1@0000020?ooo`D000000P3oool5000002<0oooo1@0000020?ooo`D000000P3oool5
000002@0oooo1@0000020?ooo`D0000000<0oooo0000000000000`00000O0?oooa/0dLfY000J0=7=
ZAl0oooo00<000000?ooo`3oool00`3oool2000000D0oooo0P00000W0?ooo`8000001@3oool20000
00D0oooo00<000000?ooo`3oool09@3oool2000000D0oooo0P0000050?ooo`800000803ooolK0=7=
Z@006P3AcJTO0?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`8000009`3oool2000000D0
oooo0P0000050?ooo`030000003oool0oooo02D0oooo0P0000050?ooo`8000001@3oool200000200
oooo6`3AcJT001X0dLfY803oool4000000030?ooo`00000000000080oooo0`00000[0?ooo`<00000
0P3oool2000000030?ooo`000000000000800000:P3oool4000000030?ooo`00000000000080oooo
0`00000R0?oooa/0dLfY000J0=7=ZB00oooo100000000`3oool00000000000020?ooo`<00000:`3o
ool300000080oooo0P0000000`3oool0000000000002000002X0oooo100000000`3oool000000000
00020?ooo`<000008P3ooolK0=7=Z@006P3AcJTR0?ooo`80000000<0oooo0000000000000P3oool2
000002d0oooo0P0000020?ooo`80000000<0oooo000000000000;P3oool2000000030?ooo`000000
00000080oooo00<000000?ooo`3oool08P3ooolK0=7=Z@006P3AcJTT0?ooo`D00000<@3oool50000
0380oooo1@00000U0?oooa/0dLfY000J0=7=ZB@0oooo1@00000a0?ooo`D00000<P3oool5000002D0
oooo6`3AcJT001X0dLfY9@3oool2000003D0oooo0P00000d0?ooo`8000009`3ooolK0=7=Z@006P3A
cJTU0?ooo`800000=@3oool2000003@0oooo0P00000W0?oooa/0dLfY000J0=7=ZBL0oooo10000000
0`3oool0000000000002000000030?ooo`00000000000080000000<0oooo0000000000000P000002
0?ooo`<000000P3oool300000080oooo0`0000020?ooo`<000000P3oool300000080oooo0`000002
0?ooo`D000000P3oool300000080oooo0`0000020?ooo`@0000000<0oooo0000000000000P000000
0`3oool0000000000002000000030?ooo`0000000000008000000P3oool300000080oooo0`000002
0?ooo`<000000P3oool3000002T0oooo6`3AcJT001X0dLfY:@3oool2000000030?ooo`0000000000
00D0oooo0P0000000`3oool00000000000050?ooo`8000000P3oool00`000000oooo0?ooo`030?oo
o`8000000P3oool2000000D0oooo00<000000?ooo`3oool00P0000050?ooo`8000001@3oool00`00
0000oooo0?ooo`02000000D0oooo0P0000000`3oool00000000000050?ooo`80000000<0oooo0000
000000001@3oool200000080oooo00<000000?ooo`3oool00`3oool200000080oooo0P00000Z0?oo
oa/0dLfY000J0=7=ZBT0oooo0P0000000`3oool00000000000050?ooo`80000000<0oooo00000000
00001@3oool200000080oooo00<000000?ooo`3oool00`3oool200000080oooo0P0000050?ooo`03
0000003oool0oooo008000001@3oool2000000D0oooo00<000000?ooo`3oool00P0000050?ooo`80
000000<0oooo0000000000001@3oool2000000030?ooo`000000000000D0oooo0P0000020?ooo`03
0000003oool0oooo00<0oooo0P0000020?ooo`800000:P3ooolK0=7=Z@006P3AcJT[0?ooo`D00000
00<0oooo0000000000000`0000090?ooo`D000000P3oool5000000P0oooo1@0000020?ooo`D00000
0P3oool5000000T0oooo1@0000000`3oool0000000000003000000T0oooo1@0000020?ooo`D00000
;03ooolK0=7=Z@006P3AcJT[0?ooo`D0000000<0oooo0000000000000`0000090?ooo`D000000P3o
ool5000000P0oooo1@0000020?ooo`D000000P3oool5000000T0oooo1@0000000`3oool000000000
0003000000T0oooo1@0000020?ooo`D00000;03ooolK0=7=Z@006P3AcJT/0?ooo`8000001@3oool2
000000`0oooo00<000000?ooo`3oool00`3oool2000000`0oooo0P0000050?ooo`8000001@3oool0
0`000000oooo0?ooo`0:0?ooo`8000001@3oool2000000`0oooo00<000000?ooo`3oool00`3oool2
000002h0oooo6`3AcJT001X0dLfY;P3oool300000080oooo0P0000000`3oool00000000000020000
0080oooo0`0000020?ooo`030000003oool0oooo00<00000403oool300000080oooo0P0000000`3o
ool0000000000002000000l0oooo0`0000020?ooo`80000000<0oooo0000000000000P0000020?oo
o`<000000P3oool00`000000oooo0?ooo`0300000300oooo6`3AcJT001X0dLfY;P3oool300000080
oooo0P0000000`3oool000000000000200000080oooo0`0000020?ooo`030000003oool0oooo00<0
0000403oool300000080oooo0P0000000`3oool0000000000002000000l0oooo0`0000020?ooo`80
000000<0oooo0000000000000P0000020?ooo`<000000P3oool00`000000oooo0?ooo`0300000300
oooo6`3AcJT001X0dLfY<03oool00`000000oooo0?ooo`02000000030?ooo`000000000000D0oooo
0P0000020?ooo`030000003oool0oooo008000004P3oool200000080oooo0P0000000`3oool00000
0000000C0?ooo`030000003oool0oooo0080000000<0oooo0000000000001@3oool200000080oooo
00<000000?ooo`3oool00P00000a0?oooa/0dLfY000J0=7=ZC00oooo00<000000?ooo`3oool00P00
00000`3oool00000000000050?ooo`8000000P3oool00`000000oooo0?ooo`0200000180oooo0P00
00020?ooo`80000000<0oooo0000000000004`3oool00`000000oooo0?ooo`02000000030?ooo`00
0000000000D0oooo0P0000020?ooo`030000003oool0oooo00800000<@3ooolK0=7=Z@006P3AcJTa
0?ooo`D000002@3oool5000001H0oooo1@00000F0?ooo`D000002@3oool5000003<0oooo6`3AcJT0
01X0dLfY<@3oool5000000T0oooo1@00000F0?ooo`D000005P3oool5000000T0oooo1@00000c0?oo
oa/0dLfY000J0=7=ZC<0oooo0P00000<0?ooo`030000003oool0oooo01P0oooo0P00000I0?ooo`80
0000303oool00`000000oooo0?ooo`0c0?oooa/0dLfY000J0=7=ZCD0oooo0`0000020?ooo`<00000
0P3oool500000080oooo0`0000020?ooo`<000000P3oool300000080oooo0`0000020?ooo`D00000
0P3oool300000080oooo0`0000020?ooo`@0000000<0oooo0000000000000P0000000`3oool00000
0000000300000080oooo100000000`3oool0000000000002000003H0oooo6`3AcJT001X0dLfY=@3o
ool300000080oooo0`0000020?ooo`D000000P3oool300000080oooo0`0000020?ooo`<000000P3o
ool300000080oooo1@0000020?ooo`<000000P3oool300000080oooo100000000`3oool000000000
0002000000030?ooo`000000000000<000000P3oool4000000030?ooo`000000000000800000=P3o
oolK0=7=Z@006P3AcJTf0?ooo`8000000P3oool2000000D0oooo00<000000?ooo`3oool00`3oool2
00000080oooo0P0000050?ooo`030000003oool0oooo008000001@3oool2000000D0oooo00<00000
0?ooo`3oool00P0000050?ooo`80000000<0oooo0000000000001@3oool2000000D0oooo0P000000
0`3oool000000000000h0?oooa/0dLfY000J0=7=ZCH0oooo0P0000020?ooo`8000001@3oool00`00
0000oooo0?ooo`030?ooo`8000000P3oool2000000D0oooo00<000000?ooo`3oool00P0000050?oo
o`8000001@3oool00`000000oooo0?ooo`02000000D0oooo0P0000000`3oool00000000000050?oo
o`8000001@3oool2000000030?ooo`000000000003P0oooo6`3AcJT001X0dLfY>03oool500000080
oooo1@0000020?ooo`D00000203oool500000080oooo1@0000020?ooo`D000002@3oool500000003
0?ooo`000000000000<000000P3oool5000003X0oooo6`3AcJT001X0dLfY>P3oool2000000D0oooo
00<000000?ooo`3oool00`3oool2000000`0oooo0P0000050?ooo`8000001@3oool00`000000oooo
0?ooo`0:0?ooo`8000001@3oool2000000D0oooo0P00000k0?oooa/0dLfY000J0=7=ZCX0oooo0P00
00050?ooo`030000003oool0oooo00<0oooo0P00000<0?ooo`8000001@3oool2000000D0oooo00<0
00000?ooo`3oool02P3oool2000000D0oooo0P0000050?ooo`800000>`3ooolK0=7=Z@006P3AcJTl
0?ooo`<000000P3oool00`000000oooo0?ooo`0300000100oooo0`0000020?ooo`80000000<0oooo
0000000000000P00000?0?ooo`<000000P3oool2000000030?ooo`000000000000800000?@3ooolK
0=7=Z@006P3AcJTl0?ooo`<000000P3oool00`000000oooo0?ooo`0300000100oooo0`0000020?oo
o`80000000<0oooo0000000000000P00000?0?ooo`<000000P3oool2000000030?ooo`0000000000
00800000?@3ooolK0=7=Z@006P3AcJTm0?ooo`8000000P3oool00`000000oooo0?ooo`0200000180
oooo0P0000020?ooo`80000000<0oooo0000000000004`3oool00`000000oooo0?ooo`0200000003
0?ooo`000000000003l0oooo6`3AcJT001X0dLfY?`3oool5000001H0oooo1@00000F0?ooo`D00000
@@3ooolK0=7=Z@006P3AcJTo0?ooo`D000005P3oool5000001H0oooo1@0000110?oooa/0dLfY000J
0=7=ZD40oooo00<000000?ooo`3oool0603oool2000001T0oooo0P0000120?oooa/0dLfY000J0=7=
ZD40oooo00<000000?ooo`3oool0603oool2000001T0oooo0P0000120?oooa/0dLfY000J0=7=ZD80
oooo100000000`3oool000000000000200000080oooo0`0000020?ooo`<000000P3oool300000080
oooo0P0000000`3oool0000000000002000000030?ooo`00000000000080000000<0oooo00000000
00000P0000020?ooo`<000000P3oool3000004@0oooo6`3AcJT001X0dLfY@P3oool4000000030?oo
o`0000000000008000000P3oool300000080oooo0`0000020?ooo`<000000P3oool2000000030?oo
o`00000000000080000000<0oooo0000000000000P0000000`3oool000000000000200000080oooo
0`0000020?ooo`<00000A03ooolK0=7=Z@006P3AcJU40?ooo`80000000<0oooo0000000000001@3o
ool200000080oooo00<000000?ooo`3oool00`3oool200000080oooo0P0000000`3oool000000000
00050?ooo`80000000<0oooo0000000000001@3oool200000080oooo00<000000?ooo`3oool0A03o
oolK0=7=Z@006P3AcJU60?ooo`D000000P3oool5000000P0oooo1@0000090?ooo`D000000P3oool5
000004L0oooo6`3AcJT001X0dLfYAP3oool500000080oooo1@0000080?ooo`D000002@3oool50000
0080oooo1@0000170?oooa/0dLfY000J0=7=ZDL0oooo0P0000050?ooo`800000303oool2000000/0
oooo0P0000050?ooo`800000B@3ooolK0=7=Z@006P3AcJU70?ooo`8000001@3oool2000000`0oooo
0P00000;0?ooo`8000001@3oool2000004T0oooo6`3AcJT001X0dLfYB@3oool4000000030?ooo`00
000000000080oooo0`0000020?ooo`<000000P3oool2000000030?ooo`00000000000080000000<0
oooo0000000000000P0000000`3oool00000000000020?ooo`<00000B`3ooolK0=7=Z@006P3AcJU;
0?ooo`80000000<0oooo0000000000000P3oool00`000000oooo0?ooo`030?ooo`8000000P3oool2
000000030?ooo`000000000000D0oooo0P0000000`3oool00000000000020?ooo`800000C03ooolK
0=7=Z@006P3AcJU;0?ooo`80000000<0oooo0000000000000P3oool00`000000oooo0?ooo`030?oo
o`8000000P3oool2000000030?ooo`000000000000D0oooo0P0000000`3oool00000000000020?oo
o`800000C03ooolK0=7=Z@006P3AcJU=0?ooo`D00000203oool5000000T0oooo1@00001>0?oooa/0
dLfY000J0=7=ZDd0oooo1@0000080?ooo`D000002@3oool5000004h0oooo6`3AcJT001X0dLfYCP3o
ool2000000`0oooo0P00000;0?ooo`800000D03ooolK0=7=Z@006P3AcJU@0?ooo`<000000P3oool3
00000080oooo1@0000020?ooo`<000000P3oool300000580oooo6`3AcJT001X0dLfYD03oool30000
0080oooo0`0000020?ooo`D000000P3oool300000080oooo0`00001B0?oooa/0dLfY000J0=7=ZE80
oooo00<000000?ooo`3oool00P0000050?ooo`8000001@3oool00`000000oooo0?ooo`02000005<0
oooo6`3AcJT001X0dLfYDP3oool00`000000oooo0?ooo`02000000D0oooo0P0000050?ooo`030000
003oool0oooo00800000D`3ooolK0=7=Z@006P3AcJUC0?ooo`D000000P3oool500000080oooo1@00
001E0?oooa/0dLfY000J0=7=ZE<0oooo1@0000020?ooo`D000000P3oool5000005D0oooo6`3AcJT0
01X0dLfYE@3oool2000000D0oooo0P0000050?ooo`030000003oool0oooo05D0oooo6`3AcJT001X0
dLfYE`3oool300000080oooo0P0000000`3oool0000000000002000005P0oooo6`3AcJT001X0dLfY
E`3oool300000080oooo0P0000000`3oool0000000000002000005P0oooo6`3AcJT001X0dLfYF03o
ool200000080oooo0P0000000`3oool000000000001J0?oooa/0dLfY000J0=7=ZEP0oooo0P000002
0?ooo`80000000<0oooo000000000000FP3ooolK0=7=Z@006P3AcJUJ0?ooo`D00000G03ooolK0=7=
Z@006P3AcJUL0?ooo`800000G@3ooolK0=7=Z@006P3AcJUL0?ooo`800000G@3ooolK0=7=Z@00l03A
cJT00?00dLfY003`0=7=Z@00l03AcJT00?00dLfY003`0=7=Z@00l03AcJT00?00dLfY001_0=7=Z@E0
00000P3AcJT2@00000@0dLfY0T00001b0=7=Z@00L@3AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@1_0=7=Z@00L@3AcJT01D000000
dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@1_0=7=
Z@00L@3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJT0dLfY0T00001b
0=7=Z@00L@3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00E000000=7=Z@3AcJT0dLfY@000
001c0=7=Z@00L03AcJT2@00000@0dLfY0T0000040=7=Z@=00000L@3AcJT00?00dLfY003`0=7=Z@00
l03AcJT00?00dLfY003`0=7=Z@00l03AcJT00?00dLfY003`0=7=Z@00l03AcJT00?00dLfY003`0=7=
Z@00l03AcJT00?00dLfY003`0=7=Z@00l03AcJT001X0dLfYG03oool3000001P0oooo0`00000H0?oo
o`@000005`3oool4000000X0oooo6`3AcJT001X0dLfYG03oool3000001P0oooo0`00000H0?ooo`@0
00005`3oool4000000X0oooo6`3AcJT001X0dLfYG03oool2000001T0oooo0P00000I0?ooo`800000
6@3oool2000000`0oooo6`3AcJT001X0dLfYG03ooolK000001/0oooo6`00000>0?oooa/0dLfY000J
0=7=ZE`0oooo6`00000K0?oooa/000003P3ooolK0=7=Z@006P3AcJUL0?ooo`80000000<0oooo0000
000000000P3oool00`000000oooo0?ooo`02000000030?ooo`00000000000080oooo0P0000000`3o
ool00000000000020?ooo`030000003oool0oooo01/0oooo0P0000020?ooo`030000003oool0oooo
0080000000<0oooo0000000000000P3oool2000000030?ooo`00000000000080oooo00<000000?oo
o`3oool00P00000?0?oooa/0dLfY000J0=7=ZE`0oooo0P0000000`3oool00000000000020?ooo`03
0000003oool0oooo0080000000<0oooo0000000000000P3oool2000000030?ooo`00000000000080
oooo00<000000?ooo`3oool06`3oool200000080oooo00<000000?ooo`3oool00P0000000`3oool0
0000000000020?ooo`80000000<0oooo0000000000000P3oool00`000000oooo0?ooo`02000000l0
oooo6`3AcJT001X0dLfYG03oool3000000@0oooo0`0000030?ooo`@000000`3oool4000001h0oooo
100000030?ooo`<00000103oool3000000@0oooo0`00000A0?oooa/0dLfY000J0=7=ZE`0oooo0`00
00040?ooo`<000000`3oool4000000<0oooo1000000N0?ooo`@000000`3oool3000000@0oooo0`00
00040?ooo`<000004@3ooolK0=7=Z@006P3AcJUL0?ooo`8000001@3oool00`000000oooo0?ooo`03
0?ooo`8000001@3oool200000200oooo0P0000050?ooo`8000001@3oool2000000D0oooo00<00000
0?ooo`3oool04@3ooolK0=7=Z@006P3AcJUL0?ooo`L000001P3oool700000280oooo1`0000070?oo
o`L00000503ooolK0=7=Z@006P3AcJUL0?ooo`L000001P3oool700000280oooo1`0000070?ooo`L0
0000503ooolK0=7=Z@006P3AcJUL0?ooo`80000000<0oooo000000000000203oool200000080oooo
0P00000S0?ooo`8000000P3oool00`000000oooo0?ooo`070?ooo`80000000<0oooo000000000000
5P3ooolK0=7=Z@006P3AcJUL0?ooo`80000000<0oooo000000000000203oool200000080oooo0P00
000S0?ooo`8000000P3oool00`000000oooo0?ooo`070?ooo`80000000<0oooo0000000000005P3o
oolK0=7=Z@006P3AcJUL0?ooo`<000002P3oool4000002D0oooo1000000:0?ooo`<00000603ooolK
0=7=Z@006P3AcJUL0?ooo`8000002`3oool2000002L0oooo0P00000<0?ooo`8000006@3ooolK0=7=
Z@006P3AcJUL0?ooo`8000002`3oool2000002L0oooo0P00000<0?ooo`8000006@3ooolK0=7=Z@00
6P3AcJUL0?ooo`d00000:@3oool>000001/0oooo6`3AcJT001X0dLfYG03oool=000002T0oooo3P00
000K0?oooa/0dLfY000J0=7=ZE`0oooo0P0000000`3oool00000000000020?ooo`030000003oool0
oooo00800000:P3oool200000080oooo00<000000?ooo`3oool00P0000000`3oool000000000000M
0?oooa/0dLfY000J0=7=ZE`0oooo0`0000040?ooo`<00000;03oool4000000<0oooo0`00000O0?oo
oa/0dLfY000J0=7=ZE`0oooo0`0000040?ooo`<00000;03oool4000000<0oooo0`00000O0?oooa/0
dLfY000J0=7=ZE`0oooo0P0000050?ooo`030000003oool0oooo02`0oooo0P0000050?ooo`800000
803ooolK0=7=Z@006P3AcJUL0?ooo`8000001@3oool00`000000oooo0?ooo`0/0?ooo`8000001@3o
ool200000200oooo6`3AcJT001X0dLfYG03oool7000002l0oooo1`00000R0?oooa/0dLfY000J0=7=
ZE`0oooo1`00000_0?ooo`L000008P3ooolK0=7=Z@006P3AcJUL0?ooo`80000000<0oooo00000000
0000<@3oool200000080oooo00<000000?ooo`3oool08P3ooolK0=7=Z@006P3AcJUL0?ooo`<00000
<`3oool4000002D0oooo6`3AcJT001X0dLfYG03oool3000003<0oooo1000000U0?oooa/0dLfY000J
0=7=ZE`0oooo0P00000d0?ooo`8000009`3ooolK0=7=Z@006P3AcJUL0?ooo`800000=03oool20000
02L0oooo6`3AcJT001X0dLfYG03ooolf000002T0oooo6`3AcJT001X0dLfYG03oool2000000030?oo
o`00000000000080oooo00<000000?ooo`3oool00P0000000`3oool00000000000020?ooo`800000
00<0oooo0000000000000P3oool00`000000oooo0?ooo`02000000030?ooo`00000000000080oooo
0P0000000`3oool00000000000020?ooo`030000003oool0oooo0080000000<0oooo000000000000
0P3oool2000002X0oooo6`3AcJT001X0dLfYG03oool2000000030?ooo`00000000000080oooo00<0
00000?ooo`3oool00P0000000`3oool00000000000020?ooo`80000000<0oooo0000000000000P3o
ool00`000000oooo0?ooo`02000000030?ooo`00000000000080oooo0P0000000`3oool000000000
00020?ooo`030000003oool0oooo0080000000<0oooo0000000000000P3oool2000002X0oooo6`3A
cJT001X0dLfYG03oool3000000@0oooo0`0000030?ooo`@000000`3oool4000000<0oooo0`000004
0?ooo`<00000103oool3000000<0oooo1000000/0?oooa/0dLfY000J0=7=ZE`0oooo0`0000040?oo
o`<000000`3oool4000000<0oooo100000030?ooo`<00000103oool3000000@0oooo0`0000030?oo
o`@00000;03ooolK0=7=Z@006P3AcJUL0?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`80
00001@3oool2000000D0oooo0P0000050?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`80
0000;P3ooolK0=7=Z@006P3AcJUL0?ooo`L000001P3oool7000000L0oooo1`0000070?ooo`H00000
<03ooolK0=7=Z@006P3AcJUL0?ooo`L000001P3oool7000000L0oooo1`0000070?ooo`H00000<03o
oolK0=7=Z@006P3AcJUL0?ooo`80000000<0oooo000000000000203oool200000080oooo0P000008
0?ooo`80000000<0oooo0000000000002@3oool00`000000oooo0?ooo`0200000340oooo6`3AcJT0
01X0dLfYG03oool2000000030?ooo`000000000000P0oooo0P0000020?ooo`800000203oool20000
00030?ooo`000000000000T0oooo00<000000?ooo`3oool00P00000a0?oooa/0dLfY000J0=7=ZE`0
oooo0`00000:0?ooo`@000002P3oool3000000/0oooo0`00000c0?oooa/0dLfY000J0=7=ZE`0oooo
0`00000:0?ooo`@000002P3oool3000000/0oooo0`00000c0?oooa/0dLfY000J0=7=ZE`0oooo0P00
000;0?ooo`800000303oool2000000`0oooo00<000000?ooo`3oool0<`3ooolK0=7=Z@006P3AcJUL
0?ooo`d000003P3oool>000003H0oooo6`3AcJT001X0dLfYG03oool=000000h0oooo3P00000f0?oo
oa/0dLfY000J0=7=ZE`0oooo0P0000000`3oool00000000000020?ooo`030000003oool0oooo0080
00003`3oool2000000030?ooo`00000000000080oooo0P0000000`3oool000000000000h0?oooa/0
dLfY000J0=7=ZE`0oooo0P0000000`3oool00000000000020?ooo`030000003oool0oooo00800000
3`3oool2000000030?ooo`00000000000080oooo0P0000000`3oool000000000000h0?oooa/0dLfY
000J0=7=ZE`0oooo0`0000040?ooo`<000004@3oool3000000@0oooo0`00000j0?oooa/0dLfY000J
0=7=ZE`0oooo0P0000050?ooo`030000003oool0oooo0140oooo0P0000050?ooo`800000>`3ooolK
0=7=Z@006P3AcJUL0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`8000001@3oool20000
03/0oooo6`3AcJT001X0dLfYG03oool7000001@0oooo1`00000m0?oooa/0dLfY000J0=7=ZE`0oooo
1`00000D0?ooo`L00000?@3ooolK0=7=Z@006P3AcJUL0?ooo`80000000<0oooo0000000000005P3o
ool2000000030?ooo`000000000003l0oooo6`3AcJT001X0dLfYG03oool3000001P0oooo0`000011
0?oooa/0dLfY000J0=7=ZE`0oooo0`00000H0?ooo`<00000@@3ooolK0=7=Z@006P3AcJUL0?ooo`80
00006@3oool200000480oooo6`3AcJT001X0dLfYG03oool2000001T0oooo0P0000120?oooa/0dLfY
000J0=7=ZE`0oooo6`0000140?oooa/0dLfY000J0=7=ZE`0oooo6`0000140?oooa/0dLfY000J0=7=
ZE`0oooo0P0000000`3oool00000000000020?ooo`030000003oool0oooo0080000000<0oooo0000
000000000P3oool2000000030?ooo`00000000000080oooo00<000000?ooo`3oool0A03ooolK0=7=
Z@006P3AcJUL0?ooo`<00000103oool3000000<0oooo100000030?ooo`@00000A`3ooolK0=7=Z@00
6P3AcJUL0?ooo`<00000103oool3000000<0oooo100000030?ooo`@00000A`3ooolK0=7=Z@006P3A
cJUL0?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`8000001@3oool2000004T0oooo6`3A
cJT001X0dLfYG03oool2000000D0oooo00<000000?ooo`3oool00`3oool2000000D0oooo0P000019
0?oooa/0dLfY000J0=7=ZE`0oooo1`0000060?ooo`L00000B`3ooolK0=7=Z@006P3AcJUL0?ooo`80
000000<0oooo000000000000203oool200000080oooo0P00001<0?oooa/0dLfY000J0=7=ZE`0oooo
0P0000000`3oool00000000000080?ooo`8000000P3oool2000004`0oooo6`3AcJT001X0dLfYG03o
ool3000000X0oooo1000001>0?oooa/0dLfY000J0=7=ZE`0oooo0`00000:0?ooo`@00000CP3ooolK
0=7=Z@006P3AcJUL0?ooo`8000002`3oool200000500oooo6`3AcJT001X0dLfYG03oool=00000580
oooo6`3AcJT001X0dLfYG03oool=00000580oooo6`3AcJT001X0dLfYG03oool2000000030?ooo`00
000000000080oooo00<000000?ooo`3oool00P00001C0?oooa/0dLfY000J0=7=ZE`0oooo0P000000
0`3oool00000000000020?ooo`030000003oool0oooo00800000D`3ooolK0=7=Z@006P3AcJUL0?oo
o`<00000103oool3000005D0oooo6`3AcJT001X0dLfYG03oool3000000@0oooo0`00001E0?oooa/0
dLfY000J0=7=ZE`0oooo0P0000050?ooo`030000003oool0oooo05D0oooo6`3AcJT001X0dLfYG03o
ool7000005P0oooo6`3AcJT001X0dLfYG03oool7000005P0oooo6`3AcJT001X0dLfYG03oool20000
00030?ooo`000000000005X0oooo6`3AcJT001X0dLfYG03oool2000000030?ooo`000000000005X0
oooo6`3AcJT001X0dLfYG03oool3000005`0oooo6`3AcJT001X0dLfYG03oool2000005d0oooo6`3A
cJT001X0dLfYG03oool2000005d0oooo6`3AcJT00?00dLfY003`0=7=Z@00l03AcJT00?00dLfY003`
0=7=Z@00l03AcJT00?00dLfY003`0=7=Z@00LP3AcJT3@00000@0dLfY0T00001e0=7=Z@00LP3AcJT0
14000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00007@0dLfY001b0=7=Z@04@000003A
cJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000M03AcJT00780dLfY0d0000030=7=Z@04@000
003AcJT0dLfY@00007@0dLfY001c0=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU0
0000M03AcJT007<0dLfY0d0000030=7=Z@900000M@3AcJT00?00dLfY003`0=7=Z@00l03AcJT00?00
dLfY003`0=7=Z@00l03AcJT00?00dLfY003`0=7=Z@00l03AcJT00?00dLfY003`0=7=Z@00l03AcJT0
0?00dLfY003`0=7=Z@00l03AcJT001X0dLfYG03ooomE000000X0oooo6`3AcJT001X0dLfYG03ooomE
000000X0oooo6`3AcJT001X0dLfYG03ooomC000000`0oooo6`3AcJT001X0dLfYG03ooomA000000h0
oooo6`3AcJT001X0dLfYG03ooomA000000h0oooo6`3AcJT001X0dLfYG03ooom@000000l0oooo6`3A
cJT001X0dLfYG03ooom@000000l0oooo6`3AcJT001X0dLfYG03ooom>00000140oooo6`3AcJT001X0
dLfYG03ooom>00000140oooo6`3AcJT001X0dLfYG03ooom<000001<0oooo6`3AcJT001X0dLfYG03o
oom;000001@0oooo6`3AcJT001X0dLfYG03ooom;000001@0oooo6`3AcJT001X0dLfYG03ooom90000
01H0oooo6`3AcJT001X0dLfYG03ooom9000001H0oooo6`3AcJT001X0dLfYG03ooom7000001P0oooo
6`3AcJT001X0dLfYG03ooom6000001T0oooo6`3AcJT001X0dLfYG03ooom6000001T0oooo6`3AcJT0
01X0dLfYG03ooom4000001/0oooo6`3AcJT001X0dLfYG03ooom4000001/0oooo6`3AcJT001X0dLfY
G03ooom2000001d0oooo6`3AcJT001X0dLfYG03ooom0000001l0oooo6`3AcJT001X0dLfYG03ooom0
000001l0oooo6`3AcJT001X0dLfYG03ooolo00000200oooo6`3AcJT001X0dLfYG03ooolo00000200
oooo6`3AcJT001X0dLfYG03ooolm00000280oooo6`3AcJT001X0dLfYG03ooolm00000280oooo6`3A
cJT001X0dLfYG03ooolk000002@0oooo6`3AcJT001X0dLfYG03ooolj000002D0oooo6`3AcJT001X0
dLfYG03ooolj000002D0oooo6`3AcJT001X0dLfYG03ooolh000002L0oooo6`3AcJT001X0dLfYG03o
oolh000002L0oooo6`3AcJT001X0dLfYG03ooolf000002T0oooo6`3AcJT001X0dLfYG03ooole0000
02X0oooo6`3AcJT001X0dLfYG03ooole000002X0oooo6`3AcJT001X0dLfYG03ooolc000002`0oooo
6`3AcJT001X0dLfYG03ooolc000002`0oooo6`3AcJT001X0dLfYG03ooola000002h0oooo6`3AcJT0
01X0dLfYG03oool_00000300oooo6`3AcJT001X0dLfYG03oool_00000300oooo6`3AcJT001X0dLfY
G03oool^00000340oooo6`3AcJT001X0dLfYG03oool^00000340oooo6`3AcJT001X0dLfYG03oool/
000003<0oooo6`3AcJT001X0dLfYG03oool/000003<0oooo6`3AcJT001X0dLfYG03ooolZ000003D0
oooo6`3AcJT001X0dLfYG03ooolY000003H0oooo6`3AcJT001X0dLfYG03ooolY000003H0oooo6`3A
cJT001X0dLfYG03ooolW000003P0oooo6`3AcJT001X0dLfYG03ooolW000003P0oooo6`3AcJT001X0
dLfYG03ooolU000003X0oooo6`3AcJT001X0dLfYG03ooolT000003/0oooo6`3AcJT001X0dLfYG03o
oolT000003/0oooo6`3AcJT001X0dLfYG03ooolR000003d0oooo6`3AcJT001X0dLfYG03ooolR0000
03d0oooo6`3AcJT001X0dLfYG03ooolP000003l0oooo6`3AcJT001X0dLfYG03ooolN00000440oooo
6`3AcJT001X0dLfYG03ooolN00000440oooo6`3AcJT001X0dLfYG03ooolM00000480oooo6`3AcJT0
01X0dLfYG03ooolM00000480oooo6`3AcJT001X0dLfYG03ooolK000004@0oooo6`3AcJT001X0dLfY
G03ooolK000004@0oooo6`3AcJT001X0dLfYG03ooolI000004H0oooo6`3AcJT001X0dLfYG03ooolH
000004L0oooo6`3AcJT001X0dLfYG03ooolH000004L0oooo6`3AcJT001X0dLfYG03ooolF000004T0
oooo6`3AcJT001X0dLfYG03ooolF000004T0oooo6`3AcJT001X0dLfYG03ooolD000004/0oooo6`3A
cJT001X0dLfYG03ooolC000004`0oooo6`3AcJT001X0dLfYG03ooolC000004`0oooo6`3AcJT001X0
dLfYG03ooolA000004h0oooo6`3AcJT001X0dLfYG03ooolA000004h0oooo6`3AcJT001X0dLfYG03o
ool?00000500oooo6`3AcJT001X0dLfYG03oool=00000580oooo6`3AcJT001X0dLfYG03oool=0000
0580oooo6`3AcJT001X0dLfYG03oool<000005<0oooo6`3AcJT001X0dLfYG03oool<000005<0oooo
6`3AcJT001X0dLfYG03oool:000005D0oooo6`3AcJT001X0dLfYG03oool:000005D0oooo6`3AcJT0
01X0dLfYG03oool8000005L0oooo6`3AcJT001X0dLfYG03oool7000005P0oooo6`3AcJT001X0dLfY
G03oool7000005P0oooo6`3AcJT001X0dLfYG03oool5000005X0oooo6`3AcJT001X0dLfYG03oool5
000005X0oooo6`3AcJT001X0dLfYG03oool3000005`0oooo6`3AcJT001X0dLfYG03oool2000005d0
oooo6`3AcJT001X0dLfYG03oool2000005d0oooo6`3AcJT00?00dLfY003`0=7=Z@00l03AcJT00?00
dLfY003`0=7=Z@00l03AcJT00?00dLfY003`0=7=Z@00L`3AcJT2@00000<0dLfY0d00001e0=7=Z@00
LP3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY07<0dLfY001e0=7=Z@04@000
003AcJT0dLfY0=7=Z@=00000M03AcJT007<0dLfY0T0000030=7=Z@04@000003AcJT0dLfY@00007@0
dLfY001c0=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU00000M03AcJT007<0dLfY
0d0000030=7=Z@=00000M03AcJT00?00dLfY003`0=7=Z@00l03AcJT00?00dLfY003`0=7=Z@00l03A
cJT00?00dLfY003`0=7=Z@00l03AcJT00?00dLfY003`0=7=Z@00l03AcJT00?00dLfY003`0=7=Z@00
l03AcJT00?00dLfY003`0=7=Z@00\
\>"],
  ImageRangeCache->{{{0, 239.313}, {588.813, 0}} -> {-0.0250052, -0.0644654, \
0.00438761, 0.00438761}, {{5.6875, 233.563}, {574.063, 470.5}} -> {-15.4804, \
-9.69064, 0.589178, 0.589178}, {{5.6875, 233.563}, {460.125, 356.563}} -> \
{-15.4804, -76.8201, 0.589178, 0.589178}, {{5.6875, 233.563}, {346.188, \
242.563}} -> {-15.4318, -143.851, 0.588772, 0.588772}, {{5.6875, 233.563}, \
{232.25, 128.625}} -> {-15.4318, -210.934, 0.588772, 0.588772}, {{5.6875, \
233.563}, {118.25, 14.6875}} -> {-15.4804, -278.245, 0.589178, 0.589178}}]
}, Open  ]],

Cell["\<\
These CA are included in file reversible2.

As the generations (step) grow, we can see the number of those that are \
reversible up to that point.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(allRules = << allRules2;\)\), "\[IndentingNewLine]", 
    \(\(b = 2;\)\), "\[IndentingNewLine]", 
    \(\(cS = cellularSpace[110];\)\), "\[IndentingNewLine]", 
    \(\(aR = Table[1, {51}];\)\), "\[IndentingNewLine]", 
    \(\(aR\[LeftDoubleBracket]1\[RightDoubleBracket] = 
        allRules;\)\), "\[IndentingNewLine]", 
    \(\(Do[\[IndentingNewLine]aR\[LeftDoubleBracket]
            gen + 1\[RightDoubleBracket] = 
          Select[aR\[LeftDoubleBracket]
              gen\[RightDoubleBracket], \[IndentingNewLine]\((v = 
                  evolve[b, cS, #, gen]; \[IndentingNewLine]reversibleQ[b, 
                  Last[v], #, gen])\) &], {gen, 
          50}];\)\), "\[IndentingNewLine]", 
    \(\(Length[#] &\)\  /@ \ aR\)}], "Input"],

Cell[BoxData[
    \({23, 19, 17, 12, 8, 6, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 
      5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 
      5, 5, 5, 5, 5}\)], "Output",
  CellLabel->"Out[420]="]
}, Open  ]],

Cell["\<\
For triadic CA, however, the following list eliminates all after the 16th \
generation.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(allRules = << totalistic3;\)\), "\[IndentingNewLine]", 
    \(\(b = 3;\)\), "\[IndentingNewLine]", 
    \(\(cS = cellularSpace[50];\)\), "\[IndentingNewLine]", 
    \(\(aR = Table[1, {17}];\)\), "\[IndentingNewLine]", 
    \(\(aR\[LeftDoubleBracket]1\[RightDoubleBracket] = 
        allRules;\)\), "\[IndentingNewLine]", 
    \(\(Do[\[IndentingNewLine]aR\[LeftDoubleBracket]
            gen + 1\[RightDoubleBracket] = 
          Select[aR\[LeftDoubleBracket]
              gen\[RightDoubleBracket], \[IndentingNewLine]\((v = 
                  evolve[b, cS, #, gen]; \[IndentingNewLine]reversibleQ[b, 
                  Last[v], #, gen])\) &], {gen, 
          16}];\)\), "\[IndentingNewLine]", 
    \(\(Length[#] &\)\  /@ \ aR\)}], "Input"],

Cell[BoxData[
    \({99, 60, 56, 39, 33, 25, 17, 13, 8, 4, 4, 4, 4, 2, 2, 1, 0}\)], "Output",\

  CellLabel->"Out[121]="]
}, Open  ]],

Cell["\<\
And the only one keeping its reversibility condition for as long as possible \
up to the 15th generation is:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gen = 15;\)\), "\[IndentingNewLine]", 
    \(\(aR = 
        Select[allRules, \[IndentingNewLine]\((v = 
                evolve[b, cS, #, gen]; \[IndentingNewLine]reversibleQ[b, 
                Last[v], #, gen])\) &];\)\), "\[IndentingNewLine]", 
    \(\(g = 
        Map[showCA[b, cS, #, gen, 1, 1, 43, 2] &, 
          aR];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Partition[g, 1]], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .34884 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.00830565 0.952381 [
[ 0 0 0 0 ]
[ 1 .34884 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .34884 L
0 .34884 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00830565 0.97619 0.340532 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0223614 0.00670841 0.0223614 [
[.5 .36134 -41 0 ]
[.5 .36134 41 12.875 ]
[ 0 0 0 0 ]
[ 1 .34884 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .36134 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1576639413142) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .34884 L
0 .34884 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00671 translate
.96154 .33542 scale
43 string
43 15 8 [43 0 0 15 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFF8000FFFFFF80FFFF00FFFF80800080008080FFFF00FFFF80FFFF
FF0080FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF808080808000FF80808080008000800080808080FF00808080
8080FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF80FFFF80FF800080800080008000800080800080FF80FFFF
80FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF008080FFFF80800000008080FFFF808000FF0080
FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF808080FFFF8000FF0000800000FF0080FFFF808080FF
FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFF808080FF80FF808080FFFFFFFF80FFFF
FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000808000FF0080800080FF0080FFFFFF
FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF808080000000FFFFFF000000808080FFFFFFFF
FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFF00FFFFFFFFFF00FFFF80FFFFFFFFFF
FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FFFFFFFFFFFFFF0080FFFFFFFFFFFF
FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF808080808080808080FFFFFFFFFFFFFF
FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFF80FFFF80FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF0080FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF808080FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 100.438},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000I2000`400?l00000o`00003oo`3AcJTQ
0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@008P3AcJTc
ooooo`D0P8201@00000?ooooo`D0P8202oooool5000000[ooooo2P20P805000000D0P8201@00000;
0820P0[ooooo1@00000:ooooo`D0P8203oooool5000000H0P8205?oooolS0=7=Z@008P3AcJTcoooo
o`D0P8201@00000?ooooo`D0P8202oooool5000000[ooooo2P20P805000000D0P8201@00000;0820
P0[ooooo1@00000:ooooo`D0P8203oooool5000000H0P8205?oooolS0=7=Z@008P3AcJTcooooo`D0
P8201@00000?ooooo`D0P8202oooool5000000[ooooo2P20P805000000D0P8201@00000;0820P0[o
oooo1@00000:ooooo`D0P8203oooool5000000H0P8205?oooolS0=7=Z@008P3AcJTcooooo`D0P820
1@00000?ooooo`D0P8202oooool5000000[ooooo2P20P805000000D0P8201@00000;0820P0[ooooo
1@00000:ooooo`D0P8203oooool5000000H0P8205?oooolS0=7=Z@008P3AcJTcooooo`D0P8201@00
000?ooooo`D0P8202oooool5000000[ooooo2P20P805000000D0P8201@00000;0820P0[ooooo1@00
000:ooooo`D0P8203oooool5000000H0P8205?oooolS0=7=Z@008P3AcJThoooooaT0P8201P000005
oooooa@0P8201@0000050820P0D000001@20P805000001D0P8201Oooool5000001T0P8206_oooolS
0=7=Z@008P3AcJThoooooaT0P8201P000005oooooa@0P8201@0000050820P0D000001@20P8050000
01D0P8201Oooool5000001T0P8206_oooolS0=7=Z@008P3AcJThoooooaT0P8201P000005oooooa@0
P8201@0000050820P0D000001@20P805000001D0P8201Oooool5000001T0P8206_oooolS0=7=Z@00
8P3AcJThoooooaT0P8201P000005oooooa@0P8201@0000050820P0D000001@20P805000001D0P820
1Oooool5000001T0P8206_oooolS0=7=Z@008P3AcJThoooooaT0P8201P000005oooooa@0P8201@00
00050820P0D000001@20P805000001D0P8201Oooool5000001T0P8206_oooolS0=7=Z@008P3AcJTm
ooooo`D0P8202_ooool50820P0Kooooo1@20P805000000X0P8201@0000050820P0D000001@20P805
000000D0P8201P00000:0820P0D000001@20P805ooooo`D0P8202_ooool50820P1oooooo8`3AcJT0
0280dLfY?Oooool50820P0[ooooo1@20P806ooooo`D0P8201@00000:0820P0D000001@20P8050000
00D0P8201@0000050820P0H000002P20P805000000D0P8201Oooool50820P0[ooooo1@20P80Ooooo
ob<0dLfY000R0=7=ZCgooooo1@20P80:ooooo`D0P8201_ooool50820P0D000002P20P805000000D0
P8201@0000050820P0D000001@20P806000000X0P8201@0000050820P0Gooooo1@20P80:ooooo`D0
P8207ooooolS0=7=Z@008P3AcJTmooooo`D0P8202_ooool50820P0Kooooo1@20P805000000X0P820
1@0000050820P0D000001@20P805000000D0P8201P00000:0820P0D000001@20P805ooooo`D0P820
2_ooool50820P1oooooo8`3AcJT00280dLfY?Oooool50820P0[ooooo1@20P806ooooo`D0P8201@00
000:0820P0D000001@20P805000000D0P8201@0000050820P0H000002P20P805000000D0P8201Ooo
ool50820P0[ooooo1@20P80Oooooob<0dLfY000R0=7=ZD;ooooo1@20P805000000Gooooo1P00000:
0820P0[ooooo2P20P80?000000/0P8202_ooool:0820P0D000001Oooool5000000D0P8209?oooolS
0=7=Z@008P3AcJU2ooooo`D0P8201@000005ooooo`H000002P20P80:ooooo`X0P8203`00000;0820
P0[ooooo2P20P805000000Gooooo1@0000050820P2Cooooo8`3AcJT00280dLfY@_ooool50820P0D0
00001Oooool6000000X0P8202_ooool:0820P0l000002`20P80:ooooo`X0P8201@000005ooooo`D0
00001@20P80Tooooob<0dLfY000R0=7=ZD;ooooo1@20P805000000Gooooo1P00000:0820P0[ooooo
2P20P80?000000/0P8202_ooool:0820P0D000001Oooool5000000D0P8209?oooolS0=7=Z@008P3A
cJU2ooooo`D0P8201@000005ooooo`H000002P20P80:ooooo`X0P8203`00000;0820P0[ooooo2P20
P805000000Gooooo1@0000050820P2Cooooo8`3AcJT00280dLfYAoooool@0820P0[ooooo1@20P805
000000Gooooo2P0000050820P0X000001_ooool5000000D0P8202_ooool?0820P2Wooooo8`3AcJT0
0280dLfYAoooool@0820P0[ooooo1@20P805000000Gooooo2P0000050820P0X000001_ooool50000
00D0P8202_ooool?0820P2Wooooo8`3AcJT00280dLfYAoooool@0820P0[ooooo1@20P805000000Go
oooo2P0000050820P0X000001_ooool5000000D0P8202_ooool?0820P2Wooooo8`3AcJT00280dLfY
Aoooool@0820P0[ooooo1@20P805000000Gooooo2P0000050820P0X000001_ooool5000000D0P820
2_ooool?0820P2Wooooo8`3AcJT00280dLfYAoooool@0820P0[ooooo1@20P805000000Gooooo2P00
00050820P0X000001_ooool5000000D0P8202_ooool?0820P2Wooooo8`3AcJT00280dLfYC?ooool5
0820P1Gooooo3`20P805ooooo`D0P8201Oooool@0820P1Cooooo1@20P80^ooooob<0dLfY000R0=7=
ZDcooooo1@20P80Eooooo`l0P8201Oooool50820P0Gooooo4020P80Dooooo`D0P820;_oooolS0=7=
Z@008P3AcJU<ooooo`D0P8205Oooool?0820P0Gooooo1@20P805oooooa00P8205?ooool50820P2ko
oooo8`3AcJT00280dLfYC?ooool50820P1Gooooo3`20P805ooooo`D0P8201Oooool@0820P1Cooooo
1@20P80^ooooob<0dLfY000R0=7=ZDcooooo1@20P80Eooooo`l0P8201Oooool50820P0Gooooo4020
P80Dooooo`D0P820;_oooolS0=7=Z@008P3AcJUAooooo`H0P8201@000005ooooo`D0P8201@00000:
0820P0D000001Oooool5000000/0P8201@0000050820P0Gooooo1@0000050820P3?ooooo8`3AcJT0
0280dLfYDOooool60820P0D000001Oooool50820P0D000002P20P805000000Gooooo1@00000;0820
P0D000001@20P805ooooo`D000001@20P80cooooob<0dLfY000R0=7=ZE7ooooo1P20P805000000Go
oooo1@20P805000000X0P8201@000005ooooo`D000002`20P805000000D0P8201Oooool5000000D0
P820<ooooolS0=7=Z@008P3AcJUAooooo`H0P8201@000005ooooo`D0P8201@00000:0820P0D00000
1Oooool5000000/0P8201@0000050820P0Gooooo1@0000050820P3?ooooo8`3AcJT00280dLfYDOoo
ool60820P0D000001Oooool50820P0D000002P20P805000000Gooooo1@00000;0820P0D000001@20
P805ooooo`D000001@20P80cooooob<0dLfY000R0=7=ZEOooooo3`20P80?000000oooooo4000000?
0820P3Sooooo8`3AcJT00280dLfYEoooool?0820P0l000003oooool@000000l0P820>?oooolS0=7=
Z@008P3AcJUGooooo`l0P8203`00000?oooooa0000003`20P80hooooob<0dLfY000R0=7=ZEOooooo
3`20P80?000000oooooo4000000?0820P3Sooooo8`3AcJT00280dLfYEoooool?0820P0l000003ooo
ool@000000l0P820>?oooolS0=7=Z@008P3AcJULooooo`D0P8202_ooool5000001Wooooo1P00000:
ooooo`D0P820?OoooolS0=7=Z@008P3AcJULooooo`D0P8202_ooool5000001Wooooo1P00000:oooo
o`D0P820?OoooolS0=7=Z@008P3AcJULooooo`D0P8202_ooool5000001Wooooo1P00000:ooooo`D0
P820?OoooolS0=7=Z@008P3AcJULooooo`D0P8202_ooool5000001Wooooo1P00000:ooooo`D0P820
?OoooolS0=7=Z@008P3AcJULooooo`D0P8202_ooool5000001Wooooo1P00000:ooooo`D0P820?Ooo
oolS0=7=Z@008P3AcJUQooooo`D0P8201@00000Tooooo`D000001@20P812ooooob<0dLfY000R0=7=
ZF7ooooo1@20P805000002Cooooo1@0000050820P4;ooooo8`3AcJT00280dLfYHOooool50820P0D0
00009?ooool5000000D0P820@_oooolS0=7=Z@008P3AcJUQooooo`D0P8201@00000Tooooo`D00000
1@20P812ooooob<0dLfY000R0=7=ZF7ooooo1@20P805000002Cooooo1@0000050820P4;ooooo8`3A
cJT00280dLfYI_ooool^0820P4Oooooo8`3AcJT00280dLfYI_ooool^0820P4Oooooo8`3AcJT00280
dLfYI_ooool^0820P4Oooooo8`3AcJT00280dLfYI_ooool^0820P4Oooooo8`3AcJT00280dLfYI_oo
ool^0820P4Oooooo8`3AcJT00280dLfYJoooool50820P0[ooooo1@20P80:ooooo`H0P820C?oooolS
0=7=Z@008P3AcJU[ooooo`D0P8202_ooool50820P0[ooooo1P20P81<ooooob<0dLfY000R0=7=ZF_o
oooo1@20P80:ooooo`D0P8202_ooool60820P4cooooo8`3AcJT00280dLfYJoooool50820P0[ooooo
1@20P80:ooooo`H0P820C?oooolS0=7=Z@008P3AcJU[ooooo`D0P8202_ooool50820P0[ooooo1P20
P81<ooooob<0dLfY000R0=7=ZG3ooooo1@20P805000000Gooooo1@0000050820P5;ooooo8`3AcJT0
0280dLfYL?ooool50820P0D000001Oooool5000000D0P820D_oooolS0=7=Z@008P3AcJU`ooooo`D0
P8201@000005ooooo`D000001@20P81Booooob<0dLfY000R0=7=ZG3ooooo1@20P805000000Gooooo
1@0000050820P5;ooooo8`3AcJT00280dLfYL?ooool50820P0D000001Oooool5000000D0P820D_oo
oolS0=7=Z@008P3AcJUeooooo`l0P820EooooolS0=7=Z@008P3AcJUeooooo`l0P820EooooolS0=7=
Z@008P3AcJUeooooo`l0P820EooooolS0=7=Z@008P3AcJUeooooo`l0P820EooooolS0=7=Z@008P3A
cJUeooooo`l0P820EooooolS0=7=Z@008P3AcJUjooooo`D0P820G?oooolS0=7=Z@008P3AcJUjoooo
o`D0P820G?oooolS0=7=Z@008P3AcJUjooooo`D0P820G?oooolS0=7=Z@008P3AcJUjooooo`D0P820
G?oooolS0=7=Z@008P3AcJUjooooo`D0P820G?oooolS0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=
Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=
Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00J@3AcJT5@0000080dLfY0T0000050=7=Z@04@000003A
cJT0dLfY0=7=Z@=000000`3AcJT3@00000@0dLfY0T0000030=7=Z@=000001@3AcJT3@00000030=7=
ZD000010000000=000000P3AcJT2@00000<0dLfY1D0000030=7=Z@=0000000<0dLfY@00004000000
0T00001[0=7=Z@00J`3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0
0P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0103AcJT0
0d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=
Z@020=7=Z@03@000003AcJT0dLfY00@0dLfY00A000000=7=Z@3AcJU00000KP3AcJT006/0dLfY00=0
00000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD000000
0P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3A
cJT00P3AcJT3@0000080dLfY1D0000030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3A
cJT00`3AcJT014000000dLfY0=7=Z@3AcJT5@0000080dLfY00=000000=7=Z@3AcJT0J`3AcJT006/0
dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000H0dLfY00=000000=7=Z@3AcJT00d0000030=7=Z@=0
00001P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=00000
0=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY0080dLfY00E00000
0=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0JP3A
cJT006/0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0
dLfY@00000<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003A
cJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY@00000040=7=Z@05
@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY
0080dLfY00=000000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD00001[0=7=Z@00JP3AcJT2@000
00@0dLfY0d0000020=7=Z@A000000`3AcJT3@00000<0dLfY0d0000030=7=Z@900000103AcJT3@000
00@0dLfY0T0000030=7=Z@900000103AcJT2@00000@0dLfY0T0000050=7=Z@9000000`3AcJT2@000
06`0dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o0=7=
ZB40dLfY0000\
\>"],
  ImageRangeCache->{{{0, 287}, {99.4375, 0}} -> {-0.0285932, -0.00872276, \
0.00368358, 0.00368358}, {{7.75, 279.188}, {97.0625, 2.3125}} -> {-6.81575, \
-0.768822, 0.197365, 0.197365}}]
}, Open  ]],

Cell["In the case of tetradic CA, the sequence starts as:", "Text"],

Cell[BoxData[
    \({21523, 8610, 7997, 6481, 4549, 2763, 1475, 915, 507, 267, 133, 87, 55, 
      41, 34, 24, 22, 21, 16, 14, 10, 9, 8, 8, 6, 6, 5, 5, 5, 4, 4, 4, 4, 4, 
      4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 3, 3, 3, 3, 3}\)], "Output",
  CellLabel->"Out[452]="],

Cell["The last three reversible ones are the following:", "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5534 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0369857 0.952381 [
[ 0 0 0 0 ]
[ 1 1.5534 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.5534 L
0 1.5534 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0369857 0.97619 0.499307 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00933532 0.00933532 0.00933532 [
[.5 .49794 -116 0 ]
[.5 .49794 116 12.875 ]
[ 0 0 0 0 ]
[ 1 .48544 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .49794 -177 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(72901867090519768565735837748145084515) show
291.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .48544 L
0 .48544 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00934 translate
.96154 .46676 scale
103 string
103 50 8 [103 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00555500AAFF000055AAFF00FF5500FFAAAA55FFAA55AAAAAAFFAAFFAA5500FF0000
AA00AA55AAFF0000FF5555005555FFAAFF5555005555FF0000FFAA55AA00AA0000FF0055
AAFFAAFFAAAAAA55AAFF55AAAAFF0055FF00FFAA550000FFAA00555500FFFF
FFFFFFAA55FF000055FF00FF00AAAA55FF00AA55005500AA0055AA00FF00AA55FF00AAAA
0055FFFF000055FF00AA000000AA00FF00AA000000AA00FF550000FFFF5500AAAA00FF55
AA00FF00AA5500AA00550055AA00FF55AAAA00FF00FF550000FF55AAFFFFFF
FFFFFFFF55AAAA00AA00FF5555AA005555FF0000AAAAAA0055FFAAAA00FF55FFAA00AA55
00FFFFFFFFAAFF5555AA00AAAA0055FF5500AAAA00AA5555FFAAFFFFFFFF0055AA00AAFF
55FF00AAAAFF5500AAAAAA0000FF555500AA5555FF00AA00AAAA55FFFFFFFF
FFFFFFFFFF0000FF55FF00AA0000FF55AAFF0055FFFF55FF00FFAAAAFFFFFF00AA555555
00FFAA00FFAAAA55FFAAAA0055AA55FF55AA5500AAAAFF55AAAAFF00AAFF00555555AA00
FFFFFFAAAAFF00FF55FFFF5500FFAA55FF0000AA00FF55FF0000FFFFFFFFFF
FFFFFFFFFFFFAAFF00FFAAFFAAFFFFFF000055FFAA00FFFFFFAA0055AAAA55AA55005555
00FFAAAA00FF0000AAFFAAAA0000FFFFFF0000AAAAFFAA0000FF00AAAAFF0055550055AA
55AAAA5500AAFFFFFF00AAFF550000FFFFFFAAFFAAFF00FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFF5555AAAAFF00005500000000AAFFAAFF00AAFFAAFF55FFFF0000AAAAAA
AA00FF00000055FF000055AA00AAAA55AAAA00AA550000FF55000000FF00AAAAAAAA0000
FFFF55FFAAFFAA00FFAAFFAA00000000550000FFAAAA5555FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF000055FF00FF5500FF55FF55FF5500AAFFAA00005500FF55FFFF
55FF00AAAA00AA00FF550055AA5500AA0055AA550055FF00AA00AAAA00FF55FFFF55FF00
550000AAFFAA0055FF55FF55FF0055FF00FF550000FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA00AAAAAA5555FFAAFF00FFAA55AAFFFF555555AA55FF00AA00FF
AA55AA5500AAAAFFFFFF0055555500FF0055555500FFFFFFAAAA0055AA55AAFF00AA00FF
55AA555555FFFFAA55AAFF00FFAAFF5555AAAAAA00AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5500AA55005555FFFFFFAA00555555FF55AAFF55FFAA00AA5555
FFFF0000AAAAFFAA00FFAAFF55AAFFFFFFAA55FFAAFF00AAFFAAAA0000FFFF5555AA00AA
FF55FFAA55FF55555500AAFFFFFF55550055AA0055FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0055AAFFFF00FFAA00FF00555500550055AAAAAA5500FF00FF
FFFFFFAAFFAAAA5500FFAAAA55FFFFFFFFFF55AAAAFF0055AAAAFFAAFFFFFFFF00FF0055
AAAAAA55005500555500FF00AAFF00FFFFAA5500FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55000055FF55FF00AAAAAAAA000000AA5500AA00AAFFFF
FFFFFFFF5555555500FFAAAAFF5555FF5555FFAAAAFF0055555555FFFFFFFFFFFFAA00AA
0055AA000000AAAAAAAA00FF55FF55000055AAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF55AA55550000AAFFFF55FFFF5500FF55FFAAFFAAFFAA00
FFAA00FFAA55FFAA5555FFFF55550055005555FFFF5555AAFF55AAFF00AAFF00AAFFAAFF
AAFF55FF0055FFFF55FFFFAA00005555AA55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000AA00AAAAFF00AA00FFAA5555FFAA005500AAFFAA
FF00000055AAFF0000AA00FFAA55FF00FF55AAFF00AA0000FFAA55000000FFAAFFAA0055
00AAFF5555AAFF00AA00FFAAAA00AA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAAFFAAAA555555AAAAFF55AAAAFFFF0055AAAA
FF0055FF00FF00AAAA0055FF55FFAA00AAFF55FF5500AAAA00FF00FF5500FFAAAA5500FF
FFAAAA55FFAAAA555555AAAAFFAAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFF55AAFF55FFFFFF0000FFAA00AA0055
AAAA000055FF5500AA55550000AAFFAAFFAA00005555AA0055FF550000AAAA5500AA00AA
FF0000FFFFFF55FFAA55FFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00005555FF5555AA55AA00AA5555
00AA5555AAFF00FF55FFAA5555AA00FF00AA5555AAFF55FF00FFAA5555AA005555AA00AA
55AA5555FF55550000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00FFAA00AAAAAAAA55FFAAAAAAFFFF55AA
FFFF55AAFFAA00AAFF5555550055AA55AA5500555555FFAA00AAFFAA55FFFFAA55FFFFAA
AAAAFF55AAAAAAAA00AAFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550000FF55FFFF55FFAA0055AA00FFAA55
0000555555FFFFAAAA55FFAA555500AA005555AAFF55AAAAFFFF555555000055AAFF00AA
5500AAFF55FFFF55FF000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055FF55AAAA55FF55FF00FF005500AA
00AAAAAAAAAA55AA005555FFFF00FF55FF00FFFF555500AA55AAAAAAAAAA00AA005500FF
00FF55FF55AAAA55FF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55AAFFAAAAAA55FF55000000AAAA
FFFF55FFFF55FFAAAA0000AAFF0055005500FFAA0000AAAAFF55FFFF55FFFFAAAA000000
55FF55AAAAAAFFAA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00FF0000FFFFFF0055FF0000
FFAA000055005500AA5555AA00FF55AA55FF00AA5555AA005500550000AAFF0000FF5500
FFFFFF0000FF00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000055FF00AAFF005555FF00
5500AAAA000000AAAAFF55AA00AAFF55FFAA00AA55FFAAAA000000AAAA005500FF555500
FFAA00FF55000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF00AAAAFF0055550000
00AAAAFFAAFFFFAAAAFF00FF0055AAAAAA5500FF00FFAAAAFFFFAAFFAAAA000000555500
FFAAAA00FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF0000FFAAFF55AA55
55AA005500AAFF0000FFAAFF00555555555500FFAAFF0000FFAA005500AA5555AA55FFAA
FF0000FF5555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFAAFFFFFF555500AA
0000FF55AA550000000055AAAA0000AA0000AAAA550000000055AA55FF0000AA005555FF
FFFFAAFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00550000555500FF
0055FF55AA000000000000AA5500FF55FF0055AA000000000000AA55FF5500FF00555500
005500AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550055FF00FFFFAA
00AA00FFFF5500FF5500FF55FFAAFF00FFAAFF55FF0055FF0055FFFF00AA00AAFFFF00FF
550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005555FF00AAFF
AAFFAAFF00AA00AAFF550000AAFFAA00AAFFAA000055FFAA00AA00FFAAFFAAFFAA00FF55
5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF5500AA
FFAA005500FF0055AAAAAA00AA55AA00AA55AA00AAAAAA5500FF005500AAFFAA0055FF55
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAAAA00
5500AAAAAA00FF55AA0055AA550055AA550055AA5500AA55FF00AAAAAA005500AAAAAA55
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00
5555AA0055AA55AAFFAAFF55FFAAFF55FFAAFF55FFAAFFAA55AA5500AA555500FF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00
555500AAAAAAFF55FF55FF55AAAAFF00FFAAAA55FF55FF55FFAAAAAA00555500FFAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555
AAFF5500AA550000AAFF555500AA55AA55AA005555FFAA000055AA0055FFAA5555FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00AA00AA55FF0055AAAAAAAA0055555500AAAAAAAA5500FF55AA00AA00FF00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA00AA555555000000AA5500AA5555005555AA0055AA000000555555AA00AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF5500AA0000AAAA00AA55FF0000AA00AA0000FF55AA00AAAA0000AA0055FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0055AA55555555AA000055FF000000FF550000AA55555555AA5500FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAA550055550055AA555500000000005555AA550055550055AAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF55AA55FFAAFF55FFAA5555AA5555AAFF55FFAAFF55AA55FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000AAFFAA000055AAFF55FFAA550000AAFFAA0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFAA0055FF00FF00AA00FF00FF5500AAFFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF555555AAFF005500FF005500FFAA555555FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFF5555AAFFFFFFAA5555FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA00FFFF0000550000FFFF00AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF55000055FF00FF55000055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0055FFAA00AAFF5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAA55AA00AA55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF55AA00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.545539 0.97619 1.00786 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00933532 0.00933532 0.00933532 [
[.5 .49794 -116 0 ]
[.5 .49794 116 12.875 ]
[ 0 0 0 0 ]
[ 1 .48544 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .49794 -177 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60754138548947969887125294151508014290) show
291.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .48544 L
0 .48544 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00934 translate
.96154 .46676 scale
103 string
103 50 8 [103 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF5500AAFF5555FFFFAAAAAA00000055AAFFAAFF00FF55FFFFAA550055AA0000005500
AA55FF5555AAFFFFAAFF55FFAAAAFF00FFAAAAFF55FFAAFFFFAA5555FF55AA0055000000
AA550055AAFFFF55FF00FFAAFFAA55000000AAAAAAFFFF5555FFAA0055FFFF
FFFFFFAAAAAA5555AAAA55FFAA5500AA55550000AAFFAA00AAFF00FF55FF00FF0000FF55
FFAAFF0055FFAA00FFFFFFAA0000AAFFAA0000AAFFFFFF00AAFF5500FFAAFF55FF0000FF
00FF55FF00FFAA00AAFFAA00005555AA0055AAFF55AAAA5555AAAAAAFFFFFF
FFFFFFFF00FFFFAAFF55AA55AAFFFF55AA555555550000AA55FF55FF550000FFAAAAFF00
55005500AAAA55FFFFFFFFFF0000FFFFFF0000FFFFFFFFFF55AAAA0055005500FFAAAAFF
000055FF55FF55AA000055555555AA55FFFFAA55AA55FFAAFFFF00FFFFFFFF
FFFFFFFFFF5555FFAA00AA00AA00FFAAFF5500FF5500AA55FF00AAAA55555555FFAA55AA
00AA5555550055FF5555FF55555555FF55555555FF5555FF5500555555AA00AA55AAFF55
555555AAAA00FF55AA0055FF0055FFAAFF00AA00AA00AAFF5555FFFFFFFFFF
FFFFFFFFFFFFAAFF00FF00FF00FF00AA00FF55FF5500AA00AAFFAA55FF0055FF00AA00AA
005555AA555555AAAA00AAFFFFAAFFFFFFAAFFFFAA00AAAA555555AA555500AA00AA00FF
5500FF55AAFFAA00AA0055FF55FF00AA00FF00FF00FF00FFAAFFFFFFFFFFFF
FFFFFFFFFFFFFF00AA55AA00FF00AA55FFFFFFAA00AA55FFFF00AA00AAFFAAFF0000AA55
FFFFAAFF5500FF55AAFFAA55AAAAAA55AAAAAA55AAFFAA55FF0055FFAAFFFF55AA0000FF
AAFFAA00AA00FFFF55AA00AAFFFFFF55AA00FF00AA55AA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55AA55FFFFFF55AA55AAAA55FFFF00550000FFFF55AAAAAA5500AA00
AAFF00FFAAFFAA00AA00FFFFAA55FFAAFF55AAFFFF00AA00AAFFAAFF00FFAA00AA0055AA
AAAA55FFFF00005500FFFF55AAAA55AA55FFFFFF55AA55FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA5555FF5555AAFFFF00FF5555FFFFAAAAFF00AAAAAAAAAA005555
550000FFAA55AAFFAA5500005555AAAAAA5555000055AAFFAA55AAFF000055555500AAAA
AAAAAA00FFAAAAFFFF5555FF00FFFFAA5555FF5555AAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055FF5500FFFFFFFF5555AA55AAAAAAAA5500555500555555AA
55555555FFAAFF555500FF00000000AA00000000FF005555FFAAFF55555555AA55555500
55550055AAAAAAAA55AA5555FFFFFFFF0055FF5500FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55000000FFAA00FFAAFFFF005555005555AA00AAAAFFFFAAFF
5500FF550000AAFFFFAAAA5500AA550055AA0055AAAAFFFFAA000055FF0055FFAAFFFFAA
AA00AA555500555500FFFFAAFF00AAFF00000055FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAAFFAA0000FFAA55AAAAFFFFAAAA00AA00555500005555
FF000055FFFF55AAAA55FFAAFFAA555555AAFFAAFF55AAAA55FFFF550000FF5555000055
5500AA00AAAAFFFFAAAA55AAFF0000AAFFAAAAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFAA5500AAFF55005555FF55AAFFAA5500FF55FFFFAA
FF0000FF5555FF00FFFFAA00005555AA55550000AAFFFF00FF5555FF0000FFAAFFFF55FF
0055AAFFAA55FF55550055FFAA0055AAFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF555500FF00FFAAFFAAFFFFFFAA55AAFFFF5555AAAA55
FF55FFFFFFAAFF0000550055AA00AAAAAA00AA5500550000FFAAFFFFFF55FF55AAAA5555
FFFFAA55AAFFFFFFAAFFAAFF00FF005555FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA00550055005500005555AAFF00AAAA0000AA
AA5555FF55550000FF0055AA55FFFF00FFFF55AA5500FF00005555FF5555AAAA0000AAAA
00FFAA55550000550055005500AAFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA0055FFFFAAAA0055AA55550000FFFF0000FF
FF0055FF5500FF000055AA55FF00AAFFAA00FF55AA550000FF0055FF5500FFFF0000FFFF
00005555AA5500AAAAFFFF5500AA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AA00AAFF00FFFF550055FF0000FFAA0055AA
AA5500FFAAFFAA0055AA55FF00AA55FF55AA00FF55AA5500AAFFAAFF0055AAAA5500AAFF
0000FF550055FFFF00FFAA00AA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55005500AAFF0055AA55AA00550055AA55
FFAAFFAA0000555555AAFFFFFF55AA55AA55FFFFFFAA5555550000AAFFAAFF55AA550055
00AA55AA5500FFAA00550055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0055AA55005500AAAAAA0000FF55FF00FF
55550000AA5500FF550055000055FFAAFF550000550055FF0055AA00005555FF00FF55FF
0000AAAAAA00550055AA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF550055FFFFAAAAAAAAAAFFAA00AAFFAA
00AAAAFFAA555555FF000000FF0055005500FF000000FF555555AAFFAAAA00AAFFAA00AA
FFAAAAAAAAAAFFFF550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAA00FFAA55FFAA55FF55AA000055
555500550055FF005500AA550000FF55FF000055AA005500FF550055005555550000AA55
FF55AAFF55AAFF00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00AA00AAFF55000000AA5500
FF5500AAAAFFFFFF5500AA00AA5500000055AA00AA0055FFFFFFAAAA0055FF0055AA0000
0055FFAA00AA00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55555500AA00FF55FFFF55AA55
000000FFFF00AAFF0055AAFFAA5555555555AAFFAA5500FFAA00FFFF00000055AA55FFFF
55FF00AA00555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFF55AA00FF5555FF00FF
55FFFF5555FFFF00AA55550000AAAA00AAAA00005555AA00FFFF5555FFFF55FF00FF5555
FF00AA55FFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAFFFF000055FF00AA55
AA55AAAA00AAFF0000AAAA0055AAFF55FFAA5500AAAA0000FFAA00AAAA55AA55AA00FF55
0000FFFFAA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55AAAA5500AAAA550055
FFAAFF55AA000055AA0000AA55550000005555AA0000AA550000AA55FFAAFF550055AAAA
0055AAAA55FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA55FF0000AA00AA55
55FFAA00AA0055AA55FFFF55AA5555555555AA55FFFF55AA5500AA00AAFF5555AA00AA00
00FF55AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005500AA55FFFF00
55FF55AA0000FF55AA55AAAA00000000000000AAAA55AA55FF0000AA55FF5500FFFF55AA
005500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5500AA00AAFF00
000055FFAAAAFF005555AAFF55FFFF55FFFF55FFAA555500FFAAAAFF55000000FFAA00AA
0055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAFF5555
555555AAAAAAAA5500FF55AAAA00FFAAFF00AAAA55FF0055AAAAAAAA5555555555FFAAAA
AAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFAA
FFFFAAFF55AAFF5500AAFFFF00FF00AA00FF00FFFFAA0055FFAA55FFAAFFFFAAFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FF55
AAAA55FF55005500FF00FFAA005500AA005500AAFF00FF00550055FF55AAAA55FF5555FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFF00
555500FFAAFFAAFFAA00550055AA550055AA55005500AAFFAAFFAAFF00555500FFAAFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AA
5555AA00FFFFFF00AA0055FFFFAA555555AAFFFF5500AA00FFFFFF00AA5555AA00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55
AA555500AAFF00AA55FFFFAA00FFFFAAFFFF00AAFFFF55AA00FFAA005555AA55FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AA5555AA000055AAFFFFFFFF00005500550000FFFFFFFFAA550000AA5555AAFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0055FFAAAAFFFF00AAFF00AA5500FF0055AA00FFAA00FFFFAAAAFF5500FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF550000AA00FFAAAAAA550055FFFFFF550055AAAAAAFF00AA000055FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFAAAAFF55FF55AAFF5500AAAA55AAAA0055FFAA55FF55FFAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFAAFF005555FF0000AA00AA0000FF555500FFAAFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF55550000FF550000FF00FF00FF000055FF00005555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAAFFAAAA55555555FFFFFF55555555AAAAFFAAFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00AA00000000000055000000000000AA00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF55AA0055AA0055AA5500AA5500AA55FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFAA5500FFFF550055FFFF0055AAFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0055AAAA555555AAAA5500FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF55005555AA55550055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFAAAA00AA00AAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.05409 0.97619 1.51641 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00933532 0.00933532 0.00933532 [
[.5 .49794 -116 0 ]
[.5 .49794 116 12.875 ]
[ 0 0 0 0 ]
[ 1 .48544 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .49794 -177 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40504489771945264131172035335963965665) show
291.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .48544 L
0 .48544 L
closepath
clip
newpath
% Start of gray image
p
.01923 .00934 translate
.96154 .46676 scale
103 string
103 50 8 [103 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{492.375, 764.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007/0002o2000`400?l00000o`00003oo`3AcJW]
0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]
0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]
0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]
0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]
0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@009P3AcJT8ooooo`@00000201EEED4000000@0ZZZZ
1?ooool8000000@0EEEE1@2ZZZX4ooooo`@000001?ooool405EEE@@000001?ooool80:ZZZP@0EEEE
1?ooool40:ZZZP@0EEEE302ZZZX4ooooo`@0ZZZZ1?ooool40:ZZZP@0EEEE10000004ooooo`P00000
102ZZZX4000000@0ZZZZ101EEED40:ZZZPCooooo20000004ooooo`P0EEEE1@00000805EEE@Cooooo
102ZZZX4ooooo`P0EEEE1000000805EEE@Cooooo20000004ooooo`@0ZZZZ101EEED40:ZZZP@00000
102ZZZX8000000Cooooo1000000405EEE@@0ZZZZ1?ooool40:ZZZPCooooo302ZZZX405EEE@@0ZZZZ
1?ooool505EEE@P0ZZZZ1?ooool4000000@0EEEE1?ooool4000000Cooooo102ZZZX405EEE@P00000
1?ooool40:ZZZP@00000201EEED4000000Sooooo9`3AcJT002H0dLfY2?ooool4000000P0EEEE1000
00040:ZZZPCooooo2000000405EEE@D0ZZZZ1?ooool4000000Cooooo101EEED4000000Cooooo202Z
ZZX405EEE@Cooooo102ZZZX405EEE@`0ZZZZ1?ooool40:ZZZPCooooo102ZZZX405EEE@@000001?oo
ool8000000@0ZZZZ100000040:ZZZP@0EEEE102ZZZX4ooooo`P000001?ooool805EEE@D00000201E
EED4ooooo`@0ZZZZ1?ooool805EEE@@00000201EEED4ooooo`P000001?ooool40:ZZZP@0EEEE102Z
ZZX4000000@0ZZZZ20000004ooooo`@00000101EEED40:ZZZPCooooo102ZZZX4ooooo``0ZZZZ101E
EED40:ZZZPCooooo1@1EEED80:ZZZPCooooo1000000405EEE@Cooooo10000004ooooo`@0ZZZZ101E
EED8000000Cooooo102ZZZX4000000P0EEEE10000008ooooobL0dLfY000V0=7=Z@Sooooo10000008
05EEE@@00000102ZZZX4ooooo`P00000101EEED50:ZZZPCooooo10000004ooooo`@0EEEE10000004
ooooo`P0ZZZZ101EEED4ooooo`@0ZZZZ101EEED<0:ZZZPCooooo102ZZZX4ooooo`@0ZZZZ101EEED4
000000Cooooo200000040:ZZZP@00000102ZZZX405EEE@@0ZZZZ1?ooool8000000Cooooo201EEED5
000000P0EEEE1?ooool40:ZZZPCooooo201EEED4000000P0EEEE1?ooool8000000Cooooo102ZZZX4
05EEE@@0ZZZZ100000040:ZZZPP000001?ooool4000000@0EEEE102ZZZX4ooooo`@0ZZZZ1?ooool<
0:ZZZP@0EEEE102ZZZX4ooooo`D0EEEE202ZZZX4ooooo`@00000101EEED4ooooo`@000001?ooool4
0:ZZZP@0EEEE20000004ooooo`@0ZZZZ1000000805EEE@@000002?oooolW0=7=Z@009P3AcJT8oooo
o`@00000201EEED4000000@0ZZZZ1?ooool8000000@0EEEE1@2ZZZX4ooooo`@000001?ooool405EE
E@@000001?ooool80:ZZZP@0EEEE1?ooool40:ZZZP@0EEEE302ZZZX4ooooo`@0ZZZZ1?ooool40:ZZ
ZP@0EEEE10000004ooooo`P00000102ZZZX4000000@0ZZZZ101EEED40:ZZZPCooooo20000004oooo
o`P0EEEE1@00000805EEE@Cooooo102ZZZX4ooooo`P0EEEE1000000805EEE@Cooooo20000004oooo
o`@0ZZZZ101EEED40:ZZZP@00000102ZZZX8000000Cooooo1000000405EEE@@0ZZZZ1?ooool40:ZZ
ZPCooooo302ZZZX405EEE@@0ZZZZ1?ooool505EEE@P0ZZZZ1?ooool4000000@0EEEE1?ooool40000
00Cooooo102ZZZX405EEE@P000001?ooool40:ZZZP@00000201EEED4000000Sooooo9`3AcJT002H0
dLfY3?ooool40:ZZZP@0EEEE1?ooool8000000@0EEEE1?ooool4000000Gooooo100000080:ZZZP@0
EEEE1?ooool4000000@0ZZZZ101EEED4000000@0EEEE100000040:ZZZP@00000101EEED40:ZZZP@0
00001?ooool4000000@0ZZZZ101EEED4ooooo`@00000202ZZZX4000000@0EEEE2?ooool8000000@0
EEEE1?ooool4000000@0ZZZZ3@0000040:ZZZP@000001?ooool4000000@0ZZZZ300000040:ZZZP@0
00001?ooool405EEE@P000002?ooool405EEE@@00000202ZZZX4000000Cooooo101EEED40:ZZZP@0
00001?ooool4000000@0ZZZZ101EEED4000000@0ZZZZ1000000405EEE@D00000101EEED40:ZZZP@0
00001?ooool405EEE@P0ZZZZ10000004ooooo`@000001?ooool405EEE@P000001?ooool405EEE@@0
ZZZZ3?oooolW0=7=Z@009P3AcJT<ooooo`@0ZZZZ101EEED4ooooo`P00000101EEED4ooooo`@00000
1Oooool4000000P0ZZZZ101EEED4ooooo`@00000102ZZZX405EEE@@00000101EEED4000000@0ZZZZ
1000000405EEE@@0ZZZZ10000004ooooo`@00000102ZZZX405EEE@Cooooo100000080:ZZZP@00000
101EEED8ooooo`P00000101EEED4ooooo`@00000102ZZZX=000000@0ZZZZ10000004ooooo`@00000
102ZZZX<000000@0ZZZZ10000004ooooo`@0EEEE20000008ooooo`@0EEEE100000080:ZZZP@00000
1?ooool405EEE@@0ZZZZ10000004ooooo`@00000102ZZZX405EEE@@00000102ZZZX4000000@0EEEE
1@00000405EEE@@0ZZZZ10000004ooooo`@0EEEE202ZZZX4000000Cooooo10000004ooooo`@0EEEE
20000004ooooo`@0EEEE102ZZZX<ooooobL0dLfY000V0=7=Z@cooooo102ZZZX405EEE@Cooooo2000
000405EEE@Cooooo10000005ooooo`@00000202ZZZX405EEE@Cooooo100000040:ZZZP@0EEEE1000
000405EEE@@00000102ZZZX4000000@0EEEE102ZZZX4000000Cooooo100000040:ZZZP@0EEEE1?oo
ool4000000P0ZZZZ1000000405EEE@Sooooo2000000405EEE@Cooooo100000040:ZZZPd00000102Z
ZZX4000000Cooooo100000040:ZZZP`00000102ZZZX4000000Cooooo101EEED8000000Sooooo101E
EED4000000P0ZZZZ10000004ooooo`@0EEEE102ZZZX4000000Cooooo100000040:ZZZP@0EEEE1000
00040:ZZZP@00000101EEED5000000@0EEEE102ZZZX4000000Cooooo101EEED80:ZZZP@000001?oo
ool4000000Cooooo101EEED8000000Cooooo101EEED40:ZZZPcooooo9`3AcJT002H0dLfY3?ooool4
0:ZZZP@0EEEE1?ooool8000000@0EEEE1?ooool4000000Gooooo100000080:ZZZP@0EEEE1?ooool4
000000@0ZZZZ101EEED4000000@0EEEE100000040:ZZZP@00000101EEED40:ZZZP@000001?ooool4
000000@0ZZZZ101EEED4ooooo`@00000202ZZZX4000000@0EEEE2?ooool8000000@0EEEE1?ooool4
000000@0ZZZZ3@0000040:ZZZP@000001?ooool4000000@0ZZZZ300000040:ZZZP@000001?ooool4
05EEE@P000002?ooool405EEE@@00000202ZZZX4000000Cooooo101EEED40:ZZZP@000001?ooool4
000000@0ZZZZ101EEED4000000@0ZZZZ1000000405EEE@D00000101EEED40:ZZZP@000001?ooool4
05EEE@P0ZZZZ10000004ooooo`@000001?ooool405EEE@P000001?ooool405EEE@@0ZZZZ3?oooolW
0=7=Z@009P3AcJT@ooooo`@0EEEE202ZZZX4000000@0ZZZZ10000004ooooo`T0EEEE102ZZZX40000
00P0EEEE1?ooool8000000`0ZZZZ1000000405EEE@Cooooo202ZZZX4000000Cooooo101EEED4oooo
o`@0ZZZZ100000040:ZZZP@0EEEE1000000@ooooo`@0ZZZZ1?ooool805EEE@@0ZZZZ100000090:ZZ
ZP@00000101EEED4ooooo`@0EEEE100000080:ZZZP@00000102ZZZX805EEE@Cooooo102ZZZX@oooo
o`@00000101EEED40:ZZZP@00000102ZZZX4ooooo`@0EEEE1?ooool4000000P0ZZZZ1?ooool405EE
E@@000003@2ZZZX8000000Cooooo201EEED4000000@0ZZZZ201EEED4ooooo`@00000102ZZZX40000
00P0ZZZZ101EEED@ooooobL0dLfY000V0=7=ZA3ooooo101EEED80:ZZZP@00000102ZZZX4000000Co
oooo2@1EEED40:ZZZP@00000201EEED4ooooo`P00000302ZZZX4000000@0EEEE1?ooool80:ZZZP@0
00001?ooool405EEE@Cooooo102ZZZX4000000@0ZZZZ101EEED40000013ooooo102ZZZX4ooooo`P0
EEEE102ZZZX4000000T0ZZZZ1000000405EEE@Cooooo101EEED4000000P0ZZZZ100000040:ZZZPP0
EEEE1?ooool40:ZZZQ3ooooo1000000405EEE@@0ZZZZ100000040:ZZZPCooooo101EEED4ooooo`@0
0000202ZZZX4ooooo`@0EEEE1000000=0:ZZZPP000001?ooool805EEE@@00000102ZZZX805EEE@Co
oooo100000040:ZZZP@00000202ZZZX405EEEA3ooooo9`3AcJT002H0dLfY4?ooool405EEE@P0ZZZZ
100000040:ZZZP@000001?ooool905EEE@@0ZZZZ1000000805EEE@Cooooo2000000<0:ZZZP@00000
101EEED4ooooo`P0ZZZZ10000004ooooo`@0EEEE1?ooool40:ZZZP@00000102ZZZX405EEE@@00000
4?ooool40:ZZZPCooooo201EEED40:ZZZP@000002@2ZZZX4000000@0EEEE1?ooool405EEE@@00000
202ZZZX4000000@0ZZZZ201EEED4ooooo`@0ZZZZ4?ooool4000000@0EEEE102ZZZX4000000@0ZZZZ
1?ooool405EEE@Cooooo100000080:ZZZPCooooo101EEED4000000d0ZZZZ20000004ooooo`P0EEEE
100000040:ZZZPP0EEEE1?ooool4000000@0ZZZZ100000080:ZZZP@0EEEE4?oooolW0=7=Z@009P3A
cJT@ooooo`@0EEEE202ZZZX4000000@0ZZZZ10000004ooooo`T0EEEE102ZZZX4000000P0EEEE1?oo
ool8000000`0ZZZZ1000000405EEE@Cooooo202ZZZX4000000Cooooo101EEED4ooooo`@0ZZZZ1000
00040:ZZZP@0EEEE1000000@ooooo`@0ZZZZ1?ooool805EEE@@0ZZZZ100000090:ZZZP@00000101E
EED4ooooo`@0EEEE100000080:ZZZP@00000102ZZZX805EEE@Cooooo102ZZZX@ooooo`@00000101E
EED40:ZZZP@00000102ZZZX4ooooo`@0EEEE1?ooool4000000P0ZZZZ1?ooool405EEE@@000003@2Z
ZZX8000000Cooooo201EEED4000000@0ZZZZ201EEED4ooooo`@00000102ZZZX4000000P0ZZZZ101E
EED@ooooobL0dLfY000V0=7=ZACooooo20000004ooooo`@0EEEE1?ooool4000000D0ZZZZ20000004
ooooo`@0EEEE102ZZZX4ooooo`@00000101EEED8ooooo`@0EEEE1?ooool4000000Cooooo202ZZZX<
ooooo`@00000102ZZZX<05EEE@@000001?ooool40:ZZZP@000001?ooool80:ZZZP@0EEEE1?ooool8
0:ZZZPD00000101EEED40:ZZZP@0EEEE1?ooool405EEE@@0ZZZZ101EEED4000000P0ZZZZ1?ooool4
05EEE@P0ZZZZ1?ooool4000000@0ZZZZ1?ooool4000000`0EEEE102ZZZX4000000cooooo202ZZZX4
ooooo`@000001?ooool405EEE@Wooooo101EEED4000000Cooooo102ZZZX405EEE@Cooooo20000004
0:ZZZP@000001?ooool405EEE@Cooooo2000000DooooobL0dLfY000V0=7=ZACooooo20000004oooo
o`@0EEEE1?ooool4000000D0ZZZZ20000004ooooo`@0EEEE102ZZZX4ooooo`@00000101EEED8oooo
o`@0EEEE1?ooool4000000Cooooo202ZZZX<ooooo`@00000102ZZZX<05EEE@@000001?ooool40:ZZ
ZP@000001?ooool80:ZZZP@0EEEE1?ooool80:ZZZPD00000101EEED40:ZZZP@0EEEE1?ooool405EE
E@@0ZZZZ101EEED4000000P0ZZZZ1?ooool405EEE@P0ZZZZ1?ooool4000000@0ZZZZ1?ooool40000
00`0EEEE102ZZZX4000000cooooo202ZZZX4ooooo`@000001?ooool405EEE@Wooooo101EEED40000
00Cooooo102ZZZX405EEE@Cooooo200000040:ZZZP@000001?ooool405EEE@Cooooo2000000Doooo
obL0dLfY000V0=7=ZACooooo20000004ooooo`@0EEEE1?ooool4000000D0ZZZZ20000004ooooo`@0
EEEE102ZZZX4ooooo`@00000101EEED8ooooo`@0EEEE1?ooool4000000Cooooo202ZZZX<ooooo`@0
0000102ZZZX<05EEE@@000001?ooool40:ZZZP@000001?ooool80:ZZZP@0EEEE1?ooool80:ZZZPD0
0000101EEED40:ZZZP@0EEEE1?ooool405EEE@@0ZZZZ101EEED4000000P0ZZZZ1?ooool405EEE@P0
ZZZZ1?ooool4000000@0ZZZZ1?ooool4000000`0EEEE102ZZZX4000000cooooo202ZZZX4ooooo`@0
00001?ooool405EEE@Wooooo101EEED4000000Cooooo102ZZZX405EEE@Cooooo200000040:ZZZP@0
00001?ooool405EEE@Cooooo2000000DooooobL0dLfY000V0=7=ZACooooo20000004ooooo`@0EEEE
1?ooool4000000D0ZZZZ20000004ooooo`@0EEEE102ZZZX4ooooo`@00000101EEED8ooooo`@0EEEE
1?ooool4000000Cooooo202ZZZX<ooooo`@00000102ZZZX<05EEE@@000001?ooool40:ZZZP@00000
1?ooool80:ZZZP@0EEEE1?ooool80:ZZZPD00000101EEED40:ZZZP@0EEEE1?ooool405EEE@@0ZZZZ
101EEED4000000P0ZZZZ1?ooool405EEE@P0ZZZZ1?ooool4000000@0ZZZZ1?ooool4000000`0EEEE
102ZZZX4000000cooooo202ZZZX4ooooo`@000001?ooool405EEE@Wooooo101EEED4000000Cooooo
102ZZZX405EEE@Cooooo200000040:ZZZP@000001?ooool405EEE@Cooooo2000000DooooobL0dLfY
000V0=7=ZASooooo102ZZZX4ooooo`@000001?ooool40:ZZZPGooooo102ZZZX<ooooo`P00000101E
EED4ooooo`@0ZZZZ1000000<ooooo`@0ZZZZ1000000405EEE@P0ZZZZ101EEED40:ZZZP@0EEEE1000
000805EEE@@000001?ooool80:ZZZP@000001?ooool8000000@0ZZZZ1?ooool90:ZZZPP000003?oo
ool8000000P0ZZZZ1?ooool40:ZZZPP000001?ooool4000000P0ZZZZ1?ooool4000000P0EEEE1000
000405EEE@@0ZZZZ101EEED80:ZZZP@0EEEE100000040:ZZZPcooooo100000050:ZZZPCooooo101E
EED8000000cooooo102ZZZX4ooooo`@0ZZZZ1?ooool4000000Cooooo102ZZZXHooooobL0dLfY000V
0=7=ZASooooo102ZZZX4ooooo`@000001?ooool40:ZZZPGooooo102ZZZX<ooooo`P00000101EEED4
ooooo`@0ZZZZ1000000<ooooo`@0ZZZZ1000000405EEE@P0ZZZZ101EEED40:ZZZP@0EEEE10000008
05EEE@@000001?ooool80:ZZZP@000001?ooool8000000@0ZZZZ1?ooool90:ZZZPP000003?ooool8
000000P0ZZZZ1?ooool40:ZZZPP000001?ooool4000000P0ZZZZ1?ooool4000000P0EEEE10000004
05EEE@@0ZZZZ101EEED80:ZZZP@0EEEE100000040:ZZZPcooooo100000050:ZZZPCooooo101EEED8
000000cooooo102ZZZX4ooooo`@0ZZZZ1?ooool4000000Cooooo102ZZZXHooooobL0dLfY000V0=7=
ZASooooo102ZZZX4ooooo`@000001?ooool40:ZZZPGooooo102ZZZX<ooooo`P00000101EEED4oooo
o`@0ZZZZ1000000<ooooo`@0ZZZZ1000000405EEE@P0ZZZZ101EEED40:ZZZP@0EEEE1000000805EE
E@@000001?ooool80:ZZZP@000001?ooool8000000@0ZZZZ1?ooool90:ZZZPP000003?ooool80000
00P0ZZZZ1?ooool40:ZZZPP000001?ooool4000000P0ZZZZ1?ooool4000000P0EEEE1000000405EE
E@@0ZZZZ101EEED80:ZZZP@0EEEE100000040:ZZZPcooooo100000050:ZZZPCooooo101EEED80000
00cooooo102ZZZX4ooooo`@0ZZZZ1?ooool4000000Cooooo102ZZZXHooooobL0dLfY000V0=7=ZASo
oooo102ZZZX4ooooo`@000001?ooool40:ZZZPGooooo102ZZZX<ooooo`P00000101EEED4ooooo`@0
ZZZZ1000000<ooooo`@0ZZZZ1000000405EEE@P0ZZZZ101EEED40:ZZZP@0EEEE1000000805EEE@@0
00001?ooool80:ZZZP@000001?ooool8000000@0ZZZZ1?ooool90:ZZZPP000003?ooool8000000P0
ZZZZ1?ooool40:ZZZPP000001?ooool4000000P0ZZZZ1?ooool4000000P0EEEE1000000405EEE@@0
ZZZZ101EEED80:ZZZP@0EEEE100000040:ZZZPcooooo100000050:ZZZPCooooo101EEED8000000co
oooo102ZZZX4ooooo`@0ZZZZ1?ooool4000000Cooooo102ZZZXHooooobL0dLfY000V0=7=ZAcooooo
201EEED80:ZZZPGooooo2000000405EEEA000000102ZZZX4ooooo`@0ZZZZ1?ooool4000000@0ZZZZ
1?ooool40:ZZZPCooooo101EEED8ooooo`P00000402ZZZX4000000Cooooo3000000405EEE@Cooooo
2000000405EEE@D0ZZZZ100000080:ZZZP@0EEEE202ZZZX4000000@0ZZZZ101EEED8000000Cooooo
101EEED<000000Cooooo1000000@0:ZZZPP000002?ooool405EEE@Cooooo102ZZZX4ooooo`@0ZZZZ
10000004ooooo`@0ZZZZ1Oooool40:ZZZQ000000101EEED8000000Cooooo202ZZZX805EEEAcooooo
9`3AcJT002H0dLfY7?ooool805EEE@P0ZZZZ1Oooool8000000@0EEEE400000040:ZZZPCooooo102Z
ZZX4ooooo`@00000102ZZZX4ooooo`@0ZZZZ1?ooool405EEE@Sooooo2000000@0:ZZZP@000001?oo
ool<000000@0EEEE1?ooool8000000@0EEEE1@2ZZZX4000000P0ZZZZ101EEED80:ZZZP@00000102Z
ZZX405EEE@P000001?ooool405EEE@`000001?ooool400000100ZZZZ20000008ooooo`@0EEEE1?oo
ool40:ZZZPCooooo102ZZZX4000000Cooooo102ZZZX5ooooo`@0ZZZZ4000000405EEE@P000001?oo
ool80:ZZZPP0EEEE7?oooolW0=7=Z@009P3AcJTLooooo`P0EEEE202ZZZX5ooooo`P00000101EEED@
000000@0ZZZZ1?ooool40:ZZZPCooooo100000040:ZZZPCooooo102ZZZX4ooooo`@0EEEE2?ooool8
00000100ZZZZ10000004ooooo``00000101EEED4ooooo`P00000101EEED50:ZZZP@00000202ZZZX4
05EEE@P0ZZZZ100000040:ZZZP@0EEEE20000004ooooo`@0EEEE30000004ooooo`@00000402ZZZX8
000000Sooooo101EEED4ooooo`@0ZZZZ1?ooool40:ZZZP@000001?ooool40:ZZZPGooooo102ZZZX@
000000@0EEEE20000004ooooo`P0ZZZZ201EEEDLooooobL0dLfY000V0=7=ZAcooooo201EEED80:ZZ
ZPGooooo2000000405EEEA000000102ZZZX4ooooo`@0ZZZZ1?ooool4000000@0ZZZZ1?ooool40:ZZ
ZPCooooo101EEED8ooooo`P00000402ZZZX4000000Cooooo3000000405EEE@Cooooo2000000405EE
E@D0ZZZZ100000080:ZZZP@0EEEE202ZZZX4000000@0ZZZZ101EEED8000000Cooooo101EEED<0000
00Cooooo1000000@0:ZZZPP000002?ooool405EEE@Cooooo102ZZZX4ooooo`@0ZZZZ10000004oooo
o`@0ZZZZ1Oooool40:ZZZQ000000101EEED8000000Cooooo202ZZZX805EEEAcooooo9`3AcJT002H0
dLfY8?ooool4000000Cooooo2@00000405EEE@Cooooo10000004ooooo`@0EEEE10000004ooooo`@0
EEEE1?ooool405EEE@Cooooo101EEED4000000@0ZZZZ1?ooool40:ZZZPP00000101EEED4000000Co
oooo101EEED8ooooo`@0EEEE1?ooool4000000P0ZZZZ100000040:ZZZP@000001?ooool405EEE@@0
00001@1EEED40:ZZZP@0EEEE100000040:ZZZP@00000101EEED40:ZZZP@0EEEE1000000405EEE@Co
oooo100000040:ZZZP@00000202ZZZX4000000Cooooo101EEED8ooooo`@0EEEE1?ooool4000000@0
EEEE200000040:ZZZPCooooo102ZZZX4000000@0EEEE1?ooool405EEE@Gooooo101EEED4ooooo`@0
0000101EEED4ooooo`@000001?ooool405EEE@P000001?ooool40000023ooooo9`3AcJT002H0dLfY
8?ooool4000000Cooooo2@00000405EEE@Cooooo10000004ooooo`@0EEEE10000004ooooo`@0EEEE
1?ooool405EEE@Cooooo101EEED4000000@0ZZZZ1?ooool40:ZZZPP00000101EEED4000000Cooooo
101EEED8ooooo`@0EEEE1?ooool4000000P0ZZZZ100000040:ZZZP@000001?ooool405EEE@@00000
1@1EEED40:ZZZP@0EEEE100000040:ZZZP@00000101EEED40:ZZZP@0EEEE1000000405EEE@Cooooo
100000040:ZZZP@00000202ZZZX4000000Cooooo101EEED8ooooo`@0EEEE1?ooool4000000@0EEEE
200000040:ZZZPCooooo102ZZZX4000000@0EEEE1?ooool405EEE@Gooooo101EEED4ooooo`@00000
101EEED4ooooo`@000001?ooool405EEE@P000001?ooool40000023ooooo9`3AcJT002H0dLfY8?oo
ool4000000Cooooo2@00000405EEE@Cooooo10000004ooooo`@0EEEE10000004ooooo`@0EEEE1?oo
ool405EEE@Cooooo101EEED4000000@0ZZZZ1?ooool40:ZZZPP00000101EEED4000000Cooooo101E
EED8ooooo`@0EEEE1?ooool4000000P0ZZZZ100000040:ZZZP@000001?ooool405EEE@@000001@1E
EED40:ZZZP@0EEEE100000040:ZZZP@00000101EEED40:ZZZP@0EEEE1000000405EEE@Cooooo1000
00040:ZZZP@00000202ZZZX4000000Cooooo101EEED8ooooo`@0EEEE1?ooool4000000@0EEEE2000
00040:ZZZPCooooo102ZZZX4000000@0EEEE1?ooool405EEE@Gooooo101EEED4ooooo`@00000101E
EED4ooooo`@000001?ooool405EEE@P000001?ooool40000023ooooo9`3AcJT002H0dLfY8?ooool4
000000Cooooo2@00000405EEE@Cooooo10000004ooooo`@0EEEE10000004ooooo`@0EEEE1?ooool4
05EEE@Cooooo101EEED4000000@0ZZZZ1?ooool40:ZZZPP00000101EEED4000000Cooooo101EEED8
ooooo`@0EEEE1?ooool4000000P0ZZZZ100000040:ZZZP@000001?ooool405EEE@@000001@1EEED4
0:ZZZP@0EEEE100000040:ZZZP@00000101EEED40:ZZZP@0EEEE1000000405EEE@Cooooo10000004
0:ZZZP@00000202ZZZX4000000Cooooo101EEED8ooooo`@0EEEE1?ooool4000000@0EEEE20000004
0:ZZZPCooooo102ZZZX4000000@0EEEE1?ooool405EEE@Gooooo101EEED4ooooo`@00000101EEED4
ooooo`@000001?ooool405EEE@P000001?ooool40000023ooooo9`3AcJT002H0dLfY9?ooool40:ZZ
ZP@000003@2ZZZX805EEE@Cooooo102ZZZX4ooooo`@000001?ooool40:ZZZP@0EEEE102ZZZX8oooo
o``0EEEE102ZZZX405EEE@Cooooo100000040:ZZZP@000001?ooool40:ZZZP@0EEEE102ZZZX405EE
E@@00000202ZZZX<ooooo`@000003@1EEED4000000Cooooo1000000<05EEE@@000003?ooool80:ZZ
ZP@00000101EEED40:ZZZP@0EEEE102ZZZX4ooooo`@00000102ZZZX4000000Cooooo101EEED40:ZZ
ZP`0EEEE2?ooool40:ZZZP@0EEEE102ZZZX5ooooo`@000001?ooool40:ZZZPCooooo201EEED<0:ZZ
ZP@00000102ZZZXTooooobL0dLfY000V0=7=ZBCooooo102ZZZX4000000d0ZZZZ201EEED4ooooo`@0
ZZZZ1?ooool4000000Cooooo102ZZZX405EEE@@0ZZZZ2?ooool<05EEE@@0ZZZZ101EEED4ooooo`@0
0000102ZZZX4000000Cooooo102ZZZX405EEE@@0ZZZZ101EEED4000000P0ZZZZ3?ooool4000000d0
EEEE10000004ooooo`@00000301EEED4000000cooooo202ZZZX4000000@0EEEE102ZZZX405EEE@@0
ZZZZ1?ooool4000000@0ZZZZ10000004ooooo`@0EEEE102ZZZX<05EEE@Sooooo102ZZZX405EEE@@0
ZZZZ1Oooool4000000Cooooo102ZZZX4ooooo`P0EEEE302ZZZX4000000@0ZZZZ9?oooolW0=7=Z@00
9P3AcJTTooooo`@0ZZZZ1000000=0:ZZZPP0EEEE1?ooool40:ZZZPCooooo10000004ooooo`@0ZZZZ
101EEED40:ZZZPSooooo301EEED40:ZZZP@0EEEE1?ooool4000000@0ZZZZ10000004ooooo`@0ZZZZ
101EEED40:ZZZP@0EEEE100000080:ZZZPcooooo1000000=05EEE@@000001?ooool4000000`0EEEE
1000000<ooooo`P0ZZZZ1000000405EEE@@0ZZZZ101EEED40:ZZZPCooooo100000040:ZZZP@00000
1?ooool405EEE@@0ZZZZ301EEED8ooooo`@0ZZZZ101EEED40:ZZZPGooooo10000004ooooo`@0ZZZZ
1?ooool805EEE@`0ZZZZ100000040:ZZZRCooooo9`3AcJT002H0dLfY9?ooool40:ZZZP@000003@2Z
ZZX805EEE@Cooooo102ZZZX4ooooo`@000001?ooool40:ZZZP@0EEEE102ZZZX8ooooo``0EEEE102Z
ZZX405EEE@Cooooo100000040:ZZZP@000001?ooool40:ZZZP@0EEEE102ZZZX405EEE@@00000202Z
ZZX<ooooo`@000003@1EEED4000000Cooooo1000000<05EEE@@000003?ooool80:ZZZP@00000101E
EED40:ZZZP@0EEEE102ZZZX4ooooo`@00000102ZZZX4000000Cooooo101EEED40:ZZZP`0EEEE2?oo
ool40:ZZZP@0EEEE102ZZZX5ooooo`@000001?ooool40:ZZZPCooooo201EEED<0:ZZZP@00000102Z
ZZXTooooobL0dLfY000V0=7=ZBSooooo101EEED5000000@0ZZZZ101EEED4000000P0EEEE3?ooool4
0:ZZZP@00000301EEED4ooooo`@0EEEE102ZZZX4ooooo`@0EEEE1?ooool40:ZZZP@00000102ZZZX8
05EEE@Sooooo200000080:ZZZPCooooo102ZZZX4000000Cooooo102ZZZX5ooooo`@0EEEE102ZZZX<
ooooo`@0ZZZZ101EEED4ooooo`@0ZZZZ1?ooool4000000@0ZZZZ1?ooool80:ZZZPP000002?ooool8
05EEE@@0ZZZZ100000040:ZZZPCooooo101EEED4ooooo`@0ZZZZ101EEED4ooooo``0EEEE10000005
0:ZZZPcooooo201EEED4000000@0EEEE102ZZZX4000000@0EEEE:?oooolW0=7=Z@009P3AcJTXoooo
o`@0EEEE1@0000040:ZZZP@0EEEE1000000805EEE@cooooo102ZZZX4000000`0EEEE1?ooool405EE
E@@0ZZZZ1?ooool405EEE@Cooooo102ZZZX4000000@0ZZZZ201EEED8ooooo`P00000202ZZZX4oooo
o`@0ZZZZ10000004ooooo`@0ZZZZ1Oooool405EEE@@0ZZZZ3?ooool40:ZZZP@0EEEE1?ooool40:ZZ
ZPCooooo100000040:ZZZPCooooo202ZZZX8000000Sooooo201EEED40:ZZZP@00000102ZZZX4oooo
o`@0EEEE1?ooool40:ZZZP@0EEEE1?ooool<05EEE@@000001@2ZZZX<ooooo`P0EEEE1000000405EE
E@@0ZZZZ1000000405EEEBSooooo9`3AcJT002H0dLfY:?ooool405EEE@D00000102ZZZX405EEE@@0
0000201EEED<ooooo`@0ZZZZ1000000<05EEE@Cooooo101EEED40:ZZZPCooooo101EEED4ooooo`@0
ZZZZ100000040:ZZZPP0EEEE2?ooool8000000P0ZZZZ1?ooool40:ZZZP@000001?ooool40:ZZZPGo
oooo101EEED40:ZZZPcooooo102ZZZX405EEE@Cooooo102ZZZX4ooooo`@00000102ZZZX4ooooo`P0
ZZZZ20000008ooooo`P0EEEE102ZZZX4000000@0ZZZZ1?ooool405EEE@Cooooo102ZZZX405EEE@Co
oooo301EEED4000000D0ZZZZ3?ooool805EEE@@00000101EEED40:ZZZP@00000101EEEDXooooobL0
dLfY000V0=7=ZBSooooo101EEED5000000@0ZZZZ101EEED4000000P0EEEE3?ooool40:ZZZP@00000
301EEED4ooooo`@0EEEE102ZZZX4ooooo`@0EEEE1?ooool40:ZZZP@00000102ZZZX805EEE@Sooooo
200000080:ZZZPCooooo102ZZZX4000000Cooooo102ZZZX5ooooo`@0EEEE102ZZZX<ooooo`@0ZZZZ
101EEED4ooooo`@0ZZZZ1?ooool4000000@0ZZZZ1?ooool80:ZZZPP000002?ooool805EEE@@0ZZZZ
100000040:ZZZPCooooo101EEED4ooooo`@0ZZZZ101EEED4ooooo``0EEEE100000050:ZZZPcooooo
201EEED4000000@0EEEE102ZZZX4000000@0EEEE:?oooolW0=7=Z@009P3AcJT/ooooo`D00000101E
EED40:ZZZPSooooo10000004ooooo`@0ZZZZ10000004ooooo`@00000201EEED4000000@0EEEE1000
000405EEE@`0ZZZZ101EEED4000000Cooooo1000000@ooooo`@0ZZZZ1?ooool80:ZZZP@0EEEE1000
0004ooooo`T0ZZZZ101EEEDDooooo`@0EEEE202ZZZX4ooooo`@00000101EEED80:ZZZPCooooo102Z
ZZX@ooooo`@000001?ooool4000000@0EEEE302ZZZX405EEE@@00000101EEED4000000P0EEEE1000
0005ooooo`@00000102ZZZX4ooooo`@000002?ooool40:ZZZP@0EEEE1000000/ooooobL0dLfY000V
0=7=ZBcooooo1@00000405EEE@@0ZZZZ2?ooool4000000Cooooo102ZZZX4000000Cooooo10000008
05EEE@@00000101EEED4000000@0EEEE302ZZZX405EEE@@000001?ooool40000013ooooo102ZZZX4
ooooo`P0ZZZZ101EEED4000000Cooooo2@2ZZZX405EEEACooooo101EEED80:ZZZPCooooo10000004
05EEE@P0ZZZZ1?ooool40:ZZZQ3ooooo10000004ooooo`@00000101EEED<0:ZZZP@0EEEE10000004
05EEE@@00000201EEED4000000Gooooo100000040:ZZZPCooooo10000008ooooo`@0ZZZZ101EEED4
000002cooooo9`3AcJT002H0dLfY;?ooool5000000@0EEEE102ZZZX8ooooo`@000001?ooool40:ZZ
ZP@000001?ooool4000000P0EEEE1000000405EEE@@00000101EEED<0:ZZZP@0EEEE10000004oooo
o`@000004?ooool40:ZZZPCooooo202ZZZX405EEE@@000001?ooool90:ZZZP@0EEEE5?ooool405EE
E@P0ZZZZ1?ooool4000000@0EEEE202ZZZX4ooooo`@0ZZZZ4?ooool4000000Cooooo1000000405EE
E@`0ZZZZ101EEED4000000@0EEEE1000000805EEE@@000001Oooool4000000@0ZZZZ1?ooool40000
00Sooooo102ZZZX405EEE@@00000;?oooolW0=7=Z@009P3AcJT/ooooo`D00000101EEED40:ZZZPSo
oooo10000004ooooo`@0ZZZZ10000004ooooo`@00000201EEED4000000@0EEEE1000000405EEE@`0
ZZZZ101EEED4000000Cooooo1000000@ooooo`@0ZZZZ1?ooool80:ZZZP@0EEEE10000004ooooo`T0
ZZZZ101EEEDDooooo`@0EEEE202ZZZX4ooooo`@00000101EEED80:ZZZPCooooo102ZZZX@ooooo`@0
00001?ooool4000000@0EEEE302ZZZX405EEE@@00000101EEED4000000P0EEEE10000005ooooo`@0
0000102ZZZX4ooooo`@000002?ooool40:ZZZP@0EEEE1000000/ooooobL0dLfY000V0=7=ZC7ooooo
102ZZZX405EEE@P00000101EEED4ooooo`@0EEEE1?ooool400000100ZZZZ300000040:ZZZP@0EEEE
100000040:ZZZP@00000102ZZZXHoooooa00EEEE10000004ooooo`T0ZZZZ1?ooool805EEE@Cooooo
201EEED4ooooo`P0ZZZZ1?ooool400000100EEEE6?ooool40:ZZZP@00000102ZZZX4000000@0EEEE
102ZZZX<00000100ZZZZ1@000004ooooo`@0EEEE1?ooool405EEE@P00000101EEED40:ZZZS3ooooo
9`3AcJT002H0dLfY<Oooool40:ZZZP@0EEEE2000000405EEE@Cooooo101EEED4ooooo`@00000402Z
ZZX<000000@0ZZZZ101EEED4000000@0ZZZZ100000040:ZZZQSooooo401EEED4000000Cooooo2@2Z
ZZX4ooooo`P0EEEE1?ooool805EEE@Cooooo202ZZZX4ooooo`@00000401EEEDHooooo`@0ZZZZ1000
00040:ZZZP@00000101EEED40:ZZZP`00000402ZZZX5000000Cooooo101EEED4ooooo`@0EEEE2000
000405EEE@@0ZZZZ<?oooolW0=7=Z@009P3AcJTaooooo`@0ZZZZ101EEED8000000@0EEEE1?ooool4
05EEE@Cooooo1000000@0:ZZZP`00000102ZZZX405EEE@@00000102ZZZX4000000@0ZZZZ6?ooool@
05EEE@@000001?ooool90:ZZZPCooooo201EEED4ooooo`P0EEEE1?ooool80:ZZZPCooooo1000000@
05EEEASooooo102ZZZX4000000@0ZZZZ1000000405EEE@@0ZZZZ3000000@0:ZZZPD000001?ooool4
05EEE@Cooooo101EEED8000000@0EEEE102ZZZX`ooooobL0dLfY000V0=7=ZC7ooooo102ZZZX405EE
E@P00000101EEED4ooooo`@0EEEE1?ooool400000100ZZZZ300000040:ZZZP@0EEEE100000040:ZZ
ZP@00000102ZZZXHoooooa00EEEE10000004ooooo`T0ZZZZ1?ooool805EEE@Cooooo201EEED4oooo
o`P0ZZZZ1?ooool400000100EEEE6?ooool40:ZZZP@00000102ZZZX4000000@0EEEE102ZZZX<0000
0100ZZZZ1@000004ooooo`@0EEEE1?ooool405EEE@P00000101EEED40:ZZZS3ooooo9`3AcJT002H0
dLfY=Oooool405EEE@@0ZZZZ201EEED8000000@0ZZZZ2?ooool405EEE@Sooooo101EEED4000000Co
oooo101EEED4ooooo`@0ZZZZ1?ooool40:ZZZPCooooo102ZZZX4000000Cooooo102ZZZX4000000Co
oooo102ZZZX405EEE@Cooooo102ZZZX805EEE@Wooooo201EEED4000000@0EEEE1000000805EEE@So
oooo201EEED40:ZZZPCooooo101EEED40:ZZZPCooooo100000040:ZZZPCooooo100000040:ZZZPCo
oooo102ZZZX4ooooo`@0ZZZZ1?ooool405EEE@Cooooo1000000405EEE@Sooooo101EEED9ooooo`@0
ZZZZ2000000805EEE@@0ZZZZ101EEEDdooooobL0dLfY000V0=7=ZCGooooo101EEED40:ZZZPP0EEEE
200000040:ZZZPSooooo101EEED8ooooo`@0EEEE10000004ooooo`@0EEEE1?ooool40:ZZZPCooooo
102ZZZX4ooooo`@0ZZZZ10000004ooooo`@0ZZZZ10000004ooooo`@0ZZZZ101EEED4ooooo`@0ZZZZ
201EEED9ooooo`P0EEEE1000000405EEE@@00000201EEED8ooooo`P0EEEE102ZZZX4ooooo`@0EEEE
102ZZZX4ooooo`@00000102ZZZX4ooooo`@00000102ZZZX4ooooo`@0ZZZZ1?ooool40:ZZZPCooooo
101EEED4ooooo`@00000101EEED8ooooo`@0EEEE2Oooool40:ZZZPP00000201EEED40:ZZZP@0EEEE
=?oooolW0=7=Z@009P3AcJTeooooo`@0EEEE102ZZZX805EEE@P00000102ZZZX8ooooo`@0EEEE2?oo
ool405EEE@@000001?ooool405EEE@Cooooo102ZZZX4ooooo`@0ZZZZ1?ooool40:ZZZP@000001?oo
ool40:ZZZP@000001?ooool40:ZZZP@0EEEE1?ooool40:ZZZPP0EEEE2Oooool805EEE@@00000101E
EED4000000P0EEEE2?ooool805EEE@@0ZZZZ1?ooool405EEE@@0ZZZZ1?ooool4000000@0ZZZZ1?oo
ool4000000@0ZZZZ1?ooool40:ZZZPCooooo102ZZZX4ooooo`@0EEEE1?ooool4000000@0EEEE2?oo
ool405EEE@Wooooo102ZZZX8000000P0EEEE102ZZZX405EEECCooooo9`3AcJT002H0dLfY=Oooool4
05EEE@@0ZZZZ201EEED8000000@0ZZZZ2?ooool405EEE@Sooooo101EEED4000000Cooooo101EEED4
ooooo`@0ZZZZ1?ooool40:ZZZPCooooo102ZZZX4000000Cooooo102ZZZX4000000Cooooo102ZZZX4
05EEE@Cooooo102ZZZX805EEE@Wooooo201EEED4000000@0EEEE1000000805EEE@Sooooo201EEED4
0:ZZZPCooooo101EEED40:ZZZPCooooo100000040:ZZZPCooooo100000040:ZZZPCooooo102ZZZX4
ooooo`@0ZZZZ1?ooool405EEE@Cooooo1000000405EEE@Sooooo101EEED9ooooo`@0ZZZZ20000008
05EEE@@0ZZZZ101EEEDdooooobL0dLfY000V0=7=ZCWooooo200000040:ZZZP@00000202ZZZX4oooo
o`@00000102ZZZX4000000Cooooo102ZZZX805EEE@Cooooo102ZZZX4000000@0EEEE100000040:ZZ
ZPCooooo102ZZZX4ooooo``00000101EEED40:ZZZPCooooo200000040:ZZZP@000001Oooool40:ZZ
ZP@0EEEE1?ooool4000000Cooooo101EEED40:ZZZPCooooo100000040:ZZZPP000001?ooool40:ZZ
ZP@0EEEE30000004ooooo`@0ZZZZ1?ooool40:ZZZP@00000101EEED4000000@0ZZZZ1?ooool805EE
E@@0ZZZZ1?ooool4000000@0ZZZZ10000005ooooo`P0ZZZZ100000040:ZZZPP00000>?oooolW0=7=
Z@009P3AcJTiooooo`P00000102ZZZX4000000P0ZZZZ1?ooool4000000@0ZZZZ10000004ooooo`@0
ZZZZ201EEED4ooooo`@0ZZZZ1000000405EEE@@00000102ZZZX4ooooo`@0ZZZZ1?ooool<000000@0
EEEE102ZZZX4ooooo`P00000102ZZZX4000000Gooooo102ZZZX405EEE@Cooooo10000004ooooo`@0
EEEE102ZZZX4ooooo`@00000102ZZZX8000000Cooooo102ZZZX405EEE@`000001?ooool40:ZZZPCo
oooo102ZZZX4000000@0EEEE100000040:ZZZPCooooo201EEED40:ZZZPCooooo100000040:ZZZP@0
00001Oooool80:ZZZP@00000102ZZZX8000003Sooooo9`3AcJT002H0dLfY>Oooool8000000@0ZZZZ
100000080:ZZZPCooooo100000040:ZZZP@000001?ooool40:ZZZPP0EEEE1?ooool40:ZZZP@00000
101EEED4000000@0ZZZZ1?ooool40:ZZZPCooooo3000000405EEE@@0ZZZZ1?ooool8000000@0ZZZZ
10000005ooooo`@0ZZZZ101EEED4ooooo`@000001?ooool405EEE@@0ZZZZ1?ooool4000000@0ZZZZ
20000004ooooo`@0ZZZZ101EEED<000000Cooooo102ZZZX4ooooo`@0ZZZZ1000000405EEE@@00000
102ZZZX4ooooo`P0EEEE102ZZZX4ooooo`@00000102ZZZX4000000Gooooo202ZZZX4000000@0ZZZZ
2000000hooooobL0dLfY000V0=7=ZCWooooo200000040:ZZZP@00000202ZZZX4ooooo`@00000102Z
ZZX4000000Cooooo102ZZZX805EEE@Cooooo102ZZZX4000000@0EEEE100000040:ZZZPCooooo102Z
ZZX4ooooo``00000101EEED40:ZZZPCooooo200000040:ZZZP@000001Oooool40:ZZZP@0EEEE1?oo
ool4000000Cooooo101EEED40:ZZZPCooooo100000040:ZZZPP000001?ooool40:ZZZP@0EEEE3000
0004ooooo`@0ZZZZ1?ooool40:ZZZP@00000101EEED4000000@0ZZZZ1?ooool805EEE@@0ZZZZ1?oo
ool4000000@0ZZZZ10000005ooooo`P0ZZZZ100000040:ZZZPP00000>?oooolW0=7=Z@009P3AcJTm
ooooo`@0ZZZZ1?ooool40:ZZZPCooooo202ZZZX<05EEE@P0ZZZZ1?ooool405EEE@P0ZZZZ2?ooool4
000000@0EEEE202ZZZX4ooooo`@00000101EEED4ooooo`@000001?ooool4000000P0ZZZZ10000004
05EEE@Gooooo101EEED4ooooo`@0ZZZZ100000040:ZZZPCooooo101EEED4ooooo`@0EEEE10000008
0:ZZZP@000001?ooool4000000Cooooo101EEED4000000Cooooo202ZZZX405EEE@@000002?ooool8
0:ZZZP@0EEEE1?ooool80:ZZZP`0EEEE2@2ZZZX4ooooo`@0ZZZZ1?ooool40:ZZZScooooo9`3AcJT0
02H0dLfY?Oooool40:ZZZPCooooo102ZZZX4ooooo`P0ZZZZ301EEED80:ZZZPCooooo101EEED80:ZZ
ZPSooooo1000000405EEE@P0ZZZZ1?ooool4000000@0EEEE1?ooool4000000Cooooo100000080:ZZ
ZP@00000101EEED5ooooo`@0EEEE1?ooool40:ZZZP@00000102ZZZX4ooooo`@0EEEE1?ooool405EE
E@@00000202ZZZX4000000Cooooo10000004ooooo`@0EEEE10000004ooooo`P0ZZZZ101EEED40000
00Sooooo202ZZZX405EEE@Cooooo202ZZZX<05EEE@T0ZZZZ1?ooool40:ZZZPCooooo102ZZZXloooo
obL0dLfY000V0=7=ZCgooooo102ZZZX4ooooo`@0ZZZZ1?ooool80:ZZZP`0EEEE202ZZZX4ooooo`@0
EEEE202ZZZX8ooooo`@00000101EEED80:ZZZPCooooo1000000405EEE@Cooooo10000004ooooo`@0
0000202ZZZX4000000@0EEEE1Oooool405EEE@Cooooo102ZZZX4000000@0ZZZZ1?ooool405EEE@Co
oooo101EEED4000000P0ZZZZ10000004ooooo`@000001?ooool405EEE@@000001?ooool80:ZZZP@0
EEEE10000008ooooo`P0ZZZZ101EEED4ooooo`P0ZZZZ301EEED90:ZZZPCooooo102ZZZX4ooooo`@0
ZZZZ??oooolW0=7=Z@009P3AcJTmooooo`@0ZZZZ1?ooool40:ZZZPCooooo202ZZZX<05EEE@P0ZZZZ
1?ooool405EEE@P0ZZZZ2?ooool4000000@0EEEE202ZZZX4ooooo`@00000101EEED4ooooo`@00000
1?ooool4000000P0ZZZZ1000000405EEE@Gooooo101EEED4ooooo`@0ZZZZ100000040:ZZZPCooooo
101EEED4ooooo`@0EEEE100000080:ZZZP@000001?ooool4000000Cooooo101EEED4000000Cooooo
202ZZZX405EEE@@000002?ooool80:ZZZP@0EEEE1?ooool80:ZZZP`0EEEE2@2ZZZX4ooooo`@0ZZZZ
1?ooool40:ZZZScooooo9`3AcJT002H0dLfY@Oooool<05EEE@Sooooo101EEED40:ZZZPCooooo101E
EED<ooooo`P000001?ooool40:ZZZP@00000102ZZZX4000000@0EEEE202ZZZX8000000@0EEEE1?oo
ool405EEE@@00000102ZZZX805EEE@T00000102ZZZX4ooooo`@0ZZZZ1?ooool40:ZZZPP00000201E
EED40:ZZZP@00000101EEED4ooooo`@0EEEE200000080:ZZZP@0EEEE100000040:ZZZP@00000102Z
ZZX4ooooo`P000003?ooool405EEE@Cooooo102ZZZX405EEE@Wooooo301EEEE0ooooobL0dLfY000V
0=7=ZD7ooooo301EEED8ooooo`@0EEEE102ZZZX4ooooo`@0EEEE3?ooool8000000Cooooo102ZZZX4
000000@0ZZZZ1000000405EEE@P0ZZZZ2000000405EEE@Cooooo101EEED4000000@0ZZZZ201EEED9
000000@0ZZZZ1?ooool40:ZZZPCooooo102ZZZX8000000P0EEEE102ZZZX4000000@0EEEE1?ooool4
05EEE@P00000202ZZZX405EEE@@00000102ZZZX4000000@0ZZZZ1?ooool8000000cooooo101EEED4
ooooo`@0ZZZZ101EEED9ooooo``0EEEE@?oooolW0=7=Z@009P3AcJU1ooooo``0EEEE2?ooool405EE
E@@0ZZZZ1?ooool405EEE@cooooo20000004ooooo`@0ZZZZ100000040:ZZZP@00000101EEED80:ZZ
ZPP00000101EEED4ooooo`@0EEEE100000040:ZZZPP0EEEE2@0000040:ZZZPCooooo102ZZZX4oooo
o`@0ZZZZ2000000805EEE@@0ZZZZ1000000405EEE@Cooooo101EEED8000000P0ZZZZ101EEED40000
00@0ZZZZ100000040:ZZZPCooooo2000000<ooooo`@0EEEE1?ooool40:ZZZP@0EEEE2Oooool<05EE
ED3ooooo9`3AcJT002H0dLfY@Oooool<05EEE@Sooooo101EEED40:ZZZPCooooo101EEED<ooooo`P0
00001?ooool40:ZZZP@00000102ZZZX4000000@0EEEE202ZZZX8000000@0EEEE1?ooool405EEE@@0
0000102ZZZX805EEE@T00000102ZZZX4ooooo`@0ZZZZ1?ooool40:ZZZPP00000201EEED40:ZZZP@0
0000101EEED4ooooo`@0EEEE200000080:ZZZP@0EEEE100000040:ZZZP@00000102ZZZX4ooooo`P0
00003?ooool405EEE@Cooooo102ZZZX405EEE@Wooooo301EEEE0ooooobL0dLfY000V0=7=ZDGooooo
1000000@ooooo`P00000201EEED4ooooo`P0EEEE102ZZZX405EEE@@0ZZZZ100000040:ZZZPP0EEEE
100000040:ZZZPP0EEEE102ZZZX4ooooo`@000001?ooool405EEE@Cooooo102ZZZX905EEE@@0ZZZZ
10000004ooooo`@00000102ZZZX805EEE@@0ZZZZ1?ooool405EEE@Cooooo10000004ooooo`@0ZZZZ
201EEED40:ZZZP@00000201EEED40:ZZZP@00000102ZZZX405EEE@@0ZZZZ201EEED4ooooo`P0EEEE
2000000Aooooo`@00000A?oooolW0=7=Z@009P3AcJU5ooooo`@000004?ooool8000000P0EEEE1?oo
ool805EEE@@0ZZZZ101EEED40:ZZZP@00000102ZZZX805EEE@@00000102ZZZX805EEE@@0ZZZZ1?oo
ool4000000Cooooo101EEED4ooooo`@0ZZZZ2@1EEED40:ZZZP@000001?ooool4000000@0ZZZZ201E
EED40:ZZZPCooooo101EEED4ooooo`@000001?ooool40:ZZZPP0EEEE102ZZZX4000000P0EEEE102Z
ZZX4000000@0ZZZZ101EEED40:ZZZPP0EEEE1?ooool805EEE@P000004Oooool4000004Cooooo9`3A
cJT002H0dLfYAOooool40000013ooooo2000000805EEE@Cooooo201EEED40:ZZZP@0EEEE102ZZZX4
000000@0ZZZZ201EEED4000000@0ZZZZ201EEED40:ZZZPCooooo10000004ooooo`@0EEEE1?ooool4
0:ZZZPT0EEEE102ZZZX4000000Cooooo100000040:ZZZPP0EEEE102ZZZX4ooooo`@0EEEE1?ooool4
000000Cooooo102ZZZX805EEE@@0ZZZZ1000000805EEE@@0ZZZZ100000040:ZZZP@0EEEE102ZZZX8
05EEE@Cooooo201EEED80000017ooooo10000014ooooobL0dLfY000V0=7=ZDGooooo1000000@oooo
o`P00000201EEED4ooooo`P0EEEE102ZZZX405EEE@@0ZZZZ100000040:ZZZPP0EEEE100000040:ZZ
ZPP0EEEE102ZZZX4ooooo`@000001?ooool405EEE@Cooooo102ZZZX905EEE@@0ZZZZ10000004oooo
o`@00000102ZZZX805EEE@@0ZZZZ1?ooool405EEE@Cooooo10000004ooooo`@0ZZZZ201EEED40:ZZ
ZP@00000201EEED40:ZZZP@00000102ZZZX405EEE@@0ZZZZ201EEED4ooooo`P0EEEE2000000Aoooo
o`@00000A?oooolW0=7=Z@009P3AcJU9ooooo`@0ZZZZ10000004ooooo`@0ZZZZ1000000@0:ZZZP@0
EEEE1?ooool<0:ZZZPSooooo101EEED40:ZZZPSooooo101EEED40:ZZZPCooooo102ZZZX4000000@0
ZZZZ1?ooool=05EEE@@00000101EEED40:ZZZP@0EEEE102ZZZX405EEE@@00000301EEED4ooooo`@0
ZZZZ100000040:ZZZPCooooo102ZZZX405EEE@Sooooo102ZZZX405EEE@Sooooo302ZZZX4ooooo`@0
EEEE402ZZZX4000000@0ZZZZ1Oooool4000000@0ZZZZB?oooolW0=7=Z@009P3AcJU9ooooo`@0ZZZZ
10000004ooooo`@0ZZZZ1000000@0:ZZZP@0EEEE1?ooool<0:ZZZPSooooo101EEED40:ZZZPSooooo
101EEED40:ZZZPCooooo102ZZZX4000000@0ZZZZ1?ooool=05EEE@@00000101EEED40:ZZZP@0EEEE
102ZZZX405EEE@@00000301EEED4ooooo`@0ZZZZ100000040:ZZZPCooooo102ZZZX405EEE@Sooooo
102ZZZX405EEE@Sooooo302ZZZX4ooooo`@0EEEE402ZZZX4000000@0ZZZZ1Oooool4000000@0ZZZZ
B?oooolW0=7=Z@009P3AcJU9ooooo`@0ZZZZ10000004ooooo`@0ZZZZ1000000@0:ZZZP@0EEEE1?oo
ool<0:ZZZPSooooo101EEED40:ZZZPSooooo101EEED40:ZZZPCooooo102ZZZX4000000@0ZZZZ1?oo
ool=05EEE@@00000101EEED40:ZZZP@0EEEE102ZZZX405EEE@@00000301EEED4ooooo`@0ZZZZ1000
00040:ZZZPCooooo102ZZZX405EEE@Sooooo102ZZZX405EEE@Sooooo302ZZZX4ooooo`@0EEEE402Z
ZZX4000000@0ZZZZ1Oooool4000000@0ZZZZB?oooolW0=7=Z@009P3AcJU9ooooo`@0ZZZZ10000004
ooooo`@0ZZZZ1000000@0:ZZZP@0EEEE1?ooool<0:ZZZPSooooo101EEED40:ZZZPSooooo101EEED4
0:ZZZPCooooo102ZZZX4000000@0ZZZZ1?ooool=05EEE@@00000101EEED40:ZZZP@0EEEE102ZZZX4
05EEE@@00000301EEED4ooooo`@0ZZZZ100000040:ZZZPCooooo102ZZZX405EEE@Sooooo102ZZZX4
05EEE@Sooooo302ZZZX4ooooo`@0EEEE402ZZZX4000000@0ZZZZ1Oooool4000000@0ZZZZB?oooolW
0=7=Z@009P3AcJU=ooooo`@0EEEE20000004ooooo`@0EEEE2?ooool405EEE@Cooooo102ZZZX40000
00@0EEEE102ZZZX4000000Cooooo102ZZZX405EEE@P00000301EEED8ooooo`P0ZZZZ101EEED4oooo
o`D0ZZZZ201EEED4000000@0ZZZZ1000000805EEE@@0ZZZZ1?ooool405EEE@P0ZZZZ2?ooool<05EE
E@P00000101EEED40:ZZZPCooooo100000040:ZZZP@0EEEE100000040:ZZZPCooooo101EEED8oooo
o`@0EEEE1?ooool9000000@0EEEEC?oooolW0=7=Z@009P3AcJU=ooooo`@0EEEE20000004ooooo`@0
EEEE2?ooool405EEE@Cooooo102ZZZX4000000@0EEEE102ZZZX4000000Cooooo102ZZZX405EEE@P0
0000301EEED8ooooo`P0ZZZZ101EEED4ooooo`D0ZZZZ201EEED4000000@0ZZZZ1000000805EEE@@0
ZZZZ1?ooool405EEE@P0ZZZZ2?ooool<05EEE@P00000101EEED40:ZZZPCooooo100000040:ZZZP@0
EEEE100000040:ZZZPCooooo101EEED8ooooo`@0EEEE1?ooool9000000@0EEEEC?oooolW0=7=Z@00
9P3AcJU=ooooo`@0EEEE20000004ooooo`@0EEEE2?ooool405EEE@Cooooo102ZZZX4000000@0EEEE
102ZZZX4000000Cooooo102ZZZX405EEE@P00000301EEED8ooooo`P0ZZZZ101EEED4ooooo`D0ZZZZ
201EEED4000000@0ZZZZ1000000805EEE@@0ZZZZ1?ooool405EEE@P0ZZZZ2?ooool<05EEE@P00000
101EEED40:ZZZPCooooo100000040:ZZZP@0EEEE100000040:ZZZPCooooo101EEED8ooooo`@0EEEE
1?ooool9000000@0EEEEC?oooolW0=7=Z@009P3AcJU=ooooo`@0EEEE20000004ooooo`@0EEEE2?oo
ool405EEE@Cooooo102ZZZX4000000@0EEEE102ZZZX4000000Cooooo102ZZZX405EEE@P00000301E
EED8ooooo`P0ZZZZ101EEED4ooooo`D0ZZZZ201EEED4000000@0ZZZZ1000000805EEE@@0ZZZZ1?oo
ool405EEE@P0ZZZZ2?ooool<05EEE@P00000101EEED40:ZZZPCooooo100000040:ZZZP@0EEEE1000
00040:ZZZPCooooo101EEED8ooooo`@0EEEE1?ooool9000000@0EEEEC?oooolW0=7=Z@009P3AcJUA
ooooo`@00000101EEED4ooooo`@0EEEE202ZZZX405EEE@Cooooo101EEED4ooooo`@000001?ooool4
000000@0EEEE100000040:ZZZP@00000502ZZZX405EEE@@0ZZZZ1000000805EEE@Wooooo10000004
ooooo`@0EEEE1?ooool4000000Sooooo201EEED4000000@0ZZZZ101EEEDD0:ZZZP@00000102ZZZX4
000000@0EEEE10000004ooooo`@000001?ooool405EEE@Cooooo101EEED80:ZZZP@0EEEE1?ooool4
05EEE@D00000D?oooolW0=7=Z@009P3AcJUAooooo`@00000101EEED4ooooo`@0EEEE202ZZZX405EE
E@Cooooo101EEED4ooooo`@000001?ooool4000000@0EEEE100000040:ZZZP@00000502ZZZX405EE
E@@0ZZZZ1000000805EEE@Wooooo10000004ooooo`@0EEEE1?ooool4000000Sooooo201EEED40000
00@0ZZZZ101EEEDD0:ZZZP@00000102ZZZX4000000@0EEEE10000004ooooo`@000001?ooool405EE
E@Cooooo101EEED80:ZZZP@0EEEE1?ooool405EEE@D00000D?oooolW0=7=Z@009P3AcJUAooooo`@0
0000101EEED4ooooo`@0EEEE202ZZZX405EEE@Cooooo101EEED4ooooo`@000001?ooool4000000@0
EEEE100000040:ZZZP@00000502ZZZX405EEE@@0ZZZZ1000000805EEE@Wooooo10000004ooooo`@0
EEEE1?ooool4000000Sooooo201EEED4000000@0ZZZZ101EEEDD0:ZZZP@00000102ZZZX4000000@0
EEEE10000004ooooo`@000001?ooool405EEE@Cooooo101EEED80:ZZZP@0EEEE1?ooool405EEE@D0
0000D?oooolW0=7=Z@009P3AcJUAooooo`@00000101EEED4ooooo`@0EEEE202ZZZX405EEE@Cooooo
101EEED4ooooo`@000001?ooool4000000@0EEEE100000040:ZZZP@00000502ZZZX405EEE@@0ZZZZ
1000000805EEE@Wooooo10000004ooooo`@0EEEE1?ooool4000000Sooooo201EEED4000000@0ZZZZ
101EEEDD0:ZZZP@00000102ZZZX4000000@0EEEE10000004ooooo`@000001?ooool405EEE@Cooooo
101EEED80:ZZZP@0EEEE1?ooool405EEE@D00000D?oooolW0=7=Z@009P3AcJUEooooo`@0ZZZZ101E
EED40:ZZZPCooooo302ZZZX405EEE@Cooooo101EEED<000000P0ZZZZ2?ooool405EEE@Sooooo101E
EED4ooooo`P0ZZZZ200000050:ZZZPCooooo1000000405EEE@@00000101EEED4000000Cooooo102Z
ZZX8000000P0ZZZZ1?ooool405EEE@Sooooo101EEED8ooooo`P0ZZZZ3000000405EEE@Cooooo101E
EED<0:ZZZPCooooo102ZZZX405EEE@@0ZZZZEOoooolW0=7=Z@009P3AcJUEooooo`@0ZZZZ101EEED4
0:ZZZPCooooo302ZZZX405EEE@Cooooo101EEED<000000P0ZZZZ2?ooool405EEE@Sooooo101EEED4
ooooo`P0ZZZZ200000050:ZZZPCooooo1000000405EEE@@00000101EEED4000000Cooooo102ZZZX8
000000P0ZZZZ1?ooool405EEE@Sooooo101EEED8ooooo`P0ZZZZ3000000405EEE@Cooooo101EEED<
0:ZZZPCooooo102ZZZX405EEE@@0ZZZZEOoooolW0=7=Z@009P3AcJUEooooo`@0ZZZZ101EEED40:ZZ
ZPCooooo302ZZZX405EEE@Cooooo101EEED<000000P0ZZZZ2?ooool405EEE@Sooooo101EEED4oooo
o`P0ZZZZ200000050:ZZZPCooooo1000000405EEE@@00000101EEED4000000Cooooo102ZZZX80000
00P0ZZZZ1?ooool405EEE@Sooooo101EEED8ooooo`P0ZZZZ3000000405EEE@Cooooo101EEED<0:ZZ
ZPCooooo102ZZZX405EEE@@0ZZZZEOoooolW0=7=Z@009P3AcJUEooooo`@0ZZZZ101EEED40:ZZZPCo
oooo302ZZZX405EEE@Cooooo101EEED<000000P0ZZZZ2?ooool405EEE@Sooooo101EEED4ooooo`P0
ZZZZ200000050:ZZZPCooooo1000000405EEE@@00000101EEED4000000Cooooo102ZZZX8000000P0
ZZZZ1?ooool405EEE@Sooooo101EEED8ooooo`P0ZZZZ3000000405EEE@Cooooo101EEED<0:ZZZPCo
oooo102ZZZX405EEE@@0ZZZZEOoooolW0=7=Z@009P3AcJUIooooo`@0EEEE102ZZZX4000000Cooooo
2000000<ooooo`@00000101EEED4ooooo`P000001?ooool40:ZZZPP00000101EEED4000000@0EEEE
100000040:ZZZPP0EEEE1@2ZZZX4000000Cooooo101EEED40:ZZZP@0EEEE1?ooool4000000@0ZZZZ
201EEED40:ZZZP@00000101EEED4000000@0EEEE200000040:ZZZPCooooo20000004ooooo`@0EEEE
1000000<ooooo`P000001?ooool4000000@0ZZZZ101EEEEIooooobL0dLfY000V0=7=ZEWooooo101E
EED40:ZZZP@000001?ooool8000000cooooo1000000405EEE@Cooooo20000004ooooo`@0ZZZZ2000
000405EEE@@00000101EEED4000000@0ZZZZ201EEED50:ZZZP@000001?ooool405EEE@@0ZZZZ101E
EED4ooooo`@00000102ZZZX805EEE@@0ZZZZ1000000405EEE@@00000101EEED8000000@0ZZZZ1?oo
ool8000000Cooooo101EEED4000000cooooo20000004ooooo`@00000102ZZZX405EEEEWooooo9`3A
cJT002H0dLfYFOooool405EEE@@0ZZZZ10000004ooooo`P000003?ooool4000000@0EEEE1?ooool8
000000Cooooo102ZZZX8000000@0EEEE1000000405EEE@@00000102ZZZX805EEE@D0ZZZZ10000004
ooooo`@0EEEE102ZZZX405EEE@Cooooo100000040:ZZZPP0EEEE102ZZZX4000000@0EEEE10000004
05EEE@P00000102ZZZX4ooooo`P000001?ooool405EEE@@000003?ooool8000000Cooooo10000004
0:ZZZP@0EEEEFOoooolW0=7=Z@009P3AcJUIooooo`@0EEEE102ZZZX4000000Cooooo2000000<oooo
o`@00000101EEED4ooooo`P000001?ooool40:ZZZPP00000101EEED4000000@0EEEE100000040:ZZ
ZPP0EEEE1@2ZZZX4000000Cooooo101EEED40:ZZZP@0EEEE1?ooool4000000@0ZZZZ201EEED40:ZZ
ZP@00000101EEED4000000@0EEEE200000040:ZZZPCooooo20000004ooooo`@0EEEE1000000<oooo
o`P000001?ooool4000000@0ZZZZ101EEEEIooooobL0dLfY000V0=7=ZEgooooo3000000405EEE@Co
oooo100000040:ZZZPCooooo1000000805EEE@Cooooo1000000405EEE@@00000202ZZZX<000000P0
ZZZZ1?ooool405EEE@D0ZZZZ100000040:ZZZPCooooo101EEED4ooooo`@0ZZZZ100000040:ZZZP@0
EEEE1?ooool80:ZZZP`00000202ZZZX4000000@0EEEE10000004ooooo`P0EEEE10000004ooooo`@0
ZZZZ10000004ooooo`@0EEEE3000001MooooobL0dLfY000V0=7=ZEgooooo3000000405EEE@Cooooo
100000040:ZZZPCooooo1000000805EEE@Cooooo1000000405EEE@@00000202ZZZX<000000P0ZZZZ
1?ooool405EEE@D0ZZZZ100000040:ZZZPCooooo101EEED4ooooo`@0ZZZZ100000040:ZZZP@0EEEE
1?ooool80:ZZZP`00000202ZZZX4000000@0EEEE10000004ooooo`P0EEEE10000004ooooo`@0ZZZZ
10000004ooooo`@0EEEE3000001MooooobL0dLfY000V0=7=ZEgooooo3000000405EEE@Cooooo1000
00040:ZZZPCooooo1000000805EEE@Cooooo1000000405EEE@@00000202ZZZX<000000P0ZZZZ1?oo
ool405EEE@D0ZZZZ100000040:ZZZPCooooo101EEED4ooooo`@0ZZZZ100000040:ZZZP@0EEEE1?oo
ool80:ZZZP`00000202ZZZX4000000@0EEEE10000004ooooo`P0EEEE10000004ooooo`@0ZZZZ1000
0004ooooo`@0EEEE3000001MooooobL0dLfY000V0=7=ZEgooooo3000000405EEE@Cooooo10000004
0:ZZZPCooooo1000000805EEE@Cooooo1000000405EEE@@00000202ZZZX<000000P0ZZZZ1?ooool4
05EEE@D0ZZZZ100000040:ZZZPCooooo101EEED4ooooo`@0ZZZZ100000040:ZZZP@0EEEE1?ooool8
0:ZZZP`00000202ZZZX4000000@0EEEE10000004ooooo`P0EEEE10000004ooooo`@0ZZZZ10000004
ooooo`@0EEEE3000001MooooobL0dLfY000V0=7=ZF7ooooo102ZZZX8ooooo`@00000202ZZZX4oooo
o`@00000201EEED<000000P0ZZZZ1?ooool40:ZZZPSooooo202ZZZX4ooooo`@000001Oooool40000
00@0EEEE302ZZZX405EEE@@000001?ooool4000000Cooooo202ZZZX8ooooo`@0ZZZZ1?ooool80:ZZ
ZP`00000201EEED4000000Cooooo202ZZZX4000000Sooooo102ZZZYQooooobL0dLfY000V0=7=ZF7o
oooo102ZZZX8ooooo`@00000202ZZZX4ooooo`@00000201EEED<000000P0ZZZZ1?ooool40:ZZZPSo
oooo202ZZZX4ooooo`@000001Oooool4000000@0EEEE302ZZZX405EEE@@000001?ooool4000000Co
oooo202ZZZX8ooooo`@0ZZZZ1?ooool80:ZZZP`00000201EEED4000000Cooooo202ZZZX4000000So
oooo102ZZZYQooooobL0dLfY000V0=7=ZF7ooooo102ZZZX8ooooo`@00000202ZZZX4ooooo`@00000
201EEED<000000P0ZZZZ1?ooool40:ZZZPSooooo202ZZZX4ooooo`@000001Oooool4000000@0EEEE
302ZZZX405EEE@@000001?ooool4000000Cooooo202ZZZX8ooooo`@0ZZZZ1?ooool80:ZZZP`00000
201EEED4000000Cooooo202ZZZX4000000Sooooo102ZZZYQooooobL0dLfY000V0=7=ZF7ooooo102Z
ZZX8ooooo`@00000202ZZZX4ooooo`@00000201EEED<000000P0ZZZZ1?ooool40:ZZZPSooooo202Z
ZZX4ooooo`@000001Oooool4000000@0EEEE302ZZZX405EEE@@000001?ooool4000000Cooooo202Z
ZZX8ooooo`@0ZZZZ1?ooool80:ZZZP`00000201EEED4000000Cooooo202ZZZX4000000Sooooo102Z
ZZYQooooobL0dLfY000V0=7=ZFGooooo201EEED4ooooo`P000001?ooool40:ZZZPCooooo101EEED4
0:ZZZPP0EEEE102ZZZX4000000@0EEEE100000040:ZZZPCooooo20000004ooooo`@0ZZZZ1Oooool4
000001@0EEEE10000004ooooo`@0ZZZZ1?ooool8000000Cooooo102ZZZX4000000@0EEEE10000004
0:ZZZPP0EEEE102ZZZX405EEE@Cooooo102ZZZX4ooooo`P000001?ooool805EEEFGooooo9`3AcJT0
02H0dLfYIOooool805EEE@Cooooo20000004ooooo`@0ZZZZ1?ooool405EEE@@0ZZZZ201EEED40:ZZ
ZP@00000101EEED4000000@0ZZZZ1?ooool8000000Cooooo102ZZZX5ooooo`@00000501EEED40000
00Cooooo102ZZZX4ooooo`P000001?ooool40:ZZZP@00000101EEED4000000@0ZZZZ201EEED40:ZZ
ZP@0EEEE1?ooool40:ZZZPCooooo20000004ooooo`P0EEEEIOoooolW0=7=Z@009P3AcJUUooooo`P0
EEEE1?ooool8000000Cooooo102ZZZX4ooooo`@0EEEE102ZZZX805EEE@@0ZZZZ1000000405EEE@@0
0000102ZZZX4ooooo`P000001?ooool40:ZZZPGooooo1000000D05EEE@@000001?ooool40:ZZZPCo
oooo20000004ooooo`@0ZZZZ1000000405EEE@@00000102ZZZX805EEE@@0ZZZZ101EEED4ooooo`@0
ZZZZ1?ooool8000000Cooooo201EEEEUooooobL0dLfY000V0=7=ZFGooooo201EEED4ooooo`P00000
1?ooool40:ZZZPCooooo101EEED40:ZZZPP0EEEE102ZZZX4000000@0EEEE100000040:ZZZPCooooo
20000004ooooo`@0ZZZZ1Oooool4000001@0EEEE10000004ooooo`@0ZZZZ1?ooool8000000Cooooo
102ZZZX4000000@0EEEE100000040:ZZZPP0EEEE102ZZZX405EEE@Cooooo102ZZZX4ooooo`P00000
1?ooool805EEEFGooooo9`3AcJT002H0dLfYJOooool4000000Cooooo102ZZZX<ooooo`P0EEEE1000
00040:ZZZPP000001?ooool405EEE@@0ZZZZ101EEED@000000@0EEEE2@2ZZZX8000000@0ZZZZ2000
00080:ZZZP@0EEEE4000000405EEE@@0ZZZZ101EEED4ooooo`P00000102ZZZX4000000P0EEEE3?oo
ool40:ZZZPCooooo1000001YooooobL0dLfY000V0=7=ZFWooooo10000004ooooo`@0ZZZZ3?ooool8
05EEE@@00000102ZZZX8000000Cooooo101EEED40:ZZZP@0EEEE4000000405EEE@T0ZZZZ20000004
0:ZZZPP00000202ZZZX405EEEA000000101EEED40:ZZZP@0EEEE1?ooool8000000@0ZZZZ10000008
05EEE@cooooo102ZZZX4ooooo`@00000JOoooolW0=7=Z@009P3AcJUYooooo`@000001?ooool40:ZZ
ZPcooooo201EEED4000000@0ZZZZ20000004ooooo`@0EEEE102ZZZX405EEEA000000101EEED90:ZZ
ZPP00000102ZZZX8000000P0ZZZZ101EEED@000000@0EEEE102ZZZX405EEE@Cooooo200000040:ZZ
ZP@00000201EEED<ooooo`@0ZZZZ1?ooool4000006Wooooo9`3AcJT002H0dLfYJOooool4000000Co
oooo102ZZZX<ooooo`P0EEEE100000040:ZZZPP000001?ooool405EEE@@0ZZZZ101EEED@000000@0
EEEE2@2ZZZX8000000@0ZZZZ200000080:ZZZP@0EEEE4000000405EEE@@0ZZZZ101EEED4ooooo`P0
0000102ZZZX4000000P0EEEE3?ooool40:ZZZPCooooo1000001YooooobL0dLfY000V0=7=ZFgooooo
102ZZZX4000000@0EEEE2000000805EEE@@000001?ooool4000000@0EEEE1?ooool405EEE@@0ZZZZ
600000050:ZZZP@0EEEE10000004ooooo`@0EEEE1?ooool4000000@0EEEE102ZZZXH000000@0ZZZZ
101EEED4ooooo`@0EEEE10000004ooooo`@00000201EEED8000000@0EEEE100000040:ZZZVgooooo
9`3AcJT002H0dLfYKOooool40:ZZZP@00000101EEED8000000P0EEEE10000004ooooo`@00000101E
EED4ooooo`@0EEEE102ZZZXH000000D0ZZZZ101EEED4000000Cooooo101EEED4ooooo`@00000101E
EED40:ZZZQP00000102ZZZX405EEE@Cooooo101EEED4000000Cooooo1000000805EEE@P00000101E
EED4000000@0ZZZZKOoooolW0=7=Z@009P3AcJU]ooooo`@0ZZZZ1000000405EEE@P00000201EEED4
000000Cooooo1000000405EEE@Cooooo101EEED40:ZZZQP000001@2ZZZX405EEE@@000001?ooool4
05EEE@Cooooo1000000405EEE@@0ZZZZ600000040:ZZZP@0EEEE1?ooool405EEE@@000001?ooool4
000000P0EEEE2000000405EEE@@00000102ZZZY]ooooobL0dLfY000V0=7=ZFgooooo102ZZZX40000
00@0EEEE2000000805EEE@@000001?ooool4000000@0EEEE1?ooool405EEE@@0ZZZZ600000050:ZZ
ZP@0EEEE10000004ooooo`@0EEEE1?ooool4000000@0EEEE102ZZZXH000000@0ZZZZ101EEED4oooo
o`@0EEEE10000004ooooo`@00000201EEED8000000@0EEEE100000040:ZZZVgooooo9`3AcJT002H0
dLfYLOooool405EEE@@00000101EEED4ooooo`@000002?ooool40:ZZZP@00000102ZZZX4000000So
oooo101EEED4000000Cooooo101EEED4000000Cooooo1@1EEED4ooooo`@0ZZZZ1?ooool4000000Co
oooo102ZZZX4ooooo`@0EEEE1?ooool4000000@0EEEE1?ooool4000000@0EEEE2?ooool4000000@0
ZZZZ100000040:ZZZPSooooo10000004ooooo`@0EEEE1000000405EEEG7ooooo9`3AcJT002H0dLfY
LOooool405EEE@@00000101EEED4ooooo`@000002?ooool40:ZZZP@00000102ZZZX4000000Sooooo
101EEED4000000Cooooo101EEED4000000Cooooo1@1EEED4ooooo`@0ZZZZ1?ooool4000000Cooooo
102ZZZX4ooooo`@0EEEE1?ooool4000000@0EEEE1?ooool4000000@0EEEE2?ooool4000000@0ZZZZ
100000040:ZZZPSooooo10000004ooooo`@0EEEE1000000405EEEG7ooooo9`3AcJT002H0dLfYLOoo
ool405EEE@@00000101EEED4ooooo`@000002?ooool40:ZZZP@00000102ZZZX4000000Sooooo101E
EED4000000Cooooo101EEED4000000Cooooo1@1EEED4ooooo`@0ZZZZ1?ooool4000000Cooooo102Z
ZZX4ooooo`@0EEEE1?ooool4000000@0EEEE1?ooool4000000@0EEEE2?ooool4000000@0ZZZZ1000
00040:ZZZPSooooo10000004ooooo`@0EEEE1000000405EEEG7ooooo9`3AcJT002H0dLfYLOooool4
05EEE@@00000101EEED4ooooo`@000002?ooool40:ZZZP@00000102ZZZX4000000Sooooo101EEED4
000000Cooooo101EEED4000000Cooooo1@1EEED4ooooo`@0ZZZZ1?ooool4000000Cooooo102ZZZX4
ooooo`@0EEEE1?ooool4000000@0EEEE1?ooool4000000@0EEEE2?ooool4000000@0ZZZZ10000004
0:ZZZPSooooo10000004ooooo`@0EEEE1000000405EEEG7ooooo9`3AcJT002H0dLfYMOooool40000
00P0EEEE1?ooool4000000@0ZZZZ1?ooool40:ZZZPCooooo102ZZZX4ooooo`@00000102ZZZX40000
00@0ZZZZ1?ooool405EEE@T00000102ZZZX4ooooo`@0ZZZZ100000040:ZZZPCooooo102ZZZX80000
00@0EEEE1?ooool40:ZZZP@00000102ZZZX4000000Cooooo102ZZZX4ooooo`@0ZZZZ1?ooool40:ZZ
ZP@000001?ooool805EEE@@00000MOoooolW0=7=Z@009P3AcJUeooooo`@00000201EEED4ooooo`@0
0000102ZZZX4ooooo`@0ZZZZ1?ooool40:ZZZPCooooo100000040:ZZZP@00000102ZZZX4ooooo`@0
EEEE2@0000040:ZZZPCooooo102ZZZX4000000@0ZZZZ1?ooool40:ZZZPP00000101EEED4ooooo`@0
ZZZZ100000040:ZZZP@000001?ooool40:ZZZPCooooo102ZZZX4ooooo`@0ZZZZ10000004ooooo`P0
EEEE1000001eooooobL0dLfY000V0=7=ZGGooooo1000000805EEE@Cooooo100000040:ZZZPCooooo
102ZZZX4ooooo`@0ZZZZ1?ooool4000000@0ZZZZ100000040:ZZZPCooooo101EEED9000000@0ZZZZ
1?ooool40:ZZZP@00000102ZZZX4ooooo`@0ZZZZ2000000405EEE@Cooooo102ZZZX4000000@0ZZZZ
10000004ooooo`@0ZZZZ1?ooool40:ZZZPCooooo102ZZZX4000000Cooooo201EEED4000007Gooooo
9`3AcJT002H0dLfYMOooool4000000P0EEEE1?ooool4000000@0ZZZZ1?ooool40:ZZZPCooooo102Z
ZZX4ooooo`@00000102ZZZX4000000@0ZZZZ1?ooool405EEE@T00000102ZZZX4ooooo`@0ZZZZ1000
00040:ZZZPCooooo102ZZZX8000000@0EEEE1?ooool40:ZZZP@00000102ZZZX4000000Cooooo102Z
ZZX4ooooo`@0ZZZZ1?ooool40:ZZZP@000001?ooool805EEE@@00000MOoooolW0=7=Z@009P3AcJUi
ooooo`@0ZZZZ101EEED4ooooo`@0EEEE100000040:ZZZPCooooo102ZZZX4000000@0EEEE10000004
ooooo`@00000101EEED<0:ZZZPD00000102ZZZX405EEE@@0ZZZZ100000040:ZZZP@0EEEE102ZZZX4
000000`0ZZZZ101EEED4000000Cooooo1000000405EEE@@00000102ZZZX4ooooo`@0ZZZZ10000004
05EEE@Cooooo101EEED40:ZZZWWooooo9`3AcJT002H0dLfYNOooool40:ZZZP@0EEEE1?ooool405EE
E@@00000102ZZZX4ooooo`@0ZZZZ1000000405EEE@@000001?ooool4000000@0EEEE302ZZZX50000
00@0ZZZZ101EEED40:ZZZP@00000102ZZZX405EEE@@0ZZZZ1000000<0:ZZZP@0EEEE10000004oooo
o`@00000101EEED4000000@0ZZZZ1?ooool40:ZZZP@00000101EEED4ooooo`@0EEEE102ZZZYioooo
obL0dLfY000V0=7=ZGWooooo102ZZZX405EEE@Cooooo101EEED4000000@0ZZZZ1?ooool40:ZZZP@0
0000101EEED4000000Cooooo1000000405EEE@`0ZZZZ1@0000040:ZZZP@0EEEE102ZZZX4000000@0
ZZZZ101EEED40:ZZZP@00000302ZZZX405EEE@@000001?ooool4000000@0EEEE100000040:ZZZPCo
oooo102ZZZX4000000@0EEEE1?ooool405EEE@@0ZZZZNOoooolW0=7=Z@009P3AcJUiooooo`@0ZZZZ
101EEED4ooooo`@0EEEE100000040:ZZZPCooooo102ZZZX4000000@0EEEE10000004ooooo`@00000
101EEED<0:ZZZPD00000102ZZZX405EEE@@0ZZZZ100000040:ZZZP@0EEEE102ZZZX4000000`0ZZZZ
101EEED4000000Cooooo1000000405EEE@@00000102ZZZX4ooooo`@0ZZZZ1000000405EEE@Cooooo
101EEED40:ZZZWWooooo9`3AcJT002H0dLfYOOooool405EEE@`0ZZZZ1000000405EEE@@00000302Z
ZZX4000000Cooooo101EEED40:ZZZP@00000101EEED50:ZZZP@0EEEE1000000405EEE@@0ZZZZ101E
EED4000000@0EEEE102ZZZX405EEE@@00000102ZZZX405EEE@Cooooo1000000<0:ZZZP@00000101E
EED4000000`0ZZZZ101EEEEmooooobL0dLfY000V0=7=ZGgooooo101EEED<0:ZZZP@00000101EEED4
000000`0ZZZZ10000004ooooo`@0EEEE102ZZZX4000000@0EEEE1@2ZZZX405EEE@@00000101EEED4
0:ZZZP@0EEEE1000000405EEE@@0ZZZZ101EEED4000000@0ZZZZ101EEED4ooooo`@00000302ZZZX4
000000@0EEEE1000000<0:ZZZP@0EEEEOOoooolW0=7=Z@009P3AcJUmooooo`@0EEEE302ZZZX40000
00@0EEEE1000000<0:ZZZP@000001?ooool405EEE@@0ZZZZ1000000405EEE@D0ZZZZ101EEED40000
00@0EEEE102ZZZX405EEE@@00000101EEED40:ZZZP@0EEEE100000040:ZZZP@0EEEE1?ooool40000
00`0ZZZZ1000000405EEE@@00000302ZZZX405EEEGgooooo9`3AcJT002H0dLfYOOooool405EEE@`0
ZZZZ1000000405EEE@@00000302ZZZX4000000Cooooo101EEED40:ZZZP@00000101EEED50:ZZZP@0
EEEE1000000405EEE@@0ZZZZ101EEED4000000@0EEEE102ZZZX405EEE@@00000102ZZZX405EEE@Co
oooo1000000<0:ZZZP@00000101EEED4000000`0ZZZZ101EEEEmooooobL0dLfY000V0=7=ZH7ooooo
20000004ooooo`@00000201EEED40:ZZZP@00000101EEED40:ZZZP@0EEEE102ZZZX4ooooo`@0ZZZZ
1?ooool505EEE@Cooooo102ZZZX4ooooo`@0EEEE1?ooool40:ZZZPCooooo101EEED4ooooo`@0ZZZZ
1?ooool40:ZZZP@0EEEE102ZZZX405EEE@@00000102ZZZX805EEE@@000001?ooool80000087ooooo
9`3AcJT002H0dLfYPOooool8000000Cooooo1000000805EEE@@0ZZZZ1000000405EEE@@0ZZZZ101E
EED40:ZZZPCooooo102ZZZX4ooooo`D0EEEE1?ooool40:ZZZPCooooo101EEED4ooooo`@0ZZZZ1?oo
ool405EEE@Cooooo102ZZZX4ooooo`@0ZZZZ101EEED40:ZZZP@0EEEE100000040:ZZZPP0EEEE1000
0004ooooo`P00000POoooolW0=7=Z@009P3AcJV1ooooo`P000001?ooool4000000P0EEEE102ZZZX4
000000@0EEEE102ZZZX405EEE@@0ZZZZ1?ooool40:ZZZPCooooo1@1EEED4ooooo`@0ZZZZ1?ooool4
05EEE@Cooooo102ZZZX4ooooo`@0EEEE1?ooool40:ZZZPCooooo102ZZZX405EEE@@0ZZZZ101EEED4
000000@0ZZZZ201EEED4000000Cooooo20000021ooooobL0dLfY000V0=7=ZH7ooooo20000004oooo
o`@00000201EEED40:ZZZP@00000101EEED40:ZZZP@0EEEE102ZZZX4ooooo`@0ZZZZ1?ooool505EE
E@Cooooo102ZZZX4ooooo`@0EEEE1?ooool40:ZZZPCooooo101EEED4ooooo`@0ZZZZ1?ooool40:ZZ
ZP@0EEEE102ZZZX405EEE@@00000102ZZZX805EEE@@000001?ooool80000087ooooo9`3AcJT002H0
dLfYQOooool40:ZZZPCooooo1000000805EEE@@00000302ZZZX4ooooo`@0EEEE1?ooool405EEE@Co
oooo1@1EEED80:ZZZPCooooo10000004ooooo`P0ZZZZ101EEED4ooooo`@0EEEE1?ooool405EEE@Co
oooo302ZZZX4000000P0EEEE10000004ooooo`@0ZZZZQOoooolW0=7=Z@009P3AcJV5ooooo`@0ZZZZ
1?ooool4000000P0EEEE1000000<0:ZZZPCooooo101EEED4ooooo`@0EEEE1?ooool505EEE@P0ZZZZ
1?ooool4000000Cooooo202ZZZX405EEE@Cooooo101EEED4ooooo`@0EEEE1?ooool<0:ZZZP@00000
201EEED4000000Cooooo102ZZZZ5ooooobL0dLfY000V0=7=ZHGooooo102ZZZX4ooooo`@00000201E
EED4000000`0ZZZZ1?ooool405EEE@Cooooo101EEED4ooooo`D0EEEE202ZZZX4ooooo`@000001?oo
ool80:ZZZP@0EEEE1?ooool405EEE@Cooooo101EEED4ooooo``0ZZZZ1000000805EEE@@000001?oo
ool40:ZZZXGooooo9`3AcJT002H0dLfYQOooool40:ZZZPCooooo1000000805EEE@@00000302ZZZX4
ooooo`@0EEEE1?ooool405EEE@Cooooo1@1EEED80:ZZZPCooooo10000004ooooo`P0ZZZZ101EEED4
ooooo`@0EEEE1?ooool405EEE@Cooooo302ZZZX4000000P0EEEE10000004ooooo`@0ZZZZQOoooolW
0=7=Z@009P3AcJV9ooooo`P0EEEE102ZZZX4ooooo`@0EEEE100000040:ZZZP@0EEEE200000040:ZZ
ZPCooooo2@1EEED4000000@0ZZZZ101EEED40:ZZZP@0EEEE102ZZZX4000000P0EEEE1?ooool40:ZZ
ZPP00000101EEED40:ZZZP@00000101EEED4ooooo`@0ZZZZ201EEEF9ooooobL0dLfY000V0=7=ZHWo
oooo201EEED40:ZZZPCooooo101EEED4000000@0ZZZZ101EEED8000000@0ZZZZ1?ooool905EEE@@0
0000102ZZZX405EEE@@0ZZZZ101EEED40:ZZZP@00000201EEED4ooooo`@0ZZZZ2000000405EEE@@0
ZZZZ1000000405EEE@Cooooo102ZZZX805EEEHWooooo9`3AcJT002H0dLfYROooool805EEE@@0ZZZZ
1?ooool405EEE@@00000102ZZZX405EEE@P00000102ZZZX4ooooo`T0EEEE100000040:ZZZP@0EEEE
102ZZZX405EEE@@0ZZZZ1000000805EEE@Cooooo102ZZZX8000000@0EEEE102ZZZX4000000@0EEEE
1?ooool40:ZZZPP0EEEEROoooolW0=7=Z@009P3AcJV9ooooo`P0EEEE102ZZZX4ooooo`@0EEEE1000
00040:ZZZP@0EEEE200000040:ZZZPCooooo2@1EEED4000000@0ZZZZ101EEED40:ZZZP@0EEEE102Z
ZZX4000000P0EEEE1?ooool40:ZZZPP00000101EEED40:ZZZP@00000101EEED4ooooo`@0ZZZZ201E
EEF9ooooobL0dLfY000V0=7=ZHgooooo10000004ooooo`@00000102ZZZX4000000@0ZZZZ101EEED4
ooooo`@00000101EEEDA0:ZZZP@00000301EEED400000100ZZZZ101EEED4000000Cooooo101EEED4
0:ZZZP@00000102ZZZX4000000Cooooo1000002=ooooobL0dLfY000V0=7=ZHgooooo10000004oooo
o`@00000102ZZZX4000000@0ZZZZ101EEED4ooooo`@00000101EEEDA0:ZZZP@00000301EEED40000
0100ZZZZ101EEED4000000Cooooo101EEED40:ZZZP@00000102ZZZX4000000Cooooo1000002=oooo
obL0dLfY000V0=7=ZHgooooo10000004ooooo`@00000102ZZZX4000000@0ZZZZ101EEED4ooooo`@0
0000101EEEDA0:ZZZP@00000301EEED400000100ZZZZ101EEED4000000Cooooo101EEED40:ZZZP@0
0000102ZZZX4000000Cooooo1000002=ooooobL0dLfY000V0=7=ZHgooooo10000004ooooo`@00000
102ZZZX4000000@0ZZZZ101EEED4ooooo`@00000101EEEDA0:ZZZP@00000301EEED400000100ZZZZ
101EEED4000000Cooooo101EEED40:ZZZP@00000102ZZZX4000000Cooooo1000002=ooooobL0dLfY
000V0=7=ZI7ooooo102ZZZX4000000@0ZZZZ301EEED<000000@0ZZZZ101EEED5000000@0ZZZZ201E
EED4000000P0EEEE102ZZZX4000000@0EEEE102ZZZX<000000`0EEEE102ZZZX4000000@0ZZZZTOoo
oolW0=7=Z@009P3AcJVAooooo`@0ZZZZ100000040:ZZZP`0EEEE300000040:ZZZP@0EEEE1@000004
0:ZZZPP0EEEE1000000805EEE@@0ZZZZ1000000405EEE@@0ZZZZ3000000<05EEE@@0ZZZZ10000004
0:ZZZY7ooooo9`3AcJT002H0dLfYTOooool40:ZZZP@00000102ZZZX<05EEE@`00000102ZZZX405EE
E@D00000102ZZZX805EEE@@00000201EEED40:ZZZP@00000101EEED40:ZZZP`00000301EEED40:ZZ
ZP@00000102ZZZZAooooobL0dLfY000V0=7=ZI7ooooo102ZZZX4000000@0ZZZZ301EEED<000000@0
ZZZZ101EEED5000000@0ZZZZ201EEED4000000P0EEEE102ZZZX4000000@0EEEE102ZZZX<000000`0
EEEE102ZZZX4000000@0ZZZZTOoooolW0=7=Z@009P3AcJVEooooo`@0EEEE100000040:ZZZPP00000
202ZZZX4000000@0ZZZZ101EEED5ooooo`P00000102ZZZX4000000@0ZZZZ20000004ooooo`@0EEEE
102ZZZX4000000P0ZZZZ200000040:ZZZP@00000101EEEFEooooobL0dLfY000V0=7=ZIGooooo101E
EED4000000@0ZZZZ200000080:ZZZP@00000102ZZZX405EEE@Gooooo200000040:ZZZP@00000102Z
ZZX8000000Cooooo101EEED40:ZZZP@00000202ZZZX8000000@0ZZZZ1000000405EEEIGooooo9`3A
cJT002H0dLfYUOooool405EEE@@00000102ZZZX8000000P0ZZZZ100000040:ZZZP@0EEEE1Oooool8
000000@0ZZZZ100000040:ZZZPP000001?ooool405EEE@@0ZZZZ100000080:ZZZPP00000102ZZZX4
000000@0EEEEUOoooolW0=7=Z@009P3AcJVEooooo`@0EEEE100000040:ZZZPP00000202ZZZX40000
00@0ZZZZ101EEED5ooooo`P00000102ZZZX4000000@0ZZZZ20000004ooooo`@0EEEE102ZZZX40000
00P0ZZZZ200000040:ZZZP@00000101EEEFEooooobL0dLfY000V0=7=ZIWooooo1000000405EEE@@0
ZZZZ401EEED40:ZZZPT00000101EEED4ooooo``000001?ooool405EEE@P00000102ZZZX@05EEE@@0
ZZZZ101EEED4000009Wooooo9`3AcJT002H0dLfYVOooool4000000@0EEEE102ZZZX@05EEE@@0ZZZZ
2@00000405EEE@Cooooo30000004ooooo`@0EEEE200000040:ZZZQ00EEEE102ZZZX405EEE@@00000
VOoooolW0=7=Z@009P3AcJVIooooo`@00000101EEED40:ZZZQ00EEEE102ZZZX9000000@0EEEE1?oo
ool<000000Cooooo101EEED8000000@0ZZZZ401EEED40:ZZZP@0EEEE1000002IooooobL0dLfY000V
0=7=ZIWooooo1000000405EEE@@0ZZZZ401EEED40:ZZZPT00000101EEED4ooooo``000001?ooool4
05EEE@P00000102ZZZX@05EEE@@0ZZZZ101EEED4000009Wooooo9`3AcJT002H0dLfYWOooool40:ZZ
ZP@0EEEE1000000805EEE@@00000101EEED40:ZZZPT0EEEE5000000805EEE@@0ZZZZ101EEED40000
00P0EEEE1000000405EEE@@0ZZZZWOoooolW0=7=Z@009P3AcJVMooooo`@0ZZZZ101EEED4000000P0
EEEE1000000405EEE@@0ZZZZ2@1EEEDD000000P0EEEE102ZZZX405EEE@@00000201EEED4000000@0
EEEE102ZZZZMooooobL0dLfY000V0=7=ZIgooooo102ZZZX405EEE@@00000201EEED4000000@0EEEE
102ZZZX905EEEA@00000201EEED40:ZZZP@0EEEE1000000805EEE@@00000101EEED40:ZZZYgooooo
9`3AcJT002H0dLfYWOooool40:ZZZP@0EEEE1000000805EEE@@00000101EEED40:ZZZPT0EEEE5000
000805EEE@@0ZZZZ101EEED4000000P0EEEE1000000405EEE@@0ZZZZWOoooolW0=7=Z@009P3AcJVQ
ooooo`@0EEEE102ZZZX405EEE@Cooooo102ZZZX4ooooo`@0EEEE1Oooool40:ZZZPP0EEEE102ZZZX8
05EEE@@0ZZZZ1?ooool405EEE@Cooooo102ZZZX4ooooo`@0EEEE102ZZZX405EEEJ7ooooo9`3AcJT0
02H0dLfYXOooool405EEE@@0ZZZZ101EEED4ooooo`@0ZZZZ1?ooool405EEE@Gooooo102ZZZX805EE
E@@0ZZZZ201EEED40:ZZZPCooooo101EEED4ooooo`@0ZZZZ1?ooool405EEE@@0ZZZZ101EEEFQoooo
obL0dLfY000V0=7=ZJ7ooooo101EEED40:ZZZP@0EEEE1?ooool40:ZZZPCooooo101EEED5ooooo`@0
ZZZZ201EEED40:ZZZPP0EEEE102ZZZX4ooooo`@0EEEE1?ooool40:ZZZPCooooo101EEED40:ZZZP@0
EEEEXOoooolW0=7=Z@009P3AcJVQooooo`@0EEEE102ZZZX405EEE@Cooooo102ZZZX4ooooo`@0EEEE
1Oooool40:ZZZPP0EEEE102ZZZX805EEE@@0ZZZZ1?ooool405EEE@Cooooo102ZZZX4ooooo`@0EEEE
102ZZZX405EEEJ7ooooo9`3AcJT002H0dLfYYOooool8000000@0ZZZZ1?ooool40:ZZZPT00000101E
EED40:ZZZPCooooo101EEED4ooooo`@0ZZZZ101EEED8000000@0ZZZZ1?ooool40:ZZZPP00000YOoo
oolW0=7=Z@009P3AcJVUooooo`P00000102ZZZX4ooooo`@0ZZZZ2@00000405EEE@@0ZZZZ1?ooool4
05EEE@Cooooo102ZZZX405EEE@P00000102ZZZX4ooooo`@0ZZZZ2000002UooooobL0dLfY000V0=7=
ZJGooooo200000040:ZZZPCooooo102ZZZX9000000@0EEEE102ZZZX4ooooo`@0EEEE1?ooool40:ZZ
ZP@0EEEE200000040:ZZZPCooooo102ZZZX800000:Gooooo9`3AcJT002H0dLfYYOooool8000000@0
ZZZZ1?ooool40:ZZZPT00000101EEED40:ZZZPCooooo101EEED4ooooo`@0ZZZZ101EEED8000000@0
ZZZZ1?ooool40:ZZZPP00000YOoooolW0=7=Z@009P3AcJVYooooo`@0ZZZZ1?ooool40:ZZZP@00000
101EEED5ooooo`@000001?ooool4000000@0ZZZZ10000004ooooo`@000001?ooool405EEE@@00000
102ZZZX4ooooo`@0ZZZZZOoooolW0=7=Z@009P3AcJVYooooo`@0ZZZZ1?ooool40:ZZZP@00000101E
EED5ooooo`@000001?ooool4000000@0ZZZZ10000004ooooo`@000001?ooool405EEE@@00000102Z
ZZX4ooooo`@0ZZZZZOoooolW0=7=Z@009P3AcJVYooooo`@0ZZZZ1?ooool40:ZZZP@00000101EEED5
ooooo`@000001?ooool4000000@0ZZZZ10000004ooooo`@000001?ooool405EEE@@00000102ZZZX4
ooooo`@0ZZZZZOoooolW0=7=Z@009P3AcJVYooooo`@0ZZZZ1?ooool40:ZZZP@00000101EEED5oooo
o`@000001?ooool4000000@0ZZZZ10000004ooooo`@000001?ooool405EEE@@00000102ZZZX4oooo
o`@0ZZZZZOoooolW0=7=Z@009P3AcJV]ooooo``0EEEE102ZZZX5ooooo`@00000101EEED4000000Co
oooo1000000405EEE@@000001?ooool40:ZZZP`0EEEE[OoooolW0=7=Z@009P3AcJV]ooooo``0EEEE
102ZZZX5ooooo`@00000101EEED4000000Cooooo1000000405EEE@@000001?ooool40:ZZZP`0EEEE
[OoooolW0=7=Z@009P3AcJV]ooooo``0EEEE102ZZZX5ooooo`@00000101EEED4000000Cooooo1000
000405EEE@@000001?ooool40:ZZZP`0EEEE[OoooolW0=7=Z@009P3AcJV]ooooo``0EEEE102ZZZX5
ooooo`@00000101EEED4000000Cooooo1000000405EEE@@000001?ooool40:ZZZP`0EEEE[OoooolW
0=7=Z@009P3AcJVaooooo`@000002?ooool905EEE@@0ZZZZ3?ooool40:ZZZPP0EEEE2?ooool40000
0;7ooooo9`3AcJT002H0dLfY/Oooool4000000Sooooo2@1EEED40:ZZZPcooooo102ZZZX805EEE@So
oooo1000002aooooobL0dLfY000V0=7=ZK7ooooo10000008ooooo`T0EEEE102ZZZX<ooooo`@0ZZZZ
201EEED8ooooo`@00000/OoooolW0=7=Z@009P3AcJVaooooo`@000002?ooool905EEE@@0ZZZZ3?oo
ool40:ZZZPP0EEEE2?ooool400000;7ooooo9`3AcJT002H0dLfY]Oooool40:ZZZP@000002Oooool8
000000@0EEEE20000008ooooo`@00000102ZZZZeooooobL0dLfY000V0=7=ZKGooooo102ZZZX40000
00Wooooo2000000405EEE@P000002?ooool4000000@0ZZZZ]OoooolW0=7=Z@009P3AcJVeooooo`@0
ZZZZ10000009ooooo`P00000101EEED8000000Sooooo100000040:ZZZ[Gooooo9`3AcJT002H0dLfY
]Oooool40:ZZZP@000002Oooool8000000@0EEEE20000008ooooo`@00000102ZZZZeooooobL0dLfY
000V0=7=ZKWooooo101EEED9000000@0EEEE1?ooool4000000Cooooo101EEED8000000@0EEEE^Ooo
oolW0=7=Z@009P3AcJViooooo`@0EEEE2@00000405EEE@Cooooo10000004ooooo`@0EEEE20000004
05EEEKWooooo9`3AcJT002H0dLfY^Oooool405EEE@T00000101EEED4ooooo`@000001?ooool405EE
E@P00000101EEEFiooooobL0dLfY000V0=7=ZKWooooo101EEED9000000@0EEEE1?ooool4000000Co
oooo101EEED8000000@0EEEE^OoooolW0=7=Z@009P3AcJVmooooo`D00000101EEED4ooooo`@0ZZZZ
100000040:ZZZPCooooo101EEED400000;gooooo9`3AcJT002H0dLfY_Oooool5000000@0EEEE1?oo
ool40:ZZZP@00000102ZZZX4ooooo`@0EEEE1000002mooooobL0dLfY000V0=7=ZKgooooo1@000004
05EEE@Cooooo102ZZZX4000000@0ZZZZ1?ooool405EEE@@00000_OoooolW0=7=Z@009P3AcJVmoooo
o`D00000101EEED4ooooo`@0ZZZZ100000040:ZZZPCooooo101EEED400000;gooooo9`3AcJT002H0
dLfY`_ooool40:ZZZP@0EEEE102ZZZX4000000@0ZZZZ101EEED40:ZZZ/7ooooo9`3AcJT002H0dLfY
`_ooool40:ZZZP@0EEEE102ZZZX4000000@0ZZZZ101EEED40:ZZZ/7ooooo9`3AcJT002H0dLfY`_oo
ool40:ZZZP@0EEEE102ZZZX4000000@0ZZZZ101EEED40:ZZZ/7ooooo9`3AcJT002H0dLfY`_ooool4
0:ZZZP@0EEEE102ZZZX4000000@0ZZZZ101EEED40:ZZZ/7ooooo9`3AcJT002H0dLfYa_ooool405EE
E@@0ZZZZ100000040:ZZZP@0EEEEaOoooolW0=7=Z@009P3AcJW6ooooo`@0EEEE102ZZZX4000000@0
ZZZZ101EEEG5ooooobL0dLfY000V0=7=ZLKooooo101EEED40:ZZZP@00000102ZZZX405EEELGooooo
9`3AcJT002H0dLfYa_ooool405EEE@@0ZZZZ100000040:ZZZP@0EEEEaOoooolW0=7=Z@009P3AcJW:
ooooo``00000bOoooolW0=7=Z@009P3AcJW:ooooo``00000bOoooolW0=7=Z@009P3AcJW:ooooo``0
0000bOoooolW0=7=Z@009P3AcJW:ooooo``00000bOoooolW0=7=Z@009P3AcJW>ooooo`@0ZZZZcOoo
oolW0=7=Z@009P3AcJW>ooooo`@0ZZZZcOoooolW0=7=Z@009P3AcJW>ooooo`@0ZZZZcOoooolW0=7=
Z@009P3AcJW>ooooo`@0ZZZZcOoooolW0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]
0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]
0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]
0=7=Z@00o`3AcJW]0=7=Z@00QP3AcJT014000000dLfY0=7=Z@3AcJT4@0000080dLfY0d0000040=7=
Z@9000000`3AcJT5@0000080dLfY0T0000030=7=Z@=000001@3AcJT00d000000dLfY0=7=Z@020=7=
Z@9000000`3AcJT3@00000@0dLfY0T0000040=7=Z@9000000`3AcJT5@00000040=7=ZD0000100000
@00000D0dLfY00A000000=7=Z@3AcJT0dLfY0d0000040=7=Z@900000103AcJT2@00000<0dLfY0d00
00040=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@020=7=Z@900000103AcJT2@00000@0dLfY0T00
00040=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY0d00
00020=7=Z@9000000`3AcJT5@00000<0dLfY0d0000020=7=Z@900000103AcJT2@00000@0dLfY0T00
00050=7=Z@=000000P3AcJT2@00000<0dLfY1D0000020=7=Z@900000Q`3AcJT008H0dLfY00E00000
0=7=Z@3AcJT0dLfY@00000070=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY
0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=
Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0
dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY
00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=
Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY
00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3A
cJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=0
00000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00@0dLfY00A0
00000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00@0dLfY
00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003A
cJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY08@0dLfY
00260=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00`3AcJT3@0000080dLfY00A0
00000=7=Z@3AcJU00000103AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3A
cJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT0
14000000dLfY0=7=Z@3AcJT3@0000080dLfY00A000000=7=Z@3AcJU000001@3AcJT00d000000dLfY
0=7=Z@020=7=Z@03@000003AcJT0dLfY0080dLfY0d0000040=7=Z@05@000003AcJT0dLfY0=7=ZD00
00000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=
Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY00=00000
0=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@040=7=Z@04@000003AcJT0dLfY@0000080dLfY00=0
00000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00A0
00000=7=Z@3AcJT0dLfY1D0000001@3AcJU000000=7=Z@3AcJU0000000@0dLfY00A000000=7=Z@3A
cJT0dLfY1D0000040=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3A
cJT00d000000dLfY0=7=Z@05@00000@0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=
Z@040=7=Z@03@000003AcJT0dLfY08@0dLfY00270=7=Z@03@000003AcJT0dLfY0080dLfY00E00000
0=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0
0P3AcJT00d000000dLfY0=7=Z@020=7=Z@9000000`3AcJT3@00000H0dLfY00A000000=7=Z@3AcJU0
00000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A00000
0=7=Z@3AcJT0dLfY0T0000050=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY
0=7=Z@030=7=Z@03@000003AcJT0dLfY00=00000103AcJT2@00000@0dLfY0T0000030=7=Z@=00000
103AcJT2@00000H0dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=Z@3AcJT2@00000@0
dLfY0T0000060=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT014000000
dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY0=7=Z@9000001@3AcJT01D000000dLfY0=7=Z@3A
cJU000000080dLfY00A000000=7=Z@3AcJT0dLfY0T0000030=7=Z@04@000003AcJT0dLfY@00000<0
dLfY0T0000030=7=Z@04@000003AcJT0dLfY@00000<0dLfY0T0000050=7=Z@03@000003AcJT0dLfY
0080dLfY0T0000270=7=Z@00Q03AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@05@000
003AcJT0dLfY0=7=ZD0000000P3AcJT01D000000dLfY0=7=Z@3AcJU0000000@0dLfY00A000000=7=
Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY
00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY0=7=Z@040=7=Z@05@000003AcJT0dLfY0=7=
ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@05@000003AcJT0dLfY0=7=ZD000000103A
cJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0
0`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3A
cJU000000`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A00000
0=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000<0
dLfY00=000000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY
0080dLfY00=000000=7=ZD0000000`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00A000000=7=Z@3AcJU000000`3AcJT00d000000dLfY@00000030=7=Z@03@000003A
cJT0dLfY00@0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@260=7=Z@00Q03AcJT4
@00000<0dLfY0T0000040=7=Z@=000000`3AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT3
@0000080dLfY140000030=7=Z@900000103AcJT3@00000<0dLfY0T0000040=7=Z@=000000`3AcJT2
@00000@0dLfY0d0000020=7=Z@A000000`3AcJT3@00000<0dLfY0T0000040=7=Z@=000000`3AcJT3
@00000<0dLfY0d0000020=7=Z@A000000`3AcJT2@00000@0dLfY0d0000030=7=Z@900000103AcJT2
@00000<0dLfY140000020=7=Z@A00000103AcJT2@00000<0dLfY0T0000040=7=Z@9000001@3AcJT2
@00000<0dLfY0d0000030=7=Z@900000103AcJT2@00000D0dLfY0T0000030=7=Z@=000000`3AcJT2
@00000@0dLfY0d0000260=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3A
cJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3A
cJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3A
cJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3A
cJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3A
cJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3AcJW]0=7=Z@00o`3A
cJW]0=7=Z@00o`3AcJW]0=7=Z@009P3AcJT8ooooo`@0EEEE100000040:ZZZPCooooo201EEED8oooo
o`d0ZZZZ3000000405EEE@@0ZZZZ1?ooool40:ZZZPCooooo10000004ooooo`@0EEEE2?ooool40:ZZ
ZP@0EEEE1000000405EEE@@0ZZZZ3000000405EEE@@00000102ZZZX405EEE@Cooooo201EEED40:ZZ
ZPSooooo102ZZZX4ooooo`@0EEEE1Oooool80:ZZZPCooooo10000004ooooo`P0ZZZZ1?ooool405EE
E@Cooooo102ZZZX8ooooo`@0ZZZZ201EEED4ooooo`@0EEEE102ZZZX4000000@0EEEE300000040:ZZ
ZP@0EEEE1000000405EEE@@0ZZZZ2?ooool405EEE@Cooooo10000005ooooo`@0ZZZZ1?ooool40:ZZ
ZP@0EEEE3000000<0:ZZZPSooooo201EEED4ooooo`@0ZZZZ1000000405EEE@Sooooo9`3AcJT002H0
dLfY2?ooool405EEE@@00000102ZZZX4ooooo`P0EEEE2?ooool=0:ZZZP`00000101EEED40:ZZZPCo
oooo102ZZZX4ooooo`@000001?ooool405EEE@Sooooo102ZZZX405EEE@@00000101EEED40:ZZZP`0
0000101EEED4000000@0ZZZZ101EEED4ooooo`P0EEEE102ZZZX8ooooo`@0ZZZZ1?ooool405EEE@Go
oooo202ZZZX4ooooo`@000001?ooool80:ZZZPCooooo101EEED4ooooo`@0ZZZZ2?ooool40:ZZZPP0
EEEE1?ooool405EEE@@0ZZZZ1000000405EEE@`00000102ZZZX405EEE@@00000101EEED40:ZZZPSo
oooo101EEED4ooooo`@000001Oooool40:ZZZPCooooo102ZZZX405EEE@`00000302ZZZX8ooooo`P0
EEEE1?ooool40:ZZZP@00000101EEED8ooooobL0dLfY000V0=7=Z@Sooooo101EEED4000000@0ZZZZ
1?ooool805EEE@Sooooo3@2ZZZX<000000@0EEEE102ZZZX4ooooo`@0ZZZZ1?ooool4000000Cooooo
101EEED8ooooo`@0ZZZZ101EEED4000000@0EEEE102ZZZX<000000@0EEEE100000040:ZZZP@0EEEE
1?ooool805EEE@@0ZZZZ2?ooool40:ZZZPCooooo101EEED5ooooo`P0ZZZZ1?ooool4000000Cooooo
202ZZZX4ooooo`@0EEEE1?ooool40:ZZZPSooooo102ZZZX805EEE@Cooooo101EEED40:ZZZP@00000
101EEED<000000@0ZZZZ101EEED4000000@0EEEE102ZZZX8ooooo`@0EEEE1?ooool4000000Gooooo
102ZZZX4ooooo`@0ZZZZ101EEED<000000`0ZZZZ2?ooool805EEE@Cooooo102ZZZX4000000@0EEEE
2?oooolW0=7=Z@009P3AcJT8ooooo`@0EEEE100000040:ZZZPCooooo201EEED8ooooo`d0ZZZZ3000
000405EEE@@0ZZZZ1?ooool40:ZZZPCooooo10000004ooooo`@0EEEE2?ooool40:ZZZP@0EEEE1000
000405EEE@@0ZZZZ3000000405EEE@@00000102ZZZX405EEE@Cooooo201EEED40:ZZZPSooooo102Z
ZZX4ooooo`@0EEEE1Oooool80:ZZZPCooooo10000004ooooo`P0ZZZZ1?ooool405EEE@Cooooo102Z
ZZX8ooooo`@0ZZZZ201EEED4ooooo`@0EEEE102ZZZX4000000@0EEEE300000040:ZZZP@0EEEE1000
000405EEE@@0ZZZZ2?ooool405EEE@Cooooo10000005ooooo`@0ZZZZ1?ooool40:ZZZP@0EEEE3000
000<0:ZZZPSooooo201EEED4ooooo`@0ZZZZ1000000405EEE@Sooooo9`3AcJT002H0dLfY3?ooool<
0:ZZZPP0EEEE202ZZZX405EEE@Gooooo102ZZZX405EEE@@00000102ZZZX805EEE@P00000102ZZZX4
ooooo`@0ZZZZ100000040:ZZZPCooooo10000004ooooo`@0EEEE1?ooool4000000Cooooo20000004
ooooo`@0EEEE1?ooool40:ZZZPCooooo1000000405EEE@Cooooo102ZZZX4000000cooooo1@2ZZZX8
000000@0ZZZZ1?ooool40:ZZZPP00000102ZZZX<ooooo`@00000102ZZZX4ooooo`@0EEEE10000004
ooooo`@0ZZZZ1?ooool405EEE@Cooooo20000004ooooo`@000001?ooool405EEE@Cooooo10000004
ooooo`@0ZZZZ100000040:ZZZPCooooo1@2ZZZX8000000P0EEEE102ZZZX4000000@0EEEE102ZZZX4
ooooo`@0EEEE202ZZZX805EEE@`0ZZZZ3?oooolW0=7=Z@009P3AcJT<ooooo``0ZZZZ201EEED80:ZZ
ZP@0EEEE1Oooool40:ZZZP@0EEEE100000040:ZZZPP0EEEE200000040:ZZZPCooooo102ZZZX40000
00@0ZZZZ1?ooool4000000Cooooo101EEED4ooooo`@000001?ooool8000000Cooooo101EEED4oooo
o`@0ZZZZ1?ooool4000000@0EEEE1?ooool40:ZZZP@000003?ooool50:ZZZPP00000102ZZZX4oooo
o`@0ZZZZ200000040:ZZZPcooooo100000040:ZZZPCooooo101EEED4000000Cooooo102ZZZX4oooo
o`@0EEEE1?ooool8000000Cooooo10000004ooooo`@0EEEE1?ooool4000000Cooooo102ZZZX40000
00@0ZZZZ1?ooool50:ZZZPP00000201EEED40:ZZZP@00000101EEED40:ZZZPCooooo101EEED80:ZZ
ZPP0EEEE302ZZZX<ooooobL0dLfY000V0=7=Z@cooooo302ZZZX805EEE@P0ZZZZ101EEED5ooooo`@0
ZZZZ101EEED4000000@0ZZZZ201EEED8000000@0ZZZZ1?ooool40:ZZZP@00000102ZZZX4ooooo`@0
00001?ooool405EEE@Cooooo10000004ooooo`P000001?ooool405EEE@Cooooo102ZZZX4ooooo`@0
0000101EEED4ooooo`@0ZZZZ1000000<ooooo`D0ZZZZ200000040:ZZZPCooooo102ZZZX8000000@0
ZZZZ3?ooool4000000@0ZZZZ1?ooool405EEE@@000001?ooool40:ZZZPCooooo101EEED4ooooo`P0
00001?ooool4000000Cooooo101EEED4ooooo`@000001?ooool40:ZZZP@00000102ZZZX4ooooo`D0
ZZZZ2000000805EEE@@0ZZZZ1000000405EEE@@0ZZZZ1?ooool405EEE@P0ZZZZ201EEED<0:ZZZPco
oooo9`3AcJT002H0dLfY3?ooool<0:ZZZPP0EEEE202ZZZX405EEE@Gooooo102ZZZX405EEE@@00000
102ZZZX805EEE@P00000102ZZZX4ooooo`@0ZZZZ100000040:ZZZPCooooo10000004ooooo`@0EEEE
1?ooool4000000Cooooo20000004ooooo`@0EEEE1?ooool40:ZZZPCooooo1000000405EEE@Cooooo
102ZZZX4000000cooooo1@2ZZZX8000000@0ZZZZ1?ooool40:ZZZPP00000102ZZZX<ooooo`@00000
102ZZZX4ooooo`@0EEEE10000004ooooo`@0ZZZZ1?ooool405EEE@Cooooo20000004ooooo`@00000
1?ooool405EEE@Cooooo10000004ooooo`@0ZZZZ100000040:ZZZPCooooo1@2ZZZX8000000P0EEEE
102ZZZX4000000@0EEEE102ZZZX4ooooo`@0EEEE202ZZZX805EEE@`0ZZZZ3?oooolW0=7=Z@009P3A
cJT@ooooo`@000002?ooool40:ZZZPCooooo101EEED40:ZZZPD0EEEE102ZZZX8ooooo`@0EEEE102Z
ZZX@05EEE@P00000102ZZZX405EEE@Cooooo101EEED4ooooo`@0EEEE20000004ooooo`P0ZZZZ1?oo
ool4000000@0EEEE1000000405EEE@@00000202ZZZX405EEEAGooooo2000000<ooooo`P000005?oo
ool405EEE@P0ZZZZ1000000405EEE@@00000101EEED4000000Cooooo202ZZZX4ooooo`P00000101E
EED4ooooo`@0EEEE1?ooool405EEE@@0ZZZZ2000000A05EEE@@0ZZZZ101EEED8ooooo`@0ZZZZ101E
EED40:ZZZP@0EEEE1?ooool40:ZZZPSooooo1000000@ooooobL0dLfY000V0=7=ZA3ooooo10000008
ooooo`@0ZZZZ1?ooool405EEE@@0ZZZZ1@1EEED40:ZZZPSooooo101EEED40:ZZZQ00EEEE20000004
0:ZZZP@0EEEE1?ooool405EEE@Cooooo101EEED8000000Cooooo202ZZZX4ooooo`@00000101EEED4
000000@0EEEE100000080:ZZZP@0EEEE5Oooool8000000cooooo2000000Dooooo`@0EEEE202ZZZX4
000000@0EEEE1000000405EEE@@000001?ooool80:ZZZPCooooo2000000405EEE@Cooooo101EEED4
ooooo`@0EEEE102ZZZX800000140EEEE102ZZZX405EEE@Sooooo102ZZZX405EEE@@0ZZZZ101EEED4
ooooo`@0ZZZZ2?ooool40000013ooooo9`3AcJT002H0dLfY4?ooool4000000Sooooo102ZZZX4oooo
o`@0EEEE102ZZZX505EEE@@0ZZZZ2?ooool405EEE@@0ZZZZ401EEED8000000@0ZZZZ101EEED4oooo
o`@0EEEE1?ooool405EEE@P000001?ooool80:ZZZPCooooo1000000405EEE@@00000101EEED40000
00P0ZZZZ101EEEDEooooo`P000003?ooool8000001Cooooo101EEED80:ZZZP@00000101EEED40000
00@0EEEE10000004ooooo`P0ZZZZ1?ooool8000000@0EEEE1?ooool405EEE@Cooooo101EEED40:ZZ
ZPP000004@1EEED40:ZZZP@0EEEE2?ooool40:ZZZP@0EEEE102ZZZX405EEE@Cooooo102ZZZX8oooo
o`@000004?oooolW0=7=Z@009P3AcJT@ooooo`@000002?ooool40:ZZZPCooooo101EEED40:ZZZPD0
EEEE102ZZZX8ooooo`@0EEEE102ZZZX@05EEE@P00000102ZZZX405EEE@Cooooo101EEED4ooooo`@0
EEEE20000004ooooo`P0ZZZZ1?ooool4000000@0EEEE1000000405EEE@@00000202ZZZX405EEEAGo
oooo2000000<ooooo`P000005?ooool405EEE@P0ZZZZ1000000405EEE@@00000101EEED4000000Co
oooo202ZZZX4ooooo`P00000101EEED4ooooo`@0EEEE1?ooool405EEE@@0ZZZZ2000000A05EEE@@0
ZZZZ101EEED8ooooo`@0ZZZZ101EEED40:ZZZP@0EEEE1?ooool40:ZZZPSooooo1000000@ooooobL0
dLfY000V0=7=ZACooooo201EEED4ooooo`@0ZZZZ100000040:ZZZPD00000102ZZZX4000000Cooooo
102ZZZX4ooooo`@0EEEE10000004ooooo`@0EEEE100000040:ZZZP@0EEEE1?ooool4000000P0ZZZZ
401EEED4ooooo`@0ZZZZ101EEED40:ZZZP@00000102ZZZX<05EEE@@00000101EEED4ooooo`P0EEEE
1?oooolA05EEE@Cooooo401EEED4ooooo`P0EEEE1?ooool405EEE@@00000301EEED40:ZZZP@00000
102ZZZX405EEE@@0ZZZZ1?ooool@05EEE@P0ZZZZ10000004ooooo`@0EEEE102ZZZX4000000D0EEEE
1?ooool4000000@0EEEE1?ooool40:ZZZPCooooo100000040:ZZZP@00000102ZZZX4000000@0ZZZZ
1?ooool805EEEACooooo9`3AcJT002H0dLfY5?ooool805EEE@Cooooo102ZZZX4000000@0ZZZZ1@00
00040:ZZZP@000001?ooool40:ZZZPCooooo101EEED4000000Cooooo101EEED4000000@0ZZZZ101E
EED4ooooo`@00000202ZZZX@05EEE@Cooooo102ZZZX405EEE@@0ZZZZ100000040:ZZZP`0EEEE1000
000405EEE@Cooooo201EEED4oooooa40EEEE1?ooool@05EEE@Cooooo201EEED4ooooo`@0EEEE1000
000<05EEE@@0ZZZZ100000040:ZZZP@0EEEE102ZZZX4oooooa00EEEE202ZZZX4000000Cooooo101E
EED40:ZZZP@000001@1EEED4ooooo`@00000101EEED4ooooo`@0ZZZZ1?ooool4000000@0ZZZZ1000
00040:ZZZP@00000102ZZZX4ooooo`P0EEEE5?oooolW0=7=Z@009P3AcJTDooooo`P0EEEE1?ooool4
0:ZZZP@00000102ZZZX5000000@0ZZZZ10000004ooooo`@0ZZZZ1?ooool405EEE@@000001?ooool4
05EEE@@00000102ZZZX405EEE@Cooooo100000080:ZZZQ00EEEE1?ooool40:ZZZP@0EEEE102ZZZX4
000000@0ZZZZ301EEED4000000@0EEEE1?ooool805EEE@Cooooo4@1EEED4oooooa00EEEE1?ooool8
05EEE@Cooooo101EEED4000000`0EEEE102ZZZX4000000@0ZZZZ101EEED40:ZZZPCooooo401EEED8
0:ZZZP@000001?ooool405EEE@@0ZZZZ1000000505EEE@Cooooo1000000405EEE@Cooooo102ZZZX4
ooooo`@00000102ZZZX4000000@0ZZZZ100000040:ZZZPCooooo201EEEDDooooobL0dLfY000V0=7=
ZACooooo201EEED4ooooo`@0ZZZZ100000040:ZZZPD00000102ZZZX4000000Cooooo102ZZZX4oooo
o`@0EEEE10000004ooooo`@0EEEE100000040:ZZZP@0EEEE1?ooool4000000P0ZZZZ401EEED4oooo
o`@0ZZZZ101EEED40:ZZZP@00000102ZZZX<05EEE@@00000101EEED4ooooo`P0EEEE1?oooolA05EE
E@Cooooo401EEED4ooooo`P0EEEE1?ooool405EEE@@00000301EEED40:ZZZP@00000102ZZZX405EE
E@@0ZZZZ1?ooool@05EEE@P0ZZZZ10000004ooooo`@0EEEE102ZZZX4000000D0EEEE1?ooool40000
00@0EEEE1?ooool40:ZZZPCooooo100000040:ZZZP@00000102ZZZX4000000@0ZZZZ1?ooool805EE
EACooooo9`3AcJT002H0dLfY6?ooool40:ZZZPCooooo10000004ooooo`@000001Oooool4000000Co
oooo100000040:ZZZP@000001?ooool405EEE@Cooooo101EEED4000000@0ZZZZ100000040:ZZZPCo
oooo102ZZZX405EEE@Cooooo1000000405EEE@Cooooo100000040:ZZZP@00000102ZZZX4000000P0
EEEE102ZZZX<05EEE@P0ZZZZ100000040:ZZZPWooooo102ZZZX<ooooo`@0ZZZZ2?ooool40:ZZZP@0
0000202ZZZX<05EEE@@0ZZZZ201EEED4000000@0ZZZZ100000040:ZZZP@000001?ooool405EEE@@0
00001?ooool405EEE@@0ZZZZ1?ooool40:ZZZP@00000102ZZZX4000000D0EEEE1?ooool405EEE@Co
oooo100000040:ZZZP@000001?ooool4000000Cooooo10000004ooooo`@000001?ooool40:ZZZQSo
oooo9`3AcJT002H0dLfY6?ooool40:ZZZPCooooo10000004ooooo`@000001Oooool4000000Cooooo
100000040:ZZZP@000001?ooool405EEE@Cooooo101EEED4000000@0ZZZZ100000040:ZZZPCooooo
102ZZZX405EEE@Cooooo1000000405EEE@Cooooo100000040:ZZZP@00000102ZZZX4000000P0EEEE
102ZZZX<05EEE@P0ZZZZ100000040:ZZZPWooooo102ZZZX<ooooo`@0ZZZZ2?ooool40:ZZZP@00000
202ZZZX<05EEE@@0ZZZZ201EEED4000000@0ZZZZ100000040:ZZZP@000001?ooool405EEE@@00000
1?ooool405EEE@@0ZZZZ1?ooool40:ZZZP@00000102ZZZX4000000D0EEEE1?ooool405EEE@Cooooo
100000040:ZZZP@000001?ooool4000000Cooooo10000004ooooo`@000001?ooool40:ZZZQSooooo
9`3AcJT002H0dLfY6?ooool40:ZZZPCooooo10000004ooooo`@000001Oooool4000000Cooooo1000
00040:ZZZP@000001?ooool405EEE@Cooooo101EEED4000000@0ZZZZ100000040:ZZZPCooooo102Z
ZZX405EEE@Cooooo1000000405EEE@Cooooo100000040:ZZZP@00000102ZZZX4000000P0EEEE102Z
ZZX<05EEE@P0ZZZZ100000040:ZZZPWooooo102ZZZX<ooooo`@0ZZZZ2?ooool40:ZZZP@00000202Z
ZZX<05EEE@@0ZZZZ201EEED4000000@0ZZZZ100000040:ZZZP@000001?ooool405EEE@@000001?oo
ool405EEE@@0ZZZZ1?ooool40:ZZZP@00000102ZZZX4000000D0EEEE1?ooool405EEE@Cooooo1000
00040:ZZZP@000001?ooool4000000Cooooo10000004ooooo`@000001?ooool40:ZZZQSooooo9`3A
cJT002H0dLfY6?ooool40:ZZZPCooooo10000004ooooo`@000001Oooool4000000Cooooo10000004
0:ZZZP@000001?ooool405EEE@Cooooo101EEED4000000@0ZZZZ100000040:ZZZPCooooo102ZZZX4
05EEE@Cooooo1000000405EEE@Cooooo100000040:ZZZP@00000102ZZZX4000000P0EEEE102ZZZX<
05EEE@P0ZZZZ100000040:ZZZPWooooo102ZZZX<ooooo`@0ZZZZ2?ooool40:ZZZP@00000202ZZZX<
05EEE@@0ZZZZ201EEED4000000@0ZZZZ100000040:ZZZP@000001?ooool405EEE@@000001?ooool4
05EEE@@0ZZZZ1?ooool40:ZZZP@00000102ZZZX4000000D0EEEE1?ooool405EEE@Cooooo10000004
0:ZZZP@000001?ooool4000000Cooooo10000004ooooo`@000001?ooool40:ZZZQSooooo9`3AcJT0
02H0dLfY7?ooool4000000@0ZZZZ101EEED40:ZZZPD000001?ooool4000000@0ZZZZ101EEED<oooo
o`@0ZZZZ100000040:ZZZP@0EEEE2?ooool4000000@0ZZZZ100000040:ZZZPCooooo102ZZZX4oooo
o`P00000102ZZZX405EEE@Sooooo102ZZZX4ooooo`@0EEEE10000004ooooo`@0EEEE102ZZZX4oooo
o`@0ZZZZ1@1EEED<0:ZZZP@0EEEE302ZZZX405EEE@@0ZZZZ1?ooool40:ZZZP@0EEEE1?ooool40000
00@0EEEE1?ooool40:ZZZPSooooo101EEED40:ZZZPP000001?ooool40:ZZZPCooooo102ZZZX40000
00@0ZZZZ10000008ooooo`@0EEEE102ZZZX5000000@0ZZZZ3?ooool405EEE@@0ZZZZ10000004oooo
o`@00000102ZZZX405EEE@@0ZZZZ1000000LooooobL0dLfY000V0=7=ZAcooooo100000040:ZZZP@0
EEEE102ZZZX5000000Cooooo100000040:ZZZP@0EEEE3?ooool40:ZZZP@00000102ZZZX405EEE@So
oooo100000040:ZZZP@00000102ZZZX4ooooo`@0ZZZZ1?ooool8000000@0ZZZZ101EEED8ooooo`@0
ZZZZ1?ooool405EEE@@000001?ooool405EEE@@0ZZZZ1?ooool40:ZZZPD0EEEE302ZZZX405EEE@`0
ZZZZ101EEED40:ZZZPCooooo102ZZZX405EEE@Cooooo1000000405EEE@Cooooo102ZZZX8ooooo`@0
EEEE102ZZZX8000000Cooooo102ZZZX4ooooo`@0ZZZZ100000040:ZZZP@000002?ooool405EEE@@0
ZZZZ1@0000040:ZZZPcooooo101EEED40:ZZZP@000001?ooool4000000@0ZZZZ101EEED40:ZZZP@0
00007?oooolW0=7=Z@009P3AcJTLooooo`@00000102ZZZX405EEE@@0ZZZZ1@000004ooooo`@00000
102ZZZX405EEE@cooooo102ZZZX4000000@0ZZZZ101EEED8ooooo`@00000102ZZZX4000000@0ZZZZ
1?ooool40:ZZZPCooooo200000040:ZZZP@0EEEE2?ooool40:ZZZPCooooo101EEED4000000Cooooo
101EEED40:ZZZPCooooo102ZZZX505EEE@`0ZZZZ101EEED<0:ZZZP@0EEEE102ZZZX4ooooo`@0ZZZZ
101EEED4ooooo`@00000101EEED4ooooo`@0ZZZZ2?ooool405EEE@@0ZZZZ20000004ooooo`@0ZZZZ
1?ooool40:ZZZP@00000102ZZZX4000000Sooooo101EEED40:ZZZPD00000102ZZZX<ooooo`@0EEEE
102ZZZX4000000Cooooo100000040:ZZZP@0EEEE102ZZZX4000001cooooo9`3AcJT002H0dLfY7?oo
ool4000000@0ZZZZ101EEED40:ZZZPD000001?ooool4000000@0ZZZZ101EEED<ooooo`@0ZZZZ1000
00040:ZZZP@0EEEE2?ooool4000000@0ZZZZ100000040:ZZZPCooooo102ZZZX4ooooo`P00000102Z
ZZX405EEE@Sooooo102ZZZX4ooooo`@0EEEE10000004ooooo`@0EEEE102ZZZX4ooooo`@0ZZZZ1@1E
EED<0:ZZZP@0EEEE302ZZZX405EEE@@0ZZZZ1?ooool40:ZZZP@0EEEE1?ooool4000000@0EEEE1?oo
ool40:ZZZPSooooo101EEED40:ZZZPP000001?ooool40:ZZZPCooooo102ZZZX4000000@0ZZZZ1000
0008ooooo`@0EEEE102ZZZX5000000@0ZZZZ3?ooool405EEE@@0ZZZZ10000004ooooo`@00000102Z
ZZX405EEE@@0ZZZZ1000000LooooobL0dLfY000V0=7=ZB3ooooo101EEED40:ZZZP@0EEEE3Oooool4
05EEE@@0ZZZZ101EEED80:ZZZP@0EEEE2?ooool4000000@0EEEE20000008ooooo`@0EEEE302ZZZX4
05EEE@@00000102ZZZX4000000@0ZZZZ1?ooool4000000Cooooo102ZZZX4ooooo`@0ZZZZ10000004
0:ZZZP@000002Oooool40:ZZZP@0EEEE1?ooool40:ZZZPCooooo101EEED40:ZZZPSooooo10000004
0:ZZZP@00000102ZZZX4ooooo`@0ZZZZ1?ooool4000000Cooooo102ZZZX4000000@0ZZZZ10000004
05EEE@`0ZZZZ101EEED8ooooo`P00000101EEED4000000Wooooo101EEED80:ZZZP@0EEEE102ZZZX4
05EEE@cooooo101EEED40:ZZZP@0EEEE8?oooolW0=7=Z@009P3AcJTPooooo`@0EEEE102ZZZX405EE
E@gooooo101EEED40:ZZZP@0EEEE202ZZZX405EEE@Sooooo1000000405EEE@P000002?ooool405EE
E@`0ZZZZ101EEED4000000@0ZZZZ100000040:ZZZPCooooo10000004ooooo`@0ZZZZ1?ooool40:ZZ
ZP@00000102ZZZX4000000Wooooo102ZZZX405EEE@Cooooo102ZZZX4ooooo`@0EEEE102ZZZX8oooo
o`@00000102ZZZX4000000@0ZZZZ1?ooool40:ZZZPCooooo10000004ooooo`@0ZZZZ100000040:ZZ
ZP@00000101EEED<0:ZZZP@0EEEE2?ooool8000000@0EEEE10000009ooooo`@0EEEE202ZZZX405EE
E@@0ZZZZ101EEED<ooooo`@0EEEE102ZZZX405EEEB3ooooo9`3AcJT002H0dLfY8?ooool405EEE@@0
ZZZZ101EEED=ooooo`@0EEEE102ZZZX405EEE@P0ZZZZ101EEED8ooooo`@00000101EEED8000000So
oooo101EEED<0:ZZZP@0EEEE100000040:ZZZP@00000102ZZZX4ooooo`@000001?ooool40:ZZZPCo
oooo102ZZZX4000000@0ZZZZ10000009ooooo`@0ZZZZ101EEED4ooooo`@0ZZZZ1?ooool405EEE@@0
ZZZZ2?ooool4000000@0ZZZZ100000040:ZZZPCooooo102ZZZX4ooooo`@000001?ooool40:ZZZP@0
0000102ZZZX4000000@0EEEE302ZZZX405EEE@Sooooo2000000405EEE@@000002Oooool405EEE@P0
ZZZZ101EEED40:ZZZP@0EEEE3?ooool405EEE@@0ZZZZ101EEEDPooooobL0dLfY000V0=7=ZB3ooooo
101EEED40:ZZZP@0EEEE3Oooool405EEE@@0ZZZZ101EEED80:ZZZP@0EEEE2?ooool4000000@0EEEE
20000008ooooo`@0EEEE302ZZZX405EEE@@00000102ZZZX4000000@0ZZZZ1?ooool4000000Cooooo
102ZZZX4ooooo`@0ZZZZ100000040:ZZZP@000002Oooool40:ZZZP@0EEEE1?ooool40:ZZZPCooooo
101EEED40:ZZZPSooooo100000040:ZZZP@00000102ZZZX4ooooo`@0ZZZZ1?ooool4000000Cooooo
102ZZZX4000000@0ZZZZ1000000405EEE@`0ZZZZ101EEED8ooooo`P00000101EEED4000000Wooooo
101EEED80:ZZZP@0EEEE102ZZZX405EEE@cooooo101EEED40:ZZZP@0EEEE8?oooolW0=7=Z@009P3A
cJTTooooo`@0ZZZZ2@1EEED4ooooo`P0EEEE102ZZZX8ooooo`@000001?ooool805EEE@Sooooo202Z
ZZX4ooooo`@00000502ZZZX4000000`0EEEE20000004ooooo`@0ZZZZ101EEED40:ZZZPCooooo102Z
ZZX405EEE@T00000201EEED<0:ZZZPP0EEEE2000000405EEE@@0ZZZZ1?ooool40:ZZZP@0EEEE102Z
ZZX4ooooo`P00000301EEED4000001@0ZZZZ10000004ooooo`P0ZZZZ2?ooool905EEE@Cooooo1000
0008ooooo`@0ZZZZ201EEED4ooooo`P0EEEE102ZZZXTooooobL0dLfY000V0=7=ZBCooooo102ZZZX9
05EEE@Cooooo201EEED40:ZZZPSooooo10000004ooooo`P0EEEE2?ooool80:ZZZPCooooo1000000D
0:ZZZP@00000301EEED8000000Cooooo102ZZZX405EEE@@0ZZZZ1?ooool40:ZZZP@0EEEE2@000008
05EEE@`0ZZZZ201EEED8000000@0EEEE102ZZZX4ooooo`@0ZZZZ101EEED40:ZZZPCooooo2000000<
05EEE@@00000502ZZZX4000000Cooooo202ZZZX8ooooo`T0EEEE1?ooool4000000Sooooo102ZZZX8
05EEE@Cooooo201EEED40:ZZZRCooooo9`3AcJT002H0dLfY9?ooool40:ZZZPT0EEEE1?ooool805EE
E@@0ZZZZ2?ooool4000000Cooooo201EEED8ooooo`P0ZZZZ1?ooool4000001@0ZZZZ1000000<05EE
E@P000001?ooool40:ZZZP@0EEEE102ZZZX4ooooo`@0ZZZZ101EEED9000000P0EEEE302ZZZX805EE
E@P00000101EEED40:ZZZPCooooo102ZZZX405EEE@@0ZZZZ1?ooool8000000`0EEEE1000000D0:ZZ
ZP@000001?ooool80:ZZZPSooooo2@1EEED4ooooo`@000002?ooool40:ZZZPP0EEEE1?ooool805EE
E@@0ZZZZ9?oooolW0=7=Z@009P3AcJTTooooo`@0ZZZZ2@1EEED4ooooo`P0EEEE102ZZZX8ooooo`@0
00001?ooool805EEE@Sooooo202ZZZX4ooooo`@00000502ZZZX4000000`0EEEE20000004ooooo`@0
ZZZZ101EEED40:ZZZPCooooo102ZZZX405EEE@T00000201EEED<0:ZZZPP0EEEE2000000405EEE@@0
ZZZZ1?ooool40:ZZZP@0EEEE102ZZZX4ooooo`P00000301EEED4000001@0ZZZZ10000004ooooo`P0
ZZZZ2?ooool905EEE@Cooooo10000008ooooo`@0ZZZZ201EEED4ooooo`P0EEEE102ZZZXTooooobL0
dLfY000V0=7=ZBSooooo1000000505EEE@Cooooo101EEED40000013ooooo201EEED40:ZZZP@0EEEE
402ZZZX405EEE@@00000201EEED4000000`0EEEE102ZZZX@05EEE@Cooooo102ZZZX4ooooo`P0EEEE
10000004oooooa400000102ZZZX@000000Cooooo1000000805EEE@Cooooo102ZZZX4oooooa00EEEE
102ZZZX<05EEE@@00000201EEED4000000@0EEEE402ZZZX405EEE@@0ZZZZ2@1EEED@ooooo`@00000
101EEED4ooooo`@0EEEE1000000XooooobL0dLfY000V0=7=ZBSooooo1000000505EEE@Cooooo101E
EED40000013ooooo201EEED40:ZZZP@0EEEE402ZZZX405EEE@@00000201EEED4000000`0EEEE102Z
ZZX@05EEE@Cooooo102ZZZX4ooooo`P0EEEE10000004oooooa400000102ZZZX@000000Cooooo1000
000805EEE@Cooooo102ZZZX4oooooa00EEEE102ZZZX<05EEE@@00000201EEED4000000@0EEEE402Z
ZZX405EEE@@0ZZZZ2@1EEED@ooooo`@00000101EEED4ooooo`@0EEEE1000000XooooobL0dLfY000V
0=7=ZBSooooo1000000505EEE@Cooooo101EEED40000013ooooo201EEED40:ZZZP@0EEEE402ZZZX4
05EEE@@00000201EEED4000000`0EEEE102ZZZX@05EEE@Cooooo102ZZZX4ooooo`P0EEEE10000004
oooooa400000102ZZZX@000000Cooooo1000000805EEE@Cooooo102ZZZX4oooooa00EEEE102ZZZX<
05EEE@@00000201EEED4000000@0EEEE402ZZZX405EEE@@0ZZZZ2@1EEED@ooooo`@00000101EEED4
ooooo`@0EEEE1000000XooooobL0dLfY000V0=7=ZBSooooo1000000505EEE@Cooooo101EEED40000
013ooooo201EEED40:ZZZP@0EEEE402ZZZX405EEE@@00000201EEED4000000`0EEEE102ZZZX@05EE
E@Cooooo102ZZZX4ooooo`P0EEEE10000004oooooa400000102ZZZX@000000Cooooo1000000805EE
E@Cooooo102ZZZX4oooooa00EEEE102ZZZX<05EEE@@00000201EEED4000000@0EEEE402ZZZX405EE
E@@0ZZZZ2@1EEED@ooooo`@00000101EEED4ooooo`@0EEEE1000000XooooobL0dLfY000V0=7=ZBco
oooo1@1EEED<000000Cooooo102ZZZX4000000Cooooo102ZZZX8ooooo`@00000201EEED4000000P0
EEEE102ZZZX4000000P0ZZZZ2?ooool40:ZZZPCooooo101EEED4000000Cooooo101EEED8000000@0
ZZZZ2?ooool80:ZZZPD0EEEE100000040:ZZZP@0EEEE1000000405EEE@@0ZZZZ1000000405EEE@P0
ZZZZ2?ooool40:ZZZPP00000101EEED4ooooo`@00000101EEED4ooooo`@0ZZZZ2?ooool80:ZZZP@0
0000102ZZZX805EEE@@00000201EEED4000000Wooooo102ZZZX4ooooo`@00000102ZZZX4ooooo``0
0000101EEED/ooooobL0dLfY000V0=7=ZBcooooo1@1EEED<000000Cooooo102ZZZX4000000Cooooo
102ZZZX8ooooo`@00000201EEED4000000P0EEEE102ZZZX4000000P0ZZZZ2?ooool40:ZZZPCooooo
101EEED4000000Cooooo101EEED8000000@0ZZZZ2?ooool80:ZZZPD0EEEE100000040:ZZZP@0EEEE
1000000405EEE@@0ZZZZ1000000405EEE@P0ZZZZ2?ooool40:ZZZPP00000101EEED4ooooo`@00000
101EEED4ooooo`@0ZZZZ2?ooool80:ZZZP@00000102ZZZX805EEE@@00000201EEED4000000Wooooo
102ZZZX4ooooo`@00000102ZZZX4ooooo``00000101EEED/ooooobL0dLfY000V0=7=ZBcooooo1@1E
EED<000000Cooooo102ZZZX4000000Cooooo102ZZZX8ooooo`@00000201EEED4000000P0EEEE102Z
ZZX4000000P0ZZZZ2?ooool40:ZZZPCooooo101EEED4000000Cooooo101EEED8000000@0ZZZZ2?oo
ool80:ZZZPD0EEEE100000040:ZZZP@0EEEE1000000405EEE@@0ZZZZ1000000405EEE@P0ZZZZ2?oo
ool40:ZZZPP00000101EEED4ooooo`@00000101EEED4ooooo`@0ZZZZ2?ooool80:ZZZP@00000102Z
ZZX805EEE@@00000201EEED4000000Wooooo102ZZZX4ooooo`@00000102ZZZX4ooooo``00000101E
EED/ooooobL0dLfY000V0=7=ZBcooooo1@1EEED<000000Cooooo102ZZZX4000000Cooooo102ZZZX8
ooooo`@00000201EEED4000000P0EEEE102ZZZX4000000P0ZZZZ2?ooool40:ZZZPCooooo101EEED4
000000Cooooo101EEED8000000@0ZZZZ2?ooool80:ZZZPD0EEEE100000040:ZZZP@0EEEE10000004
05EEE@@0ZZZZ1000000405EEE@P0ZZZZ2?ooool40:ZZZPP00000101EEED4ooooo`@00000101EEED4
ooooo`@0ZZZZ2?ooool80:ZZZP@00000102ZZZX805EEE@@00000201EEED4000000Wooooo102ZZZX4
ooooo`@00000102ZZZX4ooooo``00000101EEED/ooooobL0dLfY000V0=7=ZC7ooooo202ZZZX4oooo
o`@0ZZZZ20000004ooooo`@0ZZZZ101EEED80:ZZZPSooooo202ZZZX4000000@0ZZZZ1000000805EE
E@P00000201EEED4ooooo`P00000101EEED8ooooo`@0EEEE202ZZZX405EEE@Cooooo1@2ZZZX4oooo
o`@0ZZZZ301EEED40:ZZZPCooooo102ZZZX4ooooo`@0EEEE202ZZZX405EEE@Sooooo101EEED80000
00Cooooo201EEED8000000P0EEEE100000040:ZZZP@00000202ZZZX8ooooo`P0ZZZZ1@1EEED40:ZZ
ZPCooooo200000040:ZZZPCooooo202ZZZX`ooooobL0dLfY000V0=7=ZC7ooooo202ZZZX4ooooo`@0
ZZZZ20000004ooooo`@0ZZZZ101EEED80:ZZZPSooooo202ZZZX4000000@0ZZZZ1000000805EEE@P0
0000201EEED4ooooo`P00000101EEED8ooooo`@0EEEE202ZZZX405EEE@Cooooo1@2ZZZX4ooooo`@0
ZZZZ301EEED40:ZZZPCooooo102ZZZX4ooooo`@0EEEE202ZZZX405EEE@Sooooo101EEED8000000Co
oooo201EEED8000000P0EEEE100000040:ZZZP@00000202ZZZX8ooooo`P0ZZZZ1@1EEED40:ZZZPCo
oooo200000040:ZZZPCooooo202ZZZX`ooooobL0dLfY000V0=7=ZC7ooooo202ZZZX4ooooo`@0ZZZZ
20000004ooooo`@0ZZZZ101EEED80:ZZZPSooooo202ZZZX4000000@0ZZZZ1000000805EEE@P00000
201EEED4ooooo`P00000101EEED8ooooo`@0EEEE202ZZZX405EEE@Cooooo1@2ZZZX4ooooo`@0ZZZZ
301EEED40:ZZZPCooooo102ZZZX4ooooo`@0EEEE202ZZZX405EEE@Sooooo101EEED8000000Cooooo
201EEED8000000P0EEEE100000040:ZZZP@00000202ZZZX8ooooo`P0ZZZZ1@1EEED40:ZZZPCooooo
200000040:ZZZPCooooo202ZZZX`ooooobL0dLfY000V0=7=ZC7ooooo202ZZZX4ooooo`@0ZZZZ2000
0004ooooo`@0ZZZZ101EEED80:ZZZPSooooo202ZZZX4000000@0ZZZZ1000000805EEE@P00000201E
EED4ooooo`P00000101EEED8ooooo`@0EEEE202ZZZX405EEE@Cooooo1@2ZZZX4ooooo`@0ZZZZ301E
EED40:ZZZPCooooo102ZZZX4ooooo`@0EEEE202ZZZX405EEE@Sooooo101EEED8000000Cooooo201E
EED8000000P0EEEE100000040:ZZZP@00000202ZZZX8ooooo`P0ZZZZ1@1EEED40:ZZZPCooooo2000
00040:ZZZPCooooo202ZZZX`ooooobL0dLfY000V0=7=ZCGooooo10000004ooooo`@0ZZZZ101EEED4
000000@0ZZZZ1?ooool405EEE@@00000201EEED4ooooo`@0EEEE102ZZZX4ooooo`@0ZZZZ101EEED4
000000Cooooo101EEED8ooooo`@0ZZZZ1?ooool8000000Cooooo201EEED4ooooo`@000002?ooool4
0:ZZZPT00000201EEED40:ZZZPP0EEEE200000040:ZZZPSooooo10000004ooooo`P0EEEE1?ooool8
000000Cooooo102ZZZX8ooooo`@0EEEE1?ooool4000000@0EEEE102ZZZX4ooooo`@0ZZZZ101EEED4
ooooo`P0EEEE1000000505EEE@Cooooo102ZZZX4000000@0EEEE102ZZZX4ooooo`@00000=?oooolW
0=7=Z@009P3AcJTeooooo`@000001?ooool40:ZZZP@0EEEE100000040:ZZZPCooooo101EEED40000
00P0EEEE1?ooool405EEE@@0ZZZZ1?ooool40:ZZZP@0EEEE10000004ooooo`@0EEEE2?ooool40:ZZ
ZPCooooo20000004ooooo`P0EEEE1?ooool4000000Sooooo102ZZZX9000000P0EEEE102ZZZX805EE
E@P00000102ZZZX8ooooo`@000001?ooool805EEE@Cooooo20000004ooooo`@0ZZZZ2?ooool405EE
E@Cooooo1000000405EEE@@0ZZZZ1?ooool40:ZZZP@0EEEE1?ooool805EEE@@000001@1EEED4oooo
o`@0ZZZZ1000000405EEE@@0ZZZZ1?ooool4000003Cooooo9`3AcJT002H0dLfY=Oooool4000000Co
oooo102ZZZX405EEE@@00000102ZZZX4ooooo`@0EEEE1000000805EEE@Cooooo101EEED40:ZZZPCo
oooo102ZZZX405EEE@@000001?ooool405EEE@Sooooo102ZZZX4ooooo`P000001?ooool805EEE@Co
oooo10000008ooooo`@0ZZZZ2@00000805EEE@@0ZZZZ201EEED8000000@0ZZZZ2?ooool4000000Co
oooo201EEED4ooooo`P000001?ooool40:ZZZPSooooo101EEED4ooooo`@00000101EEED40:ZZZPCo
oooo102ZZZX405EEE@Cooooo201EEED4000000D0EEEE1?ooool40:ZZZP@00000101EEED40:ZZZPCo
oooo1000000dooooobL0dLfY000V0=7=ZCGooooo10000004ooooo`@0ZZZZ101EEED4000000@0ZZZZ
1?ooool405EEE@@00000201EEED4ooooo`@0EEEE102ZZZX4ooooo`@0ZZZZ101EEED4000000Cooooo
101EEED8ooooo`@0ZZZZ1?ooool8000000Cooooo201EEED4ooooo`@000002?ooool40:ZZZPT00000
201EEED40:ZZZPP0EEEE200000040:ZZZPSooooo10000004ooooo`P0EEEE1?ooool8000000Cooooo
102ZZZX8ooooo`@0EEEE1?ooool4000000@0EEEE102ZZZX4ooooo`@0ZZZZ101EEED4ooooo`P0EEEE
1000000505EEE@Cooooo102ZZZX4000000@0EEEE102ZZZX4ooooo`@00000=?oooolW0=7=Z@009P3A
cJTiooooo`P0EEEE10000004ooooo`@000001?ooool40:ZZZPCooooo102ZZZX<ooooo`@0ZZZZ101E
EED40:ZZZPSooooo201EEED80:ZZZP@0EEEE1?ooool405EEE@cooooo102ZZZX4ooooo`P00000101E
EED4000000D0EEEE102ZZZX4000000`0ZZZZ100000040:ZZZP@0EEEE1000000405EEE@P000001?oo
ool40:ZZZPcooooo101EEED4ooooo`@0EEEE202ZZZX805EEE@Sooooo102ZZZX405EEE@@0ZZZZ3?oo
ool40:ZZZPCooooo1@2ZZZX4ooooo`@000001?ooool4000000P0EEEE>?oooolW0=7=Z@009P3AcJTi
ooooo`P0EEEE10000004ooooo`@000001?ooool40:ZZZPCooooo102ZZZX<ooooo`@0ZZZZ101EEED4
0:ZZZPSooooo201EEED80:ZZZP@0EEEE1?ooool405EEE@cooooo102ZZZX4ooooo`P00000101EEED4
000000D0EEEE102ZZZX4000000`0ZZZZ100000040:ZZZP@0EEEE1000000405EEE@P000001?ooool4
0:ZZZPcooooo101EEED4ooooo`@0EEEE202ZZZX805EEE@Sooooo102ZZZX405EEE@@0ZZZZ3?ooool4
0:ZZZPCooooo1@2ZZZX4ooooo`@000001?ooool4000000P0EEEE>?oooolW0=7=Z@009P3AcJTioooo
o`P0EEEE10000004ooooo`@000001?ooool40:ZZZPCooooo102ZZZX<ooooo`@0ZZZZ101EEED40:ZZ
ZPSooooo201EEED80:ZZZP@0EEEE1?ooool405EEE@cooooo102ZZZX4ooooo`P00000101EEED40000
00D0EEEE102ZZZX4000000`0ZZZZ100000040:ZZZP@0EEEE1000000405EEE@P000001?ooool40:ZZ
ZPcooooo101EEED4ooooo`@0EEEE202ZZZX805EEE@Sooooo102ZZZX405EEE@@0ZZZZ3?ooool40:ZZ
ZPCooooo1@2ZZZX4ooooo`@000001?ooool4000000P0EEEE>?oooolW0=7=Z@009P3AcJTiooooo`P0
EEEE10000004ooooo`@000001?ooool40:ZZZPCooooo102ZZZX<ooooo`@0ZZZZ101EEED40:ZZZPSo
oooo201EEED80:ZZZP@0EEEE1?ooool405EEE@cooooo102ZZZX4ooooo`P00000101EEED4000000D0
EEEE102ZZZX4000000`0ZZZZ100000040:ZZZP@0EEEE1000000405EEE@P000001?ooool40:ZZZPco
oooo101EEED4ooooo`@0EEEE202ZZZX805EEE@Sooooo102ZZZX405EEE@@0ZZZZ3?ooool40:ZZZPCo
oooo1@2ZZZX4ooooo`@000001?ooool4000000P0EEEE>?oooolW0=7=Z@009P3AcJTmooooo`@0ZZZZ
1?ooool40:ZZZP@00000101EEED4000000@0EEEE1000000405EEE@P00000201EEED40:ZZZPCooooo
100000080:ZZZPP00000202ZZZX805EEE@Cooooo201EEED8000000Cooooo1000000405EEE@D0ZZZZ
101EEED8ooooo`@000002?ooool405EEE@@0ZZZZ101EEED4000000Cooooo2000000805EEE@Cooooo
201EEED80:ZZZPP00000202ZZZX4000000Cooooo102ZZZX805EEE@P00000101EEED4000000@0EEEE
1@00000405EEE@@00000102ZZZX4ooooo`@0ZZZZ??oooolW0=7=Z@009P3AcJTmooooo`@0ZZZZ1?oo
ool40:ZZZP@00000101EEED4000000@0EEEE1000000405EEE@P00000201EEED40:ZZZPCooooo1000
00080:ZZZPP00000202ZZZX805EEE@Cooooo201EEED8000000Cooooo1000000405EEE@D0ZZZZ101E
EED8ooooo`@000002?ooool405EEE@@0ZZZZ101EEED4000000Cooooo2000000805EEE@Cooooo201E
EED80:ZZZPP00000202ZZZX4000000Cooooo102ZZZX805EEE@P00000101EEED4000000@0EEEE1@00
000405EEE@@00000102ZZZX4ooooo`@0ZZZZ??oooolW0=7=Z@009P3AcJTmooooo`@0ZZZZ1?ooool4
0:ZZZP@00000101EEED4000000@0EEEE1000000405EEE@P00000201EEED40:ZZZPCooooo10000008
0:ZZZPP00000202ZZZX805EEE@Cooooo201EEED8000000Cooooo1000000405EEE@D0ZZZZ101EEED8
ooooo`@000002?ooool405EEE@@0ZZZZ101EEED4000000Cooooo2000000805EEE@Cooooo201EEED8
0:ZZZPP00000202ZZZX4000000Cooooo102ZZZX805EEE@P00000101EEED4000000@0EEEE1@000004
05EEE@@00000102ZZZX4ooooo`@0ZZZZ??oooolW0=7=Z@009P3AcJTmooooo`@0ZZZZ1?ooool40:ZZ
ZP@00000101EEED4000000@0EEEE1000000405EEE@P00000201EEED40:ZZZPCooooo100000080:ZZ
ZPP00000202ZZZX805EEE@Cooooo201EEED8000000Cooooo1000000405EEE@D0ZZZZ101EEED8oooo
o`@000002?ooool405EEE@@0ZZZZ101EEED4000000Cooooo2000000805EEE@Cooooo201EEED80:ZZ
ZPP00000202ZZZX4000000Cooooo102ZZZX805EEE@P00000101EEED4000000@0EEEE1@00000405EE
E@@00000102ZZZX4ooooo`@0ZZZZ??oooolW0=7=Z@009P3AcJU1ooooo`@00000102ZZZX4000000@0
EEEE2?ooool80:ZZZP@00000101EEED40:ZZZPP0EEEE20000008ooooo`P000002?ooool4000000@0
EEEE1?ooool405EEE@@000001?ooool8000000@0EEEE102ZZZX505EEE@Cooooo100000040:ZZZPCo
oooo102ZZZX4000000Cooooo101EEED40:ZZZP@0EEEE20000004ooooo`@00000101EEED4ooooo`@0
EEEE10000008ooooo`P000002?ooool8000000P0EEEE102ZZZX405EEE@@00000202ZZZX9ooooo`@0
EEEE100000040:ZZZP@00000@?oooolW0=7=Z@009P3AcJU1ooooo`@00000102ZZZX4000000@0EEEE
2?ooool80:ZZZP@00000101EEED40:ZZZPP0EEEE20000008ooooo`P000002?ooool4000000@0EEEE
1?ooool405EEE@@000001?ooool8000000@0EEEE102ZZZX505EEE@Cooooo100000040:ZZZPCooooo
102ZZZX4000000Cooooo101EEED40:ZZZP@0EEEE20000004ooooo`@00000101EEED4ooooo`@0EEEE
10000008ooooo`P000002?ooool8000000P0EEEE102ZZZX405EEE@@00000202ZZZX9ooooo`@0EEEE
100000040:ZZZP@00000@?oooolW0=7=Z@009P3AcJU1ooooo`@00000102ZZZX4000000@0EEEE2?oo
ool80:ZZZP@00000101EEED40:ZZZPP0EEEE20000008ooooo`P000002?ooool4000000@0EEEE1?oo
ool405EEE@@000001?ooool8000000@0EEEE102ZZZX505EEE@Cooooo100000040:ZZZPCooooo102Z
ZZX4000000Cooooo101EEED40:ZZZP@0EEEE20000004ooooo`@00000101EEED4ooooo`@0EEEE1000
0008ooooo`P000002?ooool8000000P0EEEE102ZZZX405EEE@@00000202ZZZX9ooooo`@0EEEE1000
00040:ZZZP@00000@?oooolW0=7=Z@009P3AcJU1ooooo`@00000102ZZZX4000000@0EEEE2?ooool8
0:ZZZP@00000101EEED40:ZZZPP0EEEE20000008ooooo`P000002?ooool4000000@0EEEE1?ooool4
05EEE@@000001?ooool8000000@0EEEE102ZZZX505EEE@Cooooo100000040:ZZZPCooooo102ZZZX4
000000Cooooo101EEED40:ZZZP@0EEEE20000004ooooo`@00000101EEED4ooooo`@0EEEE10000008
ooooo`P000002?ooool8000000P0EEEE102ZZZX405EEE@@00000202ZZZX9ooooo`@0EEEE10000004
0:ZZZP@00000@?oooolW0=7=Z@009P3AcJU5ooooo`@0EEEE102ZZZX4000000@0ZZZZ1?ooool40000
00Sooooo101EEED4000000@0EEEE1?ooool8000000Cooooo102ZZZX4000000@0EEEE202ZZZX405EE
E@@000001?ooool40:ZZZPCooooo102ZZZX4000000@0EEEE102ZZZX405EEE@Gooooo100000040:ZZ
ZP@0EEEE1?ooool405EEE@@0ZZZZ10000004ooooo`@0EEEE102ZZZX405EEE@@00000102ZZZX4oooo
o`@0ZZZZ1?ooool4000000@0EEEE202ZZZX405EEE@@00000102ZZZX4ooooo`P000001?ooool405EE
E@@00000101EEED8ooooo`@000001?ooool50:ZZZP@00000102ZZZX405EEEDCooooo9`3AcJT002H0
dLfYAOooool405EEE@@0ZZZZ100000040:ZZZPCooooo10000008ooooo`@0EEEE1000000405EEE@Co
oooo20000004ooooo`@0ZZZZ1000000405EEE@P0ZZZZ101EEED4000000Cooooo102ZZZX4ooooo`@0
ZZZZ1000000405EEE@@0ZZZZ101EEED5ooooo`@00000102ZZZX405EEE@Cooooo101EEED40:ZZZP@0
00001?ooool405EEE@@0ZZZZ101EEED4000000@0ZZZZ1?ooool40:ZZZPCooooo1000000405EEE@P0
ZZZZ101EEED4000000@0ZZZZ1?ooool8000000Cooooo101EEED4000000@0EEEE2?ooool4000000Co
oooo1@2ZZZX4000000@0ZZZZ101EEEE4ooooobL0dLfY000V0=7=ZDGooooo101EEED40:ZZZP@00000
102ZZZX4ooooo`@000002?ooool405EEE@@00000101EEED4ooooo`P000001?ooool40:ZZZP@00000
101EEED80:ZZZP@0EEEE10000004ooooo`@0ZZZZ1?ooool40:ZZZP@00000101EEED40:ZZZP@0EEEE
1Oooool4000000@0ZZZZ101EEED4ooooo`@0EEEE102ZZZX4000000Cooooo101EEED40:ZZZP@0EEEE
100000040:ZZZPCooooo102ZZZX4ooooo`@00000101EEED80:ZZZP@0EEEE100000040:ZZZPCooooo
20000004ooooo`@0EEEE1000000405EEE@Sooooo10000004ooooo`D0ZZZZ100000040:ZZZP@0EEEE
A?oooolW0=7=Z@009P3AcJU5ooooo`@0EEEE102ZZZX4000000@0ZZZZ1?ooool4000000Sooooo101E
EED4000000@0EEEE1?ooool8000000Cooooo102ZZZX4000000@0EEEE202ZZZX405EEE@@000001?oo
ool40:ZZZPCooooo102ZZZX4000000@0EEEE102ZZZX405EEE@Gooooo100000040:ZZZP@0EEEE1?oo
ool405EEE@@0ZZZZ10000004ooooo`@0EEEE102ZZZX405EEE@@00000102ZZZX4ooooo`@0ZZZZ1?oo
ool4000000@0EEEE202ZZZX405EEE@@00000102ZZZX4ooooo`P000001?ooool405EEE@@00000101E
EED8ooooo`@000001?ooool50:ZZZP@00000102ZZZX405EEEDCooooo9`3AcJT002H0dLfYBOooool4
0:ZZZP@0EEEE1000000405EEE@@00000102ZZZX4ooooo`@00000101EEED40:ZZZP@0EEEE102ZZZX4
000000@0EEEE1000000405EEE@@0ZZZZ101EEED4ooooo`@0ZZZZ1?ooool40:ZZZPP00000301EEED4
0:ZZZPgooooo101EEED40:ZZZP@0EEEE102ZZZX405EEE@cooooo102ZZZX<05EEE@P00000102ZZZX4
ooooo`@0ZZZZ1?ooool405EEE@@0ZZZZ101EEED4000000@0EEEE100000040:ZZZP@0EEEE102ZZZX4
05EEE@@000001?ooool40:ZZZP@00000101EEED5000000@0EEEE102ZZZY8ooooobL0dLfY000V0=7=
ZDWooooo102ZZZX405EEE@@00000101EEED4000000@0ZZZZ1?ooool4000000@0EEEE102ZZZX405EE
E@@0ZZZZ1000000405EEE@@00000101EEED40:ZZZP@0EEEE1?ooool40:ZZZPCooooo102ZZZX80000
00`0EEEE102ZZZX=ooooo`@0EEEE102ZZZX405EEE@@0ZZZZ101EEED<ooooo`@0ZZZZ301EEED80000
00@0ZZZZ1?ooool40:ZZZPCooooo101EEED40:ZZZP@0EEEE1000000405EEE@@00000102ZZZX405EE
E@@0ZZZZ101EEED4000000Cooooo102ZZZX4000000@0EEEE1@00000405EEE@@0ZZZZB?oooolW0=7=
Z@009P3AcJU9ooooo`@0ZZZZ101EEED4000000@0EEEE100000040:ZZZPCooooo1000000405EEE@@0
ZZZZ101EEED40:ZZZP@00000101EEED4000000@0EEEE102ZZZX405EEE@Cooooo102ZZZX4ooooo`@0
ZZZZ2000000<05EEE@@0ZZZZ3Oooool405EEE@@0ZZZZ101EEED40:ZZZP@0EEEE3?ooool40:ZZZP`0
EEEE200000040:ZZZPCooooo102ZZZX4ooooo`@0EEEE102ZZZX405EEE@@00000101EEED4000000@0
ZZZZ101EEED40:ZZZP@0EEEE10000004ooooo`@0ZZZZ1000000405EEE@D00000101EEED40:ZZZTSo
oooo9`3AcJT002H0dLfYBOooool40:ZZZP@0EEEE1000000405EEE@@00000102ZZZX4ooooo`@00000
101EEED40:ZZZP@0EEEE102ZZZX4000000@0EEEE1000000405EEE@@0ZZZZ101EEED4ooooo`@0ZZZZ
1?ooool40:ZZZPP00000301EEED40:ZZZPgooooo101EEED40:ZZZP@0EEEE102ZZZX405EEE@cooooo
102ZZZX<05EEE@P00000102ZZZX4ooooo`@0ZZZZ1?ooool405EEE@@0ZZZZ101EEED4000000@0EEEE
100000040:ZZZP@0EEEE102ZZZX405EEE@@000001?ooool40:ZZZP@00000101EEED5000000@0EEEE
102ZZZY8ooooobL0dLfY000V0=7=ZDgooooo1000000405EEE@@0ZZZZ101EEED4000000@0EEEE1000
000<0:ZZZPP000001?ooool405EEE@Cooooo10000004ooooo`P0EEEE200000040:ZZZP@0EEEE1000
0004ooooo`@0EEEE1000000405EEE@T00000101EEED4ooooo`@0ZZZZ1?ooool405EEE@P00000101E
EED4000000@0EEEE1?ooool4000000@0EEEE102ZZZX8000000P0EEEE1?ooool4000000Cooooo101E
EED4ooooo`P00000302ZZZX4000000@0EEEE1000000405EEE@@0ZZZZ1@1EEED4000004cooooo9`3A
cJT002H0dLfYCOooool4000000@0EEEE102ZZZX405EEE@@00000101EEED4000000`0ZZZZ20000004
ooooo`@0EEEE1?ooool4000000Cooooo201EEED8000000@0ZZZZ101EEED4000000Cooooo101EEED4
000000@0EEEE2@00000405EEE@Cooooo102ZZZX4ooooo`@0EEEE2000000405EEE@@00000101EEED4
ooooo`@00000101EEED40:ZZZPP00000201EEED4ooooo`@000001?ooool405EEE@Cooooo2000000<
0:ZZZP@00000101EEED4000000@0EEEE102ZZZX505EEE@@00000C?oooolW0=7=Z@009P3AcJU=oooo
o`@00000101EEED40:ZZZP@0EEEE1000000405EEE@@00000302ZZZX8000000Cooooo101EEED4oooo
o`@000001?ooool805EEE@P00000102ZZZX405EEE@@000001?ooool405EEE@@00000101EEED90000
00@0EEEE1?ooool40:ZZZPCooooo101EEED8000000@0EEEE1000000405EEE@Cooooo1000000405EE
E@@0ZZZZ2000000805EEE@Cooooo10000004ooooo`@0EEEE1?ooool8000000`0ZZZZ1000000405EE
E@@00000101EEED40:ZZZPD0EEEE1000001<ooooobL0dLfY000V0=7=ZDgooooo1000000405EEE@@0
ZZZZ101EEED4000000@0EEEE1000000<0:ZZZPP000001?ooool405EEE@Cooooo10000004ooooo`P0
EEEE200000040:ZZZP@0EEEE10000004ooooo`@0EEEE1000000405EEE@T00000101EEED4ooooo`@0
ZZZZ1?ooool405EEE@P00000101EEED4000000@0EEEE1?ooool4000000@0EEEE102ZZZX8000000P0
EEEE1?ooool4000000Cooooo101EEED4ooooo`P00000302ZZZX4000000@0EEEE1000000405EEE@@0
ZZZZ1@1EEED4000004cooooo9`3AcJT002H0dLfYDOooool405EEE@@00000101EEED8oooooa@0ZZZZ
1?ooool40:ZZZP@00000102ZZZX4ooooo`@0ZZZZ100000080:ZZZPCooooo102ZZZX<05EEE@Cooooo
3@000004ooooo`@00000101EEED4000000@0EEEE10000004ooooo``000001?ooool<05EEE@@0ZZZZ
1?ooool80:ZZZP@00000102ZZZX4ooooo`@0ZZZZ100000040:ZZZPCooooo502ZZZX8ooooo`@0EEEE
1000000505EEEE3ooooo9`3AcJT002H0dLfYDOooool405EEE@@00000101EEED8oooooa@0ZZZZ1?oo
ool40:ZZZP@00000102ZZZX4ooooo`@0ZZZZ100000080:ZZZPCooooo102ZZZX<05EEE@Cooooo3@00
0004ooooo`@00000101EEED4000000@0EEEE10000004ooooo``000001?ooool<05EEE@@0ZZZZ1?oo
ool80:ZZZP@00000102ZZZX4ooooo`@0ZZZZ100000040:ZZZPCooooo502ZZZX8ooooo`@0EEEE1000
000505EEEE3ooooo9`3AcJT002H0dLfYDOooool405EEE@@00000101EEED8oooooa@0ZZZZ1?ooool4
0:ZZZP@00000102ZZZX4ooooo`@0ZZZZ100000080:ZZZPCooooo102ZZZX<05EEE@Cooooo3@000004
ooooo`@00000101EEED4000000@0EEEE10000004ooooo``000001?ooool<05EEE@@0ZZZZ1?ooool8
0:ZZZP@00000102ZZZX4ooooo`@0ZZZZ100000040:ZZZPCooooo502ZZZX8ooooo`@0EEEE10000005
05EEEE3ooooo9`3AcJT002H0dLfYDOooool405EEE@@00000101EEED8oooooa@0ZZZZ1?ooool40:ZZ
ZP@00000102ZZZX4ooooo`@0ZZZZ100000080:ZZZPCooooo102ZZZX<05EEE@Cooooo3@000004oooo
o`@00000101EEED4000000@0EEEE10000004ooooo``000001?ooool<05EEE@@0ZZZZ1?ooool80:ZZ
ZP@00000102ZZZX4ooooo`@0ZZZZ100000040:ZZZPCooooo502ZZZX8ooooo`@0EEEE1000000505EE
EE3ooooo9`3AcJT002H0dLfYEOooool80:ZZZP@000001?ooool40:ZZZP@0EEEE1?ooool40:ZZZP@0
EEEE1?ooool405EEE@@0ZZZZ2000000<05EEE@@00000101EEED4000000@0EEEE1?ooool4000000@0
EEEE100000040:ZZZPD0EEEE20000004ooooo`@0EEEE1?ooool8000000@0EEEE102ZZZX4000000@0
EEEE10000004ooooo`@0EEEE1000000405EEE@@00000301EEED8000000@0ZZZZ101EEED4ooooo`@0
EEEE102ZZZX4ooooo`@0EEEE102ZZZX4ooooo`@00000202ZZZYEooooobL0dLfY000V0=7=ZEGooooo
202ZZZX4000000Cooooo102ZZZX405EEE@Cooooo102ZZZX405EEE@Cooooo101EEED40:ZZZPP00000
301EEED4000000@0EEEE1000000405EEE@Cooooo1000000405EEE@@00000102ZZZX505EEE@P00000
1?ooool405EEE@Cooooo2000000405EEE@@0ZZZZ1000000405EEE@@000001?ooool405EEE@@00000
101EEED4000000`0EEEE200000040:ZZZP@0EEEE1?ooool405EEE@@0ZZZZ1?ooool405EEE@@0ZZZZ
1?ooool4000000P0ZZZZEOoooolW0=7=Z@009P3AcJUEooooo`P0ZZZZ10000004ooooo`@0ZZZZ101E
EED4ooooo`@0ZZZZ101EEED4ooooo`@0EEEE102ZZZX8000000`0EEEE1000000405EEE@@00000101E
EED4ooooo`@00000101EEED4000000@0ZZZZ1@1EEED8000000Cooooo101EEED4ooooo`P00000101E
EED40:ZZZP@00000101EEED4000000Cooooo101EEED4000000@0EEEE1000000<05EEE@P00000102Z
ZZX405EEE@Cooooo101EEED40:ZZZPCooooo101EEED40:ZZZPCooooo100000080:ZZZUGooooo9`3A
cJT002H0dLfYEOooool80:ZZZP@000001?ooool40:ZZZP@0EEEE1?ooool40:ZZZP@0EEEE1?ooool4
05EEE@@0ZZZZ2000000<05EEE@@00000101EEED4000000@0EEEE1?ooool4000000@0EEEE10000004
0:ZZZPD0EEEE20000004ooooo`@0EEEE1?ooool8000000@0EEEE102ZZZX4000000@0EEEE10000004
ooooo`@0EEEE1000000405EEE@@00000301EEED8000000@0ZZZZ101EEED4ooooo`@0EEEE102ZZZX4
ooooo`@0EEEE102ZZZX4ooooo`@00000202ZZZYEooooobL0dLfY000V0=7=ZEWooooo10000004oooo
o`@00000102ZZZX4000000@0ZZZZ1?ooool405EEE@`00000102ZZZX405EEE@@000001?ooool405EE
E@@00000202ZZZX<ooooo`@0EEEE100000040:ZZZPD00000102ZZZX405EEE@`00000101EEED40:ZZ
ZP@00000102ZZZX4000000@0EEEE3?ooool80:ZZZP@00000101EEED4ooooo`@00000101EEED40:ZZ
ZP`00000101EEED4ooooo`@0ZZZZ100000040:ZZZP@000001?ooool4000005Wooooo9`3AcJT002H0
dLfYFOooool4000000Cooooo100000040:ZZZP@00000102ZZZX4ooooo`@0EEEE300000040:ZZZP@0
EEEE10000004ooooo`@0EEEE100000080:ZZZPcooooo101EEED4000000@0ZZZZ1@0000040:ZZZP@0
EEEE3000000405EEE@@0ZZZZ100000040:ZZZP@00000101EEED<ooooo`P0ZZZZ1000000405EEE@Co
oooo1000000405EEE@@0ZZZZ3000000405EEE@Cooooo102ZZZX4000000@0ZZZZ10000004ooooo`@0
0000FOoooolW0=7=Z@009P3AcJUIooooo`@000001?ooool4000000@0ZZZZ100000040:ZZZPCooooo
101EEED<000000@0ZZZZ101EEED4000000Cooooo101EEED4000000P0ZZZZ3?ooool405EEE@@00000
102ZZZX5000000@0ZZZZ101EEED<000000@0EEEE102ZZZX4000000@0ZZZZ1000000405EEE@cooooo
202ZZZX4000000@0EEEE1?ooool4000000@0EEEE102ZZZX<000000@0EEEE1?ooool40:ZZZP@00000
102ZZZX4000000Cooooo1000001IooooobL0dLfY000V0=7=ZEWooooo10000004ooooo`@00000102Z
ZZX4000000@0ZZZZ1?ooool405EEE@`00000102ZZZX405EEE@@000001?ooool405EEE@@00000202Z
ZZX<ooooo`@0EEEE100000040:ZZZPD00000102ZZZX405EEE@`00000101EEED40:ZZZP@00000102Z
ZZX4000000@0EEEE3?ooool80:ZZZP@00000101EEED4ooooo`@00000101EEED40:ZZZP`00000101E
EED4ooooo`@0ZZZZ100000040:ZZZP@000001?ooool4000005Wooooo9`3AcJT002H0dLfYGOooool<
05EEE@@00000102ZZZX4000000Cooooo101EEED8ooooo`@0EEEE102ZZZX405EEE@`000002?ooool4
000000@0ZZZZ1?ooool4000000@0EEEE102ZZZX5ooooo`@0ZZZZ501EEED40:ZZZPCooooo102ZZZX4
05EEE@@000001?ooool40:ZZZP@000002?ooool<000000@0EEEE102ZZZX405EEE@Sooooo101EEED4
ooooo`@00000102ZZZX4000000`0EEEEGOoooolW0=7=Z@009P3AcJUMooooo``0EEEE100000040:ZZ
ZP@000001?ooool405EEE@Sooooo101EEED40:ZZZP@0EEEE30000008ooooo`@00000102ZZZX4oooo
o`@00000101EEED40:ZZZPGooooo102ZZZXD05EEE@@0ZZZZ1?ooool40:ZZZP@0EEEE10000004oooo
o`@0ZZZZ10000008ooooo``00000101EEED40:ZZZP@0EEEE2?ooool405EEE@Cooooo100000040:ZZ
ZP@00000301EEEEMooooobL0dLfY000V0=7=ZEgooooo301EEED4000000@0ZZZZ10000004ooooo`@0
EEEE2?ooool405EEE@@0ZZZZ101EEED<000000Sooooo100000040:ZZZPCooooo1000000405EEE@@0
ZZZZ1Oooool40:ZZZQ@0EEEE102ZZZX4ooooo`@0ZZZZ101EEED4000000Cooooo102ZZZX4000000So
oooo3000000405EEE@@0ZZZZ101EEED8ooooo`@0EEEE1?ooool4000000@0ZZZZ1000000<05EEEEgo
oooo9`3AcJT002H0dLfYGOooool<05EEE@@00000102ZZZX4000000Cooooo101EEED8ooooo`@0EEEE
102ZZZX405EEE@`000002?ooool4000000@0ZZZZ1?ooool4000000@0EEEE102ZZZX5ooooo`@0ZZZZ
501EEED40:ZZZPCooooo102ZZZX405EEE@@000001?ooool40:ZZZP@000002?ooool<000000@0EEEE
102ZZZX405EEE@Sooooo101EEED4ooooo`@00000102ZZZX4000000`0EEEEGOoooolW0=7=Z@009P3A
cJUQooooo`@0ZZZZ2?ooool405EEE@@0ZZZZ10000004ooooo`P0EEEE1?ooool4000000Cooooo101E
EED8ooooo`P0EEEE2?ooool4000000@0ZZZZ201EEED9000000P0ZZZZ100000080:ZZZPP00000201E
EED40:ZZZP@000002?ooool805EEE@Sooooo101EEED4ooooo`@000001?ooool805EEE@Cooooo1000
00040:ZZZP@0EEEE2?ooool40:ZZZV7ooooo9`3AcJT002H0dLfYHOooool40:ZZZPSooooo101EEED4
0:ZZZP@000001?ooool805EEE@Cooooo10000004ooooo`@0EEEE2?ooool805EEE@Sooooo10000004
0:ZZZPP0EEEE2@0000080:ZZZP@00000202ZZZX8000000P0EEEE102ZZZX4000000Sooooo201EEED8
ooooo`@0EEEE1?ooool4000000Cooooo201EEED4ooooo`@00000102ZZZX405EEE@Sooooo102ZZZYQ
ooooobL0dLfY000V0=7=ZF7ooooo102ZZZX8ooooo`@0EEEE102ZZZX4000000Cooooo201EEED4oooo
o`@000001?ooool405EEE@Sooooo201EEED8ooooo`@00000102ZZZX805EEE@T00000202ZZZX40000
00P0ZZZZ2000000805EEE@@0ZZZZ10000008ooooo`P0EEEE2?ooool405EEE@Cooooo10000004oooo
o`P0EEEE1?ooool4000000@0ZZZZ101EEED8ooooo`@0ZZZZHOoooolW0=7=Z@009P3AcJUQooooo`@0
ZZZZ2?ooool405EEE@@0ZZZZ10000004ooooo`P0EEEE1?ooool4000000Cooooo101EEED8ooooo`P0
EEEE2?ooool4000000@0ZZZZ201EEED9000000P0ZZZZ100000080:ZZZPP00000201EEED40:ZZZP@0
00002?ooool805EEE@Sooooo101EEED4ooooo`@000001?ooool805EEE@Cooooo100000040:ZZZP@0
EEEE2?ooool40:ZZZV7ooooo9`3AcJT002H0dLfYIOooool4000000@0ZZZZ2?ooool8000000@0EEEE
1?ooool4000000@0ZZZZ101EEED40:ZZZP@0EEEE202ZZZX4000000@0ZZZZ1?ooool8000000P0ZZZZ
1@00000405EEE@@0ZZZZ1?ooool405EEE@Cooooo102ZZZX405EEE@@00000202ZZZX8000000Cooooo
102ZZZX4000000P0ZZZZ101EEED40:ZZZP@0EEEE102ZZZX4000000Cooooo101EEED8000000Sooooo
102ZZZX4000006Gooooo9`3AcJT002H0dLfYIOooool4000000@0ZZZZ2?ooool8000000@0EEEE1?oo
ool4000000@0ZZZZ101EEED40:ZZZP@0EEEE202ZZZX4000000@0ZZZZ1?ooool8000000P0ZZZZ1@00
000405EEE@@0ZZZZ1?ooool405EEE@Cooooo102ZZZX405EEE@@00000202ZZZX8000000Cooooo102Z
ZZX4000000P0ZZZZ101EEED40:ZZZP@0EEEE102ZZZX4000000Cooooo101EEED8000000Sooooo102Z
ZZX4000006Gooooo9`3AcJT002H0dLfYIOooool4000000@0ZZZZ2?ooool8000000@0EEEE1?ooool4
000000@0ZZZZ101EEED40:ZZZP@0EEEE202ZZZX4000000@0ZZZZ1?ooool8000000P0ZZZZ1@000004
05EEE@@0ZZZZ1?ooool405EEE@Cooooo102ZZZX405EEE@@00000202ZZZX8000000Cooooo102ZZZX4
000000P0ZZZZ101EEED40:ZZZP@0EEEE102ZZZX4000000Cooooo101EEED8000000Sooooo102ZZZX4
000006Gooooo9`3AcJT002H0dLfYIOooool4000000@0ZZZZ2?ooool8000000@0EEEE1?ooool40000
00@0ZZZZ101EEED40:ZZZP@0EEEE202ZZZX4000000@0ZZZZ1?ooool8000000P0ZZZZ1@00000405EE
E@@0ZZZZ1?ooool405EEE@Cooooo102ZZZX405EEE@@00000202ZZZX8000000Cooooo102ZZZX40000
00P0ZZZZ101EEED40:ZZZP@0EEEE102ZZZX4000000Cooooo101EEED8000000Sooooo102ZZZX40000
06Gooooo9`3AcJT002H0dLfYJOooool405EEE@P0ZZZZ101EEED4000000P0ZZZZ101EEED4000000@0
EEEE1?ooool40:ZZZPCooooo101EEED40:ZZZPP00000101EEED40:ZZZPP000001@2ZZZX805EEE@`0
0000201EEED40:ZZZPP00000102ZZZX405EEE@P00000102ZZZX405EEE@Cooooo102ZZZX4ooooo`@0
EEEE1000000405EEE@P0ZZZZ1000000405EEE@P0ZZZZ101EEEEYooooobL0dLfY000V0=7=ZFWooooo
101EEED80:ZZZP@0EEEE100000080:ZZZP@0EEEE1000000405EEE@Cooooo102ZZZX4ooooo`@0EEEE
102ZZZX8000000@0EEEE102ZZZX8000000D0ZZZZ201EEED<000000P0EEEE102ZZZX8000000@0ZZZZ
101EEED8000000@0ZZZZ101EEED4ooooo`@0ZZZZ1?ooool405EEE@@00000101EEED80:ZZZP@00000
101EEED80:ZZZP@0EEEEJOoooolW0=7=Z@009P3AcJUYooooo`@0EEEE202ZZZX405EEE@@00000202Z
ZZX405EEE@@00000101EEED4ooooo`@0ZZZZ1?ooool405EEE@@0ZZZZ2000000405EEE@@0ZZZZ2000
00050:ZZZPP0EEEE3000000805EEE@@0ZZZZ200000040:ZZZP@0EEEE200000040:ZZZP@0EEEE1?oo
ool40:ZZZPCooooo101EEED4000000@0EEEE202ZZZX4000000@0EEEE202ZZZX405EEEFWooooo9`3A
cJT002H0dLfYJOooool405EEE@P0ZZZZ101EEED4000000P0ZZZZ101EEED4000000@0EEEE1?ooool4
0:ZZZPCooooo101EEED40:ZZZPP00000101EEED40:ZZZPP000001@2ZZZX805EEE@`00000201EEED4
0:ZZZPP00000102ZZZX405EEE@P00000102ZZZX405EEE@Cooooo102ZZZX4ooooo`@0EEEE10000004
05EEE@P0ZZZZ1000000405EEE@P0ZZZZ101EEEEYooooobL0dLfY000V0=7=ZFgooooo102ZZZX405EE
E@Cooooo200000040:ZZZP@00000102ZZZX805EEE@Cooooo102ZZZX4000000@0ZZZZ1000000405EE
E@@0ZZZZ101EEED8ooooo`D0EEEE102ZZZXD05EEE@@0ZZZZ101EEED8ooooo`@0EEEE102ZZZX405EE
E@@00000102ZZZX4000000@0ZZZZ1?ooool805EEE@@0ZZZZ100000040:ZZZPP000001?ooool405EE
E@@0ZZZZKOoooolW0=7=Z@009P3AcJU]ooooo`@0ZZZZ101EEED4ooooo`P00000102ZZZX4000000@0
ZZZZ201EEED4ooooo`@0ZZZZ100000040:ZZZP@00000101EEED40:ZZZP@0EEEE2?ooool505EEE@@0
ZZZZ501EEED40:ZZZP@0EEEE2?ooool405EEE@@0ZZZZ101EEED4000000@0ZZZZ100000040:ZZZPCo
oooo201EEED40:ZZZP@00000102ZZZX8000000Cooooo101EEED40:ZZZVgooooo9`3AcJT002H0dLfY
KOooool40:ZZZP@0EEEE1?ooool8000000@0ZZZZ100000040:ZZZPP0EEEE1?ooool40:ZZZP@00000
102ZZZX4000000@0EEEE102ZZZX405EEE@Sooooo1@1EEED40:ZZZQ@0EEEE102ZZZX405EEE@Sooooo
101EEED40:ZZZP@0EEEE100000040:ZZZP@00000102ZZZX4ooooo`P0EEEE102ZZZX4000000@0ZZZZ
20000004ooooo`@0EEEE102ZZZY]ooooobL0dLfY000V0=7=ZFgooooo102ZZZX405EEE@Cooooo2000
00040:ZZZP@00000102ZZZX805EEE@Cooooo102ZZZX4000000@0ZZZZ1000000405EEE@@0ZZZZ101E
EED8ooooo`D0EEEE102ZZZXD05EEE@@0ZZZZ101EEED8ooooo`@0EEEE102ZZZX405EEE@@00000102Z
ZZX4000000@0ZZZZ1?ooool805EEE@@0ZZZZ100000040:ZZZPP000001?ooool405EEE@@0ZZZZKOoo
oolW0=7=Z@009P3AcJUaooooo`@00000101EEED4000000@0ZZZZ101EEED8ooooo`@00000101EEED4
ooooo`@0EEEE102ZZZX8000000Cooooo101EEED40:ZZZP@0EEEE2@2ZZZXL000000P0ZZZZ101EEED4
0:ZZZP@0EEEE1?ooool8000000@0ZZZZ101EEED4ooooo`@0EEEE10000008ooooo`@0EEEE102ZZZX4
000000@0EEEE1000001aooooobL0dLfY000V0=7=ZG7ooooo1000000405EEE@@00000102ZZZX405EE
E@Sooooo1000000405EEE@Cooooo101EEED40:ZZZPP000001?ooool405EEE@@0ZZZZ101EEED90:ZZ
ZQ`00000202ZZZX405EEE@@0ZZZZ101EEED4ooooo`P00000102ZZZX405EEE@Cooooo101EEED40000
00Sooooo101EEED40:ZZZP@00000101EEED40000077ooooo9`3AcJT002H0dLfYLOooool4000000@0
EEEE100000040:ZZZP@0EEEE2?ooool4000000@0EEEE1?ooool405EEE@@0ZZZZ20000004ooooo`@0
EEEE102ZZZX405EEE@T0ZZZZ700000080:ZZZP@0EEEE102ZZZX405EEE@Cooooo200000040:ZZZP@0
EEEE1?ooool405EEE@@000002?ooool405EEE@@0ZZZZ1000000405EEE@@00000LOoooolW0=7=Z@00
9P3AcJUaooooo`@00000101EEED4000000@0ZZZZ101EEED8ooooo`@00000101EEED4ooooo`@0EEEE
102ZZZX8000000Cooooo101EEED40:ZZZP@0EEEE2@2ZZZXL000000P0ZZZZ101EEED40:ZZZP@0EEEE
1?ooool8000000@0ZZZZ101EEED4ooooo`@0EEEE10000008ooooo`@0EEEE102ZZZX4000000@0EEEE
1000001aooooobL0dLfY000V0=7=ZGGooooo101EEED4000000@0ZZZZ100000040:ZZZPCooooo3000
000405EEE@Cooooo202ZZZX4ooooo`@00000201EEED40:ZZZPGooooo101EEED8ooooo`@0EEEE2?oo
ool405EEE@Cooooo102ZZZX805EEE@@000001?ooool80:ZZZPCooooo101EEED<000000Cooooo102Z
ZZX4000000@0ZZZZ1000000405EEEGGooooo9`3AcJT002H0dLfYMOooool405EEE@@00000102ZZZX4
000000@0ZZZZ1?ooool<000000@0EEEE1?ooool80:ZZZPCooooo1000000805EEE@@0ZZZZ1Oooool4
05EEE@Sooooo101EEED8ooooo`@0EEEE1?ooool40:ZZZPP0EEEE10000004ooooo`P0ZZZZ1?ooool4
05EEE@`000001?ooool40:ZZZP@00000102ZZZX4000000@0EEEEMOoooolW0=7=Z@009P3AcJUeoooo
o`@0EEEE100000040:ZZZP@00000102ZZZX4ooooo``00000101EEED4ooooo`P0ZZZZ1?ooool40000
00P0EEEE102ZZZX5ooooo`@0EEEE2?ooool405EEE@Sooooo101EEED4ooooo`@0ZZZZ201EEED40000
00Cooooo202ZZZX4ooooo`@0EEEE30000004ooooo`@0ZZZZ100000040:ZZZP@00000101EEEEeoooo
obL0dLfY000V0=7=ZGGooooo101EEED4000000@0ZZZZ100000040:ZZZPCooooo3000000405EEE@Co
oooo202ZZZX4ooooo`@00000201EEED40:ZZZPGooooo101EEED8ooooo`@0EEEE2?ooool405EEE@Co
oooo102ZZZX805EEE@@000001?ooool80:ZZZPCooooo101EEED<000000Cooooo102ZZZX4000000@0
ZZZZ1000000405EEEGGooooo9`3AcJT002H0dLfYNOooool<0:ZZZPCooooo501EEED@0:ZZZP@0EEEE
10000004ooooo`@0EEEE2@2ZZZX4000000Cooooo102ZZZX4ooooo`@00000202ZZZX405EEE@Cooooo
1000000405EEEA00ZZZZ501EEED4ooooo``0ZZZZNOoooolW0=7=Z@009P3AcJUiooooo``0ZZZZ1?oo
oolD05EEEA00ZZZZ101EEED4000000Cooooo101EEED90:ZZZP@000001?ooool40:ZZZPCooooo1000
00080:ZZZP@0EEEE1?ooool4000000@0EEEE402ZZZXD05EEE@Cooooo302ZZZYiooooobL0dLfY000V
0=7=ZGWooooo302ZZZX4oooooa@0EEEE402ZZZX405EEE@@000001?ooool405EEE@T0ZZZZ10000004
ooooo`@0ZZZZ1?ooool4000000P0ZZZZ101EEED4ooooo`@00000101EEED@0:ZZZQ@0EEEE1?ooool<
0:ZZZWWooooo9`3AcJT002H0dLfYNOooool<0:ZZZPCooooo501EEED@0:ZZZP@0EEEE10000004oooo
o`@0EEEE2@2ZZZX4000000Cooooo102ZZZX4ooooo`@00000202ZZZX405EEE@Cooooo1000000405EE
EA00ZZZZ501EEED4ooooo``0ZZZZNOoooolW0=7=Z@009P3AcJUmooooo`@000003?ooool40:ZZZPSo
oooo102ZZZX4ooooo`@0EEEE102ZZZX4ooooo`@0EEEE100000040:ZZZPWooooo10000004ooooo`@0
0000102ZZZX4000000Cooooo10000008ooooo`@0ZZZZ1000000405EEE@Cooooo102ZZZX405EEE@Co
oooo102ZZZX8ooooo`@0ZZZZ3?ooool4000007gooooo9`3AcJT002H0dLfYOOooool4000000cooooo
102ZZZX8ooooo`@0ZZZZ1?ooool405EEE@@0ZZZZ1?ooool405EEE@@00000102ZZZX9ooooo`@00000
1?ooool4000000@0ZZZZ10000004ooooo`@000002?ooool40:ZZZP@00000101EEED4ooooo`@0ZZZZ
101EEED4ooooo`@0ZZZZ2?ooool40:ZZZPcooooo1000001mooooobL0dLfY000V0=7=ZGgooooo1000
000<ooooo`@0ZZZZ2?ooool40:ZZZPCooooo101EEED40:ZZZPCooooo101EEED4000000@0ZZZZ2Ooo
ool4000000Cooooo100000040:ZZZP@000001?ooool4000000Sooooo102ZZZX4000000@0EEEE1?oo
ool40:ZZZP@0EEEE1?ooool40:ZZZPSooooo102ZZZX<ooooo`@00000OOoooolW0=7=Z@009P3AcJUm
ooooo`@000003?ooool40:ZZZPSooooo102ZZZX4ooooo`@0EEEE102ZZZX4ooooo`@0EEEE10000004
0:ZZZPWooooo10000004ooooo`@00000102ZZZX4000000Cooooo10000008ooooo`@0ZZZZ10000004
05EEE@Cooooo102ZZZX405EEE@Cooooo102ZZZX8ooooo`@0ZZZZ3?ooool4000007gooooo9`3AcJT0
02H0dLfYPOooool805EEE@Cooooo101EEED80:ZZZP@0EEEE1?ooool405EEE@@00000101EEED40000
00Cooooo10000004ooooo`D0ZZZZ1000000405EEE@@00000102ZZZX4000000@0EEEE100000040:ZZ
ZPCooooo10000004ooooo`@00000101EEED4000000@0EEEE1?ooool405EEE@P0ZZZZ101EEED4oooo
o`P0EEEEPOoooolW0=7=Z@009P3AcJV1ooooo`P0EEEE1?ooool405EEE@P0ZZZZ101EEED4ooooo`@0
EEEE1000000405EEE@@000001?ooool4000000Cooooo1@2ZZZX4000000@0EEEE100000040:ZZZP@0
0000101EEED4000000@0ZZZZ1?ooool4000000Cooooo1000000405EEE@@00000101EEED4ooooo`@0
EEEE202ZZZX405EEE@Cooooo201EEEF1ooooobL0dLfY000V0=7=ZH7ooooo201EEED4ooooo`@0EEEE
202ZZZX405EEE@Cooooo101EEED4000000@0EEEE10000004ooooo`@000001?ooool50:ZZZP@00000
101EEED4000000@0ZZZZ1000000405EEE@@00000102ZZZX4ooooo`@000001?ooool4000000@0EEEE
1000000405EEE@Cooooo101EEED80:ZZZP@0EEEE1?ooool805EEEH7ooooo9`3AcJT002H0dLfYPOoo
ool805EEE@Cooooo101EEED80:ZZZP@0EEEE1?ooool405EEE@@00000101EEED4000000Cooooo1000
0004ooooo`D0ZZZZ1000000405EEE@@00000102ZZZX4000000@0EEEE100000040:ZZZPCooooo1000
0004ooooo`@00000101EEED4000000@0EEEE1?ooool405EEE@P0ZZZZ101EEED4ooooo`P0EEEEPOoo
oolW0=7=Z@009P3AcJV5ooooo`@0ZZZZ1?ooool4000000P0EEEE10000004ooooo`@0ZZZZ1?ooool4
0:ZZZPCooooo102ZZZX4000000@0EEEE1@00000405EEE@@0ZZZZ101EEED4000000@0EEEE102ZZZX4
05EEE@@00000101EEED4000000@0ZZZZ1?ooool40:ZZZPCooooo102ZZZX4ooooo`@00000201EEED4
000000Cooooo102ZZZZ5ooooobL0dLfY000V0=7=ZHGooooo102ZZZX4ooooo`@00000201EEED40000
00Cooooo102ZZZX4ooooo`@0ZZZZ1?ooool40:ZZZP@00000101EEED5000000@0EEEE102ZZZX405EE
E@@00000101EEED40:ZZZP@0EEEE1000000405EEE@@00000102ZZZX4ooooo`@0ZZZZ1?ooool40:ZZ
ZPCooooo1000000805EEE@@000001?ooool40:ZZZXGooooo9`3AcJT002H0dLfYQOooool40:ZZZPCo
oooo1000000805EEE@@000001?ooool40:ZZZPCooooo102ZZZX4ooooo`@0ZZZZ1000000405EEE@D0
0000101EEED40:ZZZP@0EEEE1000000405EEE@@0ZZZZ101EEED4000000@0EEEE100000040:ZZZPCo
oooo102ZZZX4ooooo`@0ZZZZ1?ooool4000000P0EEEE10000004ooooo`@0ZZZZQOoooolW0=7=Z@00
9P3AcJV5ooooo`@0ZZZZ1?ooool4000000P0EEEE10000004ooooo`@0ZZZZ1?ooool40:ZZZPCooooo
102ZZZX4000000@0EEEE1@00000405EEE@@0ZZZZ101EEED4000000@0EEEE102ZZZX405EEE@@00000
101EEED4000000@0ZZZZ1?ooool40:ZZZPCooooo102ZZZX4ooooo`@00000201EEED4000000Cooooo
102ZZZZ5ooooobL0dLfY000V0=7=ZHWooooo100000040:ZZZPP0EEEE102ZZZX4000000cooooo1000
00040:ZZZP@00000101EEED9ooooo`@0ZZZZ301EEED40:ZZZPSooooo101EEED4000000@0ZZZZ1000
000<ooooo`@00000102ZZZX805EEE@@0ZZZZ10000029ooooobL0dLfY000V0=7=ZHWooooo10000004
0:ZZZPP0EEEE102ZZZX4000000cooooo100000040:ZZZP@00000101EEED9ooooo`@0ZZZZ301EEED4
0:ZZZPSooooo101EEED4000000@0ZZZZ1000000<ooooo`@00000102ZZZX805EEE@@0ZZZZ10000029
ooooobL0dLfY000V0=7=ZHWooooo100000040:ZZZPP0EEEE102ZZZX4000000cooooo100000040:ZZ
ZP@00000101EEED9ooooo`@0ZZZZ301EEED40:ZZZPSooooo101EEED4000000@0ZZZZ1000000<oooo
o`@00000102ZZZX805EEE@@0ZZZZ10000029ooooobL0dLfY000V0=7=ZHWooooo100000040:ZZZPP0
EEEE102ZZZX4000000cooooo100000040:ZZZP@00000101EEED9ooooo`@0ZZZZ301EEED40:ZZZPSo
oooo101EEED4000000@0ZZZZ1000000<ooooo`@00000102ZZZX805EEE@@0ZZZZ10000029ooooobL0
dLfY000V0=7=ZHgooooo101EEED40:ZZZPP0EEEE100000040:ZZZPCooooo100000040:ZZZP@0EEEE
2?ooool50:ZZZP@000002?ooool40:ZZZPSooooo100000040:ZZZPSooooo101EEED40:ZZZP@00000
1?ooool40:ZZZP@00000201EEED40:ZZZP@0EEEESOoooolW0=7=Z@009P3AcJV=ooooo`@0EEEE102Z
ZZX805EEE@@00000102ZZZX4ooooo`@00000102ZZZX405EEE@Sooooo1@2ZZZX4000000Sooooo102Z
ZZX8ooooo`@00000102ZZZX8ooooo`@0EEEE102ZZZX4000000Cooooo102ZZZX4000000P0EEEE102Z
ZZX405EEEHgooooo9`3AcJT002H0dLfYSOooool405EEE@@0ZZZZ201EEED4000000@0ZZZZ1?ooool4
000000@0ZZZZ101EEED8ooooo`D0ZZZZ10000008ooooo`@0ZZZZ2?ooool4000000@0ZZZZ2?ooool4
05EEE@@0ZZZZ10000004ooooo`@0ZZZZ1000000805EEE@@0ZZZZ101EEEF=ooooobL0dLfY000V0=7=
ZHgooooo101EEED40:ZZZPP0EEEE100000040:ZZZPCooooo100000040:ZZZP@0EEEE2?ooool50:ZZ
ZP@000002?ooool40:ZZZPSooooo100000040:ZZZPSooooo101EEED40:ZZZP@000001?ooool40:ZZ
ZP@00000201EEED40:ZZZP@0EEEESOoooolW0=7=Z@009P3AcJVAooooo`@0ZZZZ201EEED40:ZZZPP0
0000101EEED40:ZZZQ7ooooo2000000405EEE@@00000101EEED80000013ooooo102ZZZX405EEE@P0
0000102ZZZX805EEE@@0ZZZZTOoooolW0=7=Z@009P3AcJVAooooo`@0ZZZZ201EEED40:ZZZPP00000
101EEED40:ZZZQ7ooooo2000000405EEE@@00000101EEED80000013ooooo102ZZZX405EEE@P00000
102ZZZX805EEE@@0ZZZZTOoooolW0=7=Z@009P3AcJVAooooo`@0ZZZZ201EEED40:ZZZPP00000101E
EED40:ZZZQ7ooooo2000000405EEE@@00000101EEED80000013ooooo102ZZZX405EEE@P00000102Z
ZZX805EEE@@0ZZZZTOoooolW0=7=Z@009P3AcJVAooooo`@0ZZZZ201EEED40:ZZZPP00000101EEED4
0:ZZZQ7ooooo2000000405EEE@@00000101EEED80000013ooooo102ZZZX405EEE@P00000102ZZZX8
05EEE@@0ZZZZTOoooolW0=7=Z@009P3AcJVEooooo`@00000101EEED4ooooo`P0ZZZZ2?ooool40000
00@0ZZZZ1?ooool5000000@0ZZZZ101EEED4000000Cooooo1000000405EEE@@0ZZZZ10000004oooo
o`@0ZZZZ10000008ooooo`P0ZZZZ1?ooool405EEE@@00000UOoooolW0=7=Z@009P3AcJVEooooo`@0
0000101EEED4ooooo`P0ZZZZ2?ooool4000000@0ZZZZ1?ooool5000000@0ZZZZ101EEED4000000Co
oooo1000000405EEE@@0ZZZZ10000004ooooo`@0ZZZZ10000008ooooo`P0ZZZZ1?ooool405EEE@@0
0000UOoooolW0=7=Z@009P3AcJVEooooo`@00000101EEED4ooooo`P0ZZZZ2?ooool4000000@0ZZZZ
1?ooool5000000@0ZZZZ101EEED4000000Cooooo1000000405EEE@@0ZZZZ10000004ooooo`@0ZZZZ
10000008ooooo`P0ZZZZ1?ooool405EEE@@00000UOoooolW0=7=Z@009P3AcJVEooooo`@00000101E
EED4ooooo`P0ZZZZ2?ooool4000000@0ZZZZ1?ooool5000000@0ZZZZ101EEED4000000Cooooo1000
000405EEE@@0ZZZZ10000004ooooo`@0ZZZZ10000008ooooo`P0ZZZZ1?ooool405EEE@@00000UOoo
oolW0=7=Z@009P3AcJVIooooo`@0EEEE200000040:ZZZP@000001?ooool<0:ZZZPD0EEEE10000004
05EEE@cooooo101EEED4000000@0EEEE302ZZZX4ooooo`@00000102ZZZX8000000@0EEEEVOoooolW
0=7=Z@009P3AcJVIooooo`@0EEEE200000040:ZZZP@000001?ooool<0:ZZZPD0EEEE1000000405EE
E@cooooo101EEED4000000@0EEEE302ZZZX4ooooo`@00000102ZZZX8000000@0EEEEVOoooolW0=7=
Z@009P3AcJVIooooo`@0EEEE200000040:ZZZP@000001?ooool<0:ZZZPD0EEEE1000000405EEE@co
oooo101EEED4000000@0EEEE302ZZZX4ooooo`@00000102ZZZX8000000@0EEEEVOoooolW0=7=Z@00
9P3AcJVIooooo`@0EEEE200000040:ZZZP@000001?ooool<0:ZZZPD0EEEE1000000405EEE@cooooo
101EEED4000000@0EEEE302ZZZX4ooooo`@00000102ZZZX8000000@0EEEEVOoooolW0=7=Z@009P3A
cJVMooooo`P0ZZZZ1?ooool405EEE@Cooooo101EEED40:ZZZPCooooo1@1EEED4000000P0ZZZZ101E
EED80:ZZZP@00000101EEED4ooooo`@0ZZZZ101EEED4ooooo`@0EEEE1?ooool80:ZZZYgooooo9`3A
cJT002H0dLfYWOooool80:ZZZPCooooo101EEED4ooooo`@0EEEE102ZZZX4ooooo`D0EEEE10000008
0:ZZZP@0EEEE202ZZZX4000000@0EEEE1?ooool40:ZZZP@0EEEE1?ooool405EEE@Cooooo202ZZZZM
ooooobL0dLfY000V0=7=ZIgooooo202ZZZX4ooooo`@0EEEE1?ooool405EEE@@0ZZZZ1?ooool505EE
E@@00000202ZZZX405EEE@P0ZZZZ1000000405EEE@Cooooo102ZZZX405EEE@Cooooo101EEED4oooo
o`P0ZZZZWOoooolW0=7=Z@009P3AcJVMooooo`P0ZZZZ1?ooool405EEE@Cooooo101EEED40:ZZZPCo
oooo1@1EEED4000000P0ZZZZ101EEED80:ZZZP@00000101EEED4ooooo`@0ZZZZ101EEED4ooooo`@0
EEEE1?ooool80:ZZZYgooooo9`3AcJT002H0dLfYXOooool4000000Cooooo102ZZZX4ooooo`@00000
201EEED5ooooo`P00000102ZZZX4000000@0ZZZZ20000004ooooo`P0EEEE10000004ooooo`@0ZZZZ
1?ooool400000:7ooooo9`3AcJT002H0dLfYXOooool4000000Cooooo102ZZZX4ooooo`@00000201E
EED5ooooo`P00000102ZZZX4000000@0ZZZZ20000004ooooo`P0EEEE10000004ooooo`@0ZZZZ1?oo
ool400000:7ooooo9`3AcJT002H0dLfYXOooool4000000Cooooo102ZZZX4ooooo`@00000201EEED5
ooooo`P00000102ZZZX4000000@0ZZZZ20000004ooooo`P0EEEE10000004ooooo`@0ZZZZ1?ooool4
00000:7ooooo9`3AcJT002H0dLfYXOooool4000000Cooooo102ZZZX4ooooo`@00000201EEED5oooo
o`P00000102ZZZX4000000@0ZZZZ20000004ooooo`P0EEEE10000004ooooo`@0ZZZZ1?ooool40000
0:7ooooo9`3AcJT002H0dLfYYOooool805EEE@P000001?ooool405EEE@T000001?ooool4000000Co
oooo10000004ooooo`P00000101EEED4ooooo`P00000201EEEFUooooobL0dLfY000V0=7=ZJGooooo
201EEED8000000Cooooo101EEED9000000Cooooo10000004ooooo`@000001?ooool8000000@0EEEE
1?ooool8000000P0EEEEYOoooolW0=7=Z@009P3AcJVUooooo`P0EEEE20000004ooooo`@0EEEE2@00
0004ooooo`@000001?ooool4000000Cooooo2000000405EEE@Cooooo2000000805EEEJGooooo9`3A
cJT002H0dLfYYOooool805EEE@P000001?ooool405EEE@T000001?ooool4000000Cooooo10000004
ooooo`P00000101EEED4ooooo`P00000201EEEFUooooobL0dLfY000V0=7=ZJWooooo102ZZZX4oooo
o`P0ZZZZ4@1EEED<oooooa00EEEE202ZZZX4ooooo`@0ZZZZZOoooolW0=7=Z@009P3AcJVYooooo`@0
ZZZZ1?ooool80:ZZZQ40EEEE3?ooool@05EEE@P0ZZZZ1?ooool40:ZZZZWooooo9`3AcJT002H0dLfY
ZOooool40:ZZZPCooooo202ZZZXA05EEE@cooooo401EEED80:ZZZPCooooo102ZZZZYooooobL0dLfY
000V0=7=ZJWooooo102ZZZX4ooooo`P0ZZZZ4@1EEED<oooooa00EEEE202ZZZX4ooooo`@0ZZZZZOoo
oolW0=7=Z@009P3AcJV]ooooo`@00000102ZZZXI000000@0EEEE600000040:ZZZP@00000[OoooolW
0=7=Z@009P3AcJV]ooooo`@00000102ZZZXI000000@0EEEE600000040:ZZZP@00000[OoooolW0=7=
Z@009P3AcJV]ooooo`@00000102ZZZXI000000@0EEEE600000040:ZZZP@00000[OoooolW0=7=Z@00
9P3AcJV]ooooo`@00000102ZZZXI000000@0EEEE600000040:ZZZP@00000[OoooolW0=7=Z@009P3A
cJVaooooo`@0EEEE102ZZZX4000000D0EEEE102ZZZX4000000@0EEEE102ZZZX405EEE@@00000102Z
ZZX405EEE@@00000102ZZZX405EEEK7ooooo9`3AcJT002H0dLfY/Oooool405EEE@@0ZZZZ10000005
05EEE@@0ZZZZ1000000405EEE@@0ZZZZ101EEED4000000@0ZZZZ101EEED4000000@0ZZZZ101EEEFa
ooooobL0dLfY000V0=7=ZK7ooooo101EEED40:ZZZP@000001@1EEED40:ZZZP@00000101EEED40:ZZ
ZP@0EEEE100000040:ZZZP@0EEEE100000040:ZZZP@0EEEE/OoooolW0=7=Z@009P3AcJVaooooo`@0
EEEE102ZZZX4000000D0EEEE102ZZZX4000000@0EEEE102ZZZX405EEE@@00000102ZZZX405EEE@@0
0000102ZZZX405EEEK7ooooo9`3AcJT002H0dLfY]Oooool40:ZZZP@0EEEE1@000008ooooo`@0EEEE
1000000405EEE@Sooooo1000000405EEE@@0ZZZZ]OoooolW0=7=Z@009P3AcJVeooooo`@0ZZZZ101E
EED5000000Sooooo101EEED4000000@0EEEE2?ooool4000000@0EEEE102ZZZZeooooobL0dLfY000V
0=7=ZKGooooo102ZZZX405EEE@D000002?ooool405EEE@@00000101EEED8ooooo`@00000101EEED4
0:ZZZ[Gooooo9`3AcJT002H0dLfY]Oooool40:ZZZP@0EEEE1@000008ooooo`@0EEEE1000000405EE
E@Sooooo1000000405EEE@@0ZZZZ]OoooolW0=7=Z@009P3AcJViooooo`@000001@1EEED80:ZZZP`0
EEEE202ZZZX405EEE@@00000^OoooolW0=7=Z@009P3AcJViooooo`@000001@1EEED80:ZZZP`0EEEE
202ZZZX405EEE@@00000^OoooolW0=7=Z@009P3AcJViooooo`@000001@1EEED80:ZZZP`0EEEE202Z
ZZX405EEE@@00000^OoooolW0=7=Z@009P3AcJViooooo`@000001@1EEED80:ZZZP`0EEEE202ZZZX4
05EEE@@00000^OoooolW0=7=Z@009P3AcJVmooooo`D0EEEE1000000805EEE@@0ZZZZ201EEED40000
00@0EEEE_OoooolW0=7=Z@009P3AcJVmooooo`D0EEEE1000000805EEE@@0ZZZZ201EEED4000000@0
EEEE_OoooolW0=7=Z@009P3AcJVmooooo`D0EEEE1000000805EEE@@0ZZZZ201EEED4000000@0EEEE
_OoooolW0=7=Z@009P3AcJVmooooo`D0EEEE1000000805EEE@@0ZZZZ201EEED4000000@0EEEE_Ooo
oolW0=7=Z@009P3AcJW2ooooo`P0ZZZZ100000040:ZZZP@00000202ZZZ[1ooooobL0dLfY000V0=7=
ZL;ooooo202ZZZX4000000@0ZZZZ100000080:ZZZ/7ooooo9`3AcJT002H0dLfY`_ooool80:ZZZP@0
0000102ZZZX4000000P0ZZZZ`OoooolW0=7=Z@009P3AcJW2ooooo`P0ZZZZ100000040:ZZZP@00000
202ZZZ[1ooooobL0dLfY000V0=7=ZLKooooo10000004ooooo`@000001?ooool400000<Gooooo9`3A
cJT002H0dLfYa_ooool4000000Cooooo10000004ooooo`@00000aOoooolW0=7=Z@009P3AcJW6oooo
o`@000001?ooool4000000Cooooo10000035ooooobL0dLfY000V0=7=ZLKooooo10000004ooooo`@0
00001?ooool400000<Gooooo9`3AcJT002H0dLfYb_ooool<05EEELWooooo9`3AcJT002H0dLfYb_oo
ool<05EEELWooooo9`3AcJT002H0dLfYb_ooool<05EEELWooooo9`3AcJT002H0dLfYb_ooool<05EE
ELWooooo9`3AcJT002H0dLfYc_ooool40:ZZZ/gooooo9`3AcJT002H0dLfYc_ooool40:ZZZ/gooooo
9`3AcJT002H0dLfYc_ooool40:ZZZ/gooooo9`3AcJT002H0dLfYc_ooool40:ZZZ/gooooo9`3AcJT0
0?l0dLfYk@3AcJT00?l0dLfYk@3AcJT00?l0dLfYk@3AcJT00?l0dLfYk@3AcJT00?l0dLfYk@3AcJT0
0?l0dLfYk@3AcJT00?l0dLfYk@3AcJT00?l0dLfYk@3AcJT00?l0dLfYk@3AcJT00?l0dLfYk@3AcJT0
0?l0dLfYk@3AcJT00?l0dLfYk@3AcJT00?l0dLfYk@3AcJT00?l0dLfYk@3AcJT008@0dLfY0d000004
0=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@020=7=Z@9000001@3AcJT3@00000030=7=ZD000010
000000=000000P3AcJT2@00000@0dLfY0T0000040=7=Z@9000001@3AcJT3@0000080dLfY0T000003
0=7=Z@=000001@3AcJT3@00000<0dLfY00A000000=7=Z@3AcJT0dLfY0d0000030=7=Z@=000000`3A
cJT3@00000@0dLfY0T0000040=7=Z@9000001@3AcJT014000000dLfY0=7=Z@3AcJT5@00000030=7=
ZD0000100000009000000`3AcJT2@00000<0dLfY140000020=7=Z@=000001@3AcJT3@00000030=7=
ZD000010000000=000000P3AcJT2@00000<0dLfY1D0000020=7=Z@900000103AcJT2@00000@0dLfY
0T0000040=7=Z@9000000`3AcJT5@00000<0dLfY0d0000000`3AcJU00000@0000002@0000080dLfY
0d0000040=7=Z@900000Q`3AcJT008@0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@030=7=
Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0
dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@030=7=Z@04@000
003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@040=7=Z@03
@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00`3AcJT01D000000dLfY0=7=Z@3AcJU00000
0080dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A00000
0=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00<0dLfY00E0
00000=7=Z@3AcJT0dLfY@00000050=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3A
cJT01@3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0dLfY@0000002
0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0103AcJT014000000
dLfY0=7=ZD0000070=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@24
0=7=Z@00Q03AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=0
00000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@05@00000<0dLfY00=000000=7=Z@3AcJT00`3A
cJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY
0=7=Z@05@00000050=7=ZD000000dLfY0=7=ZD0000000`3AcJT3@0000080dLfY1D0000030=7=Z@03
@000003AcJT0dLfY0080dLfY0d0000020=7=Z@04@000003AcJT0dLfY@00000<0dLfY0d0000020=7=
Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000103AcJT00d000000dLfY0=7=
Z@030=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT01@3AcJT01D000000dLfY0=7=
Z@3AcJU0000000D0dLfY0d0000020=7=Z@E000000`3AcJT00d000000dLfY0=7=Z@040=7=Z@03@000
003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT0103AcJT014000000dLfY0=7=ZD0000020=7=Z@04
@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@02
0=7=Z@04@000003AcJT0dLfY0=7=Z@E000000P3AcJT00d000000dLfY0=7=Z@030=7=Z@=000000P3A
cJT014000000dLfY0=7=ZD0000260=7=Z@00Q03AcJT3@00000<0dLfY00A000000=7=Z@3AcJU00000
1@3AcJT014000000dLfY0=7=Z@3AcJT2@00000<0dLfY00A000000=7=Z@3AcJU00000103AcJT00d00
0000dLfY0=7=Z@040=7=Z@04@000003AcJT0dLfY0=7=Z@900000103AcJT2@00000<0dLfY00A00000
0=7=Z@3AcJU000000`3AcJT2@00000<0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD0000050=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT00d0000030=7=
Z@04@000003AcJT0dLfY@00000<0dLfY0T0000040=7=Z@9000001P3AcJT00d000000dLfY0=7=Z@02
0=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00P3AcJT2@00000D0dLfY00E00000
0=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3AcJT0
0P3AcJT00d000000dLfY0=7=Z@020=7=Z@9000001@3AcJT00d000000dLfY0=7=Z@020=7=Z@900000
0`3AcJT014000000dLfY0=7=ZD0000030=7=Z@9000000`3AcJT014000000dLfY0=7=ZD0000040=7=
Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0
dLfY0=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY08@0dLfY
00250=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=ZD000000103AcJT01D000000
dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT01D000000dLfY0=7=Z@3A
cJU0000000D0dLfY00=000000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000
003AcJT0dLfY@00000<0dLfY00=000000=7=ZD0000000P3AcJT014000000dLfY0=7=ZD0000020=7=
Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD00
00020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000
dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT01D000000dLfY0=7=Z@3A
cJU0000000@0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03
@000003AcJU0000000@0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@040=7=Z@03
@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000020=7=
Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000103AcJT00d000000dLfY0=7=
Z@020=7=Z@03@000003AcJU000000080dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00008H0dLfY00250=7=Z@=000000`3AcJT2@00000<0
dLfY140000030=7=Z@=00000103AcJT2@00000<0dLfY0T0000040=7=Z@900000103AcJT2@00000@0
dLfY0d0000040=7=Z@9000000`3AcJT2@00000@0dLfY0d0000040=7=Z@9000000P3AcJT4@00000<0
dLfY0d0000030=7=Z@=000000`3AcJT3@00000<0dLfY0T0000040=7=Z@9000000`3AcJT4@00000<0
dLfY0T0000040=7=Z@900000103AcJT3@00000<0dLfY0T0000040=7=Z@=00000103AcJT2@00000<0
dLfY0T0000040=7=Z@=000000`3AcJT2@00000@0dLfY0d0000030=7=Z@900000103AcJT2@00000@0
dLfY0T0000040=7=Z@9000001@3AcJT2@00000<0dLfY0T0000040=7=Z@=000000`3AcJT2@00008L0
dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0
dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0
dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0
dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0
dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0
dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0
dLfY000V0=7=Z@Sooooo202ZZZX4ooooo`@0ZZZZ301EEED4ooooo`@0EEEE1@00000805EEE@Sooooo
102ZZZX405EEE@@0ZZZZ2000000405EEE@Cooooo100000040:ZZZPCooooo101EEED4ooooo`@0ZZZZ
101EEED80:ZZZP@00000102ZZZX8ooooo`P00000102ZZZX4ooooo`@0EEEE1?ooool405EEE@`0ZZZZ
101EEED9ooooo`@0EEEE1?ooool4000000Cooooo101EEED8ooooo`@0EEEE302ZZZX405EEE@Cooooo
101EEED4ooooo`@0ZZZZ20000008ooooo`@0ZZZZ100000080:ZZZP@0EEEE102ZZZX4ooooo`@0EEEE
1?ooool40:ZZZP@000001?ooool405EEE@T00000102ZZZX405EEE@@0ZZZZ2?ooool805EEE@@00000
101EEED4ooooo``0EEEE102ZZZX4ooooo`P0ZZZZ2?oooolW0=7=Z@009P3AcJT8ooooo`P0ZZZZ1?oo
ool40:ZZZP`0EEEE1?ooool405EEE@D00000201EEED8ooooo`@0ZZZZ101EEED40:ZZZPP00000101E
EED4ooooo`@00000102ZZZX4ooooo`@0EEEE1?ooool40:ZZZP@0EEEE202ZZZX4000000@0ZZZZ2?oo
ool8000000@0ZZZZ1?ooool405EEE@Cooooo101EEED<0:ZZZP@0EEEE2Oooool405EEE@Cooooo1000
0004ooooo`@0EEEE2?ooool405EEE@`0ZZZZ101EEED4ooooo`@0EEEE1?ooool40:ZZZPP000002?oo
ool40:ZZZP@00000202ZZZX405EEE@@0ZZZZ1?ooool405EEE@Cooooo102ZZZX4000000Cooooo101E
EED9000000@0ZZZZ101EEED40:ZZZPSooooo201EEED4000000@0EEEE1?ooool<05EEE@@0ZZZZ1?oo
ool80:ZZZPSooooo9`3AcJT002H0dLfY2?ooool80:ZZZPCooooo102ZZZX<05EEE@Cooooo101EEED5
000000P0EEEE2?ooool40:ZZZP@0EEEE102ZZZX8000000@0EEEE1?ooool4000000@0ZZZZ1?ooool4
05EEE@Cooooo102ZZZX405EEE@P0ZZZZ100000040:ZZZPSooooo200000040:ZZZPCooooo101EEED4
ooooo`@0EEEE302ZZZX405EEE@Wooooo101EEED4ooooo`@000001?ooool405EEE@Sooooo101EEED<
0:ZZZP@0EEEE1?ooool405EEE@Cooooo102ZZZX8000000Sooooo102ZZZX4000000P0ZZZZ101EEED4
0:ZZZPCooooo101EEED4ooooo`@0ZZZZ10000004ooooo`@0EEEE2@0000040:ZZZP@0EEEE102ZZZX8
ooooo`P0EEEE1000000405EEE@Cooooo301EEED40:ZZZPCooooo202ZZZX8ooooobL0dLfY000V0=7=
Z@Sooooo202ZZZX4ooooo`@0ZZZZ301EEED4ooooo`@0EEEE1@00000805EEE@Sooooo102ZZZX405EE
E@@0ZZZZ2000000405EEE@Cooooo100000040:ZZZPCooooo101EEED4ooooo`@0ZZZZ101EEED80:ZZ
ZP@00000102ZZZX8ooooo`P00000102ZZZX4ooooo`@0EEEE1?ooool405EEE@`0ZZZZ101EEED9oooo
o`@0EEEE1?ooool4000000Cooooo101EEED8ooooo`@0EEEE302ZZZX405EEE@Cooooo101EEED4oooo
o`@0ZZZZ20000008ooooo`@0ZZZZ100000080:ZZZP@0EEEE102ZZZX4ooooo`@0EEEE1?ooool40:ZZ
ZP@000001?ooool405EEE@T00000102ZZZX405EEE@@0ZZZZ2?ooool805EEE@@00000101EEED4oooo
o``0EEEE102ZZZX4ooooo`P0ZZZZ2?oooolW0=7=Z@009P3AcJT<ooooo`@0ZZZZ1?ooool4000000P0
EEEE1000000405EEE@@000001@1EEED40:ZZZPCooooo201EEED4ooooo`@000001?ooool405EEE@So
oooo100000040:ZZZPP0EEEE1?ooool40:ZZZP@00000102ZZZX4000000P0ZZZZ4?ooool405EEE@Co
oooo100000040:ZZZP@000002?ooool40:ZZZPSooooo1@0000040:ZZZPCooooo301EEED4ooooo`@0
ZZZZ10000008ooooo`@0ZZZZ2?ooool4000000@0ZZZZ10000004ooooo`@0EEEE4?ooool80:ZZZP@0
0000102ZZZX4000000@0ZZZZ1?ooool805EEE@@0ZZZZ10000009ooooo`@0EEEE1?ooool4000000Co
oooo201EEED4ooooo`@0ZZZZ101EEED4000000@0EEEE1000000805EEE@@000001?ooool40:ZZZPco
oooo9`3AcJT002H0dLfY3?ooool40:ZZZPCooooo1000000805EEE@@00000101EEED4000000D0EEEE
102ZZZX4ooooo`P0EEEE1?ooool4000000Cooooo101EEED8ooooo`@00000102ZZZX805EEE@Cooooo
102ZZZX4000000@0ZZZZ100000080:ZZZQ3ooooo101EEED4ooooo`@00000102ZZZX4000000Sooooo
102ZZZX8ooooo`D00000102ZZZX4ooooo``0EEEE1?ooool40:ZZZP@000002?ooool40:ZZZPSooooo
100000040:ZZZP@000001?ooool405EEEA3ooooo202ZZZX4000000@0ZZZZ100000040:ZZZPCooooo
201EEED40:ZZZP@000002Oooool405EEE@Cooooo10000004ooooo`P0EEEE1?ooool40:ZZZP@0EEEE
1000000405EEE@@00000201EEED4000000Cooooo102ZZZX<ooooobL0dLfY000V0=7=Z@cooooo102Z
ZZX4ooooo`@00000201EEED4000000@0EEEE1000000505EEE@@0ZZZZ1?ooool805EEE@Cooooo1000
0004ooooo`@0EEEE2?ooool4000000@0ZZZZ201EEED4ooooo`@0ZZZZ100000040:ZZZP@00000202Z
ZZX@ooooo`@0EEEE1?ooool4000000@0ZZZZ10000008ooooo`@0ZZZZ2?ooool5000000@0ZZZZ1?oo
ool<05EEE@Cooooo102ZZZX4000000Sooooo102ZZZX8ooooo`@00000102ZZZX4000000Cooooo101E
EED@ooooo`P0ZZZZ100000040:ZZZP@00000102ZZZX4ooooo`P0EEEE102ZZZX4000000Wooooo101E
EED4ooooo`@000001?ooool805EEE@Cooooo102ZZZX405EEE@@00000101EEED4000000P0EEEE1000
0004ooooo`@0ZZZZ3?oooolW0=7=Z@009P3AcJT<ooooo`@0ZZZZ1?ooool4000000P0EEEE10000004
05EEE@@000001@1EEED40:ZZZPCooooo201EEED4ooooo`@000001?ooool405EEE@Sooooo10000004
0:ZZZPP0EEEE1?ooool40:ZZZP@00000102ZZZX4000000P0ZZZZ4?ooool405EEE@Cooooo10000004
0:ZZZP@000002?ooool40:ZZZPSooooo1@0000040:ZZZPCooooo301EEED4ooooo`@0ZZZZ10000008
ooooo`@0ZZZZ2?ooool4000000@0ZZZZ10000004ooooo`@0EEEE4?ooool80:ZZZP@00000102ZZZX4
000000@0ZZZZ1?ooool805EEE@@0ZZZZ10000009ooooo`@0EEEE1?ooool4000000Cooooo201EEED4
ooooo`@0ZZZZ101EEED4000000@0EEEE1000000805EEE@@000001?ooool40:ZZZPcooooo9`3AcJT0
02H0dLfY4?ooool40:ZZZP@00000201EEED4000000@0ZZZZ1000000905EEEA00ZZZZ101EEED80000
00@0ZZZZ1?ooool<000000@0ZZZZ10000004ooooo`@0EEEE1?ooool@000000@0EEEE2000000805EE
E@Sooooo202ZZZX405EEE@@0ZZZZ101EEED90:ZZZPcooooo1000000<ooooo`P0ZZZZ101EEED40:ZZ
ZP@0EEEE202ZZZX8ooooo`P0EEEE2000000405EEEA0000001?ooool405EEE@Cooooo100000040:ZZ
ZP`000001?ooool50:ZZZPP00000101EEED@0:ZZZPP0EEEE100000040:ZZZP@00000201EEED40000
00@0ZZZZ4?oooolW0=7=Z@009P3AcJT@ooooo`@0ZZZZ1000000805EEE@@00000102ZZZX4000000T0
EEEE402ZZZX405EEE@P00000102ZZZX4ooooo``00000102ZZZX4000000Cooooo101EEED4oooooa00
0000101EEED8000000P0EEEE2?ooool80:ZZZP@0EEEE102ZZZX405EEE@T0ZZZZ3?ooool4000000co
oooo202ZZZX405EEE@@0ZZZZ101EEED80:ZZZPSooooo201EEED8000000@0EEEE40000004ooooo`@0
EEEE1?ooool4000000@0ZZZZ30000004ooooo`D0ZZZZ2000000405EEEA00ZZZZ201EEED4000000@0
ZZZZ1000000805EEE@@00000102ZZZX@ooooobL0dLfY000V0=7=ZA3ooooo102ZZZX4000000P0EEEE
100000040:ZZZP@000002@1EEED@0:ZZZP@0EEEE200000040:ZZZPCooooo300000040:ZZZP@00000
1?ooool405EEE@Cooooo4000000405EEE@P00000201EEED8ooooo`P0ZZZZ101EEED40:ZZZP@0EEEE
2@2ZZZX<ooooo`@000003?ooool80:ZZZP@0EEEE102ZZZX405EEE@P0ZZZZ2?ooool805EEE@P00000
101EEED@000000Cooooo101EEED4ooooo`@00000102ZZZX<000000Cooooo1@2ZZZX8000000@0EEEE
402ZZZX805EEE@@00000102ZZZX4000000P0EEEE100000040:ZZZQ3ooooo9`3AcJT002H0dLfY4?oo
ool40:ZZZP@00000201EEED4000000@0ZZZZ1000000905EEEA00ZZZZ101EEED8000000@0ZZZZ1?oo
ool<000000@0ZZZZ10000004ooooo`@0EEEE1?ooool@000000@0EEEE2000000805EEE@Sooooo202Z
ZZX405EEE@@0ZZZZ101EEED90:ZZZPcooooo1000000<ooooo`P0ZZZZ101EEED40:ZZZP@0EEEE202Z
ZZX8ooooo`P0EEEE2000000405EEEA0000001?ooool405EEE@Cooooo100000040:ZZZP`000001?oo
ool50:ZZZPP00000101EEED@0:ZZZPP0EEEE100000040:ZZZP@00000201EEED4000000@0ZZZZ4?oo
oolW0=7=Z@009P3AcJTDoooooa00ZZZZ2?ooool505EEE@@0ZZZZ2?ooool40:ZZZPSooooo20000004
oooooa@0EEEE102ZZZX4000000cooooo101EEED8ooooo`@0EEEE102ZZZX4000000P0EEEE20000004
05EEE@Cooooo10000004ooooo`@0EEEE102ZZZX905EEE@Cooooo301EEED4ooooo`P0EEEE102ZZZX4
05EEE@Cooooo10000004ooooo`@0EEEE2000000805EEE@@00000102ZZZX405EEE@Sooooo101EEED<
ooooo`@00000102ZZZXD05EEE@Gooooo20000008ooooo`@0ZZZZ2?ooool40:ZZZP@0EEEE2?ooool@
0:ZZZQCooooo9`3AcJT002H0dLfY5?ooool@0:ZZZPSooooo1@1EEED40:ZZZPSooooo102ZZZX8oooo
o`P000001?oooolD05EEE@@0ZZZZ1000000<ooooo`@0EEEE2?ooool405EEE@@0ZZZZ1000000805EE
E@P00000101EEED4ooooo`@000001?ooool405EEE@@0ZZZZ2@1EEED4ooooo``0EEEE1?ooool805EE
E@@0ZZZZ101EEED4ooooo`@000001?ooool405EEE@P00000201EEED4000000@0ZZZZ101EEED8oooo
o`@0EEEE3?ooool4000000@0ZZZZ501EEED5ooooo`P000002?ooool40:ZZZPSooooo102ZZZX405EE
E@Sooooo402ZZZXDooooobL0dLfY000V0=7=ZACooooo402ZZZX8ooooo`D0EEEE102ZZZX8ooooo`@0
ZZZZ2?ooool8000000Cooooo501EEED40:ZZZP@000003?ooool405EEE@Sooooo101EEED40:ZZZP@0
0000201EEED8000000@0EEEE1?ooool4000000Cooooo101EEED40:ZZZPT0EEEE1?ooool<05EEE@Co
oooo201EEED40:ZZZP@0EEEE1?ooool4000000Cooooo101EEED8000000P0EEEE100000040:ZZZP@0
EEEE2?ooool405EEE@cooooo100000040:ZZZQ@0EEEE1Oooool8000000Sooooo102ZZZX8ooooo`@0
ZZZZ101EEED8oooooa00ZZZZ5?oooolW0=7=Z@009P3AcJTDoooooa00ZZZZ2?ooool505EEE@@0ZZZZ
2?ooool40:ZZZPSooooo20000004oooooa@0EEEE102ZZZX4000000cooooo101EEED8ooooo`@0EEEE
102ZZZX4000000P0EEEE2000000405EEE@Cooooo10000004ooooo`@0EEEE102ZZZX905EEE@Cooooo
301EEED4ooooo`P0EEEE102ZZZX405EEE@Cooooo10000004ooooo`@0EEEE2000000805EEE@@00000
102ZZZX405EEE@Sooooo101EEED<ooooo`@00000102ZZZXD05EEE@Gooooo20000008ooooo`@0ZZZZ
2?ooool40:ZZZP@0EEEE2?ooool@0:ZZZQCooooo9`3AcJT002H0dLfY6?ooool40:ZZZPSooooo102Z
ZZX4000000Wooooo102ZZZX4000000Cooooo201EEED8ooooo`P0EEEE1000000805EEE@@00000101E
EEDDooooo`@00000102ZZZX4ooooo`@0EEEE100000040:ZZZPP000001?ooool4000000Cooooo202Z
ZZX405EEE@Cooooo1@00000<ooooo`@000003?ooool4000000Cooooo101EEED80:ZZZPCooooo1000
0004ooooo`P00000102ZZZX4000000@0EEEE1?ooool40:ZZZP@000005?ooool405EEE@@00000201E
EED4000000T0EEEE2?ooool805EEE@Cooooo100000040:ZZZPSooooo100000040:ZZZPSooooo102Z
ZZXHooooobL0dLfY000V0=7=ZASooooo102ZZZX8ooooo`@0ZZZZ10000009ooooo`@0ZZZZ10000004
ooooo`P0EEEE2?ooool805EEE@@00000201EEED4000000@0EEEE5?ooool4000000@0ZZZZ1?ooool4
05EEE@@00000102ZZZX8000000Cooooo10000004ooooo`P0ZZZZ101EEED4ooooo`D000003?ooool4
000000cooooo10000004ooooo`@0EEEE202ZZZX4ooooo`@000001?ooool8000000@0ZZZZ10000004
05EEE@Cooooo102ZZZX4000001Cooooo101EEED4000000P0EEEE1000000905EEE@Sooooo201EEED4
ooooo`@00000102ZZZX8ooooo`@00000102ZZZX8ooooo`@0ZZZZ6?oooolW0=7=Z@009P3AcJTHoooo
o`@0ZZZZ2?ooool40:ZZZP@000002Oooool40:ZZZP@000001?ooool805EEE@Sooooo201EEED40000
00P0EEEE1000000405EEEACooooo100000040:ZZZPCooooo101EEED4000000@0ZZZZ20000004oooo
o`@000001?ooool80:ZZZP@0EEEE1?ooool5000000cooooo1000000<ooooo`@000001?ooool405EE
E@P0ZZZZ1?ooool4000000Cooooo200000040:ZZZP@00000101EEED4ooooo`@0ZZZZ1000000Doooo
o`@0EEEE1000000805EEE@@000002@1EEED8ooooo`P0EEEE1?ooool4000000@0ZZZZ2?ooool40000
00@0ZZZZ2?ooool40:ZZZQSooooo9`3AcJT002H0dLfY6?ooool40:ZZZPSooooo102ZZZX4000000Wo
oooo102ZZZX4000000Cooooo201EEED8ooooo`P0EEEE1000000805EEE@@00000101EEEDDooooo`@0
0000102ZZZX4ooooo`@0EEEE100000040:ZZZPP000001?ooool4000000Cooooo202ZZZX405EEE@Co
oooo1@00000<ooooo`@000003?ooool4000000Cooooo101EEED80:ZZZPCooooo10000004ooooo`P0
0000102ZZZX4000000@0EEEE1?ooool40:ZZZP@000005?ooool405EEE@@00000201EEED4000000T0
EEEE2?ooool805EEE@Cooooo100000040:ZZZPSooooo100000040:ZZZPSooooo102ZZZXHooooobL0
dLfY000V0=7=ZAcooooo102ZZZX4000000Cooooo101EEED5ooooo`P0EEEE102ZZZX4000000Sooooo
100000040:ZZZPCooooo101EEED40:ZZZPP00000102ZZZX405EEE@Cooooo201EEED4ooooo``0EEEE
302ZZZX8ooooo`@0EEEE1?ooool405EEE@Cooooo101EEED4000000gooooo201EEED4ooooo`@0EEEE
1?ooool805EEE@cooooo1000000405EEE@Cooooo101EEED4ooooo`@0EEEE2?ooool<0:ZZZP`0EEEE
1?ooool805EEE@Cooooo101EEED40:ZZZPP00000102ZZZX405EEE@Gooooo102ZZZX4000000Sooooo
100000040:ZZZPP0EEEE1?ooool405EEE@Cooooo100000040:ZZZQcooooo9`3AcJT002H0dLfY7?oo
ool40:ZZZP@000001?ooool405EEE@Gooooo201EEED40:ZZZP@000002?ooool4000000@0ZZZZ1?oo
ool405EEE@@0ZZZZ200000040:ZZZP@0EEEE1?ooool805EEE@Cooooo301EEED<0:ZZZPSooooo101E
EED4ooooo`@0EEEE1?ooool405EEE@@000003Oooool805EEE@Cooooo101EEED4ooooo`P0EEEE3?oo
ool4000000@0EEEE1?ooool405EEE@Cooooo101EEED8ooooo``0ZZZZ301EEED4ooooo`P0EEEE1?oo
ool405EEE@@0ZZZZ200000040:ZZZP@0EEEE1Oooool40:ZZZP@000002?ooool4000000@0ZZZZ201E
EED4ooooo`@0EEEE1?ooool4000000@0ZZZZ7?oooolW0=7=Z@009P3AcJTLooooo`@0ZZZZ10000004
ooooo`@0EEEE1Oooool805EEE@@0ZZZZ10000008ooooo`@00000102ZZZX4ooooo`@0EEEE102ZZZX8
000000@0ZZZZ101EEED4ooooo`P0EEEE1?ooool<05EEE@`0ZZZZ2?ooool405EEE@Cooooo101EEED4
ooooo`@0EEEE1000000=ooooo`P0EEEE1?ooool405EEE@Cooooo201EEED<ooooo`@00000101EEED4
ooooo`@0EEEE1?ooool405EEE@Sooooo302ZZZX<05EEE@Cooooo201EEED4ooooo`@0EEEE102ZZZX8
000000@0ZZZZ101EEED5ooooo`@0ZZZZ10000008ooooo`@00000102ZZZX805EEE@Cooooo101EEED4
ooooo`@00000102ZZZXLooooobL0dLfY000V0=7=ZAcooooo102ZZZX4000000Cooooo101EEED5oooo
o`P0EEEE102ZZZX4000000Sooooo100000040:ZZZPCooooo101EEED40:ZZZPP00000102ZZZX405EE
E@Cooooo201EEED4ooooo``0EEEE302ZZZX8ooooo`@0EEEE1?ooool405EEE@Cooooo101EEED40000
00gooooo201EEED4ooooo`@0EEEE1?ooool805EEE@cooooo1000000405EEE@Cooooo101EEED4oooo
o`@0EEEE2?ooool<0:ZZZP`0EEEE1?ooool805EEE@Cooooo101EEED40:ZZZPP00000102ZZZX405EE
E@Gooooo102ZZZX4000000Sooooo100000040:ZZZPP0EEEE1?ooool405EEE@Cooooo100000040:ZZ
ZQcooooo9`3AcJT002H0dLfY8?ooool80:ZZZP@0EEEE1Oooool405EEE@@0ZZZZ2?ooool805EEE@So
oooo102ZZZX<000000Cooooo1000000805EEE@Cooooo102ZZZX405EEE@@0ZZZZ1?ooool405EEE@@0
ZZZZ201EEED80:ZZZP@0EEEE1?ooool405EEE@`0ZZZZ1?ooool4000000D0ZZZZ1?ooool405EEE@`0
ZZZZ101EEED4ooooo`@0ZZZZ10000004ooooo``0ZZZZ101EEED4ooooo`@0EEEE202ZZZX805EEE@@0
ZZZZ101EEED4ooooo`@0ZZZZ101EEED40:ZZZPCooooo201EEED4000000Cooooo300000050:ZZZPSo
oooo201EEED8ooooo`@0ZZZZ101EEED4ooooo`@0EEEE202ZZZXPooooobL0dLfY000V0=7=ZB3ooooo
202ZZZX405EEE@Gooooo101EEED40:ZZZPSooooo201EEED8ooooo`@0ZZZZ30000004ooooo`@00000
201EEED4ooooo`@0ZZZZ101EEED40:ZZZPCooooo101EEED40:ZZZPP0EEEE202ZZZX405EEE@Cooooo
101EEED<0:ZZZPCooooo100000050:ZZZPCooooo101EEED<0:ZZZP@0EEEE1?ooool40:ZZZP@00000
1?ooool<0:ZZZP@0EEEE1?ooool405EEE@P0ZZZZ201EEED40:ZZZP@0EEEE1?ooool40:ZZZP@0EEEE
102ZZZX4ooooo`P0EEEE10000004ooooo``000001@2ZZZX8ooooo`P0EEEE2?ooool40:ZZZP@0EEEE
1?ooool405EEE@P0ZZZZ8?oooolW0=7=Z@009P3AcJTPooooo`P0ZZZZ101EEED5ooooo`@0EEEE102Z
ZZX8ooooo`P0EEEE2?ooool40:ZZZP`000001?ooool4000000P0EEEE1?ooool40:ZZZP@0EEEE102Z
ZZX4ooooo`@0EEEE102ZZZX805EEE@P0ZZZZ101EEED4ooooo`@0EEEE302ZZZX4ooooo`@000001@2Z
ZZX4ooooo`@0EEEE302ZZZX405EEE@Cooooo102ZZZX4000000Cooooo302ZZZX405EEE@Cooooo101E
EED80:ZZZPP0EEEE102ZZZX405EEE@Cooooo102ZZZX405EEE@@0ZZZZ1?ooool805EEE@@000001?oo
ool<000000D0ZZZZ2?ooool805EEE@Sooooo102ZZZX405EEE@Cooooo101EEED80:ZZZR3ooooo9`3A
cJT002H0dLfY8?ooool80:ZZZP@0EEEE1Oooool405EEE@@0ZZZZ2?ooool805EEE@Sooooo102ZZZX<
000000Cooooo1000000805EEE@Cooooo102ZZZX405EEE@@0ZZZZ1?ooool405EEE@@0ZZZZ201EEED8
0:ZZZP@0EEEE1?ooool405EEE@`0ZZZZ1?ooool4000000D0ZZZZ1?ooool405EEE@`0ZZZZ101EEED4
ooooo`@0ZZZZ10000004ooooo``0ZZZZ101EEED4ooooo`@0EEEE202ZZZX805EEE@@0ZZZZ101EEED4
ooooo`@0ZZZZ101EEED40:ZZZPCooooo201EEED4000000Cooooo300000050:ZZZPSooooo201EEED8
ooooo`@0ZZZZ101EEED4ooooo`@0EEEE202ZZZXPooooobL0dLfY000V0=7=ZBCooooo102ZZZX4oooo
o`T0EEEE10000004ooooo`@0ZZZZ200000040:ZZZPCooooo1000000405EEE@@0ZZZZ1000000405EE
E@@00000102ZZZX8000000@0EEEE1?ooool40:ZZZPCooooo10000004ooooo`@0EEEE102ZZZX8oooo
o`@0ZZZZ101EEED40:ZZZPSooooo102ZZZX4ooooo`d00000201EEED40:ZZZPP0EEEE30000004oooo
o`@0ZZZZ2?ooool40:ZZZP@0EEEE102ZZZX8ooooo`@0ZZZZ101EEED4ooooo`@000001?ooool40:ZZ
ZPCooooo101EEED8000000@0ZZZZ1000000405EEE@@00000102ZZZX405EEE@D000001?ooool40:ZZ
ZPP00000102ZZZX4ooooo`@00000201EEED4ooooo`@0ZZZZ9?oooolW0=7=Z@009P3AcJTTooooo`@0
ZZZZ1?ooool905EEE@@000001?ooool40:ZZZPP00000102ZZZX4ooooo`@00000101EEED40:ZZZP@0
0000101EEED4000000@0ZZZZ2000000405EEE@Cooooo102ZZZX4ooooo`@000001?ooool405EEE@@0
ZZZZ2?ooool40:ZZZP@0EEEE102ZZZX8ooooo`@0ZZZZ1?ooool=000000P0EEEE102ZZZX805EEE@`0
00001?ooool40:ZZZPSooooo102ZZZX405EEE@@0ZZZZ2?ooool40:ZZZP@0EEEE1?ooool4000000Co
oooo102ZZZX4ooooo`@0EEEE200000040:ZZZP@00000101EEED4000000@0ZZZZ101EEED5000000Co
oooo102ZZZX8000000@0ZZZZ1?ooool4000000P0EEEE1?ooool40:ZZZRCooooo9`3AcJT002H0dLfY
9?ooool40:ZZZPCooooo2@1EEED4000000Cooooo102ZZZX8000000@0ZZZZ1?ooool4000000@0EEEE
102ZZZX4000000@0EEEE100000040:ZZZPP00000101EEED4ooooo`@0ZZZZ1?ooool4000000Cooooo
101EEED40:ZZZPSooooo102ZZZX405EEE@@0ZZZZ2?ooool40:ZZZPCooooo3@00000805EEE@@0ZZZZ
201EEED<000000Cooooo102ZZZX8ooooo`@0ZZZZ101EEED40:ZZZPSooooo102ZZZX405EEE@Cooooo
10000004ooooo`@0ZZZZ1?ooool405EEE@P00000102ZZZX4000000@0EEEE100000040:ZZZP@0EEEE
1@000004ooooo`@0ZZZZ200000040:ZZZPCooooo1000000805EEE@Cooooo102ZZZXTooooobL0dLfY
000V0=7=ZBCooooo102ZZZX4ooooo`T0EEEE10000004ooooo`@0ZZZZ200000040:ZZZPCooooo1000
000405EEE@@0ZZZZ1000000405EEE@@00000102ZZZX8000000@0EEEE1?ooool40:ZZZPCooooo1000
0004ooooo`@0EEEE102ZZZX8ooooo`@0ZZZZ101EEED40:ZZZPSooooo102ZZZX4ooooo`d00000201E
EED40:ZZZPP0EEEE30000004ooooo`@0ZZZZ2?ooool40:ZZZP@0EEEE102ZZZX8ooooo`@0ZZZZ101E
EED4ooooo`@000001?ooool40:ZZZPCooooo101EEED8000000@0ZZZZ1000000405EEE@@00000102Z
ZZX405EEE@D000001?ooool40:ZZZPP00000102ZZZX4ooooo`@00000201EEED4ooooo`@0ZZZZ9?oo
oolW0=7=Z@009P3AcJTXooooo`@0ZZZZ2@0000040:ZZZP@0EEEE102ZZZX405EEE@@00000202ZZZX4
05EEE@@00000101EEED8ooooo``000001?ooool4000000Cooooo102ZZZX4ooooo`P00000201EEED8
0:ZZZPP0EEEE10000004ooooo`@0ZZZZ100000040:ZZZPCooooo2@2ZZZX4ooooo`@0EEEE102ZZZX4
05EEE@Cooooo202ZZZX4ooooo`@0ZZZZ100000040:ZZZPCooooo1000000805EEE@P0ZZZZ201EEED8
000000Cooooo102ZZZX4ooooo`@000001?ooool<000000Sooooo101EEED4000000D0EEEE202ZZZX4
000000@0EEEE102ZZZX405EEE@@0ZZZZ200000040:ZZZRSooooo9`3AcJT002H0dLfY:?ooool40:ZZ
ZPT00000102ZZZX405EEE@@0ZZZZ101EEED4000000P0ZZZZ101EEED4000000@0EEEE2?ooool<0000
00Cooooo10000004ooooo`@0ZZZZ1?ooool8000000P0EEEE202ZZZX805EEE@@000001?ooool40:ZZ
ZP@00000102ZZZX4ooooo`T0ZZZZ1?ooool405EEE@@0ZZZZ101EEED4ooooo`P0ZZZZ1?ooool40:ZZ
ZP@00000102ZZZX4ooooo`@00000201EEED80:ZZZPP0EEEE20000004ooooo`@0ZZZZ1?ooool40000
00Cooooo30000008ooooo`@0EEEE1000000505EEE@P0ZZZZ1000000405EEE@@0ZZZZ101EEED40:ZZ
ZPP00000102ZZZXXooooobL0dLfY000V0=7=ZBSooooo102ZZZX9000000@0ZZZZ101EEED40:ZZZP@0
EEEE100000080:ZZZP@0EEEE1000000405EEE@Sooooo30000004ooooo`@000001?ooool40:ZZZPCo
oooo2000000805EEE@P0ZZZZ201EEED4000000Cooooo102ZZZX4000000@0ZZZZ1?ooool90:ZZZPCo
oooo101EEED40:ZZZP@0EEEE1?ooool80:ZZZPCooooo102ZZZX4000000@0ZZZZ1?ooool4000000P0
EEEE202ZZZX805EEE@P000001?ooool40:ZZZPCooooo10000004ooooo``000002?ooool405EEE@@0
00001@1EEED80:ZZZP@00000101EEED40:ZZZP@0EEEE102ZZZX8000000@0ZZZZ:?oooolW0=7=Z@00
9P3AcJTXooooo`@0ZZZZ2@0000040:ZZZP@0EEEE102ZZZX405EEE@@00000202ZZZX405EEE@@00000
101EEED8ooooo``000001?ooool4000000Cooooo102ZZZX4ooooo`P00000201EEED80:ZZZPP0EEEE
10000004ooooo`@0ZZZZ100000040:ZZZPCooooo2@2ZZZX4ooooo`@0EEEE102ZZZX405EEE@Cooooo
202ZZZX4ooooo`@0ZZZZ100000040:ZZZPCooooo1000000805EEE@P0ZZZZ201EEED8000000Cooooo
102ZZZX4ooooo`@000001?ooool<000000Sooooo101EEED4000000D0EEEE202ZZZX4000000@0EEEE
102ZZZX405EEE@@0ZZZZ200000040:ZZZRSooooo9`3AcJT002H0dLfY;?ooool90:ZZZPSooooo1000
000<05EEE@@0ZZZZ101EEED8ooooo`@00000102ZZZX4ooooo`P0ZZZZ1?ooool8000000@0EEEE1?oo
ool405EEE@Sooooo10000004ooooo`@0EEEE1000000<05EEE@Cooooo3000000505EEE@Cooooo1000
00040:ZZZP@00000102ZZZX4000000Cooooo101EEED<000000Cooooo301EEED4000000@0EEEE1?oo
ool4000000Sooooo101EEED4ooooo`@0EEEE20000004ooooo`P0ZZZZ1?ooool40:ZZZP@000002?oo
ool505EEE@@0ZZZZ301EEED4000000Sooooo202ZZZX/ooooobL0dLfY000V0=7=ZBcooooo2@2ZZZX8
ooooo`@00000301EEED40:ZZZP@0EEEE2?ooool4000000@0ZZZZ1?ooool80:ZZZPCooooo20000004
05EEE@Cooooo101EEED8ooooo`@000001?ooool405EEE@@00000301EEED4ooooo``000001@1EEED4
ooooo`@00000102ZZZX4000000@0ZZZZ10000004ooooo`@0EEEE30000004ooooo``0EEEE10000004
05EEE@Cooooo10000008ooooo`@0EEEE1?ooool405EEE@P000001?ooool80:ZZZPCooooo102ZZZX4
000000Sooooo1@1EEED40:ZZZP`0EEEE10000008ooooo`P0ZZZZ;?oooolW0=7=Z@009P3AcJT/oooo
o`T0ZZZZ2?ooool4000000`0EEEE102ZZZX405EEE@Sooooo100000040:ZZZPCooooo202ZZZX4oooo
o`P00000101EEED4ooooo`@0EEEE2?ooool4000000Cooooo101EEED4000000`0EEEE1?ooool<0000
00D0EEEE1?ooool4000000@0ZZZZ100000040:ZZZP@000001?ooool405EEE@`000001?ooool<05EE
E@@00000101EEED4ooooo`@000002?ooool405EEE@Cooooo101EEED8000000Cooooo202ZZZX4oooo
o`@0ZZZZ10000008ooooo`D0EEEE102ZZZX<05EEE@@000002?ooool80:ZZZRcooooo9`3AcJT002H0
dLfY;?ooool90:ZZZPSooooo1000000<05EEE@@0ZZZZ101EEED8ooooo`@00000102ZZZX4ooooo`P0
ZZZZ1?ooool8000000@0EEEE1?ooool405EEE@Sooooo10000004ooooo`@0EEEE1000000<05EEE@Co
oooo3000000505EEE@Cooooo100000040:ZZZP@00000102ZZZX4000000Cooooo101EEED<000000Co
oooo301EEED4000000@0EEEE1?ooool4000000Sooooo101EEED4ooooo`@0EEEE20000004ooooo`P0
ZZZZ1?ooool40:ZZZP@000002?ooool505EEE@@0ZZZZ301EEED4000000Sooooo202ZZZX/ooooobL0
dLfY000V0=7=ZC7ooooo102ZZZX4ooooo`@00000102ZZZX405EEE@Cooooo102ZZZX805EEE@P00000
101EEED40:ZZZP@0EEEE102ZZZX805EEE@Sooooo101EEED<0:ZZZP@0EEEE102ZZZX4000000Sooooo
101EEED40:ZZZPCooooo5@1EEED8000000Cooooo101EEED4ooooo`P00000501EEED4ooooo`@0ZZZZ
101EEED8ooooo`@00000102ZZZX405EEE@`0ZZZZ101EEED8ooooo`P0EEEE102ZZZX405EEE@@0ZZZZ
101EEED8000000T0EEEE102ZZZX4ooooo`@0EEEE102ZZZX4000000Cooooo102ZZZX`ooooobL0dLfY
000V0=7=ZC7ooooo102ZZZX4ooooo`@00000102ZZZX405EEE@Cooooo102ZZZX805EEE@P00000101E
EED40:ZZZP@0EEEE102ZZZX805EEE@Sooooo101EEED<0:ZZZP@0EEEE102ZZZX4000000Sooooo101E
EED40:ZZZPCooooo5@1EEED8000000Cooooo101EEED4ooooo`P00000501EEED4ooooo`@0ZZZZ101E
EED8ooooo`@00000102ZZZX405EEE@`0ZZZZ101EEED8ooooo`P0EEEE102ZZZX405EEE@@0ZZZZ101E
EED8000000T0EEEE102ZZZX4ooooo`@0EEEE102ZZZX4000000Cooooo102ZZZX`ooooobL0dLfY000V
0=7=ZC7ooooo102ZZZX4ooooo`@00000102ZZZX405EEE@Cooooo102ZZZX805EEE@P00000101EEED4
0:ZZZP@0EEEE102ZZZX805EEE@Sooooo101EEED<0:ZZZP@0EEEE102ZZZX4000000Sooooo101EEED4
0:ZZZPCooooo5@1EEED8000000Cooooo101EEED4ooooo`P00000501EEED4ooooo`@0ZZZZ101EEED8
ooooo`@00000102ZZZX405EEE@`0ZZZZ101EEED8ooooo`P0EEEE102ZZZX405EEE@@0ZZZZ101EEED8
000000T0EEEE102ZZZX4ooooo`@0EEEE102ZZZX4000000Cooooo102ZZZX`ooooobL0dLfY000V0=7=
ZC7ooooo102ZZZX4ooooo`@00000102ZZZX405EEE@Cooooo102ZZZX805EEE@P00000101EEED40:ZZ
ZP@0EEEE102ZZZX805EEE@Sooooo101EEED<0:ZZZP@0EEEE102ZZZX4000000Sooooo101EEED40:ZZ
ZPCooooo5@1EEED8000000Cooooo101EEED4ooooo`P00000501EEED4ooooo`@0ZZZZ101EEED8oooo
o`@00000102ZZZX405EEE@`0ZZZZ101EEED8ooooo`P0EEEE102ZZZX405EEE@@0ZZZZ101EEED80000
00T0EEEE102ZZZX4ooooo`@0EEEE102ZZZX4000000Cooooo102ZZZX`ooooobL0dLfY000V0=7=ZCGo
oooo102ZZZX4000000@0EEEE1?ooool40:ZZZP@00000102ZZZX8000000Cooooo10000004ooooo`@0
EEEE102ZZZX405EEE@Cooooo102ZZZX4000000Sooooo102ZZZX8ooooo`@00000101EEED80:ZZZP@0
EEEE1?ooool4000000@0ZZZZ200000040:ZZZPT000001?ooool4000000@0ZZZZ10000004ooooo`P0
0000102ZZZX8000000@0ZZZZ10000004ooooo`@0EEEE202ZZZX405EEE@@000002?ooool40:ZZZPSo
oooo100000040:ZZZPCooooo101EEED40:ZZZP@0EEEE1?ooool4000000Cooooo2@0000040:ZZZP@0
0000102ZZZX4ooooo`@0EEEE100000040:ZZZSCooooo9`3AcJT002H0dLfY=Oooool40:ZZZP@00000
101EEED4ooooo`@0ZZZZ100000040:ZZZPP000001?ooool4000000Cooooo101EEED40:ZZZP@0EEEE
1?ooool40:ZZZP@000002?ooool40:ZZZPSooooo1000000405EEE@P0ZZZZ101EEED4ooooo`@00000
102ZZZX8000000@0ZZZZ2@000004ooooo`@00000102ZZZX4000000Cooooo200000040:ZZZPP00000
102ZZZX4000000Cooooo101EEED80:ZZZP@0EEEE10000008ooooo`@0ZZZZ2?ooool4000000@0ZZZZ
1?ooool405EEE@@0ZZZZ101EEED4ooooo`@000001?ooool9000000@0ZZZZ100000040:ZZZPCooooo
101EEED4000000@0ZZZZ=?oooolW0=7=Z@009P3AcJTeooooo`@0ZZZZ1000000405EEE@Cooooo102Z
ZZX4000000@0ZZZZ20000004ooooo`@000001?ooool405EEE@@0ZZZZ101EEED4ooooo`@0ZZZZ1000
0008ooooo`@0ZZZZ2?ooool4000000@0EEEE202ZZZX405EEE@Cooooo100000040:ZZZPP00000102Z
ZZX9000000Cooooo100000040:ZZZP@000001?ooool8000000@0ZZZZ200000040:ZZZP@000001?oo
ool405EEE@P0ZZZZ101EEED4000000Sooooo102ZZZX8ooooo`@00000102ZZZX4ooooo`@0EEEE102Z
ZZX405EEE@Cooooo10000004ooooo`T00000102ZZZX4000000@0ZZZZ1?ooool405EEE@@00000102Z
ZZXdooooobL0dLfY000V0=7=ZCGooooo102ZZZX4000000@0EEEE1?ooool40:ZZZP@00000102ZZZX8
000000Cooooo10000004ooooo`@0EEEE102ZZZX405EEE@Cooooo102ZZZX4000000Sooooo102ZZZX8
ooooo`@00000101EEED80:ZZZP@0EEEE1?ooool4000000@0ZZZZ200000040:ZZZPT000001?ooool4
000000@0ZZZZ10000004ooooo`P00000102ZZZX8000000@0ZZZZ10000004ooooo`@0EEEE202ZZZX4
05EEE@@000002?ooool40:ZZZPSooooo100000040:ZZZPCooooo101EEED40:ZZZP@0EEEE1?ooool4
000000Cooooo2@0000040:ZZZP@00000102ZZZX4ooooo`@0EEEE100000040:ZZZSCooooo9`3AcJT0
02H0dLfY>Oooool<0:ZZZP`0EEEE102ZZZX4000000@0EEEE100000040:ZZZPCooooo101EEED40000
00@0EEEE10000004ooooo`@00000102ZZZX@ooooo`@0EEEE102ZZZX805EEE@P000001?ooool405EE
E@Sooooo2@2ZZZX4ooooo``000001?ooool80:ZZZPSooooo101EEED4ooooo`P00000201EEED40:ZZ
ZP@0EEEE4?ooool40:ZZZP@000001?ooool4000000@0EEEE1000000405EEE@Cooooo102ZZZX40000
00@0EEEE100000050:ZZZP`0EEEE302ZZZXhooooobL0dLfY000V0=7=ZCWooooo302ZZZX<05EEE@@0
ZZZZ1000000405EEE@@00000102ZZZX4ooooo`@0EEEE1000000405EEE@@000001?ooool4000000@0
ZZZZ4?ooool405EEE@@0ZZZZ201EEED8000000Cooooo101EEED8ooooo`T0ZZZZ1?ooool<000000Co
oooo202ZZZX8ooooo`@0EEEE1?ooool8000000P0EEEE102ZZZX405EEEA3ooooo102ZZZX4000000Co
oooo1000000405EEE@@00000101EEED4ooooo`@0ZZZZ1000000405EEE@@000001@2ZZZX<05EEE@`0
ZZZZ>?oooolW0=7=Z@009P3AcJTiooooo``0ZZZZ301EEED40:ZZZP@00000101EEED4000000@0ZZZZ
1?ooool405EEE@@00000101EEED4000000Cooooo100000040:ZZZQ3ooooo101EEED40:ZZZPP0EEEE
20000004ooooo`@0EEEE2?ooool90:ZZZPCooooo30000004ooooo`P0ZZZZ2?ooool405EEE@Cooooo
2000000805EEE@@0ZZZZ101EEED@ooooo`@0ZZZZ10000004ooooo`@00000101EEED4000000@0EEEE
1?ooool40:ZZZP@00000101EEED4000000D0ZZZZ301EEED<0:ZZZSSooooo9`3AcJT002H0dLfY>Ooo
ool<0:ZZZP`0EEEE102ZZZX4000000@0EEEE100000040:ZZZPCooooo101EEED4000000@0EEEE1000
0004ooooo`@00000102ZZZX@ooooo`@0EEEE102ZZZX805EEE@P000001?ooool405EEE@Sooooo2@2Z
ZZX4ooooo``000001?ooool80:ZZZPSooooo101EEED4ooooo`P00000201EEED40:ZZZP@0EEEE4?oo
ool40:ZZZP@000001?ooool4000000@0EEEE1000000405EEE@Cooooo102ZZZX4000000@0EEEE1000
00050:ZZZP`0EEEE302ZZZXhooooobL0dLfY000V0=7=ZCgooooo102ZZZX8ooooo`@000002?ooool<
0:ZZZPcooooo200000040:ZZZP@0EEEE102ZZZX4000000@0ZZZZ1?ooool4000000@0ZZZZ1?ooool4
05EEE@@00000401EEED4ooooo`@0ZZZZ10000005ooooo`@0EEEE20000004ooooo`P00000101EEED4
ooooo`@00000102ZZZX4oooooa00EEEE1000000405EEE@Cooooo102ZZZX4000000Cooooo102ZZZX4
000000@0ZZZZ101EEED40:ZZZPP000003?ooool<0:ZZZPWooooo10000008ooooo`@0ZZZZ??oooolW
0=7=Z@009P3AcJTmooooo`@0ZZZZ2?ooool4000000Sooooo302ZZZX<ooooo`P00000102ZZZX405EE
E@@0ZZZZ100000040:ZZZPCooooo100000040:ZZZPCooooo101EEED400000100EEEE1?ooool40:ZZ
ZP@000001Oooool405EEE@P000001?ooool8000000@0EEEE1?ooool4000000@0ZZZZ1?ooool@05EE
E@@00000101EEED4ooooo`@0ZZZZ10000004ooooo`@0ZZZZ100000040:ZZZP@0EEEE102ZZZX80000
00cooooo302ZZZX9ooooo`@000002?ooool40:ZZZScooooo9`3AcJT002H0dLfY?Oooool40:ZZZPSo
oooo10000008ooooo``0ZZZZ3?ooool8000000@0ZZZZ101EEED40:ZZZP@00000102ZZZX4ooooo`@0
0000102ZZZX4ooooo`@0EEEE1000000@05EEE@Cooooo102ZZZX4000000Gooooo101EEED8000000Co
oooo2000000405EEE@Cooooo100000040:ZZZPCooooo401EEED4000000@0EEEE1?ooool40:ZZZP@0
00001?ooool40:ZZZP@00000102ZZZX405EEE@@0ZZZZ2000000<ooooo``0ZZZZ2Oooool4000000So
oooo102ZZZXlooooobL0dLfY000V0=7=ZCgooooo102ZZZX8ooooo`@000002?ooool<0:ZZZPcooooo
200000040:ZZZP@0EEEE102ZZZX4000000@0ZZZZ1?ooool4000000@0ZZZZ1?ooool405EEE@@00000
401EEED4ooooo`@0ZZZZ10000005ooooo`@0EEEE20000004ooooo`P00000101EEED4ooooo`@00000
102ZZZX4oooooa00EEEE1000000405EEE@Cooooo102ZZZX4000000Cooooo102ZZZX4000000@0ZZZZ
101EEED40:ZZZPP000003?ooool<0:ZZZPWooooo10000008ooooo`@0ZZZZ??oooolW0=7=Z@009P3A
cJU1ooooo`@0ZZZZ10000004ooooo`@00000102ZZZX8ooooo`@0ZZZZ1?ooool4000000@0ZZZZ1?oo
ool80:ZZZP`000001?ooool<05EEE@`0ZZZZ1?ooool405EEE@@0ZZZZ1?ooool805EEE@@0ZZZZ1@00
0008ooooo`@0EEEE1?ooool405EEE@Sooooo100000040:ZZZPP0EEEE1?ooool40:ZZZP@0EEEE1?oo
ool<0:ZZZP`0EEEE1?ooool<000000P0ZZZZ1?ooool40:ZZZP@000001?ooool40:ZZZPSooooo1@2Z
ZZX4000000Cooooo100000040:ZZZT3ooooo9`3AcJT002H0dLfY@Oooool40:ZZZP@000001?ooool4
000000@0ZZZZ2?ooool40:ZZZPCooooo100000040:ZZZPCooooo202ZZZX<000000Cooooo301EEED<
0:ZZZPCooooo101EEED40:ZZZPCooooo201EEED40:ZZZPD000002?ooool405EEE@Cooooo101EEED8
ooooo`@00000102ZZZX805EEE@Cooooo102ZZZX405EEE@Cooooo302ZZZX<05EEE@Cooooo30000008
0:ZZZPCooooo102ZZZX4000000Cooooo102ZZZX8ooooo`D0ZZZZ10000004ooooo`@00000102ZZZY0
ooooobL0dLfY000V0=7=ZD7ooooo102ZZZX4000000Cooooo100000040:ZZZPSooooo102ZZZX4oooo
o`@00000102ZZZX4ooooo`P0ZZZZ30000004ooooo``0EEEE302ZZZX4ooooo`@0EEEE102ZZZX4oooo
o`P0EEEE102ZZZX5000000Sooooo101EEED4ooooo`@0EEEE2?ooool4000000@0ZZZZ201EEED4oooo
o`@0ZZZZ101EEED4ooooo``0ZZZZ301EEED4ooooo``00000202ZZZX4ooooo`@0ZZZZ10000004oooo
o`@0ZZZZ2?ooool50:ZZZP@000001?ooool4000000@0ZZZZ@?oooolW0=7=Z@009P3AcJU1ooooo`@0
ZZZZ10000004ooooo`@00000102ZZZX8ooooo`@0ZZZZ1?ooool4000000@0ZZZZ1?ooool80:ZZZP`0
00001?ooool<05EEE@`0ZZZZ1?ooool405EEE@@0ZZZZ1?ooool805EEE@@0ZZZZ1@000008ooooo`@0
EEEE1?ooool405EEE@Sooooo100000040:ZZZPP0EEEE1?ooool40:ZZZP@0EEEE1?ooool<0:ZZZP`0
EEEE1?ooool<000000P0ZZZZ1?ooool40:ZZZP@000001?ooool40:ZZZPSooooo1@2ZZZX4000000Co
oooo100000040:ZZZT3ooooo9`3AcJT002H0dLfYAOooool80:ZZZP@0EEEE10000004ooooo`@0ZZZZ
100000040:ZZZPCooooo102ZZZX4ooooo`@00000101EEED8ooooo`@0EEEE1?ooool405EEE@@0ZZZZ
1?ooool405EEE@@000001?ooool805EEE@@000001?ooool40:ZZZP@0EEEE1?ooool9000000@0EEEE
1000000405EEE@@00000101EEED8000000Cooooo101EEED40:ZZZPCooooo1000000805EEE@Cooooo
1000000405EEE@Cooooo102ZZZX405EEE@Cooooo101EEED8ooooo`@0EEEE10000004ooooo`@0ZZZZ
1?ooool40:ZZZP@00000102ZZZX4ooooo`D00000101EEED80:ZZZTCooooo9`3AcJT002H0dLfYAOoo
ool80:ZZZP@0EEEE10000004ooooo`@0ZZZZ100000040:ZZZPCooooo102ZZZX4ooooo`@00000101E
EED8ooooo`@0EEEE1?ooool405EEE@@0ZZZZ1?ooool405EEE@@000001?ooool805EEE@@000001?oo
ool40:ZZZP@0EEEE1?ooool9000000@0EEEE1000000405EEE@@00000101EEED8000000Cooooo101E
EED40:ZZZPCooooo1000000805EEE@Cooooo1000000405EEE@Cooooo102ZZZX405EEE@Cooooo101E
EED8ooooo`@0EEEE10000004ooooo`@0ZZZZ1?ooool40:ZZZP@00000102ZZZX4ooooo`D00000101E
EED80:ZZZTCooooo9`3AcJT002H0dLfYAOooool80:ZZZP@0EEEE10000004ooooo`@0ZZZZ10000004
0:ZZZPCooooo102ZZZX4ooooo`@00000101EEED8ooooo`@0EEEE1?ooool405EEE@@0ZZZZ1?ooool4
05EEE@@000001?ooool805EEE@@000001?ooool40:ZZZP@0EEEE1?ooool9000000@0EEEE10000004
05EEE@@00000101EEED8000000Cooooo101EEED40:ZZZPCooooo1000000805EEE@Cooooo10000004
05EEE@Cooooo102ZZZX405EEE@Cooooo101EEED8ooooo`@0EEEE10000004ooooo`@0ZZZZ1?ooool4
0:ZZZP@00000102ZZZX4ooooo`D00000101EEED80:ZZZTCooooo9`3AcJT002H0dLfYAOooool80:ZZ
ZP@0EEEE10000004ooooo`@0ZZZZ100000040:ZZZPCooooo102ZZZX4ooooo`@00000101EEED8oooo
o`@0EEEE1?ooool405EEE@@0ZZZZ1?ooool405EEE@@000001?ooool805EEE@@000001?ooool40:ZZ
ZP@0EEEE1?ooool9000000@0EEEE1000000405EEE@@00000101EEED8000000Cooooo101EEED40:ZZ
ZPCooooo1000000805EEE@Cooooo1000000405EEE@Cooooo102ZZZX405EEE@Cooooo101EEED8oooo
o`@0EEEE10000004ooooo`@0ZZZZ1?ooool40:ZZZP@00000102ZZZX4ooooo`D00000101EEED80:ZZ
ZTCooooo9`3AcJT002H0dLfYBOooool40:ZZZPCooooo101EEED4ooooo`@0EEEE100000080:ZZZPP0
EEEE2?ooool4000000@0ZZZZ1?ooool805EEE@@000001?ooool40:ZZZP@0EEEE200000040:ZZZP@0
0000101EEED4000000gooooo101EEED4ooooo``0ZZZZ1?ooool405EEE@cooooo1000000405EEE@@0
0000102ZZZX8000000@0EEEE102ZZZX4ooooo`@00000201EEED4ooooo`@0ZZZZ10000008ooooo`P0
EEEE202ZZZX4000000@0EEEE1?ooool505EEE@Cooooo102ZZZY8ooooobL0dLfY000V0=7=ZDWooooo
102ZZZX4ooooo`@0EEEE1?ooool405EEE@@00000202ZZZX805EEE@Sooooo100000040:ZZZPCooooo
201EEED4000000Cooooo102ZZZX405EEE@P00000102ZZZX4000000@0EEEE1000000=ooooo`@0EEEE
1?ooool<0:ZZZPCooooo101EEED<ooooo`@00000101EEED4000000@0ZZZZ2000000405EEE@@0ZZZZ
1?ooool4000000P0EEEE1?ooool40:ZZZP@000002?ooool805EEE@P0ZZZZ1000000405EEE@Cooooo
1@1EEED4ooooo`@0ZZZZB?oooolW0=7=Z@009P3AcJU9ooooo`@0ZZZZ1?ooool405EEE@Cooooo101E
EED4000000P0ZZZZ201EEED8ooooo`@00000102ZZZX4ooooo`P0EEEE10000004ooooo`@0ZZZZ101E
EED8000000@0ZZZZ1000000405EEE@@000003Oooool405EEE@Cooooo302ZZZX4ooooo`@0EEEE3?oo
ool4000000@0EEEE100000040:ZZZPP00000101EEED40:ZZZPCooooo1000000805EEE@Cooooo102Z
ZZX4000000Sooooo201EEED80:ZZZP@00000101EEED4ooooo`D0EEEE1?ooool40:ZZZTSooooo9`3A
cJT002H0dLfYBOooool40:ZZZPCooooo101EEED4ooooo`@0EEEE100000080:ZZZPP0EEEE2?ooool4
000000@0ZZZZ1?ooool805EEE@@000001?ooool40:ZZZP@0EEEE200000040:ZZZP@00000101EEED4
000000gooooo101EEED4ooooo``0ZZZZ1?ooool405EEE@cooooo1000000405EEE@@00000102ZZZX8
000000@0EEEE102ZZZX4ooooo`@00000201EEED4ooooo`@0ZZZZ10000008ooooo`P0EEEE202ZZZX4
000000@0EEEE1?ooool505EEE@Cooooo102ZZZY8ooooobL0dLfY000V0=7=ZDgooooo102ZZZX80000
00`0EEEE102ZZZX405EEE@Cooooo102ZZZX4000000Cooooo1000000405EEE@@00000301EEED4oooo
o`@000001?ooool<000000Sooooo201EEED5ooooo`@0EEEE202ZZZX4000000P0ZZZZ101EEED4oooo
o`P0EEEE2?ooool<000000Cooooo10000004ooooo``0EEEE1000000405EEE@@000001?ooool40000
00@0ZZZZ1?ooool405EEE@@0ZZZZ301EEED9000000@0ZZZZC?oooolW0=7=Z@009P3AcJU=ooooo`@0
ZZZZ2000000<05EEE@@0ZZZZ101EEED4ooooo`@0ZZZZ10000004ooooo`@00000101EEED4000000`0
EEEE1?ooool4000000Cooooo30000008ooooo`P0EEEE1Oooool405EEE@P0ZZZZ100000080:ZZZP@0
EEEE1?ooool805EEE@Sooooo30000004ooooo`@000001?ooool<05EEE@@00000101EEED4000000Co
oooo100000040:ZZZPCooooo101EEED40:ZZZP`0EEEE2@0000040:ZZZTcooooo9`3AcJT002H0dLfY
COooool40:ZZZPP00000301EEED40:ZZZP@0EEEE1?ooool40:ZZZP@000001?ooool4000000@0EEEE
1000000<05EEE@Cooooo10000004ooooo``000002?ooool805EEE@Gooooo101EEED80:ZZZP@00000
202ZZZX405EEE@Cooooo201EEED8ooooo``000001?ooool4000000Cooooo301EEED4000000@0EEEE
10000004ooooo`@00000102ZZZX4ooooo`@0EEEE102ZZZX<05EEE@T00000102ZZZY<ooooobL0dLfY
000V0=7=ZDgooooo102ZZZX8000000`0EEEE102ZZZX405EEE@Cooooo102ZZZX4000000Cooooo1000
000405EEE@@00000301EEED4ooooo`@000001?ooool<000000Sooooo201EEED5ooooo`@0EEEE202Z
ZZX4000000P0ZZZZ101EEED4ooooo`P0EEEE2?ooool<000000Cooooo10000004ooooo``0EEEE1000
000405EEE@@000001?ooool4000000@0ZZZZ1?ooool405EEE@@0ZZZZ301EEED9000000@0ZZZZC?oo
oolW0=7=Z@009P3AcJUAooooo`P0ZZZZ1?ooool405EEE@@0ZZZZ2?ooool4000000P0ZZZZ1?ooool8
000000@0ZZZZ101EEED4ooooo`@0ZZZZ101EEED40:ZZZP@000001?ooool8000000Cooooo102ZZZX8
000000D0ZZZZ1?ooool405EEE@@000001?ooool4000000@0EEEE1?ooool40:ZZZPP00000102ZZZX4
ooooo`P000001?ooool4000000@0ZZZZ101EEED40:ZZZPCooooo101EEED40:ZZZPP000001?ooool8
0:ZZZP@000002?ooool40:ZZZP@0EEEE1?ooool90:ZZZU3ooooo9`3AcJT002H0dLfYDOooool80:ZZ
ZPCooooo101EEED40:ZZZPSooooo100000080:ZZZPCooooo200000040:ZZZP@0EEEE1?ooool40:ZZ
ZP@0EEEE102ZZZX4000000Cooooo20000004ooooo`@0ZZZZ200000050:ZZZPCooooo101EEED40000
00Cooooo1000000405EEE@Cooooo102ZZZX8000000@0ZZZZ1?ooool8000000Cooooo100000040:ZZ
ZP@0EEEE102ZZZX4ooooo`@0EEEE102ZZZX8000000Cooooo202ZZZX4000000Sooooo102ZZZX405EE
E@Cooooo2@2ZZZY@ooooobL0dLfY000V0=7=ZE7ooooo202ZZZX4ooooo`@0EEEE102ZZZX8ooooo`@0
0000202ZZZX4ooooo`P00000102ZZZX405EEE@Cooooo102ZZZX405EEE@@0ZZZZ10000004ooooo`P0
00001?ooool40:ZZZPP000001@2ZZZX4ooooo`@0EEEE10000004ooooo`@00000101EEED4ooooo`@0
ZZZZ200000040:ZZZPCooooo20000004ooooo`@00000102ZZZX405EEE@@0ZZZZ1?ooool405EEE@@0
ZZZZ20000004ooooo`P0ZZZZ10000008ooooo`@0ZZZZ101EEED4ooooo`T0ZZZZD?oooolW0=7=Z@00
9P3AcJUAooooo`P0ZZZZ1?ooool405EEE@@0ZZZZ2?ooool4000000P0ZZZZ1?ooool8000000@0ZZZZ
101EEED4ooooo`@0ZZZZ101EEED40:ZZZP@000001?ooool8000000Cooooo102ZZZX8000000D0ZZZZ
1?ooool405EEE@@000001?ooool4000000@0EEEE1?ooool40:ZZZPP00000102ZZZX4ooooo`P00000
1?ooool4000000@0ZZZZ101EEED40:ZZZPCooooo101EEED40:ZZZPP000001?ooool80:ZZZP@00000
2?ooool40:ZZZP@0EEEE1?ooool90:ZZZU3ooooo9`3AcJT002H0dLfYEOooool40:ZZZPCooooo1000
0004ooooo`P0EEEE2?ooool40:ZZZPCooooo20000004ooooo`@0EEEE202ZZZX<000000Cooooo202Z
ZZX4ooooo`@00000101EEED40:ZZZPD00000102ZZZX4ooooo`@0EEEE1?ooool405EEE@Cooooo102Z
ZZX4000000@0ZZZZ101EEED4000000Cooooo202ZZZX4ooooo``00000202ZZZX405EEE@Cooooo2000
0004ooooo`@0ZZZZ2?ooool805EEE@Cooooo10000004ooooo`@0ZZZZEOoooolW0=7=Z@009P3AcJUE
ooooo`@0ZZZZ1?ooool4000000Cooooo201EEED8ooooo`@0ZZZZ1?ooool8000000Cooooo101EEED8
0:ZZZP`000001?ooool80:ZZZPCooooo1000000405EEE@@0ZZZZ1@0000040:ZZZPCooooo101EEED4
ooooo`@0EEEE1?ooool40:ZZZP@00000102ZZZX405EEE@@000001?ooool80:ZZZPCooooo30000008
0:ZZZP@0EEEE1?ooool8000000Cooooo102ZZZX8ooooo`P0EEEE1?ooool4000000Cooooo102ZZZYE
ooooobL0dLfY000V0=7=ZEGooooo102ZZZX4ooooo`@000001?ooool805EEE@Sooooo102ZZZX4oooo
o`P000001?ooool405EEE@P0ZZZZ30000004ooooo`P0ZZZZ1?ooool4000000@0EEEE102ZZZX50000
00@0ZZZZ1?ooool405EEE@Cooooo101EEED4ooooo`@0ZZZZ100000040:ZZZP@0EEEE10000004oooo
o`P0ZZZZ1?ooool<000000P0ZZZZ101EEED4ooooo`P000001?ooool40:ZZZPSooooo201EEED4oooo
o`@000001?ooool40:ZZZUGooooo9`3AcJT002H0dLfYEOooool40:ZZZPCooooo10000004ooooo`P0
EEEE2?ooool40:ZZZPCooooo20000004ooooo`@0EEEE202ZZZX<000000Cooooo202ZZZX4ooooo`@0
0000101EEED40:ZZZPD00000102ZZZX4ooooo`@0EEEE1?ooool405EEE@Cooooo102ZZZX4000000@0
ZZZZ101EEED4000000Cooooo202ZZZX4ooooo``00000202ZZZX405EEE@Cooooo20000004ooooo`@0
ZZZZ2?ooool805EEE@Cooooo10000004ooooo`@0ZZZZEOoooolW0=7=Z@009P3AcJUIooooo`@0ZZZZ
1000000405EEE@@00000201EEED4ooooo`@0EEEE20000004ooooo`@00000102ZZZX4000000P0ZZZZ
1?ooool80:ZZZPP0EEEE202ZZZX4ooooo`@0EEEE1@0000080:ZZZP@0EEEE1?ooool405EEE@P0ZZZZ
1000000405EEE@Cooooo202ZZZX805EEE@P0ZZZZ1?ooool80:ZZZP@00000102ZZZX4000000Cooooo
2000000405EEE@Cooooo201EEED4000000@0EEEE100000040:ZZZUWooooo9`3AcJT002H0dLfYFOoo
ool40:ZZZP@00000101EEED4000000P0EEEE1?ooool405EEE@P000001?ooool4000000@0ZZZZ1000
00080:ZZZPCooooo202ZZZX805EEE@P0ZZZZ1?ooool405EEE@D00000202ZZZX405EEE@Cooooo101E
EED80:ZZZP@00000101EEED4ooooo`P0ZZZZ201EEED80:ZZZPCooooo202ZZZX4000000@0ZZZZ1000
0004ooooo`P00000101EEED4ooooo`P0EEEE1000000405EEE@@00000102ZZZYIooooobL0dLfY000V
0=7=ZEWooooo102ZZZX4000000@0EEEE1000000805EEE@Cooooo101EEED8000000Cooooo10000004
0:ZZZP@00000202ZZZX4ooooo`P0ZZZZ201EEED80:ZZZPCooooo101EEED5000000P0ZZZZ101EEED4
ooooo`@0EEEE202ZZZX4000000@0EEEE1?ooool80:ZZZPP0EEEE202ZZZX4ooooo`P0ZZZZ10000004
0:ZZZP@000001?ooool8000000@0EEEE1?ooool805EEE@@00000101EEED4000000@0ZZZZFOoooolW
0=7=Z@009P3AcJUIooooo`@0ZZZZ1000000405EEE@@00000201EEED4ooooo`@0EEEE20000004oooo
o`@00000102ZZZX4000000P0ZZZZ1?ooool80:ZZZPP0EEEE202ZZZX4ooooo`@0EEEE1@0000080:ZZ
ZP@0EEEE1?ooool405EEE@P0ZZZZ1000000405EEE@Cooooo202ZZZX805EEE@P0ZZZZ1?ooool80:ZZ
ZP@00000102ZZZX4000000Cooooo2000000405EEE@Cooooo201EEED4000000@0EEEE100000040:ZZ
ZUWooooo9`3AcJT002H0dLfYGOooool<0:ZZZPCooooo101EEED<0:ZZZPCooooo102ZZZX4000000@0
EEEE2?ooool40:ZZZPCooooo1000000405EEE@Cooooo102ZZZX805EEE@d0ZZZZ2?ooool40:ZZZP@0
EEEE102ZZZX8ooooo``0ZZZZ201EEED40:ZZZPCooooo101EEED4000000Cooooo102ZZZX8ooooo`@0
EEEE100000040:ZZZPCooooo302ZZZX405EEE@Cooooo302ZZZYMooooobL0dLfY000V0=7=ZEgooooo
302ZZZX4ooooo`@0EEEE302ZZZX4ooooo`@0ZZZZ1000000405EEE@Sooooo102ZZZX4ooooo`@00000
101EEED4ooooo`@0ZZZZ201EEED=0:ZZZPSooooo102ZZZX405EEE@@0ZZZZ2?ooool<0:ZZZPP0EEEE
102ZZZX4ooooo`@0EEEE10000004ooooo`@0ZZZZ2?ooool405EEE@@00000102ZZZX4ooooo``0ZZZZ
101EEED4ooooo``0ZZZZGOoooolW0=7=Z@009P3AcJUMooooo``0ZZZZ1?ooool405EEE@`0ZZZZ1?oo
ool40:ZZZP@00000101EEED8ooooo`@0ZZZZ1?ooool4000000@0EEEE1?ooool40:ZZZPP0EEEE3@2Z
ZZX8ooooo`@0ZZZZ101EEED40:ZZZPSooooo302ZZZX805EEE@@0ZZZZ1?ooool405EEE@@000001?oo
ool40:ZZZPSooooo101EEED4000000@0ZZZZ1?ooool<0:ZZZP@0EEEE1?ooool<0:ZZZUgooooo9`3A
cJT002H0dLfYGOooool<0:ZZZPCooooo101EEED<0:ZZZPCooooo102ZZZX4000000@0EEEE2?ooool4
0:ZZZPCooooo1000000405EEE@Cooooo102ZZZX805EEE@d0ZZZZ2?ooool40:ZZZP@0EEEE102ZZZX8
ooooo``0ZZZZ201EEED40:ZZZPCooooo101EEED4000000Cooooo102ZZZX8ooooo`@0EEEE10000004
0:ZZZPCooooo302ZZZX405EEE@Cooooo302ZZZYMooooobL0dLfY000V0=7=ZF7ooooo102ZZZX<oooo
o`@00000101EEED4ooooo`@00000202ZZZX4ooooo`P0EEEE1?ooool4000000@0ZZZZ101EEED4oooo
o`@0EEEE1000000805EEE@@0ZZZZ2@1EEED4ooooo`@0EEEE1000000405EEE@Cooooo201EEED40:ZZ
ZPP0EEEE1000000405EEE@Cooooo101EEED40:ZZZP@000001?ooool805EEE@Cooooo202ZZZX40000
00Cooooo101EEED4000000cooooo102ZZZYQooooobL0dLfY000V0=7=ZF7ooooo102ZZZX<ooooo`@0
0000101EEED4ooooo`@00000202ZZZX4ooooo`P0EEEE1?ooool4000000@0ZZZZ101EEED4ooooo`@0
EEEE1000000805EEE@@0ZZZZ2@1EEED4ooooo`@0EEEE1000000405EEE@Cooooo201EEED40:ZZZPP0
EEEE1000000405EEE@Cooooo101EEED40:ZZZP@000001?ooool805EEE@Cooooo202ZZZX4000000Co
oooo101EEED4000000cooooo102ZZZYQooooobL0dLfY000V0=7=ZF7ooooo102ZZZX<ooooo`@00000
101EEED4ooooo`@00000202ZZZX4ooooo`P0EEEE1?ooool4000000@0ZZZZ101EEED4ooooo`@0EEEE
1000000805EEE@@0ZZZZ2@1EEED4ooooo`@0EEEE1000000405EEE@Cooooo201EEED40:ZZZPP0EEEE
1000000405EEE@Cooooo101EEED40:ZZZP@000001?ooool805EEE@Cooooo202ZZZX4000000Cooooo
101EEED4000000cooooo102ZZZYQooooobL0dLfY000V0=7=ZF7ooooo102ZZZX<ooooo`@00000101E
EED4ooooo`@00000202ZZZX4ooooo`P0EEEE1?ooool4000000@0ZZZZ101EEED4ooooo`@0EEEE1000
000805EEE@@0ZZZZ2@1EEED4ooooo`@0EEEE1000000405EEE@Cooooo201EEED40:ZZZPP0EEEE1000
000405EEE@Cooooo101EEED40:ZZZP@000001?ooool805EEE@Cooooo202ZZZX4000000Cooooo101E
EED4000000cooooo102ZZZYQooooobL0dLfY000V0=7=ZFGooooo102ZZZX4000000Cooooo302ZZZX4
05EEE@@000001?ooool805EEE@@00000101EEED4000000`0ZZZZ101EEED8ooooo`@000001?ooool5
05EEE@@0ZZZZ1?ooool4000000Cooooo10000004ooooo`@0ZZZZ101EEED4ooooo`@000002?ooool4
05EEE@`0ZZZZ1000000405EEE@@00000201EEED4ooooo`@00000101EEED<0:ZZZPCooooo10000004
0:ZZZVGooooo9`3AcJT002H0dLfYIOooool40:ZZZP@000001?ooool<0:ZZZP@0EEEE10000004oooo
o`P0EEEE1000000405EEE@@00000302ZZZX405EEE@Sooooo10000004ooooo`D0EEEE102ZZZX4oooo
o`@000001?ooool4000000Cooooo102ZZZX405EEE@Cooooo10000008ooooo`@0EEEE302ZZZX40000
00@0EEEE1000000805EEE@Cooooo1000000405EEE@`0ZZZZ1?ooool4000000@0ZZZZIOoooolW0=7=
Z@009P3AcJUUooooo`@0ZZZZ10000004ooooo``0ZZZZ101EEED4000000Cooooo201EEED4000000@0
EEEE1000000<0:ZZZP@0EEEE2?ooool4000000Cooooo1@1EEED40:ZZZPCooooo10000004ooooo`@0
00001?ooool40:ZZZP@0EEEE1?ooool4000000Sooooo101EEED<0:ZZZP@00000101EEED4000000P0
EEEE1?ooool4000000@0EEEE302ZZZX4ooooo`@00000102ZZZYUooooobL0dLfY000V0=7=ZFGooooo
102ZZZX4000000Cooooo302ZZZX405EEE@@000001?ooool805EEE@@00000101EEED4000000`0ZZZZ
101EEED8ooooo`@000001?ooool505EEE@@0ZZZZ1?ooool4000000Cooooo10000004ooooo`@0ZZZZ
101EEED4ooooo`@000002?ooool405EEE@`0ZZZZ1000000405EEE@@00000201EEED4ooooo`@00000
101EEED<0:ZZZPCooooo100000040:ZZZVGooooo9`3AcJT002H0dLfYJOooool80:ZZZPP0EEEE102Z
ZZX405EEE@cooooo10000004ooooo`@000001?ooool4000000@0EEEE1?ooool4000000Cooooo102Z
ZZX4000000@0EEEE1@00000405EEE@Cooooo101EEED4ooooo`@0EEEE1?ooool405EEE@@00000101E
EED4000000@0ZZZZ1?ooool4000000Cooooo101EEED4000000Cooooo10000004ooooo`@000003?oo
ool405EEE@@0ZZZZ201EEED80:ZZZVWooooo9`3AcJT002H0dLfYJOooool80:ZZZPP0EEEE102ZZZX4
05EEE@cooooo10000004ooooo`@000001?ooool4000000@0EEEE1?ooool4000000Cooooo102ZZZX4
000000@0EEEE1@00000405EEE@Cooooo101EEED4ooooo`@0EEEE1?ooool405EEE@@00000101EEED4
000000@0ZZZZ1?ooool4000000Cooooo101EEED4000000Cooooo10000004ooooo`@000003?ooool4
05EEE@@0ZZZZ201EEED80:ZZZVWooooo9`3AcJT002H0dLfYJOooool80:ZZZPP0EEEE102ZZZX405EE
E@cooooo10000004ooooo`@000001?ooool4000000@0EEEE1?ooool4000000Cooooo102ZZZX40000
00@0EEEE1@00000405EEE@Cooooo101EEED4ooooo`@0EEEE1?ooool405EEE@@00000101EEED40000
00@0ZZZZ1?ooool4000000Cooooo101EEED4000000Cooooo10000004ooooo`@000003?ooool405EE
E@@0ZZZZ201EEED80:ZZZVWooooo9`3AcJT002H0dLfYJOooool80:ZZZPP0EEEE102ZZZX405EEE@co
oooo10000004ooooo`@000001?ooool4000000@0EEEE1?ooool4000000Cooooo102ZZZX4000000@0
EEEE1@00000405EEE@Cooooo101EEED4ooooo`@0EEEE1?ooool405EEE@@00000101EEED4000000@0
ZZZZ1?ooool4000000Cooooo101EEED4000000Cooooo10000004ooooo`@000003?ooool405EEE@@0
ZZZZ201EEED80:ZZZVWooooo9`3AcJT002H0dLfYKOooool40:ZZZPCooooo101EEED40:ZZZP@0EEEE
1?ooool805EEE@cooooo301EEED8000000Cooooo102ZZZX4ooooo`@0ZZZZ1@1EEED4000000@0EEEE
1000000405EEE@@00000101EEED4000000@0EEEE102ZZZX4ooooo`@0ZZZZ1?ooool8000000`0EEEE
3?ooool805EEE@Cooooo101EEED40:ZZZP@0EEEE1?ooool40:ZZZVgooooo9`3AcJT002H0dLfYKOoo
ool40:ZZZPCooooo101EEED40:ZZZP@0EEEE1?ooool805EEE@cooooo301EEED8000000Cooooo102Z
ZZX4ooooo`@0ZZZZ1@1EEED4000000@0EEEE1000000405EEE@@00000101EEED4000000@0EEEE102Z
ZZX4ooooo`@0ZZZZ1?ooool8000000`0EEEE3?ooool805EEE@Cooooo101EEED40:ZZZP@0EEEE1?oo
ool40:ZZZVgooooo9`3AcJT002H0dLfYKOooool40:ZZZPCooooo101EEED40:ZZZP@0EEEE1?ooool8
05EEE@cooooo301EEED8000000Cooooo102ZZZX4ooooo`@0ZZZZ1@1EEED4000000@0EEEE10000004
05EEE@@00000101EEED4000000@0EEEE102ZZZX4ooooo`@0ZZZZ1?ooool8000000`0EEEE3?ooool8
05EEE@Cooooo101EEED40:ZZZP@0EEEE1?ooool40:ZZZVgooooo9`3AcJT002H0dLfYKOooool40:ZZ
ZPCooooo101EEED40:ZZZP@0EEEE1?ooool805EEE@cooooo301EEED8000000Cooooo102ZZZX4oooo
o`@0ZZZZ1@1EEED4000000@0EEEE1000000405EEE@@00000101EEED4000000@0EEEE102ZZZX4oooo
o`@0ZZZZ1?ooool8000000`0EEEE3?ooool805EEE@Cooooo101EEED40:ZZZP@0EEEE1?ooool40:ZZ
ZVgooooo9`3AcJT002H0dLfYLOooool40:ZZZP`00000102ZZZX4ooooo`@0EEEE202ZZZX405EEE@@0
ZZZZ1?ooool405EEE@@0ZZZZ1000000405EEE@@000001?ooool40:ZZZPGooooo101EEED4ooooo``0
ZZZZ1?ooool405EEE@Cooooo102ZZZX4ooooo`@00000101EEED4000000@0ZZZZ101EEED4ooooo`@0
ZZZZ101EEED80:ZZZP@0EEEE1?ooool40:ZZZP`00000102ZZZYaooooobL0dLfY000V0=7=ZG7ooooo
102ZZZX<000000@0ZZZZ1?ooool405EEE@P0ZZZZ101EEED40:ZZZPCooooo101EEED40:ZZZP@00000
101EEED4000000Cooooo102ZZZX5ooooo`@0EEEE1?ooool<0:ZZZPCooooo101EEED4ooooo`@0ZZZZ
1?ooool4000000@0EEEE100000040:ZZZP@0EEEE1?ooool40:ZZZP@0EEEE202ZZZX405EEE@Cooooo
102ZZZX<000000@0ZZZZLOoooolW0=7=Z@009P3AcJUaooooo`@0ZZZZ300000040:ZZZPCooooo101E
EED80:ZZZP@0EEEE102ZZZX4ooooo`@0EEEE102ZZZX4000000@0EEEE10000004ooooo`@0ZZZZ1Ooo
ool405EEE@Cooooo302ZZZX4ooooo`@0EEEE1?ooool40:ZZZPCooooo1000000405EEE@@00000102Z
ZZX405EEE@Cooooo102ZZZX405EEE@P0ZZZZ101EEED4ooooo`@0ZZZZ300000040:ZZZW7ooooo9`3A
cJT002H0dLfYLOooool40:ZZZP`00000102ZZZX4ooooo`@0EEEE202ZZZX405EEE@@0ZZZZ1?ooool4
05EEE@@0ZZZZ1000000405EEE@@000001?ooool40:ZZZPGooooo101EEED4ooooo``0ZZZZ1?ooool4
05EEE@Cooooo102ZZZX4ooooo`@00000101EEED4000000@0ZZZZ101EEED4ooooo`@0ZZZZ101EEED8
0:ZZZP@0EEEE1?ooool40:ZZZP`00000102ZZZYaooooobL0dLfY000V0=7=ZGGooooo202ZZZX4oooo
o`@0ZZZZ1?ooool4000000Cooooo101EEED4000000@0EEEE1?ooool405EEE@@0ZZZZ101EEED40000
00@0EEEE202ZZZX5000000cooooo102ZZZX<ooooo`@00000202ZZZX405EEE@@00000101EEED40:ZZ
ZP@0EEEE1?ooool405EEE@@00000101EEED4ooooo`@000001?ooool40:ZZZPCooooo202ZZZYeoooo
obL0dLfY000V0=7=ZGGooooo202ZZZX4ooooo`@0ZZZZ1?ooool4000000Cooooo101EEED4000000@0
EEEE1?ooool405EEE@@0ZZZZ101EEED4000000@0EEEE202ZZZX5000000cooooo102ZZZX<ooooo`@0
0000202ZZZX405EEE@@00000101EEED40:ZZZP@0EEEE1?ooool405EEE@@00000101EEED4ooooo`@0
00001?ooool40:ZZZPCooooo202ZZZYeooooobL0dLfY000V0=7=ZGGooooo202ZZZX4ooooo`@0ZZZZ
1?ooool4000000Cooooo101EEED4000000@0EEEE1?ooool405EEE@@0ZZZZ101EEED4000000@0EEEE
202ZZZX5000000cooooo102ZZZX<ooooo`@00000202ZZZX405EEE@@00000101EEED40:ZZZP@0EEEE
1?ooool405EEE@@00000101EEED4ooooo`@000001?ooool40:ZZZPCooooo202ZZZYeooooobL0dLfY
000V0=7=ZGGooooo202ZZZX4ooooo`@0ZZZZ1?ooool4000000Cooooo101EEED4000000@0EEEE1?oo
ool405EEE@@0ZZZZ101EEED4000000@0EEEE202ZZZX5000000cooooo102ZZZX<ooooo`@00000202Z
ZZX405EEE@@00000101EEED40:ZZZP@0EEEE1?ooool405EEE@@00000101EEED4ooooo`@000001?oo
ool40:ZZZPCooooo202ZZZYeooooobL0dLfY000V0=7=ZGWooooo102ZZZX4ooooo`@00000101EEED4
000000@0ZZZZ1?ooool405EEE@Cooooo102ZZZX<000000@0ZZZZ101EEED4ooooo`@000001@1EEED8
0:ZZZP@0EEEE102ZZZX405EEE@P0ZZZZ101EEED4000000Cooooo101EEED40:ZZZP`00000102ZZZX4
ooooo`@0EEEE1?ooool40:ZZZP@00000101EEED4000000Cooooo102ZZZYiooooobL0dLfY000V0=7=
ZGWooooo102ZZZX4ooooo`@00000101EEED4000000@0ZZZZ1?ooool405EEE@Cooooo102ZZZX<0000
00@0ZZZZ101EEED4ooooo`@000001@1EEED80:ZZZP@0EEEE102ZZZX405EEE@P0ZZZZ101EEED40000
00Cooooo101EEED40:ZZZP`00000102ZZZX4ooooo`@0EEEE1?ooool40:ZZZP@00000101EEED40000
00Cooooo102ZZZYiooooobL0dLfY000V0=7=ZGWooooo102ZZZX4ooooo`@00000101EEED4000000@0
ZZZZ1?ooool405EEE@Cooooo102ZZZX<000000@0ZZZZ101EEED4ooooo`@000001@1EEED80:ZZZP@0
EEEE102ZZZX405EEE@P0ZZZZ101EEED4000000Cooooo101EEED40:ZZZP`00000102ZZZX4ooooo`@0
EEEE1?ooool40:ZZZP@00000101EEED4000000Cooooo102ZZZYiooooobL0dLfY000V0=7=ZGWooooo
102ZZZX4ooooo`@00000101EEED4000000@0ZZZZ1?ooool405EEE@Cooooo102ZZZX<000000@0ZZZZ
101EEED4ooooo`@000001@1EEED80:ZZZP@0EEEE102ZZZX405EEE@P0ZZZZ101EEED4000000Cooooo
101EEED40:ZZZP`00000102ZZZX4ooooo`@0EEEE1?ooool40:ZZZP@00000101EEED4000000Cooooo
102ZZZYiooooobL0dLfY000V0=7=ZGgooooo102ZZZX4000000`0EEEE302ZZZXD05EEE@@0ZZZZ1?oo
ool9000000P0ZZZZ300000080:ZZZPP000001?ooool40:ZZZQ@0EEEE302ZZZX<05EEE@@00000102Z
ZZYmooooobL0dLfY000V0=7=ZGgooooo102ZZZX4000000`0EEEE302ZZZXD05EEE@@0ZZZZ1?ooool9
000000P0ZZZZ300000080:ZZZPP000001?ooool40:ZZZQ@0EEEE302ZZZX<05EEE@@00000102ZZZYm
ooooobL0dLfY000V0=7=ZGgooooo102ZZZX4000000`0EEEE302ZZZXD05EEE@@0ZZZZ1?ooool90000
00P0ZZZZ300000080:ZZZPP000001?ooool40:ZZZQ@0EEEE302ZZZX<05EEE@@00000102ZZZYmoooo
obL0dLfY000V0=7=ZGgooooo102ZZZX4000000`0EEEE302ZZZXD05EEE@@0ZZZZ1?ooool9000000P0
ZZZZ300000080:ZZZPP000001?ooool40:ZZZQ@0EEEE302ZZZX<05EEE@@00000102ZZZYmooooobL0
dLfY000V0=7=ZH7ooooo502ZZZX4000001`0ZZZZ10000004oooooa4000001?ooool@000000Cooooo
1000000L0:ZZZP@00000502ZZZZ1ooooobL0dLfY000V0=7=ZH7ooooo502ZZZX4000001`0ZZZZ1000
0004oooooa4000001?ooool@000000Cooooo1000000L0:ZZZP@00000502ZZZZ1ooooobL0dLfY000V
0=7=ZH7ooooo502ZZZX4000001`0ZZZZ10000004oooooa4000001?ooool@000000Cooooo1000000L
0:ZZZP@00000502ZZZZ1ooooobL0dLfY000V0=7=ZH7ooooo502ZZZX4000001`0ZZZZ10000004oooo
oa4000001?ooool@000000Cooooo1000000L0:ZZZP@00000502ZZZZ1ooooobL0dLfY000V0=7=ZHGo
oooo102ZZZX8ooooo`@0ZZZZ1?ooool40:ZZZPSooooo102ZZZX8ooooo`@0ZZZZ1?ooool40:ZZZPD0
0000101EEED40:ZZZP@00000101EEED4000000@0ZZZZ101EEED4000000@0ZZZZ1?ooool40:ZZZPSo
oooo102ZZZX8ooooo`@0ZZZZ1?ooool40:ZZZPSooooo102ZZZZ5ooooobL0dLfY000V0=7=ZHGooooo
102ZZZX8ooooo`@0ZZZZ1?ooool40:ZZZPSooooo102ZZZX8ooooo`@0ZZZZ1?ooool40:ZZZPD00000
101EEED40:ZZZP@00000101EEED4000000@0ZZZZ101EEED4000000@0ZZZZ1?ooool40:ZZZPSooooo
102ZZZX8ooooo`@0ZZZZ1?ooool40:ZZZPSooooo102ZZZZ5ooooobL0dLfY000V0=7=ZHGooooo102Z
ZZX8ooooo`@0ZZZZ1?ooool40:ZZZPSooooo102ZZZX8ooooo`@0ZZZZ1?ooool40:ZZZPD00000101E
EED40:ZZZP@00000101EEED4000000@0ZZZZ101EEED4000000@0ZZZZ1?ooool40:ZZZPSooooo102Z
ZZX8ooooo`@0ZZZZ1?ooool40:ZZZPSooooo102ZZZZ5ooooobL0dLfY000V0=7=ZHGooooo102ZZZX8
ooooo`@0ZZZZ1?ooool40:ZZZPSooooo102ZZZX8ooooo`@0ZZZZ1?ooool40:ZZZPD00000101EEED4
0:ZZZP@00000101EEED4000000@0ZZZZ101EEED4000000@0ZZZZ1?ooool40:ZZZPSooooo102ZZZX8
ooooo`@0ZZZZ1?ooool40:ZZZPSooooo102ZZZZ5ooooobL0dLfY000V0=7=ZHWooooo102ZZZX40000
00Cooooo201EEED80:ZZZPP0EEEE1?ooool405EEE@d000002?ooool<0:ZZZPSooooo3000000405EE
E@Cooooo201EEED80:ZZZPP0EEEE1?ooool4000000@0ZZZZROoooolW0=7=Z@009P3AcJV9ooooo`@0
ZZZZ10000004ooooo`P0EEEE202ZZZX805EEE@Cooooo101EEED=000000Sooooo302ZZZX8ooooo``0
0000101EEED4ooooo`P0EEEE202ZZZX805EEE@Cooooo100000040:ZZZXWooooo9`3AcJT002H0dLfY
ROooool40:ZZZP@000001?ooool805EEE@P0ZZZZ201EEED4ooooo`@0EEEE3@000008ooooo``0ZZZZ
2?ooool<000000@0EEEE1?ooool805EEE@P0ZZZZ201EEED4ooooo`@00000102ZZZZ9ooooobL0dLfY
000V0=7=ZHWooooo102ZZZX4000000Cooooo201EEED80:ZZZPP0EEEE1?ooool405EEE@d000002?oo
ool<0:ZZZPSooooo3000000405EEE@Cooooo201EEED80:ZZZPP0EEEE1?ooool4000000@0ZZZZROoo
oolW0=7=Z@009P3AcJV=ooooo`P0ZZZZ101EEED4ooooo`@0ZZZZ2?ooool4000000Cooooo102ZZZX4
05EEE@@000001@2ZZZX405EEE@P0ZZZZ100000080:ZZZP@0EEEE102ZZZX4000000@0EEEE102ZZZX4
ooooo`@000002?ooool40:ZZZPCooooo101EEED80:ZZZXgooooo9`3AcJT002H0dLfYSOooool80:ZZ
ZP@0EEEE1?ooool40:ZZZPSooooo10000004ooooo`@0ZZZZ101EEED4000000D0ZZZZ101EEED80:ZZ
ZP@00000202ZZZX405EEE@@0ZZZZ1000000405EEE@@0ZZZZ1?ooool4000000Sooooo102ZZZX4oooo
o`@0EEEE202ZZZZ=ooooobL0dLfY000V0=7=ZHgooooo202ZZZX405EEE@Cooooo102ZZZX8ooooo`@0
00001?ooool40:ZZZP@0EEEE100000050:ZZZP@0EEEE202ZZZX4000000P0ZZZZ101EEED40:ZZZP@0
0000101EEED40:ZZZPCooooo10000008ooooo`@0ZZZZ1?ooool405EEE@P0ZZZZSOoooolW0=7=Z@00
9P3AcJV=ooooo`P0ZZZZ101EEED4ooooo`@0ZZZZ2?ooool4000000Cooooo102ZZZX405EEE@@00000
1@2ZZZX405EEE@P0ZZZZ100000080:ZZZP@0EEEE102ZZZX4000000@0EEEE102ZZZX4ooooo`@00000
2?ooool40:ZZZPCooooo101EEED80:ZZZXgooooo9`3AcJT002H0dLfYTOooool40:ZZZPCooooo201E
EED80:ZZZP@0EEEE300000040:ZZZPT0EEEE10000004ooooo`@0EEEE1?ooool4000000P0EEEE102Z
ZZX<000000@0EEEE202ZZZX805EEE@Cooooo102ZZZZAooooobL0dLfY000V0=7=ZI7ooooo102ZZZX4
ooooo`P0EEEE202ZZZX405EEE@`00000102ZZZX905EEE@@000001?ooool405EEE@Cooooo10000008
05EEE@@0ZZZZ3000000405EEE@P0ZZZZ201EEED4ooooo`@0ZZZZTOoooolW0=7=Z@009P3AcJVAoooo
o`@0ZZZZ1?ooool805EEE@P0ZZZZ101EEED<000000@0ZZZZ2@1EEED4000000Cooooo101EEED4oooo
o`@00000201EEED40:ZZZP`00000101EEED80:ZZZPP0EEEE1?ooool40:ZZZY7ooooo9`3AcJT002H0
dLfYTOooool40:ZZZPCooooo201EEED80:ZZZP@0EEEE300000040:ZZZPT0EEEE10000004ooooo`@0
EEEE1?ooool4000000P0EEEE102ZZZX<000000@0EEEE202ZZZX805EEE@Cooooo102ZZZZAooooobL0
dLfY000V0=7=ZIGooooo102ZZZX8000000P0ZZZZ20000004ooooo`d00000102ZZZX4000000@0EEEE
1000000405EEE@@00000102ZZZX<000000Cooooo200000080:ZZZPP00000102ZZZZEooooobL0dLfY
000V0=7=ZIGooooo102ZZZX8000000P0ZZZZ20000004ooooo`d00000102ZZZX4000000@0EEEE1000
000405EEE@@00000102ZZZX<000000Cooooo200000080:ZZZPP00000102ZZZZEooooobL0dLfY000V
0=7=ZIGooooo102ZZZX8000000P0ZZZZ20000004ooooo`d00000102ZZZX4000000@0EEEE10000004
05EEE@@00000102ZZZX<000000Cooooo200000080:ZZZPP00000102ZZZZEooooobL0dLfY000V0=7=
ZIGooooo102ZZZX8000000P0ZZZZ20000004ooooo`d00000102ZZZX4000000@0EEEE1000000405EE
E@@00000102ZZZX<000000Cooooo200000080:ZZZPP00000102ZZZZEooooobL0dLfY000V0=7=ZIWo
oooo202ZZZX8ooooo`P0ZZZZ1?ooool8000000Gooooo1000000405EEE@@0ZZZZ1?ooool40:ZZZP@0
EEEE10000004ooooo`P000001?ooool80:ZZZPSooooo202ZZZZIooooobL0dLfY000V0=7=ZIWooooo
202ZZZX8ooooo`P0ZZZZ1?ooool8000000Gooooo1000000405EEE@@0ZZZZ1?ooool40:ZZZP@0EEEE
10000004ooooo`P000001?ooool80:ZZZPSooooo202ZZZZIooooobL0dLfY000V0=7=ZIWooooo202Z
ZZX8ooooo`P0ZZZZ1?ooool8000000Gooooo1000000405EEE@@0ZZZZ1?ooool40:ZZZP@0EEEE1000
0004ooooo`P000001?ooool80:ZZZPSooooo202ZZZZIooooobL0dLfY000V0=7=ZIWooooo202ZZZX8
ooooo`P0ZZZZ1?ooool8000000Gooooo1000000405EEE@@0ZZZZ1?ooool40:ZZZP@0EEEE10000004
ooooo`P000001?ooool80:ZZZPSooooo202ZZZZIooooobL0dLfY000V0=7=ZIgooooo102ZZZX4oooo
o`@00000202ZZZX4000000Cooooo2@00000405EEE@@0ZZZZ3?ooool40:ZZZP@0EEEE20000004oooo
o`@00000202ZZZX4000000Cooooo102ZZZZMooooobL0dLfY000V0=7=ZIgooooo102ZZZX4ooooo`@0
0000202ZZZX4000000Cooooo2@00000405EEE@@0ZZZZ3?ooool40:ZZZP@0EEEE20000004ooooo`@0
0000202ZZZX4000000Cooooo102ZZZZMooooobL0dLfY000V0=7=ZIgooooo102ZZZX4ooooo`@00000
202ZZZX4000000Cooooo2@00000405EEE@@0ZZZZ3?ooool40:ZZZP@0EEEE20000004ooooo`@00000
202ZZZX4000000Cooooo102ZZZZMooooobL0dLfY000V0=7=ZIgooooo102ZZZX4ooooo`@00000202Z
ZZX4000000Cooooo2@00000405EEE@@0ZZZZ3?ooool40:ZZZP@0EEEE20000004ooooo`@00000202Z
ZZX4000000Cooooo102ZZZZMooooobL0dLfY000V0=7=ZJ7ooooo102ZZZX4000000@0EEEE1?ooool8
000000@0EEEE1@2ZZZX<000000@0EEEE300000040:ZZZP@0EEEE20000004ooooo`@0EEEE10000004
0:ZZZZ7ooooo9`3AcJT002H0dLfYXOooool40:ZZZP@00000101EEED4ooooo`P00000101EEED50:ZZ
ZP`00000101EEED<000000@0ZZZZ101EEED8000000Cooooo101EEED4000000@0ZZZZXOoooolW0=7=
Z@009P3AcJVQooooo`@0ZZZZ1000000405EEE@Cooooo2000000405EEE@D0ZZZZ3000000405EEE@`0
0000102ZZZX405EEE@P000001?ooool405EEE@@00000102ZZZZQooooobL0dLfY000V0=7=ZJ7ooooo
102ZZZX4000000@0EEEE1?ooool8000000@0EEEE1@2ZZZX<000000@0EEEE300000040:ZZZP@0EEEE
20000004ooooo`@0EEEE100000040:ZZZZ7ooooo9`3AcJT002H0dLfYYOooool<0:ZZZP@0EEEE1000
00040:ZZZPD00000102ZZZX405EEE@@00000102ZZZX4000000@0EEEE102ZZZX4000000@0ZZZZ1000
000405EEE@`0ZZZZYOoooolW0=7=Z@009P3AcJVUooooo``0ZZZZ101EEED4000000@0ZZZZ1@000004
0:ZZZP@0EEEE100000040:ZZZP@00000101EEED40:ZZZP@00000102ZZZX4000000@0EEEE302ZZZZU
ooooobL0dLfY000V0=7=ZJGooooo302ZZZX405EEE@@00000102ZZZX5000000@0ZZZZ101EEED40000
00@0ZZZZ1000000405EEE@@0ZZZZ100000040:ZZZP@00000101EEED<0:ZZZZGooooo9`3AcJT002H0
dLfYYOooool<0:ZZZP@0EEEE100000040:ZZZPD00000102ZZZX405EEE@@00000102ZZZX4000000@0
EEEE102ZZZX4000000@0ZZZZ1000000405EEE@`0ZZZZYOoooolW0=7=Z@009P3AcJVYooooo`@0ZZZZ
2?ooool=000000Cooooo101EEED40:ZZZP@00000102ZZZX405EEE@Cooooo30000008ooooo`@0ZZZZ
ZOoooolW0=7=Z@009P3AcJVYooooo`@0ZZZZ2?ooool=000000Cooooo101EEED40:ZZZP@00000102Z
ZZX405EEE@Cooooo30000008ooooo`@0ZZZZZOoooolW0=7=Z@009P3AcJVYooooo`@0ZZZZ2?ooool=
000000Cooooo101EEED40:ZZZP@00000102ZZZX405EEE@Cooooo30000008ooooo`@0ZZZZZOoooolW
0=7=Z@009P3AcJVYooooo`@0ZZZZ2?ooool=000000Cooooo101EEED40:ZZZP@00000102ZZZX405EE
E@Cooooo30000008ooooo`@0ZZZZZOoooolW0=7=Z@009P3AcJV]ooooo`@0ZZZZ10000004ooooo`T0
00001?ooool40:ZZZP`0EEEE102ZZZX4ooooo`P000001?ooool4000000@0ZZZZ[OoooolW0=7=Z@00
9P3AcJV]ooooo`@0ZZZZ10000004ooooo`T000001?ooool40:ZZZP`0EEEE102ZZZX4ooooo`P00000
1?ooool4000000@0ZZZZ[OoooolW0=7=Z@009P3AcJV]ooooo`@0ZZZZ10000004ooooo`T000001?oo
ool40:ZZZP`0EEEE102ZZZX4ooooo`P000001?ooool4000000@0ZZZZ[OoooolW0=7=Z@009P3AcJV]
ooooo`@0ZZZZ10000004ooooo`T000001?ooool40:ZZZP`0EEEE102ZZZX4ooooo`P000001?ooool4
000000@0ZZZZ[OoooolW0=7=Z@009P3AcJVaooooo`P0ZZZZ101EEED5000000@0ZZZZ2?ooool40000
00Sooooo102ZZZX4000000@0EEEE202ZZZZaooooobL0dLfY000V0=7=ZK7ooooo202ZZZX405EEE@D0
0000102ZZZX8ooooo`@000002?ooool40:ZZZP@00000101EEED80:ZZZ[7ooooo9`3AcJT002H0dLfY
/Oooool80:ZZZP@0EEEE1@0000040:ZZZPSooooo10000008ooooo`@0ZZZZ1000000405EEE@P0ZZZZ
/OoooolW0=7=Z@009P3AcJVaooooo`P0ZZZZ101EEED5000000@0ZZZZ2?ooool4000000Sooooo102Z
ZZX4000000@0EEEE202ZZZZaooooobL0dLfY000V0=7=ZKGooooo102ZZZX4ooooo`D0EEEE1?ooool4
000000@0ZZZZ1?ooool40:ZZZP@000001?ooool405EEE@Cooooo102ZZZZeooooobL0dLfY000V0=7=
ZKGooooo102ZZZX4ooooo`D0EEEE1?ooool4000000@0ZZZZ1?ooool40:ZZZP@000001?ooool405EE
E@Cooooo102ZZZZeooooobL0dLfY000V0=7=ZKGooooo102ZZZX4ooooo`D0EEEE1?ooool4000000@0
ZZZZ1?ooool40:ZZZP@000001?ooool405EEE@Cooooo102ZZZZeooooobL0dLfY000V0=7=ZKGooooo
102ZZZX4ooooo`D0EEEE1?ooool4000000@0ZZZZ1?ooool40:ZZZP@000001?ooool405EEE@Cooooo
102ZZZZeooooobL0dLfY000V0=7=ZKWooooo102ZZZX9000000@0EEEE102ZZZX405EEE@@0ZZZZ101E
EED8000000@0ZZZZ^OoooolW0=7=Z@009P3AcJViooooo`@0ZZZZ2@00000405EEE@@0ZZZZ101EEED4
0:ZZZP@0EEEE200000040:ZZZ[Wooooo9`3AcJT002H0dLfY^Oooool40:ZZZPT00000101EEED40:ZZ
ZP@0EEEE102ZZZX405EEE@P00000102ZZZZiooooobL0dLfY000V0=7=ZKWooooo102ZZZX9000000@0
EEEE102ZZZX405EEE@@0ZZZZ101EEED8000000@0ZZZZ^OoooolW0=7=Z@009P3AcJVmooooo`T0ZZZZ
1?ooool405EEE@@00000101EEED4ooooo`P0ZZZZ_OoooolW0=7=Z@009P3AcJVmooooo`T0ZZZZ1?oo
ool405EEE@@00000101EEED4ooooo`P0ZZZZ_OoooolW0=7=Z@009P3AcJVmooooo`T0ZZZZ1?ooool4
05EEE@@00000101EEED4ooooo`P0ZZZZ_OoooolW0=7=Z@009P3AcJVmooooo`T0ZZZZ1?ooool405EE
E@@00000101EEED4ooooo`P0ZZZZ_OoooolW0=7=Z@009P3AcJW2ooooo`@0ZZZZ1?ooool4000000Co
oooo10000004ooooo`@0ZZZZ`OoooolW0=7=Z@009P3AcJW2ooooo`@0ZZZZ1?ooool4000000Cooooo
10000004ooooo`@0ZZZZ`OoooolW0=7=Z@009P3AcJW2ooooo`@0ZZZZ1?ooool4000000Cooooo1000
0004ooooo`@0ZZZZ`OoooolW0=7=Z@009P3AcJW2ooooo`@0ZZZZ1?ooool4000000Cooooo10000004
ooooo`@0ZZZZ`OoooolW0=7=Z@009P3AcJW6ooooo`@0ZZZZ1000000405EEE@@00000102ZZZ[5oooo
obL0dLfY000V0=7=ZLKooooo102ZZZX4000000@0EEEE100000040:ZZZ/Gooooo9`3AcJT002H0dLfY
a_ooool40:ZZZP@00000101EEED4000000@0ZZZZaOoooolW0=7=Z@009P3AcJW6ooooo`@0ZZZZ1000
000405EEE@@00000102ZZZ[5ooooobL0dLfY000V0=7=ZL[ooooo302ZZZ[9ooooobL0dLfY000V0=7=
ZL[ooooo302ZZZ[9ooooobL0dLfY000V0=7=ZL[ooooo302ZZZ[9ooooobL0dLfY000V0=7=ZL[ooooo
302ZZZ[9ooooobL0dLfY000V0=7=ZLkooooo102ZZZ[=ooooobL0dLfY000V0=7=ZLkooooo102ZZZ[=
ooooobL0dLfY000V0=7=ZLkooooo102ZZZ[=ooooobL0dLfY000V0=7=ZLkooooo102ZZZ[=ooooobL0
dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0
dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0
dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY003o0=7=ZNd0dLfY00260=7=Z@=0
00000P3AcJT2@00000@0dLfY0T0000040=7=Z@9000001@3AcJT3@00000<0dLfY0d0000020=7=Z@90
00000`3AcJT3@00000D0dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=Z@3AcJT5@000
00040=7=ZD0000100000@00000D0dLfY0d0000020=7=Z@9000000`3AcJT4@0000080dLfY0d000005
0=7=Z@=0000000<0dLfY@000040000000d0000020=7=Z@9000000`3AcJT5@00000030=7=ZD000010
000000=000000`3AcJT014000000dLfY0=7=Z@3AcJT4@00000<0dLfY0T0000040=7=Z@900000103A
cJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000<0dLfY0d0000030=7=Z@=00000103A
cJT2@00000<0dLfY0d0000030=7=Z@=00000103AcJT2@00000<0dLfY0d0000030=7=Z@=00000103A
cJT2@00008L0dLfY00270=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000
0P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3A
cJT00`3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=
Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=
Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@040=7=Z@04@000003AcJT0dLfY@0000080dLfY00A00000
0=7=Z@3AcJU000001@3AcJT014000000dLfY0=7=ZD0000050=7=Z@03@000003AcJT0dLfY0080dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3A
cJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@05@000003AcJT0dLfY0=7=ZD0000001@3AcJT01400
0000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000
0P3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=
Z@3AcJU00000103AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00A000000=7=Z@3AcJU00000
0P3AcJT00d000000dLfY0=7=Z@020=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT014000000
dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3A
cJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY08@0dLfY00240=7=Z@E0000000D0
dLfY@000003AcJT0dLfY@00000050=7=Z@04@000003AcJT0dLfY@0000080dLfY00=000000=7=Z@3A
cJT01D0000000`3AcJU00000@0000003@00000050=7=ZD000000dLfY0=7=ZD0000000`3AcJT3@000
00@0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY
0080dLfY0d0000020=7=Z@E00000103AcJT01D000000dLfY0=7=Z@3AcJU0000000@0dLfY00A00000
0=7=Z@3AcJU000000P3AcJT5@00000<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=
Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=
Z@020=7=Z@03@000003AcJT0dLfY0080dLfY00A000000=7=Z@3AcJU00000103AcJT00d000000dLfY
0=7=Z@040=7=Z@03@000003AcJT0dLfY0080dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY
0=7=Z@040=7=Z@04@000003AcJT0dLfY0=7=Z@=000000P3AcJT014000000dLfY0=7=ZD0000040=7=
Z@03@000003AcJT0dLfY0080dLfY0d0000020=7=Z@04@000003AcJT0dLfY@00000D0dLfY00A00000
0=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY00<0dLfY
00=000000=7=Z@3AcJT0Q03AcJT008@0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD0000030=7=Z@9000000`3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY
@0000080dLfY00A000000=7=Z@3AcJU000000`3AcJT2@00000<0dLfY00A000000=7=Z@3AcJU00000
1@3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY0080dLfY00E000000=7=Z@3AcJT0
dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJT0dLfY0T000005
0=7=Z@04@000003AcJT0dLfY0=7=Z@=000000`3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000
003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000
003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT00P3AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00=000000=7=Z@3AcJT00`3AcJT014000000dLfY0=7=Z@3AcJT2@00000H0dLfY00=000000=7=
Z@3AcJT00`3AcJT014000000dLfY0=7=Z@3AcJT2@00000<0dLfY00A000000=7=Z@3AcJU000000P3A
cJT3@00000H0dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@03@00000@0dLfY
0T0000030=7=Z@=000000`3AcJT3@00000@0dLfY0T0000270=7=Z@00Q@3AcJT00d000000dLfY@000
00020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY
0=7=ZD0000030=7=Z@03@000003AcJU0000000<0dLfY00=000000=7=ZD0000000P3AcJT014000000
dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU000000P3A
cJT014000000dLfY0=7=ZD0000040=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT01d000000
dLfY0=7=Z@3AcJU000000=7=ZD0000000`3AcJT00d000000dLfY0=7=Z@020=7=Z@04@000003AcJT0
dLfY@00000<0dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY@00000040=7=Z@05@000003A
cJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY00<0dLfY
00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=
Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000020=7=Z@05@000003AcJT0dLfY0=7=ZD000000
103AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=
Z@3AcJT00P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY0080dLfY00A00000
0=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD0000030=7=Z@03@000003AcJT0dLfY00<0dLfY
00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY00<0dLfY
00=000000=7=Z@3AcJT0QP3AcJT008H0dLfY0T0000030=7=Z@900000103AcJT3@00000<0dLfY0T00
00050=7=Z@900000103AcJT2@00000<0dLfY0T0000040=7=Z@=000000P3AcJT4@0000080dLfY1400
00030=7=Z@900000103AcJT3@00000@0dLfY0T0000030=7=Z@=000000`3AcJT2@00000@0dLfY0d00
00040=7=Z@9000000`3AcJT2@00000@0dLfY0T0000040=7=Z@900000103AcJT2@00000<0dLfY1400
00030=7=Z@900000103AcJT2@00000@0dLfY0T0000040=7=Z@=000000`3AcJT2@00000@0dLfY0T00
00040=7=Z@=000000`3AcJT3@00000<0dLfY0d0000030=7=Z@900000103AcJT3@00000<0dLfY0d00
00030=7=Z@=000000`3AcJT3@00000<0dLfY0d0000030=7=Z@=00000QP3AcJT00?l0dLfYk@3AcJT0
0?l0dLfYk@3AcJT00?l0dLfYk@3AcJT00?l0dLfYk@3AcJT00?l0dLfYk@3AcJT00?l0dLfYk@3AcJT0
0?l0dLfYk@3AcJT00?l0dLfYk@3AcJT00?l0dLfYk@3AcJT00?l0dLfYk@3AcJT00?l0dLfYk@3AcJT0
0?l0dLfYk@3AcJT00?l0dLfYk@3AcJT00?l0dLfYk@3AcJT00?l0dLfYk@3AcJT00?l0dLfYk@3AcJT0
0?l0dLfYk@3AcJT00?l0dLfYk@3AcJT00?l0dLfYk@3AcJT00?l0dLfYk@3AcJT00?l0dLfYk@3AcJT0
0001\
\>"],
  ImageRangeCache->{{{0, 491.375}, {763.75, 0}} -> {-0.0250052, -0.0393219, \
0.00213688, 0.00213688}, {{11.6875, 479.625}, {745.313, 518.125}} -> \
{-9.64097, -5.58915, 0.248888, 0.248888}, {{11.6875, 479.625}, {495.438, \
268.25}} -> {-9.64097, -67.7801, 0.248888, 0.248888}, {{11.6875, 479.625}, \
{245.563, 18.375}} -> {-9.64097, -129.971, 0.248888, 0.248888}}],

Cell["The above results are stored in file reversible4.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2D-CA: THE ALL-ONES PROBLEM", "Section"],

Cell[TextData[{
  "Suppose that each one of the",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(n\^2\)\)\)]],
  " squares forming a chessboard of size n x n can be made to be white or \
black by just touching it. Every time a square is touched, it changes its \
present color. Moreover, by touching a square we toggle not only the color of \
that one but all of the other four edge-adjacent squares as well. The \
All-Ones problem can be stated as follows: assuming that initially all \
squares are white, is it possible to choose a subset of squares in such a way \
that by touching all of them one at a time we are able to eventually set all \
squares to black? (we identify white with a 0 and black with a 1). In [4] it \
is shown that this problems has always a solution.\nA one-dimensional version \
of this problem is furnished by rule "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[
      StringJoin[ToString\  /@ \ IntegerDigits[#, 2, 3], "\< \[Rule] \>", 
          ToString\  /@ \ IntegerDigits[7 - #, 2, 3]] &, 
      Range[0, 7]]\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \({"000 \[Rule] 111", "001 \[Rule] 110", "010 \[Rule] 101", 
      "011 \[Rule] 100", "100 \[Rule] 011", "101 \[Rule] 010", 
      "110 \[Rule] 001", "111 \[Rule] 000"}\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell["\<\
which, although not local, can be thought off as changing the state of the \
cellular space by a local change at a time. In general, the All-Ones problem \
can be rephrased as finding out whether a cellular space filled with 1\.b4s \
is a Garden-of-Eden for a given value of n. In other words, whether the \
All-Ones state is reversible. 

The following comprises a table of the solutions corresponding to the \
All-Ones problem for chessboards of size n=2 through n=51. Black squares are \
the subset of squares sought, that is, the squares that, when touching them \
in any order, solve the problem.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ans = {};\)\), "\[IndentingNewLine]", 
    \(\(Do[\[IndentingNewLine]A = 
          Table[0, {n\^2}, {n\^2}]; \[IndentingNewLine]Do[
          i = 1 + \[LeftFloor]\(r - 1\)\/n\[RightFloor]; \[IndentingNewLine]j \
= r - \((i - 1)\) n; \[IndentingNewLine]neigh = 
            Select[{{i, j - 1}, {i, j}, {i, j + 1}, {i - 1, j}, {i + 1, 
                  j}}, \((\((0 < First[#] \[LessEqual] n)\) && \((0 < 
                        Last[#] \[LessEqual] 
                        n)\))\) &]; \[IndentingNewLine]\(\((A\
\[LeftDoubleBracket]r, #\[RightDoubleBracket] = 
                  1)\) &\)\  /@ \ \((\(\((\((First[#] - 1)\) n + 
                      Last[#])\) &\)\  /@ \ neigh)\), {r, 
            n\^2}]; \[IndentingNewLine]X = 
          LinearSolve[A, Table[1, {n\^2}], 
            Modulus \[Rule] 
              2]; \[IndentingNewLine]sol = \({i = 
                  1 + \[LeftFloor]\(# - 1\)\/n\[RightFloor], # - \((i - 1)\) 
                    n} &\)\  /@ \ 
            Flatten[Position[X, 1]]; \[IndentingNewLine]B = 
          Table[0, {n}, {n}]; \[IndentingNewLine]\(\((B\[LeftDoubleBracket]
                  First[#], Last[#]\[RightDoubleBracket] = 1)\) &\)\  /@ \ 
          sol; \[IndentingNewLine]AppendTo[ans, 
          ListDensityPlot[Reverse[\(-B\)]\ , FrameTicks \[Rule] None, 
            Frame \[Rule] False, Mesh \[Rule] False, 
            AspectRatio \[Rule] Automatic, 
            DisplayFunction \[Rule] Identity]], {n, 2, 
          51}];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[Partition[ans, 5]]];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.01852 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.04806 0.190476 [
[ 0 0 0 0 ]
[ 1 2.01852 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 2.01852 L
0 2.01852 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.04806 0.200176 0.224427 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0204583 0.0192308 0.0204583 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
47 string
47 47 8 [47 0 0 47 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00FF00FFFFFF00FF0000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFF00FFFF000000FF0000FFFFFF000000000000000000000000000000000000
0000000000000000000000
00FFFFFF00FFFFFF000000FF000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00
FF000000FFFFFFFF0000FFFF0000FFFF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000
0000FF00000000FFFFFF00FFFFFF00FFFF00FF00FF000000000000000000000000000000
0000000000000000FF00FF
00FFFFFFFFFF00FFFF00FFFFFF00FFFF00FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000
000000FFFF0000FFFFFF0000FFFF00FFFF00FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFF0000
FFFF00FFFF00FFFF00000000FF00FFFF00FFFFFFFF00FFFF000000000000000000000000
0000000000FFFF0000FFFF
FF0000FFFF0000FF00FF00FF00FF00FFFF000000FFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FF00000000FF
FF00FFFFFFFF000000FF00FFFFFFFFFF0000FF00FF00FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFF00000000000000FF
FF0000000000FFFFFF0000FFFF00FFFF00FFFF0000FFFF000000FF000000000000000000
0000FF0000FF000000FFFF
FFFFFFFFFF0000FF0000FFFFFFFFFFFF0000FFFF0000FFFF00FF0000FFFFFFFFFFFFFFFF
FF0000FFFFFFFF00FF0000
00FFFFFF00FF000000FF000000FF00FFFF00FF00FF00FF0000FF00FF00FFFFFFFFFFFFFF
00FF0000FF000000FF0000
FFFF00FFFFFFFFFFFFFF00FF0000FFFF000000FFFF000000FF0000FFFFFF0000000000FF
FFFFFF000000FFFF00FFFF
FFFFFFFFFF00FFFFFFFF00FFFF0000FF00000000FFFFFFFFFF00FFFFFFFF00FFFFFF00FF
FF0000FFFFFF0000FF00FF
0000FF00FFFFFF0000FF00FF00FF0000FF000000FFFFFFFFFF00000000FF0000FF0000FF
FF000000FF000000FFFFFF
000000FFFFFFFF0000000000FFFFFF00FFFF00FFFF000000FFFFFFFF0000FF000000FFFF
FFFF0000000000FFFFFF00
FF0000000000FFFF00FF000000000000FF000000FF00FF00FFFFFF00FF00FFFFFFFF0000
0000FF00FF00FF0000FFFF
00FF00FFFF00FF0000FFFF00FFFFFFFF000000000000FF00FF00FFFFFF00FFFFFF0000FF
FF00FF00FF00FF0000FFFF
FFFF000000000000FFFF000000FFFF0000000000FFFF000000FFFFFFFF00FF00FF00FF00
00000000000000FFFFFF00
FFFFFFFFFF00FFFF00FF000000FFFF00000000FF0000000000000000FF0000FF0000FF00
FF00FF00FF000000FFFFFF
0000FFFF00000000FF00FF00FFFFFFFF0000FFFF00FF000000FFFF0000FF00FF00FF0000
FF00FF00FFFF0000FF00FF
0000FFFF0000FF00FFFFFF0000000000FFFF00FF00FFFF00FF0000FF00FF000000FF00FF
00000000FF00FFFF00FFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFF000000FF0000FF0000FF0000FF0000FFFFFF0000FF
0000FFFF00FF0000FF0000
FFFF0000FFFFFF00FF0000FFFFFF00FFFF00FF00FF0000FF00FFFF00FF0000FF0000FF00
FFFF0000FFFF0000FF0000
00FF0000FF00FF00000000FF00FFFF0000000000FF00FFFFFF0000FFFFFF000000FFFFFF
0000000000FFFFFF00FFFF
FF00FFFF00FF00FFFF00FF00FFFF0000FF00FFFF00000000000000000000FFFFFF000000
00FF000000FFFF00FF00FF
00FF0000FFFFFF000000FFFF00FF00FFFF0000000000FFFFFF0000FFFF0000FF0000FFFF
FFFFFF00FFFFFFFFFFFFFF
FFFF000000000000FFFFFF00FF000000FFFFFFFF00FF00FF00FFFF0000FF000000FF00FF
FF000000000000FF00FF00
FFFFFF00FFFFFFFF00FFFFFFFF000000FFFFFF0000FFFF00FF00000000FFFFFFFFFFFFFF
FF00FF00FFFF0000FF00FF
0000000000FFFF00FFFF00FFFFFF00FFFF00FF00FFFF00FFFF00FF00FFFFFFFFFF00FF00
FF00FF000000FF00FFFF00
00FFFF0000FFFFFF00FFFFFF00000000FFFF000000FFFF00FF00FF0000000000FFFF00FF
000000FFFF00FF00FF00FF
000000FFFFFF0000FFFFFFFF00FF0000FF00000000FF00FF000000FFFFFFFF00FF00FFFF
000000000000000000FF00
FFFF0000FFFF0000000000FF00FFFFFF00000000FF00FFFF00000000FFFF000000FF00FF
FF0000FFFF00FF0000FFFF
FF00FF00FFFFFF00FFFF000000FFFF00000000FFFFFF00FFFF000000FFFF000000FFFFFF
00FFFF000000FFFFFFFFFF
FFFFFF00FF0000000000FFFFFFFFFF000000FF000000FFFF00FF00FFFFFFFF00FFFFFFFF
FF000000FFFFFFFFFF0000
00FFFF000000FF00FF0000FFFF00FFFF00FFFF00FF0000FFFFFF00000000000000000000
0000FFFF00FF0000FF0000
FFFFFFFFFFFFFF00FFFF00FFFFFFFF000000FF00FFFF00FFFFFFFFFFFFFFFF00FFFFFFFF
FFFF0000FF00000000FFFF
FF0000FFFFFFFF00FF0000FF00FFFF0000000000FF0000FF0000FFFFFFFF000000FFFFFF
FF000000FF0000000000FF
FF0000FF0000FF000000FF00FFFFFFFF0000FFFF0000FF000000FF0000FF000000FF0000
FF0000FF00FF00000000FF
FFFFFF00000000FFFFFFFFFF00000000FFFF000000FFFF0000FF00000000FF00FF000000
00FFFFFFFFFFFF0000FFFF
00FF000000000000FFFF000000FFFF00000000FFFF00FFFFFFFF00000000FF00FF000000
0000FF00FF0000FFFF0000
FF00000000000000FFFF00FFFF0000FFFFFFFF0000FFFFFFFFFFFF0000FF000000FF0000
000000FF00000000000000
00000000000000FFFFFF000000000000FFFF000000000000000000FFFFFF000000FFFF00
000000FF000000FFFF00FF
000000000000FF0000FFFFFFFF000000FFFF000000FFFFFFFFFF0000FFFFFF00FFFF00FF
0000FF00FF00FF00000000
FF00000000FFFF0000FFFFFF00FF00FFFFFFFF00FF00FFFFFF00FF00FF00000000FFFFFF
FFFFFFFFFF00FF00FF0000
00FF0000FF00FFFFFFFF00FFFFFF000000000000FFFFFF00FFFFFF000000FF0000FFFF00
FFFF00FFFF000000FFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.04806 0.39418 0.224427 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0200321 0.0192308 0.0200321 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
48 string
48 48 8 [48 0 0 48 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00FFFF0000FF00FFFFFF00FF00FFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFF00FF00
FFFFFF00FF0000FFFF00FF00
FF00FFFFFF000000FFFF00FFFF00FFFF000000FFFFFF00000000FFFFFF000000FFFF00FF
FF00FFFF000000FFFFFF00FF
00FF0000FFFF000000FFFFFF00FF00FF00FF00FFFFFF00FFFF00FFFFFF00FF00FF00FF00
FFFFFF000000FFFF0000FF00
FFFF0000FF00FF0000FFFFFFFFFFFF0000FF00FF00FF00000000FF00FF00FF0000FFFFFF
FFFFFF0000FF00FF0000FFFF
FFFFFFFF00FFFFFFFFFF0000FF000000FF000000FF00FFFFFFFF00FF000000FF000000FF
0000FFFFFFFFFF00FFFFFFFF
0000FF00FF0000FFFFFF00000000FFFFFF000000FFFF00FFFF00FFFF000000FFFFFF0000
0000FFFFFF0000FF00FF0000
000000FFFF0000FF00FFFF00FFFF00FFFFFF00FFFF00FFFFFFFF00FFFF00FFFFFF00FFFF
00FFFF00FF0000FFFF000000
FF000000FFFFFF00FFFF00000000FFFF00000000FFFF00000000FFFF00000000FFFF0000
0000FFFF00FFFFFF000000FF
00FF0000FFFF00FF00FF0000FF0000FF00FF0000FF0000FFFF0000FF0000FF00FF0000FF
0000FF00FF00FFFF0000FF00
FFFFFFFFFFFFFFFFFF00FFFFFFFF000000FFFFFF0000FF0000FF0000FFFFFF000000FFFF
FFFF00FFFFFFFFFFFFFFFFFF
FF00FFFF0000FF0000FF00FF0000FFFFFFFFFF0000FFFF0000FFFF0000FFFFFFFFFF0000
FF00FF0000FF0000FFFF00FF
FFFFFFFF0000000000FFFF00000000FFFF00FF00FF00FFFFFFFF00FF00FF00FFFF000000
00FFFF0000000000FFFFFFFF
00FF00FFFF00FF00FFFF0000000000FFFFFF0000FFFFFFFFFFFFFFFF0000FFFFFF000000
0000FFFF00FF00FFFF00FF00
FF00FFFF0000FF0000FF00000000FFFF000000FFFFFF00000000FFFFFF000000FFFF0000
0000FF0000FF0000FFFF00FF
00FF00FF00FF00FF0000FF0000FF00FF00FFFF0000FF00FFFF00FF0000FFFF00FF00FF00
00FF0000FF00FF00FF00FF00
FFFFFF0000FFFFFFFF00FFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFF00FFFFFFFF0000FFFFFF
FF000000FFFFFF000000FFFFFF00000000FFFF0000FF00FFFF00FF0000FFFF00000000FF
FFFF000000FFFFFF000000FF
FF00FFFF0000FF00FFFFFF00FF00FF00FF0000FFFFFF00000000FFFFFF0000FF00FF00FF
00FFFFFF00FF0000FFFF00FF
FF0000000000000000FFFFFF0000FF00FF000000FFFFFFFFFFFFFFFF000000FF00FF0000
FFFFFF0000000000000000FF
FFFFFFFF0000FF0000FF000000FF000000FF0000FF00FFFFFFFF00FF0000FF000000FF00
0000FF0000FF0000FFFFFFFF
00FFFF00FFFFFFFFFF0000FFFFFF000000FFFFFF00FFFF0000FFFF00FFFFFF000000FFFF
FF0000FFFFFFFFFF00FFFF00
FFFFFFFF00FF00FF0000FF00FFFFFF00FFFFFF00FF00FF0000FF00FF00FFFFFF00FFFFFF
00FF0000FF00FF00FFFFFFFF
FF000000FF00FF0000FFFFFFFF0000000000FFFFFFFF00FFFF00FFFFFFFF0000000000FF
FFFFFF0000FF00FF000000FF
FF00FF00FFFFFF00FF0000FFFF00FF00FF00FFFF0000FF0000FF0000FFFF00FF00FF00FF
FF0000FF00FFFFFF00FF00FF
FF00FF00FFFFFF00FF0000FFFF00FF00FF00FFFF0000FF0000FF0000FFFF00FF00FF00FF
FF0000FF00FFFFFF00FF00FF
FF000000FF00FF0000FFFFFFFF0000000000FFFFFFFF00FFFF00FFFFFFFF0000000000FF
FFFFFF0000FF00FF000000FF
FFFFFFFF00FF00FF0000FF00FFFFFF00FFFFFF00FF00FF0000FF00FF00FFFFFF00FFFFFF
00FF0000FF00FF00FFFFFFFF
00FFFF00FFFFFFFFFF0000FFFFFF000000FFFFFF00FFFF0000FFFF00FFFFFF000000FFFF
FF0000FFFFFFFFFF00FFFF00
FFFFFFFF0000FF0000FF000000FF000000FF0000FF00FFFFFFFF00FF0000FF000000FF00
0000FF0000FF0000FFFFFFFF
FF0000000000000000FFFFFF0000FF00FF000000FFFFFFFFFFFFFFFF000000FF00FF0000
FFFFFF0000000000000000FF
FF00FFFF0000FF00FFFFFF00FF00FF00FF0000FFFFFF00000000FFFFFF0000FF00FF00FF
00FFFFFF00FF0000FFFF00FF
FF000000FFFFFF000000FFFFFF00000000FFFF0000FF00FFFF00FF0000FFFF00000000FF
FFFF000000FFFFFF000000FF
FFFFFF0000FFFFFFFF00FFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFF00FFFFFFFF0000FFFFFF
00FF00FF00FF00FF0000FF0000FF00FF00FFFF0000FF00FFFF00FF0000FFFF00FF00FF00
00FF0000FF00FF00FF00FF00
FF00FFFF0000FF0000FF00000000FFFF000000FFFFFF00000000FFFFFF000000FFFF0000
0000FF0000FF0000FFFF00FF
00FF00FFFF00FF00FFFF0000000000FFFFFF0000FFFFFFFFFFFFFFFF0000FFFFFF000000
0000FFFF00FF00FFFF00FF00
FFFFFFFF0000000000FFFF00000000FFFF00FF00FF00FFFFFFFF00FF00FF00FFFF000000
00FFFF0000000000FFFFFFFF
FF00FFFF0000FF0000FF00FF0000FFFFFFFFFF0000FFFF0000FFFF0000FFFFFFFFFF0000
FF00FF0000FF0000FFFF00FF
FFFFFFFFFFFFFFFFFF00FFFFFFFF000000FFFFFF0000FF0000FF0000FFFFFF000000FFFF
FFFF00FFFFFFFFFFFFFFFFFF
00FF0000FFFF00FF00FF0000FF0000FF00FF0000FF0000FFFF0000FF0000FF00FF0000FF
0000FF00FF00FFFF0000FF00
FF000000FFFFFF00FFFF00000000FFFF00000000FFFF00000000FFFF00000000FFFF0000
0000FFFF00FFFFFF000000FF
000000FFFF0000FF00FFFF00FFFF00FFFFFF00FFFF00FFFFFFFF00FFFF00FFFFFF00FFFF
00FFFF00FF0000FFFF000000
0000FF00FF0000FFFFFF00000000FFFFFF000000FFFF00FFFF00FFFF000000FFFFFF0000
0000FFFFFF0000FF00FF0000
FFFFFFFF00FFFFFFFFFF0000FF000000FF000000FF00FFFFFFFF00FF000000FF000000FF
0000FFFFFFFFFF00FFFFFFFF
FFFF0000FF00FF0000FFFFFFFFFFFF0000FF00FF00FF00000000FF00FF00FF0000FFFFFF
FFFFFF0000FF00FF0000FFFF
00FF0000FFFF000000FFFFFF00FF00FF00FF00FFFFFF00FFFF00FFFFFF00FF00FF00FF00
FFFFFF000000FFFF0000FF00
FF00FFFFFF000000FFFF00FFFF00FFFF000000FFFFFF00000000FFFFFF000000FFFF00FF
FF00FFFF000000FFFFFF00FF
00FF00FFFF0000FF00FFFFFF00FF00FFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFFFF00FF00
FFFFFF00FF0000FFFF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.04806 0.588183 0.224427 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0196232 0.0192308 0.0196232 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
49 string
49 49 8 [49 0 0 49 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00000000FF0000000000000000FFFFFF00FF0000FF00000000FFFFFF0000FF00FF00FF00
FFFFFF00FFFFFFFFFFFFFFFFFF
00FFFF000000FFFFFFFFFFFF00FF00FFFF0000000000FFFF00FF00FF000000FF00FF00FF
FF00FFFFFF0000000000000000
000000FFFFFF00FFFFFFFF000000FFFF00000000FFFF00000000FF00FF0000FFFFFFFF00
FFFFFFFFFF00FFFFFFFFFFFF00
FFFF0000FF00FFFF0000FF00000000FF000000FF000000FF0000FFFFFFFFFFFFFF0000FF
FFFF0000FF0000FFFFFFFF0000
FF00FF0000FF00FF000000FF00000000FF00FFFF00FFFFFFFFFFFFFF00FFFF00FF000000
00FF000000FF00FF0000FF00FF
FFFFFFFF00FFFF00FF0000FFFF000000FF0000FF0000FF00FFFF00FFFFFFFFFF00FF00FF
0000FF0000FF00000000000000
00FF000000FF00FFFFFFFFFF00FF00FF00FF0000FF0000FFFFFFFFFFFF000000FFFF00FF
FF00FFFFFF00FFFF0000FF0000
FF0000FFFF00FF0000FFFFFFFFFF00FFFFFFFF00FFFF00000000FF00FF00FF0000FF00FF
0000FFFF00FF0000FFFFFFFFFF
0000FF0000FFFF0000FF0000FFFF00FFFF000000FF00FFFFFF0000FF0000FFFF00000000
00FFFFFFFFFF000000FF00FFFF
00FFFF000000FFFFFF000000FFFF00FFFF00FFFF00FF00FF00FF00FF00FFFF00FFFF00FF
FF000000FFFFFF000000FFFF00
0000FFFF0000FFFF000000FFFFFF00FFFF000000FFFFFF00FFFF00000000FFFF00000000
0000FF00FF0000FF000000FFFF
FF00FF00FFFFFFFF0000FF0000FF00FFFFFFFF00000000FF00FFFFFF0000FF0000FF00FF
FFFFFF00000000FFFF0000FFFF
000000FF00FF00FFFFFFFF00000000FF00FF00FFFFFF00FFFFFFFF00FFFF0000FFFF0000
FFFFFFFFFF00FFFF00FFFFFF00
000000FFFF00FFFFFFFFFFFF00FFFF00FF00FF00FF0000FFFF00FFFF000000FF00FFFF00
FF0000FF000000FFFF00FFFFFF
FF00FFFF00FF000000000000000000FFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFF0000
00000000000000FF00FFFF00FF
000000FFFFFF00FFFFFFFFFF00FF000000FF000000FF000000FFFF00FF00FF00FFFF0000
FF0000FF0000FF00FF00FFFFFF
000000FFFFFF0000FFFFFF0000FFFFFF000000FFFFFF00FF00FFFF00FFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00
FF00FFFF00FFFF00FF00FF00FFFFFF00FFFFFF00FFFF00FF00FFFF00FF00FF000000FFFF
00FFFF00FFFF00FF00FF00FFFF
000000FFFFFF000000FF00000000FFFF00FF00FFFFFF000000FFFF0000FFFF00FF00FFFF
FFFFFFFFFFFFFF00FF00FFFFFF
000000FFFFFF000000FF0000FF00FF00FF00FF0000FFFFFFFFFFFFFF0000FF00FF00FF00
FF0000FF000000FFFFFF000000
FF00FFFF00FFFF00FF00FFFFFF0000FFFFFFFF0000FFFFFFFF000000FF000000000000FF
0000000000FF0000000000FF00
000000FFFFFF0000FFFF00FFFFFF000000FFFFFFFFFF0000FF00FF00FFFFFF00FF0000FF
000000FFFFFFFFFFFFFFFFFF00
000000FFFFFF00FFFF00FFFF0000FFFF00FF00FFFFFF00000000FF00FFFF0000FFFFFF00
FF00FF00FF00FFFFFFFFFFFF00
FF00FFFF00FF0000FFFF00FF000000000000FFFF00FFFF00FFFF0000FFFF00FFFFFF00FF
FF00FFFF00FFFF00000000FF00
000000FFFF00FF00FF00FF00FF00FFFF000000FFFFFF0000000000FFFFFF000000FFFF00
FF00FF00FF00FF00FFFF000000
000000FF00FFFF0000FFFFFFFF000000FF0000FFFFFF0000FFFFFF0000FFFFFF00FF00FF
000000FFFFFF00000000FFFFFF
FF00FF00FF00FFFF000000FFFFFFFF00FFFFFFFF00FFFFFF00FF000000FFFF000000FFFF
0000000000000000FF0000FFFF
0000FFFFFFFFFF00FFFF00FF00FF0000FFFFFFFFFFFFFF00FF000000FFFFFF00000000FF
FF0000FFFFFF00FFFFFF00FF00
00FFFFFF00FFFFFF00000000FF0000FFFF000000FF00FFFFFF0000FF0000FFFF000000FF
00FFFF00FF00000000000000FF
000000FFFFFF000000FF0000FF00FF00FF00FF0000FFFFFFFFFFFFFF0000FF00FF00FF00
FF0000FF000000FFFFFF000000
FFFF00FFFFFF00FFFFFFFFFF0000FFFF0000FFFF0000000000FFFFFFFFFF00FFFF00FFFF
FF0000FF0000FF00FF00FF0000
FF0000FF00FF0000FF00FF0000FFFF0000FFFF00FFFFFFFF00FF0000FF00FF00FF00FFFF
FFFFFF00FFFFFFFF00FFFFFFFF
FF00FF00FF00FF0000FF0000FF00FF00FF00FFFF00FFFF000000000000FFFFFF0000FF00
00FF00FF00FF0000FF0000FFFF
FF00FFFFFFFFFFFF00FF00FFFFFF0000FFFFFF00FFFFFF0000FF00000000000000FF0000
0000FFFFFF000000FF0000FF00
FF00FFFF00FF000000000000000000FFFFFFFFFF0000FFFFFFFFFF0000FFFFFFFFFF0000
00000000000000FF00FFFF00FF
FF00FFFFFF0000FF00FF00FFFFFFFF00000000000000FFFFFF0000FFFF00FFFFFFFFFF00
0000FFFFFF00FFFFFF0000FF00
FF00FF000000FFFF00FF0000FFFF0000FFFFFFFF00FFFF00FF00000000FFFF00000000FF
00FF00FF00000000000000FFFF
FF000000FFFF00FF0000FF00FFFF00FF00FFFF000000FFFF00FF00FF0000FF00FFFF00FF
00FFFF000000FFFFFF00FFFFFF
FFFFFFFF0000FF00FF00FF00FFFF00FFFFFFFF000000FF00FFFF00FFFF00000000000000
00FF000000FF00FF0000000000
00FFFF000000FFFFFF000000FFFF00FFFF00FFFF00FF00FF00FF00FF00FFFF00FFFF00FF
FF000000FFFFFF000000FFFF00
FFFFFF0000FFFFFFFFFFFFFFFFFF00FFFFFFFF0000FFFFFFFF000000FF00000000000000
000000FF0000000000FF000000
FF00FFFFFF00000000FFFFFF00FF00FF00FFFF00FFFFFF0000000000FF00FF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF
FFFFFFFF0000FFFF00FF00FFFF000000FFFFFF000000FF00FF0000FF0000FF0000000000
000000FF0000000000FF0000FF
00FF00FF00FF00000000FFFF000000000000FFFFFF000000FFFFFFFF00FF00FFFFFF00FF
FF000000FFFFFF000000FF00FF
FF00FF0000FF00FF000000FF00000000FF00FFFF00FFFFFFFFFFFFFF00FFFF00FF000000
00FF000000FF00FF0000FF00FF
00FFFF00FF0000FFFF000000FF0000FFFF00FFFFFF00FFFF000000FF00FF00FF000000FF
00FFFF000000FFFFFFFF0000FF
FF00FF00FF00FFFF00FF0000FFFFFF00FF00FF0000FFFFFF00FF00000000FFFF0000FFFF
00FF00FF00000000FF0000FFFF
00FF0000000000FFFFFFFFFFFFFF00FF00000000000000FF00FFFFFF000000FFFFFF00FF
0000FFFFFF00FF000000FF0000
FFFF0000FF0000FFFF00FFFF00FFFFFF0000FF0000FF000000FFFF00FF0000FFFF00FF00
FF0000000000FFFFFFFFFF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.04806 0.782187 0.224427 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0192308 0.0192308 0.0192308 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
50 string
50 50 8 [50 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FFFF00FF00FFFFFF00FF00FFFFFF00000000000000FF0000FF0000FFFF00FFFF00
FFFF0000FF00FFFFFFFFFFFFFFFF
FF0000FFFFFF00FFFF00FFFF00FFFF00FF00FFFFFFFFFF00000000000000FFFFFFFFFFFF
FFFF000000FFFF00000000000000
FFFFFFFF0000FF00FFFFFF00FF00FFFF000000FFFFFF00FFFF0000FF00FFFF00FF0000FF
00FFFF000000FF00FFFFFFFFFF00
00FFFFFF0000FFFFFFFFFFFFFFFFFF00000000FF00FFFF0000FFFFFF0000FFFF00000000
FFFF00FF0000000000FFFFFF0000
FFFF00FFFFFFFFFF000000FF00FFFF000000FF00FFFF00000000FFFFFF00FF0000000000
00FFFFFFFF00FF0000FF00FF00FF
FFFFFFFFFFFF00FF00FF0000FFFFFFFF00FFFFFF00FF00000000FF000000000000000000
00FFFF000000FFFFFF00FF000000
0000FF0000FFFF0000FFFF000000000000000000FF00FF0000FF0000FF00FF0000000000
FFFFFF00FFFFFFFF00FFFF000000
0000000000FF0000FFFF00FFFFFFFFFF00FFFF00FFFFFFFFFFFF00FFFF00FFFF000000FF
0000FF0000FF00FFFF00FFFF00FF
FF00FF00FF0000FF00FFFF00FFFFFF0000000000FFFF00FFFFFF0000FF00FF00FF00FFFF
000000FF0000FFFF00FFFF000000
0000FF00FF00FFFFFFFF00FFFF00FF0000FFFFFFFFFFFFFF00FFFF00000000FFFF0000FF
FF0000FFFF0000FFFF00FF000000
00FF000000000000FFFFFF00FFFF00FFFF00FFFF0000FFFFFFFF00FFFF000000FFFF00FF
00FFFFFF00FF00FF00FF00FF00FF
00FF0000FF00FF00FF0000FFFF00FF0000FFFFFF0000FF00FFFFFF0000FF0000FF000000
FF00FFFFFFFF0000FFFFFFFF0000
0000FFFFFF00FF0000000000FFFFFF00000000FFFFFF00FFFF00000000FFFFFF00000000
FFFFFF00FFFFFF000000FFFFFF00
FF0000FFFF0000FFFF000000FFFFFFFF00FF00FFFF00FF00FF00FF00FFFFFF00000000FF
FFFFFFFFFF0000FFFF00FF000000
00FF00FFFFFF000000FF00FFFF00000000FF00FFFFFFFFFF0000FF000000FF000000FF00
000000FFFF00000000000000FFFF
FFFF00FF0000FFFF00FF0000FF00FFFFFF0000FF00FF000000FF00FFFF0000FF00FFFF00
FFFF00FFFFFF00FFFF00FFFF00FF
FFFF0000000000000000FF00000000FF0000FF00FF0000FFFFFFFF0000FF00FF0000FF00
000000FF0000000000000000FFFF
00FFFFFF0000FFFF0000FFFFFF00000000FFFFFFFF00FF00FF00000000FF0000FF0000FF
FFFFFF0000FF00FFFF00FF000000
FFFFFF00FFFF0000FFFFFFFF00FF00FFFF0000FFFF00FFFF0000FF00FF00FF00FFFF0000
FFFF0000FFFF00000000FFFFFF00
FF00FFFF0000000000FF00FFFFFF0000000000FFFF00FF0000FFFF00FFFFFF00FF00FF00
FFFF00FF00FFFFFFFFFFFFFF0000
FFFFFF0000FF00000000FFFFFFFFFFFFFF00FFFFFF000000FF00FF00FFFFFF0000FFFF00
FFFF00FFFFFFFFFFFFFF00FF00FF
00FFFF00FFFFFF00000000000000FFFF00000000FFFFFFFFFFFF0000FF00FFFF0000FF00
FFFF00FFFF00000000FFFF000000
FFFFFF00000000FF0000FFFFFF00FFFF0000FF00FFFFFFFF000000FF00FFFF00FF000000
FFFF00FFFF00FFFF00FF00000000
FF00FFFFFFFF00FFFFFF00FF0000FFFFFFFFFF00FF0000FF00FFFFFFFF00FFFFFFFFFFFF
FFFF00FFFF0000000000000000FF
FFFFFFFFFF0000FFFF00FF0000FFFF00FFFFFF00000000000000FF0000FFFFFF00FFFFFF
00FF00FFFFFFFFFF00FF0000FF00
00FF0000FF00FFFFFFFFFF00FF00FFFFFF00FFFFFF0000FF00000000000000FFFFFF00FF
FF0000FF00FFFF0000FFFFFFFFFF
FF0000000000000000FFFF00FFFFFFFFFFFFFFFF00FFFFFFFF00FF0000FF00FFFFFFFFFF
0000FF00FFFFFF00FFFFFFFF00FF
00000000FF00FFFF00FFFF00FFFF000000FF00FFFF00FF000000FFFFFFFF00FF0000FFFF
00FFFFFF0000FF00000000FFFFFF
000000FFFF00000000FFFF00FFFF00FF0000FFFF00FF0000FFFFFFFFFFFF00000000FFFF
00000000000000FFFFFF00FFFF00
FF00FF00FFFFFFFFFFFFFF00FFFF00FFFF0000FFFFFF00FF00FF000000FFFFFF00FFFFFF
FFFFFFFF00000000FF0000FFFFFF
0000FFFFFFFFFFFFFF00FF00FFFF00FF00FF00FFFFFF00FFFF0000FF00FFFF0000000000
FFFFFF00FF0000000000FFFF00FF
00FFFFFF00000000FFFF0000FFFF0000FFFF00FF00FF00FF0000FFFF00FFFF0000FFFF00
FF00FFFFFFFF0000FFFF00FFFFFF
000000FF00FFFF00FF0000FFFFFFFF0000FF0000FF00000000FF00FF00FFFFFFFF000000
00FFFFFF0000FFFF0000FFFFFF00
FFFF0000000000000000FF00000000FF0000FF00FF0000FFFFFFFF0000FF00FF0000FF00
000000FF0000000000000000FFFF
FF00FFFF00FFFF00FFFFFF00FFFF00FFFF00FF0000FFFF00FF000000FF00FF0000FFFFFF
00FF0000FF00FFFF0000FF00FFFF
FFFF00000000000000FFFF00000000FF000000FF000000FF0000FFFFFFFFFF00FF000000
00FFFF00FF000000FFFFFF00FF00
000000FF00FFFF0000FFFFFFFFFFFF00000000FFFFFF00FF00FF00FF00FFFF00FF00FFFF
FFFF000000FFFF0000FFFF0000FF
00FFFFFF000000FFFFFF00FFFFFF00000000FFFFFF00000000FFFF00FFFFFF00000000FF
FFFF0000000000FF00FFFFFF0000
0000FFFFFFFF0000FFFFFFFF00FF000000FF0000FF0000FFFFFF00FF0000FFFFFF0000FF
00FFFF0000FF00FF00FF0000FF00
FF00FF00FF00FF00FF00FFFFFF00FF00FFFF000000FFFF00FFFFFFFF0000FFFF00FFFF00
FFFF00FFFFFF000000000000FF00
000000FF00FFFF0000FFFF0000FFFF0000FFFF00000000FFFF00FFFFFFFFFFFFFF0000FF
00FFFF00FFFFFFFF00FF00FF0000
000000FFFF00FFFF0000FF000000FFFF00FF00FF00FF0000FFFFFF00FFFF0000000000FF
FFFF00FFFF00FF0000FF00FF00FF
FF00FFFF00FFFF00FF0000FF0000FF000000FFFF00FFFF00FFFFFFFFFFFF00FFFF00FFFF
FFFFFF00FFFF0000FF0000000000
000000FFFF00FFFFFFFF00FFFFFF0000000000FF00FF0000FF0000FF00FF000000000000
000000FFFF0000FFFF0000FF0000
000000FF00FFFFFF000000FFFF00000000000000000000FF00000000FF00FFFFFF00FFFF
FFFF0000FF00FF00FFFFFFFFFFFF
FF00FF00FF0000FF00FFFFFFFF000000000000FF00FFFFFF00000000FFFF00FF000000FF
FF00FF000000FFFFFFFFFF00FFFF
0000FFFFFF0000000000FF00FFFF00000000FFFF0000FFFFFF0000FFFF00FF00000000FF
FFFFFFFFFFFFFFFF0000FFFFFF00
00FFFFFFFFFF00FF000000FFFF00FF0000FF00FFFF00FF0000FFFF00FFFFFF000000FFFF
00FF00FFFFFF00FF0000FFFFFFFF
00000000000000FFFF000000FFFFFFFFFFFFFFFF00000000000000FFFFFFFFFF00FF00FF
FF00FFFF00FFFF00FFFFFF0000FF
FFFFFFFFFFFFFFFF00FF0000FFFF00FFFF00FFFF0000FF0000FF00000000000000FFFFFF
00FF00FFFFFF00FF00FFFF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.04806 0.97619 0.224427 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0188537 0.0192308 0.0188537 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
51 string
51 51 8 [51 0 0 51 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF0000FFFF00FF00FFFF0000FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF
00FF0000FFFF00FF00FFFF0000FF00
FF000000FFFFFF00FFFFFF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF000000FFFFFF00FFFFFF000000FF
000000FFFF0000FF0000FFFF000000FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF
000000FFFF0000FF0000FFFF000000
0000FF00FF0000FF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FF00FF0000FF0000FF00FF0000
FFFFFFFF00FFFF00FFFF00FFFFFFFFFF0000FF00FF000000FF00FF000000FF00FF0000FF
FFFFFFFF00FFFF00FFFF00FFFFFFFF
FFFF0000FF0000FF0000FF0000FFFFFF000000FF0000FF0000FF0000FF0000FF000000FF
FFFF0000FF0000FF0000FF0000FFFF
00FF0000FF0000FF0000FF0000FF00FFFF0000FF00FFFFFF00FF00FFFFFF00FF0000FFFF
00FF0000FF0000FF0000FF0000FF00
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00000000000000000000000000FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FF
00FF0000FF0000FF0000FF0000FF00FFFF00000000FFFFFF00FF00FFFFFF00000000FFFF
00FF0000FF0000FF0000FF0000FF00
FFFF0000FF0000FF0000FF0000FFFFFF0000FF00FF00FF0000FF0000FF00FF00FF0000FF
FFFF0000FF0000FF0000FF0000FFFF
FFFFFFFF00FFFF00FFFF00FFFFFFFFFF00FFFF00FFFF0000FF00FF0000FFFF00FFFF00FF
FFFFFFFF00FFFF00FFFF00FFFFFFFF
0000FF00FF0000FF0000FF00FF0000FF0000FF00FF0000FFFFFFFFFF0000FF00FF0000FF
0000FF00FF0000FF0000FF00FF0000
000000FFFF0000FF0000FFFF00000000FF0000000000FF0000FF0000FF0000000000FF00
000000FFFF0000FF0000FFFF000000
FF000000FFFFFF00FFFFFF0000000000FFFFFF00FFFFFF0000000000FFFFFF00FFFFFF00
00000000FFFFFF00FFFFFF000000FF
00FF0000FFFF00FF00FFFF00000000FFFFFF000000FFFFFF00FF00FFFFFF000000FFFFFF
00000000FFFF00FF00FFFF0000FF00
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF000000FF000000FF000000FF000000FF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFF0000FF00FF000000FFFFFF000000FF00FF0000FFFF00FFFF0000FF00FF000000
FFFFFF000000FF00FF0000FFFF00FF
FFFFFFFF000000FF0000FF0000FFFFFF0000FF00FF00FF0000FF0000FF00FF00FF0000FF
FFFF0000FF0000FF000000FFFFFFFF
00FF00FFFF0000FF00FFFFFF00FF0000FFFF00000000FF0000FF0000FF00000000FFFF00
00FF00FFFFFF00FF0000FFFF00FF00
FF00FFFF00FFFF00000000000000000000000000FFFF00FFFF00FFFF00FFFF0000000000
0000000000000000FFFF00FFFF00FF
00FF00FFFF00000000FFFFFF00FF0000FFFF00FF0000FF0000FF0000FF0000FF00FFFF00
00FF00FFFFFF00000000FFFF00FF00
FFFFFFFF0000FF00FF00FF0000FFFFFF000000FF0000FF0000FF0000FF0000FF000000FF
FFFF0000FF00FF00FF0000FFFFFFFF
FF00FFFF00FFFF00FFFF0000FFFFFF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000
FFFFFF0000FFFF00FFFF00FFFF00FF
FFFFFFFF0000FF00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF00FF0000FFFFFFFF
00FF00FFFF0000000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
000000FFFF0000000000FFFF00FF00
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FF
00FF00FFFF0000000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF00
000000FFFF0000000000FFFF00FF00
FFFFFFFF0000FF00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF0000FF0000FF00FF0000FFFFFFFF
FF00FFFF00FFFF00FFFF0000FFFFFF0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF0000
FFFFFF0000FFFF00FFFF00FFFF00FF
FFFFFFFF0000FF00FF00FF0000FFFFFF000000FF0000FF0000FF0000FF0000FF000000FF
FFFF0000FF00FF00FF0000FFFFFFFF
00FF00FFFF00000000FFFFFF00FF0000FFFF00FF0000FF0000FF0000FF0000FF00FFFF00
00FF00FFFFFF00000000FFFF00FF00
FF00FFFF00FFFF00000000000000000000000000FFFF00FFFF00FFFF00FFFF0000000000
0000000000000000FFFF00FFFF00FF
00FF00FFFF0000FF00FFFFFF00FF0000FFFF00000000FF0000FF0000FF00000000FFFF00
00FF00FFFFFF00FF0000FFFF00FF00
FFFFFFFF000000FF0000FF0000FFFFFF0000FF00FF00FF0000FF0000FF00FF00FF0000FF
FFFF0000FF0000FF000000FFFFFFFF
FF00FFFF0000FF00FF000000FFFFFF000000FF00FF0000FFFF00FFFF0000FF00FF000000
FFFFFF000000FF00FF0000FFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF000000FF000000FF000000FF000000FF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFF
00FF0000FFFF00FF00FFFF00000000FFFFFF000000FFFFFF00FF00FFFFFF000000FFFFFF
00000000FFFF00FF00FFFF0000FF00
FF000000FFFFFF00FFFFFF0000000000FFFFFF00FFFFFF0000000000FFFFFF00FFFFFF00
00000000FFFFFF00FFFFFF000000FF
000000FFFF0000FF0000FFFF00000000FF0000000000FF0000FF0000FF0000000000FF00
000000FFFF0000FF0000FFFF000000
0000FF00FF0000FF0000FF00FF0000FF0000FF00FF0000FFFFFFFFFF0000FF00FF0000FF
0000FF00FF0000FF0000FF00FF0000
FFFFFFFF00FFFF00FFFF00FFFFFFFFFF00FFFF00FFFF0000FF00FF0000FFFF00FFFF00FF
FFFFFFFF00FFFF00FFFF00FFFFFFFF
FFFF0000FF0000FF0000FF0000FFFFFF0000FF00FF00FF0000FF0000FF00FF00FF0000FF
FFFF0000FF0000FF0000FF0000FFFF
00FF0000FF0000FF0000FF0000FF00FFFF00000000FFFFFF00FF00FFFFFF00000000FFFF
00FF0000FF0000FF0000FF0000FF00
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00000000000000000000000000FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FF
00FF0000FF0000FF0000FF0000FF00FFFF0000FF00FFFFFF00FF00FFFFFF00FF0000FFFF
00FF0000FF0000FF0000FF0000FF00
FFFF0000FF0000FF0000FF0000FFFFFF000000FF0000FF0000FF0000FF0000FF000000FF
FFFF0000FF0000FF0000FF0000FFFF
FFFFFFFF00FFFF00FFFF00FFFFFFFFFF0000FF00FF000000FF00FF000000FF00FF0000FF
FFFFFFFF00FFFF00FFFF00FFFFFFFF
0000FF00FF0000FF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FF00FF0000FF0000FF00FF0000
000000FFFF0000FF0000FFFF000000FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF
000000FFFF0000FF0000FFFF000000
FF000000FFFFFF00FFFFFF000000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF000000FFFFFF00FFFFFF000000FF
00FF0000FFFF00FF00FFFF0000FF00FFFFFF00FF00FFFFFF00FF00FFFFFF00FF00FFFFFF
00FF0000FFFF00FF00FFFF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.242063 0.200176 0.41843 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0228938 0.0192308 0.0228938 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
42 string
42 42 8 [42 0 0 42 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF00FF000000FF00FFFF00FF00FF0000FF00FFFF00FF0000FF00FF00FFFF00FF0000
00FF00FF0000
000000FF0000FF0000FFFFFFFF00FF00000000FFFFFFFF00000000FF00FFFFFFFF0000FF
0000FF000000
FF0000FF00FFFFFF0000000000FFFF000000000000000000000000FFFF0000000000FFFF
FF00FF0000FF
00FFFF0000000000FFFFFFFF0000FFFF000000FFFFFFFF000000FFFF0000FFFFFFFF0000
000000FFFF00
FF00000000FFFF0000FFFF00FF00FF00FF00FF00FFFF00FF00FF00FF00FF00FFFF0000FF
FF00000000FF
0000FF00FF0000FF00FFFFFFFF0000FFFF00FFFFFFFFFFFF00FFFF0000FFFFFFFF00FF00
00FF00FF0000
00FFFF00FF0000FF00FF00FFFFFF0000FF00FFFF0000FFFF00FF0000FFFFFF00FF00FF00
00FF00FFFF00
0000FF0000FFFF000000FFFF0000FF000000FFFF0000FFFF000000FF0000FFFF000000FF
FF0000FF0000
FF0000FF00000000000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000000000
0000FF0000FF
00FF00FFFFFFFF0000000000FFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFF0000000000FF
FFFFFF00FF00
FFFF00FFFFFF00FF0000000000FF000000FF0000FFFF0000FF000000FF0000000000FF00
FFFFFF00FFFF
FFFF00FF00FFFFFFFF000000000000FF0000FFFFFFFFFFFF0000FF000000000000FFFFFF
FF00FF00FFFF
00FF0000FFFFFF0000FF000000FFFFFFFF0000FF0000FF0000FFFFFFFF000000FF0000FF
FFFF0000FF00
FF00FF000000FF0000FFFF00FF00FF0000FF000000000000FF0000FF00FF00FFFF0000FF
000000FF00FF
00FFFFFFFF0000FFFFFF0000FFFF000000FFFFFF0000FFFFFF000000FFFF0000FFFFFF00
00FFFFFFFF00
FF0000FF00FF0000FFFF00FFFF000000FFFFFF00FFFF00FFFFFF000000FFFF00FFFF0000
FF00FF0000FF
00000000FFFFFF00FFFF0000FF0000FF0000FFFF0000FFFF0000FF0000FF0000FFFF00FF
FFFF00000000
0000000000000000FFFFFF0000FFFFFF0000FF00000000FF0000FFFFFF0000FFFFFF0000
000000000000
FF000000FFFFFFFFFF0000FF0000FFFFFFFF000000000000FFFFFFFF0000FF0000FFFFFF
FFFF000000FF
00FF00FF00FFFFFFFF0000FFFF00FF00FF0000000000000000FF00FF00FFFF0000FFFFFF
FF00FF00FF00
FFFF00FFFFFF0000FFFFFFFF000000FF00000000000000000000FF000000FFFFFFFF0000
FFFFFF00FFFF
FFFF00FFFFFF0000FFFFFFFF000000FF00000000000000000000FF000000FFFFFFFF0000
FFFFFF00FFFF
00FF00FF00FFFFFFFF0000FFFF00FF00FF0000000000000000FF00FF00FFFF0000FFFFFF
FF00FF00FF00
FF000000FFFFFFFFFF0000FF0000FFFFFFFF000000000000FFFFFFFF0000FF0000FFFFFF
FFFF000000FF
0000000000000000FFFFFF0000FFFFFF0000FF00000000FF0000FFFFFF0000FFFFFF0000
000000000000
00000000FFFFFF00FFFF0000FF0000FF0000FFFF0000FFFF0000FF0000FF0000FFFF00FF
FFFF00000000
FF0000FF00FF0000FFFF00FFFF000000FFFFFF00FFFF00FFFFFF000000FFFF00FFFF0000
FF00FF0000FF
00FFFFFFFF0000FFFFFF0000FFFF000000FFFFFF0000FFFFFF000000FFFF0000FFFFFF00
00FFFFFFFF00
FF00FF000000FF0000FFFF00FF00FF0000FF000000000000FF0000FF00FF00FFFF0000FF
000000FF00FF
00FF0000FFFFFF0000FF000000FFFFFFFF0000FF0000FF0000FFFFFFFF000000FF0000FF
FFFF0000FF00
FFFF00FF00FFFFFFFF000000000000FF0000FFFFFFFFFFFF0000FF000000000000FFFFFF
FF00FF00FFFF
FFFF00FFFFFF00FF0000000000FF000000FF0000FFFF0000FF000000FF0000000000FF00
FFFFFF00FFFF
00FF00FFFFFFFF0000000000FFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFF0000000000FF
FFFFFF00FF00
FF0000FF00000000000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000000000
0000FF0000FF
0000FF0000FFFF000000FFFF0000FF000000FFFF0000FFFF000000FF0000FFFF000000FF
FF0000FF0000
00FFFF00FF0000FF00FF00FFFFFF0000FF00FFFF0000FFFF00FF0000FFFFFF00FF00FF00
00FF00FFFF00
0000FF00FF0000FF00FFFFFFFF0000FFFF00FFFFFFFFFFFF00FFFF0000FFFFFFFF00FF00
00FF00FF0000
FF00000000FFFF0000FFFF00FF00FF00FF00FF00FFFF00FF00FF00FF00FF00FFFF0000FF
FF00000000FF
00FFFF0000000000FFFFFFFF0000FFFF000000FFFFFFFF000000FFFF0000FFFFFFFF0000
000000FFFF00
FF0000FF00FFFFFF0000000000FFFF000000000000000000000000FFFF0000000000FFFF
FF00FF0000FF
000000FF0000FF0000FFFFFFFF00FF00000000FFFFFFFF00000000FF00FFFFFFFF0000FF
0000FF000000
0000FF00FF000000FF00FFFF00FF00FF0000FF00FFFF00FF0000FF00FF00FFFF00FF0000
00FF00FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.242063 0.39418 0.41843 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0223614 0.0192308 0.0223614 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
43 string
43 43 8 [43 0 0 43 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF00FF0000FFFF00FF000000FFFFFF0000FFFF00FFFF0000FFFFFF000000FF00FFFF
0000FF00FF0000
000000FF000000FFFFFF0000FF00FF00FF0000FFFFFFFFFF0000FF00FF00FF0000FFFFFF
000000FF000000
FF0000FF0000FFFF000000FFFF0000FF00FFFFFF00FF00FFFFFF00FF0000FFFF000000FF
FF0000FF0000FF
00FFFF00FFFF00FF00FFFF00FFFF00FFFF00FFFFFF00FFFFFF00FFFF00FFFF00FFFF00FF
00FFFF00FFFF00
FF0000FF0000FF00000000FFFF0000FF00FFFF0000FF0000FFFF00FF0000FFFF00000000
FF0000FF0000FF
000000FF0000FF0000FF0000FF00FF00FF00FF0000FF0000FF00FF00FF00FF0000FF0000
FF0000FF000000
0000FF00FFFF00FFFFFFFF000000FFFFFFFF00FFFF00FFFF00FFFFFFFF000000FFFFFFFF
00FFFF00FF0000
FFFFFFFF0000FF00FF0000FFFFFFFFFF0000FF0000FF0000FF0000FFFFFFFFFF0000FF00
FF0000FFFFFFFF
FFFF00000000FFFF00000000FFFF00FF0000FF0000FF0000FF0000FF00FFFF00000000FF
FF00000000FFFF
00FF00FF00FFFF0000000000FFFFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000000000
FFFF00FF00FF00
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000
FF0000FF0000FF
0000FF00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF
0000FF00FF0000
00FFFFFFFFFF00FFFFFFFFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFFFFFF
00FFFFFFFFFF00
000000FF000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFF
000000FF000000
FFFF000000FFFFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF
FFFF000000FFFF
FF00FFFFFF00FFFFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF00FFFFFF00FF
FFFF00FF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FFFF00FF00FFFF
0000FF00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00FF00FF0000
0000FFFFFFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFFFFFF0000
FFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FFFFFFFF
FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFF00FFFF00
FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00FFFF
FFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FFFFFFFF
0000FFFFFFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00FFFFFFFF0000
0000FF00FF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00FF00FF0000
FFFF00FF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FFFF00FF00FFFF
FF00FFFFFF00FFFFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
FF00FFFFFF00FF
FFFF000000FFFFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF
FFFF000000FFFF
000000FF000000FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFF
000000FF000000
00FFFFFFFFFF00FFFFFFFFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFFFFFFFF
00FFFFFFFFFF00
0000FF00FF0000FF0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000FF
0000FF00FF0000
FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000
FF0000FF0000FF
00FF00FF00FFFF0000000000FFFFFF00FFFF00FFFF00FFFF00FFFF00FFFFFF0000000000
FFFF00FF00FF00
FFFF00000000FFFF00000000FFFF00FF0000FF0000FF0000FF0000FF00FFFF00000000FF
FF00000000FFFF
FFFFFFFF0000FF00FF0000FFFFFFFFFF0000FF0000FF0000FF0000FFFFFFFFFF0000FF00
FF0000FFFFFFFF
0000FF00FFFF00FFFFFFFF000000FFFFFFFF00FFFF00FFFF00FFFFFFFF000000FFFFFFFF
00FFFF00FF0000
000000FF0000FF0000FF0000FF00FF00FF00FF0000FF0000FF00FF00FF00FF0000FF0000
FF0000FF000000
FF0000FF0000FF00000000FFFF0000FF00FFFF0000FF0000FFFF00FF0000FFFF00000000
FF0000FF0000FF
00FFFF00FFFF00FF00FFFF00FFFF00FFFF00FFFFFF00FFFFFF00FFFF00FFFF00FFFF00FF
00FFFF00FFFF00
FF0000FF0000FFFF000000FFFF0000FF00FFFFFF00FF00FFFFFF00FF0000FFFF000000FF
FF0000FF0000FF
000000FF000000FFFFFF0000FF00FF00FF0000FFFFFFFFFF0000FF00FF00FF0000FFFFFF
000000FF000000
0000FF00FF0000FFFF00FF000000FFFFFF0000FFFF00FFFF0000FFFFFF000000FF00FFFF
0000FF00FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.242063 0.588183 0.41843 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0218531 0.0192308 0.0218531 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
44 string
44 44 8 [44 0 0 44 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFF00FF00FF00FFFFFFFF00FF0000FFFF00000000FFFF0000FF00FFFFFFFF00FF
00FF00FFFFFFFFFF
00000000FFFF00FF00FFFF0000FFFF000000FFFF00FFFF00FFFF000000FFFF0000FFFF00
FF00FFFF00000000
00FFFF00FF00FFFFFF00FF0000FF000000FFFFFF00000000FFFFFF000000FF0000FF00FF
FFFF00FF00FFFF00
0000000000FF000000FF00FFFF000000FF0000FFFFFFFFFFFF0000FF000000FFFF00FF00
0000FF0000000000
FFFFFF0000FF00FF00FFFF00000000FFFF0000FFFFFFFFFFFF0000FFFF00000000FFFF00
FF00FF0000FFFFFF
FFFF00FFFF0000FF00FF0000FF00FF00FFFFFFFF00000000FFFFFFFF00FF00FF0000FF00
FF0000FFFF00FFFF
00FFFF000000FF00000000FFFF00FFFFFFFFFFFF00FFFF00FFFFFFFFFFFF00FFFF000000
00FF000000FFFF00
FFFF0000FFFFFF0000FFFF00FF00FFFF000000FF00000000FF000000FFFF00FF00FFFF00
00FFFFFF0000FFFF
FFFF00FF00FFFFFFFF0000FF0000FFFF00FF0000FFFFFFFF0000FF00FFFF0000FF0000FF
FFFFFF00FF00FFFF
00FF00FFFFFF00FF000000FF00FFFFFF00FFFF0000FFFF0000FFFF00FFFFFF00FF000000
FF00FFFFFF00FF00
FF0000FFFFFFFF000000FF00000000FF00FF00FF00FFFF00FF00FF00FF00000000FF0000
00FFFFFFFF0000FF
0000FFFF0000000000FFFF0000FF00000000FFFF00FFFF00FFFF00000000FF0000FFFF00
00000000FFFF0000
00FF00FF00FFFF00FF00FFFFFFFFFFFF000000FF00FFFF00FF000000FFFFFFFFFFFF00FF
00FFFF00FF00FF00
00FFFF0000000000FFFFFFFFFF00FF00FF00000000FFFF00000000FF00FF00FFFFFFFFFF
0000000000FFFF00
00FF000000FFFFFFFFFF0000FFFF00FFFFFF00FFFFFFFFFFFF00FFFFFF00FFFF0000FFFF
FFFFFF000000FF00
00000000FF00FFFF00FF0000FF00FF0000000000FF0000FF0000000000FF00FF0000FF00
FFFF00FF00000000
FFFF00FFFFFFFFFFFF00FFFF00FFFF00FFFF0000000000000000FFFF00FFFF00FFFF00FF
FFFFFFFFFF00FFFF
FF00000000FF000000FF0000FF00FF000000FF00FF0000FF00FF000000FF00FF0000FF00
0000FF00000000FF
FF0000FF000000FF00FF0000FFFF00FFFF00FF00FFFFFFFF00FF00FFFF00FFFF0000FF00
FF000000FF0000FF
FFFFFFFFFFFFFFFF0000FFFFFF00FF0000000000FFFFFFFF0000000000FF00FFFFFF0000
FFFFFFFFFFFFFFFF
00FFFF00FFFFFFFFFF0000FFFFFFFF00FF00FFFFFF0000FFFFFF00FF00FFFFFFFF0000FF
FFFFFFFF00FFFF00
FFFFFFFFFF00000000FF00FF00FFFF00FF0000FFFF0000FFFF0000FF00FFFF00FF00FF00
000000FFFFFFFFFF
FF0000FFFF00FFFF00FF0000FFFFFF0000FF00FFFFFFFFFFFF00FF0000FFFFFF0000FF00
FFFF00FFFF0000FF
FF0000FFFF0000000000FF000000FFFF00FF00FF00FFFF00FF00FF00FFFF000000FF0000
000000FFFF0000FF
FFFFFFFFFFFFFFFF0000FFFFFF00FF0000000000FFFFFFFF0000000000FF00FFFFFF0000
FFFFFFFFFFFFFFFF
00FFFF0000FFFF00FFFFFFFF0000000000FF0000000000000000FF0000000000FFFFFFFF
00FFFF0000FFFF00
FFFFFF0000FFFFFF00FF00FF0000FF00FFFFFF00FFFFFFFF00FFFFFF00FF0000FF00FF00
FFFFFF0000FFFFFF
FF00FFFFFFFF0000FF00FF00FFFFFF000000000000FFFF000000000000FFFFFF00FF00FF
0000FFFFFFFF00FF
FFFFFFFFFFFF0000FFFFFFFF00FFFFFFFFFFFF0000FFFF0000FFFFFFFFFFFF00FFFFFFFF
0000FFFFFFFFFFFF
00FF000000FFFFFFFFFF0000FFFF00FFFFFF00FFFFFFFFFFFF00FFFFFF00FFFF0000FFFF
FFFFFF000000FF00
FF0000FF00FFFFFF00FF000000FFFFFF00FFFF00FF0000FF00FFFF00FFFFFF000000FF00
FFFFFF00FF0000FF
0000FFFF00FF00FFFF00FF0000FFFFFFFFFF00FF00000000FF00FFFFFFFFFF0000FF00FF
FF00FF00FFFF0000
00FF00FF0000FFFF00FFFFFFFFFF0000FFFFFFFF00000000FFFFFFFF0000FFFFFFFFFF00
FFFF0000FF00FF00
00FFFF00FF0000FFFF0000FFFFFF0000FF00FFFFFF0000FFFFFF00FF0000FFFFFF0000FF
FF0000FF00FFFF00
00FF00FFFFFF00FF000000FF00FFFFFF00FFFF0000FFFF0000FFFF00FFFFFF00FF000000
FF00FFFFFF00FF00
0000FF00000000000000FF00FFFFFF00FF00FF000000000000FF00FF00FFFFFF00FF0000
0000000000FF0000
FF00FF00FFFF00FF00FFFFFF0000FFFFFFFF00FF00FFFF00FF00FFFFFFFF0000FFFFFF00
FF00FFFF00FF00FF
00000000000000FF000000000000FFFF0000FFFF00000000FFFF0000FFFF000000000000
FF00000000000000
0000FF00FFFFFF00FFFFFFFF00FFFFFF000000FFFFFFFFFFFF000000FFFFFF00FFFFFFFF
00FFFFFF00FF0000
FFFFFF0000FF00FF00FFFF00000000FFFF0000FFFFFFFFFFFF0000FFFF00000000FFFF00
FF00FF0000FFFFFF
FFFFFFFF0000FFFFFFFFFF0000FF00FF00FFFFFF00000000FFFFFF00FF00FF0000FFFFFF
FFFF0000FFFFFFFF
00000000FF000000FF00FFFFFFFF0000FF00FFFF00FFFF00FFFF00FF0000FFFFFFFF00FF
000000FF00000000
00FFFF00FFFFFF0000FFFFFFFFFFFF00FFFFFFFF00000000FFFFFFFF00FFFFFFFFFFFF00
00FFFFFF00FFFF00
00000000FFFF00FF0000000000000000FFFF00FFFFFFFFFFFF00FFFF0000000000000000
FF00FFFF00000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.242063 0.782187 0.41843 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0213675 0.0192308 0.0213675 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
45 string
45 45 8 [45 0 0 45 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF0000FFFF000000FFFF0000000000FF00000000FFFFFF00000000FF0000000000FFFF
000000FFFF0000FF00
FF000000FFFF00FF00FFFF00FFFFFF000000FFFF00FF00FF00FFFF000000FFFFFF00FFFF
00FF00FFFF000000FF
000000FFFFFF00FF00FFFF0000FF00FFFFFF00000000FF00000000FFFFFF00FF0000FFFF
00FF00FFFFFF000000
0000FF0000FF000000FFFFFF0000FF00FF0000FF0000FF0000FF0000FF00FF0000FFFFFF
000000FF0000FF0000
FFFFFF000000FFFFFFFF0000FF00FFFF0000FFFFFFFF00FFFFFFFF0000FFFF00FF0000FF
FFFFFF000000FFFFFF
FFFFFFFF000000FFFFFF0000FF00FF0000FF0000FF00FF00FF0000FF0000FF00FF0000FF
FFFF000000FFFFFFFF
00000000FF0000FF00FFFFFF00000000FFFF000000FFFFFF000000FFFF00000000FFFFFF
00FF0000FF00000000
00FFFF00FFFFFF00FFFFFF000000FFFF00FFFF00000000000000FFFF00FFFF000000FFFF
FF00FFFFFF00FFFF00
00000000FFFF00FF0000FF0000FF0000FFFF00FF00FFFFFF00FF00FFFF0000FF0000FF00
00FF00FFFF00000000
FFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFF0000FF0000FFFFFF000000FFFFFF0000
00FFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFF000000FFFFFF0000FFFFFFFF000000FFFFFFFF0000FFFFFF000000
FFFFFF0000FFFFFFFF
000000FF0000FF0000FF0000FF0000FFFFFF000000FFFFFF000000FFFFFF0000FF0000FF
0000FF0000FF000000
00FF0000FFFF000000FFFFFF00000000FFFF00FF0000FF0000FF00FFFF00000000FFFFFF
000000FFFF0000FF00
00FFFF0000000000FFFFFF0000000000FFFF00FFFF000000FFFF00FFFF0000000000FFFF
FF0000000000FFFF00
00FF00FFFFFF00FF0000FF00000000FFFFFF00FF00FFFFFF00FF00FFFFFF00000000FF00
00FF00FFFFFF00FF00
0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF00FF0000FF0000FF0000FF0000
00FF0000FF00FF0000
FF00FFFF0000FF00FF0000FFFFFFFF000000FF00FFFF00FFFF00FF000000FFFFFFFF0000
FF00FF0000FFFF00FF
0000FF0000FFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF0000FFFFFFFFFFFFFF
FFFFFFFF0000FF0000
00FF0000FF0000FF00FFFF0000000000FFFF000000FFFFFF000000FFFF0000000000FFFF
00FF0000FF0000FF00
00FF00FFFF000000FFFFFF00FFFFFF000000000000000000000000000000FFFFFF00FFFF
FF000000FFFF00FF00
00000000FFFF00000000FF0000FF00FFFFFF000000FFFFFF000000FFFFFF00FF0000FF00
000000FFFF00000000
FFFF0000FF00FF00FF0000FF0000FF00FF00FF00FF00FF00FF00FF00FF00FF0000FF0000
FF00FF00FF0000FFFF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FF
FFFF0000FF00FF00FF0000FF0000FF00FF00FF00FF00FF00FF00FF00FF00FF0000FF0000
FF00FF00FF0000FFFF
00000000FFFF00000000FF0000FF00FFFFFF000000FFFFFF000000FFFFFF00FF0000FF00
000000FFFF00000000
00FF00FFFF000000FFFFFF00FFFFFF000000000000000000000000000000FFFFFF00FFFF
FF000000FFFF00FF00
00FF0000FF0000FF00FFFF0000000000FFFF000000FFFFFF000000FFFF0000000000FFFF
00FF0000FF0000FF00
0000FF0000FFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF0000FFFFFFFFFFFFFF
FFFFFFFF0000FF0000
FF00FFFF0000FF00FF0000FFFFFFFF000000FF00FFFF00FFFF00FF000000FFFFFFFF0000
FF00FF0000FFFF00FF
0000FF00FF0000FF000000FF0000FF0000FF0000FF00FF00FF0000FF0000FF0000FF0000
00FF0000FF00FF0000
00FF00FFFFFF00FF0000FF00000000FFFFFF00FF00FFFFFF00FF00FFFFFF00000000FF00
00FF00FFFFFF00FF00
00FFFF0000000000FFFFFF0000000000FFFF00FFFF000000FFFF00FFFF0000000000FFFF
FF0000000000FFFF00
00FF0000FFFF000000FFFFFF00000000FFFF00FF0000FF0000FF00FFFF00000000FFFFFF
000000FFFF0000FF00
000000FF0000FF0000FF0000FF0000FFFFFF000000FFFFFF000000FFFFFF0000FF0000FF
0000FF0000FF000000
FFFFFFFF0000FFFFFF000000FFFFFF0000FFFFFFFF000000FFFFFFFF0000FFFFFF000000
FFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFF0000FF0000FFFFFF000000FFFFFF0000
00FFFFFFFFFFFFFFFF
00000000FFFF00FF0000FF0000FF0000FFFF00FF00FFFFFF00FF00FFFF0000FF0000FF00
00FF00FFFF00000000
00FFFF00FFFFFF00FFFFFF000000FFFF00FFFF00000000000000FFFF00FFFF000000FFFF
FF00FFFFFF00FFFF00
00000000FF0000FF00FFFFFF00000000FFFF000000FFFFFF000000FFFF00000000FFFFFF
00FF0000FF00000000
FFFFFFFF000000FFFFFF0000FF00FF0000FF0000FF00FF00FF0000FF0000FF00FF0000FF
FFFF000000FFFFFFFF
FFFFFF000000FFFFFFFF0000FF00FFFF0000FFFFFFFF00FFFFFFFF0000FFFF00FF0000FF
FFFFFF000000FFFFFF
0000FF0000FF000000FFFFFF0000FF00FF0000FF0000FF0000FF0000FF00FF0000FFFFFF
000000FF0000FF0000
000000FFFFFF00FF00FFFF0000FF00FFFFFF00000000FF00000000FFFFFF00FF0000FFFF
00FF00FFFFFF000000
FF000000FFFF00FF00FFFF00FFFFFF000000FFFF00FF00FF00FFFF000000FFFFFF00FFFF
00FF00FFFF000000FF
00FF0000FFFF000000FFFF0000000000FF00000000FFFFFF00000000FF0000000000FFFF
000000FFFF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.242063 0.97619 0.41843 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.020903 0.0192308 0.020903 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
46 string
46 46 8 [46 0 0 46 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF00FF000000FF00FFFF00FF000000FF00FFFFFF0000FFFFFF00FF000000FF00FFFF
00FF000000FF00FF0000
000000FF0000FF0000FFFFFFFF0000FF0000FFFF00FF0000FF00FFFF0000FF0000FFFFFF
FF0000FF0000FF000000
FF0000FF00FFFFFF000000000000FFFFFF0000FFFF00FFFF00FFFF0000FFFFFF00000000
0000FFFFFF00FF0000FF
00FFFF0000000000FFFFFFFFFFFF000000FF00FF00FF0000FF00FF00FF000000FFFFFFFF
FFFF0000000000FFFF00
FF00000000FFFF0000FFFFFFFF0000FF00FF0000FFFF0000FFFF0000FF00FF0000FFFFFF
FF0000FFFF00000000FF
0000FF00FF0000FF00FF0000FF00FFFF0000FF0000FFFFFFFF0000FF0000FFFF00FF0000
FF00FF0000FF00FF0000
00FFFF00FF0000FF00000000000000FFFF00FFFF00FFFFFFFF00FFFF00FFFF0000000000
0000FF0000FF00FFFF00
0000FF0000FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FFFF00FFFF0000FF0000
FF0000FF000000FF0000FFFFFFFFFF0000FF0000FF00000000FF0000FF0000FFFFFFFFFF
0000FF000000FF0000FF
00FF00FFFFFF00FF000000FF00FF0000FFFF00FFFF00000000FFFF00FFFF0000FF00FF00
0000FF00FFFFFF00FF00
FFFF00FFFF000000FF000000FF0000FF00FF0000FFFF0000FFFF0000FF00FF0000FF0000
00FF000000FFFF00FFFF
FFFF00FFFF000000FFFF0000FF00FFFFFF00FF00FF00FFFF00FF00FF00FFFFFF00FF0000
FFFF000000FFFF00FFFF
00FF00FFFFFF00FFFF00FFFF0000000000FFFF0000FF0000FF0000FFFF0000000000FFFF
00FFFF00FFFFFF00FF00
FF0000FF00000000FFFF00000000FFFF0000FFFF00FF0000FF00FFFF0000FFFF00000000
FFFF00000000FF0000FF
0000FF0000FF0000FF0000FF00FF0000FF00FF000000FFFF000000FF00FF0000FF00FF00
00FF0000FF0000FF0000
00FFFF00FFFFFFFF0000FFFF00FF0000FF000000000000000000000000FF0000FF00FFFF
0000FFFFFFFF00FFFF00
0000FF000000FF0000FF00FF0000FFFF00FFFF000000FFFF000000FFFF00FFFF0000FF00
FF0000FF000000FF0000
FF0000FFFF000000FFFFFF00FF000000FF0000FF00FF0000FF00FF0000FF000000FF00FF
FFFF000000FFFF0000FF
00FF000000FFFFFF000000FFFFFFFF00FF0000FF00FF0000FF00FF0000FF00FFFFFFFF00
0000FFFFFF000000FF00
FFFFFFFF0000FF0000FF000000FF000000FFFF000000FFFF000000FFFF000000FF000000
FF0000FF0000FFFFFFFF
FF00FF00FF000000FFFFFFFF00000000000000000000000000000000000000000000FFFF
FFFF000000FF00FF00FF
FFFF00FFFFFFFFFF0000FF00FFFF000000FFFF000000FFFF000000FFFF000000FFFF00FF
0000FFFFFFFFFF00FFFF
0000FF0000FFFF00000000FF0000FF00FF0000FF00FF0000FF00FF0000FF00FF0000FF00
000000FFFF0000FF0000
0000FF0000FFFF00000000FF0000FF00FF0000FF00FF0000FF00FF0000FF00FF0000FF00
000000FFFF0000FF0000
FFFF00FFFFFFFFFF0000FF00FFFF000000FFFF000000FFFF000000FFFF000000FFFF00FF
0000FFFFFFFFFF00FFFF
FF00FF00FF000000FFFFFFFF00000000000000000000000000000000000000000000FFFF
FFFF000000FF00FF00FF
FFFFFFFF0000FF0000FF000000FF000000FFFF000000FFFF000000FFFF000000FF000000
FF0000FF0000FFFFFFFF
00FF000000FFFFFF000000FFFFFFFF00FF0000FF00FF0000FF00FF0000FF00FFFFFFFF00
0000FFFFFF000000FF00
FF0000FFFF000000FFFFFF00FF000000FF0000FF00FF0000FF00FF0000FF000000FF00FF
FFFF000000FFFF0000FF
0000FF000000FF0000FF00FF0000FFFF00FFFF000000FFFF000000FFFF00FFFF0000FF00
FF0000FF000000FF0000
00FFFF00FFFFFFFF0000FFFF00FF0000FF000000000000000000000000FF0000FF00FFFF
0000FFFFFFFF00FFFF00
0000FF0000FF0000FF0000FF00FF0000FF00FF000000FFFF000000FF00FF0000FF00FF00
00FF0000FF0000FF0000
FF0000FF00000000FFFF00000000FFFF0000FFFF00FF0000FF00FFFF0000FFFF00000000
FFFF00000000FF0000FF
00FF00FFFFFF00FFFF00FFFF0000000000FFFF0000FF0000FF0000FFFF0000000000FFFF
00FFFF00FFFFFF00FF00
FFFF00FFFF000000FFFF0000FF00FFFFFF00FF00FF00FFFF00FF00FF00FFFFFF00FF0000
FFFF000000FFFF00FFFF
FFFF00FFFF000000FF000000FF0000FF00FF0000FFFF0000FFFF0000FF00FF0000FF0000
00FF000000FFFF00FFFF
00FF00FFFFFF00FF000000FF00FF0000FFFF00FFFF00000000FFFF00FFFF0000FF00FF00
0000FF00FFFFFF00FF00
FF0000FF000000FF0000FFFFFFFFFF0000FF0000FF00000000FF0000FF0000FFFFFFFFFF
0000FF000000FF0000FF
0000FF0000FFFF00FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FFFF00FFFF0000FF0000
00FFFF00FF0000FF00000000000000FFFF00FFFF00FFFFFFFF00FFFF00FFFF0000000000
0000FF0000FF00FFFF00
0000FF00FF0000FF00FF0000FF00FFFF0000FF0000FFFFFFFF0000FF0000FFFF00FF0000
FF00FF0000FF00FF0000
FF00000000FFFF0000FFFFFFFF0000FF00FF0000FFFF0000FFFF0000FF00FF0000FFFFFF
FF0000FFFF00000000FF
00FFFF0000000000FFFFFFFFFFFF000000FF00FF00FF0000FF00FF00FF000000FFFFFFFF
FFFF0000000000FFFF00
FF0000FF00FFFFFF000000000000FFFFFF0000FFFF00FFFF00FFFF0000FFFFFF00000000
0000FFFFFF00FF0000FF
000000FF0000FF0000FFFFFFFF0000FF0000FFFF00FF0000FF00FFFF0000FF0000FFFFFF
FF0000FF0000FF000000
0000FF00FF000000FF00FFFF00FF000000FF00FFFFFF0000FFFFFF00FF000000FF00FFFF
00FF000000FF00FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.436067 0.200176 0.612434 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0259875 0.0192308 0.0259875 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
37 string
37 37 8 [37 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFFFFFF0000FF00FF000000FFFFFFFF00FFFFFFFF000000FF00FF0000FFFFFFFF00
00
0000FF0000FF000000FF0000FF00FF0000FFFFFF0000FF00FF0000FF000000FF0000FF00
00
FFFF00000000FF0000FF00FFFF00000000FFFFFF00000000FFFF00FF0000FF00000000FF
FF
FF0000000000FFFFFF000000FFFFFF00FFFF00FFFF00FFFFFF000000FFFFFF0000000000
FF
FF00000000FFFFFF00000000FFFF000000FFFFFF000000FFFF00000000FFFFFF00000000
FF
FFFF0000FF0000FF000000FFFFFF000000FFFFFF000000FFFFFF000000FF0000FF0000FF
FF
0000FFFFFF000000FF00FF0000FFFF00FFFF00FFFF00FFFF0000FF00FF000000FFFFFF00
00
000000FFFFFF0000FF00FF0000FF000000FFFFFF000000FF0000FF00FF0000FFFFFF0000
00
FF0000FF0000FFFF000000FFFF00000000FFFFFF00000000FFFF000000FFFF0000FF0000
FF
00FFFF00000000000000000000000000FFFF00FFFF00000000000000000000000000FFFF
00
FF0000000000FFFF000000FFFF0000FF00FFFFFF00FF0000FFFF000000FFFF0000000000
FF
0000FF0000FF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FF0000FF00
00
00FFFFFFFFFF0000FF00FF000000FF00FF000000FF00FF000000FF00FF0000FFFFFFFFFF
00
000000FFFFFFFFFF000000FF000000FF0000FF0000FF000000FF000000FFFFFFFFFF0000
00
FFFF00FF0000FF00000000FFFF0000FF00FFFFFF00FF0000FFFF00000000FF0000FF00FF
FF
FF000000000000000000FFFF00FFFF00000000000000FFFF00FFFF000000000000000000
FF
FF0000FF0000FF0000FF00FFFF00000000FFFFFF00000000FFFF00FF0000FF0000FF0000
FF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF
00
FFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF00FF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFF
FF
FF0000FF0000FF0000FF00FFFF00000000FFFFFF00000000FFFF00FF0000FF0000FF0000
FF
FF000000000000000000FFFF00FFFF00000000000000FFFF00FFFF000000000000000000
FF
FFFF00FF0000FF00000000FFFF0000FF00FFFFFF00FF0000FFFF00000000FF0000FF00FF
FF
000000FFFFFFFFFF000000FF000000FF0000FF0000FF000000FF000000FFFFFFFFFF0000
00
00FFFFFFFFFF0000FF00FF000000FF00FF000000FF00FF000000FF00FF0000FFFFFFFFFF
00
0000FF0000FF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFF0000FF00FF0000FF0000FF00
00
FF0000000000FFFF000000FFFF0000FF00FFFFFF00FF0000FFFF000000FFFF0000000000
FF
00FFFF00000000000000000000000000FFFF00FFFF00000000000000000000000000FFFF
00
FF0000FF0000FFFF000000FFFF00000000FFFFFF00000000FFFF000000FFFF0000FF0000
FF
000000FFFFFF0000FF00FF0000FF000000FFFFFF000000FF0000FF00FF0000FFFFFF0000
00
0000FFFFFF000000FF00FF0000FFFF00FFFF00FFFF00FFFF0000FF00FF000000FFFFFF00
00
FFFF0000FF0000FF000000FFFFFF000000FFFFFF000000FFFFFF000000FF0000FF0000FF
FF
FF00000000FFFFFF00000000FFFF000000FFFFFF000000FFFF00000000FFFFFF00000000
FF
FF0000000000FFFFFF000000FFFFFF00FFFF00FFFF00FFFFFF000000FFFFFF0000000000
FF
FFFF00000000FF0000FF00FFFF00000000FFFFFF00000000FFFF00FF0000FF00000000FF
FF
0000FF0000FF000000FF0000FF00FF0000FFFFFF0000FF00FF0000FF000000FF0000FF00
00
0000FFFFFFFF0000FF00FF000000FFFFFFFF00FFFFFFFF000000FF00FF0000FFFFFFFF00
00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.436067 0.39418 0.612434 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0253036 0.0192308 0.0253036 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
38 string
38 38 8 [38 0 0 38 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF0000FF00FF00FF00FF00FF000000FFFF0000FFFF000000FF00FF00FF00FF00FF0000
FF00
FF00000000FF00FF00FF00FF0000FF00FFFF0000FFFF00FF0000FF00FF00FF00FF000000
00FF
0000000000FFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFF000000
0000
00000000FFFFFF00FF00FFFF0000FF00FF00FFFF00FF00FF0000FFFF00FF00FFFFFF0000
0000
FF0000FF0000FFFF00FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00FFFF0000FF00
00FF
00FFFFFF0000FF00FF00000000FFFF0000000000000000FFFF00000000FF00FF0000FFFF
FF00
FF00FFFFFFFF00FFFF00FFFF000000FF00FFFFFFFF00FF000000FFFF00FFFF00FFFFFFFF
00FF
00FFFF00FF00FF00FF000000FFFF00FF0000FFFF0000FF00FFFF000000FF00FF00FF00FF
FF00
FF00FFFF00FFFFFF00FFFF0000000000FF00FFFF00FF0000000000FFFF00FFFFFF00FFFF
00FF
00FFFF00FF000000FF0000FFFFFF0000FF00FFFF00FF0000FFFFFF0000FF000000FF00FF
FF00
FF00FFFFFF00FF00FF000000FF00FFFF0000FFFF0000FFFF00FF000000FF00FF00FFFFFF
00FF
00FFFFFFFF00FF0000FF000000FF000000FFFFFFFF000000FF000000FF0000FF00FFFFFF
FF00
FF000000FF0000FF00FFFF0000FF00FFFF00000000FFFF00FF0000FFFF00FF0000FF0000
00FF
0000FF0000FF00FF00FF00FFFF0000000000FFFF0000000000FFFF00FF00FF00FF0000FF
0000
00FFFFFF00FF00000000FF00000000FFFFFF0000FFFFFF00000000FF00000000FF00FFFF
FF00
000000000000FFFF0000FF00FF00FF00FF00000000FF00FF00FF00FF0000FFFF00000000
0000
FFFFFFFF00000000FFFF0000FF00FFFF000000000000FFFF00FF0000FFFF00000000FFFF
FFFF
FFFFFF00FF00FF00000000FF0000FF0000000000000000FF0000FF00000000FF00FF00FF
FFFF
0000FFFFFF00FFFFFFFFFFFF00FF00000000000000000000FF00FFFFFFFFFFFF00FFFFFF
0000
0000FFFFFF00FFFFFFFFFFFF00FF00000000000000000000FF00FFFFFFFFFFFF00FFFFFF
0000
FFFFFF00FF00FF00000000FF0000FF0000000000000000FF0000FF00000000FF00FF00FF
FFFF
FFFFFFFF00000000FFFF0000FF00FFFF000000000000FFFF00FF0000FFFF00000000FFFF
FFFF
000000000000FFFF0000FF00FF00FF00FF00000000FF00FF00FF00FF0000FFFF00000000
0000
00FFFFFF00FF00000000FF00000000FFFFFF0000FFFFFF00000000FF00000000FF00FFFF
FF00
0000FF0000FF00FF00FF00FFFF0000000000FFFF0000000000FFFF00FF00FF00FF0000FF
0000
FF000000FF0000FF00FFFF0000FF00FFFF00000000FFFF00FF0000FFFF00FF0000FF0000
00FF
00FFFFFFFF00FF0000FF000000FF000000FFFFFFFF000000FF000000FF0000FF00FFFFFF
FF00
FF00FFFFFF00FF00FF000000FF00FFFF0000FFFF0000FFFF00FF000000FF00FF00FFFFFF
00FF
00FFFF00FF000000FF0000FFFFFF0000FF00FFFF00FF0000FFFFFF0000FF000000FF00FF
FF00
FF00FFFF00FFFFFF00FFFF0000000000FF00FFFF00FF0000000000FFFF00FFFFFF00FFFF
00FF
00FFFF00FF00FF00FF000000FFFF00FF0000FFFF0000FF00FFFF000000FF00FF00FF00FF
FF00
FF00FFFFFFFF00FFFF00FFFF000000FF00FFFFFFFF00FF000000FFFF00FFFF00FFFFFFFF
00FF
00FFFFFF0000FF00FF00000000FFFF0000000000000000FFFF00000000FF00FF0000FFFF
FF00
FF0000FF0000FFFF00FFFFFFFF00000000FFFFFFFF00000000FFFFFFFF00FFFF0000FF00
00FF
00000000FFFFFF00FF00FFFF0000FF00FF00FFFF00FF00FF0000FFFF00FF00FFFFFF0000
0000
0000000000FFFFFFFFFFFFFF00FFFF00FFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFF000000
0000
FF00000000FF00FF00FF00FF0000FF00FFFF0000FFFF00FF0000FF00FF00FF00FF000000
00FF
00FF0000FF00FF00FF00FF00FF000000FFFF0000FFFF000000FF00FF00FF00FF00FF0000
FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.436067 0.588183 0.612434 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0246548 0.0192308 0.0246548 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
39 string
39 39 8 [39 0 0 39 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
00FFFF00FFFF000000000000000000000000000000000000000000000000000000000000
000000
FFFF00FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000
0000FF0000000000FF000000000000000000000000000000000000000000000000000000
FF00FF
00000000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000
FF00FFFFFFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FF0000
000000FF00FFFFFF00FFFFFF000000000000000000000000000000000000000000FFFF00
00FFFF
00000000FFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000
0000FF
FF00000000FFFF0000FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
0000FF
00FF000000FF0000FF00FF00FF00FF000000000000000000000000000000FF0000FF0000
00FFFF
FFFFFF00FF0000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00
FF0000
FF000000FF00FF0000FF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FF0000FF000000
FF0000
FF00FFFF0000FF000000FFFF00FFFF00FFFF000000000000000000FFFFFFFF000000FFFF
00FFFF
FF00000000FF00FF000000FFFFFFFFFF00FF00FFFFFFFFFFFFFF00FFFF0000FFFFFF0000
FF00FF
FFFFFFFFFFFFFFFFFF0000FFFF000000FF000000FFFFFFFFFF0000FFFF000000FF000000
FFFFFF
00FFFFFFFF00FF0000FFFFFFFF00FF00FF000000FF000000FF00FFFFFFFF0000000000FF
FFFF00
FFFF0000FFFF00000000FF00FF00FF0000FF00FF0000FF00000000000000FF00FF00FF00
00FFFF
FFFF0000FF000000000000FF000000FF00FF00FF00FFFFFFFF00FFFFFF00FF00FF00FF00
00FFFF
00FFFFFF00000000000000FF000000FF00000000000000FF000000FF00000000000000FF
FFFF00
FFFFFF00000000000000FF00FF00FF00FFFF00FF00FF0000000000000000FF00FF000000
FFFFFF
FF00FF000000000000FFFFFFFF00FFFF000000FF00FFFFFF000000FF00FFFF00FFFF0000
FF00FF
FFFF00FF00000000FF0000FFFF00FF0000FFFF0000FFFF00FF00FFFF0000FF00FF00FFFF
00FFFF
0000FFFFFF0000FFFF0000FFFF000000FF000000FFFFFFFFFF0000FFFF00000000FF0000
FF0000
0000000000FFFF00FFFFFFFFFFFFFFFFFF00FFFF000000FFFFFF00FF00FFFF0000FF0000
FF0000
FF00FFFF000000FFFFFFFF0000FFFFFFFF00000000FF00FF00000000FF0000FFFF00FFFF
00FFFF
00000000FFFF00000000FF0000FF0000FFFFFFFFFFFF000000FF0000FF00000000FF0000
FF00FF
0000FF000000FFFFFF0000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FF0000
FFFFFF
FFFFFFFFFF0000FF00FF0000000000FFFF0000000000FFFFFF00FF00FFFF00FF0000FFFF
FFFF00
FFFF00FF00FF0000FFFFFFFFFF00FF00FF00FFFFFF00FF00FFFF00FF00FF0000FF0000FF
00FFFF
00FFFF00FFFFFF000000FFFF0000FFFF000000FF000000FFFF00FFFFFF00FF00FFFF0000
FFFFFF
FFFF00FF000000FFFF00FFFF00FFFF000000000000000000FFFF000000FFFF00FF00FF00
000000
FFFFFFFF00FF00000000FFFF0000FF00000000FF00000000FF0000FF0000FF0000FFFFFF
FFFF00
0000FFFF00FFFFFFFFFFFFFFFF0000FF0000FFFFFF0000FF0000FFFFFF0000FF000000FF
FF0000
0000FFFF00FFFFFFFFFF000000FF00FFFFFF000000FFFFFF00FF000000FF00FFFFFF00FF
FF00FF
FFFFFFFF00FF000000FF00FF00FF00FFFF0000FF0000FFFF00FF00FF00FF00FFFF0000FF
FF0000
FFFF00FF000000FF000000FF000000FFFF00FFFFFF00FFFF000000FF000000FFFF00FFFF
FFFF00
00FFFF00FFFFFFFFFFFFFF00FFFFFFFFFF0000000000FFFFFFFFFF00FFFFFFFFFF000000
000000
FFFF00FF00FFFF00FFFF00FF00FFFF00FFFFFFFFFFFFFF00FFFF00FF00FFFF00FFFFFFFF
FFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.436067 0.782187 0.612434 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00FFFFFFFFFFFFFF00FFFF0000FFFF000000000000FFFF0000FFFF00FFFFFFFFFFFF
FF00FF00
FF00FFFF0000000000FFFFFFFF0000FFFF00FFFFFFFF00FFFF0000FFFFFFFF0000000000
FFFF00FF
00FF00FF00FFFFFF00FFFF00FFFFFFFFFF0000FFFF0000FFFFFFFFFF00FFFF00FFFFFF00
FF00FF00
FFFFFF000000FF0000FFFFFFFFFFFF00FFFF00FFFF00FFFF00FFFFFFFFFFFF0000FF0000
00FFFFFF
FF00000000000000FFFF00FF0000FFFFFF0000FFFF0000FFFFFF0000FF00FFFF00000000
000000FF
FF00FF000000FFFF00FFFF000000FFFFFF00FFFFFFFF00FFFFFF000000FFFF00FFFF0000
00FF00FF
FF00FFFF00FF0000FFFF000000FFFF00FF000000000000FF00FFFF000000FFFF0000FF00
FFFF00FF
FF00FF0000FF000000FF0000FF00FFFF00FFFFFFFFFFFF00FFFF00FF0000FF000000FF00
00FF00FF
FF000000FF00FF000000FFFFFFFFFF00FF00FFFFFFFF00FF00FFFFFFFFFF000000FF00FF
000000FF
FFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFF0000FFFFFFFFFFFF00FF000000FFFFFFFF
FFFFFFFF
00FFFFFF00FF0000FF000000FFFF00FF00FFFF0000FFFF00FF00FFFF000000FF0000FF00
FFFFFF00
FFFF00FFFF000000FFFF000000FFFF00FFFFFFFFFFFFFFFF00FFFF000000FFFF000000FF
FF00FFFF
FFFFFFFF000000FFFF00FF0000FF00FF000000FFFF000000FF00FF0000FF00FFFF000000
FFFFFFFF
0000FFFF0000FF00FFFFFFFFFF00FFFF00FF00FFFF00FF00FFFF00FFFFFFFFFF00FF0000
FFFF0000
0000FFFFFFFFFFFFFFFF00FF00FF00FF00FF00FFFF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFF0000
FFFFFF00FFFF00FF00FFFF00FFFFFF00000000FFFF00000000FFFFFF00FFFF00FF00FFFF
00FFFFFF
FFFFFFFFFFFFFF00FFFF00FF0000000000FFFFFFFFFFFF0000000000FF00FFFF00FFFFFF
FFFFFFFF
000000FF000000FF00FFFFFF00FFFF00FF00FF0000FF00FF00FFFF00FFFFFF00FF000000
FF000000
00FF000000FF00FFFFFFFFFF00000000FFFF00000000FFFF00000000FFFFFFFFFF00FF00
0000FF00
00FFFFFFFFFF00FFFF0000FFFFFFFFFFFF000000000000FFFFFFFFFFFF0000FFFF00FFFF
FFFFFF00
00FFFFFFFFFF00FFFF0000FFFFFFFFFFFF000000000000FFFFFFFFFFFF0000FFFF00FFFF
FFFFFF00
00FF000000FF00FFFFFFFFFF00000000FFFF00000000FFFF00000000FFFFFFFFFF00FF00
0000FF00
000000FF000000FF00FFFFFF00FFFF00FF00FF0000FF00FF00FFFF00FFFFFF00FF000000
FF000000
FFFFFFFFFFFFFF00FFFF00FF0000000000FFFFFFFFFFFF0000000000FF00FFFF00FFFFFF
FFFFFFFF
FFFFFF00FFFF00FF00FFFF00FFFFFF00000000FFFF00000000FFFFFF00FFFF00FF00FFFF
00FFFFFF
0000FFFFFFFFFFFFFFFF00FF00FF00FF00FF00FFFF00FF00FF00FF00FF00FFFFFFFFFFFF
FFFF0000
0000FFFF0000FF00FFFFFFFFFF00FFFF00FF00FFFF00FF00FFFF00FFFFFFFFFF00FF0000
FFFF0000
FFFFFFFF000000FFFF00FF0000FF00FF000000FFFF000000FF00FF0000FF00FFFF000000
FFFFFFFF
FFFF00FFFF000000FFFF000000FFFF00FFFFFFFFFFFFFFFF00FFFF000000FFFF000000FF
FF00FFFF
00FFFFFF00FF0000FF000000FFFF00FF00FFFF0000FFFF00FF00FFFF000000FF0000FF00
FFFFFF00
FFFFFFFFFFFFFFFF000000FF00FFFFFFFFFFFF0000FFFFFFFFFFFF00FF000000FFFFFFFF
FFFFFFFF
FF000000FF00FF000000FFFFFFFFFF00FF00FFFFFFFF00FF00FFFFFFFFFF000000FF00FF
000000FF
FF00FF0000FF000000FF0000FF00FFFF00FFFFFFFFFFFF00FFFF00FF0000FF000000FF00
00FF00FF
FF00FFFF00FF0000FFFF000000FFFF00FF000000000000FF00FFFF000000FFFF0000FF00
FFFF00FF
FF00FF000000FFFF00FFFF000000FFFFFF00FFFFFFFF00FFFFFF000000FFFF00FFFF0000
00FF00FF
FF00000000000000FFFF00FF0000FFFFFF0000FFFF0000FFFFFF0000FF00FFFF00000000
000000FF
FFFFFF000000FF0000FFFFFFFFFFFF00FFFF00FFFF00FFFF00FFFFFFFFFFFF0000FF0000
00FFFFFF
00FF00FF00FFFFFF00FFFF00FFFFFFFFFF0000FFFF0000FFFFFFFFFF00FFFF00FFFFFF00
FF00FF00
FF00FFFF0000000000FFFFFFFF0000FFFF00FFFFFFFF00FFFF0000FFFFFFFF0000000000
FFFF00FF
00FF00FFFFFFFFFFFFFF00FFFF0000FFFF000000000000FFFF0000FFFF00FFFFFFFFFFFF
FF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.436067 0.97619 0.612434 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0234522 0.0192308 0.0234522 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
41 string
41 41 8 [41 0 0 41 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF00FF0000FFFF00FF000000FFFFFF000000FFFFFF000000FFFFFF0000FFFF00FF00
00FFFFFFFF
000000FF000000FFFFFF0000FF00FF00FF00FF00FF00FF00FF00FF00FF0000FFFFFF0000
00FF000000
FF0000FF0000FFFF000000FFFF0000FF0000FF0000FF0000FF0000FF00FFFFFF00000000
FF0000FF00
00FFFF00FFFF00FF00FFFF00FFFF00FF00FF00FF00FF00FF00FF00FFFF00FFFF00FF00FF
FF00FFFF00
FF0000FF0000FF00000000FFFF00000000FFFFFF000000FFFFFF00FF00FFFFFF00FF0000
FF0000FF00
000000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF00
00FF000000
0000FF00FFFF00FFFFFFFF0000FFFF00FF000000FFFFFF0000FFFF00FF000000FF00FFFF
00FFFFFFFF
FFFFFFFF0000FF00FF0000FF000000FF0000FF00FF00FF0000FF000000FF0000FF00FF00
00FFFFFFFF
FFFF00000000FFFF000000FFFFFF00FF00FFFF0000FF00FFFF00000000FFFFFF00000000
FFFF000000
00FF00FF00FFFF000000FFFFFF0000000000FFFF00FFFF0000000000FFFFFF000000FFFF
00FF00FF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00
0000FF00FF0000FFFFFF000000FFFFFFFFFF0000FF0000FFFFFFFFFF000000FFFFFF0000
FF00FF0000
00FFFFFFFFFF0000FFFFFF000000FF00FF0000FFFF00FF0000FFFFFFFF000000FFFFFFFF
0000FF00FF
000000FF0000FF00FF0000FF000000FF0000FF00FF00FF0000FF000000FF0000FF00FF00
00FF000000
FFFF00000000FF00000000FFFF0000FF00FFFFFF000000FFFF0000FF00FFFFFF00FF0000
FFFF000000
FF00FFFF00FF00FFFF00FFFF00FFFF0000000000000000000000FFFF00FFFF00FFFF00FF
00FFFF00FF
FFFF000000FFFF00000000FFFF00000000FFFFFF000000FFFFFF00FF00FFFFFF00FF00FF
FFFF000000
000000FFFFFF0000FF0000FF0000FF00FF00FF00FF00FF00FF00FF0000FF0000FF0000FF
FFFF000000
00FFFF00FFFF00FFFFFFFF0000FFFF00FFFF00FFFF00FFFF00FFFF00FF000000FF00FFFF
00FFFF00FF
000000FFFFFF000000FF0000FF00FF00FF00FF00FF00FF00FF00FF00FF0000FF000000FF
FFFF000000
FFFF000000FFFFFF000000FFFFFF000000FFFFFF000000FFFFFF000000FFFFFF000000FF
FFFF000000
FF00FFFF00FFFF00FFFFFF00000000000000000000000000000000000000FFFFFF00FFFF
00FFFF00FF
FFFF000000FFFFFF00FF0000FFFF000000FFFFFF000000FFFFFF00000000FF00000000FF
FFFF000000
000000FFFFFF0000FF0000FF0000FF00FF00FF00FF00FF00FF00FF0000FF0000FF0000FF
FFFF000000
00FFFF00FFFF0000FF00FFFF0000FF00FFFF00FFFF00FFFF00FFFFFFFFFF00FFFFFFFFFF
00FFFF00FF
000000FFFFFFFFFF000000FFFFFF0000FF00FF00FF00FF00FF0000FFFFFF000000FFFFFF
FFFF000000
FFFF00000000FF00000000FFFF0000FF00FFFFFF000000FFFF0000FF00FFFFFF00FF0000
FFFF000000
FF00FFFFFF0000000000FFFFFF00FFFFFF00000000000000FFFFFF00FFFFFF0000000000
FFFFFF00FF
FFFF00FF00FFFF0000FF0000FF0000000000FFFF00000000FFFF00FF0000FF0000FF00FF
FF00000000
0000FF00FF0000FFFFFF000000FFFFFFFFFF0000FF0000FFFFFFFFFF000000FFFFFF0000
FF00FF0000
0000FFFFFF000000FFFFFF000000FFFFFF000000FFFFFF000000FFFFFF000000FFFFFF00
0000FFFFFF
FFFFFFFFFFFF0000FF0000FF0000FF00FF0000FFFFFF0000FF00FF0000FF0000FF0000FF
FFFFFFFFFF
FFFF00000000FFFF000000FFFFFF00FF00FFFF0000FF00FFFF00000000FFFFFF00000000
FFFF000000
00FF00FFFF0000000000FFFFFF00FFFFFF00000000000000FFFFFF00FFFFFF0000000000
FFFF00FF00
FF00000000FFFFFF00FF0000FFFF00000000FF0000FF0000FFFF00000000FF00000000FF
FFFF00FF00
000000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF00
00FF000000
0000FFFFFF000000FF00FFFF0000FF00FFFF00FFFF00FFFF00FFFFFFFFFF00FFFFFFFF00
0000FFFFFF
FFFF000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
000000FFFF
FF0000FF0000FFFF000000FFFF0000FF0000FF0000FF0000FF0000FF00FFFFFF00000000
FF0000FF00
FF00FFFFFF00FFFF00FFFF00000000000000000000000000000000000000FFFF00FFFF00
FFFFFF00FF
FF0000000000FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00000000
FFFF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.630071 0.200176 0.806437 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0300481 0.0192308 0.0300481 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.630071 0.39418 0.806437 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0291375 0.0192308 0.0291375 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
33 string
33 33 8 [33 0 0 33 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.630071 0.588183 0.806437 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0282805 0.0192308 0.0282805 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
34 string
34 34 8 [34 0 0 34 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.630071 0.782187 0.806437 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0274725 0.0192308 0.0274725 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
35 string
35 35 8 [35 0 0 35 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.630071 0.97619 0.806437 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0267094 0.0192308 0.0267094 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
36 string
36 36 8 [36 0 0 36 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.824074 0.200176 1.00044 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0356125 0.0192308 0.0356125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
27 string
27 27 8 [27 0 0 27 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF0000FFFF00FF00FFFF0000FF0000FFFF00FF00FFFF0000FF00
FF000000FFFFFF00FFFFFF0000000000FFFFFF00FFFFFF000000FF
000000FFFF0000FF0000FFFF00FF00FFFF0000FF0000FFFF000000
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
FFFFFFFF00FFFF00FFFF0000FF00FF0000FFFF00FFFF00FFFFFFFF
FFFF0000FF0000FF000000FFFFFFFFFF000000FF0000FF0000FFFF
00FF0000FF0000FF00FFFF0000FF0000FFFF00FF0000FF0000FF00
FF00FFFF00FFFF00000000000000000000000000FFFF00FFFF00FF
00FF0000FF00000000FFFF0000FF0000FFFF00000000FF0000FF00
FFFF0000FF00FF00FF0000FFFFFFFFFF0000FF00FF00FF0000FFFF
FFFFFFFF0000FF00FF000000FF00FF000000FF00FF0000FFFFFFFF
0000FF0000FF000000FF000000FF000000FF000000FF0000FF0000
00000000FFFF000000FFFF0000FF0000FFFF000000FFFF00000000
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
00000000FFFF000000FFFF0000FF0000FFFF000000FFFF00000000
0000FF0000FF000000FF000000FF000000FF000000FF0000FF0000
FFFFFFFF0000FF00FF000000FF00FF000000FF00FF0000FFFFFFFF
FFFF0000FF00FF00FF0000FFFFFFFFFF0000FF00FF00FF0000FFFF
00FF0000FF00000000FFFF0000FF0000FFFF00000000FF0000FF00
FF00FFFF00FFFF00000000000000000000000000FFFF00FFFF00FF
00FF0000FF0000FF00FFFF0000FF0000FFFF00FF0000FF0000FF00
FFFF0000FF0000FF000000FFFFFFFFFF000000FF0000FF0000FFFF
FFFFFFFF00FFFF00FFFF0000FF00FF0000FFFF00FFFF00FFFFFFFF
0000FF00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF0000
000000FFFF0000FF0000FFFF00FF00FFFF0000FF0000FFFF000000
FF000000FFFFFF00FFFFFF0000000000FFFFFF00FFFFFF000000FF
00FF0000FFFF00FF00FFFF0000FF0000FFFF00FF00FFFF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.824074 0.39418 1.00044 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0343407 0.0192308 0.0343407 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
28 string
28 28 8 [28 0 0 28 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF0000FF00FF00FFFF00FFFF0000FFFF00FFFF00FF00FF0000FF00
FF00000000FF00FFFFFFFFFFFF0000FFFFFFFFFFFF00FF00000000FF
0000000000FFFF000000FF00FFFFFFFF00FF000000FFFF0000000000
00000000FFFF0000FF0000FFFFFFFFFFFF0000FF0000FFFF00000000
FF0000FF00FF00FFFFFF0000000000000000FFFFFF00FF00FF0000FF
00FFFFFFFF0000000000FFFFFFFFFFFFFFFF0000000000FFFFFFFF00
FF00FF00000000FFFF0000FFFFFFFFFFFF0000FFFF00000000FF00FF
00FF0000FF00FF0000FF00FF00000000FF00FF0000FF00FF0000FF00
FFFF00FFFF00FF0000FF000000FFFF000000FF0000FF00FFFF00FFFF
FFFF0000FF0000FFFF00FFFFFF0000FFFFFF00FFFF0000FF0000FFFF
00FFFF0000FF000000FF00FF00000000FF00FF000000FF0000FFFF00
FFFF00FF00FFFFFF00FFFF000000000000FFFF00FFFFFF00FF00FFFF
FFFFFFFF00FFFF0000FF0000000000000000FF0000FFFF00FFFFFFFF
0000FFFF00FFFF00FF00000000000000000000FF00FFFF00FFFF0000
0000FFFF00FFFF00FF00000000000000000000FF00FFFF00FFFF0000
FFFFFFFF00FFFF0000FF0000000000000000FF0000FFFF00FFFFFFFF
FFFF00FF00FFFFFF00FFFF000000000000FFFF00FFFFFF00FF00FFFF
00FFFF0000FF000000FF00FF00000000FF00FF000000FF0000FFFF00
FFFF0000FF0000FFFF00FFFFFF0000FFFFFF00FFFF0000FF0000FFFF
FFFF00FFFF00FF0000FF000000FFFF000000FF0000FF00FFFF00FFFF
00FF0000FF00FF0000FF00FF00000000FF00FF0000FF00FF0000FF00
FF00FF00000000FFFF0000FFFFFFFFFFFF0000FFFF00000000FF00FF
00FFFFFFFF0000000000FFFFFFFFFFFFFFFF0000000000FFFFFFFF00
FF0000FF00FF00FFFFFF0000000000000000FFFFFF00FF00FF0000FF
00000000FFFF0000FF0000FFFFFFFFFFFF0000FF0000FFFF00000000
0000000000FFFF000000FF00FFFFFFFF00FF000000FFFF0000000000
FF00000000FF00FFFFFFFFFFFF0000FFFFFFFFFFFF00FF00000000FF
00FF0000FF00FF00FFFF00FFFF0000FFFF00FFFF00FF00FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.824074 0.588183 1.00044 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0331565 0.0192308 0.0331565 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
29 string
29 29 8 [29 0 0 29 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFF0000FF00FFFF00FF0000FF0000FFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFF000000000000FFFFFFFF000000000000000000
FF00FFFF000000000000000000FF00FFFF00FFFF00FFFFFFFFFFFFFF00
FFFFFF00FF00FFFFFFFF0000FFFF0000FFFFFFFF0000FFFFFFFFFF0000
00FFFFFFFF0000FFFF00FFFF00FFFF00FFFF00FFFF00FF000000FF00FF
FFFF00FFFFFF00FFFFFF0000FFFF0000FFFFFFFF00000000FF00000000
FFFFFFFF000000FF0000000000FF00FFFF00FFFF0000FFFFFFFFFF0000
0000FFFF00FFFF0000FF000000000000FFFFFFFFFFFF00FF00FF00FFFF
0000FFFF00000000FFFFFF0000FF0000FFFF0000FF00FF00FF00FF00FF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF
FFFF0000FFFFFF0000FF0000FF00FFFF00FFFF00000000FF00FF00FF00
00FF0000FF00FF00FFFFFF0000FFFFFFFFFF00FF00FF0000FF00FF00FF
FF00FFFF00FF0000000000FF00000000FFFFFFFF00FFFF00FFFFFFFF00
00FF0000FFFF0000FFFF00FFFFFFFF00FF00FFFF00FF0000FFFF0000FF
FFFF000000FFFFFF000000FFFFFF000000FFFFFF000000FFFFFF000000
FFFFFF0000FFFF0000FFFFFF00FF0000000000FFFFFFFF0000FFFF0000
000000FFFFFFFF00FF00FFFFFF00FF0000FF00FFFFFF000000FF00FFFF
00FF0000FF00FF00FFFFFF0000FFFFFFFFFF00FF00FF0000FF00FF00FF
00FFFF0000FF0000FFFFFF00000000FFFFFF0000FF00FFFFFFFFFFFFFF
00FF00FF00FF00FFFF00FFFF00FF00FF00FFFF00FFFF00FF00FF00FF00
0000FFFF00000000FFFFFF0000FF0000FFFF0000FF00FF00FF00FF00FF
FF0000FFFFFF0000FFFFFF00FF00FF0000FF00FF00FFFFFFFFFFFFFF00
00FF00FFFF00FFFFFF00FF00FFFFFFFF000000FFFF0000FF00FF0000FF
FFFF00FFFFFF00FFFFFF0000FFFF0000FFFFFFFF00000000FF00000000
FFFF00FF0000FFFF000000FFFFFF000000FFFFFF00000000FF00000000
00FF0000000000FF00FFFF0000FFFF0000FF00FFFF0000FF00FF0000FF
FF00FFFF000000000000000000FF00FFFF00FFFF00FFFFFFFFFFFFFF00
00FF0000FF0000FF00FFFF00FF00FF0000FF00FFFF00FF00FF00FF00FF
FFFF0000FFFFFFFF00000000FFFFFF0000FFFFFF00FF00FF00FF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.824074 0.782187 1.00044 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0320513 0.0192308 0.0320513 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
30 string
30 30 8 [30 0 0 30 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF000000FF00FF0000000000000000000000000000000000000000
0000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF0000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FF0000FF000000FFFF00FFFF0000000000000000000000000000FF00FF
0000FFFF0000FF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF00000000
FF00000000FFFF00FF0000FF000000FFFFFFFFFFFFFFFFFFFF00FFFF0000
00FFFFFFFF00FF00000000FF000000FF0000000000000000FFFF0000FFFF
FF00FFFF00FF00FFFF00FF00FF00FF0000FFFFFFFFFFFF00FF00000000FF
00FFFFFFFFFFFF000000FFFFFF00FF00FF00FFFFFFFF00000000000000FF
FF000000FF000000FFFFFFFFFF000000FFFFFF0000FF0000FF000000FFFF
0000FF000000FFFF00FF0000FFFFFFFFFFFFFF000000FFFFFFFF00FF0000
00FFFFFFFFFF0000FF000000FFFFFFFF0000FFFF000000FF000000FF0000
000000FFFF000000FF0000FFFF0000FF0000FF00FF00000000FFFF00FFFF
FFFF00FFFF0000FF00FFFF00FF000000FFFF00FFFFFF00FFFF0000FF00FF
FF0000FFFFFFFFFFFF0000FF00FF00000000FF0000000000000000FFFFFF
FF00FFFF00FFFF00000000FFFFFFFF00FF00FF00FFFF00FFFF00FFFFFF00
FF0000FFFFFFFF00FF00FFFFFF000000FF0000000000000000000000FFFF
FFFF00FFFF00FF00FF000000FF00FFFF00FFFF00FFFF00FFFF00FF00FFFF
000000FFFFFF000000FFFF0000000000FF000000000000000000FF00FF00
00FFFFFF00000000000000FFFF00FF00FF00FF00FFFF00FFFFFF000000FF
0000FFFF00FF000000FF00000000FF000000FF0000000000FF0000000000
FF00FFFF00FFFF00FFFFFFFFFFFF00FFFFFF00FFFFFF0000000000000000
0000FFFF00FF00000000FFFFFF00FF00FF00FF00FF00FF00FF00000000FF
00FFFFFF00000000FF00FF00FFFFFFFF00FFFFFF00FFFF00FFFF0000FF00
000000FFFFFF00FFFF0000FFFFFF0000FF000000FF00FF00FF00FFFFFFFF
FFFF00FFFF000000FFFF000000FF0000FF00FF00FFFF000000FF00FF00FF
FF0000FFFF000000FF00FFFF0000FFFF0000FF00FF00000000FFFF00FFFF
FF00FFFFFFFF00FF00FF0000FF00000000FF000000000000FFFF00FF0000
FF000000000000FFFFFF0000FFFFFFFFFFFF0000FF0000FF00FFFFFF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.824074 0.97619 1.00044 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0310174 0.0192308 0.0310174 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
31 string
31 31 8 [31 0 0 31 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF00FF000000FF00FFFF0000FF00FF0000FFFF00FF000000FF00FF0000
000000FF0000FF0000FFFFFF000000FF000000FFFFFF0000FF0000FF000000
FF0000FF00FFFFFF000000FFFF0000FF0000FFFF000000FFFFFF00FF0000FF
00FFFF0000000000FFFF00FF00FFFF00FFFF00FF00FFFF0000000000FFFF00
FF00000000FFFF0000000000FF0000FF0000FF0000000000FFFF00000000FF
0000FF00FF0000FFFFFF0000FF0000FF0000FF0000FFFFFF0000FF00FF0000
00FFFF00FF000000FF00FFFF00FFFF00FFFF00FFFF00FF000000FF00FFFF00
0000FF0000FF000000FF0000FF0000FF0000FF0000FF000000FF0000FF0000
FF0000FF00FFFF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF0000FF
00FF00FF00FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF00FF00FF00
FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF
FFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFF
0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000
000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF000000
0000FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000
FFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFF
FFFF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FFFF
00FF00FF00FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF00FF00FF00
FF0000FF00FFFF0000FF0000FF0000FF0000FF0000FF0000FFFF00FF0000FF
0000FF0000FF000000FF0000FF0000FF0000FF0000FF000000FF0000FF0000
00FFFF00FF000000FF00FFFF00FFFF00FFFF00FFFF00FF000000FF00FFFF00
0000FF00FF0000FFFFFF0000FF0000FF0000FF0000FFFFFF0000FF00FF0000
FF00000000FFFF0000000000FF0000FF0000FF0000000000FFFF00000000FF
00FFFF0000000000FFFF00FF00FFFF00FFFF00FF00FFFF0000000000FFFF00
FF0000FF00FFFFFF000000FFFF0000FF0000FFFF000000FFFFFF00FF0000FF
000000FF0000FF0000FFFFFF000000FF000000FFFFFF0000FF0000FF000000
0000FF00FF000000FF00FFFF0000FF00FF0000FFFF00FF000000FF00FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.01808 0.200176 1.19444 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0437063 0.0192308 0.0437063 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
22 string
22 22 8 [22 0 0 22 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFFFF00FF0000FFFFFFFF0000FF00FFFFFF0000
0000FF00FFFF000000FF0000FF000000FFFF00FF0000
FFFF00FFFF000000FF00000000FF000000FFFF00FFFF
FF00FF00FF0000FFFF00000000FFFF0000FF00FF00FF
FFFFFFFF00FFFF00FFFF0000FFFF00FFFF00FFFFFFFF
00FF0000FF0000FFFF00FFFF00FFFF0000FF0000FF00
FF000000FF000000FFFF0000FFFF000000FF000000FF
000000FF00FF0000FF00000000FF0000FF00FF000000
0000FFFFFFFFFFFF000000000000FFFFFFFFFFFF0000
FFFF0000FF00FF0000000000000000FF00FF0000FFFF
FF00000000FF00000000000000000000FF00000000FF
FF00000000FF00000000000000000000FF00000000FF
FFFF0000FF00FF0000000000000000FF00FF0000FFFF
0000FFFFFFFFFFFF000000000000FFFFFFFFFFFF0000
000000FF00FF0000FF00000000FF0000FF00FF000000
FF000000FF000000FFFF0000FFFF000000FF000000FF
00FF0000FF0000FFFF00FFFF00FFFF0000FF0000FF00
FFFFFFFF00FFFF00FFFF0000FFFF00FFFF00FFFFFFFF
FF00FF00FF0000FFFF00000000FFFF0000FF00FF00FF
FFFF00FFFF000000FF00000000FF000000FFFF00FFFF
0000FF00FFFF000000FF0000FF000000FFFF00FF0000
0000FFFFFF00FF0000FFFFFFFF0000FF00FFFFFF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.01808 0.39418 1.19444 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.041806 0.0192308 0.041806 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
23 string
23 23 8 [23 0 0 23 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFF0000FF0000000000000000000000000000
000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF00
0000FF000000FF0000FF00FFFFFFFFFFFFFFFFFFFF0000
FFFFFF00FF000000FFFFFFFF0000000000000000FF00FF
FFFFFF00FFFFFFFF0000FFFF00FFFFFFFFFFFF00000000
0000FF00FFFFFF000000FFFF0000FFFFFFFF00FFFF0000
00000000FF00FF0000FFFFFFFF00FF0000FFFF0000FFFF
FF00FFFF00FF00FFFF0000000000000000FF00000000FF
00000000FFFFFF000000FFFFFF00FF00FF0000000000FF
0000FF0000000000FFFF00FF0000FF00FF00000000FFFF
FFFFFFFFFFFFFFFF0000FF0000FF000000FF0000FF0000
FFFF00FFFFFFFF000000FF00FFFF000000FFFFFFFF0000
00FFFFFF0000FF0000FF000000FFFF00FFFFFFFFFFFFFF
FFFFFFFF000000FFFFFF000000FF00000000000000FFFF
FF0000FFFF000000FFFFFF00FF000000FFFFFFFF00FF00
FF0000FF00FF0000FF000000FF0000FF00FFFF000000FF
FFFFFF00FFFFFFFF0000FFFF00FFFFFFFFFFFF00000000
00FF00FF0000FF0000FF0000FF00FF00FF00FFFF000000
FF00FFFF00000000FFFF0000FFFF00FF00FFFF00FF00FF
00FF00FFFF00FFFF00FFFFFFFF00FFFFFF00FFFFFF0000
FFFFFFFF00000000FFFFFFFFFFFF000000FFFFFFFFFF00
FF00FFFF0000FF0000000000000000FF00000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.01808 0.588183 1.19444 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0400641 0.0192308 0.0400641 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
24 string
24 24 8 [24 0 0 24 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFF00FF000000FF00FF00000000000000FFFFFFFFFFFF
FFFFFFFF0000FF0000FF0000FFFFFFFFFF00FF0000000000
FF00000000FFFFFF00FF00FF00FFFFFF00000000FFFFFF00
FF00FFFFFF000000000000FFFFFF00FF0000FFFF00FF0000
FF0000FF0000FFFF00FFFFFFFFFFFF00FFFF0000FF0000FF
FFFF000000FF00000000FF00000000FF00000000FF00FF00
0000FFFFFFFF00FF00000000FFFF00FF00FF00FF0000FFFF
000000FFFFFF00FFFF00FFFF0000000000FF00FF00FFFFFF
FF0000FF00FF00FF0000000000FF00FFFF00000000000000
00FFFF00FF0000000000FFFFFFFF0000000000FF00FFFF00
FF0000FFFF0000FF00FF00FFFFFFFFFFFF00FFFF00000000
00000000FFFFFFFF00FFFFFF0000FFFF000000FFFFFFFFFF
00000000FFFFFFFF00FFFFFF0000FFFF000000FFFFFFFFFF
FF0000FFFF0000FF00FF00FFFFFFFFFFFF00FFFF00000000
00FFFF00FF0000000000FFFFFFFF0000000000FF00FFFF00
FF0000FF00FF00FF0000000000FF00FFFF00000000000000
000000FFFFFF00FFFF00FFFF0000000000FF00FF00FFFFFF
0000FFFFFFFF00FF00000000FFFF00FF00FF00FF0000FFFF
FFFF000000FF00000000FF00000000FF00000000FF00FF00
FF0000FF0000FFFF00FFFFFFFFFFFF00FFFF0000FF0000FF
FF00FFFFFF000000000000FFFFFF00FF0000FFFF00FF0000
FF00000000FFFFFF00FF00FF00FFFFFF00000000FFFFFF00
FFFFFFFF0000FF0000FF0000FFFFFFFFFF00FF0000000000
00FFFF00FF000000FF00FF00000000000000FFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.01808 0.782187 1.19444 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0384615 0.0192308 0.0384615 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
25 string
25 25 8 [25 0 0 25 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF00FF0000FFFF00FFFF00FFFF00FFFF0000FF00FF0000
000000FF000000FFFFFFFFFFFFFFFFFFFFFF000000FF000000
FF0000FF0000FFFF00FF0000FF0000FF00FFFF0000FF0000FF
00FFFF00FFFF00FFFF00000000000000FFFF00FFFF00FFFF00
FF0000FF0000FFFF00000000FF00000000FFFF0000FF0000FF
000000FF000000FF000000FFFFFF000000FF000000FF000000
0000FF00FF000000FF00FF000000FF00FF000000FF00FF0000
FFFFFFFFFFFF0000FF00FF00FF00FF00FF0000FFFFFFFFFFFF
FFFF00FF0000FFFF00000000FF00000000FFFF0000FF00FFFF
00FFFF00000000000000FFFF00FFFF00000000000000FFFF00
FFFF00000000FFFF00FF0000FF0000FF00FFFF00000000FFFF
FFFF000000FF000000FF0000FF0000FF000000FF000000FFFF
00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00
FFFF000000FF000000FF0000FF0000FF000000FF000000FFFF
FFFF00000000FFFF00FF0000FF0000FF00FFFF00000000FFFF
00FFFF00000000000000FFFF00FFFF00000000000000FFFF00
FFFF00FF0000FFFF00000000FF00000000FFFF0000FF00FFFF
FFFFFFFFFFFF0000FF00FF00FF00FF00FF0000FFFFFFFFFFFF
0000FF00FF000000FF00FF000000FF00FF000000FF00FF0000
000000FF000000FF000000FFFFFF000000FF000000FF000000
FF0000FF0000FFFF00000000FF00000000FFFF0000FF0000FF
00FFFF00FFFF00FFFF00000000000000FFFF00FFFF00FFFF00
FF0000FF0000FFFF00FF0000FF0000FF00FFFF0000FF0000FF
000000FF000000FFFFFFFFFFFFFFFFFFFFFF000000FF000000
0000FF00FF0000FFFF00FFFF00FFFF00FFFF0000FF00FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.01808 0.97619 1.19444 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0369822 0.0192308 0.0369822 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
26 string
26 26 8 [26 0 0 26 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00FFFF0000FF00FFFF00000000FFFF00FF0000FFFF00FF00
FF00FFFFFF000000FFFFFF00FFFF00FFFFFF000000FFFFFF00FF
00FF0000FFFF00000000FF00000000FF00000000FFFF0000FF00
FFFF0000FF00FF00FF0000FFFFFFFF0000FF00FF00FF0000FFFF
FFFFFFFF00FFFF00FFFF0000FFFF0000FFFF00FFFF00FFFFFFFF
0000FF00FF00FF00FF00FF00FFFF00FF00FF00FF00FF00FF0000
000000FFFFFF000000FFFF00FFFF00FFFF000000FFFFFF000000
FF000000000000000000FF00FFFF00FF000000000000000000FF
00FF00FFFFFF000000000000FFFF000000000000FFFFFF00FF00
FFFF0000FF00FF000000FFFFFFFFFFFF000000FF00FF0000FFFF
FFFFFF0000FFFFFF00FF00FF0000FF00FF00FFFFFF0000FFFFFF
000000FF0000000000FFFF00000000FFFF0000000000FF000000
00FF00FFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFF00FF00
00FF00FFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFF00FF00
000000FF0000000000FFFF00000000FFFF0000000000FF000000
FFFFFF0000FFFFFF00FF00FF0000FF00FF00FFFFFF0000FFFFFF
FFFF0000FF00FF000000FFFFFFFFFFFF000000FF00FF0000FFFF
00FF00FFFFFF000000000000FFFF000000000000FFFFFF00FF00
FF000000000000000000FF00FFFF00FF000000000000000000FF
000000FFFFFF000000FFFF00FFFF00FFFF000000FFFFFF000000
0000FF00FF00FF00FF00FF00FFFF00FF00FF00FF00FF00FF0000
FFFFFFFF00FFFF00FFFF0000FFFF0000FFFF00FFFF00FFFFFFFF
FFFF0000FF00FF00FF0000FFFFFFFF0000FF00FF00FF0000FFFF
00FF0000FFFF00000000FF00000000FF00000000FFFF0000FF00
FF00FFFFFF000000FFFFFF00FFFF00FFFFFF000000FFFFFF00FF
00FF00FFFF0000FF00FFFF00000000FFFF00FF0000FFFF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.21208 0.200176 1.38845 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0565611 0.0192308 0.0565611 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
17 string
17 17 8 [17 0 0 17 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFFFFFF00FFFF00FFFF0000FFFFFF
0000FF0000FFFFFFFFFFFFFF0000FF0000
FFFF000000FFFF0000FF00FFFFFF000000
FF000000FFFFFF000000FFFFFF000000FF
FF0000FF0000FFFF00000000FF0000FF00
FFFFFFFF0000FF00FF00FF0000FFFFFFFF
00FFFFFFFFFF00FFFF00FFFF0000FF00FF
FFFF0000FF00FF00FF00FF00FF0000FFFF
FFFF000000FFFFFF000000FFFFFF000000
00FFFF0000000000000000000000FFFF00
FFFF00FF00FFFFFF000000FFFF00000000
FFFFFFFF0000FF00FF00FF0000FFFFFFFF
0000FFFFFF0000FFFF00FF000000FFFFFF
0000FF0000FF0000FF0000FF0000FF0000
FFFF000000FFFF0000FF00FFFFFF000000
FF000000FFFF00FF00FF00FFFF000000FF
FF0000FF00FFFFFF000000FFFF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.21208 0.39418 1.38845 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0534188 0.0192308 0.0534188 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
18 string
18 18 8 [18 0 0 18 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF00FF000000FFFF000000FF00FF0000
000000FF0000FF00FFFF00FF0000FF000000
FF0000FF00FFFF00FFFF00FFFF00FF0000FF
00FFFF000000FF00FFFF00FF000000FFFF00
FF00000000000000FFFF00000000000000FF
0000FF000000FFFFFFFFFFFF000000FF0000
00FFFFFF00FF00FF0000FF00FF00FFFFFF00
0000000000FFFF00000000FFFF0000000000
FFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFF
0000000000FFFF00000000FFFF0000000000
00FFFFFF00FF00FF0000FF00FF00FFFFFF00
0000FF000000FFFFFFFFFFFF000000FF0000
FF00000000000000FFFF00000000000000FF
00FFFF000000FF00FFFF00FF000000FFFF00
FF0000FF00FFFF00FFFF00FFFF00FF0000FF
000000FF0000FF00FFFF00FF0000FF000000
0000FF00FF000000FFFF000000FF00FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.21208 0.588183 1.38845 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0506073 0.0192308 0.0506073 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
19 string
19 19 8 [19 0 0 19 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000000000000000000000000000
00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000
FF00FFFF00FF00000000000000000000FF00FF
FFFFFF00000000FFFFFFFFFFFFFFFF00000000
00FFFF0000FFFF00FFFFFFFFFFFF00FFFF0000
FFFFFFFFFF0000FFFF00000000FFFF0000FFFF
FF0000FF00000000FF00FFFF00FF00000000FF
FF0000000000000000000000000000000000FF
FFFF00FF00000000FF00FFFF00FF000000FFFF
000000FFFF0000FFFF00000000FFFF00FF0000
00FFFFFF00FFFF00FFFFFFFFFFFF0000FF0000
0000FFFFFF0000FFFFFFFFFFFFFF00FF00FFFF
FF00FF00000000000000000000FF00FFFF00FF
00000000FF0000FFFFFFFFFF000000FF00FFFF
0000FFFFFFFFFF00FFFFFF00FFFFFF00FF0000
FFFF00FF00FF00FFFF00FFFF00FF00FFFF0000
FF00FF00FF00FF00FFFFFF00FF00FF00FFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.21208 0.782187 1.38845 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0480769 0.0192308 0.0480769 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
20 string
20 20 8 [20 0 0 20 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00FFFF00000000000000000000FFFF00FF00
FF00FFFFFF00FFFFFFFFFFFFFFFF00FFFFFF00FF
00FF0000FF0000FFFFFFFFFFFF0000FF0000FF00
FFFF000000FF00FF00000000FF00FF000000FFFF
FFFFFF0000FF000000FFFF000000FF0000FFFFFF
000000FFFF00FFFFFF0000FFFFFF00FFFF000000
00FF000000FF00FF00000000FF00FF000000FF00
00FFFFFF00FFFF000000000000FFFF00FFFFFF00
00FFFF0000FF0000000000000000FF0000FFFF00
00FFFF00FF00000000000000000000FF00FFFF00
00FFFF00FF00000000000000000000FF00FFFF00
00FFFF0000FF0000000000000000FF0000FFFF00
00FFFFFF00FFFF000000000000FFFF00FFFFFF00
00FF000000FF00FF00000000FF00FF000000FF00
000000FFFF00FFFFFF0000FFFFFF00FFFF000000
FFFFFF0000FF000000FFFF000000FF0000FFFFFF
FFFF000000FF00FF00000000FF00FF000000FFFF
00FF0000FF0000FFFFFFFFFFFF0000FF0000FF00
FF00FFFFFF00FFFFFFFFFFFFFFFF00FFFFFF00FF
00FF00FFFF00000000000000000000FFFF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.21208 0.97619 1.38845 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0457875 0.0192308 0.0457875 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
21 string
21 21 8 [21 0 0 21 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00FFFF00000000FFFFFF00000000FFFF00FF00
FF00FFFFFF00FFFF00FF00FF00FFFF00FFFFFF00FF
00FF0000FF0000000000FF0000000000FF0000FF00
FFFF000000FFFFFF0000FF0000FFFFFF000000FFFF
FFFFFF000000FF00FFFF00FFFF00FF000000FFFFFF
000000FF000000FF0000FF0000FF000000FF000000
00FF00FFFF0000FF0000FF0000FF0000FFFF00FF00
00FF00FF00FFFF00FFFF00FFFF00FFFF00FF00FF00
00000000FF0000FF0000FF0000FF0000FF00000000
FFFF0000FF0000FF0000FF0000FF0000FF0000FFFF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF
FFFF0000FF0000FF0000FF0000FF0000FF0000FFFF
00000000FF0000FF0000FF0000FF0000FF00000000
00FF00FF00FFFF00FFFF00FFFF00FFFF00FF00FF00
00FF00FFFF0000FF0000FF0000FF0000FFFF00FF00
000000FF000000FF0000FF0000FF000000FF000000
FFFFFF000000FF00FFFF00FFFF00FF000000FFFFFF
FFFF000000FFFFFF0000FF0000FFFFFF000000FFFF
00FF0000FF0000000000FF0000000000FF0000FF00
FF00FFFFFF00FFFF00FF00FF00FFFF00FFFFFF00FF
00FF00FFFF00000000FFFFFF00000000FFFF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.40608 0.200176 1.58245 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0801282 0.0192308 0.0801282 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
12 string
12 12 8 [12 0 0 12 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00FFFFFFFFFFFF00FF00
FF00FFFF00000000FFFF00FF
00FF00FF00FFFF00FF00FF00
FFFFFF000000000000FFFFFF
FF00000000FFFF00000000FF
FF00FF00FF0000FF00FF00FF
FF00FF00FF0000FF00FF00FF
FF00000000FFFF00000000FF
FFFFFF000000000000FFFFFF
00FF00FF00FFFF00FF00FF00
FF00FFFF00000000FFFF00FF
00FF00FFFFFFFFFFFF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.40608 0.39418 1.58245 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0739645 0.0192308 0.0739645 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
13 string
13 13 8 [13 0 0 13 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF00FF000000FF00FF0000
000000FF0000FF0000FF000000
FF0000FF00FFFFFF00FF0000FF
00FFFF00000000000000FFFF00
FF00000000FFFFFF00000000FF
0000FF00FF00FF00FF00FF0000
00FFFF00FFFF00FFFF00FFFF00
0000FF00FF00FF00FF00FF0000
FF00000000FFFFFF00000000FF
00FFFF00000000000000FFFF00
FF0000FF00FFFFFF00FF0000FF
000000FF0000FF0000FF000000
0000FF00FF000000FF00FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.40608 0.588183 1.58245 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0686813 0.0192308 0.0686813 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
14 string
14 14 8 [14 0 0 14 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFF00FFFFFFFF00FFFFFFFFFF
FFFFFFFFFF0000FFFFFF00000000
FF0000FFFF0000FFFFFF00FFFF00
FF0000FFFFFFFFFF00FF00000000
FFFFFFFF00FFFFFFFF00FFFFFFFF
00FFFFFFFFFF000000FF00FFFFFF
FFFF0000FFFF00FF00FFFFFF0000
FFFF0000FFFF00FF00FFFFFF0000
00FFFFFFFFFF000000FF00FFFFFF
FFFFFFFF00FFFFFFFF00FFFFFFFF
FF0000FFFFFFFFFF00FF00000000
FF0000FFFF0000FFFFFF00FFFF00
FFFFFFFFFF0000FFFFFF00000000
00FFFF00FFFFFFFF00FFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.40608 0.782187 1.58245 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0641026 0.0192308 0.0641026 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
15 string
15 15 8 [15 0 0 15 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF0000FFFF00FF00FFFF0000FF00
FF000000FFFFFF00FFFFFF000000FF
000000FFFF0000FF0000FFFF000000
0000FF00FF0000FF0000FF00FF0000
FFFFFFFF00FFFF00FFFF00FFFFFFFF
FFFF0000FF0000FF0000FF0000FFFF
00FF0000FF0000FF0000FF0000FF00
FF00FFFF00FFFF00FFFF00FFFF00FF
00FF0000FF0000FF0000FF0000FF00
FFFF0000FF0000FF0000FF0000FFFF
FFFFFFFF00FFFF00FFFF00FFFFFFFF
0000FF00FF0000FF0000FF00FF0000
000000FFFF0000FF0000FFFF000000
FF000000FFFFFF00FFFFFF000000FF
00FF0000FFFF00FF00FFFF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.40608 0.97619 1.58245 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0600962 0.0192308 0.0600962 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
16 string
16 16 8 [16 0 0 16 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FFFF00FF00FFFFFFFFFFFFFFFF
FF0000FFFFFF00FFFF00000000000000
FFFFFFFF0000FF00FF00FFFFFFFFFF00
00FFFFFF0000FFFF000000FFFFFF0000
FFFF00FFFFFFFF00000000FF00FF00FF
FFFFFFFFFFFFFF000000FF00FF000000
0000FF000000FFFF00FFFFFFFF000000
00000000FF00FF00000000FFFFFF00FF
FF00FFFFFF00000000FF00FF00000000
000000FFFFFFFF00FFFF000000FF0000
000000FF00FF000000FFFFFFFFFFFFFF
FF00FF00FF00000000FFFFFFFF00FFFF
0000FFFFFF000000FFFF0000FFFFFF00
00FFFFFFFFFF00FF00FF0000FFFFFFFF
00000000000000FFFF00FFFFFF0000FF
FFFFFFFFFFFFFFFF00FF00FFFF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.60009 0.200176 1.77646 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.137363 0.0192308 0.137363 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
7 string
7 7 8 [7 0 0 7 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF00FF0000
000000FF000000
FF0000FF0000FF
00FFFF00FFFF00
FF0000FF0000FF
000000FF000000
0000FF00FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.60009 0.39418 1.77646 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.120192 0.0192308 0.120192 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFFFFFF0000
0000FF0000FF0000
FFFF00000000FFFF
FF000000000000FF
FF000000000000FF
FFFF00000000FFFF
0000FF0000FF0000
0000FFFFFFFF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.60009 0.588183 1.77646 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.106838 0.0192308 0.106838 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
9 string
9 9 8 [9 0 0 9 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFF
000000000000000000
00FFFFFFFFFFFFFF00
0000FFFFFFFFFF0000
FF00FF000000FF00FF
00000000FF00000000
0000FFFFFFFFFF0000
FFFF00FF00FF00FFFF
FF00FF00FF00FF00FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.60009 0.782187 1.77646 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0961538 0.0192308 0.0961538 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
10 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00FFFFFFFF00FF00
FF00FFFF0000FFFF00FF
00FF00FF0000FF00FF00
FFFFFF00FFFF00FFFFFF
FF0000FF0000FF0000FF
FF0000FF0000FF0000FF
FFFFFF00FFFF00FFFFFF
00FF00FF0000FF00FF00
FF00FFFF0000FFFF00FF
00FF00FFFFFFFF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.60009 0.97619 1.77646 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0874126 0.0192308 0.0874126 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
11 string
11 11 8 [11 0 0 11 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFFFF00FFFFFFFFFFFF
FFFF00FFFFFF0000000000
FFFFFFFFFFFF00FFFFFF00
0000FF0000FF0000FF0000
000000000000FF000000FF
FF00FF000000FFFFFFFF00
0000FFFF00FFFFFFFF00FF
00FFFF0000000000FFFF00
0000FF0000FFFF00FF00FF
FF0000FFFF00000000FF00
00FF00000000FF0000FFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.79409 0.200176 1.97046 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.480769 0.0192308 0.480769 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
2 string
2 2 8 [2 0 0 2 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8080
8080
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.79409 0.39418 1.97046 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.320513 0.0192308 0.320513 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
3 string
3 3 8 [3 0 0 3 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00
FF00FF
00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.79409 0.588183 1.97046 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFF
00000000
00FFFF00
00000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.79409 0.782187 1.97046 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.192308 0.0192308 0.192308 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
5 string
5 5 8 [5 0 0 5 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFFFF
0000FF0000
FFFF000000
FF000000FF
FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.79409 0.97619 1.97046 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.160256 0.0192308 0.160256 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
6 string
6 6 8 [6 0 0 6 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF0000FF00
FF00000000FF
000000000000
000000000000
FF00000000FF
00FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{459, 926.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007;0003WR000`400?l00000o`00003oo`3AcJW<
0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<
0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<
0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<
0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<
0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00303AcJT2
000000030?ooo`00000000000080oooo00<000000?ooo`3oool00`3oool200000080oooo0`000007
0?ooo`030000003oool0oooo0300oooo2`3AcJT2000000030?ooo`000000000000<0oooo0`000002
0?ooo`8000001@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00P0oooo0P00
00080?ooo`030000003oool0oooo00800000103oool200000080oooo0`0000030?ooo`80000000<0
oooo0000000000002`3AcJT600000080oooo300000050?ooo`80000000@0oooo0000000000000000
0P3oool6000000D0oooo0`0000020?ooo`040000003oool0oooo00000080oooo0P0000040?ooo`80
00003P3oool;0=7=Z@80oooo0`0000030?ooo`040000003oool0oooo000000D0oooo0P0000000`3o
ool00000000000050?ooo`X000000P3oool300000080oooo0`0000030?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool0oooo0`0000020?ooo`800000303oool;0=7=Z@80000000@0oooo
00000000000000000`3oool2000000030?ooo`000000000000<0oooo0`0000000`3oool000000000
00050?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3oool000001@3oool010000000
oooo0?ooo`0000050?ooo`80000000@0oooo00000000000000000`3oool2000000030?ooo`000000
000000<0oooo0`0000000`3oool000000000000>0=7=Z@00303AcJT2000000030?ooo`0000000000
0080oooo00<000000?ooo`3oool00`3oool200000080oooo0`0000070?ooo`030000003oool0oooo
0300oooo2`3AcJT2000000030?ooo`000000000000<0oooo0`0000020?ooo`8000001@3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo00P0oooo0P0000080?ooo`030000003oool0
oooo00800000103oool200000080oooo0`0000030?ooo`80000000<0oooo0000000000002`3AcJT6
00000080oooo300000050?ooo`80000000@0oooo00000000000000000P3oool6000000D0oooo0`00
00020?ooo`040000003oool0oooo00000080oooo0P0000040?ooo`8000003P3oool;0=7=Z@80oooo
0`0000030?ooo`040000003oool0oooo000000D0oooo0P0000000`3oool00000000000050?ooo`X0
00000P3oool300000080oooo0`0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool0oooo0`0000020?ooo`800000303oool;0=7=Z@80000000@0oooo00000000000000000`3oool2
000000030?ooo`000000000000<0oooo0`0000000`3oool00000000000050?ooo`040000003oool0
oooo000000D0oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`0000050?ooo`80
000000@0oooo00000000000000000`3oool2000000030?ooo`000000000000<0oooo0`0000000`3o
ool000000000000>0=7=Z@00303AcJT20?ooo`030000003oool0oooo008000000`3oool2000000<0
oooo1@0000020?ooo`<000001@3oool`000000/0dLfY0P3oool00`000000oooo0?ooo`030?ooo`D0
00000`3oool2000000<0oooo0P0000030?ooo`D000001@3oool6000000D0oooo1@0000030?ooo`80
00000`3oool2000000<0oooo1@0000050?ooo`030000003oool0oooo00/0dLfY0P0000030?ooo`@0
00002P3oool00`000000oooo0?ooo`02000000<0oooo200000030?ooo`040000003oool0oooo0000
0080oooo1@000000103oool000000000003oool2000000<0oooo0P0000040?ooo`d000002`3AcJT2
0?ooo`<00000103oool2000000<0oooo0P0000030?ooo`040000003oool0oooo0?ooo`8000000P3o
ool00`000000oooo0?ooo`060?ooo`/00000303oool5000000<0oooo2`00000;0=7=Z@80oooo1000
00050?ooo`030000003oool0oooo00<0oooo100000030?ooo`8000000`3oool2000000<0oooo00@0
00000?ooo`3oool0oooo0P0000030?ooo`040000003oool0oooo0?ooo`8000000`3oool2000000<0
oooo100000050?ooo`030000003oool0oooo00<0oooo100000020?ooo`h0dLfY000<0=7=Z@800000
1@3oool00`000000oooo0?ooo`030?ooo`D000000P3oool5000000D0oooo0P00000/0?ooo`800000
2`3AcJT2000000030?ooo`0000000000008000000`3oool5000000D0oooo00@000000?ooo`3oool0
00000P3oool2000000030?ooo`000000000000D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`80000000<0oooo0000000000000P3oool00`000000oooo0?ooo`02000000@0
oooo1@0000040?ooo`<0000000<0oooo0000000000002`3AcJT5000000@0oooo0P0000060?ooo`D0
00000`3oool6000000@0oooo1P0000000`3oool00000000000020?ooo`<000001P3oool2000000L0
oooo0P0000090?ooo`8000002`3AcJT60?ooo`<000000P3oool00`000000oooo0?ooo`030?ooo`80
000000<0oooo0000000000000`3oool5000000@0oooo0P0000030?ooo`<000000P3oool010000000
oooo0?ooo`3oool2000000030?ooo`00000000000080000000<0oooo0000000000000`3oool50000
00030?ooo`000000000000L0oooo0P00000;0=7=Z@D000000`3oool3000000040?ooo`0000000000
000000<0oooo1@0000050?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3oool00000
1@3oool010000000oooo0?ooo`0000050?ooo`D000000`3oool3000000040?ooo`00000000000000
00<0oooo1@00000>0=7=Z@00303AcJT2000000D0oooo00<000000?ooo`3oool00`3oool500000080
oooo1@0000050?ooo`800000;03oool2000000/0dLfY0P0000000`3oool0000000000002000000<0
oooo1@0000050?ooo`040000003oool0oooo00000080oooo0P0000000`3oool00000000000050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool2000000030?ooo`0000000000
0080oooo00<000000?ooo`3oool00P0000040?ooo`D00000103oool3000000030?ooo`0000000000
00/0dLfY1@0000040?ooo`8000001P3oool5000000<0oooo1P0000040?ooo`H0000000<0oooo0000
000000000P3oool3000000H0oooo0P0000070?ooo`8000002@3oool2000000/0dLfY1P3oool30000
0080oooo00<000000?ooo`3oool00`3oool2000000030?ooo`000000000000<0oooo1@0000040?oo
o`8000000`3oool300000080oooo00@000000?ooo`3oool0oooo0P0000000`3oool0000000000002
000000030?ooo`000000000000<0oooo1@0000000`3oool00000000000070?ooo`8000002`3AcJT5
000000<0oooo0`000000103oool000000000000000030?ooo`D000001@3oool010000000oooo0?oo
o`0000050?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3oool000001@3oool50000
00<0oooo0`000000103oool000000000000000030?ooo`D000003P3AcJT000`0dLfY0P3oool50000
00H0oooo100000030?ooo`<00000103oool00`000000oooo0?ooo`03000002X0oooo0`00000;0=7=
Z@<0oooo10000000103oool000000000003oool4000000T0oooo100000000`3oool0000000000002
0?ooo`030000003oool0oooo00H000000P3oool2000000040?ooo`00000000000?ooo`@000002@3o
ool4000000030?ooo`00000000000080oooo0`0000030?ooo`/0dLfY0`3oool300000080oooo00<0
00000?ooo`3oool00P3oool3000000030?ooo`000000000000D0000000<0oooo0000000000000`00
00000`3oool000000000000300000080oooo0`00000;0?ooo`<000001@3oool3000000030?ooo`00
00000000008000001P3oool3000000/0dLfY0P0000040?ooo`<000003P3oool7000000030?ooo`00
0000000000<0oooo0`0000050?ooo`<000000`3oool6000000<0oooo0P0000000`3oool000000000
0006000000D0oooo0`00000;0=7=Z@<000000P3oool00`000000oooo0?ooo`03000000040?ooo`00
0000000000000080oooo00<000000?ooo`3oool00`00000P0?ooo`<000000P3oool00`000000oooo
0?ooo`03000000040?ooo`000000000000000080oooo00<000000?ooo`3oool00`00000>0=7=Z@00
303AcJT20?ooo`D000001P3oool4000000<0oooo0`0000040?ooo`030000003oool0oooo00<00000
:P3oool3000000/0dLfY0`3oool4000000040?ooo`00000000000?ooo`@000002@3oool400000003
0?ooo`00000000000080oooo00<000000?ooo`3oool01P0000020?ooo`80000000@0oooo00000000
0000oooo100000090?ooo`@0000000<0oooo0000000000000P3oool3000000<0oooo2`3AcJT20?oo
o`030000003oool0oooo00<0000000<0oooo0000000000000P3oool400000080oooo1P0000020?oo
o`040000003oool0oooo0?ooo`8000002`3oool2000000<0oooo00<000000?ooo`3oool01P000002
0?ooo`@000000P3oool2000000040?ooo`000000000000000080oooo00<000000?ooo`3oool02`3A
cJT30?ooo`8000001`3oool500000080oooo00@000000?ooo`3oool0oooo1@0000020?ooo`040000
003oool0oooo0?ooo`L00000103oool2000000030?ooo`000000000000P000001P3oool200000004
0?ooo`000000000000000080oooo00@000000?ooo`3oool000000P3oool;0=7=Z@H0oooo0P000003
0?ooo`040000003oool0oooo0?ooo`8000001`3oool4000000040?ooo`00000000000?ooo`D00000
00@0oooo000000000000oooo1@000000103oool000000000003oool4000000L0oooo0P0000030?oo
o`040000003oool0oooo0?ooo`8000001P3oool>0=7=Z@00303AcJT300000080oooo1`0000050?oo
o`030000003oool0oooo00<0oooo0P0000030?ooo`8000000P3oool00`000000oooo0?ooo`0V0000
0080oooo00<000000?ooo`3oool02`3AcJT70?ooo`030000003oool0oooo00H0oooo100000000`3o
ool000000000000300000080oooo1@0000000`3oool00000000000060?ooo`8000000P3oool40000
0080oooo1@0000020?ooo`<00000203oool2000000H0oooo2`3AcJT20?ooo`030000003oool0oooo
00<0000000<0oooo0000000000000P3oool400000080oooo1P0000020?ooo`040000003oool0oooo
0?ooo`8000002`3oool2000000<0oooo00<000000?ooo`3oool01P0000020?ooo`@000000P3oool2
000000040?ooo`000000000000000080oooo00<000000?ooo`3oool02`3AcJT30?ooo`8000001`3o
ool500000080oooo00@000000?ooo`3oool0oooo1@0000020?ooo`040000003oool0oooo0?ooo`L0
0000103oool2000000030?ooo`000000000000P000001P3oool2000000040?ooo`00000000000000
0080oooo00@000000?ooo`3oool000000P3oool;0=7=Z@H0oooo0P0000030?ooo`040000003oool0
oooo0?ooo`8000001`3oool4000000040?ooo`00000000000?ooo`D0000000@0oooo000000000000
oooo1@000000103oool000000000003oool4000000L0oooo0P0000030?ooo`040000003oool0oooo
0?ooo`8000001P3oool>0=7=Z@00303AcJT2000000P0oooo0P0000030?ooo`8000001@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo1@00000R0?ooo`L000002`3AcJT30000
0080oooo0P000000103oool000000000000000050?ooo`L000001@3oool5000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`@000001@3oool7000000D0oooo0`000002
0?ooo`030000003oool0oooo00<000002`3AcJT60?ooo`8000000`3oool2000000040?ooo`000000
0000000000<0oooo1@0000020?ooo`<0000000<0oooo0000000000000P0000000`3oool000000000
00030?ooo`030000003oool0oooo00H0oooo0P0000000`3oool00000000000020?ooo`<0000000@0
oooo00000000000000000P3oool;000000/0dLfY2@3oool2000000030?ooo`00000000000080oooo
0`0000060?ooo`800000103oool2000000030?ooo`000000000000D0000000<0oooo000000000000
3P0000030?ooo`D00000103oool2000000030?ooo`000000000000<000002`3AcJT30?ooo`<00000
0P3oool3000000040?ooo`000000000000000080oooo0`0000040?ooo`D000000P3oool300000004
0?ooo`000000000000000080oooo0`000000103oool000000000000000020?ooo`D00000103oool3
00000080oooo0`000000103oool000000000000000020?ooo`<000000`3oool>0=7=Z@00303AcJT2
000000P0oooo0P0000030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo1@00000R0?ooo`L000002`3AcJT300000080oooo0P000000103oool0000000000000
00050?ooo`L000001@3oool5000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`@000001@3oool7000000D0oooo0`0000020?ooo`030000003oool0oooo00<000002`3A
cJT60?ooo`8000000`3oool2000000040?ooo`0000000000000000<0oooo1@0000020?ooo`<00000
00<0oooo0000000000000P0000000`3oool00000000000030?ooo`030000003oool0oooo00H0oooo
0P0000000`3oool00000000000020?ooo`<0000000@0oooo00000000000000000P3oool;000000/0
dLfY0`0000020?ooo`<000000`3oool3000000<0oooo3P0000020?ooo`030000003oool0oooo00<0
00000P3oool3000000040?ooo`00000000000?ooo`P000001@3oool00`000000oooo0?ooo`050?oo
o`040000003oool0oooo0?ooo`D000002`3AcJT2000000040?ooo`000000000000000080oooo0`00
0000103oool000000000000000020?ooo`<0000000<0oooo0000000000000`3oool300000080oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00<0
00000`3oool2000000040?ooo`000000000000000080oooo0`000000103oool00000000000000002
0?ooo`<0000000<0oooo0000000000003P3AcJT000`0dLfY1@0000030?ooo`@000001@3oool30000
00<0oooo0P0000030?ooo`8000001`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
0080oooo0`00000;0=7=Z@D000000`3oool300000080oooo0P0000030?ooo`8000000`3oool00`00
0000oooo0?ooo`030?ooo`8000000`3oool2000000H0oooo0P0000030?ooo`8000001@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000000P3oool3000000<0oooo1@00000;
0=7=Z@80000000<0oooo0000000000000`0000000`3oool00000000000080?ooo`030000003oool0
oooo0080000000@0oooo000000000000oooo0`0000020?ooo`<000002P3oool4000000<0oooo0P00
00030?ooo`800000103oool2000000<0oooo0`0000020?ooo`<000002`3AcJT300000080oooo0`00
00030?ooo`<000000`3oool>00000080oooo00<000000?ooo`3oool00`0000020?ooo`<0000000@0
oooo000000000000oooo200000050?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool0
oooo1@00000;0=7=Z@80000000@0oooo00000000000000000P3oool3000000040?ooo`0000000000
00000080oooo0`0000000`3oool00000000000030?ooo`<000000P3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool00`0000030?ooo`80000000@0
oooo00000000000000000P3oool3000000040?ooo`000000000000000080oooo0`0000000`3oool0
00000000000>0=7=Z@00303AcJT5000000<0oooo100000050?ooo`<000000`3oool2000000<0oooo
0P0000070?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool3000000/0dLfY
0P3oool5000000@0oooo0P0000030?ooo`L000000`3oool7000000<0oooo1P0000040?ooo`H00000
0`3oool7000000<0oooo0P0000050?ooo`@000000P3oool;0=7=Z@80oooo0`0000030?ooo`030000
003oool0oooo00<00000203oool2000000H0oooo00<000000?ooo`3oool00P3oool6000000030?oo
o`00000000000080oooo00<000000?ooo`3oool00`0000000`3oool00000000000020?ooo`<00000
0`3oool00`000000oooo0?ooo`03000000P0oooo2`3AcJT8000000040?ooo`0000000000000000@0
oooo00<000000?ooo`3oool01P3oool2000000<0oooo00<000000?ooo`3oool0203oool010000000
oooo0?ooo`3oool2000000<0oooo1@000000103oool000000000000000020?ooo`<000000P3oool0
10000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool02`3AcJT20?ooo`040000003o
ool0oooo0?ooo`8000000`3oool010000000oooo0?ooo`3oool2000000<0oooo00@000000?ooo`3o
ool0oooo0P0000030?oooa@000000`3oool2000000<0oooo00@000000?ooo`3oool0oooo0P000003
0?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`0>0=7=Z@00303AcJT3
0?ooo`8000000`3oool2000000<0oooo1`0000020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool2000000<0oooo700000030?ooo`@000000`3oool;0=7=Z@80oooo1@000004
0?ooo`8000000`3oool7000000<0oooo1`0000030?ooo`H00000103oool6000000<0oooo1`000003
0?ooo`8000001@3oool400000080oooo2`3AcJT20?ooo`<000000`3oool00`000000oooo0?ooo`03
000000P0oooo0P0000060?ooo`030000003oool0oooo0080oooo1P0000000`3oool0000000000002
0?ooo`030000003oool0oooo00<0000000<0oooo0000000000000P3oool3000000<0oooo00<00000
0?ooo`3oool00`0000080?ooo`/0dLfY0P3oool010000000oooo0?ooo`0000020?ooo`<0000000<0
oooo0000000000000`3oool2000000@0oooo200000030?ooo`8000001@3oool3000000040?ooo`00
000000000?ooo`80000000<0oooo0000000000000`3oool5000000030?ooo`000000000000800000
0`3oool010000000oooo0?ooo`3oool5000000/0dLfY0P000000103oool000000000000000020?oo
o`<0000000@0oooo00000000000000000P3oool3000000030?ooo`000000000000<0oooo1P000005
0?ooo`040000003oool0oooo000000D0oooo1P0000030?ooo`80000000@0oooo0000000000000000
0P3oool3000000040?ooo`000000000000000080oooo0`0000000`3oool000000000000>0=7=Z@00
303AcJT20?ooo`<000000`3oool4000000030?ooo`00000000000080oooo00<000000?ooo`3oool0
0P0000000`3oool00000000000030?ooo`D00000103oool00`000000oooo0?ooo`02000001P0oooo
0P0000020?ooo`H000000P3oool;0=7=Z@80000000<0oooo0000000000000P0000030?ooo`030000
003oool0oooo0080000000<0oooo0000000000000P000000103oool000000000000000020?ooo`80
000000<0oooo0000000000000P000000103oool000000000000000040?ooo`<000000P3oool30000
00030?ooo`00000000000080oooo0`0000020?ooo`<0000000<0oooo0000000000000P3oool00`00
0000oooo0?ooo`020?ooo`<0000000<0oooo0000000000002`3AcJT300000080oooo0`0000030?oo
o`<000000P3oool3000000<0oooo0P0000030?ooo`@000000P3oool2000000@0oooo0`0000020?oo
o`<000000`3oool8000000P0oooo1@0000000`3oool00000000000030?ooo`/0dLfY0P3oool01000
0000oooo0?ooo`0000020?ooo`<0000000<0oooo0000000000000`3oool2000000@0oooo20000003
0?ooo`8000001@3oool3000000040?ooo`00000000000?ooo`80000000<0oooo0000000000000`3o
ool5000000030?ooo`0000000000008000000`3oool010000000oooo0?ooo`3oool5000000/0dLfY
0P000000103oool000000000000000020?ooo`<0000000@0oooo00000000000000000P3oool30000
00030?ooo`000000000000<0oooo1P0000050?ooo`040000003oool0oooo000000D0oooo1P000003
0?ooo`80000000@0oooo00000000000000000P3oool3000000040?ooo`000000000000000080oooo
0`0000000`3oool000000000000>0=7=Z@00303AcJT20?ooo`<000000`3oool4000000030?ooo`00
000000000080oooo00<000000?ooo`3oool00P0000000`3oool00000000000030?ooo`D00000103o
ool00`000000oooo0?ooo`02000001P0oooo0P0000020?ooo`H000000P3oool;0=7=Z@80000000<0
oooo0000000000000P0000030?ooo`030000003oool0oooo0080000000<0oooo0000000000000P00
0000103oool000000000000000020?ooo`80000000<0oooo0000000000000P000000103oool00000
0000000000040?ooo`<000000P3oool3000000030?ooo`00000000000080oooo0`0000020?ooo`<0
000000<0oooo0000000000000P3oool00`000000oooo0?ooo`020?ooo`<0000000<0oooo00000000
00002`3AcJT2000000<0oooo100000050?ooo`D000000`3oool2000000<0oooo00@000000?ooo`3o
ool0oooo0P0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P000003
0?ooo`040000003oool0oooo0?ooo`8000000`3oool5000000D0oooo100000030?ooo`8000002`3A
cJT300000080oooo00@000000?ooo`3oool000001`3oool010000000oooo0?ooo`3oool200000003
0?ooo`0000000000008000002P3oool2000000<0oooo1P0000030?ooo`@000000`3oool3000000<0
oooo0`0000030?ooo`80000000<0oooo0000000000000`00000;0=7=Z@<0oooo0`0000020?ooo`<0
000000@0oooo00000000000000000P3oool3000000@0oooo10000000103oool000000000003oool2
000000040?ooo`000000000000000080oooo0`000000103oool000000000003oool2000000030?oo
o`000000000000800000103oool300000080oooo0`000000103oool000000000000000020?ooo`<0
00000`3oool>0=7=Z@00303AcJT20?ooo`030000003oool0oooo00D0oooo1@0000020?ooo`030000
003oool0oooo00L0oooo0`0000020?ooo`030000003oool0oooo0080000000<0oooo000000000000
0`00000F0?ooo`/000000P3oool;0=7=Z@l0oooo00<000000?ooo`3oool01@3oool5000000D0oooo
0`0000000`3oool0000000000002000000030?ooo`000000000000800000103oool5000000L0oooo
00<000000?ooo`3oool03@3oool;0=7=Z@8000000`3oool4000000D0oooo1@0000030?ooo`800000
0`3oool010000000oooo0?ooo`3oool200000080oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`02000000<0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`D000001@3oool4
000000<0oooo0P00000;0=7=Z@<000000P3oool010000000oooo0?ooo`0000070?ooo`040000003o
ool0oooo0?ooo`80000000<0oooo0000000000000P00000:0?ooo`8000000`3oool6000000<0oooo
100000030?ooo`<000000`3oool3000000<0oooo0P0000000`3oool0000000000003000000/0dLfY
1P3oool2000000<0oooo00@000000?ooo`3oool0oooo0P0000070?ooo`8000000`3oool2000000<0
oooo0`000000103oool000000000003oool3000000<0oooo0P0000030?ooo`8000001`3oool20000
00<0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`h0dLfY000<0=7=Z@80oooo00<000000?oo
o`3oool01@3oool500000080oooo00<000000?ooo`3oool01`3oool300000080oooo00<000000?oo
o`3oool00P0000000`3oool0000000000003000001H0oooo2`0000020?ooo`/0dLfY0P3oool00`00
0000oooo0?ooo`020?ooo`<0000000<0oooo0000000000000P0000000`3oool00000000000020?oo
o`<00000203oool3000000<0oooo100000030?ooo`<00000203oool4000000040?ooo`0000000000
0?ooo`@0000000<0oooo0000000000000P0000030?ooo`030000003oool0oooo00/0dLfY0`000003
0?ooo`<00000103oool4000000D0oooo0P0000030?ooo`@000001@3oool2000000<0oooo1P000003
0?ooo`X0000000@0oooo000000000000oooo100000000`3oool0000000000003000000<0oooo2`3A
cJT2000000030?ooo`000000000000L000001@3oool2000000<0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`3oool3000000L0oooo00@000000?ooo`3oool0oooo1@0000030?ooo`80
000000<0oooo000000000000103oool200000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`/0dLfY1P3oool2000000<0oooo00@000000?ooo`3oool0oooo0P00
00070?ooo`8000000`3oool2000000<0oooo0`000000103oool000000000003oool3000000<0oooo
0P0000030?ooo`8000001`3oool2000000<0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`h0
dLfY000<0=7=Z@80oooo200000050?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo0`0000030?ooo`D000000P3ooolB00000080oooo0`0000020?ooo`D00000
0`3oool;0=7=Z@80oooo00<000000?ooo`3oool00P3oool3000000030?ooo`000000000000800000
00<0oooo0000000000000P3oool3000000P0oooo0`0000030?ooo`@000000`3oool3000000P0oooo
10000000103oool000000000003oool4000000030?ooo`0000000000008000000`3oool00`000000
oooo0?ooo`0;0=7=Z@<000000`3oool3000000@0oooo100000050?ooo`8000000`3oool4000000D0
oooo0P0000030?ooo`H000000`3oool:000000040?ooo`00000000000?ooo`@0000000<0oooo0000
000000000`0000030?ooo`/0dLfY0P000000103oool000000000000000020?ooo`040000003oool0
oooo00000080oooo0`0000030?ooo`80000000<0oooo0000000000000P0000040?ooo`<000000P3o
ool00`000000oooo0?ooo`030?ooo`<000000P3oool3000000030?ooo`000000000000<000000P3o
ool00`000000oooo0?ooo`050?ooo`<000001P3oool3000000/0dLfY0`0000020?ooo`030000003o
ool0oooo00<0000000@0oooo00000000000000000P3oool00`000000oooo0?ooo`03000000030?oo
o`00000000000080000000@0oooo000000000000oooo0`0000080?ooo`<0000000@0oooo00000000
0000oooo10000000103oool000000000000000020?ooo`030000003oool0oooo00<0000000@0oooo
00000000000000000P3oool00`000000oooo0?ooo`03000000h0dLfY000<0=7=Z@P0oooo10000000
0`3oool0000000000002000000X0oooo0`0000030?ooo`@000000`3oool2000000040?ooo`000000
0000000000l0oooo100000060?ooo`8000000P3oool3000000/0dLfY1`3oool8000000<0oooo1P00
00040?ooo`030000003oool0oooo0080000000<0oooo0000000000001P3oool200000080oooo00@0
00000?ooo`3oool00000103oool6000000<0oooo2@0000060?ooo`/0dLfY0P3oool010000000oooo
0?ooo`0000070?ooo`<0000000@0oooo00000000000000000P3oool2000000H0oooo1P0000020?oo
o`030000003oool0oooo00<0oooo0`0000020?ooo`<0000000<0oooo0000000000001P3oool70000
00<0oooo0`0000030?ooo`/0dLfY0P000000103oool000000000000000020?ooo`040000003oool0
oooo00000080oooo0`0000030?ooo`80000000<0oooo0000000000000P0000040?ooo`<000000P3o
ool00`000000oooo0?ooo`030?ooo`<000000P3oool3000000030?ooo`000000000000<000000P3o
ool00`000000oooo0?ooo`050?ooo`<000001P3oool3000000/0dLfY1@0000030?ooo`<0000000@0
oooo00000000000000000`3oool600000080oooo20000000103oool000000000000000020?ooo`<0
000000<0oooo0000000000001P0000020?ooo`H000000`3oool3000000040?ooo`00000000000000
00<0oooo1@00000>0=7=Z@00303AcJT80?ooo`@0000000<0oooo0000000000000P00000:0?ooo`<0
00000`3oool4000000<0oooo0P000000103oool0000000000000000?0?ooo`@000001P3oool20000
0080oooo0`00000;0=7=Z@L0oooo200000030?ooo`H00000103oool00`000000oooo0?ooo`020000
00030?ooo`000000000000H0oooo0P0000020?ooo`040000003oool0oooo000000@0oooo1P000003
0?ooo`T000001P3oool;0=7=Z@D0000000@0oooo000000000000oooo0P0000060?ooo`L0000000@0
oooo000000000000oooo0P0000050?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`<00000
0`3oool4000000L0oooo0P0000030?ooo`800000103oool2000000/0dLfY0`0000050?ooo`030000
003oool0oooo00P00000103oool7000000@0oooo0P0000030?ooo`H000001@3oool6000000D0oooo
00<000000?ooo`3oool00`3oool5000000@0oooo0P00000;0=7=Z@D000000`3oool3000000040?oo
o`0000000000000000<0oooo1P0000020?ooo`P0000000@0oooo00000000000000000P3oool30000
00030?ooo`000000000000H000000P3oool6000000<0oooo0`000000103oool00000000000000003
0?ooo`D000003P3AcJT000`0dLfY0P0000050?ooo`030000003oool0oooo00D000000P3oool50000
00030?ooo`000000000000<0oooo0P0000020?ooo`030000003oool0oooo0080000000<0oooo0000
000000000P000000103oool000000000003oool2000000`0oooo00<000000?ooo`3oool00`000002
0?ooo`D000000P3oool3000000/0dLfY0P0000000`3oool00000000000030?ooo`80000000<0oooo
0000000000000`3oool8000000D0oooo1000000=0?ooo`<000001@3oool8000000<0oooo0P000000
0`3oool00000000000030?ooo`80000000<0oooo0000000000002`3AcJT5000000040?ooo`000000
00000?ooo`8000001P3oool7000000040?ooo`00000000000?ooo`8000001@3oool00`000000oooo
0?ooo`040?ooo`8000000`3oool3000000<0oooo100000070?ooo`8000000`3oool2000000@0oooo
0P00000;0=7=Z@80oooo0`0000030?ooo`<000000`3oool5000000H0oooo0P0000000`3oool00000
000000030?ooo`040000003oool0oooo00000080oooo0P0000000`3oool00000000000040?ooo`L0
00002@3oool3000000<0oooo0P0000000`3oool0000000000003000000/0dLfY0P3oool4000000D0
oooo00<000000?ooo`3oool00`3oool7000000D0oooo0P0000040?ooo`P00000103oool2000000D0
oooo1`0000050?ooo`030000003oool0oooo00<0oooo100000020?ooo`h0dLfY000<0=7=Z@800000
1@3oool00`000000oooo0?ooo`0500000080oooo1@0000000`3oool00000000000030?ooo`800000
0P3oool00`000000oooo0?ooo`02000000030?ooo`00000000000080000000@0oooo000000000000
oooo0P00000<0?ooo`030000003oool0oooo00<000000P3oool500000080oooo0`00000;0=7=Z@80
oooo00<000000?ooo`3oool00P3oool3000000030?ooo`00000000000080000000<0oooo00000000
00001@0000030?ooo`D000001@3oool6000000D0oooo1@0000030?ooo`L0000000<0oooo00000000
00000P0000000`3oool0000000000002000000<0oooo00<000000?ooo`3oool02`3AcJT5000000<0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool00`0000030?ooo`8000000`3oool5000000030?ooo`0000000000
00<0oooo0P000000103oool000000000000000020?ooo`D000000`3oool00`000000oooo0?ooo`03
0?ooo`/0dLfY0P3oool3000000<0oooo0`0000030?ooo`D000001P3oool2000000030?ooo`000000
000000<0oooo00@000000?ooo`3oool000000P3oool2000000030?ooo`000000000000@0oooo1`00
00090?ooo`<000000`3oool2000000030?ooo`000000000000<000002`3AcJT2000000040?ooo`00
00000000000000<0oooo0P0000000`3oool00000000000030?ooo`H000001@3oool4000000D0oooo
00@000000?ooo`3oool000001@3oool4000000D0oooo1P0000030?ooo`80000000<0oooo00000000
00000`3oool3000000030?ooo`000000000000h0dLfY000<0=7=Z@<0oooo0P00000<0?ooo`030000
003oool0oooo00<00000103oool5000000<0oooo1@0000020?ooo`<000001@3oool8000000L0oooo
1@0000030?ooo`8000000`3oool;0=7=Z@80oooo00<000000?ooo`3oool00P3oool3000000030?oo
o`00000000000080000000<0oooo0000000000001@0000030?ooo`D000001@3oool6000000D0oooo
1@0000030?ooo`L0000000<0oooo0000000000000P0000000`3oool0000000000002000000<0oooo
00<000000?ooo`3oool02`3AcJT20?ooo`040000003oool0oooo0?ooo`80000000<0oooo00000000
00003@0000070?ooo`@000001`3oool4000000L0oooo3`0000000`3oool00000000000030?ooo`03
0000003oool0oooo00/0dLfY0P0000000`3oool00000000000040?ooo`D000000P3oool010000000
oooo0?ooo`3oool7000000030?ooo`000000000000L0oooo100000000`3oool00000000000030000
00030?ooo`000000000000<000000P3oool6000000<0oooo2`0000030?ooo`/0dLfY0P000000103o
ool000000000000000030?ooo`80000000<0oooo0000000000000`3oool6000000D0oooo10000005
0?ooo`040000003oool0oooo000000D0oooo100000050?ooo`H000000`3oool2000000030?ooo`00
0000000000<0oooo0`0000000`3oool000000000000>0=7=Z@00303AcJT80?ooo`8000001`3oool0
0`000000oooo0?ooo`020?ooo`<000000P3oool6000000T0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`030?ooo`8000000`3oool4000000D0oooo0`0000020?ooo`030000003oool0
oooo00/0dLfY0P0000000`3oool00000000000020?ooo`040000003oool0oooo00000080oooo0`00
00020?ooo`<000000P3oool00`000000oooo0?ooo`02000000<0oooo0`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`0000030?ooo`8000000P3oool00`000000oooo0?oo
o`0300000080oooo0`0000020?ooo`030000003oool0oooo0080000000@0oooo000000000000oooo
0P00000;0=7=Z@80oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000000000=000000L0
oooo100000070?ooo`@000001`3oool?000000030?ooo`000000000000<0oooo00<000000?ooo`3o
ool02`3AcJT30?ooo`80000000@0oooo00000000000000000`3oool200000080oooo0`0000000`3o
ool00000000000050?ooo`<0000000@0oooo000000000000oooo1@0000020?ooo`040000003oool0
oooo0?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`800000
1@3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool02`3AcJTB0?ooo`<0
00000P3oool300000080oooo100000020?ooo`@000000P3oool400000080oooo100000020?ooo`<0
00000P3oool300000180oooo3P3AcJT000`0dLfY203oool2000000L0oooo00<000000?ooo`3oool0
0P3oool300000080oooo1P0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool2000000<0oooo100000050?ooo`<000000P3oool00`000000oooo0?ooo`0;0=7=Z@D0oooo
0`0000070?ooo`030000003oool0oooo00H0oooo7P0000080?ooo`030000003oool0oooo00D0oooo
0`0000050?ooo`/0dLfY1@0000040?ooo`800000203oool00`000000oooo0?ooo`05000000030?oo
o`000000000000<000000P3oool4000000<0oooo0P0000020?ooo`040000003oool0oooo000000<0
oooo10000000103oool000000000000000020?ooo`<000000P3oool010000000oooo0?ooo`000005
0?ooo`/0dLfY0`3oool2000000040?ooo`0000000000000000<0oooo0P0000020?ooo`<0000000<0
oooo0000000000001@3oool3000000040?ooo`00000000000?ooo`D000000P3oool010000000oooo
0?ooo`3oool300000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool20000
00D0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo00/0dLfY0P3oool0
10000000oooo0?ooo`3oool300000080oooo00<000000?ooo`3oool0100000050?ooo`D0000000@0
oooo000000000000oooo0`0000030?ooo`8000000`3oool3000000040?ooo`00000000000?ooo`D0
00001@3oool400000080oooo00<000000?ooo`3oool00`0000030?ooo`030000003oool0oooo00h0
dLfY000<0=7=Z@<000000P3oool2000000D0oooo0`0000020?ooo`030000003oool0oooo00800000
00<0oooo0000000000000P0000000`3oool0000000000003000000T0oooo1P0000020?ooo`<00000
0P3oool3000000<0oooo1@0000020?ooo`D000001@3oool;0=7=Z@D0oooo0`0000070?ooo`030000
003oool0oooo00H0oooo7P0000080?ooo`030000003oool0oooo00D0oooo0`0000050?ooo`/0dLfY
1@0000040?ooo`@00000103oool3000000D0oooo1@0000050?ooo`040000003oool0oooo000000<0
oooo0P0000030?ooo`8000006P3oool2000000/0dLfY0`3oool=000000030?ooo`000000000000@0
00000P3oool300000080oooo00<000000?ooo`3oool00`0000060?ooo`<000000P3oool00`000000
oooo0?ooo`0300000080oooo1P0000000`3oool000000000000;000000<0oooo2`3AcJT20?ooo`04
0000003oool0oooo0?ooo`<000000P3oool00`000000oooo0?ooo`04000000D0oooo1@000000103o
ool000000000003oool3000000<0oooo0P0000030?ooo`<0000000@0oooo000000000000oooo1@00
00050?ooo`@000000P3oool00`000000oooo0?ooo`03000000<0oooo00<000000?ooo`3oool03P3A
cJT000`0dLfY0`0000020?ooo`8000001@3oool300000080oooo00<000000?ooo`3oool00P000000
0`3oool0000000000002000000030?ooo`000000000000<000002@3oool600000080oooo0`000002
0?ooo`<000000`3oool500000080oooo1@0000050?ooo`/0dLfY0P3oool5000000@0oooo1@000005
0?ooo`L000000`3oool300000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
000000<0oooo1`0000050?ooo`D000001@3oool400000080oooo2`3AcJT5000000@0oooo10000004
0?ooo`<000001@3oool5000000D0oooo00@000000?ooo`3oool000000`3oool2000000<0oooo0P00
000J0?ooo`8000002`3AcJT30?ooo`d0000000<0oooo000000000000100000020?ooo`<000000P3o
ool00`000000oooo0?ooo`03000000H0oooo0`0000020?ooo`030000003oool0oooo00<000000P3o
ool6000000030?ooo`000000000000/000000`3oool;0=7=Z@H0oooo1@000000103oool000000000
000000020?ooo`<00000103oool4000000040?ooo`00000000000?ooo`80000000@0oooo00000000
000000000P3oool3000000040?ooo`00000000000?ooo`80000000<0oooo0000000000000P000004
0?ooo`<000000P3oool3000000030?ooo`000000000000<000001P3oool>0=7=Z@00303AcJT50000
00L0oooo200000050?ooo`8000000`3oool2000000<0oooo1@0000060?ooo`@0000000<0oooo0000
000000000`0000070?ooo`P000001@3oool2000000/0dLfY0P3oool5000000@0oooo1@0000050?oo
o`L000000`3oool300000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030000
00<0oooo1`0000050?ooo`D000001@3oool400000080oooo2`3AcJT20?ooo`040000003oool0oooo
0?ooo`8000000`3oool2000000040?ooo`00000000000?ooo`8000001@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool200000080oooo
00<000000?ooo`3oool0100000040?ooo`040000003oool0oooo0?ooo`8000000`3oool200000004
0?ooo`00000000000?ooo`8000000`3oool;0=7=Z@800000103oool3000000<0oooo100000040?oo
o`L000001P3oool010000000oooo0?ooo`0000020?ooo`H000000P3oool3000000030?ooo`000000
0000008000001P3oool300000080oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000000
0003000000/0dLfY1P3oool5000000040?ooo`000000000000000080oooo0`0000040?ooo`@00000
00@0oooo000000000000oooo0P000000103oool000000000000000020?ooo`<0000000@0oooo0000
00000000oooo0P0000000`3oool0000000000002000000@0oooo0`0000020?ooo`<0000000<0oooo
0000000000000`0000060?ooo`h0dLfY000<0=7=Z@80oooo200000030?ooo`8000000P3oool:0000
00030?ooo`000000000000<000000P3oool2000000030?ooo`000000000000D0oooo00<000000?oo
o`3oool00P0000060?ooo`L000000P3oool00`000000oooo0?ooo`02000000030?ooo`0000000000
008000000`3oool;0=7=Z@80oooo00<000000?ooo`3oool00P3oool3000000030?ooo`0000000000
00D0oooo0P000000103oool000000000003oool200000080oooo0`0000050?ooo`H000001@3oool3
00000080oooo0P0000000`3oool00000000000020?ooo`030000003oool0oooo00<0oooo0P000000
0`3oool0000000000002000000<0oooo00<000000?ooo`3oool02`3AcJT20?ooo`040000003oool0
oooo0?ooo`8000000`3oool2000000040?ooo`00000000000?ooo`8000001@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool200000080
oooo00<000000?ooo`3oool0100000040?ooo`040000003oool0oooo0?ooo`8000000`3oool20000
00040?ooo`00000000000?ooo`8000000`3oool;0=7=Z@D0oooo00@000000?ooo`3oool0oooo0`00
00070?ooo`040000003oool0oooo000000@0oooo0`0000030?ooo`040000003oool0oooo0?ooo`@0
000000@0oooo000000000000oooo0P0000000`3oool00000000000030?ooo`<000000`3oool30000
00@0oooo1P0000040?ooo`8000002`3AcJT2000000030?ooo`000000000000<0oooo0`0000000`3o
ool00000000000040?ooo`80000000@0oooo0000000000000000103oool6000000040?ooo`000000
000000000080oooo0`0000000`3oool0000000000004000000@0oooo0`0000000`3oool000000000
00040?ooo`80000000@0oooo00000000000000000`3oool2000000030?ooo`000000000000h0dLfY
000<0=7=Z@80oooo200000030?ooo`8000000P3oool:000000030?ooo`000000000000<000000P3o
ool2000000030?ooo`000000000000D0oooo00<000000?ooo`3oool00P0000060?ooo`L000000P3o
ool00`000000oooo0?ooo`02000000030?ooo`0000000000008000000`3oool;0=7=Z@80oooo3@00
00050?ooo`<0000000<0oooo0000000000000P3oool5000000d0oooo100000020?ooo`80000000<0
oooo0000000000000P0000040?ooo`d000000P3oool;0=7=Z@D00000103oool500000080oooo1P00
00030?ooo`80000000<0oooo0000000000001@3oool4000000<0oooo100000030?ooo`040000003o
ool0oooo000000l0oooo00@000000?ooo`3oool000001@3oool;0=7=Z@D0oooo00@000000?ooo`3o
ool0oooo0`0000070?ooo`040000003oool0oooo000000@0oooo0`0000030?ooo`040000003oool0
oooo0?ooo`@0000000@0oooo000000000000oooo0P0000000`3oool00000000000030?ooo`<00000
0`3oool3000000@0oooo1P0000040?ooo`8000002`3AcJT20?ooo`040000003oool0oooo0?ooo`80
00000`3ooolD000000<0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`040000003oool0oooo
0?oooa@000000`3oool2000000<0oooo00<000000?ooo`3oool03P3AcJT000`0dLfY0P0000000`3o
ool00000000000030?ooo`8000000P3oool3000000<0oooo0P0000070?ooo`X0000000<0oooo0000
000000000P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool3000000<0oooo0P0000020?oo
o`030000003oool0oooo0080000000<0oooo0000000000000P0000030?ooo`/0dLfY0P3oool=0000
00D0oooo0`0000000`3oool00000000000020?ooo`D000003@3oool400000080oooo0P0000000`3o
ool0000000000002000000@0oooo3@0000020?ooo`/0dLfY1@0000040?ooo`D000000P3oool30000
00030?ooo`00000000000080oooo00@000000?ooo`3oool000000P3oool3000000/0oooo0`000002
0?ooo`040000003oool0oooo00000080oooo0P000000103oool000000000000000020?ooo`D00000
103oool5000000/0dLfY0P3oool010000000oooo0?ooo`3oool800000080oooo00<000000?ooo`3o
ool00`3oool8000000<0oooo00<000000?ooo`3oool00`0000030?ooo`800000103oool200000003
0?ooo`00000000000080oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000000000;0?oo
o`<000002`3AcJT20?ooo`040000003oool0oooo0?ooo`8000000`3ooolD000000<0oooo00@00000
0?ooo`3oool0oooo0P0000030?ooo`040000003oool0oooo0?oooa@000000`3oool2000000<0oooo
00<000000?ooo`3oool03P3AcJT000`0dLfY0P0000000`3oool00000000000030?ooo`8000000P3o
ool3000000<0oooo0P0000070?ooo`X0000000<0oooo0000000000000P3oool00`000000oooo0?oo
o`030?ooo`8000001@3oool3000000<0oooo0P0000020?ooo`030000003oool0oooo0080000000<0
oooo0000000000000P0000030?ooo`/0dLfY1`3oool3000000030?ooo`00000000000080000000<0
oooo0000000000000`0000020?ooo`D0000000<0oooo0000000000000P0000000`3oool000000000
00060?ooo`8000000P3oool3000000030?ooo`000000000000<000000P3oool5000000030?ooo`00
000000000080000000<0oooo0000000000000P0000060?ooo`/0dLfY1@0000040?ooo`D000000P3o
ool3000000030?ooo`00000000000080oooo00@000000?ooo`3oool000000P3oool3000000/0oooo
0`0000020?ooo`040000003oool0oooo00000080oooo0P000000103oool000000000000000020?oo
o`D00000103oool5000000/0dLfY1@3oool3000000030?ooo`000000000000D000002`3oool00`00
0000oooo0?ooo`030?ooo`@000000P3oool2000000030?ooo`000000000000@0oooo0`0000040?oo
o`040000003oool0oooo0?ooo`8000002`3oool010000000oooo0?ooo`0000020?ooo`/0dLfY0P00
00000`3oool00000000000030?ooo`H00000103oool2000000040?ooo`0000000000000000@0oooo
00<000000?ooo`3oool00`000000103oool000000000000000020?ooo`<0000000@0oooo00000000
000000000P3oool00`000000oooo0?ooo`020?ooo`<0000000<0oooo000000000000103oool60000
00<0oooo0P0000000`3oool000000000000>0=7=Z@00303AcJT30?ooo`X00000103oool5000000<0
oooo200000040?ooo`D000001P3oool2000000030?ooo`00000000000080oooo00<000000?ooo`3o
ool03@0000050?ooo`8000002`3AcJT70?ooo`<0000000<0oooo0000000000000P0000000`3oool0
00000000000300000080oooo1@0000000`3oool0000000000002000000030?ooo`000000000000H0
oooo0P0000020?ooo`<0000000<0oooo0000000000000`0000020?ooo`D0000000<0oooo00000000
00000P0000000`3oool0000000000002000000H0oooo2`3AcJT20?ooo`040000003oool0oooo0?oo
o`8000000`3oool2000000030?ooo`000000000000@0oooo100000060?ooo`<000001P3oool50000
0080oooo2@0000020?ooo`L000000P3oool8000000030?ooo`000000000000/0dLfY1@3oool30000
00030?ooo`000000000000D000002`3oool00`000000oooo0?ooo`030?ooo`@000000P3oool20000
00030?ooo`000000000000@0oooo0`0000040?ooo`040000003oool0oooo0?ooo`8000002`3oool0
10000000oooo0?ooo`0000020?ooo`/0dLfY1P3oool300000080oooo00@000000?ooo`3oool00000
0P3oool3000000@0oooo1@0000020?ooo`<0000000@0oooo00000000000000000P3oool300000004
0?ooo`000000000000000080oooo1@0000040?ooo`<000000P3oool010000000oooo0?ooo`000002
0?ooo`<000001P3oool>0=7=Z@00303AcJT80?ooo`8000000`3oool200000080oooo1@0000030?oo
o`L0000000<0oooo0000000000002`0000020?ooo`<000000P3oool300000080oooo0P0000000`3o
ool00000000000020?ooo`030000003oool0oooo00D000001@3oool;0=7=Z@8000000`3oool20000
00P0oooo0`0000050?ooo`D000001@3oool010000000oooo0?ooo`3oool4000000<0oooo0P000004
0?ooo`D000001@3oool3000000T0oooo00@000000?ooo`3oool0oooo0P00000;0=7=Z@D00000103o
ool4000000<0oooo00<000000?ooo`3oool00`3oool5000000P0oooo0`000000103oool000000000
003oool2000000D0oooo00<000000?ooo`3oool00`0000020?ooo`@000003P3oool2000000/0dLfY
0P0000030?ooo`030000003oool0oooo00<0oooo2`0000030?ooo`H000002P3oool3000000030?oo
o`000000000000<0oooo0`0000020?ooo`040000003oool0oooo0?ooo`8000000`3oool6000000<0
oooo1@00000;0=7=Z@H0oooo0`0000020?ooo`040000003oool0oooo00000080oooo0`0000040?oo
o`D000000P3oool3000000040?ooo`000000000000000080oooo0`000000103oool0000000000000
00020?ooo`D00000103oool300000080oooo00@000000?ooo`3oool000000P3oool3000000H0oooo
3P3AcJT000`0dLfY203oool2000000<0oooo0P0000020?ooo`D000000`3oool7000000030?ooo`00
0000000000/000000P3oool300000080oooo0`0000020?ooo`80000000<0oooo0000000000000P3o
ool00`000000oooo0?ooo`05000000D0oooo2`3AcJT70?ooo`040000003oool0oooo00000080oooo
0`0000020?ooo`800000103oool2000000D0oooo0P000000103oool000000000003oool400000003
0?ooo`00000000000080oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3o
ool00`0000020?ooo`030000003oool0oooo008000001P3oool;0=7=Z@D00000103oool4000000<0
oooo00<000000?ooo`3oool00`3oool5000000P0oooo0`000000103oool000000000003oool20000
00D0oooo00<000000?ooo`3oool00`0000020?ooo`@000003P3oool2000000/0dLfY1@3oool60000
00030?ooo`000000000000800000103oool2000000<0oooo0`0000020?ooo`030000003oool0oooo
00@0oooo1@0000020?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000000000000`000003
0?ooo`8000000`3oool2000000<0oooo00<000000?ooo`3oool01P00000;0=7=Z@80oooo00@00000
0?ooo`3oool0oooo0P0000030?ooo`040000003oool0oooo0?ooo`<000001@3oool3000000<0oooo
0P0000030?ooo`040000003oool0oooo0?ooo`8000000`3oool010000000oooo0?ooo`3oool20000
00<0oooo0`0000050?ooo`<000000`3oool010000000oooo0?ooo`3oool2000000<0oooo00<00000
0?ooo`3oool03P3AcJT000`0dLfY0`0000040?ooo`H000000P3oool2000000030?ooo`0000000000
00L0oooo0`0000030?ooo`8000000P3oool5000000<0oooo0`0000020?ooo`030000003oool0oooo
0080000000<0oooo0000000000000P0000000`3oool00000000000020?ooo`030000003oool0oooo
0080oooo0`0000020?ooo`030000003oool0oooo00/0dLfY1`3oool010000000oooo0?ooo`000002
0?ooo`<000000P3oool2000000@0oooo0P0000050?ooo`80000000@0oooo000000000000oooo1000
00000`3oool00000000000020?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003o
ool0oooo00<000000P3oool00`000000oooo0?ooo`02000000H0oooo2`3AcJT5000000@0oooo0P00
00030?ooo`8000000`3oool3000000<0oooo0P0000000`3oool00000000000050?ooo`H0000000<0
oooo0000000000000`3oool3000000D0oooo0P000000103oool000000000003oool2000000030?oo
o`000000000000T0oooo0P00000;0=7=Z@D0oooo1P0000000`3oool0000000000002000000@0oooo
0P0000030?ooo`<000000P3oool00`000000oooo0?ooo`040?ooo`D000000P3oool010000000oooo
0?ooo`3oool2000000030?ooo`000000000000<000000`3oool2000000<0oooo0P0000030?ooo`03
0000003oool0oooo00H000002`3AcJT60?ooo`<000000P3oool00`000000oooo0?ooo`0300000004
0?ooo`000000000000000080oooo00<000000?ooo`3oool00`0000020?ooo`<0000000@0oooo0000
0000000000000P3oool3000000040?ooo`000000000000000080oooo0`0000020?ooo`030000003o
ool0oooo00<0000000@0oooo00000000000000000P3oool00`000000oooo0?ooo`03000000H0oooo
3P3AcJT000`0dLfY0`0000040?ooo`H000000P3oool2000000030?ooo`000000000000L0oooo0`00
00030?ooo`8000000P3oool5000000<0oooo0`0000020?ooo`030000003oool0oooo0080000000<0
oooo0000000000000P0000000`3oool00000000000020?ooo`030000003oool0oooo0080oooo0`00
00020?ooo`030000003oool0oooo00/0dLfY0P3oool5000000040?ooo`00000000000?ooo`@00000
1P3oool8000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`P00000
1P3oool4000000030?ooo`00000000000080oooo100000020?ooo`/0dLfY1@0000040?ooo`800000
0`3oool2000000<0oooo0`0000030?ooo`80000000<0oooo0000000000001@3oool6000000030?oo
o`000000000000<0oooo0`0000050?ooo`80000000@0oooo000000000000oooo0P0000000`3oool0
0000000000090?ooo`8000002`3AcJT20?ooo`030000003oool0oooo00@0oooo0P0000050?ooo`03
0000003oool0oooo00<00000203oool00`000000oooo0?ooo`03000000030?ooo`000000000000H0
oooo0P00000<0?ooo`8000000`3oool<00000080oooo2`3AcJT60?ooo`<000000P3oool00`000000
oooo0?ooo`03000000040?ooo`000000000000000080oooo00<000000?ooo`3oool00`0000020?oo
o`<0000000@0oooo00000000000000000P3oool3000000040?ooo`000000000000000080oooo0`00
00020?ooo`030000003oool0oooo00<0000000@0oooo00000000000000000P3oool00`000000oooo
0?ooo`03000000H0oooo3P3AcJT000`0dLfY0`0000040?ooo`<000000P3oool00`000000oooo0?oo
o`030?ooo`T000000`3oool2000000030?ooo`000000000000<0oooo0P0000020?ooo`<0000000<0
oooo0000000000000P3oool5000000030?ooo`00000000000080oooo1P0000020?ooo`8000000`3o
ool2000000<0oooo2`3AcJT20?ooo`030000003oool0oooo00800000103oool200000080oooo0`00
00030?ooo`80000000<0oooo0000000000000P3oool00`000000oooo0?ooo`020?ooo`<0000000<0
oooo0000000000000P0000000`3oool0000000000002000000<0oooo00<000000?ooo`3oool00P00
00000`3oool00000000000030?ooo`<000000P3oool2000000D0oooo00@000000?ooo`3oool00000
0P3oool;0=7=Z@80oooo00@000000?ooo`3oool0oooo0P0000000`3oool0000000000002000000<0
oooo00<000000?ooo`3oool02@0000030?ooo`8000000`3oool2000000<0oooo0`0000030?ooo`80
0000103oool2000000<0oooo0P0000030?ooo`030000003oool0oooo0080oooo1P0000000`3oool0
00000000000;0=7=Z@P0oooo0`0000030?ooo`80000000@0oooo00000000000000000`3oool20000
00D0oooo2`000000103oool000000000000000050?ooo`030000003oool0oooo00<0oooo0P000000
0`3oool00000000000080?ooo`030000003oool0oooo00<0000000<0oooo0000000000002`3AcJT2
000000030?ooo`000000000000<0oooo1`0000030?ooo`H000000P3oool300000080oooo0`000000
103oool000000000000000020?ooo`<0000000@0oooo00000000000000000P3oool300000080oooo
1P0000030?ooo`L000000`3oool2000000030?ooo`000000000000h0dLfY000<0=7=Z@`0oooo00<0
00000?ooo`3oool02P3oool500000080oooo0`0000020?ooo`<000000P3oool3000000030?ooo`00
00000000008000001@3oool300000080oooo0`0000030?ooo`8000000P3oool300000080oooo0`00
000;0=7=Z@80oooo00<000000?ooo`3oool00P0000040?ooo`8000000P3oool3000000<0oooo0P00
00000`3oool00000000000020?ooo`030000003oool0oooo0080oooo0`0000000`3oool000000000
0002000000030?ooo`0000000000008000000`3oool00`000000oooo0?ooo`02000000030?ooo`00
0000000000<0oooo0`0000020?ooo`8000001@3oool010000000oooo0?ooo`0000020?ooo`/0dLfY
1@0000030?ooo`030000003oool0oooo0080000000@0oooo000000000000oooo0P0000000`3oool0
0000000000030?ooo`D000001@3oool7000000D0oooo1@0000030?ooo`80000000@0oooo00000000
0000oooo0P0000000`3oool00000000000020?ooo`040000003oool0oooo0?ooo`D000002`3AcJT8
0?ooo`<000000`3oool2000000040?ooo`0000000000000000<0oooo0P0000050?ooo`/0000000@0
oooo00000000000000001@3oool00`000000oooo0?ooo`030?ooo`80000000<0oooo000000000000
203oool00`000000oooo0?ooo`03000000030?ooo`000000000000/0dLfY0P3oool010000000oooo
0?ooo`3oool2000000<0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`040000003oool0oooo
0?ooo`8000000`3oool2000000<0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`040000003o
ool0oooo0?ooo`8000000`3oool2000000<0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`04
0000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`0>0=7=Z@00303AcJT<0?ooo`03
0000003oool0oooo00X0oooo1@0000020?ooo`<000000P3oool300000080oooo0`0000000`3oool0
000000000002000000D0oooo0`0000020?ooo`<000000`3oool200000080oooo0`0000020?ooo`<0
00002`3AcJT20?ooo`030000003oool0oooo00800000103oool200000080oooo0`0000030?ooo`80
000000<0oooo0000000000000P3oool00`000000oooo0?ooo`020?ooo`<0000000<0oooo00000000
00000P0000000`3oool0000000000002000000<0oooo00<000000?ooo`3oool00P0000000`3oool0
0000000000030?ooo`<000000P3oool2000000D0oooo00@000000?ooo`3oool000000P3oool;0=7=
Z@D000000`3oool00`000000oooo0?ooo`02000000040?ooo`00000000000?ooo`80000000<0oooo
0000000000000`3oool5000000D0oooo1`0000050?ooo`D000000`3oool2000000040?ooo`000000
00000?ooo`80000000<0oooo0000000000000P3oool010000000oooo0?ooo`3oool5000000/0dLfY
0P000000103oool000000000000000020?ooo`030000003oool0oooo00H0oooo0P0000000`3oool0
0000000000050?ooo`030000003oool0oooo00<0oooo0`0000000`3oool0000000000009000000D0
oooo0P0000030?ooo`<0000000<0oooo0000000000000`3oool3000000P0oooo2`3AcJT20?ooo`04
0000003oool0oooo0?ooo`8000000`3oool010000000oooo0?ooo`3oool2000000<0oooo00@00000
0?ooo`3oool0oooo0P0000030?ooo`8000000`3oool010000000oooo0?ooo`3oool2000000<0oooo
00@000000?ooo`3oool0oooo0P0000030?ooo`8000000`3oool010000000oooo0?ooo`3oool20000
00<0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo00h0dLfY000<0=7=
Z@<0oooo100000050?ooo`030000003oool0oooo00<000001@3oool2000000<0oooo0P0000020?oo
o`030000003oool0oooo00<000000P3oool2000000<0oooo00<000000?ooo`3oool00`0000020?oo
o`<000000P3oool2000000<0oooo0`0000040?ooo`<000000P3oool3000000/0dLfY0P3oool00`00
0000oooo0?ooo`02000000@0oooo0P0000020?ooo`<000000`3oool2000000030?ooo`0000000000
0080oooo00<000000?ooo`3oool00P3oool3000000030?ooo`00000000000080000000<0oooo0000
000000000P0000030?ooo`030000003oool0oooo0080000000<0oooo0000000000000`3oool30000
0080oooo0P0000050?ooo`040000003oool0oooo00000080oooo2`3AcJT5000000030?ooo`000000
000000<0oooo0`0000060?ooo`D000000P3oool3000000D0oooo0`0000040?ooo`@00000103oool2
000000030?ooo`00000000000080oooo100000050?ooo`H000001@3oool;0=7=Z@80000000@0oooo
00000000000000000P3oool00`000000oooo0?ooo`060?ooo`80000000<0oooo0000000000001@3o
ool00`000000oooo0?ooo`030?ooo`<0000000<0oooo0000000000002@0000050?ooo`8000000`3o
ool3000000030?ooo`000000000000<0oooo0`0000080?ooo`/0dLfY0P0000000`3oool000000000
00030?ooo`L000000`3oool600000080oooo0`0000020?ooo`<0000000@0oooo0000000000000000
0P3oool3000000040?ooo`000000000000000080oooo0`0000020?ooo`H000000`3oool7000000<0
oooo0P0000000`3oool000000000000>0=7=Z@00303AcJT2000000030?ooo`000000000000800000
00<0oooo0000000000000P3oool600000080oooo0P0000030?ooo`P000000P3oool2000000D0oooo
0`0000050?ooo`D000001@3oool8000000D0oooo0P0000030?ooo`/0dLfY0P3oool5000000040?oo
o`00000000000?ooo`@000001P3oool8000000L0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`P000001P3oool4000000030?ooo`00000000000080oooo100000020?ooo`/0
dLfY0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo100000070?oo
o`030000003oool0oooo00@0oooo0P0000050?ooo`030000003oool0oooo00D000000`3oool40000
00@0oooo300000020?ooo`<000000`3oool;0=7=Z@80oooo300000030?ooo`800000303oool20000
00H0oooo0P000000103oool000000000000000020?ooo`030000003oool0oooo00H0oooo0`000002
0?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`030000003oool0oooo00/0dLfY1P3oool3
00000080oooo00<000000?ooo`3oool00`000000103oool000000000000000020?ooo`030000003o
ool0oooo00<000000P3oool3000000040?ooo`000000000000000080oooo0`000000103oool00000
0000000000020?ooo`<000000P3oool00`000000oooo0?ooo`03000000040?ooo`00000000000000
0080oooo00<000000?ooo`3oool00`0000060?ooo`h0dLfY000<0=7=Z@80000000<0oooo00000000
00000P0000000`3oool00000000000020?ooo`H000000P3oool2000000<0oooo200000020?ooo`80
00001@3oool3000000D0oooo1@0000050?ooo`P000001@3oool2000000<0oooo2`3AcJT70?ooo`04
0000003oool0oooo00000080oooo0`0000020?ooo`800000103oool2000000D0oooo0P000000103o
ool000000000003oool4000000030?ooo`00000000000080oooo00<000000?ooo`3oool00`3oool2
000000D0oooo00<000000?ooo`3oool00`0000020?ooo`030000003oool0oooo008000001P3oool;
0=7=Z@80oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`@000001`3o
ool00`000000oooo0?ooo`040?ooo`8000001@3oool00`000000oooo0?ooo`05000000<0oooo1000
00040?ooo``000000P3oool3000000<0oooo2`3AcJT600000080oooo00@000000?ooo`3oool0oooo
0P0000030?ooo`8000000`3oool5000000030?ooo`000000000000<0oooo00<000000?ooo`3oool0
1@0000060?ooo`030000003oool0oooo00<000000`3oool2000000@0oooo100000000`3oool00000
00000004000000D0oooo2`3AcJT60?ooo`<000000P3oool00`000000oooo0?ooo`03000000040?oo
o`000000000000000080oooo00<000000?ooo`3oool00`0000020?ooo`<0000000@0oooo00000000
000000000P3oool3000000040?ooo`000000000000000080oooo0`0000020?ooo`030000003oool0
oooo00<0000000@0oooo00000000000000000P3oool00`000000oooo0?ooo`03000000H0oooo3P3A
cJT000`0dLfY0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo008000000`3oool2
000000030?ooo`000000000000<0oooo100000000`3oool00000000000030?oooa4000001@3oool6
00000080oooo1@0000030?ooo`8000000P3oool00`000000oooo0?ooo`0;0=7=Z@L0oooo00@00000
0?ooo`3oool000000P3oool300000080oooo0P0000040?ooo`8000001@3oool2000000040?ooo`00
000000000?ooo`@0000000<0oooo0000000000000P3oool00`000000oooo0?ooo`030?ooo`800000
1@3oool00`000000oooo0?ooo`0300000080oooo00<000000?ooo`3oool00P0000060?ooo`/0dLfY
0`0000080?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`<000002`3oool200000003
0?ooo`000000000000<000001@3oool6000000<0oooo0`0000050?ooo`800000103oool200000003
0?ooo`000000000000/0dLfY1P0000020?ooo`040000003oool0oooo0?ooo`8000000`3oool20000
00<0oooo1@0000000`3oool00000000000030?ooo`030000003oool0oooo00D000001P3oool00`00
0000oooo0?ooo`03000000<0oooo0P0000040?ooo`@0000000<0oooo000000000000100000050?oo
o`/0dLfY0P3oool010000000oooo0?ooo`3oool2000000<0oooo00@000000?ooo`3oool0oooo0`00
00050?ooo`<000000`3oool2000000<0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`040000
003oool0oooo0?ooo`8000000`3oool3000000D0oooo0`0000030?ooo`040000003oool0oooo0?oo
o`8000000`3oool00`000000oooo0?ooo`0>0=7=Z@00303AcJT20?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P0000030?ooo`80000000<0oooo0000000000000`3oool400000003
0?ooo`000000000000<0oooo4@0000050?ooo`H000000P3oool5000000<0oooo0P0000020?ooo`03
0000003oool0oooo00/0dLfY0P0000030?ooo`800000203oool3000000D0oooo1@0000050?ooo`04
0000003oool0oooo0?ooo`@000000`3oool2000000@0oooo1@0000050?ooo`<000002@3oool01000
0000oooo0?ooo`3oool2000000/0dLfY0`0000080?ooo`8000000`3oool010000000oooo0?ooo`00
00020?ooo`<000002`3oool2000000030?ooo`000000000000<000001@3oool6000000<0oooo0`00
00050?ooo`800000103oool2000000030?ooo`000000000000/0dLfY1@0000030?ooo`H000000`3o
ool2000000<0oooo00<000000?ooo`3oool00`0000030?ooo`80000000@0oooo0000000000000000
2P3oool6000000<0oooo2`0000050?ooo`040000003oool0oooo0?ooo`8000002`3AcJT60?ooo`<0
00000P3oool010000000oooo0?ooo`0000020?ooo`<00000103oool500000080oooo0`000000103o
ool000000000000000020?ooo`<0000000@0oooo00000000000000000P3oool5000000@0oooo0`00
00020?ooo`040000003oool0oooo00000080oooo0`0000060?ooo`h0dLfY000<0=7=Z@80000000<0
oooo0000000000000P0000050?ooo`D000000`3oool2000000030?ooo`000000000000<0oooo2@00
00050?ooo`<000000`3oool300000080oooo0`0000090?ooo`030000003oool0oooo00X0oooo2`3A
cJT2000000<0oooo0P0000080?ooo`<000001@3oool5000000D0oooo00@000000?ooo`3oool0oooo
100000030?ooo`800000103oool5000000D0oooo0`0000090?ooo`040000003oool0oooo0?ooo`80
00002`3AcJT2000000@0oooo0P0000050?ooo`H0000000<0oooo0000000000000P0000030?ooo`@0
00000P3oool2000000@0oooo0`0000020?ooo`<000000`3oool500000080oooo00@000000?ooo`3o
ool0oooo0P0000000`3oool000000000000900000080oooo2`3AcJT20?ooo`040000003oool0oooo
000000/0oooo0P0000030?ooo`030000003oool0oooo0080oooo0`0000040?ooo`80000000<0oooo
0000000000000P3oool4000000D0oooo00<000000?ooo`3oool02@3oool7000000040?ooo`000000
0000000000D0oooo2`3AcJT60?ooo`<000000P3oool010000000oooo0?ooo`0000020?ooo`<00000
103oool500000080oooo0`000000103oool000000000000000020?ooo`<0000000@0oooo00000000
000000000P3oool5000000@0oooo0`0000020?ooo`040000003oool0oooo00000080oooo0`000006
0?ooo`h0dLfY000<0=7=Z@<0oooo2P0000050?ooo`8000000P3oool5000000H0oooo0P0000020?oo
o`030000003oool0oooo008000000`3oool300000080oooo1@0000000`3oool00000000000030?oo
o`X000000P3oool2000000030?ooo`000000000000/0dLfY1`3oool3000000030?ooo`0000000000
0080000000<0oooo0000000000000`0000020?ooo`D0000000<0oooo0000000000000P0000000`3o
ool00000000000060?ooo`8000000P3oool3000000030?ooo`000000000000<000000P3oool50000
00030?ooo`00000000000080000000<0oooo0000000000000P0000060?ooo`/0dLfY1@0000040?oo
o`D000000P3oool3000000030?ooo`00000000000080oooo00@000000?ooo`3oool000000P3oool3
000000/0oooo0`0000020?ooo`040000003oool0oooo00000080oooo0P000000103oool000000000
000000020?ooo`D00000103oool5000000/0dLfY0P3oool010000000oooo0?ooo`00000;0?ooo`80
00000`3oool00`000000oooo0?ooo`020?ooo`<00000103oool2000000030?ooo`00000000000080
oooo100000050?ooo`030000003oool0oooo00T0oooo1`000000103oool000000000000000050?oo
o`/0dLfY0P0000000`3oool00000000000030?ooo`H00000103oool2000000040?ooo`0000000000
000000@0oooo00<000000?ooo`3oool00`000000103oool000000000000000020?ooo`<0000000@0
oooo00000000000000000P3oool00`000000oooo0?ooo`020?ooo`<0000000<0oooo000000000000
103oool6000000<0oooo0P0000000`3oool000000000000>0=7=Z@00303AcJT30?ooo`X000001@3o
ool200000080oooo1@0000060?ooo`8000000P3oool00`000000oooo0?ooo`02000000<0oooo0`00
00020?ooo`D0000000<0oooo0000000000000`3oool:00000080oooo0P0000000`3oool000000000
000;0=7=Z@80oooo3@0000050?ooo`<0000000<0oooo0000000000000P3oool5000000d0oooo1000
00020?ooo`80000000<0oooo0000000000000P0000040?ooo`d000000P3oool;0=7=Z@D00000103o
ool500000080oooo0`0000000`3oool00000000000020?ooo`040000003oool0oooo00000080oooo
0`00000;0?ooo`<000000P3oool010000000oooo0?ooo`0000020?ooo`80000000@0oooo00000000
000000000P3oool5000000@0oooo1@00000;0=7=Z@<000002`3oool2000000030?ooo`0000000000
00<0oooo00<000000?ooo`3oool00P0000000`3oool00000000000040?ooo`8000000`3oool30000
0080oooo00@000000?ooo`3oool0oooo200000050?ooo`030000003oool0oooo00P000000`3oool0
0`000000oooo0?ooo`0;0=7=Z@80oooo00@000000?ooo`3oool0oooo0P0000030?oooa@000000`3o
ool010000000oooo0?ooo`3oool2000000<0oooo00@000000?ooo`3oool0oooo500000030?ooo`80
00000`3oool00`000000oooo0?ooo`0>0=7=Z@00303AcJT50?ooo`8000001P3oool2000000L0oooo
1@0000050?ooo`<000000`3oool200000080oooo1P00000=0?ooo`8000000P3oool00`000000oooo
0?ooo`020?ooo`<000000P3oool00`000000oooo0?ooo`0;0=7=Z@80oooo3@0000050?ooo`<00000
00<0oooo0000000000000P3oool5000000d0oooo100000020?ooo`80000000<0oooo000000000000
0P0000040?ooo`d000000P3oool;0=7=Z@<0oooo0P0000040?ooo`800000203oool3000000<0oooo
0`0000030?ooo`P00000203oool2000000<0oooo00<000000?ooo`3oool00`3oool300000080oooo
0`0000020?ooo`040000003oool0oooo00000080oooo0`00000;0=7=Z@800000103oool6000000@0
oooo0`0000030?ooo`<000000`3oool2000000040?ooo`00000000000?ooo`80000000<0oooo0000
000000000P0000030?ooo`040000003oool0oooo0?ooo`<00000103oool010000000oooo0?ooo`00
00070?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`/0dLfY0P3oool010000000oooo0?oo
o`3oool2000000<0oooo500000030?ooo`040000003oool0oooo0?ooo`8000000`3oool010000000
oooo0?ooo`3ooolD000000<0oooo0P0000030?ooo`030000003oool0oooo00h0dLfY000<0=7=Z@D0
oooo0P0000060?ooo`8000001`3oool5000000D0oooo0`0000030?ooo`8000000P3oool6000000d0
oooo0P0000020?ooo`030000003oool0oooo0080oooo0`0000020?ooo`030000003oool0oooo00/0
dLfY0P3oool00`000000oooo0?ooo`020?ooo`<0000000<0oooo0000000000001@3oool200000004
0?ooo`00000000000?ooo`8000000P3oool3000000D0oooo1P0000050?ooo`<000000P3oool20000
00030?ooo`00000000000080oooo00<000000?ooo`3oool00`3oool2000000030?ooo`0000000000
008000000`3oool00`000000oooo0?ooo`0;0=7=Z@80oooo0`000000103oool000000000003oool4
000000040?ooo`00000000000?ooo`<00000103oool3000000<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0300000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`060?ooo`8000001P3oool2000000H0oooo2`3AcJT2000000@0oooo1P0000040?ooo`<00000
0`3oool3000000<0oooo0P000000103oool000000000003oool2000000030?ooo`00000000000080
00000`3oool010000000oooo0?ooo`3oool3000000@0oooo00@000000?ooo`3oool000001`3oool3
000000<0oooo00<000000?ooo`3oool00`3oool;0=7=Z@80000000<0oooo0000000000000`3oool3
000000030?ooo`000000000000@0oooo0P000000103oool000000000000000040?ooo`H0000000@0
oooo00000000000000000P3oool3000000030?ooo`000000000000@00000103oool3000000030?oo
o`000000000000@0oooo0P000000103oool000000000000000030?ooo`80000000<0oooo00000000
00003P3AcJT000`0dLfY200000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool2000000<0oooo0P0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080000000<0oooo00000000
00000P3oool5000000030?ooo`000000000000<0oooo0P00000;0=7=Z@80oooo1@0000040?ooo`D0
00001@3oool7000000<0oooo0`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`0000030?ooo`L000001@3oool5000000D0oooo100000020?ooo`/0dLfY0P3oool300000004
0?ooo`00000000000?ooo`@0000000@0oooo000000000000oooo0`0000040?ooo`<000000`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00<000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00H0oooo0P0000060?ooo`8000001P3oool;0=7=Z@D0000000<0
oooo0000000000000`3oool00`000000oooo0?ooo`03000000H0oooo10000000103oool000000000
000000020?ooo`H000000P3oool010000000oooo0?ooo`0000060?ooo`L00000103oool4000000<0
oooo0`0000040?ooo`8000002`3AcJT60?ooo`D0000000@0oooo00000000000000000P3oool30000
00@0oooo10000000103oool000000000003oool2000000040?ooo`000000000000000080oooo0`00
0000103oool000000000003oool2000000030?ooo`000000000000800000103oool300000080oooo
0`0000000`3oool0000000000003000000H0oooo3P3AcJT000`0dLfY0P0000030?ooo`<000001@3o
ool2000000D0oooo1`0000030?ooo`D000000`3oool200000080oooo00<000000?ooo`3oool02000
00030?ooo`8000000P3oool5000000<0oooo0P0000000`3oool00000000000020?ooo`030000003o
ool0oooo00/0dLfY0P3oool5000000@0oooo1@0000050?ooo`L000000`3oool300000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`03000000<0oooo1`0000050?ooo`D000001@3o
ool400000080oooo2`3AcJT20?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
0`0000020?ooo`<0000000<0oooo0000000000000P3oool010000000oooo0?ooo`0000030?ooo`80
00000`3oool:000000@0oooo0`0000020?ooo`<000000P3oool010000000oooo0?ooo`0000020?oo
o`<000000P3oool3000000<0oooo2`3AcJT30?ooo`d0000000<0oooo000000000000100000020?oo
o`<000000P3oool00`000000oooo0?ooo`03000000H0oooo0`0000020?ooo`030000003oool0oooo
00<000000P3oool6000000030?ooo`000000000000/000000`3oool;0=7=Z@H0oooo1@000000103o
ool000000000000000020?ooo`<00000103oool4000000040?ooo`00000000000?ooo`80000000@0
oooo00000000000000000P3oool3000000040?ooo`00000000000?ooo`80000000<0oooo00000000
00000P0000040?ooo`<000000P3oool3000000030?ooo`000000000000<000001P3oool>0=7=Z@00
303AcJT2000000<0oooo0`0000050?ooo`8000001@3oool7000000<0oooo1@0000030?ooo`800000
0P3oool00`000000oooo0?ooo`08000000<0oooo0P0000020?ooo`D000000`3oool2000000030?oo
o`00000000000080oooo00<000000?ooo`3oool02`3AcJT50?ooo`<000001`3oool00`000000oooo
0?ooo`060?oooah00000203oool00`000000oooo0?ooo`050?ooo`<000001@3oool;0=7=Z@80oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0300000080oooo0`0000000`3oool0
0000000000020?ooo`040000003oool0oooo000000<0oooo0P0000030?ooo`X00000103oool30000
0080oooo0`0000020?ooo`040000003oool0oooo00000080oooo0`0000020?ooo`<000000`3oool;
0=7=Z@<0oooo3@0000000`3oool000000000000400000080oooo0`0000020?ooo`030000003oool0
oooo00<000001P3oool300000080oooo00<000000?ooo`3oool00`0000020?ooo`H0000000<0oooo
0000000000002`0000030?ooo`/0dLfY0P3oool010000000oooo0?ooo`3oool300000080oooo00<0
00000?ooo`3oool0100000050?ooo`D0000000@0oooo000000000000oooo0`0000030?ooo`800000
0`3oool3000000040?ooo`00000000000?ooo`D000001@3oool400000080oooo00<000000?ooo`3o
ool00`0000030?ooo`030000003oool0oooo00h0dLfY000<0=7=Z@D000001@3oool3000000L0oooo
0P0000000`3oool0000000000002000000030?ooo`000000000000D000000P3oool00`000000oooo
0?ooo`05000000H0oooo0P0000020?ooo`030000003oool0oooo0080oooo3`0000000`3oool00000
0000000;0=7=Z@D0oooo0`0000070?ooo`030000003oool0oooo00H0oooo7P0000080?ooo`030000
003oool0oooo00D0oooo0`0000050?ooo`/0dLfY0P3oool00`000000oooo0?ooo`080?ooo`040000
003oool0oooo000000D0oooo0`0000050?ooo`030000003oool0oooo00<0oooo0`0000020?ooo`/0
000000<0oooo0000000000001@0000040?ooo`D000000P3oool3000000030?ooo`000000000000/0
dLfY0P3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool00`3oool20000
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03000000<0oooo00<000000?oo
o`3oool01@000000103oool000000000003oool3000000D0oooo0P000000103oool0000000000000
00020?ooo`8000000`3oool3000000030?ooo`000000000000<0oooo2`3AcJT20?ooo`040000003o
ool0oooo0?ooo`<000000P3oool00`000000oooo0?ooo`04000000D0oooo1@000000103oool00000
0000003oool3000000<0oooo0P0000030?ooo`<0000000@0oooo000000000000oooo1@0000050?oo
o`@000000P3oool00`000000oooo0?ooo`03000000<0oooo00<000000?ooo`3oool03P3AcJT000`0
dLfY1@0000050?ooo`<000001`3oool2000000030?ooo`00000000000080000000<0oooo00000000
00001@0000020?ooo`030000003oool0oooo00D000001P3oool200000080oooo00<000000?ooo`3o
ool00P3oool?000000030?ooo`000000000000/0dLfY0P0000000`3oool00000000000020?ooo`04
0000003oool0oooo00000080oooo0`0000020?ooo`<000000P3oool00`000000oooo0?ooo`020000
00<0oooo0`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`0000030?oo
o`8000000P3oool00`000000oooo0?ooo`0300000080oooo0`0000020?ooo`030000003oool0oooo
0080000000@0oooo000000000000oooo0P00000;0=7=Z@80oooo00@000000?ooo`3oool0oooo0P00
00000`3oool000000000000=000000L0oooo100000070?ooo`@000001`3oool?000000030?ooo`00
0000000000<0oooo00<000000?ooo`3oool02`3AcJT20?ooo`040000003oool0oooo0?ooo`800000
0`3oool00`000000oooo0?ooo`030?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<000000`3oool00`000000oooo0?ooo`05000000040?ooo`00000000000?ooo`<0
00001@3oool2000000040?ooo`000000000000000080oooo0P0000030?ooo`<0000000<0oooo0000
000000000`3oool;0=7=ZA80oooo0`0000020?ooo`<000000P3oool400000080oooo100000020?oo
o`@000000P3oool400000080oooo0`0000020?ooo`<000004P3oool>0=7=Z@00303AcJT30?ooo`@0
00000`3oool800000080oooo0P0000050?ooo`H000000P3oool2000000<0oooo1P0000040?ooo`D0
000000<0oooo0000000000000`3oool4000000<0oooo0P0000000`3oool0000000000002000000<0
oooo2`3AcJT20?ooo`030000003oool0oooo0080oooo0`0000000`3oool000000000000200000003
0?ooo`000000000000D000000`3oool5000000D0oooo1P0000050?ooo`D000000`3oool700000003
0?ooo`00000000000080000000<0oooo0000000000000P0000030?ooo`030000003oool0oooo00/0
dLfY0P3oool010000000oooo0?ooo`3oool2000000030?ooo`000000000000d000001`3oool40000
00L0oooo100000070?ooo`l0000000<0oooo0000000000000`3oool00`000000oooo0?ooo`0;0=7=
Z@<0oooo2`0000030?ooo`H000000P3oool5000000030?ooo`000000000000<0000000<0oooo0000
000000000P0000070?ooo`80000000<0oooo0000000000001@0000030?ooo`030000003oool0oooo
00D00000103oool2000000030?ooo`000000000000/0dLfY0P000000103oool00000000000000003
0?ooo`80000000<0oooo0000000000000`3oool6000000D0oooo100000050?ooo`040000003oool0
oooo000000D0oooo100000050?ooo`H000000`3oool2000000030?ooo`000000000000<0oooo0`00
00000`3oool000000000000>0=7=Z@00303AcJT20?ooo`030000003oool0oooo008000001@3oool0
0`000000oooo0?ooo`020?ooo`D000000`3oool7000000D0oooo00<000000?ooo`3oool00P3oool4
000000@0oooo1@0000050?ooo`030000003oool0oooo0080oooo1@0000080?ooo`/0dLfY0P3oool0
0`000000oooo0?ooo`020?ooo`<0000000<0oooo0000000000000P0000000`3oool0000000000005
000000<0oooo1@0000050?ooo`H000001@3oool5000000<0oooo1`0000000`3oool0000000000002
000000030?ooo`0000000000008000000`3oool00`000000oooo0?ooo`0;0=7=Z@80oooo00<00000
0?ooo`3oool00`3oool300000080oooo00@000000?ooo`3oool000001`3oool;000000@0oooo0`00
00040?ooo`030000003oool0oooo00H0oooo1@0000040?ooo`8000001@3oool3000000030?ooo`00
0000000000/0dLfY1@0000000`3oool00000000000030?ooo`<000002@3oool7000000@0oooo0P00
00000`3oool00000000000020?ooo`040000003oool0oooo000000<0oooo0P0000000`3oool00000
000000060?ooo`D000000`3oool3000000<0oooo0`0000020?ooo`/0dLfY0P000000103oool00000
0000000000030?ooo`80000000<0oooo0000000000000`3oool6000000D0oooo100000050?ooo`04
0000003oool0oooo000000D0oooo100000050?ooo`H000000`3oool2000000030?ooo`0000000000
00<0oooo0`0000000`3oool000000000000>0=7=Z@00303AcJT20?ooo`030000003oool0oooo0080
00001@3oool00`000000oooo0?ooo`020?ooo`D000000`3oool7000000D0oooo00<000000?ooo`3o
ool00P3oool4000000@0oooo1@0000050?ooo`030000003oool0oooo0080oooo1@0000080?ooo`/0
dLfY0P0000000`3oool00000000000030?ooo`80000000<0oooo0000000000000`3oool8000000D0
oooo1000000=0?ooo`<000001@3oool8000000<0oooo0P0000000`3oool00000000000030?ooo`80
000000<0oooo0000000000002`3AcJT20?ooo`030000003oool0oooo00@00000103oool00`000000
oooo0?ooo`03000000<0oooo0`0000060?ooo`8000000`3oool2000000030?ooo`000000000000D0
00000`3oool600000080oooo00@000000?ooo`3oool000000P3oool;000000<0oooo2`3AcJT50000
00030?ooo`000000000000<0oooo0`0000090?ooo`L00000103oool2000000030?ooo`0000000000
0080oooo00@000000?ooo`3oool000000`3oool2000000030?ooo`000000000000H0oooo1@000003
0?ooo`<000000`3oool300000080oooo2`3AcJT20?ooo`@000001@3oool00`000000oooo0?ooo`03
0?ooo`L000001@3oool2000000@0oooo200000040?ooo`8000001@3oool7000000D0oooo00<00000
0?ooo`3oool00`3oool400000080oooo3P3AcJT000`0dLfY1@3oool2000000030?ooo`0000000000
00L00000203oool500000080oooo1@0000030?ooo`80000000<0oooo0000000000001P3oool20000
00P0oooo1@0000090?ooo`<000002`3AcJT2000000030?ooo`000000000000<0oooo0P0000000`3o
ool00000000000030?ooo`P000001@3oool4000000d0oooo0`0000050?ooo`P000000`3oool20000
00030?ooo`000000000000<0oooo0P0000000`3oool000000000000;0=7=Z@80oooo00<000000?oo
o`3oool0100000040?ooo`030000003oool0oooo00<000000`3oool3000000H0oooo0P0000030?oo
o`80000000<0oooo0000000000001@0000030?ooo`H000000P3oool010000000oooo0?ooo`000002
0?ooo`/000000`3oool;0=7=Z@800000103oool5000000D0oooo00<000000?ooo`3oool00`3oool6
000000D0oooo1P0000030?ooo`800000103oool7000000@0oooo200000020?ooo`030000003oool0
oooo00<0oooo0`00000;0=7=Z@D000000`3oool3000000040?ooo`0000000000000000<0oooo1P00
00020?ooo`P0000000@0oooo00000000000000000P3oool3000000030?ooo`000000000000H00000
0P3oool6000000<0oooo0`000000103oool000000000000000030?ooo`D000003P3AcJT000`0dLfY
1@3oool2000000030?ooo`000000000000L00000203oool500000080oooo1@0000030?ooo`800000
00<0oooo0000000000001P3oool2000000P0oooo1@0000090?ooo`<000002`3AcJT70?ooo`P00000
0`3oool6000000@0oooo00<000000?ooo`3oool00P0000000`3oool00000000000060?ooo`800000
0P3oool010000000oooo0?ooo`0000040?ooo`H000000`3oool9000000H0oooo2`3AcJT20?ooo`@0
00000`3oool200000080oooo0`0000000`3oool00000000000030?ooo`80000000<0oooo00000000
00000`3oool5000000<0oooo00@000000?ooo`3oool000000P3oool300000080oooo00@000000?oo
o`3oool0oooo0P0000020?ooo`040000003oool0oooo0?ooo`D000001@3oool00`000000oooo0?oo
o`030?ooo`/0dLfY0`0000060?ooo`<000001`3oool00`000000oooo0?ooo`05000000040?ooo`00
0000000000000080oooo0`0000050?ooo`030000003oool0oooo00<00000103oool4000000030?oo
o`000000000000<0oooo0`0000020?ooo`040000003oool0oooo00000080oooo0`0000000`3oool0
00000000000;0=7=Z@D000000`3oool3000000040?ooo`0000000000000000<0oooo1P0000020?oo
o`P0000000@0oooo00000000000000000P3oool3000000030?ooo`000000000000H000000P3oool6
000000<0oooo0`000000103oool000000000000000030?ooo`D000003P3AcJT000`0dLfY0P000003
0?ooo`D000000P3oool00`000000oooo0?ooo`03000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<000001@3ooolD000000<0oooo0P000002
0?ooo`<000000P3oool3000000/0dLfY0P3oool00`000000oooo0?ooo`020?ooo`<0000000<0oooo
0000000000000P0000000`3oool00000000000020?ooo`<00000203oool3000000<0oooo10000003
0?ooo`<00000203oool4000000040?ooo`00000000000?ooo`@0000000<0oooo0000000000000P00
00030?ooo`030000003oool0oooo00/0dLfY1P3oool300000080oooo0P000000103oool000000000
003oool2000000<0oooo0P0000060?ooo`D0000000<0oooo0000000000000`3oool00`000000oooo
0?ooo`020?ooo``000000P3oool400000080oooo0P0000000`3oool0000000000006000000/0dLfY
0`0000060?ooo`<000001`3oool00`000000oooo0?ooo`05000000040?ooo`000000000000000080
oooo0`0000050?ooo`030000003oool0oooo00<00000103oool4000000030?ooo`000000000000<0
oooo0`0000020?ooo`040000003oool0oooo00000080oooo0`0000000`3oool000000000000;0=7=
Z@<000000P3oool00`000000oooo0?ooo`03000000040?ooo`000000000000000080oooo00<00000
0?ooo`3oool00`0000000`3oool0000000000002000000040?ooo`00000000000?ooo`<00000203o
ool3000000040?ooo`00000000000?ooo`@0000000@0oooo00000000000000000P3oool00`000000
oooo0?ooo`03000000040?ooo`000000000000000080oooo00<000000?ooo`3oool00`00000>0=7=
Z@00303AcJT<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool500000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`8000002P3oool300000080
oooo1`0000030?ooo`/0dLfY0P3oool00`000000oooo0?ooo`020?ooo`<0000000<0oooo00000000
00000P0000000`3oool00000000000020?ooo`<00000203oool3000000<0oooo100000030?ooo`<0
0000203oool4000000040?ooo`00000000000?ooo`@0000000<0oooo0000000000000P0000030?oo
o`030000003oool0oooo00/0dLfY1P3oool300000080oooo0P000000103oool000000000003oool2
000000<0oooo0P0000060?ooo`D0000000<0oooo0000000000000`3oool00`000000oooo0?ooo`02
0?ooo``000000P3oool400000080oooo0P0000000`3oool0000000000006000000/0dLfY0P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo0P0000040?ooo`800000
00<0oooo0000000000000`3oool5000000<0oooo00<000000?ooo`3oool01@3oool3000000<0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000000D0oooo2@0000000`3oool0
00000000000;0=7=Z@H0oooo0P0000030?ooo`040000003oool0oooo0?ooo`8000001`3oool20000
00<0oooo0P0000030?ooo`<0000000@0oooo000000000000oooo0`0000030?ooo`8000000`3oool2
000000L0oooo0P0000030?ooo`040000003oool0oooo0?ooo`8000001P3oool>0=7=Z@00303AcJT<
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool500000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`8000002P3oool300000080oooo1`000003
0?ooo`/0dLfY3`3oool00`000000oooo0?ooo`050?ooo`D000001@3oool3000000030?ooo`000000
00000080000000<0oooo0000000000000P0000040?ooo`D000001`3oool00`000000oooo0?ooo`0=
0?ooo`/0dLfY0P0000030?ooo`@000001@3oool5000000<0oooo0P0000030?ooo`040000003oool0
oooo0?ooo`8000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00800000
0`3oool010000000oooo0?ooo`3oool2000000<0oooo1@0000050?ooo`@000000`3oool2000000/0
dLfY1@0000000`3oool00000000000030?ooo`<000000`3oool3000000<0oooo100000030?ooo`H0
00000`3oool2000000X0oooo100000000`3oool00000000000030?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`3oool000000P3oool3000000/0dLfY1P3oool2000000<0oooo00@000000?oo
o`3oool0oooo0P0000070?ooo`8000000`3oool2000000<0oooo0`000000103oool000000000003o
ool3000000<0oooo0P0000030?ooo`8000001`3oool2000000<0oooo00@000000?ooo`3oool0oooo
0P0000060?ooo`h0dLfY000<0=7=Z@80oooo0`0000070?ooo`030000003oool0oooo00<000000P3o
ool2000000<0oooo200000020?ooo`<000000P3oool3000000L0oooo1@0000060?ooo`D000000P3o
ool800000080oooo2`3AcJT2000000030?ooo`0000000000008000000`3oool00`000000oooo0?oo
o`02000000030?ooo`00000000000080000000@0oooo00000000000000000P3oool2000000030?oo
o`00000000000080000000@0oooo0000000000000000103oool300000080oooo0`0000000`3oool0
0000000000020?ooo`<000000P3oool3000000030?ooo`00000000000080oooo00<000000?ooo`3o
ool00P3oool3000000030?ooo`000000000000/0dLfY0P0000030?ooo`@000001@3oool5000000<0
oooo0P0000030?ooo`040000003oool0oooo0?ooo`8000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo008000000`3oool010000000oooo0?ooo`3oool2000000<0oooo1@00
00050?ooo`@000000`3oool2000000/0dLfY1@0000000`3oool00000000000030?ooo`<000000`3o
ool3000000<0oooo100000030?ooo`H000000`3oool2000000X0oooo100000000`3oool000000000
00030?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool3000000/0dLfY
0`3oool300000080oooo0`000000103oool000000000000000020?ooo`<00000103oool400000004
0?ooo`00000000000?ooo`80000000@0oooo00000000000000000P3oool3000000040?ooo`000000
00000?ooo`80000000<0oooo0000000000000P0000040?ooo`<000000P3oool3000000040?ooo`00
0000000000000080oooo0`0000030?ooo`h0dLfY000<0=7=Z@80oooo0`0000070?ooo`030000003o
ool0oooo00<000000P3oool2000000<0oooo200000020?ooo`<000000P3oool3000000L0oooo1@00
00060?ooo`D000000P3oool800000080oooo2`3AcJT2000000030?ooo`0000000000008000000`3o
ool00`000000oooo0?ooo`02000000030?ooo`00000000000080000000@0oooo0000000000000000
0P3oool2000000030?ooo`00000000000080000000@0oooo0000000000000000103oool300000080
oooo0`0000000`3oool00000000000020?ooo`<000000P3oool3000000030?ooo`00000000000080
oooo00<000000?ooo`3oool00P3oool3000000030?ooo`000000000000/0dLfY1@3oool3000000h0
oooo0P0000060?ooo`<000001P3oool500000080oooo3`0000020?ooo`P0000000<0oooo00000000
00000`00000;0=7=Z@D000000`3oool010000000oooo0?ooo`3oool4000000030?ooo`0000000000
00<000000`3oool2000000040?ooo`00000000000?ooo`80000000@0oooo00000000000000001@3o
ool2000000<0oooo200000040?ooo`8000000`3oool2000000040?ooo`000000000000000080oooo
00@000000?ooo`3oool000000P3oool;0=7=Z@80000000@0oooo00000000000000000P3oool30000
00040?ooo`000000000000000080oooo0`0000000`3oool00000000000030?ooo`H000001@3oool0
10000000oooo0?ooo`0000050?ooo`H000000`3oool2000000040?ooo`000000000000000080oooo
0`000000103oool000000000000000020?ooo`<0000000<0oooo0000000000003P3AcJT000`0dLfY
0P3oool300000080oooo0`0000020?ooo`D0000000<0oooo0000000000001`3oool3000000<0oooo
100000000`3oool000000000000300000080oooo0`0000020?ooo`D0000000<0oooo000000000000
0P0000000`3oool0000000000002000000030?ooo`00000000000080oooo1P0000020?ooo`/0dLfY
0P3oool5000000@0oooo0P0000030?ooo`L000000`3oool7000000<0oooo1P0000040?ooo`H00000
0`3oool7000000<0oooo0P0000050?ooo`@000000P3oool;0=7=Z@80oooo00<000000?ooo`3oool0
0`3oool6000000D0oooo00<000000?ooo`3oool00P0000000`3oool00000000000030?ooo`030000
003oool0oooo00<0oooo200000020?ooo`040000003oool0oooo000000<0oooo0P0000030?ooo`80
00000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000000`3oool;0=7=
Z@D000000`3oool010000000oooo0?ooo`3oool4000000030?ooo`000000000000<000000`3oool2
000000040?ooo`00000000000?ooo`80000000@0oooo00000000000000001@3oool2000000<0oooo
200000040?ooo`8000000`3oool2000000040?ooo`000000000000000080oooo00@000000?ooo`3o
ool000000P3oool;0=7=Z@80000000@0oooo00000000000000000P3oool3000000040?ooo`000000
000000000080oooo0`0000000`3oool00000000000030?ooo`H000001@3oool010000000oooo0?oo
o`0000050?ooo`H000000`3oool2000000040?ooo`000000000000000080oooo0`000000103oool0
00000000000000020?ooo`<0000000<0oooo0000000000003P3AcJT000`0dLfY1@3oool7000000P0
oooo1`0000030?ooo`D000000`3oool4000000030?ooo`000000000000D0000000<0oooo00000000
00000P3oool6000000X0oooo100000030?ooo`/0dLfY0P3oool5000000@0oooo0P0000030?ooo`L0
00000`3oool7000000<0oooo1P0000040?ooo`H000000`3oool7000000<0oooo0P0000050?ooo`@0
00000P3oool;0=7=Z@80oooo00<000000?ooo`3oool00`3oool6000000D0oooo00<000000?ooo`3o
ool00P0000000`3oool00000000000030?ooo`030000003oool0oooo00<0oooo200000020?ooo`04
0000003oool0oooo000000<0oooo0P0000030?ooo`8000000`3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo0?ooo`8000000`3oool;0=7=Z@80oooo00@000000?ooo`3oool0oooo0P00
00030?ooo`030000003oool0oooo00<000000P3oool3000000030?ooo`000000000000<000000`3o
ool2000000<0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`3oool2000000P0oooo
00<000000?ooo`3oool00P3oool3000000030?ooo`000000000000H000002`3AcJT20?ooo`040000
003oool0oooo0?ooo`8000000`3oool010000000oooo0?ooo`3oool2000000<0oooo00@000000?oo
o`3oool0oooo0P0000030?oooa@000000`3oool2000000<0oooo00@000000?ooo`3oool0oooo0P00
00030?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`0>0=7=Z@00303A
cJT50?ooo`L00000203oool7000000<0oooo1@0000030?ooo`@0000000<0oooo0000000000001@00
00000`3oool00000000000020?ooo`H000002P3oool4000000<0oooo2`3AcJT5000000<0oooo0`00
00020?ooo`8000000`3oool2000000<0oooo00<000000?ooo`3oool00`3oool2000000<0oooo0P00
00060?ooo`8000000`3oool2000000D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`3oool200000080oooo0`0000030?ooo`D000002`3AcJT60?ooo`<00000103oool010000000oooo
0?ooo`0000030?ooo`D000001@3oool5000000040?ooo`00000000000?ooo`<000000P3oool30000
0080oooo300000020?ooo`P0000000@0oooo00000000000000000P3oool;0=7=Z@D000000`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo20000000103oool000000000003o
ool300000080oooo0`0000020?ooo`030000003oool0oooo00h000000`3oool3000000<0oooo0`00
00020?ooo`<000002`3AcJT2000000040?ooo`000000000000000080oooo0`000000103oool00000
0000000000020?ooo`<0000000<0oooo0000000000000`3oool300000080oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00<000000`3oool20000
00040?ooo`000000000000000080oooo0`000000103oool000000000000000020?ooo`<0000000<0
oooo0000000000003P3AcJT000`0dLfY0P0000000`3oool0000000000008000000@0oooo1@000003
0?ooo`L000000`3oool2000000H0oooo1`0000000`3oool00000000000020?ooo`P000000P3oool0
0`000000oooo0?ooo`03000000@0oooo0`00000;0=7=Z@<000000P3oool2000000040?ooo`000000
0000000000D0oooo1`0000050?ooo`D000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo100000050?ooo`L000001@3oool300000080oooo00<000000?ooo`3oool00`00
000;0=7=Z@80000000@0oooo000000000000oooo0P0000000`3oool0000000000005000000<0oooo
2@0000050?ooo`D000001P3oool2000000030?ooo`000000000000@0oooo0P0000030?ooo`D00000
1@3oool400000080oooo00<000000?ooo`3oool02`3AcJT5000000<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`P0000000@0oooo000000000000oooo0`0000020?ooo`<0
00000P3oool00`000000oooo0?ooo`0>000000<0oooo0`0000030?ooo`<000000P3oool3000000/0
dLfY0P000000103oool000000000000000020?ooo`<0000000@0oooo00000000000000000P3oool3
000000030?ooo`000000000000<0oooo0`0000020?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`03000000<0oooo0P000000103oool000000000
000000020?ooo`<0000000@0oooo00000000000000000P3oool3000000030?ooo`000000000000h0
dLfY000<0=7=Z@80000000<0oooo000000000000200000040?ooo`D000000`3oool7000000<0oooo
0P0000060?ooo`L0000000<0oooo0000000000000P3oool800000080oooo00<000000?ooo`3oool0
0`0000040?ooo`<000002`3AcJT300000080oooo0P000000103oool000000000000000050?ooo`L0
00001@3oool5000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`@0
00001@3oool7000000D0oooo0`0000020?ooo`030000003oool0oooo00<000002`3AcJT200000004
0?ooo`00000000000?ooo`80000000<0oooo0000000000001@0000030?ooo`T000001@3oool50000
00H0oooo0P0000000`3oool00000000000040?ooo`8000000`3oool5000000D0oooo100000020?oo
o`030000003oool0oooo00/0dLfY1@0000000`3oool00000000000040?ooo`D000000`3oool@0000
00030?ooo`000000000000D0000000<0oooo000000000000103oool2000000H0oooo0`0000020?oo
o`80000000<0oooo0000000000002@3oool;0=7=Z@<0oooo0`0000020?ooo`<0000000@0oooo0000
0000000000000P3oool3000000@0oooo1@0000020?ooo`<0000000@0oooo00000000000000000P3o
ool3000000040?ooo`000000000000000080oooo1@0000040?ooo`<000000P3oool3000000040?oo
o`000000000000000080oooo0`0000030?ooo`h0dLfY000<0=7=Z@80oooo2`0000040?ooo`030000
003oool0oooo0080oooo0`0000070?ooo`<000002P3oool300000080oooo1@0000000`3oool00000
00000007000000030?ooo`000000000000X000002`3AcJT70?ooo`030000003oool0oooo00H0oooo
100000000`3oool000000000000300000080oooo1@0000000`3oool00000000000060?ooo`800000
0P3oool400000080oooo1@0000020?ooo`<00000203oool2000000H0oooo2`3AcJT20?ooo`030000
003oool0oooo00<0000000<0oooo0000000000000P3oool400000080oooo1P0000020?ooo`040000
003oool0oooo0?ooo`8000002`3oool2000000<0oooo00<000000?ooo`3oool01P0000020?ooo`@0
00000P3oool2000000040?ooo`000000000000000080oooo00<000000?ooo`3oool02`3AcJT20?oo
o`040000003oool0oooo00000080oooo0`0000000`3oool00000000000060?ooo`X0000000<0oooo
000000000000103oool7000000<0oooo00<000000?ooo`3oool01@0000030?ooo`030000003oool0
oooo00D000001`3oool2000000<0oooo2`3AcJT60?ooo`8000000`3oool010000000oooo0?ooo`3o
ool2000000L0oooo10000000103oool000000000003oool5000000040?ooo`00000000000?ooo`D0
000000@0oooo000000000000oooo100000070?ooo`8000000`3oool010000000oooo0?ooo`3oool2
000000H0oooo3P3AcJT000`0dLfY300000050?ooo`X000000`3oool?000000D0oooo1@0000030?oo
o`L0000000<0oooo0000000000000`0000040?ooo`030000003oool0oooo00/0dLfY1`3oool00`00
0000oooo0?ooo`060?ooo`@0000000<0oooo0000000000000`0000020?ooo`D0000000<0oooo0000
000000001P3oool200000080oooo100000020?ooo`D000000P3oool3000000P0oooo0P0000060?oo
o`/0dLfY0P3oool00`000000oooo0?ooo`03000000030?ooo`00000000000080oooo100000020?oo
o`H000000P3oool010000000oooo0?ooo`3oool2000000/0oooo0P0000030?ooo`030000003oool0
oooo00H000000P3oool400000080oooo0P000000103oool000000000000000020?ooo`030000003o
ool0oooo00/0dLfY0P3oool010000000oooo0?ooo`0000020?ooo`<0000000<0oooo000000000000
1P3oool:000000030?ooo`000000000000@0oooo1`0000030?ooo`030000003oool0oooo00D00000
0`3oool00`000000oooo0?ooo`05000000L0oooo0P0000030?ooo`/0dLfY1P3oool2000000<0oooo
00@000000?ooo`3oool0oooo0P0000070?ooo`@0000000@0oooo000000000000oooo1@000000103o
ool000000000003oool5000000040?ooo`00000000000?ooo`@000001`3oool2000000<0oooo00@0
00000?ooo`3oool0oooo0P0000060?ooo`h0dLfY000<0=7=Z@`000001@3oool:000000<0oooo3`00
00050?ooo`D000000`3oool7000000030?ooo`000000000000<00000103oool00`000000oooo0?oo
o`0;0=7=Z@<0oooo10000000103oool000000000003oool4000000T0oooo100000000`3oool00000
000000020?ooo`030000003oool0oooo00H000000P3oool2000000040?ooo`00000000000?ooo`@0
00002@3oool4000000030?ooo`00000000000080oooo0`0000030?ooo`/0dLfY0P0000030?ooo`03
0000003oool0oooo00<000000`3oool5000000030?ooo`0000000000008000000`3oool00`000000
oooo0?ooo`030?ooo`8000000`3oool400000080oooo0P000000103oool000000000003oool50000
0080oooo00@000000?ooo`3oool0oooo1@0000060?ooo`<000000P3oool;0=7=Z@<000001@3oool8
000000030?ooo`000000000000<0oooo1P0000030?ooo`<000001@3oool3000000<0oooo0P000000
0`3oool0000000000005000000h0oooo0`0000040?ooo`8000002`3AcJT300000080oooo00<00000
0?ooo`3oool00`000000103oool000000000000000020?ooo`030000003oool0oooo00<00000803o
ool300000080oooo00<000000?ooo`3oool00`000000103oool000000000000000020?ooo`030000
003oool0oooo00<000003P3AcJT000`0dLfY2P0000020?ooo`<000001`3oool5000000<0oooo1@00
00080?ooo`<000001@3oool2000000<0oooo0P0000020?ooo`<000000P3oool00`000000oooo0?oo
o`02000000030?ooo`000000000000D000002`3AcJT2000000030?ooo`0000000000008000000`3o
ool5000000D0oooo00@000000?ooo`3oool000000P3oool2000000030?ooo`000000000000D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`80000000<0oooo000000000000
0P3oool00`000000oooo0?ooo`02000000@0oooo1@0000040?ooo`<0000000<0oooo000000000000
2`3AcJT20?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`03000000D0oooo00@000000?ooo`3oool000000P3oool3000000D0oooo00<000000?oo
o`3oool01P0000030?ooo`<00000103oool010000000oooo0?ooo`0000020?ooo`H000000P3oool3
000000<0oooo2`3AcJT2000000L0oooo0P0000000`3oool0000000000003000000<0oooo0P000000
0`3oool0000000000002000000030?ooo`000000000000<0oooo00<000000?ooo`3oool00`000003
0?ooo`800000103oool5000000<0oooo0P0000000`3oool00000000000050?ooo`030000003oool0
oooo00<000001P3oool;0=7=Z@D000000`3oool3000000040?ooo`0000000000000000<0oooo1@00
00050?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3oool000001@3oool010000000
oooo0?ooo`0000050?ooo`D000000`3oool3000000040?ooo`0000000000000000<0oooo1@00000>
0=7=Z@00303AcJT:00000080oooo0`0000070?ooo`D000000`3oool5000000P0oooo0`0000050?oo
o`8000000`3oool200000080oooo0`0000020?ooo`030000003oool0oooo0080000000<0oooo0000
000000001@00000;0=7=Z@80000000<0oooo0000000000000P0000030?ooo`D000001@3oool01000
0000oooo0?ooo`0000020?ooo`80000000<0oooo0000000000001@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo0P0000000`3oool00000000000020?ooo`030000003oool0
oooo00800000103oool5000000@0oooo0`0000000`3oool000000000000;0=7=Z@80oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<000001@3o
ool010000000oooo0?ooo`0000020?ooo`<000001@3oool00`000000oooo0?ooo`06000000<0oooo
0`0000040?ooo`040000003oool0oooo00000080oooo1P0000020?ooo`<000000`3oool;0=7=Z@80
00001`3oool2000000030?ooo`000000000000<000000`3oool2000000030?ooo`00000000000080
000000<0oooo0000000000000`3oool00`000000oooo0?ooo`03000000<0oooo0P0000040?ooo`D0
00000`3oool2000000030?ooo`000000000000D0oooo00<000000?ooo`3oool00`0000060?ooo`/0
dLfY1@0000030?ooo`<0000000@0oooo00000000000000000`3oool5000000D0oooo00@000000?oo
o`3oool000001@3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000D0oooo
1@0000030?ooo`<0000000@0oooo00000000000000000`3oool5000000h0dLfY000<0=7=Z@80oooo
1P0000040?ooo`<000001@3oool2000000030?ooo`000000000000L0oooo00<000000?ooo`3oool0
0P0000050?ooo`040000003oool0oooo00000080oooo1`00000=0?ooo`80000000<0oooo00000000
00000P3oool3000000/0dLfY0P3oool00`000000oooo0?ooo`030?ooo`D000000`3oool2000000<0
oooo0P0000030?ooo`D000001@3oool6000000D0oooo1@0000030?ooo`8000000`3oool2000000<0
oooo1@0000050?ooo`030000003oool0oooo00/0dLfY0P0000000`3oool0000000000006000000/0
oooo0P0000000`3oool000000000000900000080oooo00<000000?ooo`3oool00`3oool5000000@0
oooo0P0000020?ooo`<00000103oool200000080oooo100000020?ooo`<000002`3AcJT;000000<0
oooo1@00000<0?ooo`/00000203oool00`000000oooo0?ooo`02000000<0oooo00@000000?ooo`3o
ool0oooo0P0000030?ooo`800000103oool300000080oooo2`3AcJT20?ooo`@000001@3oool00`00
0000oooo0?ooo`030?ooo`@000000`3oool2000000<0oooo0P0000030?ooo`040000003oool0oooo
0?ooo`8000000`3oool010000000oooo0?ooo`3oool2000000<0oooo0P0000030?ooo`@000001@3o
ool00`000000oooo0?ooo`030?ooo`@000000P3oool>0=7=Z@00303AcJT2000000030?ooo`000000
00000080000000<0oooo0000000000001`3oool00`000000oooo0?ooo`030?ooo`X000001@3oool2
000000D0oooo1@0000000`3oool0000000000002000000<0oooo0P0000030?ooo`8000000`3oool5
000000D0oooo2`3AcJT2000000030?ooo`000000000000<0oooo0`0000020?ooo`8000001@3oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo00P0oooo0P0000080?ooo`030000003o
ool0oooo00800000103oool200000080oooo0`0000030?ooo`80000000<0oooo0000000000002`3A
cJT30?ooo`<000000P3oool3000000<0oooo0P0000030?ooo`030000003oool0oooo00<0oooo0`00
00020?ooo`<000000P3oool4000000<0oooo0P0000020?ooo`<000000`3oool00`000000oooo0?oo
o`02000000030?ooo`000000000000H00000203oool3000000/0dLfY303oool200000080oooo0`00
00030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0`0000020?ooo`<00000
0P3oool:000000D0oooo0P0000000`3oool00000000000050?ooo`040000003oool0oooo000000<0
oooo0`0000020?ooo`/0dLfY0P000000103oool000000000000000030?ooo`80000000<0oooo0000
000000000`3oool3000000030?ooo`000000000000D0oooo00@000000?ooo`3oool000001@3oool0
10000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000D0oooo0P000000103oool00000
0000000000030?ooo`80000000<0oooo0000000000000`3oool3000000030?ooo`000000000000h0
dLfY000<0=7=Z@80000000<0oooo0000000000000P0000000`3oool00000000000070?ooo`030000
003oool0oooo00<0oooo2P0000050?ooo`8000001@3oool5000000030?ooo`000000000000800000
0`3oool2000000<0oooo0P0000030?ooo`D000001@3oool;0=7=Z@80000000<0oooo000000000000
0`3oool300000080oooo0P0000050?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool0203oool2000000P0oooo00<000000?ooo`3oool00P0000040?ooo`8000000P3oool3000000<0
oooo0P0000000`3oool000000000000;0=7=Z@<0oooo0`0000020?ooo`<000000`3oool2000000<0
oooo00<000000?ooo`3oool00`3oool300000080oooo0`0000020?ooo`@000000`3oool200000080
oooo0`0000030?ooo`030000003oool0oooo0080000000<0oooo0000000000001P0000080?ooo`<0
00002`3AcJT<0?ooo`8000000P3oool3000000<0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`3oool300000080oooo0`0000020?ooo`X000001@3oool2000000030?ooo`0000000000
00D0oooo00@000000?ooo`3oool000000`3oool300000080oooo2`3AcJT2000000040?ooo`000000
0000000000<0oooo0P0000000`3oool00000000000030?ooo`<0000000<0oooo0000000000001@3o
ool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3o
ool000001@3oool2000000040?ooo`0000000000000000<0oooo0P0000000`3oool0000000000003
0?ooo`<0000000<0oooo0000000000003P3AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfY
c03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfY
c03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT000`0dLfY100000020?ooo`03
0000003oool0oooo00H000000P3oool2000000<0oooo0P0000020?ooo`8000000P3oool300000080
oooo0P0000040?ooo`8000000P3oool300000080oooo0P0000020?ooo`8000000`3oool200000080
oooo1P0000020?ooo`030000003oool0oooo00@000002`3AcJT4000000030?ooo`00000000000080
oooo100000030?ooo`8000000P3oool5000000H0oooo0`0000040?ooo`800000103oool3000000H0
oooo1@0000020?ooo`8000000`3oool400000080oooo0P0000000`3oool0000000000002000000/0
dLfY2@3oool2000000030?ooo`00000000000080oooo0P0000070?ooo`030000003oool0oooo00@0
00000`3oool7000000@0oooo0`0000020?ooo`8000001`3oool00`000000oooo0?ooo`0200000080
oooo00<000000?ooo`3oool01`3oool;0=7=Z@80000000<0oooo0000000000000P0000030?ooo`H0
00000`3oool9000000030?ooo`000000000000D000001P3oool7000000030?ooo`000000000000L0
00000`3oool6000000<0oooo100000000`3oool000000000000;0=7=Z@<000000P3oool200000003
0?ooo`000000000000@0000000<0oooo0000000000000`3oool200000080oooo1@0000020?ooo`03
0000003oool0oooo00<0oooo100000050?ooo`030000003oool0oooo00D000000P3oool2000000<0
oooo0P0000000`3oool0000000000004000000030?ooo`00000000000080oooo0`00000>0=7=Z@00
303AcJT400000080oooo00<000000?ooo`3oool01P0000020?ooo`8000000`3oool200000080oooo
0P0000020?ooo`<000000P3oool2000000@0oooo0P0000020?ooo`<000000P3oool200000080oooo
0P0000030?ooo`8000000P3oool600000080oooo00<000000?ooo`3oool01000000;0=7=Z@@00000
00<0oooo0000000000000P3oool4000000<0oooo0P0000020?ooo`D000001P3oool3000000@0oooo
0P0000040?ooo`<000001P3oool500000080oooo0P0000030?ooo`@000000P3oool2000000030?oo
o`0000000000008000002`3AcJT90?ooo`80000000<0oooo0000000000000P3oool2000000L0oooo
00<000000?ooo`3oool0100000030?ooo`L00000103oool300000080oooo0P0000070?ooo`030000
003oool0oooo008000000P3oool00`000000oooo0?ooo`070?ooo`/0dLfY0P0000000`3oool00000
00000002000000<0oooo1P0000030?ooo`T0000000<0oooo0000000000001@0000060?ooo`L00000
00<0oooo0000000000001`0000030?ooo`H000000`3oool4000000030?ooo`000000000000/0dLfY
0`0000020?ooo`80000000<0oooo000000000000100000000`3oool00000000000030?ooo`800000
0P3oool500000080oooo00<000000?ooo`3oool00`3oool4000000D0oooo00<000000?ooo`3oool0
1@0000020?ooo`8000000`3oool2000000030?ooo`000000000000@0000000<0oooo000000000000
0P3oool3000000h0dLfY000<0=7=Z@H0000000<0oooo0000000000000P0000020?ooo`@000001`3o
ool200000080oooo1`0000080?ooo`L000000P3oool2000000L0oooo100000020?ooo`@0000000<0
oooo0000000000001000000;0=7=Z@D000000P3oool6000000D0oooo100000020?ooo`030000003o
ool0oooo008000000P3oool3000000X0oooo0`0000020?ooo`8000000P3oool00`000000oooo0?oo
o`04000000D0oooo1P0000020?ooo`D000002`3AcJT7000000@0oooo00<000000?ooo`3oool00P00
00030?ooo`@000000`3oool6000000<0oooo0P0000030?ooo`800000103oool5000000<0oooo1000
00030?ooo`8000000P3oool2000000<0oooo1`00000;0=7=Z@80oooo1@0000030?ooo`8000000P3o
ool2000000<0oooo0P0000050?ooo`D00000103oool00`000000oooo0?ooo`0200000080oooo00<0
00000?ooo`3oool00P3oool5000000D0oooo0P0000030?ooo`8000000P3oool2000000<0oooo1@00
00020?ooo`/0dLfY1@0000020?ooo`<000000P3oool3000000L0oooo0`0000020?ooo`@000000`3o
ool2000000030?ooo`00000000000080000000<0oooo0000000000000`3oool400000080oooo0`00
00070?ooo`<000000P3oool300000080oooo1@00000>0=7=Z@00303AcJT6000000030?ooo`000000
0000008000000P3oool4000000L0oooo0P0000020?ooo`L00000203oool700000080oooo0P000007
0?ooo`@000000P3oool4000000030?ooo`000000000000@000002`3AcJT500000080oooo1P000005
0?ooo`@000000P3oool00`000000oooo0?ooo`0200000080oooo0`00000:0?ooo`<000000P3oool2
00000080oooo00<000000?ooo`3oool0100000050?ooo`H000000P3oool5000000/0dLfY1`000004
0?ooo`030000003oool0oooo008000000`3oool4000000<0oooo1P0000030?ooo`8000000`3oool2
000000@0oooo1@0000030?ooo`@000000`3oool200000080oooo0P0000030?ooo`L000002`3AcJT5
000000D0oooo0P0000020?ooo`8000000`3oool4000000030?ooo`000000000000D0oooo1`000002
0?ooo`L000001@3oool2000000030?ooo`0000000000008000000`3oool200000080oooo0P000005
0?ooo`D000002`3AcJT20?ooo`<000000P3oool00`000000oooo0?ooo`040?ooo`X000001@3oool3
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`<000001@3oool:
000000H0oooo00<000000?ooo`3oool00`0000020?ooo`h0dLfY000<0=7=Z@80oooo100000000`3o
ool00000000000060?ooo`T00000103ooolF000000@0oooo2@0000060?ooo`80000000<0oooo0000
000000000P0000020?ooo`/0dLfY0P3oool300000080oooo100000040?ooo`D00000103oool30000
0080oooo0P0000050?ooo`8000000P3oool2000000D0oooo0P0000020?ooo`<00000103oool60000
00<0oooo100000020?ooo`<000000P3oool;0=7=Z@8000000`3oool200000080oooo0P0000050?oo
o`80000000<0oooo0000000000000P0000020?ooo`D000001@3oool7000000D0oooo1P0000000`3o
ool000000000000200000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020000
00<0oooo0P00000;0=7=Z@D000001@3oool200000080oooo0P0000030?ooo`@0000000<0oooo0000
000000001@3oool700000080oooo1`0000050?ooo`80000000<0oooo0000000000000P0000030?oo
o`8000000P3oool2000000D0oooo1@00000;0=7=Z@80oooo0`0000020?ooo`030000003oool0oooo
00@0oooo2P0000050?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo0`0000050?ooo`X000001P3oool00`000000oooo0?ooo`0300000080oooo3P3AcJT000`0
dLfY0P3oool4000000030?ooo`000000000000H0oooo2@0000040?oooaH00000103oool9000000H0
oooo0P0000000`3oool000000000000200000080oooo2`3AcJT2000000<0oooo0P0000040?ooo`80
00000P3oool00`000000oooo0?ooo`020?ooo`8000000`3oool2000000@0oooo0P0000050?ooo`80
00001@3oool2000000@0oooo0P0000030?ooo`800000103oool2000000030?ooo`000000000000@0
oooo0P0000030?ooo`8000002`3AcJT900000080oooo1@0000020?ooo`030000003oool0oooo0080
oooo1@0000020?ooo`<000002`3oool300000080oooo1@0000040?ooo`80000000<0oooo00000000
0000100000000`3oool0000000000007000000/0dLfY0`0000020?ooo`@0000000<0oooo00000000
0000100000050?ooo`<000000P3oool2000000030?ooo`0000000000008000000P3oool300000080
oooo0`0000020?ooo`@0000000<0oooo0000000000000P3oool3000000D0oooo1P0000000`3oool0
00000000000200000080oooo0`00000;0=7=Z@8000000`3oool9000000X0oooo1@0000020?ooo`03
0000003oool0oooo0080000000<0oooo0000000000000P0000000`3oool00000000000020?ooo`03
0000003oool0oooo00D000002P3oool9000000<0oooo0P00000>0=7=Z@00303AcJT2000000@0oooo
2@0000070?ooo`@00000103oool5000000P0oooo1@0000040?ooo`@000001`3oool9000000@0oooo
0P00000;0=7=Z@8000000`3oool2000000@0oooo0P0000020?ooo`030000003oool0oooo0080oooo
0P0000030?ooo`800000103oool2000000D0oooo0P0000050?ooo`800000103oool2000000<0oooo
0P0000040?ooo`80000000<0oooo000000000000103oool2000000<0oooo0P00000;0=7=Z@T00000
0P3oool500000080oooo00<000000?ooo`3oool00P3oool500000080oooo0`00000;0?ooo`<00000
0P3oool5000000@0oooo0P0000000`3oool0000000000004000000030?ooo`000000000000L00000
2`3AcJT300000080oooo100000000`3oool0000000000004000000D0oooo0`0000020?ooo`800000
00<0oooo0000000000000P0000020?ooo`<000000P3oool300000080oooo100000000`3oool00000
000000020?ooo`<000001@3oool6000000030?ooo`0000000000008000000P3oool3000000/0dLfY
0P0000030?ooo`T000002P3oool500000080oooo00<000000?ooo`3oool00P0000000`3oool00000
00000002000000030?ooo`00000000000080oooo00<000000?ooo`3oool01@00000:0?ooo`T00000
0`3oool2000000h0dLfY000<0=7=Z@80oooo1`0000040?ooo`@000000`3oool200000080oooo0P00
00020?ooo`8000000P3oool00`000000oooo0?ooo`02000000@0oooo0P0000020?ooo`030000003o
ool0oooo008000000P3oool200000080oooo0P0000030?ooo`@00000103oool700000080oooo2`3A
cJT20?ooo`<000000P3oool400000080oooo1`0000040?ooo`<000000P3oool2000000<0oooo1000
00020?ooo`@000000`3oool200000080oooo0`0000040?ooo`L000000P3oool400000080oooo0`00
00020?ooo`/0dLfY1@3oool400000080oooo00<000000?ooo`3oool00P0000030?ooo`L00000103o
ool3000000/0oooo0`0000040?ooo`L000000`3oool200000080oooo0P0000000`3oool000000000
0002000000D0oooo2`3AcJT50?ooo`D000001`3oool400000080oooo00<000000?ooo`3oool00P3o
ool3000000L0oooo0P0000070?ooo`<00000103oool00`000000oooo0?ooo`04000000L0oooo1@00
00050?ooo`/0dLfY0P3oool6000000@0oooo0`0000070?ooo`<000000P3oool200000080oooo0`00
00030?ooo`@000000`3oool300000080oooo0P0000020?ooo`<000001`3oool3000000@0oooo1P00
00020?ooo`h0dLfY000<0=7=Z@80oooo1`0000040?ooo`@000000`3oool200000080oooo0P000002
0?ooo`8000000P3oool00`000000oooo0?ooo`02000000@0oooo0P0000020?ooo`030000003oool0
oooo008000000P3oool200000080oooo0P0000030?ooo`@00000103oool700000080oooo2`3AcJT2
0?ooo`<000000P3oool400000080oooo1`0000040?ooo`<000000P3oool2000000<0oooo10000002
0?ooo`@000000`3oool200000080oooo0`0000040?ooo`L000000P3oool400000080oooo0`000002
0?ooo`/0dLfY1@3oool400000080oooo00<000000?ooo`3oool00P0000030?ooo`L00000103oool3
000000/0oooo0`0000040?ooo`L000000`3oool200000080oooo0P0000000`3oool0000000000002
000000D0oooo2`3AcJT50?ooo`D000001`3oool400000080oooo00<000000?ooo`3oool00P3oool3
000000L0oooo0P0000070?ooo`<00000103oool00`000000oooo0?ooo`04000000L0oooo1@000005
0?ooo`/0dLfY0`0000020?ooo`80000000<0oooo0000000000000P0000020?ooo`030000003oool0
oooo00<000000P3oool2000000<0oooo100000000`3oool0000000000002000000H0oooo10000000
0`3oool0000000000002000000<0oooo0P0000020?ooo`<000000P3oool00`000000oooo0?ooo`04
000000030?ooo`00000000000080oooo0`00000>0=7=Z@00303AcJT400000080oooo00<000000?oo
o`3oool0100000020?ooo`8000001`3oool4000000@0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`020?ooo`@000001`3oool200000080oooo100000020?ooo`030000003oool0oooo
00@000002`3AcJT500000080oooo100000020?ooo`<000000P3oool400000080oooo00<000000?oo
o`3oool00P0000020?ooo`80000000<0oooo0000000000000P0000020?ooo`@0000000<0oooo0000
000000000P3oool200000080oooo00<000000?ooo`3oool0100000020?ooo`<000000P3oool40000
0080oooo1@00000;0=7=Z@@0oooo00<000000?ooo`3oool00P3oool300000080oooo0P0000020?oo
o`<000000P3oool2000000030?ooo`000000000000L0oooo1`0000070?ooo`8000000P3oool00`00
0000oooo0?ooo`04000000030?ooo`00000000000080oooo0`0000040?ooo`8000000`3oool;0=7=
Z@L0oooo1@0000050?ooo`@000000P3oool00`000000oooo0?ooo`0300000080oooo100000000`3o
ool00000000000020?ooo`80000000<0oooo0000000000000P0000020?ooo`<000000P3oool00`00
0000oooo0?ooo`04000000D0oooo1@0000070?ooo`/0dLfY0`0000020?ooo`80000000<0oooo0000
000000000P0000020?ooo`030000003oool0oooo00<000000P3oool2000000<0oooo100000000`3o
ool0000000000002000000H0oooo100000000`3oool0000000000002000000<0oooo0P0000020?oo
o`<000000P3oool00`000000oooo0?ooo`04000000030?ooo`00000000000080oooo0`00000>0=7=
Z@00303AcJT400000080oooo00<000000?ooo`3oool0100000020?ooo`8000001`3oool4000000@0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`@000001`3oool200000080
oooo100000020?ooo`030000003oool0oooo00@000002`3AcJT500000080oooo100000020?ooo`<0
00000P3oool400000080oooo00<000000?ooo`3oool00P0000020?ooo`80000000<0oooo00000000
00000P0000020?ooo`@0000000<0oooo0000000000000P3oool200000080oooo00<000000?ooo`3o
ool0100000020?ooo`<000000P3oool400000080oooo1@00000;0=7=Z@@0oooo00<000000?ooo`3o
ool00P3oool300000080oooo0P0000020?ooo`<000000P3oool2000000030?ooo`000000000000L0
oooo1`0000070?ooo`8000000P3oool00`000000oooo0?ooo`04000000030?ooo`00000000000080
oooo0`0000040?ooo`8000000`3oool;0=7=Z@L000000P3oool300000080oooo0P0000050?ooo`L0
00000`3oool5000000H0oooo1@0000030?ooo`L000001@3oool200000080oooo0`0000020?ooo`L0
00002`3AcJT2000000<0oooo0P0000000`3oool000000000000200000080oooo2`0000040?ooo`80
00000`3oool2000000H0oooo0P0000030?ooo`800000103oool;00000080oooo100000000`3oool0
0000000000030?ooo`8000003P3AcJT000`0dLfY0P0000040?ooo`030000003oool0oooo00@00000
0P3oool200000080oooo00<000000?ooo`3oool0103oool400000080oooo00<000000?ooo`3oool0
0P3oool4000000@0oooo00<000000?ooo`3oool0100000060?ooo`030000003oool0oooo00800000
0P3oool400000080oooo00<000000?ooo`3oool00P3oool2000000/0dLfY100000000`3oool00000
000000040?ooo`8000001`3oool5000000P0oooo00<000000?ooo`3oool00P3oool2000000@0oooo
00<000000?ooo`3oool01P3oool5000000L0oooo0P0000040?ooo`80000000<0oooo000000000000
0P00000;0=7=Z@8000000`3oool6000000030?ooo`000000000000D00000103oool2000000X0oooo
0P0000030?ooo`8000002`3oool00`000000oooo0?ooo`020?ooo`L000000P3oool5000000<0oooo
0P00000;0=7=Z@L000000P3oool300000080oooo0P0000050?ooo`L000000`3oool5000000H0oooo
1@0000030?ooo`L000001@3oool200000080oooo0`0000020?ooo`L000002`3AcJT2000000<0oooo
0P0000000`3oool000000000000200000080oooo2`0000040?ooo`8000000`3oool2000000H0oooo
0P0000030?ooo`800000103oool;00000080oooo100000000`3oool00000000000030?ooo`800000
3P3AcJT000`0dLfY0P0000040?ooo`030000003oool0oooo00@000000P3oool200000080oooo00<0
00000?ooo`3oool0103oool400000080oooo00<000000?ooo`3oool00P3oool4000000@0oooo00<0
00000?ooo`3oool0100000060?ooo`030000003oool0oooo008000000P3oool400000080oooo00<0
00000?ooo`3oool00P3oool2000000/0dLfY100000000`3oool00000000000040?ooo`8000001`3o
ool5000000P0oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`3oool01P3o
ool5000000L0oooo0P0000040?ooo`80000000<0oooo0000000000000P00000;0=7=Z@@0oooo0`00
00050?ooo`@000000`3oool200000080oooo0P0000030?ooo`D000000P3oool700000080oooo1@00
00040?ooo`030000003oool0oooo008000000`3oool4000000D0oooo100000030?ooo`/0dLfY0P00
00030?ooo`8000001@3oool2000000D0oooo1@0000040?ooo`030000003oool0oooo0080oooo3000
00040?ooo`030000003oool0oooo0080oooo1@0000050?ooo`8000001@3oool2000000<0oooo0P00
000;0=7=Z@<000000P3oool3000000@0oooo0P0000030?ooo`<000000P3oool300000080oooo1000
00000`3oool0000000000002000000030?ooo`00000000000080000000<0oooo0000000000000P00
00000`3oool000000000000200000080oooo0`0000020?ooo`<000000`3oool2000000@0oooo0`00
00020?ooo`<000003P3AcJT000`0dLfY100000020?ooo`<00000103oool6000000<0oooo10000002
0?ooo`D00000103oool4000000@0oooo1@0000020?ooo`@000000`3oool6000000@0oooo0`000002
0?ooo`@000002`3AcJT70?ooo`@000000P3oool2000000030?ooo`0000000000008000002@3oool4
000000030?ooo`0000000000008000000P3oool4000000030?ooo`0000000000008000002@3oool4
00000080oooo00<000000?ooo`3oool0100000070?ooo`/0dLfY103oool3000000D0oooo10000003
0?ooo`8000000P3oool2000000<0oooo1@0000020?ooo`L000000P3oool5000000@0oooo00<00000
0?ooo`3oool00P0000030?ooo`@000001@3oool4000000<0oooo2`3AcJT2000000<0oooo0P000005
0?ooo`8000001@3oool5000000@0oooo00<000000?ooo`3oool00P3oool<000000@0oooo00<00000
0?ooo`3oool00P3oool5000000D0oooo0P0000050?ooo`8000000`3oool2000000/0dLfY0`000002
0?ooo`<00000103oool2000000<0oooo0`0000020?ooo`<000000P3oool4000000030?ooo`000000
00000080000000<0oooo0000000000000P0000000`3oool0000000000002000000030?ooo`000000
0000008000000P3oool300000080oooo0`0000030?ooo`800000103oool300000080oooo0`00000>
0=7=Z@00303AcJT400000080oooo0`0000040?ooo`H000000`3oool400000080oooo1@0000040?oo
o`@00000103oool500000080oooo100000030?ooo`H00000103oool300000080oooo1000000;0=7=
Z@L0oooo100000020?ooo`80000000<0oooo0000000000000P0000090?ooo`@0000000<0oooo0000
000000000P0000020?ooo`@0000000<0oooo0000000000000P0000090?ooo`@000000P3oool00`00
0000oooo0?ooo`04000000L0oooo2`3AcJT40?ooo`030000003oool0oooo008000001`3oool30000
0080oooo100000030?ooo`8000000P3oool3000000L0oooo100000000`3oool00000000000040?oo
o`<000000P3oool3000000L0oooo0P0000020?ooo`8000000`3oool;0=7=Z@L000000`3oool20000
0080oooo0`0000020?ooo`@0000000<0oooo0000000000000P0000030?ooo`8000000P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo008000000`3oool4000000030?ooo`0000000000
008000000P3oool300000080oooo0P0000030?ooo`L000002`3AcJT20?ooo`<000000P3oool50000
0080oooo0`0000080?ooo`@000000P3oool300000080oooo1P0000020?ooo`<000000P3oool40000
00P0oooo0`0000020?ooo`D000000P3oool300000080oooo3P3AcJT000`0dLfY0P3oool400000003
0?ooo`000000000000/000000P3oool4000001X0oooo100000020?ooo`d0000000<0oooo00000000
00000P0000020?ooo`/0dLfY103oool7000000@0oooo1`0000030?ooo`8000000P3oool400000003
0?ooo`0000000000008000000P3oool4000000030?ooo`0000000000008000000P3oool2000000<0
oooo200000030?ooo`L00000103oool;0=7=Z@@0oooo00<000000?ooo`3oool00P0000070?ooo`<0
00000P3oool4000000<0oooo0P0000020?ooo`<000001`3oool4000000030?ooo`000000000000@0
oooo0`0000020?ooo`<000001`3oool200000080oooo0P0000030?ooo`/0dLfY1`0000030?ooo`80
00000P3oool300000080oooo100000000`3oool0000000000002000000<0oooo0P0000020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P0000030?ooo`@0000000<0oooo00000000
00000P0000020?ooo`<000000P3oool2000000<0oooo1`00000;0=7=Z@80000000<0oooo00000000
00001@3oool200000080oooo1@0000000`3oool00000000000020?ooo`<00000103oool00`000000
oooo0?ooo`020?ooo`H00000103oool00`000000oooo0?ooo`020?ooo`<000000P3oool200000003
0?ooo`000000000000<000000P3oool2000000D0oooo0P0000000`3oool000000000000>0=7=Z@00
303AcJT20?ooo`@0000000<0oooo0000000000002`0000020?ooo`@000006P3oool400000080oooo
3@0000000`3oool000000000000200000080oooo2`3AcJT200000080oooo00<000000?ooo`3oool0
0P0000040?ooo`T000001@3oool2000000@0oooo00<000000?ooo`3oool00P3oool2000000@0oooo
00<000000?ooo`3oool00P3oool2000000D0oooo2@0000040?ooo`8000000P3oool00`000000oooo
0?ooo`02000000/0dLfY0P0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@0000020?ooo`8000001@3oool2000000<0oooo100000030?ooo`@000000`3oool2000000D0oooo
0P0000020?ooo`D000000P3oool2000000D0oooo0P0000000`3oool000000000000;0=7=Z@h0oooo
1@0000050?ooo`D000001P3oool300000080oooo0`0000060?ooo`D000001@3oool5000000h0oooo
2`3AcJT2000000030?ooo`000000000000D0oooo0P0000020?ooo`D0000000<0oooo000000000000
0P3oool3000000@0oooo00<000000?ooo`3oool00P3oool6000000@0oooo00<000000?ooo`3oool0
0P3oool300000080oooo0P0000000`3oool000000000000300000080oooo0P0000050?ooo`800000
00<0oooo0000000000003P3AcJT000`0dLfY0P0000020?ooo`8000001`3oool9000000/0oooo1000
00040?ooo`@000002`3oool9000000L0oooo0P0000020?ooo`8000002`3AcJT200000080oooo00<0
00000?ooo`3oool00P0000040?ooo`T000001@3oool2000000@0oooo00<000000?ooo`3oool00P3o
ool2000000@0oooo00<000000?ooo`3oool00P3oool2000000D0oooo2@0000040?ooo`8000000P3o
ool00`000000oooo0?ooo`02000000/0dLfY0P0000020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@0000020?ooo`8000001@3oool2000000<0oooo100000030?ooo`@000000`3o
ool2000000D0oooo0P0000020?ooo`D000000P3oool2000000D0oooo0P0000000`3oool000000000
000;0=7=Z@L0oooo0`0000060?ooo`D000001@3oool3000000L0oooo1P0000070?ooo`<000001@3o
ool5000000H0oooo0`0000070?ooo`/0dLfY0`3oool2000000<0oooo1P0000000`3oool000000000
000300000080oooo0`0000020?ooo`8000000P3oool3000000<0oooo100000030?ooo`<000000P3o
ool200000080oooo0`0000020?ooo`D0000000<0oooo000000000000100000030?ooo`8000000`3o
ool>0=7=Z@00303AcJT200000080oooo0P0000070?ooo`T000002`3oool4000000@0oooo1000000;
0?ooo`T000001`3oool200000080oooo0P00000;0=7=Z@80oooo0`0000020?ooo`@000000P3oool7
000000@0oooo0`0000020?ooo`@0000000<0oooo0000000000000P0000020?ooo`@0000000<0oooo
0000000000000P0000020?ooo`<00000103oool700000080oooo100000020?ooo`<000000P3oool;
0=7=Z@80oooo0`0000070?ooo`H0000000<0oooo0000000000001@0000020?ooo`8000000P3oool0
0`000000oooo0?ooo`02000000<0oooo0P0000020?ooo`80000000<0oooo0000000000000P3oool7
00000080oooo1@0000070?ooo`<000000P3oool;0=7=Z@L0oooo0`0000060?ooo`D000001@3oool3
000000L0oooo1P0000070?ooo`<000001@3oool5000000H0oooo0`0000070?ooo`/0dLfY0`3oool2
000000<0oooo1P0000000`3oool000000000000300000080oooo0`0000020?ooo`8000000P3oool3
000000<0oooo100000030?ooo`<000000P3oool200000080oooo0`0000020?ooo`D0000000<0oooo
000000000000100000030?ooo`8000000`3oool>0=7=Z@00303AcJT40?ooo`8000001@3oool20000
0080oooo2@0000020?ooo`H0000000<0oooo0000000000000P0000040?ooo`@0000000<0oooo0000
00000000100000020?ooo`T000000P3oool2000000D0oooo0P0000040?ooo`/0dLfY0P3oool30000
0080oooo100000020?ooo`L00000103oool300000080oooo100000000`3oool00000000000020000
0080oooo100000000`3oool000000000000200000080oooo0`0000040?ooo`L000000P3oool40000
0080oooo0`0000020?ooo`/0dLfY0P3oool3000000L0oooo1P0000000`3oool00000000000050000
0080oooo0P0000020?ooo`030000003oool0oooo008000000`3oool200000080oooo0P0000000`3o
ool00000000000020?ooo`L000000P3oool5000000L0oooo0`0000020?ooo`/0dLfY1@0000020?oo
o`<000000P3oool4000000030?ooo`0000000000008000000P3oool3000000D0oooo1@0000060?oo
o`D000001@3oool300000080oooo100000000`3oool000000000000200000080oooo0`0000020?oo
o`D000002`3AcJT30?ooo`8000000`3oool6000000<0oooo0`0000020?ooo`8000001@3oool20000
00030?ooo`00000000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020000
00030?ooo`000000000000D0oooo0P0000020?ooo`<000000`3oool6000000<0oooo0P0000030?oo
o`h0dLfY000<0=7=Z@@0oooo0P0000000`3oool00000000000080?ooo`/000000P3oool3000000`0
oooo0`0000020?ooo`/00000203oool2000000030?ooo`000000000000@0oooo2`3AcJT400000003
0?ooo`00000000000080oooo100000020?ooo`<000000P3oool200000080oooo0`0000020?ooo`@0
000000<0oooo0000000000000P0000020?ooo`@0000000<0oooo0000000000000P0000020?ooo`<0
00000P3oool200000080oooo100000000`3oool000000000000200000080oooo0P0000000`3oool0
000000000002000000/0dLfY100000030?ooo`T000000`3oool400000080oooo1`0000030?ooo`80
00000`3oool2000000@0oooo1`0000000`3oool0000000000002000000<0oooo2@0000040?ooo`<0
00002`3AcJT500000080oooo0`0000020?ooo`@0000000<0oooo0000000000000P0000020?ooo`<0
00001@3oool5000000H0oooo1@0000050?ooo`<000000P3oool4000000030?ooo`00000000000080
00000P3oool300000080oooo1@00000;0=7=Z@80000000<0oooo0000000000001@3oool2000000<0
oooo0P0000030?ooo`T000000`3oool4000000030?ooo`00000000000080000000<0oooo00000000
00000P0000030?ooo`T000000`3oool2000000<0oooo0P0000050?ooo`80000000<0oooo00000000
00003P3AcJT000`0dLfY103oool2000000030?ooo`000000000000P0oooo2`0000020?ooo`<00000
303oool300000080oooo2`0000080?ooo`80000000<0oooo000000000000103oool;0=7=Z@@00000
00<0oooo0000000000000P3oool400000080oooo0`0000020?ooo`8000000P3oool300000080oooo
100000000`3oool000000000000200000080oooo100000000`3oool000000000000200000080oooo
0`0000020?ooo`8000000P3oool4000000030?ooo`0000000000008000000P3oool2000000030?oo
o`0000000000008000002`3AcJT200000080oooo00<000000?ooo`3oool00P0000030?ooo`800000
0P3oool2000000X0oooo1@0000020?ooo`8000000`3oool200000080oooo1@00000;0?ooo`030000
003oool0oooo008000000`3oool200000080oooo0P0000000`3oool000000000000;0=7=Z@800000
00<0oooo0000000000000P0000030?ooo`H000001@3oool7000000<0oooo0P0000020?ooo`<00000
0P3oool300000080oooo0P0000030?ooo`L000001@3oool6000000<0oooo100000000`3oool00000
0000000;0=7=Z@80000000<0oooo0000000000001@3oool2000000<0oooo0P0000030?ooo`T00000
0`3oool4000000030?ooo`00000000000080000000<0oooo0000000000000P0000030?ooo`T00000
0`3oool2000000<0oooo0P0000050?ooo`80000000<0oooo0000000000003P3AcJT000`0dLfY0P00
00020?ooo`<000001P3oool400000080oooo1@0000080?ooo`<000000P3oool400000080oooo0`00
00080?ooo`D000000P3oool4000000H0oooo0`0000020?ooo`8000002`3AcJT2000000T0oooo0P00
00090?ooo`8000000`3oool2000000@0oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<0
00000?ooo`3oool00P3oool2000000<0oooo0P0000090?ooo`8000002@3oool2000000/0dLfY0P00
00020?ooo`030000003oool0oooo008000000`3oool200000080oooo0P00000:0?ooo`D000000P3o
ool2000000<0oooo0P0000020?ooo`D000002`3oool00`000000oooo0?ooo`02000000<0oooo0P00
00020?ooo`80000000<0oooo0000000000002`3AcJT2000000030?ooo`0000000000008000000`3o
ool6000000D0oooo1`0000030?ooo`8000000P3oool300000080oooo0`0000020?ooo`8000000`3o
ool7000000D0oooo1P0000030?ooo`@0000000<0oooo0000000000002`3AcJT20?ooo`<000000P3o
ool7000000<0oooo1`0000030?ooo`@000000`3oool2000000030?ooo`00000000000080000000<0
oooo0000000000000`3oool4000000<0oooo1`0000030?ooo`L000000P3oool300000080oooo3P3A
cJT000`0dLfY0P0000020?ooo`<000001P3oool400000080oooo1@0000080?ooo`<000000P3oool4
00000080oooo0`0000080?ooo`D000000P3oool4000000H0oooo0`0000020?ooo`8000002`3AcJT2
000000T0oooo0P0000090?ooo`8000000`3oool2000000@0oooo00<000000?ooo`3oool00P3oool2
000000@0oooo00<000000?ooo`3oool00P3oool2000000<0oooo0P0000090?ooo`8000002@3oool2
000000/0dLfY0P0000030?ooo`T000002@3oool2000000030?ooo`00000000000080oooo1`000003
0?ooo`L000000P3oool200000080oooo00<000000?ooo`3oool01`3oool9000000<0oooo0P00000;
0=7=Z@8000000`3oool9000000D0oooo2@0000030?ooo`8000000`3oool6000000<0oooo0P000003
0?ooo`T000001@3oool9000000<0oooo0P00000;0=7=Z@80oooo0`0000020?ooo`L000000`3oool7
000000<0oooo100000030?ooo`80000000<0oooo0000000000000P0000000`3oool0000000000003
0?ooo`@000000`3oool7000000<0oooo1`0000020?ooo`<000000P3oool>0=7=Z@00303AcJT20?oo
o`8000000P3oool500000080oooo100000030?ooo`8000000P3oool200000080oooo100000000`3o
ool000000000000:000000030?ooo`0000000000008000000P3oool200000080oooo0P0000030?oo
o`@000000P3oool500000080oooo0P0000020?ooo`/0dLfY1@0000020?ooo`H000001@3oool40000
0080oooo0`0000020?ooo`@0000000<0oooo0000000000000P0000020?ooo`@0000000<0oooo0000
000000000P0000020?ooo`<000000P3oool4000000D0oooo1P0000020?ooo`D000002`3AcJT20000
00<0oooo2@0000090?ooo`80000000<0oooo0000000000000P3oool7000000<0oooo1`0000020?oo
o`8000000P3oool00`000000oooo0?ooo`070?ooo`T000000`3oool2000000/0dLfY0P0000000`3o
ool00000000000050?ooo`8000000P3oool300000080oooo1`0000050?ooo`8000000P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo008000001@3oool700000080oooo0`0000020?oo
o`8000001@3oool2000000030?ooo`000000000000/0dLfY0`0000020?ooo`<000000P3oool40000
00030?ooo`00000000000080000000<0oooo0000000000000P3oool300000080oooo0P0000000`3o
ool0000000000003000000@0oooo1@0000000`3oool00000000000020?ooo`<000000P3oool20000
00030?ooo`00000000000080000000<0oooo0000000000000P0000020?ooo`<000000P3oool30000
00h0dLfY000<0=7=Z@80oooo0P0000020?ooo`D000000P3oool4000000<0oooo0P0000020?ooo`80
00000P3oool4000000030?ooo`000000000000X0000000<0oooo0000000000000P0000020?ooo`80
00000P3oool2000000<0oooo100000020?ooo`D000000P3oool200000080oooo2`3AcJT40?ooo`D0
00001P3oool00`000000oooo0?ooo`0400000080oooo0`0000020?ooo`@0000000<0oooo00000000
00000P0000020?ooo`@0000000<0oooo0000000000000P0000020?ooo`<000000P3oool400000080
oooo0P0000050?ooo`D00000103oool;0=7=Z@8000000P3oool5000000T0oooo0`0000040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool2000000D0oooo0P0000030?ooo`@0
0000203oool6000000030?ooo`000000000000/0dLfY0P0000000`3oool00000000000050?ooo`80
00000P3oool300000080oooo1`0000050?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo008000001@3oool700000080oooo0`0000020?ooo`8000001@3oool200000003
0?ooo`000000000000/0dLfY0P0000030?ooo`8000001`3oool3000000<0oooo0P0000020?ooo`<0
00000P3ooolD00000080oooo0`0000020?ooo`8000000`3oool3000000L0oooo0P0000030?ooo`80
00003P3AcJT000`0dLfY0P0000070?ooo`@000001P3oool3000000@0oooo1P0000050?ooo`@00000
1@3oool6000000@0oooo0`0000060?ooo`@000001`3oool2000000/0dLfY103oool5000000H0oooo
00<000000?ooo`3oool0100000020?ooo`<000000P3oool4000000030?ooo`000000000000800000
0P3oool4000000030?ooo`0000000000008000000P3oool300000080oooo100000020?ooo`800000
1@3oool5000000@0oooo2`3AcJT200000080oooo1@0000090?ooo`<00000103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00T0oooo0P0000050?ooo`8000000`3oool4000000P0oooo
1P0000000`3oool000000000000;0=7=Z@<000000P3oool200000080oooo0`0000020?ooo`D00000
0P3oool300000080oooo0`0000020?ooo`@0000000<0oooo0000000000000P3oool2000000030?oo
o`0000000000008000000P3oool300000080oooo0`0000020?ooo`D000000P3oool300000080oooo
0P0000020?ooo`<000002`3AcJT2000000<0oooo0P0000070?ooo`<000000`3oool200000080oooo
0`0000020?oooa@000000P3oool300000080oooo0P0000030?ooo`<000001`3oool2000000<0oooo
0P00000>0=7=Z@00303AcJT2000000L0oooo100000060?ooo`<00000103oool6000000D0oooo1000
00050?ooo`H00000103oool3000000H0oooo100000070?ooo`8000002`3AcJT20?ooo`8000001@3o
ool2000000D0oooo0P0000040?ooo`8000000`3oool2000000@0oooo00<000000?ooo`3oool00P3o
ool2000000@0oooo00<000000?ooo`3oool00P3oool2000000<0oooo0P0000040?ooo`8000001@3o
ool2000000D0oooo0P0000020?ooo`/0dLfY1`0000020?ooo`8000000`3oool200000080oooo0`00
00020?ooo`80000000<0oooo0000000000001`0000020?ooo`<000000P3oool900000080oooo00<0
00000?ooo`3oool0100000000`3oool00000000000040?ooo`030000003oool0oooo00L000002`3A
cJT300000080oooo0P0000020?ooo`<000000P3oool500000080oooo0`0000020?ooo`<000000P3o
ool4000000030?ooo`00000000000080oooo0P0000000`3oool000000000000200000080oooo0`00
00020?ooo`<000000P3oool500000080oooo0`0000020?ooo`8000000P3oool3000000/0dLfY0`00
00020?ooo`D000000P3oool300000080oooo0P0000000`3oool0000000000002000000<0oooo0P00
00030?ooo`D00000103oool5000000<0oooo0P0000030?ooo`@0000000<0oooo0000000000000P3o
ool300000080oooo1@0000020?ooo`<000003P3AcJT000`0dLfY0P3oool4000000030?ooo`000000
00000080oooo100000040?ooo`030000003oool0oooo0080oooo1P0000050?ooo`800000103oool2
000000D0oooo1P0000040?ooo`030000003oool0oooo0080oooo100000020?ooo`80000000<0oooo
0000000000000P0000020?ooo`/0dLfY0P3oool2000000D0oooo0P0000050?ooo`800000103oool2
000000<0oooo0P0000040?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0
oooo0080oooo0P0000030?ooo`800000103oool2000000D0oooo0P0000050?ooo`8000000P3oool;
0=7=Z@@0oooo00<000000?ooo`3oool02@3oool2000000<0oooo0P0000030?ooo`800000103oool>
000000<0oooo0P0000030?ooo`800000103oool00`000000oooo0?ooo`090?ooo`8000000`3oool;
0=7=Z@80oooo00<000000?ooo`3oool00P3oool300000080oooo0P0000020?ooo`<000001`3oool5
00000080oooo0P0000030?ooo`8000000`3oool200000080oooo1@0000070?ooo`<000000P3oool2
00000080oooo0`0000040?ooo`030000003oool0oooo00/0dLfY0`0000020?ooo`D000000P3oool3
00000080oooo0P0000000`3oool0000000000002000000<0oooo0P0000030?ooo`D00000103oool5
000000<0oooo0P0000030?ooo`@0000000<0oooo0000000000000P3oool300000080oooo1@000002
0?ooo`<000003P3AcJT000`0dLfY0P3oool4000000030?ooo`00000000000080oooo100000040?oo
o`030000003oool0oooo0080oooo1P0000050?ooo`800000103oool2000000D0oooo1P0000040?oo
o`030000003oool0oooo0080oooo100000020?ooo`80000000<0oooo0000000000000P0000020?oo
o`/0dLfY103oool00`000000oooo0?ooo`02000000@0oooo0`0000020?ooo`@000000P3oool30000
0080oooo100000000`3oool000000000000200000080oooo100000000`3oool00000000000020000
0080oooo0`0000020?ooo`@000000P3oool3000000@0oooo0P0000020?ooo`030000003oool0oooo
0080oooo2`3AcJT40?ooo`030000003oool0oooo00T0oooo0P0000030?ooo`8000000`3oool20000
00@0oooo3P0000030?ooo`8000000`3oool2000000@0oooo00<000000?ooo`3oool02@3oool20000
00<0oooo2`3AcJT300000080oooo1000000C0?ooo`<000000P3oool2000000030?ooo`0000000000
0080oooo0P0000000`3oool00000000000020?ooo`<000004`3oool400000080oooo0`00000;0=7=
Z@80oooo0`0000030?ooo`H000001@3oool00`000000oooo0?ooo`0500000080oooo0`0000020?oo
o`80000000<0oooo0000000000000P0000000`3oool00000000000020?ooo`<000000P3oool50000
0080oooo00<000000?ooo`3oool00`3oool6000000<0oooo0`0000020?ooo`h0dLfY000<0=7=Z@L0
00001P3oool2000000@0oooo0`0000020?ooo`@000000P3oool3000000@0oooo100000040?ooo`<0
00000P3oool400000080oooo0`0000040?ooo`8000001P3oool7000000/0dLfY103oool00`000000
oooo0?ooo`02000000@0oooo0`0000020?ooo`@000000P3oool300000080oooo100000000`3oool0
00000000000200000080oooo100000000`3oool000000000000200000080oooo0`0000020?ooo`@0
00000P3oool3000000@0oooo0P0000020?ooo`030000003oool0oooo0080oooo2`3AcJT20?ooo`L0
00000P3oool500000080oooo0`0000020?ooo`80000000<0oooo000000000000100000000`3oool0
0000000000020?ooo`<000000P3oool200000080oooo1@0000020?ooo`030000003oool0oooo00@0
000000<0oooo000000000000100000000`3oool000000000000500000080oooo2`3AcJT300000080
oooo1000000C0?ooo`<000000P3oool2000000030?ooo`00000000000080oooo0P0000000`3oool0
0000000000020?ooo`<000004`3oool400000080oooo0`00000;0=7=Z@80oooo0`0000030?ooo`H0
00001@3oool00`000000oooo0?ooo`0500000080oooo0`0000020?ooo`80000000<0oooo00000000
00000P0000000`3oool00000000000020?ooo`<000000P3oool500000080oooo00<000000?ooo`3o
ool00`3oool6000000<0oooo0`0000020?ooo`h0dLfY000<0=7=Z@L000001P3oool2000000@0oooo
0`0000020?ooo`@000000P3oool3000000@0oooo100000040?ooo`<000000P3oool400000080oooo
0`0000040?ooo`8000001P3oool7000000/0dLfY100000000`3oool00000000000020?ooo`800000
0P3oool300000080oooo100000020?ooo`<000000P3oool4000000030?ooo`000000000000800000
0P3oool4000000030?ooo`0000000000008000000P3oool300000080oooo100000020?ooo`<00000
0P3oool200000080oooo0P0000000`3oool0000000000002000000/0dLfY0P3oool700000080oooo
1@0000020?ooo`<000000P3oool2000000030?ooo`000000000000@0000000<0oooo000000000000
0P3oool300000080oooo0P0000020?ooo`D000000P3oool00`000000oooo0?ooo`04000000030?oo
o`000000000000@0000000<0oooo0000000000001@0000020?ooo`/0dLfY0P0000000`3oool00000
0000000200000080oooo0`0000020?ooo`8000000`3oool9000000<0oooo1@0000060?ooo`D00000
0`3oool9000000<0oooo0P0000020?ooo`<000000P3oool4000000030?ooo`000000000000/0dLfY
0P0000000`3oool0000000000003000000H0oooo1@0000060?ooo`8000000P3oool300000080oooo
0P0000000`3oool0000000000002000000030?ooo`00000000000080oooo0`0000020?ooo`800000
1P3oool5000000H0oooo1@0000000`3oool000000000000>0=7=Z@00303AcJT?000000D0oooo1000
00060?ooo`<000000P3oool800000080oooo0`0000060?ooo`@000001@3oool?000000/0dLfY1000
00000`3oool00000000000020?ooo`8000000P3oool300000080oooo100000020?ooo`<000000P3o
ool4000000030?ooo`0000000000008000000P3oool4000000030?ooo`0000000000008000000P3o
ool300000080oooo100000020?ooo`<000000P3oool200000080oooo0P0000000`3oool000000000
0002000000/0dLfY0P3oool300000080oooo1@0000020?ooo`8000000P3oool3000000@0oooo00<0
00000?ooo`3oool00P3oool2000000030?ooo`000000000000L0oooo0P0000020?ooo`030000003o
ool0oooo0080oooo0P0000030?ooo`@0000000<0oooo0000000000000P3oool500000080oooo0`00
00020?ooo`/0dLfY0P0000000`3oool000000000000200000080oooo0`0000020?ooo`8000000`3o
ool9000000<0oooo1@0000060?ooo`D000000`3oool9000000<0oooo0P0000020?ooo`<000000P3o
ool4000000030?ooo`000000000000/0dLfY1`3oool300000080oooo0`0000020?ooo`D000000P3o
ool5000000<0oooo1@0000040?ooo`D000000`3oool500000080oooo1@0000020?ooo`<000000P3o
ool3000000L0oooo3P3AcJT000`0dLfY0P3oool5000000X0oooo0`0000020?ooo`@000001`3oool<
000000L0oooo100000020?ooo`<000002P3oool500000080oooo2`3AcJT4000000L0oooo0P000003
0?ooo`800000103oool2000000<0oooo0P0000040?ooo`030000003oool0oooo0080oooo0P000004
0?ooo`030000003oool0oooo0080oooo0P0000030?ooo`800000103oool2000000<0oooo0P000007
0?ooo`@000002`3AcJT20?ooo`<000000P3oool500000080oooo0P0000020?ooo`<00000103oool0
0`000000oooo0?ooo`020?ooo`80000000<0oooo0000000000001`3oool200000080oooo00<00000
0?ooo`3oool00P3oool2000000<0oooo100000000`3oool00000000000020?ooo`D000000P3oool3
00000080oooo2`3AcJT2000000030?ooo`000000000000@0oooo1@0000050?ooo`8000001@3ooolJ
000000D0oooo0P0000050?ooo`D00000103oool2000000030?ooo`000000000000/0dLfY1`3oool3
00000080oooo0`0000020?ooo`D000000P3oool5000000<0oooo1@0000040?ooo`D000000`3oool5
00000080oooo1@0000020?ooo`<000000P3oool3000000L0oooo3P3AcJT000`0dLfY0P3oool50000
00X0oooo0`0000020?ooo`@000001`3oool<000000L0oooo100000020?ooo`<000002P3oool50000
0080oooo2`3AcJT70?ooo`@000000P3oool300000080oooo100000020?ooo`<000000P3oool40000
00030?ooo`0000000000008000000P3oool4000000030?ooo`0000000000008000000P3oool30000
0080oooo100000020?ooo`<000000P3oool4000000L0oooo2`3AcJT>0?ooo`@000001@3oool20000
00030?ooo`000000000000L000001`3oool900000080oooo00<000000?ooo`3oool0103oool30000
00h0oooo2`3AcJT2000000030?ooo`000000000000@0oooo1@0000050?ooo`8000001@3ooolJ0000
00D0oooo0P0000050?ooo`D00000103oool2000000030?ooo`000000000000/0dLfY0P3oool00`00
0000oooo0?ooo`02000000030?ooo`000000000000@000001P3ooolV000000H0oooo1P0000000`3o
ool00000000000020?ooo`030000003oool0oooo00h0dLfY000<0=7=Z@8000000P3oool200000003
0?ooo`000000000000P0oooo0`0000040?ooo`8000000P3oool200000080oooo3P0000020?ooo`80
00000P3oool2000000@0oooo0`0000080?ooo`80000000<0oooo0000000000000P3oool2000000/0
dLfY1`3oool400000080oooo0`0000020?ooo`@000000P3oool300000080oooo100000000`3oool0
00000000000200000080oooo100000000`3oool000000000000200000080oooo0`0000020?ooo`@0
00000P3oool300000080oooo100000070?ooo`/0dLfY0P0000030?ooo`8000002@3oool3000000L0
oooo0P0000020?ooo`8000001@3oool3000000H0oooo00<000000?ooo`3oool00P0000070?ooo`<0
00002@3oool2000000<0oooo0P00000;0=7=Z@L000000`3oool700000080oooo100000000`3oool0
0000000000050?ooo`D000001P3oool5000000D0oooo0P0000000`3oool000000000000200000080
oooo1`0000030?ooo`L000002`3AcJT20?ooo`030000003oool0oooo0080000000<0oooo00000000
0000100000060?ooobH000001P3oool6000000030?ooo`00000000000080oooo00<000000?ooo`3o
ool03P3AcJT000`0dLfY0P0000020?ooo`80000000<0oooo000000000000203oool3000000@0oooo
0P0000020?ooo`8000000P3oool>00000080oooo0P0000020?ooo`800000103oool3000000P0oooo
0P0000000`3oool00000000000020?ooo`8000002`3AcJT40?ooo`030000003oool0oooo00@00000
0P3oool300000080oooo100000020?ooo`<000000P3oool4000000030?ooo`000000000000800000
0P3oool4000000030?ooo`0000000000008000000P3oool300000080oooo100000020?ooo`<00000
0P3oool400000080oooo00<000000?ooo`3oool00P3oool;0=7=Z@8000000`3oool2000000T0oooo
0`0000070?ooo`8000000P3oool2000000D0oooo0`0000060?ooo`030000003oool0oooo00800000
1`3oool3000000T0oooo0P0000030?ooo`8000002`3AcJT30?ooo`@000000P3oool00`000000oooo
0?ooo`0200000080oooo0`0000020?ooo`<000000P3oool2000000030?ooo`00000000000080oooo
0P0000000`3oool00000000000020?ooo`80000000<0oooo0000000000000P3oool2000000030?oo
o`00000000000080oooo0`0000020?ooo`<000000P3oool200000080oooo00<000000?ooo`3oool0
100000030?ooo`/0dLfY0`3oool2000000T0oooo0`0000020?ooo`030000003oool0oooo0080oooo
1@0000030?ooo`D00000103oool5000000<0oooo1@0000040?ooo`030000003oool0oooo00<00000
2@3oool2000000<0oooo3P3AcJT000`0dLfY103oool2000000D0oooo100000070?ooo`H000000P3o
oolB00000080oooo1P0000070?ooo`@000001@3oool2000000@0oooo2`3AcJT40?ooo`030000003o
ool0oooo00@000000P3oool300000080oooo100000020?ooo`<000000P3oool4000000030?ooo`00
00000000008000000P3oool4000000030?ooo`0000000000008000000P3oool300000080oooo1000
00020?ooo`<000000P3oool400000080oooo00<000000?ooo`3oool00P3oool;0=7=Z@T0oooo1`00
00020?ooo`030000003oool0oooo008000000`3oool200000080oooo0`0000040?ooo`<00000103o
ool300000080oooo0P0000030?ooo`8000000P3oool2000000030?ooo`000000000000D000002@3o
ool;0=7=Z@<0oooo100000020?ooo`030000003oool0oooo008000000P3oool300000080oooo0`00
00020?ooo`80000000<0oooo0000000000000P3oool2000000030?ooo`00000000000080oooo0P00
00000`3oool00000000000020?ooo`80000000<0oooo0000000000000P3oool300000080oooo0`00
00020?ooo`8000000P3oool00`000000oooo0?ooo`04000000<0oooo2`3AcJT300000080oooo0`00
00040?ooo`L0000000<0oooo0000000000000P0000000`3oool00000000000020?ooo`<000000P3o
ool2000000030?ooo`00000000000080000000<0oooo0000000000000P3oool300000080oooo0P00
00000`3oool0000000000002000000030?ooo`000000000000D00000103oool300000080oooo0`00
000>0=7=Z@00303AcJT40?ooo`8000001@3oool4000000L0oooo1P0000020?oooa8000000P3oool6
000000L0oooo100000050?ooo`800000103oool;0=7=Z@8000000`3oool2000000@0oooo0P000003
0?ooo`800000103oool2000000<0oooo0P0000040?ooo`030000003oool0oooo0080oooo0P000004
0?ooo`030000003oool0oooo0080oooo0P0000030?ooo`800000103oool2000000<0oooo0P000004
0?ooo`8000000`3oool2000000/0dLfY2@3oool700000080oooo00<000000?ooo`3oool00P000003
0?ooo`8000000P3oool3000000@0oooo0`0000040?ooo`<000000P3oool2000000<0oooo0P000002
0?ooo`80000000<0oooo0000000000001@0000090?ooo`/0dLfY0P3oool00`000000oooo0?ooo`02
0?ooo`8000000`3oool2000000<0oooo0P0000040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool2000000<0oooo0P0000030?ooo`800000103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo0P0000030?ooo`8000000`3oool2000000@0oooo00<00000
0?ooo`3oool02`3AcJT300000080oooo0`0000040?ooo`L0000000<0oooo0000000000000P000000
0`3oool00000000000020?ooo`<000000P3oool2000000030?ooo`00000000000080000000<0oooo
0000000000000P3oool300000080oooo0P0000000`3oool0000000000002000000030?ooo`000000
000000D00000103oool300000080oooo0`00000>0=7=Z@00303AcJT40?ooo`8000001@3oool40000
00L0oooo1P0000020?oooa8000000P3oool6000000L0oooo100000050?ooo`800000103oool;0=7=
Z@8000000`3oool2000000@0oooo0P0000030?ooo`800000103oool2000000<0oooo0P0000040?oo
o`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo0080oooo0P0000030?oo
o`800000103oool2000000<0oooo0P0000040?ooo`8000000`3oool2000000/0dLfY0P3oool30000
00@0oooo0P0000030?ooo`8000000P3oool3000000D0oooo100000020?ooo`030000003oool0oooo
00T0oooo0P0000000`3oool0000000000002000000D0oooo100000000`3oool00000000000040?oo
o`030000003oool0oooo0080oooo0`0000020?ooo`/0dLfY0P3oool00`000000oooo0?ooo`020?oo
o`8000000`3oool2000000<0oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool2000000<0oooo0P0000030?ooo`800000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo0P0000030?ooo`8000000`3oool2000000@0oooo00<000000?oo
o`3oool02`3AcJT300000080oooo0`0000040?ooo`L0000000<0oooo0000000000000P0000000`3o
ool00000000000020?ooo`<000000P3oool2000000030?ooo`00000000000080000000<0oooo0000
000000000P3oool300000080oooo0P0000000`3oool0000000000002000000030?ooo`0000000000
00D00000103oool300000080oooo0`00000>0=7=Z@00303AcJT40?ooo`8000001@3oool4000000L0
oooo1P0000020?oooa8000000P3oool6000000L0oooo100000050?ooo`800000103oool;0=7=Z@@0
oooo00<000000?ooo`3oool0100000020?ooo`<000000P3oool400000080oooo0`0000020?ooo`@0
000000<0oooo0000000000000P0000020?ooo`@0000000<0oooo0000000000000P0000020?ooo`<0
00000P3oool400000080oooo0`0000020?ooo`@000000P3oool00`000000oooo0?ooo`020?ooo`/0
dLfY0P3oool3000000@0oooo0P0000030?ooo`8000000P3oool3000000D0oooo100000020?ooo`03
0000003oool0oooo00T0oooo0P0000000`3oool0000000000002000000D0oooo100000000`3oool0
0000000000040?ooo`030000003oool0oooo0080oooo0`0000020?ooo`/0dLfY0`3oool400000080
oooo00<000000?ooo`3oool00P0000020?ooo`<000000P3oool300000080oooo0P0000000`3oool0
0000000000020?ooo`80000000<0oooo0000000000000P3oool2000000030?ooo`00000000000080
oooo0P0000000`3oool00000000000020?ooo`<000000P3oool300000080oooo0P0000020?ooo`03
0000003oool0oooo00@000000`3oool;0=7=Z@<000000P3oool3000000@0oooo1`0000000`3oool0
000000000002000000030?ooo`00000000000080oooo0`0000020?ooo`80000000<0oooo00000000
00000P0000000`3oool00000000000020?ooo`<000000P3oool2000000030?ooo`00000000000080
000000<0oooo0000000000001@0000040?ooo`<000000P3oool3000000h0dLfY000<0=7=Z@800000
0P3oool2000000030?ooo`000000000000P0oooo0`0000040?ooo`8000000P3oool200000080oooo
3P0000020?ooo`8000000P3oool2000000@0oooo0`0000080?ooo`80000000<0oooo000000000000
0P3oool2000000/0dLfY103oool00`000000oooo0?ooo`0400000080oooo0`0000020?ooo`@00000
0P3oool300000080oooo100000000`3oool000000000000200000080oooo100000000`3oool00000
0000000200000080oooo0`0000020?ooo`@000000P3oool300000080oooo100000020?ooo`030000
003oool0oooo0080oooo2`3AcJT20?ooo`<00000103oool9000000030?ooo`000000000000@00000
0`3oool200000080oooo00<000000?ooo`3oool00P0000030?ooo`8000000P3oool2000000030?oo
o`000000000000@0oooo1@0000020?ooo`P00000103oool300000080oooo2`3AcJT30?ooo`@00000
0P3oool00`000000oooo0?ooo`0200000080oooo0`0000020?ooo`<000000P3oool2000000030?oo
o`00000000000080oooo0P0000000`3oool00000000000020?ooo`80000000<0oooo000000000000
0P3oool2000000030?ooo`00000000000080oooo0`0000020?ooo`<000000P3oool200000080oooo
00<000000?ooo`3oool0100000030?ooo`/0dLfY0`3oool2000000T0oooo0`0000020?ooo`030000
003oool0oooo0080oooo1@0000030?ooo`D00000103oool5000000<0oooo1@0000040?ooo`030000
003oool0oooo00<000002@3oool2000000<0oooo3P3AcJT000`0dLfY0P0000020?ooo`80000000<0
oooo000000000000203oool3000000@0oooo0P0000020?ooo`8000000P3oool>00000080oooo0P00
00020?ooo`800000103oool3000000P0oooo0P0000000`3oool00000000000020?ooo`8000002`3A
cJT70?ooo`@000000P3oool300000080oooo100000020?ooo`<000000P3oool4000000030?ooo`00
00000000008000000P3oool4000000030?ooo`0000000000008000000P3oool300000080oooo1000
00020?ooo`<000000P3oool4000000L0oooo2`3AcJT20?ooo`<00000103oool9000000030?ooo`00
0000000000@000000`3oool200000080oooo00<000000?ooo`3oool00P0000030?ooo`8000000P3o
ool2000000030?ooo`000000000000@0oooo1@0000020?ooo`P00000103oool300000080oooo2`3A
cJT7000000<0oooo1`0000020?ooo`@0000000<0oooo0000000000001@3oool5000000H0oooo1@00
00050?ooo`80000000<0oooo0000000000000P0000020?ooo`L000000`3oool7000000/0dLfY0P3o
ool00`000000oooo0?ooo`02000000030?ooo`000000000000@000001P3ooolV000000H0oooo1P00
00000`3oool00000000000020?ooo`030000003oool0oooo00h0dLfY000<0=7=Z@80oooo1@00000:
0?ooo`<000000P3oool4000000L0oooo300000070?ooo`@000000P3oool3000000X0oooo1@000002
0?ooo`/0dLfY1`3oool400000080oooo0`0000020?ooo`@000000P3oool300000080oooo10000000
0`3oool000000000000200000080oooo100000000`3oool000000000000200000080oooo0`000002
0?ooo`@000000P3oool300000080oooo100000070?ooo`/0dLfY3P3oool4000000D0oooo0P000000
0`3oool0000000000007000000L0oooo2@0000020?ooo`030000003oool0oooo00@0oooo0`00000>
0?ooo`/0dLfY0P0000000`3oool00000000000040?ooo`D000001@3oool2000000D0oooo6P000005
0?ooo`8000001@3oool5000000@0oooo0P0000000`3oool000000000000;0=7=Z@80oooo00<00000
0?ooo`3oool00P0000000`3oool0000000000004000000H0oooo9P0000060?ooo`H0000000<0oooo
0000000000000P3oool00`000000oooo0?ooo`0>0=7=Z@00303AcJT20?ooo`D000002P3oool30000
0080oooo100000070?ooo``000001`3oool400000080oooo0`00000:0?ooo`D000000P3oool;0=7=
Z@@000001`3oool2000000<0oooo0P0000040?ooo`8000000`3oool2000000@0oooo00<000000?oo
o`3oool00P3oool2000000@0oooo00<000000?ooo`3oool00P3oool2000000<0oooo0P0000040?oo
o`8000000`3oool2000000L0oooo1000000;0=7=Z@8000000`3oool4000000<0oooo0P0000070?oo
o`T000000P3oool>000000030?ooo`000000000000L000001`3oool2000000<0oooo100000030?oo
o`8000002`3AcJT2000000030?ooo`000000000000@0oooo1@0000050?ooo`8000001@3ooolJ0000
00D0oooo0P0000050?ooo`D00000103oool2000000030?ooo`000000000000/0dLfY1`3oool30000
0080oooo0`0000020?ooo`D000000P3oool5000000<0oooo1@0000040?ooo`D000000`3oool50000
0080oooo1@0000020?ooo`<000000P3oool3000000L0oooo3P3AcJT000`0dLfY3`0000050?ooo`@0
00001P3oool300000080oooo200000020?ooo`<000001P3oool4000000D0oooo3`00000;0=7=Z@@0
000000<0oooo0000000000000P3oool200000080oooo0`0000020?ooo`@000000P3oool300000080
oooo100000000`3oool000000000000200000080oooo100000000`3oool000000000000200000080
oooo0`0000020?ooo`@000000P3oool300000080oooo0P0000020?ooo`80000000<0oooo00000000
00000P00000;0=7=Z@8000000`3oool4000000<0oooo0P0000070?ooo`T000000P3oool>00000003
0?ooo`000000000000L000001`3oool2000000<0oooo100000030?ooo`8000002`3AcJT200000003
0?ooo`0000000000008000000P3oool300000080oooo0P0000030?ooo`T000000`3oool5000000H0
oooo1@0000030?ooo`T000000`3oool200000080oooo0`0000020?ooo`@0000000<0oooo00000000
00002`3AcJT70?ooo`<000000P3oool300000080oooo1@0000020?ooo`D000000`3oool5000000@0
oooo1@0000030?ooo`D000000P3oool500000080oooo0`0000020?ooo`<000001`3oool>0=7=Z@00
303AcJT7000000H0oooo0P0000040?ooo`<000000P3oool400000080oooo0`0000040?ooo`@00000
103oool300000080oooo100000020?ooo`<00000103oool2000000H0oooo1`00000;0=7=Z@@00000
00<0oooo0000000000000P3oool200000080oooo0`0000020?ooo`@000000P3oool300000080oooo
100000000`3oool000000000000200000080oooo100000000`3oool000000000000200000080oooo
0`0000020?ooo`@000000P3oool300000080oooo0P0000020?ooo`80000000<0oooo000000000000
0P00000;0=7=Z@D0oooo100000050?ooo`8000000P3oool00`000000oooo0?ooo`04000000030?oo
o`000000000000D0oooo0P0000070?ooo`8000001@3oool200000080oooo0`0000020?ooo`800000
00<0oooo0000000000001@3oool4000000D0oooo2`3AcJT2000000030?ooo`000000000000800000
0P3oool300000080oooo0P0000030?ooo`T000000`3oool5000000H0oooo1@0000030?ooo`T00000
0`3oool200000080oooo0`0000020?ooo`@0000000<0oooo0000000000002`3AcJT2000000030?oo
o`000000000000<000001P3oool5000000H0oooo0P0000020?ooo`<000000P3oool2000000030?oo
o`00000000000080000000<0oooo0000000000000P3oool300000080oooo0P0000060?ooo`D00000
1P3oool5000000030?ooo`000000000000h0dLfY000<0=7=Z@L000001P3oool2000000@0oooo0`00
00020?ooo`@000000P3oool3000000@0oooo100000040?ooo`<000000P3oool400000080oooo0`00
00040?ooo`8000001P3oool7000000/0dLfY103oool00`000000oooo0?ooo`02000000@0oooo0`00
00020?ooo`@000000P3oool300000080oooo100000000`3oool000000000000200000080oooo1000
00000`3oool000000000000200000080oooo0`0000020?ooo`@000000P3oool3000000@0oooo0P00
00020?ooo`030000003oool0oooo0080oooo2`3AcJT50?ooo`@000001@3oool200000080oooo00<0
00000?ooo`3oool0100000000`3oool00000000000050?ooo`8000001`3oool2000000D0oooo0P00
00020?ooo`<000000P3oool2000000030?ooo`000000000000D0oooo100000050?ooo`/0dLfY0`00
00020?ooo`@000004`3oool300000080oooo0P0000000`3oool00000000000020?ooo`80000000<0
oooo0000000000000P3oool3000001<0oooo100000020?ooo`<000002`3AcJT20?ooo`<000000`3o
ool6000000D0oooo00<000000?ooo`3oool01@0000020?ooo`<000000P3oool2000000030?ooo`00
000000000080000000<0oooo0000000000000P3oool300000080oooo1@0000020?ooo`030000003o
ool0oooo00<0oooo1P0000030?ooo`<000000P3oool>0=7=Z@00303AcJT20?ooo`@0000000<0oooo
0000000000000P3oool4000000@0oooo00<000000?ooo`3oool00P3oool6000000D0oooo0P000004
0?ooo`8000001@3oool6000000@0oooo00<000000?ooo`3oool00P3oool400000080oooo0P000000
0`3oool000000000000200000080oooo2`3AcJT40?ooo`030000003oool0oooo00800000103oool3
00000080oooo100000020?ooo`<000000P3oool4000000030?ooo`0000000000008000000P3oool4
000000030?ooo`0000000000008000000P3oool300000080oooo100000020?ooo`<00000103oool2
00000080oooo00<000000?ooo`3oool00P3oool;0=7=Z@80oooo0P0000070?ooo`<000000P3oool2
000000030?ooo`000000000000D0oooo2`0000030?ooo`/000001@3oool200000080oooo00<00000
0?ooo`3oool0100000070?ooo`030000003oool0oooo00/0dLfY0`0000020?ooo`@000004`3oool3
00000080oooo0P0000000`3oool00000000000020?ooo`80000000<0oooo0000000000000P3oool3
000001<0oooo100000020?ooo`<000002`3AcJT20?ooo`<000000`3oool6000000D0oooo00<00000
0?ooo`3oool01@0000020?ooo`<000000P3oool2000000030?ooo`00000000000080000000<0oooo
0000000000000P3oool300000080oooo1@0000020?ooo`030000003oool0oooo00<0oooo1P000003
0?ooo`<000000P3oool>0=7=Z@00303AcJT20?ooo`@0000000<0oooo0000000000000P3oool40000
00@0oooo00<000000?ooo`3oool00P3oool6000000D0oooo0P0000040?ooo`8000001@3oool60000
00@0oooo00<000000?ooo`3oool00P3oool400000080oooo0P0000000`3oool00000000000020000
0080oooo2`3AcJT20?ooo`8000001@3oool2000000D0oooo0P0000040?ooo`8000000`3oool20000
00@0oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`3oool00P3oool20000
00<0oooo0P0000040?ooo`8000001@3oool2000000D0oooo0P0000020?ooo`/0dLfY0P3oool20000
00L0oooo0`0000020?ooo`80000000<0oooo0000000000001@3oool;000000<0oooo2`0000050?oo
o`8000000P3oool00`000000oooo0?ooo`04000000L0oooo00<000000?ooo`3oool02`3AcJT20?oo
o`030000003oool0oooo0080oooo0`0000020?ooo`8000000P3oool3000000L0oooo1@0000020?oo
o`8000000`3oool2000000<0oooo0P0000020?ooo`D000001`3oool300000080oooo0P0000020?oo
o`<00000103oool00`000000oooo0?ooo`0;0=7=Z@<000000P3oool500000080oooo0`0000020?oo
o`80000000<0oooo0000000000000P0000030?ooo`8000000`3oool5000000@0oooo1@0000030?oo
o`8000000`3oool4000000030?ooo`00000000000080oooo0`0000020?ooo`D000000P3oool30000
00h0dLfY000<0=7=Z@8000001`3oool4000000H0oooo0`0000040?ooo`H000001@3oool4000000D0
oooo1P0000040?ooo`<000001P3oool4000000L0oooo0P00000;0=7=Z@80oooo0P0000050?ooo`80
00001@3oool2000000@0oooo0P0000030?ooo`800000103oool00`000000oooo0?ooo`020?ooo`80
0000103oool00`000000oooo0?ooo`020?ooo`8000000`3oool2000000@0oooo0P0000050?ooo`80
00001@3oool200000080oooo2`3AcJT;0?ooo`<000001`3oool2000000X0oooo100000030?ooo`@0
00002P3oool2000000L0oooo1000000:0?ooo`/0dLfY0`0000020?ooo`8000000P3oool300000080
oooo1@0000020?ooo`<000000P3oool300000080oooo100000000`3oool00000000000020?ooo`80
000000<0oooo0000000000000P0000020?ooo`<000000P3oool300000080oooo1@0000020?ooo`<0
00000P3oool200000080oooo0`00000;0=7=Z@<000000P3oool500000080oooo0`0000020?ooo`80
000000<0oooo0000000000000P0000030?ooo`8000000`3oool5000000@0oooo1@0000030?ooo`80
00000`3oool4000000030?ooo`00000000000080oooo0`0000020?ooo`D000000P3oool3000000h0
dLfY000<0=7=Z@8000001`3oool4000000H0oooo0`0000040?ooo`H000001@3oool4000000D0oooo
1P0000040?ooo`<000001P3oool4000000L0oooo0P00000;0=7=Z@@0oooo1@0000060?ooo`030000
003oool0oooo00@000000P3oool300000080oooo100000000`3oool000000000000200000080oooo
100000000`3oool000000000000200000080oooo0`0000020?ooo`@000000P3oool2000000D0oooo
1@0000040?ooo`/0dLfY0P0000020?ooo`D000002@3oool3000000@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`090?ooo`8000001@3oool2000000<0oooo100000080?ooo`H00000
00<0oooo0000000000002`3AcJT300000080oooo0P0000020?ooo`<000000P3oool500000080oooo
0`0000020?ooo`<000000P3oool4000000030?ooo`00000000000080oooo0P0000000`3oool00000
0000000200000080oooo0`0000020?ooo`<000000P3oool500000080oooo0`0000020?ooo`800000
0P3oool3000000/0dLfY0P0000030?ooo`8000001`3oool3000000<0oooo0P0000020?ooo`<00000
0P3ooolD00000080oooo0`0000020?ooo`8000000`3oool3000000L0oooo0P0000030?ooo`800000
3P3AcJT000`0dLfY0P3oool200000080oooo1@0000020?ooo`@000000`3oool200000080oooo0P00
00020?ooo`@0000000<0oooo0000000000002P0000000`3oool000000000000200000080oooo0P00
00020?ooo`8000000`3oool400000080oooo1@0000020?ooo`8000000P3oool;0=7=Z@@0oooo1@00
00060?ooo`030000003oool0oooo00@000000P3oool300000080oooo100000000`3oool000000000
000200000080oooo100000000`3oool000000000000200000080oooo0`0000020?ooo`@000000P3o
ool2000000D0oooo1@0000040?ooo`/0dLfY0P0000020?ooo`D000002@3oool3000000@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`8000001@3oool2000000<0oooo1000
00080?ooo`H0000000<0oooo0000000000002`3AcJT2000000030?ooo`000000000000D0oooo0P00
00020?ooo`<000000P3oool7000000D0oooo0P0000020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P0000050?ooo`L000000P3oool300000080oooo0P0000050?ooo`80000000<0
oooo0000000000002`3AcJT2000000<0oooo0P0000070?ooo`<000000`3oool200000080oooo0`00
00020?oooa@000000P3oool300000080oooo0P0000030?ooo`<000001`3oool2000000<0oooo0P00
000>0=7=Z@00303AcJT20?ooo`8000000P3oool500000080oooo100000030?ooo`8000000P3oool2
00000080oooo100000000`3oool000000000000:000000030?ooo`0000000000008000000P3oool2
00000080oooo0P0000030?ooo`@000000P3oool500000080oooo0P0000020?ooo`/0dLfY1@000002
0?ooo`H000001@3oool400000080oooo0`0000020?ooo`@0000000<0oooo0000000000000P000002
0?ooo`@0000000<0oooo0000000000000P0000020?ooo`<000000P3oool4000000D0oooo1P000002
0?ooo`D000002`3AcJT20?ooo`<000000P3oool2000000D0oooo0P0000020?ooo`D000001@3oool2
000000<0oooo0P0000020?ooo`<000000P3oool2000000<0oooo0P0000050?ooo`H0000000<0oooo
0000000000001@3oool200000080oooo0`0000020?ooo`/0dLfY0P0000000`3oool0000000000005
0?ooo`8000000P3oool300000080oooo1`0000050?ooo`8000000P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo008000001@3oool700000080oooo0`0000020?ooo`8000001@3oool2
000000030?ooo`000000000000/0dLfY0`0000020?ooo`<000000P3oool4000000030?ooo`000000
00000080000000<0oooo0000000000000P3oool300000080oooo0P0000000`3oool0000000000003
000000@0oooo1@0000000`3oool00000000000020?ooo`<000000P3oool2000000030?ooo`000000
00000080000000<0oooo0000000000000P0000020?ooo`<000000P3oool3000000h0dLfY000<0=7=
Z@8000000P3oool3000000H0oooo100000020?ooo`D00000203oool300000080oooo100000020?oo
o`<00000203oool500000080oooo100000060?ooo`<000000P3oool2000000/0dLfY0P0000090?oo
o`8000002@3oool2000000<0oooo0P0000040?ooo`030000003oool0oooo0080oooo0P0000040?oo
o`030000003oool0oooo0080oooo0P0000030?ooo`8000002@3oool2000000T0oooo0P00000;0=7=
Z@80oooo0`0000020?ooo`8000001@3oool200000080oooo1@0000050?ooo`8000000`3oool20000
0080oooo0`0000020?ooo`8000000`3oool2000000D0oooo1P0000000`3oool00000000000050?oo
o`8000000P3oool300000080oooo2`3AcJT2000000<0oooo2@0000050?ooo`T000000`3oool20000
00<0oooo1P0000030?ooo`8000000`3oool9000000D0oooo2@0000030?ooo`8000002`3AcJT20?oo
o`<000000P3oool7000000<0oooo1`0000030?ooo`@000000`3oool2000000030?ooo`0000000000
0080000000<0oooo0000000000000`3oool4000000<0oooo1`0000030?ooo`L000000P3oool30000
0080oooo3P3AcJT000`0dLfY0P0000020?ooo`<000001P3oool400000080oooo1@0000080?ooo`<0
00000P3oool400000080oooo0`0000080?ooo`D000000P3oool4000000H0oooo0`0000020?ooo`80
00002`3AcJT2000000T0oooo0P0000090?ooo`8000000`3oool2000000@0oooo00<000000?ooo`3o
ool00P3oool2000000@0oooo00<000000?ooo`3oool00P3oool2000000<0oooo0P0000090?ooo`80
00002@3oool2000000/0dLfY100000030?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`80
000000<0oooo0000000000000P0000090?ooo`030000003oool0oooo00L000000P3oool2000000P0
oooo100000020?ooo`030000003oool0oooo0080oooo0P0000000`3oool00000000000040?ooo`<0
00002`3AcJT2000000030?ooo`0000000000008000000`3oool6000000D0oooo1`0000030?ooo`80
00000P3oool300000080oooo0`0000020?ooo`8000000`3oool7000000D0oooo1P0000030?ooo`@0
000000<0oooo0000000000002`3AcJT20?ooo`<000000P3oool7000000<0oooo1`0000030?ooo`@0
00000`3oool2000000030?ooo`00000000000080000000<0oooo0000000000000`3oool4000000<0
oooo1`0000030?ooo`L000000P3oool300000080oooo3P3AcJT000`0dLfY103oool2000000030?oo
o`000000000000P0oooo2`0000020?ooo`<00000303oool300000080oooo2`0000080?ooo`800000
00<0oooo000000000000103oool;0=7=Z@@0000000<0oooo0000000000000P3oool400000080oooo
0`0000020?ooo`8000000P3oool300000080oooo100000000`3oool000000000000200000080oooo
100000000`3oool000000000000200000080oooo0`0000020?ooo`8000000P3oool4000000030?oo
o`0000000000008000000P3oool2000000030?ooo`0000000000008000002`3AcJT4000000<0oooo
0P0000020?ooo`030000003oool0oooo0080oooo0P0000000`3oool0000000000002000000T0oooo
00<000000?ooo`3oool01`0000020?ooo`800000203oool400000080oooo00<000000?ooo`3oool0
0P3oool2000000030?ooo`000000000000@0oooo0`00000;0=7=Z@80000000<0oooo000000000000
0P0000030?ooo`H000001@3oool7000000<0oooo0P0000020?ooo`<000000P3oool300000080oooo
0P0000030?ooo`L000001@3oool6000000<0oooo100000000`3oool000000000000;0=7=Z@800000
00<0oooo0000000000001@3oool2000000<0oooo0P0000030?ooo`T000000`3oool4000000030?oo
o`00000000000080000000<0oooo0000000000000P0000030?ooo`T000000`3oool2000000<0oooo
0P0000050?ooo`80000000<0oooo0000000000003P3AcJT000`0dLfY103oool2000000030?ooo`00
0000000000P0oooo2`0000020?ooo`<00000303oool300000080oooo2`0000080?ooo`80000000<0
oooo000000000000103oool;0=7=Z@@0000000<0oooo0000000000000P3oool400000080oooo0`00
00020?ooo`8000000P3oool300000080oooo100000000`3oool000000000000200000080oooo1000
00000`3oool000000000000200000080oooo0`0000020?ooo`8000000P3oool4000000030?ooo`00
00000000008000000P3oool2000000030?ooo`0000000000008000002`3AcJT200000080oooo00<0
00000?ooo`3oool0100000030?ooo`8000002@3oool3000000L0oooo1`0000070?ooo`@00000203o
ool2000000@0oooo0`0000020?ooo`80000000<0oooo0000000000002`3AcJT500000080oooo0`00
00020?ooo`@0000000<0oooo0000000000000P0000020?ooo`<000001@3oool5000000H0oooo1@00
00050?ooo`<000000P3oool4000000030?ooo`0000000000008000000P3oool300000080oooo1@00
000;0=7=Z@80000000<0oooo0000000000001@3oool2000000<0oooo0P0000030?ooo`T000000`3o
ool4000000030?ooo`00000000000080000000<0oooo0000000000000P0000030?ooo`T000000`3o
ool2000000<0oooo0P0000050?ooo`80000000<0oooo0000000000003P3AcJT000`0dLfY103oool2
000000D0oooo0P0000020?ooo`T000000P3oool6000000030?ooo`000000000000800000103oool4
000000030?ooo`000000000000@000000P3oool900000080oooo0P0000050?ooo`800000103oool;
0=7=Z@80oooo0`0000020?ooo`@000000P3oool7000000@0oooo0`0000020?ooo`@0000000<0oooo
0000000000000P0000020?ooo`@0000000<0oooo0000000000000P0000020?ooo`<00000103oool7
00000080oooo100000020?ooo`<000000P3oool;0=7=Z@8000000P3oool00`000000oooo0?ooo`04
000000<0oooo0P0000090?ooo`<000001`3oool7000000L0oooo100000080?ooo`800000103oool3
00000080oooo0P0000000`3oool000000000000;0=7=Z@D000000P3oool300000080oooo10000000
0`3oool000000000000200000080oooo0`0000050?ooo`D000001P3oool5000000D0oooo0`000002
0?ooo`@0000000<0oooo0000000000000P0000020?ooo`<000000P3oool5000000/0dLfY0`3oool2
000000<0oooo1P0000030?ooo`<000000P3oool2000000D0oooo0P0000000`3oool0000000000002
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P0000000`3oool0000000000005
0?ooo`8000000P3oool3000000<0oooo1P0000030?ooo`8000000`3oool>0=7=Z@00303AcJT20000
0080oooo0P0000070?ooo`T000002`3oool4000000@0oooo1000000;0?ooo`T000001`3oool20000
0080oooo0P00000;0=7=Z@80oooo0`0000020?ooo`@000000P3oool7000000@0oooo0`0000020?oo
o`@0000000<0oooo0000000000000P0000020?ooo`@0000000<0oooo0000000000000P0000020?oo
o`<00000103oool700000080oooo100000020?ooo`<000000P3oool;0=7=Z@8000000`3oool20000
0080oooo0`0000040?ooo`<000001P3oool300000080oooo0P0000050?ooo`<000001P3oool00`00
0000oooo0?ooo`04000000D0oooo0`0000040?ooo`<000000P3oool2000000<0oooo0P00000;0=7=
Z@L0oooo0`0000060?ooo`D000001@3oool3000000L0oooo1P0000070?ooo`<000001@3oool50000
00H0oooo0`0000070?ooo`/0dLfY0`3oool2000000<0oooo1P0000000`3oool00000000000030000
0080oooo0`0000020?ooo`8000000P3oool3000000<0oooo100000030?ooo`<000000P3oool20000
0080oooo0`0000020?ooo`D0000000<0oooo000000000000100000030?ooo`8000000`3oool>0=7=
Z@00303AcJT200000080oooo0P0000070?ooo`T000002`3oool4000000@0oooo1000000;0?ooo`T0
00001`3oool200000080oooo0P00000;0=7=Z@8000000P3oool00`000000oooo0?ooo`02000000@0
oooo2@0000050?ooo`800000103oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000
oooo0?ooo`020?ooo`8000001@3oool9000000@0oooo0P0000020?ooo`030000003oool0oooo0080
00002`3AcJT200000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0500000080
oooo0P0000050?ooo`8000000`3oool4000000<0oooo100000030?ooo`8000001@3oool200000080
oooo1@0000020?ooo`8000001@3oool2000000030?ooo`000000000000/0dLfY1`3oool3000000H0
oooo1@0000050?ooo`<000001`3oool6000000L0oooo0`0000050?ooo`D000001P3oool3000000L0
oooo2`3AcJT30?ooo`8000000`3oool6000000030?ooo`000000000000<000000P3oool300000080
oooo0P0000020?ooo`<000000`3oool4000000<0oooo0`0000020?ooo`8000000P3oool300000080
oooo1@0000000`3oool0000000000004000000<0oooo0P0000030?ooo`h0dLfY000<0=7=Z@80oooo
100000000`3oool000000000000;00000080oooo1000000J0?ooo`@000000P3oool=000000030?oo
o`0000000000008000000P3oool;0=7=Z@8000000P3oool00`000000oooo0?ooo`02000000@0oooo
2@0000050?ooo`800000103oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo
0?ooo`020?ooo`8000001@3oool9000000@0oooo0P0000020?ooo`030000003oool0oooo00800000
2`3AcJT200000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0500000080oooo
0P0000050?ooo`8000000`3oool4000000<0oooo100000030?ooo`8000001@3oool200000080oooo
1@0000020?ooo`8000001@3oool2000000030?ooo`000000000000/0dLfY3P3oool5000000D0oooo
1@0000060?ooo`<000000P3oool3000000H0oooo1@0000050?ooo`D000003P3oool;0=7=Z@800000
00<0oooo0000000000001@3oool200000080oooo1@0000000`3oool00000000000020?ooo`<00000
103oool00`000000oooo0?ooo`020?ooo`H00000103oool00`000000oooo0?ooo`020?ooo`<00000
0P3oool2000000030?ooo`000000000000<000000P3oool2000000D0oooo0P0000000`3oool00000
0000000>0=7=Z@00303AcJT20?ooo`@0000000<0oooo0000000000002`0000020?ooo`@000006P3o
ool400000080oooo3@0000000`3oool000000000000200000080oooo2`3AcJT40?ooo`L00000103o
ool7000000<0oooo0P0000020?ooo`@0000000<0oooo0000000000000P0000020?ooo`@0000000<0
oooo0000000000000P0000020?ooo`8000000`3oool8000000<0oooo1`0000040?ooo`/0dLfY1000
00000`3oool000000000000;000000030?ooo`000000000000D0oooo0P0000020?ooo`80000000<0
oooo0000000000002@0000020?ooo`030000003oool0oooo008000001@3oool200000080oooo3000
00020?ooo`<000002`3AcJT7000000<0oooo0P0000020?ooo`<000000P3oool4000000030?ooo`00
00000000008000000`3oool200000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`02000000<0oooo100000000`3oool000000000000200000080oooo0`0000020?ooo`8000000`3o
ool7000000/0dLfY0P0000000`3oool00000000000050?ooo`8000000P3oool5000000030?ooo`00
000000000080oooo0`0000040?ooo`030000003oool0oooo0080oooo1P0000040?ooo`030000003o
ool0oooo0080oooo0`0000020?ooo`80000000<0oooo0000000000000`0000020?ooo`8000001@3o
ool2000000030?ooo`000000000000h0dLfY000<0=7=Z@@000000P3oool3000000@0oooo1P000003
0?ooo`@000000P3oool5000000@0oooo100000040?ooo`D000000P3oool4000000<0oooo1P000004
0?ooo`<000000P3oool4000000/0dLfY1`3oool400000080oooo0P0000000`3oool0000000000002
000000T0oooo100000000`3oool000000000000200000080oooo100000000`3oool0000000000002
000000T0oooo100000020?ooo`030000003oool0oooo00@000001`3oool;0=7=Z@@0000000<0oooo
0000000000002`0000000`3oool00000000000050?ooo`8000000P3oool2000000030?ooo`000000
000000T000000P3oool00`000000oooo0?ooo`02000000D0oooo0P0000020?ooo``000000P3oool3
000000/0dLfY1`0000030?ooo`8000000P3oool300000080oooo100000000`3oool0000000000002
000000<0oooo0P0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P000003
0?ooo`@0000000<0oooo0000000000000P0000020?ooo`<000000P3oool2000000<0oooo1`00000;
0=7=Z@80oooo0`0000020?ooo`D000000P3oool3000000P0oooo100000020?ooo`<000000P3oool6
00000080oooo0`0000020?ooo`@00000203oool300000080oooo1@0000020?ooo`<000000P3oool>
0=7=Z@00303AcJT400000080oooo0`0000040?ooo`H000000`3oool400000080oooo1@0000040?oo
o`@00000103oool500000080oooo100000030?ooo`H00000103oool300000080oooo1000000;0=7=
Z@L0oooo100000020?ooo`80000000<0oooo0000000000000P0000090?ooo`@0000000<0oooo0000
000000000P0000020?ooo`@0000000<0oooo0000000000000P0000090?ooo`@000000P3oool00`00
0000oooo0?ooo`04000000L0oooo2`3AcJT20?ooo`80000000<0oooo000000000000103oool00`00
0000oooo0?ooo`02000000D0oooo100000070?ooo`030000003oool0oooo008000000`3oool20000
0080oooo0P0000070?ooo`<000001@3oool200000080oooo0P0000030?ooo`8000000P3oool00`00
0000oooo0?ooo`0;0=7=Z@8000000`3oool2000000D0oooo0P0000050?ooo`D00000103oool00`00
0000oooo0?ooo`020?ooo``00000103oool00`000000oooo0?ooo`020?ooo`D000001@3oool20000
00D0oooo0P0000030?ooo`8000002`3AcJT300000080oooo0`0000040?ooo`8000000`3oool30000
0080oooo0`0000020?ooo`@0000000<0oooo0000000000000P0000000`3oool00000000000020000
00030?ooo`00000000000080000000<0oooo0000000000000P0000020?ooo`<000000P3oool30000
00<0oooo0P0000040?ooo`<000000P3oool3000000h0dLfY000<0=7=Z@800000103oool00`000000
oooo0?ooo`0400000080oooo0P0000020?ooo`030000003oool0oooo00@0oooo100000020?ooo`03
0000003oool0oooo0080oooo100000040?ooo`030000003oool0oooo00@000001P3oool00`000000
oooo0?ooo`0200000080oooo100000020?ooo`030000003oool0oooo0080oooo0P00000;0=7=Z@@0
000000<0oooo000000000000103oool2000000L0oooo1@0000080?ooo`030000003oool0oooo0080
oooo0P0000040?ooo`030000003oool0oooo00H0oooo1@0000070?ooo`800000103oool200000003
0?ooo`0000000000008000002`3AcJT20?ooo`80000000<0oooo000000000000103oool00`000000
oooo0?ooo`02000000D0oooo100000070?ooo`030000003oool0oooo008000000`3oool200000080
oooo0P0000070?ooo`<000001@3oool200000080oooo0P0000030?ooo`8000000P3oool00`000000
oooo0?ooo`0;0=7=Z@8000000`3oool2000000D0oooo0P0000050?ooo`D00000103oool00`000000
oooo0?ooo`020?ooo``00000103oool00`000000oooo0?ooo`020?ooo`D000001@3oool2000000D0
oooo0P0000030?ooo`8000002`3AcJT300000080oooo0`0000040?ooo`8000000`3oool300000080
oooo0`0000020?ooo`@0000000<0oooo0000000000000P0000000`3oool000000000000200000003
0?ooo`00000000000080000000<0oooo0000000000000P0000020?ooo`<000000P3oool3000000<0
oooo0P0000040?ooo`<000000P3oool3000000h0dLfY000<0=7=Z@800000103oool00`000000oooo
0?ooo`0400000080oooo0P0000020?ooo`030000003oool0oooo00@0oooo100000020?ooo`030000
003oool0oooo0080oooo100000040?ooo`030000003oool0oooo00@000001P3oool00`000000oooo
0?ooo`0200000080oooo100000020?ooo`030000003oool0oooo0080oooo0P00000;0=7=Z@@00000
00<0oooo000000000000103oool2000000L0oooo1@0000080?ooo`030000003oool0oooo0080oooo
0P0000040?ooo`030000003oool0oooo00H0oooo1@0000070?ooo`800000103oool2000000030?oo
o`0000000000008000002`3AcJT<00000080oooo2`0000030?ooo`@000000`3oool7000000@0oooo
0`0000040?ooo`X000000P3oool<000000/0dLfY1`0000020?ooo`<000000P3oool2000000D0oooo
1`0000030?ooo`D000001P3oool5000000<0oooo1`0000050?ooo`8000000P3oool300000080oooo
1`00000;0=7=Z@8000000`3oool2000000030?ooo`0000000000008000000P3oool;000000@0oooo
0P0000030?ooo`8000001P3oool2000000<0oooo0P0000040?ooo`/000000P3oool4000000030?oo
o`000000000000<0oooo0P00000>0=7=Z@00303AcJT400000080oooo00<000000?ooo`3oool01000
00020?ooo`8000001`3oool4000000@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`020?ooo`@000001`3oool200000080oooo100000020?ooo`030000003oool0oooo00@000002`3A
cJT500000080oooo100000020?ooo`<000000P3oool400000080oooo00<000000?ooo`3oool00P00
00020?ooo`80000000<0oooo0000000000000P0000020?ooo`@0000000<0oooo0000000000000P3o
ool200000080oooo00<000000?ooo`3oool0100000020?ooo`<000000P3oool400000080oooo1@00
000;0=7=Z@@0000000<0oooo0000000000001@3oool2000000L0oooo0P0000050?ooo`D000002`3o
ool5000000D0oooo0P0000070?ooo`8000001@3oool200000080oooo0`00000;0=7=Z@L000000P3o
ool300000080oooo0P0000050?ooo`L000000`3oool5000000H0oooo1@0000030?ooo`L000001@3o
ool200000080oooo0`0000020?ooo`L000002`3AcJT2000000<0oooo0P0000000`3oool000000000
000200000080oooo2`0000040?ooo`8000000`3oool2000000H0oooo0P0000030?ooo`800000103o
ool;00000080oooo100000000`3oool00000000000030?ooo`8000003P3AcJT000`0dLfY10000002
0?ooo`030000003oool0oooo00@000000P3oool2000000L0oooo100000040?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00P3oool4000000L0oooo0P0000020?ooo`@000000P3oool0
0`000000oooo0?ooo`04000000/0dLfY1@0000020?ooo`@000000P3oool300000080oooo10000002
0?ooo`030000003oool0oooo008000000P3oool2000000030?ooo`0000000000008000000P3oool4
000000030?ooo`00000000000080oooo0P0000020?ooo`030000003oool0oooo00@000000P3oool3
00000080oooo100000020?ooo`D000002`3AcJT4000000030?ooo`000000000000D0oooo0P000007
0?ooo`8000001@3oool5000000/0oooo1@0000050?ooo`8000001`3oool2000000D0oooo0P000002
0?ooo`<000002`3AcJT70?ooo`D000001@3oool400000080oooo00<000000?ooo`3oool00`000002
0?ooo`@0000000<0oooo0000000000000P3oool2000000030?ooo`0000000000008000000P3oool3
00000080oooo00<000000?ooo`3oool0100000050?ooo`D000001`3oool;0=7=Z@<000000P3oool2
000000030?ooo`0000000000008000000P3oool00`000000oooo0?ooo`0300000080oooo0P000003
0?ooo`@0000000<0oooo0000000000000P0000060?ooo`@0000000<0oooo0000000000000P000003
0?ooo`8000000P3oool300000080oooo00<000000?ooo`3oool0100000000`3oool0000000000002
0?ooo`<000003P3AcJT000`0dLfY0P3oool7000000@0oooo100000030?ooo`8000000P3oool20000
0080oooo0P0000020?ooo`030000003oool0oooo00800000103oool200000080oooo00<000000?oo
o`3oool00P0000020?ooo`8000000P3oool2000000<0oooo100000040?ooo`L000000P3oool;0=7=
Z@80oooo0`0000020?ooo`@000000P3oool7000000@0oooo0`0000020?ooo`8000000`3oool40000
0080oooo100000030?ooo`8000000P3oool3000000@0oooo1`0000020?ooo`@000000P3oool30000
0080oooo2`3AcJT50?ooo`@000000P3oool00`000000oooo0?ooo`02000000<0oooo1`0000040?oo
o`<000002`3oool3000000@0oooo1`0000030?ooo`8000000P3oool2000000030?ooo`0000000000
008000001@3oool;0=7=Z@D0oooo1@0000070?ooo`@000000P3oool00`000000oooo0?ooo`020?oo
o`<000001`3oool2000000L0oooo0`0000040?ooo`030000003oool0oooo00@000001`3oool50000
00D0oooo2`3AcJT300000080oooo0P0000000`3oool000000000000200000080oooo00<000000?oo
o`3oool00`0000020?ooo`8000000`3oool4000000030?ooo`0000000000008000001P3oool40000
00030?ooo`0000000000008000000`3oool200000080oooo0`0000020?ooo`030000003oool0oooo
00@0000000<0oooo0000000000000P3oool3000000h0dLfY000<0=7=Z@80oooo1`0000040?ooo`@0
00000`3oool200000080oooo0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`02000000@0
oooo0P0000020?ooo`030000003oool0oooo008000000P3oool200000080oooo0P0000030?ooo`@0
0000103oool700000080oooo2`3AcJT20?ooo`<000000P3oool400000080oooo1`0000040?ooo`<0
00000P3oool2000000<0oooo100000020?ooo`@000000`3oool200000080oooo0`0000040?ooo`L0
00000P3oool400000080oooo0`0000020?ooo`/0dLfY1@3oool400000080oooo00<000000?ooo`3o
ool00P0000030?ooo`L00000103oool3000000/0oooo0`0000040?ooo`L000000`3oool200000080
oooo0P0000000`3oool0000000000002000000D0oooo2`3AcJT50?ooo`D000001`3oool400000080
oooo00<000000?ooo`3oool00P3oool3000000L0oooo0P0000070?ooo`<00000103oool00`000000
oooo0?ooo`04000000L0oooo1@0000050?ooo`/0dLfY0P3oool6000000@0oooo0`0000070?ooo`<0
00000P3oool200000080oooo0`0000030?ooo`@000000`3oool300000080oooo0P0000020?ooo`<0
00001`3oool3000000@0oooo1P0000020?ooo`h0dLfY000<0=7=Z@800000103oool9000000L0oooo
100000040?ooo`D00000203oool5000000@0oooo100000070?ooo`T00000103oool2000000/0dLfY
0P0000030?ooo`800000103oool200000080oooo00<000000?ooo`3oool00P3oool2000000<0oooo
0P0000040?ooo`8000001@3oool2000000D0oooo0P0000040?ooo`8000000`3oool2000000@0oooo
0P0000000`3oool00000000000040?ooo`8000000`3oool2000000/0dLfY1`3oool4000000P0oooo
100000020?ooo`030000003oool0oooo008000001@3oool7000000D0oooo0P0000020?ooo`800000
00<0oooo0000000000000P0000090?ooo`<000001`3oool;0=7=Z@<000000P3oool4000000030?oo
o`000000000000@000001@3oool300000080oooo0P0000000`3oool000000000000200000080oooo
0`0000020?ooo`<000000P3oool4000000030?ooo`00000000000080oooo0`0000050?ooo`H00000
00<0oooo0000000000000P0000020?ooo`<000002`3AcJT2000000<0oooo2@00000:0?ooo`D00000
0P3oool00`000000oooo0?ooo`02000000030?ooo`00000000000080000000<0oooo000000000000
0P3oool00`000000oooo0?ooo`05000000X0oooo2@0000030?ooo`8000003P3AcJT000`0dLfY0P3o
ool4000000030?ooo`000000000000H0oooo2@0000040?oooaH00000103oool9000000H0oooo0P00
00000`3oool000000000000200000080oooo2`3AcJT2000000<0oooo0P0000040?ooo`8000000P3o
ool00`000000oooo0?ooo`020?ooo`8000000`3oool2000000@0oooo0P0000050?ooo`8000001@3o
ool2000000@0oooo0P0000030?ooo`800000103oool2000000030?ooo`000000000000@0oooo0P00
00030?ooo`8000002`3AcJT70?ooo`@00000203oool400000080oooo00<000000?ooo`3oool00P00
00050?ooo`L000001@3oool200000080oooo0P0000000`3oool0000000000002000000T0oooo0`00
00070?ooo`/0dLfY0`0000020?ooo`@0000000<0oooo000000000000100000050?ooo`<000000P3o
ool2000000030?ooo`0000000000008000000P3oool300000080oooo0`0000020?ooo`@0000000<0
oooo0000000000000P3oool3000000D0oooo1P0000000`3oool000000000000200000080oooo0`00
000;0=7=Z@8000000`3oool9000000X0oooo1@0000020?ooo`030000003oool0oooo0080000000<0
oooo0000000000000P0000000`3oool00000000000020?ooo`030000003oool0oooo00D000002P3o
ool9000000<0oooo0P00000>0=7=Z@00303AcJT20?ooo`@0000000<0oooo0000000000001P3oool9
000000@0oooo5P0000040?ooo`T000001P3oool2000000030?ooo`0000000000008000000P3oool;
0=7=Z@80oooo0`0000020?ooo`@00000103oool5000000@0oooo0`0000020?ooo`8000001@3oool2
00000080oooo0P0000050?ooo`8000000P3oool3000000@0oooo1P0000030?ooo`@000000P3oool3
00000080oooo2`3AcJT700000080oooo1@0000020?ooo`8000001`3oool300000080oooo0P000003
0?ooo`8000000`3oool2000000@0oooo00<000000?ooo`3oool0100000070?ooo`030000003oool0
oooo00D000000P3oool7000000/0dLfY1@0000050?ooo`8000000P3oool2000000<0oooo10000000
0`3oool00000000000050?ooo`L000000P3oool7000000D0oooo0P0000000`3oool0000000000002
000000<0oooo0P0000020?ooo`8000001@3oool5000000/0dLfY0P3oool300000080oooo00<00000
0?ooo`3oool0103oool:000000D0oooo0`0000040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool3000000D0oooo2P0000060?ooo`030000003oool0oooo00<000000P3oool>
0=7=Z@00303AcJT6000000030?ooo`0000000000008000000P3oool4000000L0oooo0P0000020?oo
o`L00000203oool700000080oooo0P0000070?ooo`@000000P3oool4000000030?ooo`0000000000
00@000002`3AcJT500000080oooo1P0000050?ooo`@000000P3oool00`000000oooo0?ooo`020000
0080oooo0`00000:0?ooo`<000000P3oool200000080oooo00<000000?ooo`3oool0100000050?oo
o`H000000P3oool5000000/0dLfY0P0000030?ooo`8000001@3oool4000000X0oooo0P0000070?oo
o`L000001`3oool2000000X0oooo100000050?ooo`8000000`3oool2000000/0dLfY1@0000050?oo
o`8000000P3oool2000000<0oooo100000000`3oool00000000000050?ooo`L000000P3oool70000
00D0oooo0P0000000`3oool0000000000002000000<0oooo0P0000020?ooo`8000001@3oool50000
00/0dLfY0P3oool300000080oooo00<000000?ooo`3oool0103oool:000000D0oooo0`0000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool3000000D0oooo2P0000060?oo
o`030000003oool0oooo00<000000P3oool>0=7=Z@00303AcJT6000000030?ooo`00000000000080
00000P3oool4000000L0oooo0P0000020?ooo`L00000203oool700000080oooo0P0000070?ooo`@0
00000P3oool4000000030?ooo`000000000000@000002`3AcJT500000080oooo1P0000050?ooo`@0
00000P3oool00`000000oooo0?ooo`0200000080oooo0`00000:0?ooo`<000000P3oool200000080
oooo00<000000?ooo`3oool0100000050?ooo`H000000P3oool5000000/0dLfY0P0000030?ooo`80
00001@3oool4000000X0oooo0P0000070?ooo`L000001`3oool2000000X0oooo100000050?ooo`80
00000`3oool2000000/0dLfY0P3oool5000000<0oooo0P0000020?ooo`8000000`3oool2000000D0
oooo1@0000040?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`020?ooo`D0
00001@3oool2000000<0oooo0P0000020?ooo`8000000`3oool500000080oooo2`3AcJT500000080
oooo0`0000020?ooo`<000001`3oool300000080oooo100000030?ooo`80000000<0oooo00000000
00000P0000000`3oool00000000000030?ooo`@000000P3oool3000000L0oooo0`0000020?ooo`<0
00000P3oool5000000h0dLfY000<0=7=Z@@000000P3oool00`000000oooo0?ooo`0600000080oooo
0P0000030?ooo`8000000P3oool200000080oooo0`0000020?ooo`800000103oool200000080oooo
0`0000020?ooo`8000000P3oool2000000<0oooo0P0000020?ooo`H000000P3oool00`000000oooo
0?ooo`04000000/0dLfY100000000`3oool00000000000020?ooo`@000000`3oool200000080oooo
1@0000060?ooo`<00000103oool2000000@0oooo0`0000060?ooo`D000000P3oool2000000<0oooo
100000020?ooo`80000000<0oooo0000000000000P00000;0=7=Z@L00000103oool00`000000oooo
0?ooo`0>000000@0oooo00<000000?ooo`3oool02@3oool2000000<0oooo3P0000020?ooo`800000
0`3oool7000000/0dLfY0P0000000`3oool0000000000002000000<0oooo1P0000030?ooo`T00000
00<0oooo0000000000001@0000060?ooo`L0000000<0oooo0000000000001`0000030?ooo`H00000
0`3oool4000000030?ooo`000000000000/0dLfY0`0000020?ooo`80000000<0oooo000000000000
100000000`3oool00000000000030?ooo`8000000P3oool500000080oooo00<000000?ooo`3oool0
0`3oool4000000D0oooo00<000000?ooo`3oool01@0000020?ooo`8000000`3oool2000000030?oo
o`000000000000@0000000<0oooo0000000000000P3oool3000000h0dLfY000<0=7=Z@@000000P3o
ool00`000000oooo0?ooo`0600000080oooo0P0000030?ooo`8000000P3oool200000080oooo0`00
00020?ooo`800000103oool200000080oooo0`0000020?ooo`8000000P3oool2000000<0oooo0P00
00020?ooo`H000000P3oool00`000000oooo0?ooo`04000000/0dLfY100000000`3oool000000000
00020?ooo`@000000`3oool200000080oooo1@0000060?ooo`<00000103oool2000000@0oooo0`00
00060?ooo`D000000P3oool2000000<0oooo100000020?ooo`80000000<0oooo0000000000000P00
000;0=7=Z@L00000103oool00`000000oooo0?ooo`0>000000@0oooo00<000000?ooo`3oool02@3o
ool2000000<0oooo3P0000020?ooo`8000000`3oool7000000/0dLfY0P0000000`3oool000000000
0002000000<0oooo1P0000030?ooo`T0000000<0oooo0000000000001@0000060?ooo`L0000000<0
oooo0000000000001`0000030?ooo`H000000`3oool4000000030?ooo`000000000000/0dLfY0`00
00020?ooo`80000000<0oooo000000000000100000000`3oool00000000000030?ooo`8000000P3o
ool500000080oooo00<000000?ooo`3oool00`3oool4000000D0oooo00<000000?ooo`3oool01@00
00020?ooo`8000000`3oool2000000030?ooo`000000000000@0000000<0oooo0000000000000P3o
ool3000000h0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY
003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY
003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY000<0=7=Z@@000002@3oool400000080oooo0P0000020?oo
o`L00000203oool2000000T0oooo1P0000020?ooo`8000000P3oool4000000T0oooo1000000;0=7=
Z@8000000P3oool400000080oooo0P0000020?ooo`8000000P3oool300000080oooo0P0000020?oo
o`H00000103oool4000000@0oooo1P0000020?ooo`8000000P3oool300000080oooo0P0000020?oo
o`8000000P3oool400000080oooo0P00000;0=7=Z@@0oooo0P0000020?ooo`800000@`3oool;0=7=
Z@8000000P3oool2000000h0oooo00<000000?ooo`3oool00P3oool4000000@0oooo300000040?oo
o`@00000103oool2000000d0oooo0P0000020?ooo`8000002`3AcJT400000080oooo0P0000020?oo
o`<00000103oool200000080oooo1P0000050?ooo`H000001P3oool5000000H0oooo100000040?oo
o`8000000P3oool3000000P0oooo3P3AcJT000`0dLfY100000090?ooo`@000000P3oool200000080
oooo1`0000080?ooo`8000002@3oool600000080oooo0P0000020?ooo`@000002@3oool4000000/0
dLfY0P0000020?ooo`@000000P3oool200000080oooo0P0000020?ooo`<000000P3oool200000080
oooo1P0000040?ooo`@00000103oool600000080oooo0P0000020?ooo`<000000P3oool200000080
oooo0P0000020?ooo`@000000P3oool2000000/0dLfY103oool200000080oooo0P0000130?ooo`/0
dLfY0P0000020?ooo`8000003P3oool00`000000oooo0?ooo`020?ooo`@00000103oool<000000@0
oooo100000040?ooo`8000003@3oool200000080oooo0P00000;0=7=Z@@000000P3oool200000080
oooo0`0000040?ooo`8000000P3oool6000000D0oooo1P0000060?ooo`D000001P3oool4000000@0
oooo0P0000020?ooo`<00000203oool>0=7=Z@00303AcJT400000080oooo1@0000020?ooo`H00000
0P3oool400000080oooo0`0000020?ooo`@000001P3oool4000000<0oooo0P0000020?ooo`@00000
0P3oool600000080oooo1@0000020?ooo`@000002`3AcJT20?ooo`P000000P3oool200000080oooo
0P0000030?ooo`8000000P3oool400000080oooo0P0000040?ooo`@00000103oool200000080oooo
100000020?ooo`8000000`3oool200000080oooo0P0000020?ooo`P000000P3oool;0=7=Z@800000
103oool2000000@0oooo@@00000;0=7=Z@80oooo0P0000040?ooo`X000001`3oool4000000@0oooo
0P0000080?ooo`800000103oool4000000L0oooo2P0000040?ooo`8000000P3oool;0=7=Z@H00000
0P3oool5000000H0oooo100000020?ooo`8000000P3oool00`000000oooo0?ooo`0200000080oooo
0P0000020?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00P0000020?ooo`@00000
1P3oool500000080oooo1P00000>0=7=Z@00303AcJT400000080oooo1@0000020?ooo`H000000P3o
ool400000080oooo0`0000020?ooo`@000001P3oool4000000<0oooo0P0000020?ooo`@000000P3o
ool600000080oooo1@0000020?ooo`@000002`3AcJT20?ooo`P000000P3oool200000080oooo0P00
00030?ooo`8000000P3oool400000080oooo0P0000040?ooo`@00000103oool200000080oooo1000
00020?ooo`8000000`3oool200000080oooo0P0000020?ooo`P000000P3oool;0=7=Z@800000103o
ool2000000@0oooo@@00000;0=7=Z@80oooo0P0000040?ooo`X000001`3oool4000000@0oooo0P00
00080?ooo`800000103oool4000000L0oooo2P0000040?ooo`8000000P3oool;0=7=Z@H000000P3o
ool5000000H0oooo100000020?ooo`8000000P3oool00`000000oooo0?ooo`0200000080oooo0P00
00020?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00P0000020?ooo`@000001P3o
ool500000080oooo1P00000>0=7=Z@00303AcJT40?ooo`T000000P3oool400000080oooo0P000004
0?ooo`T000001P3oool9000000@0oooo0P0000020?ooo`@000000P3oool9000000@0oooo2`3AcJT:
000000l0oooo0P0000040?ooo`800000303oool2000000@0oooo0P00000?0?ooo`X000002`3AcJT4
0?ooo`8000000P3oool200000080oooo0P00000m0?ooo`8000002`3AcJT200000080oooo0P000002
0?ooo`8000001P3oool2000000<0oooo0P00000:0?ooo`@00000103oool4000000X0oooo0P000003
0?ooo`8000001P3oool200000080oooo0P0000020?ooo`8000002`3AcJT20?ooo`@000000P3oool3
000000@0oooo1P0000040?ooo`@0000000<0oooo0000000000000P0000020?ooo`@000000P3oool4
00000080oooo0`0000020?ooo`8000001P3oool8000000030?ooo`0000000000008000000P3oool2
000000h0dLfY000<0=7=Z@@0oooo2@0000020?ooo`@000000P3oool2000000@0oooo2@0000060?oo
o`T00000103oool200000080oooo100000020?ooo`T00000103oool;0=7=Z@X000003`3oool20000
00@0oooo0P00000<0?ooo`800000103oool2000000l0oooo2P00000;0=7=Z@@0oooo0P0000020?oo
o`8000000P3oool2000003d0oooo0P00000;0=7=Z@8000000P3oool200000080oooo0P0000060?oo
o`8000000`3oool2000000X0oooo100000040?ooo`@000002P3oool2000000<0oooo0P0000060?oo
o`8000000P3oool200000080oooo0P00000;0=7=Z@80oooo100000020?ooo`<00000103oool60000
00@0oooo100000000`3oool000000000000200000080oooo100000020?ooo`@000000P3oool30000
0080oooo0P0000060?ooo`P0000000<0oooo0000000000000P0000020?ooo`8000003P3AcJT000`0
dLfY0P3oool;000000H0oooo1P0000070?ooo`800000103oool2000000@0oooo0P0000070?ooo`H0
00001P3oool;00000080oooo2`3AcJT8000000H0oooo0P0000020?ooo`<00000103oool400000080
oooo0P0000020?ooo`800000103oool200000080oooo0P0000020?ooo`@00000103oool300000080
oooo0P0000060?ooo`P000002`3AcJT:0?ooo`H00000>@3oool4000000/0dLfY1P3oool600000080
oooo1000000;0?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000002`3oool400000080
oooo1P0000060?ooo`/0dLfY0P0000040?ooo`8000000`3oool200000080oooo0P0000040?ooo`80
0000103oool2000000030?ooo`00000000000080oooo0P0000020?ooo`8000000P3oool200000080
oooo0P0000000`3oool00000000000040?ooo`800000103oool200000080oooo0P0000030?ooo`80
0000103oool2000000h0dLfY000<0=7=Z@80oooo2`0000060?ooo`H000001`3oool2000000@0oooo
0P0000040?ooo`8000001`3oool6000000H0oooo2`0000020?ooo`/0dLfY200000060?ooo`800000
0P3oool3000000@0oooo100000020?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`800000
0P3oool4000000@0oooo0`0000020?ooo`8000001P3oool8000000/0dLfY2P3oool6000003T0oooo
1000000;0=7=Z@H0oooo1P0000020?ooo`@000002`3oool2000000@0oooo0P0000040?ooo`800000
103oool2000000/0oooo100000020?ooo`H000001P3oool;0=7=Z@800000103oool2000000<0oooo
0P0000020?ooo`800000103oool2000000@0oooo0P0000000`3oool00000000000020?ooo`800000
0P3oool200000080oooo0P0000020?ooo`80000000<0oooo000000000000103oool2000000@0oooo
0P0000020?ooo`8000000`3oool2000000@0oooo0P00000>0=7=Z@00303AcJT20?ooo`T000001P3o
ool8000000D0oooo1P0000060?ooo`L00000103oool8000000H0oooo2@0000020?ooo`/0dLfY0P3o
ool400000080oooo100000040?ooo`8000002@3oool8000000P0oooo200000090?ooo`800000103o
ool400000080oooo100000020?ooo`/0dLfY100000020?ooo`X000000P3ooole00000080oooo0P00
00020?ooo`/0dLfY0P3oool>000000@0oooo00<000000?ooo`3oool0100000060?ooo`@00000103o
ool4000000H0oooo100000020?ooo`8000000`3oool>00000080oooo2`3AcJT20?ooo`@000000P3o
ool300000080oooo200000040?ooo`L000001P3oool6000000D0oooo0P0000020?ooo`8000001P3o
ool200000080oooo100000000`3oool000000000000200000080oooo0P00000>0=7=Z@00303AcJT2
0?ooo`T000001P3oool8000000D0oooo1P0000060?ooo`L00000103oool8000000H0oooo2@000002
0?ooo`/0dLfY0P3oool400000080oooo100000040?ooo`8000002@3oool8000000P0oooo20000009
0?ooo`800000103oool400000080oooo100000020?ooo`/0dLfY100000020?ooo`X000000P3ooole
00000080oooo0P0000020?ooo`/0dLfY0P3oool>000000@0oooo00<000000?ooo`3oool010000006
0?ooo`@00000103oool4000000H0oooo100000020?ooo`8000000`3oool>00000080oooo2`3AcJT2
0?ooo`@000000P3oool300000080oooo200000040?ooo`L000001P3oool6000000D0oooo0P000002
0?ooo`8000001P3oool200000080oooo100000000`3oool000000000000200000080oooo0P00000>
0=7=Z@00303AcJT20?ooo`T000001P3oool8000000D0oooo1P0000060?ooo`L00000103oool80000
00H0oooo2@0000020?ooo`/0dLfY0P0000060?ooo`@000000P3oool200000080oooo2@0000040?oo
oa000000103oool900000080oooo0P0000020?ooo`@000001P3oool2000000/0dLfY200000020?oo
o`@000000P3oool400000340oooo2000000;0=7=Z@80oooo0P0000020?ooo`H00000103oool20000
00<0oooo1P0000060?ooo`800000203oool2000000H0oooo1P0000030?ooo`800000103oool60000
0080oooo0P0000020?ooo`/0dLfY1P0000020?ooo`<000000P3oool400000080oooo100000020?oo
o`@00000503oool400000080oooo100000020?ooo`@000000P3oool300000080oooo1P00000>0=7=
Z@00303AcJT40?ooo`@000000`3oool400000080oooo1P0000070?ooo`H000001P3oool7000000H0
oooo1P0000020?ooo`@000000`3oool4000000@0oooo2`3AcJT2000000H0oooo100000020?ooo`80
00000P3oool9000000@0oooo400000040?ooo`T000000P3oool200000080oooo100000060?ooo`80
00002`3AcJT800000080oooo100000020?ooo`@00000<@3oool8000000/0dLfY0P3oool200000080
oooo1P0000040?ooo`8000000`3oool6000000H0oooo0P0000080?ooo`8000001P3oool6000000<0
oooo0P0000040?ooo`H000000P3oool200000080oooo2`3AcJT400000080oooo0P0000030?ooo`80
0000203oool4000000@0oooo00<000000?ooo`3oool01P0000060?ooo`@000000`3oool200000080
oooo1P0000020?ooo`800000103oool00`000000oooo0?ooo`060?ooo`h0dLfY000<0=7=Z@@0oooo
100000030?ooo`@000000P3oool6000000L0oooo1P0000060?ooo`L000001P3oool600000080oooo
100000030?ooo`@00000103oool;0=7=Z@80oooo0P0000080?ooo`800000103oool3000000@0oooo
1P0000020?ooo`800000203oool200000080oooo1P0000040?ooo`<00000103oool2000000P0oooo
0P0000020?ooo`/0dLfY0P3oool2000000`0oooo0P0000020?ooo`800000;@3oool2000000@0oooo
1000000;0=7=Z@80oooo0P0000040?ooo`8000000P3oool4000000@0oooo1@0000040?ooo`800000
0P3oool<00000080oooo0P0000040?ooo`H000000`3oool400000080oooo0P0000040?ooo`800000
0P3oool;0=7=Z@@000000P3oool2000000<0oooo0P0000080?ooo`@00000103oool00`000000oooo
0?ooo`06000000H0oooo100000030?ooo`8000000P3oool600000080oooo0P0000040?ooo`030000
003oool0oooo00H0oooo3P3AcJT000`0dLfY100000070?ooo`H000000P3oool200000080oooo1000
00050?ooo`800000103oool2000000@0oooo0P0000050?ooo`@000000P3oool200000080oooo1P00
00070?ooo`@000002`3AcJT20?ooo`800000203oool2000000@0oooo0`0000040?ooo`H000000P3o
ool2000000P0oooo0P0000020?ooo`H00000103oool3000000@0oooo0P0000080?ooo`8000000P3o
ool;0=7=Z@80oooo0P00000<0?ooo`8000000P3oool2000002d0oooo0P0000040?ooo`@000002`3A
cJT20?ooo`800000103oool200000080oooo100000040?ooo`D00000103oool200000080oooo3000
00020?ooo`800000103oool6000000<0oooo100000020?ooo`800000103oool200000080oooo2`3A
cJT80?ooo`<000000P3oool200000080oooo100000020?ooo`H0000000<0oooo0000000000000P00
00020?ooo`8000000P3oool200000080oooo100000000`3oool000000000000400000080oooo1000
00020?ooo`8000000P3oool3000000P0oooo3P3AcJT000`0dLfY100000070?ooo`H000000P3oool2
00000080oooo100000050?ooo`800000103oool2000000@0oooo0P0000050?ooo`@000000P3oool2
00000080oooo1P0000070?ooo`@000002`3AcJT2000000@0oooo0P0000020?ooo`8000000P3oool2
00000080oooo1`0000040?ooo`8000000P3oool4000000@0oooo100000020?ooo`800000103oool7
00000080oooo0P0000020?ooo`8000000P3oool2000000@0oooo0P00000;0=7=Z@H000000P3oool2
000000H0oooo0P0000060?ooobT00000103oool4000000@0oooo2`3AcJT20?ooo`8000000P3oool4
00000080oooo1P0000020?ooo`<000000P3oool2000000@0oooo0P00000<0?ooo`800000103oool2
00000080oooo100000000`3oool000000000000400000080oooo100000020?ooo`8000000P3oool;
0=7=Z@P0oooo0`0000020?ooo`8000000P3oool400000080oooo1P0000000`3oool0000000000002
00000080oooo0P0000020?ooo`8000000P3oool4000000030?ooo`000000000000@000000P3oool4
00000080oooo0P0000020?ooo`<00000203oool>0=7=Z@00303AcJT6000000L0oooo100000020?oo
o`8000000P3oool4000000<0oooo1P0000060?ooo`L000000P3oool400000080oooo0P0000020?oo
o`@000001`3oool6000000/0dLfY0P0000040?ooo`8000000P3oool200000080oooo0P0000020?oo
o`L00000103oool200000080oooo100000040?ooo`@000000P3oool2000000@0oooo1`0000020?oo
o`8000000P3oool200000080oooo0P0000040?ooo`8000002`3AcJT600000080oooo0P0000060?oo
o`8000001P3ooolY000000@0oooo100000040?ooo`/0dLfY0P3oool200000080oooo100000020?oo
o`H000000P3oool300000080oooo0P0000040?ooo`800000303oool2000000@0oooo0P0000020?oo
o`@0000000<0oooo000000000000100000020?ooo`@000000P3oool200000080oooo2`3AcJT40?oo
o`L00000103oool6000000H0oooo0P0000000`3oool00000000000040?ooo`@000000P3oool20000
00@0oooo1`0000060?ooo`P000000`3oool6000000h0dLfY000<0=7=Z@H000001`3oool400000080
oooo0P0000020?ooo`@000000`3oool6000000H0oooo1`0000020?ooo`@000000P3oool200000080
oooo100000070?ooo`H000002`3AcJT20?ooo`800000103oool2000000H0oooo0P0000050?ooo`X0
00000P3oool2000000@0oooo0P0000020?ooo`X000001@3oool2000000H0oooo0P0000040?ooo`80
00000P3oool;0=7=Z@P00000103oool200000080oooo0P0000060?ooo`8000009@3oool200000080
oooo200000020?ooo`/0dLfY0P3oool600000080oooo0P0000020?ooo`H000002@3oool200000080
oooo0P0000080?ooo`8000000P3oool2000000X0oooo1@0000020?ooo`8000000P3oool600000080
oooo2`3AcJT40?ooo`L00000103oool6000000H0oooo0P0000000`3oool00000000000040?ooo`@0
00000P3oool2000000@0oooo1`0000060?ooo`P000000`3oool6000000h0dLfY000<0=7=Z@80oooo
100000020?ooo`D00000103oool6000000@0oooo2@0000060?ooo`T00000103oool6000000@0oooo
1@0000020?ooo`@000000P3oool;0=7=Z@80oooo0P0000040?ooo`8000001P3oool2000000D0oooo
2P0000020?ooo`800000103oool200000080oooo2P0000050?ooo`8000001P3oool2000000@0oooo
0P0000020?ooo`/0dLfY200000040?ooo`8000000P3oool2000000H0oooo0P00000U0?ooo`800000
0P3oool800000080oooo2`3AcJT20?ooo`H000000P3oool200000080oooo1P0000090?ooo`800000
0P3oool2000000P0oooo0P0000020?ooo`8000002P3oool500000080oooo0P0000020?ooo`H00000
0P3oool;0=7=Z@8000000P3oool200000080oooo0P0000030?ooo`H000001P3oool9000000@0oooo
0P0000040?ooo`T000001P3oool6000000@0oooo00<000000?ooo`3oool00P0000020?ooo`800000
3P3AcJT000`0dLfY0P3oool400000080oooo1@0000040?ooo`H00000103oool9000000H0oooo2@00
00040?ooo`H00000103oool500000080oooo100000020?ooo`/0dLfY0P0000040?ooo`8000000P3o
ool600000080oooo1@0000060?ooo`@000000P3oool2000000@0oooo0P0000020?ooo`@000001P3o
ool500000080oooo1P0000020?ooo`800000103oool2000000/0dLfY0P3oool8000000@0oooo1000
00020?ooo`8000000P3oool400000240oooo3P0000020?ooo`/0dLfY403oool500000080oooo0P00
000<0?ooo`@00000303oool200000080oooo1@00000@0?ooo`/0dLfY0P0000020?ooo`8000000P3o
ool2000000<0oooo1P0000060?ooo`T00000103oool2000000@0oooo2@0000060?ooo`H00000103o
ool00`000000oooo0?ooo`0200000080oooo0P00000>0=7=Z@00303AcJT2000000@0oooo70000004
0?ooo`800000103ooolL000000@0oooo0P00000;0=7=Z@800000103oool200000080oooo1P000002
0?ooo`D000001P3oool400000080oooo0P0000040?ooo`8000000P3oool4000000H0oooo1@000002
0?ooo`H000000P3oool2000000@0oooo0P00000;0=7=Z@80oooo200000040?ooo`@000000P3oool2
00000080oooo1000000Q0?ooo`h000000P3oool;0=7=ZA00oooo1@0000020?ooo`800000303oool4
000000`0oooo0P0000020?ooo`D00000403oool;0=7=Z@80oooo100000020?ooo`<000000P3oool4
00000080oooo100000020?ooo`@0000000<0oooo0000000000000P0000020?ooo`@000000P3oool4
00000080oooo0`0000020?ooo`@000000P3oool400000080oooo100000000`3oool0000000000002
00000080oooo0P00000>0=7=Z@00303AcJT2000000@0oooo700000040?ooo`800000103ooolL0000
00@0oooo0P00000;0=7=Z@800000103oool200000080oooo1P0000020?ooo`D000001P3oool40000
0080oooo0P0000040?ooo`8000000P3oool4000000H0oooo1@0000020?ooo`H000000P3oool20000
00@0oooo0P00000;0=7=Z@8000000P3oool600000080oooo100000020?ooo`8000000P3oool20000
0080oooo0P0000020?oooad000000P3oool400000080oooo1P0000040?ooo`/0dLfY0P0000060?oo
o`8000000P3oool400000080oooo1@0000040?ooo`8000000P3oool2000000@0oooo100000040?oo
o`8000000P3oool2000000@0oooo1@0000020?ooo`@000000P3oool2000000H0oooo0P00000;0=7=
Z@80oooo100000020?ooo`<000000P3oool400000080oooo100000020?ooo`@0000000<0oooo0000
000000000P0000020?ooo`@000000P3oool400000080oooo0`0000020?ooo`@000000P3oool40000
0080oooo100000000`3oool000000000000200000080oooo0P00000>0=7=Z@00303AcJT20?ooo`/0
0000103oool6000000@0oooo1@0000020?ooo`8000001P3oool200000080oooo1@0000040?ooo`H0
0000103oool;00000080oooo2`3AcJT20?ooo`8000001P3oool200000080oooo0P0000020?ooo`L0
00000P3oool2000000@0oooo100000040?ooo`@00000103oool200000080oooo1`0000020?ooo`80
00000P3oool2000000H0oooo0P0000020?ooo`/0dLfY0P0000020?ooo`H000000P3oool400000080
oooo0P0000020?ooo`8000000P3oool200000080oooo7@0000020?ooo`@000000P3oool6000000@0
oooo2`3AcJT40?ooo`800000103oool6000000@0oooo1@0000040?ooo`800000403oool2000000@0
oooo1P0000030?ooo`H00000103oool2000000@0oooo2`3AcJT400000080oooo0P0000020?ooo`<0
00001P3oool6000000T0oooo100000020?ooo`@000002@3oool6000000H0oooo100000000`3oool0
0000000000020?ooo`@000003P3AcJT000`0dLfY0P3oool;000000@0oooo1P0000040?ooo`D00000
0P3oool2000000H0oooo0P0000020?ooo`D00000103oool6000000@0oooo2`0000020?ooo`/0dLfY
0P3oool2000000H0oooo0P0000020?ooo`8000000P3oool700000080oooo0P0000040?ooo`@00000
103oool4000000@0oooo0P0000020?ooo`L000000P3oool200000080oooo0P0000060?ooo`800000
0P3oool;0=7=Z@H0oooo0P0000020?ooo`@00000303oool6000001T0oooo100000080?ooo`800000
0P3oool4000000/0dLfY103oool2000000@0oooo1P0000040?ooo`D00000103oool200000100oooo
0P0000040?ooo`H000000`3oool6000000@0oooo0P0000040?ooo`/0dLfY100000020?ooo`800000
0P3oool3000000H0oooo1P0000090?ooo`@000000P3oool4000000T0oooo1P0000060?ooo`@00000
00<0oooo0000000000000P3oool4000000h0dLfY000<0=7=Z@@000000P3oool500000080oooo1000
00020?ooo`8000000P3oool4000001P0oooo100000020?ooo`8000000P3oool400000080oooo1@00
00020?ooo`@000002`3AcJT2000000P0oooo0P0000020?ooo`@000000`3oool600000080oooo1P00
00080?ooo`H000000P3oool6000000<0oooo100000020?ooo`800000203oool2000000/0dLfY1P3o
ool200000080oooo1000000<0?ooo`H000006@3oool4000000P0oooo0P0000020?ooo`@000002`3A
cJT80?ooo`H00000103oool2000000030?ooo`0000000000008000000P3oool200000080oooo1P00
00040?ooo`H000000P3oool200000080oooo100000020?ooo`030000003oool0oooo0080oooo1P00
00080?ooo`/0dLfY0P0000090?ooo`@000001P3oool600000080oooo00<000000?ooo`3oool01000
00040?ooo`8000000P3oool4000000L0oooo1P0000080?ooo`<000000P3oool200000080oooo3P3A
cJT000`0dLfY100000020?ooo`D000000P3oool400000080oooo0P0000020?ooo`@00000603oool4
00000080oooo0P0000020?ooo`@000000P3oool500000080oooo1000000;0=7=Z@800000203oool2
00000080oooo100000030?ooo`H000000P3oool6000000P0oooo1P0000020?ooo`H000000`3oool4
00000080oooo0P0000080?ooo`8000002`3AcJT20?ooo`H000000P3oool200000080oooo10000002
0?ooo`8000002P3oool2000001D0oooo0P0000020?ooo`@000000P3oool600000080oooo1000000;
0=7=Z@P0oooo1P0000040?ooo`80000000<0oooo0000000000000P0000020?ooo`8000000P3oool6
000000@0oooo1P0000020?ooo`8000000P3oool400000080oooo00<000000?ooo`3oool00P3oool6
000000P0oooo2`3AcJT2000000T0oooo100000060?ooo`H000000P3oool00`000000oooo0?ooo`04
000000@0oooo0P0000020?ooo`@000001`3oool6000000P0oooo0`0000020?ooo`8000000P3oool>
0=7=Z@00303AcJT2000000/0oooo100000020?ooo`8000000P3oool700000080oooo0P0000020?oo
o`H000000P3oool2000000<0oooo1P0000020?ooo`8000000P3oool4000000/0oooo0P00000;0=7=
Z@80oooo1P0000020?ooo`@000000P3oool2000000D0oooo100000020?ooo`800000103oool80000
00@0oooo0P0000020?ooo`@000001@3oool200000080oooo100000020?ooo`H000000P3oool;0=7=
Z@80oooo1P0000020?ooo`8000000P3oool400000080oooo0P00000:0?ooo`8000005@3oool20000
0080oooo100000020?ooo`H000000P3oool4000000/0dLfY100000040?ooo`@000000P3oool20000
00T0oooo0P0000040?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`800000103oool20000
00T0oooo0P0000020?ooo`@00000103oool4000000/0dLfY1P0000020?ooo`<000000P3oool20000
0080oooo100000020?ooo`H0000000<0oooo0000000000000P0000020?ooo`8000000P3oool20000
0080oooo100000000`3oool000000000000400000080oooo100000020?ooo`8000000P3oool30000
0080oooo1P00000>0=7=Z@00303AcJT2000000/0oooo100000020?ooo`8000000P3oool700000080
oooo0P0000020?ooo`H000000P3oool2000000<0oooo1P0000020?ooo`8000000P3oool4000000/0
oooo0P00000;0=7=Z@80oooo1P0000020?ooo`@000000P3oool2000000D0oooo100000020?ooo`80
0000103oool8000000@0oooo0P0000020?ooo`@000001@3oool200000080oooo100000020?ooo`H0
00000P3oool;0=7=Z@80oooo0P0000040?ooo`@000000P3oool6000000@0oooo0P0000040?ooo`80
0000103ooolA000000P0oooo1P0000040?ooo`800000103oool;0=7=Z@@00000103oool400000080
oooo0P0000090?ooo`800000103oool200000080oooo0P0000040?ooo`8000000P3oool2000000@0
oooo0P0000090?ooo`8000000P3oool4000000@0oooo1000000;0=7=Z@H000000P3oool300000080
oooo0P0000020?ooo`@000000P3oool6000000030?ooo`0000000000008000000P3oool200000080
oooo0P0000020?ooo`@0000000<0oooo000000000000100000020?ooo`@000000P3oool200000080
oooo0`0000020?ooo`H000003P3AcJT000`0dLfY1P00000;0?ooo`H000000P3oool700000080oooo
100000020?ooo`@000000P3oool700000080oooo1P00000;0?ooo`H000002`3AcJT400000080oooo
100000020?ooo`8000000P3oool2000000<0oooo0P0000040?ooo`X00000103oool:000000@0oooo
0P0000030?ooo`8000000P3oool200000080oooo100000020?ooo`@000002`3AcJT20?ooo`800000
103oool400000080oooo1P0000040?ooo`800000103oool2000000@0oooo4@0000080?ooo`H00000
103oool2000000@0oooo2`3AcJT400000100oooo00<000000?ooo`3oool00P0000020?ooo`800000
0P3oool200000080oooo0P0000040?ooo`8000000P3oool200000080oooo0P0000020?ooo`800000
0P3oool2000000l0oooo1000000;0=7=Z@@0oooo1`0000020?ooo`P00000103oool4000000030?oo
o`000000000000H0oooo1P0000040?ooo`<000000P3oool2000000H0oooo0P0000020?ooo`@00000
0`3oool6000000h0dLfY000<0=7=Z@H000002`3oool600000080oooo1`0000020?ooo`@000000P3o
ool400000080oooo1`0000020?ooo`H000002`3oool6000000/0dLfY100000020?ooo`@000000P3o
ool200000080oooo0P0000030?ooo`800000103oool:000000@0oooo2P0000040?ooo`8000000`3o
ool200000080oooo0P0000020?ooo`@000000P3oool4000000/0dLfY0P3oool800000080oooo0P00
00020?ooo`H000002P3oool200000080oooo0P00000=0?ooo`800000103oool4000000H0oooo1000
00020?ooo`8000000P3oool;0=7=Z@@00000403oool00`000000oooo0?ooo`0200000080oooo0P00
00020?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`8000000P3oool200000080oooo0P00
00020?ooo`8000003`3oool4000000/0dLfY103oool700000080oooo200000040?ooo`@0000000<0
oooo0000000000001P3oool6000000@0oooo0`0000020?ooo`8000001P3oool200000080oooo1000
00030?ooo`H000003P3AcJT000`0dLfY1P00000;0?ooo`H000000P3oool700000080oooo10000002
0?ooo`@000000P3oool700000080oooo1P00000;0?ooo`H000002`3AcJT2000000H0oooo0P000002
0?ooo`T000000P3oool8000000H0oooo100000060?ooo`P000000P3oool900000080oooo0P000006
0?ooo`8000002`3AcJT20?ooo`P000000P3oool200000080oooo1P00000:0?ooo`8000000P3oool2
000000d0oooo0P0000040?ooo`@000001P3oool400000080oooo0P0000020?ooo`/0dLfY1P3oool2
000000@0oooo0P0000020?ooo`8000000`3oool2000000H0oooo200000040?ooo`P000001P3oool2
000000<0oooo0P0000020?ooo`800000103oool2000000H0oooo2`3AcJT20?ooo`800000103oool2
000000030?ooo`000000000000@0oooo0P0000040?ooo`800000103ooolD000000@0oooo0P000004
0?ooo`800000103oool200000080oooo00<000000?ooo`3oool00P3oool200000080oooo3P3AcJT0
00`0dLfY103oool200000080oooo1@0000020?ooo`P00000103oool500000080oooo0P0000060?oo
o`8000000P3oool5000000@0oooo200000020?ooo`D000000P3oool2000000@0oooo2`3AcJT20000
00H0oooo0P0000020?ooo`T000000P3oool8000000H0oooo100000060?ooo`P000000P3oool90000
0080oooo0P0000060?ooo`8000002`3AcJTB0?ooo`@00000103oool600000080oooo1P0000090?oo
o`@00000103oool600000080oooo1P0000060?ooo`/0dLfY1P3oool2000000@0oooo0P0000020?oo
o`8000000`3oool2000000H0oooo200000040?ooo`P000001P3oool2000000<0oooo0P0000020?oo
o`800000103oool2000000H0oooo2`3AcJT40?ooo`H000000`3oool8000000@0oooo1`0000060?oo
o`H000001@3oool200000080oooo0P0000060?ooo`8000000P3oool2000000D0oooo1P00000>0=7=
Z@00303AcJT40?ooo`8000000P3oool500000080oooo200000040?ooo`D000000P3oool2000000H0
oooo0P0000020?ooo`D00000103oool800000080oooo1@0000020?ooo`800000103oool;0=7=Z@`0
0000103oool500000080oooo0P0000020?ooo`8000000P3oool200000080oooo200000020?ooo`80
00000P3oool200000080oooo0P0000020?ooo`D00000103oool<000000/0dLfY4P3oool4000000@0
oooo1P0000020?ooo`H000002@3oool4000000@0oooo1P0000020?ooo`H000001P3oool;0=7=Z@h0
oooo0P0000040?ooo`030000003oool0oooo00X00000303oool:00000080oooo0P0000030?ooo`80
00003P3oool;0=7=Z@@0oooo1P0000030?ooo`P00000103oool7000000H0oooo1P0000050?ooo`80
00000P3oool2000000H0oooo0P0000020?ooo`8000001@3oool6000000h0dLfY000<0=7=Z@80oooo
4`0000040?ooo`8000001@3oool>000000D0oooo0P0000040?oooa<000000P3oool;0=7=Z@`00000
103oool500000080oooo0P0000020?ooo`8000000P3oool200000080oooo200000020?ooo`800000
0P3oool200000080oooo0P0000020?ooo`D00000103oool<000000/0dLfY0P0000080?ooo`800000
0P3oool4000000P0oooo0P0000020?ooo`8000000P3oool6000000030?ooo`000000000000@00000
0P3oool2000000P0oooo2P0000060?ooo`8000002`3AcJT>0?ooo`800000103oool00`000000oooo
0?ooo`0:000000`0oooo2P0000020?ooo`8000000`3oool2000000h0oooo2`3AcJT6000000D0oooo
100000020?ooo`@000000P3oool400000080oooo00<000000?ooo`3oool00P0000020?ooo`800000
0P3oool200000080oooo0P0000020?ooo`030000003oool0oooo00@000000P3oool400000080oooo
100000050?ooo`H000003P3AcJT000`0dLfY0P3ooolC000000@0oooo0P0000050?ooo`h000001@3o
ool2000000@0oooo4`0000020?ooo`/0dLfY203oool8000000D0oooo100000020?ooo`800000103o
ool<000000@0oooo0P0000020?ooo`@000001@3oool8000000P0oooo2`3AcJT2000000P0oooo0P00
00020?ooo`@00000203oool200000080oooo0P0000020?ooo`H0000000<0oooo0000000000001000
00020?ooo`800000203oool:000000H0oooo0P00000;0=7=Z@H000000P3oool600000080oooo0P00
00050?ooo`800000103oool200000080oooo0P0000020?ooo`@000000P3oool200000080oooo0P00
00040?ooo`8000001@3oool200000080oooo1P0000020?ooo`H000002`3AcJT6000000D0oooo1000
00020?ooo`@000000P3oool400000080oooo00<000000?ooo`3oool00P0000020?ooo`8000000P3o
ool200000080oooo0P0000020?ooo`030000003oool0oooo00@000000P3oool400000080oooo1000
00050?ooo`H000003P3AcJT000`0dLfY0P3oool400000080oooo1@0000020?ooo`@000000P3oool2
000000@0oooo2@0000060?ooo`T00000103oool200000080oooo100000020?ooo`D000000P3oool4
00000080oooo2`3AcJT80?ooo`P000001@3oool400000080oooo0P0000040?ooo``00000103oool2
00000080oooo100000050?ooo`P00000203oool;0=7=Z@@0oooo100000040?ooo`P000000P3oool2
00000080oooo0P0000020?ooo`@000000P3oool200000080oooo0`0000020?ooo`h000000P3oool2
00000080oooo0P0000020?ooo`@00000103oool;0=7=Z@H000000P3oool600000080oooo0P000005
0?ooo`800000103oool200000080oooo0P0000020?ooo`@000000P3oool200000080oooo0P000004
0?ooo`8000001@3oool200000080oooo1P0000020?ooo`H000002`3AcJT2000000@0oooo0P000003
0?ooo`800000203oool4000000@0oooo00<000000?ooo`3oool00P3oool2000000@0oooo0P000004
0?ooo`8000000`3oool200000080oooo1P0000020?ooo`800000103oool00`000000oooo0?ooo`02
0?ooo`8000000P3oool>0=7=Z@00303AcJT20?ooo`@000000P3oool500000080oooo100000020?oo
o`800000103oool9000000H0oooo2@0000040?ooo`8000000P3oool400000080oooo1@0000020?oo
o`@000000P3oool;0=7=Z@H0oooo0P0000020?ooo`8000000P3oool900000080oooo100000020?oo
oa0000000P3oool400000080oooo2@0000020?ooo`8000000P3oool2000000H0oooo2`3AcJT40?oo
o`@00000103oool800000080oooo0P0000020?ooo`8000000P3oool400000080oooo0P0000020?oo
o`<000000P3oool>00000080oooo0P0000020?ooo`8000000P3oool4000000@0oooo2`3AcJT20000
0080oooo1P0000020?ooo`8000002@3oool8000000@0oooo200000040?ooo`P000002@3oool20000
0080oooo1P0000020?ooo`8000002`3AcJT2000000@0oooo0P0000030?ooo`800000203oool40000
00@0oooo00<000000?ooo`3oool00P3oool2000000@0oooo0P0000040?ooo`8000000`3oool20000
0080oooo1P0000020?ooo`800000103oool00`000000oooo0?ooo`020?ooo`8000000P3oool>0=7=
Z@00303AcJTI0?ooo`D000000P3oool200000080oooo0P0000020?ooo`8000000P3oool2000000<0
oooo1000000I0?ooo`/0dLfY1P3oool200000080oooo0P0000020?ooo`T000000P3oool400000080
oooo400000020?ooo`@000000P3oool900000080oooo0P0000020?ooo`8000001P3oool;0=7=Z@@0
oooo100000020?ooo``000000P3oool600000080oooo0P0000020?ooo`8000000P3oool00`000000
oooo0?ooo`060?ooo`8000001P3oool200000080oooo0P0000020?ooo`8000000P3oool4000000@0
oooo2`3AcJT200000080oooo1P0000020?ooo`8000002@3oool8000000@0oooo200000040?ooo`P0
00002@3oool200000080oooo1P0000020?ooo`8000002`3AcJT6000000D0oooo1P0000020?ooo`@0
00000P3oool200000080oooo00<000000?ooo`3oool00P0000020?ooo`8000000P3oool200000080
oooo0P0000020?ooo`030000003oool0oooo008000000P3oool400000080oooo1P0000050?ooo`H0
00003P3AcJT000`0dLfY6@3oool500000080oooo0P0000020?ooo`8000000P3oool200000080oooo
0P0000030?ooo`@000006@3oool;0=7=Z@@000001P3oool2000000d0oooo0P0000020?oooa@00000
0P3oool2000000d0oooo0P0000060?ooo`@000002`3AcJT40?ooo`@000000P3oool<00000080oooo
1P0000020?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool01P3oool2000000H0oooo
0P0000020?ooo`8000000P3oool200000080oooo100000040?ooo`/0dLfY0P00000:0?ooo`800000
103oool3000000`0oooo3000000<0?ooo`<00000103oool2000000X0oooo0P00000;0=7=Z@H00000
1@3oool600000080oooo100000020?ooo`8000000P3oool00`000000oooo0?ooo`0200000080oooo
0P0000020?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00P0000020?ooo`@00000
0P3oool6000000D0oooo1P00000>0=7=Z@00303AcJT2000000@0oooo0P0000050?ooo`800000103o
ool2000000@0oooo0P0000050?ooo`800000103oool2000000@0oooo0P0000050?ooo`800000103o
ool2000000@0oooo0P0000050?ooo`800000103oool2000000/0dLfY100000060?ooo`8000003@3o
ool200000080oooo500000020?ooo`8000003@3oool2000000H0oooo1000000;0=7=Z@8000001P3o
ool>00000080oooo1P0000020?ooo`d000000P3oool600000080oooo3P0000060?ooo`8000002`3A
cJT2000000X0oooo0P0000040?ooo`<00000303oool<000000`0oooo0`0000040?ooo`8000002P3o
ool2000000/0dLfY103oool6000000D0oooo1P0000060?ooo`D000001P3oool6000000D0oooo1P00
00060?ooo`H000001@3oool6000000h0dLfY000<0=7=Z@800000103oool2000000D0oooo0P000004
0?ooo`800000103oool2000000D0oooo0P0000040?ooo`800000103oool2000000D0oooo0P000004
0?ooo`800000103oool2000000D0oooo0P0000040?ooo`8000002`3AcJT4000000H0oooo0P00000=
0?ooo`8000000P3ooolD00000080oooo0P00000=0?ooo`8000001P3oool4000000/0dLfY0P000006
0?ooo`h000000P3oool600000080oooo3@0000020?ooo`H000000P3oool>000000H0oooo0P00000;
0=7=Z@8000002P3oool2000000@0oooo0`00000<0?ooo``00000303oool3000000@0oooo0P00000:
0?ooo`8000002`3AcJT40?ooo`H000001@3oool6000000H0oooo1@0000060?ooo`H000001@3oool6
000000H0oooo1P0000050?ooo`H000003P3AcJT000`0dLfY6@3oool500000080oooo0P0000020?oo
o`8000000P3oool200000080oooo0P0000030?ooo`@000006@3oool;0=7=Z@@000001P3oool20000
00d0oooo0P0000020?oooa@000000P3oool2000000d0oooo0P0000060?ooo`@000002`3AcJT60?oo
o`h000000P3oool200000080oooo0P0000020?ooo`800000103oool200000080oooo00<000000?oo
o`3oool0400000020?ooo`8000000P3oool6000000H0oooo2`3AcJT2000000X0oooo0P0000040?oo
o`<00000303oool<000000`0oooo0`0000040?ooo`8000002P3oool2000000/0dLfY0P3oool20000
00@0oooo0P0000030?ooo`8000001P3ooolT000000H0oooo0P0000040?ooo`030000003oool0oooo
0080oooo0P0000020?ooo`h0dLfY000<0=7=ZAT0oooo1@0000020?ooo`8000000P3oool200000080
oooo0P0000020?ooo`8000000`3oool4000001T0oooo2`3AcJT60?ooo`8000000P3oool200000080
oooo2@0000020?ooo`@000000P3oool@00000080oooo100000020?ooo`T000000P3oool200000080
oooo0P0000060?ooo`/0dLfY1P3oool>00000080oooo0P0000020?ooo`8000000P3oool2000000@0
oooo0P0000020?ooo`030000003oool0oooo010000000P3oool200000080oooo1P0000060?ooo`/0
dLfY0P0000020?ooo`H000000P3oool2000000T0oooo200000040?ooo`P00000103oool8000000T0
oooo0P0000020?ooo`H000000P3oool2000000/0dLfY0P3oool2000000@0oooo0P0000030?ooo`80
00001P3ooolT000000H0oooo0P0000040?ooo`030000003oool0oooo0080oooo0P0000020?ooo`h0
dLfY000<0=7=Z@80oooo100000020?ooo`D000000P3oool400000080oooo0P0000040?ooo`T00000
1P3oool9000000@0oooo0P0000020?ooo`@000000P3oool500000080oooo100000020?ooo`/0dLfY
1P3oool200000080oooo0P0000020?ooo`T000000P3oool400000080oooo400000020?ooo`@00000
0P3oool900000080oooo0P0000020?ooo`8000001P3oool;0=7=Z@80oooo0P0000020?ooo``00000
203oool2000000@0oooo1P0000020?ooo`030000003oool0oooo00@0oooo1P0000020?ooo`800000
103oool2000000@0oooo100000020?ooo`8000000P3oool;0=7=Z@8000000P3oool600000080oooo
0P0000090?ooo`P00000103oool8000000@0oooo200000090?ooo`8000000P3oool600000080oooo
0P00000;0=7=Z@@0oooo1P0000050?ooo`8000000P3oool4000000@0oooo1@0000060?ooo`H00000
1@3oool800000080oooo200000050?ooo`H000003P3AcJT000`0dLfY0P3oool400000080oooo1@00
00020?ooo`@000000P3oool2000000@0oooo2@0000060?ooo`T00000103oool200000080oooo1000
00020?ooo`D000000P3oool400000080oooo2`3AcJT80?ooo`P000001@3oool400000080oooo0P00
00040?ooo``00000103oool200000080oooo100000050?ooo`P00000203oool;0=7=Z@80oooo0P00
00020?ooo``00000203oool2000000@0oooo1P0000020?ooo`030000003oool0oooo00@0oooo1P00
00020?ooo`800000103oool2000000@0oooo100000020?ooo`8000000P3oool;0=7=Z@H000000P3o
ool600000080oooo0P0000050?ooo`800000103oool200000080oooo0P0000020?ooo`@000000P3o
ool200000080oooo0P0000040?ooo`8000001@3oool200000080oooo1P0000020?ooo`H000002`3A
cJT40?ooo`H000001@3oool200000080oooo100000040?ooo`D000001P3oool6000000D0oooo2000
00020?ooo`P000001@3oool6000000h0dLfY000<0=7=Z@80oooo4`0000040?ooo`8000001@3oool>
000000D0oooo0P0000040?oooa<000000P3oool;0=7=Z@P0oooo200000050?ooo`@000000P3oool2
000000@0oooo300000040?ooo`8000000P3oool4000000D0oooo200000080?ooo`/0dLfY103oool2
00000080oooo200000020?ooo`@00000103oool200000080oooo100000040?ooo`<00000103oool2
00000080oooo0P0000040?ooo`@000000P3oool200000080oooo0P0000040?ooo`800000103oool;
0=7=Z@H000000P3oool600000080oooo0P0000050?ooo`800000103oool200000080oooo0P000002
0?ooo`@000000P3oool200000080oooo0P0000040?ooo`8000001@3oool200000080oooo1P000002
0?ooo`H000002`3AcJT6000000D0oooo100000020?ooo`@000000P3oool400000080oooo00<00000
0?ooo`3oool00P0000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`030000003oool0
oooo00@000000P3oool400000080oooo100000050?ooo`H000003P3AcJT000`0dLfY0P3ooolC0000
00@0oooo0P0000050?ooo`h000001@3oool2000000@0oooo4`0000020?ooo`/0dLfY300000040?oo
o`D000000P3oool200000080oooo0P0000020?ooo`8000000P3oool800000080oooo0P0000020?oo
o`8000000P3oool200000080oooo1@0000040?ooo``000002`3AcJT40?ooo`8000000P3oool80000
0080oooo100000040?ooo`8000000P3oool4000000@0oooo0`0000040?ooo`8000000P3oool20000
00@0oooo100000020?ooo`8000000P3oool2000000@0oooo0P0000040?ooo`/0dLfY3P3oool20000
00@0oooo00<000000?ooo`3oool02P00000<0?ooo`X000000P3oool2000000<0oooo0P00000>0?oo
o`/0dLfY1P0000050?ooo`@000000P3oool400000080oooo100000020?ooo`030000003oool0oooo
008000000P3oool200000080oooo0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`040000
0080oooo100000020?ooo`@000001@3oool6000000h0dLfY000<0=7=Z@@0oooo0P0000020?ooo`D0
00000P3oool8000000@0oooo1@0000020?ooo`8000001P3oool200000080oooo1@0000040?ooo`P0
00000P3oool500000080oooo0P0000040?ooo`/0dLfY300000040?ooo`D000000P3oool200000080
oooo0P0000020?ooo`8000000P3oool800000080oooo0P0000020?ooo`8000000P3oool200000080
oooo1@0000040?ooo``000002`3AcJT4000000H0oooo100000040?ooo`@00000103oool600000080
oooo1P0000090?ooo`@00000103oool800000080oooo100000020?ooo`@000002`3AcJT>0?ooo`80
0000103oool00`000000oooo0?ooo`0:000000`0oooo2P0000020?ooo`8000000`3oool2000000h0
oooo2`3AcJT2000000@0oooo0P0000030?ooo`@000000P3oool2000000@0oooo100000020?ooo`03
0000003oool0oooo0080oooo0P0000040?ooo`800000103oool2000000T0oooo0P00000:0?ooo`03
0000003oool0oooo0080oooo0P0000020?ooo`h0dLfY000<0=7=Z@@0oooo0P0000020?ooo`D00000
0P3oool8000000@0oooo1@0000020?ooo`8000001P3oool200000080oooo1@0000040?ooo`P00000
0P3oool500000080oooo0P0000040?ooo`/0dLfY0P0000060?ooo`8000000P3oool900000080oooo
200000060?ooo`@000001P3oool800000080oooo2@0000020?ooo`8000001P3oool2000000/0dLfY
100000060?ooo`@00000103oool4000000@0oooo1P0000020?ooo`H000002@3oool4000000@0oooo
200000020?ooo`@000000P3oool4000000/0dLfY1P3oool2000000@0oooo0P0000020?ooo`800000
0`3oool2000000H0oooo200000040?ooo`P000001P3oool2000000<0oooo0P0000020?ooo`800000
103oool2000000H0oooo2`3AcJT2000000@0oooo0P0000030?ooo`@000000P3oool2000000@0oooo
100000020?ooo`030000003oool0oooo0080oooo0P0000040?ooo`800000103oool2000000T0oooo
0P00000:0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`h0dLfY000<0=7=Z@H000002`3o
ool600000080oooo1`0000020?ooo`@000000P3oool400000080oooo1`0000020?ooo`H000002`3o
ool6000000/0dLfY0P0000060?ooo`8000000P3oool900000080oooo200000060?ooo`@000001P3o
ool800000080oooo2@0000020?ooo`8000001P3oool2000000/0dLfY2P0000040?ooo`8000004P3o
ool2000000@0oooo1@0000060?ooo`8000000P3oool2000000@0oooo100000020?ooo`@000000P3o
ool4000000/0dLfY1P3oool2000000@0oooo0P0000020?ooo`8000000`3oool2000000H0oooo2000
00040?ooo`P000001P3oool2000000<0oooo0P0000020?ooo`800000103oool2000000H0oooo2`3A
cJT6000000T0oooo1P0000060?ooo`<000000P3oool200000080oooo0P0000020?ooo`8000000P3o
ool200000080oooo0`0000060?ooo`H000002@3oool6000000h0dLfY000<0=7=Z@H000002`3oool6
00000080oooo1`0000020?ooo`@000000P3oool400000080oooo1`0000020?ooo`H000002`3oool6
000000/0dLfY100000020?ooo`@000000P3oool200000080oooo0P0000030?ooo`800000103oool:
000000@0oooo2P0000040?ooo`8000000`3oool200000080oooo0P0000020?ooo`@000000P3oool4
000000/0dLfY2P0000040?ooo`8000004P3oool2000000@0oooo1@0000060?ooo`8000000P3oool2
000000@0oooo100000020?ooo`@000000P3oool4000000/0dLfY1000000@0?ooo`030000003oool0
oooo008000000P3oool200000080oooo0P0000020?ooo`800000103oool200000080oooo0P000002
0?ooo`8000000P3oool200000080oooo0P00000?0?ooo`@000002`3AcJT40?ooo`L000000P3oool8
000000@0oooo100000000`3oool00000000000060?ooo`H00000103oool300000080oooo0P000006
0?ooo`8000000P3oool4000000<0oooo1P00000>0=7=Z@00303AcJT6000000/0oooo1P0000020?oo
o`L000000P3oool400000080oooo100000020?ooo`L000000P3oool6000000/0oooo1P00000;0=7=
Z@@000000P3oool400000080oooo0P0000020?ooo`8000000`3oool2000000@0oooo2P0000040?oo
o`X00000103oool2000000<0oooo0P0000020?ooo`8000000P3oool400000080oooo1000000;0=7=
Z@80oooo0P0000040?ooo`H00000203oool4000000P0oooo1`0000020?ooo`8000000P3oool80000
0080oooo100000040?ooo`800000103oool2000000@0oooo2`3AcJT400000100oooo00<000000?oo
o`3oool00P0000020?ooo`8000000P3oool200000080oooo0P0000040?ooo`8000000P3oool20000
0080oooo0P0000020?ooo`8000000P3oool2000000l0oooo1000000;0=7=Z@@0oooo1`0000020?oo
o`P00000103oool4000000030?ooo`000000000000H0oooo1P0000040?ooo`<000000P3oool20000
00H0oooo0P0000020?ooo`@000000`3oool6000000h0dLfY000<0=7=Z@8000002`3oool400000080
oooo0P0000020?ooo`L000000P3oool200000080oooo1P0000020?ooo`8000000`3oool600000080
oooo0P0000020?ooo`@000002`3oool2000000/0dLfY0P3oool600000080oooo100000020?ooo`80
00001@3oool400000080oooo0P0000040?ooo`P00000103oool200000080oooo100000050?ooo`80
00000P3oool400000080oooo1P0000020?ooo`/0dLfY0P3oool2000000@0oooo1P0000080?ooo`@0
0000203oool700000080oooo0P0000020?ooo`P000000P3oool4000000@0oooo0P0000040?ooo`80
0000103oool;0=7=Z@@00000103oool400000080oooo0P0000090?ooo`800000103oool200000080
oooo0P0000040?ooo`8000000P3oool2000000@0oooo0P0000090?ooo`8000000P3oool4000000@0
oooo1000000;0=7=Z@80oooo0P0000060?ooo`T000001P3oool2000000D0oooo3P0000050?ooo`80
00001P3oool:000000D0oooo0P0000020?ooo`h0dLfY000<0=7=Z@8000002`3oool400000080oooo
0P0000020?ooo`L000000P3oool200000080oooo1P0000020?ooo`8000000`3oool600000080oooo
0P0000020?ooo`@000002`3oool2000000/0dLfY0P3oool600000080oooo100000020?ooo`800000
1@3oool400000080oooo0P0000040?ooo`P00000103oool200000080oooo100000050?ooo`800000
0P3oool400000080oooo1P0000020?ooo`/0dLfY200000040?ooo`P000000P3oool400000080oooo
1000000;0?ooo`H000000P3oool400000080oooo200000020?ooo`@000000P3oool200000080oooo
2`3AcJT4000000@0oooo100000020?ooo`8000002@3oool2000000@0oooo0P0000020?ooo`800000
103oool200000080oooo0P0000040?ooo`8000002@3oool200000080oooo100000040?ooo`@00000
2`3AcJT20?ooo`8000001P3oool9000000H0oooo0P0000050?ooo`h000001@3oool2000000H0oooo
2P0000050?ooo`8000000P3oool>0=7=Z@00303AcJT400000080oooo1@0000020?ooo`@000000P3o
ool200000080oooo1000000H0?ooo`@000000P3oool200000080oooo100000020?ooo`D000000P3o
ool4000000/0dLfY0P0000080?ooo`8000000P3oool4000000<0oooo1P0000020?ooo`H00000203o
ool600000080oooo1P0000030?ooo`@000000P3oool2000000P0oooo0P00000;0=7=Z@P00000103o
ool800000080oooo100000020?ooo`@000002`3oool600000080oooo100000020?ooo`P000000P3o
ool400000080oooo0P0000020?ooo`/0dLfY203oool6000000@0oooo0P0000000`3oool000000000
000200000080oooo0P0000020?ooo`H00000103oool600000080oooo0P0000020?ooo`@000000P3o
ool00`000000oooo0?ooo`020?ooo`H00000203oool;0=7=Z@@0oooo0P0000020?ooo`8000000`3o
ool400000080oooo100000020?ooo`T00000103oool8000000<0oooo0P0000020?ooo`@000000P3o
ool400000080oooo0P0000030?ooo`P000003P3AcJT000`0dLfY100000020?ooo`D000000P3oool4
00000080oooo0P0000020?ooo`@00000603oool400000080oooo0P0000020?ooo`@000000P3oool5
00000080oooo1000000;0=7=Z@800000203oool200000080oooo100000030?ooo`H000000P3oool6
000000P0oooo1P0000020?ooo`H000000`3oool400000080oooo0P0000080?ooo`8000002`3AcJT4
00000080oooo1P0000060?ooo`@00000103oool6000001L0oooo0P0000020?ooo`8000000P3oool2
00000080oooo100000060?ooo`/0dLfY203oool6000000@0oooo0P0000000`3oool0000000000002
00000080oooo0P0000020?ooo`H00000103oool600000080oooo0P0000020?ooo`@000000P3oool0
0`000000oooo0?ooo`020?ooo`H00000203oool;0=7=Z@@0oooo0P0000020?ooo`8000000`3oool4
00000080oooo100000020?ooo`T00000103oool8000000<0oooo0P0000020?ooo`@000000P3oool4
00000080oooo0P0000030?ooo`P000003P3AcJT000`0dLfY0P3oool;000000@0oooo1P0000040?oo
o`D000000P3oool2000000H0oooo0P0000020?ooo`D00000103oool6000000@0oooo2`0000020?oo
o`/0dLfY0P3oool2000000H0oooo0P0000020?ooo`8000000P3oool700000080oooo0P0000040?oo
o`@00000103oool4000000@0oooo0P0000020?ooo`L000000P3oool200000080oooo0P0000060?oo
o`8000000P3oool;0=7=Z@@000000P3oool6000000H0oooo100000040?ooo`H000005`3oool20000
0080oooo0P0000020?ooo`8000000P3oool4000000H0oooo2`3AcJT40?ooo`800000103oool60000
00@0oooo1@0000040?ooo`800000403oool2000000@0oooo1P0000030?ooo`H00000103oool20000
00@0oooo2`3AcJT400000080oooo0P0000020?ooo`<000001P3oool6000000T0oooo100000020?oo
o`@000002@3oool6000000H0oooo100000000`3oool00000000000020?ooo`@000003P3AcJT000`0
dLfY0P3oool;000000@0oooo1P0000040?ooo`D000000P3oool2000000H0oooo0P0000020?ooo`D0
0000103oool6000000@0oooo2`0000020?ooo`/0dLfY0P3oool2000000H0oooo0P0000020?ooo`80
00000P3oool700000080oooo0P0000040?ooo`@00000103oool4000000@0oooo0P0000020?ooo`L0
00000P3oool200000080oooo0P0000060?ooo`8000000P3oool;0=7=Z@X0oooo100000020?ooo`80
00000P3oool:000000@0oooo2@0000060?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`@0
0000203oool2000000/0dLfY103oool2000000@0oooo1P0000040?ooo`D00000103oool200000100
oooo0P0000040?ooo`H000000`3oool6000000@0oooo0P0000040?ooo`/0dLfY100000020?ooo`80
00000P3oool3000000H0oooo1P0000090?ooo`@000000P3oool4000000T0oooo1P0000060?ooo`@0
000000<0oooo0000000000000P3oool4000000h0dLfY000<0=7=Z@800000103ooolL000000@0oooo
0P0000040?oooa`00000103oool2000000/0dLfY0P0000040?ooo`8000000P3oool600000080oooo
1@0000060?ooo`@000000P3oool2000000@0oooo0P0000020?ooo`@000001P3oool500000080oooo
1P0000020?ooo`800000103oool2000000/0dLfY2P3oool400000080oooo0P0000020?ooo`X00000
103oool9000000H0oooo0P0000020?ooo`800000103oool200000080oooo100000080?ooo`800000
2`3AcJT2000000H0oooo0P0000020?ooo`@000000P3oool5000000@0oooo0P0000020?ooo`800000
103oool4000000@0oooo0P0000020?ooo`800000103oool500000080oooo100000020?ooo`800000
1P3oool2000000/0dLfY100000060?ooo`D000001P3oool6000000D0oooo1P0000060?ooo`D00000
1P3oool6000000H0oooo1@0000060?ooo`h0dLfY000<0=7=Z@800000103ooolL000000@0oooo0P00
00040?oooa`00000103oool2000000/0dLfY0P0000040?ooo`8000000P3oool600000080oooo1@00
00060?ooo`@000000P3oool2000000@0oooo0P0000020?ooo`@000001P3oool500000080oooo1P00
00020?ooo`800000103oool2000000/0dLfY103oool200000080oooo0P0000020?ooo`@000002P3o
ool200000080oooo0P0000020?ooo`8000001@3oool200000080oooo0P0000040?ooo`8000000P3o
ool200000080oooo100000020?ooo`@000000P3oool2000000@0oooo2`3AcJT2000000H0oooo0P00
00020?ooo`@000000P3oool5000000@0oooo0P0000020?ooo`800000103oool4000000@0oooo0P00
00020?ooo`800000103oool500000080oooo100000020?ooo`8000001P3oool2000000/0dLfY1000
00060?ooo`D000001P3oool6000000D0oooo1P0000060?ooo`D000001P3oool6000000H0oooo1@00
00060?ooo`h0dLfY000<0=7=Z@80oooo100000020?ooo`D00000103oool6000000@0oooo2@000006
0?ooo`T00000103oool6000000@0oooo1@0000020?ooo`@000000P3oool;0=7=Z@800000103oool2
00000080oooo1P0000020?ooo`D000001P3oool400000080oooo0P0000040?ooo`8000000P3oool4
000000H0oooo1@0000020?ooo`H000000P3oool2000000@0oooo0P00000;0=7=Z@@0oooo0P000002
0?ooo`8000000P3oool4000000X0oooo0P0000020?ooo`8000000P3oool2000000D0oooo0P000002
0?ooo`800000103oool200000080oooo0P0000020?ooo`@000000P3oool400000080oooo0P000004
0?ooo`/0dLfY403oool500000080oooo0P00000<0?ooo`@00000303oool200000080oooo1@00000@
0?ooo`/0dLfY2`3oool400000080oooo100000020?ooo`@000000P3oool00`000000oooo0?ooo`04
000000H0oooo100000020?ooo`030000003oool0oooo00@000000P3oool400000080oooo1000000;
0?ooo`h0dLfY000<0=7=Z@80oooo100000020?ooo`D00000103oool6000000@0oooo2@0000060?oo
o`T00000103oool6000000@0oooo1@0000020?ooo`@000000P3oool;0=7=Z@80oooo0P0000040?oo
o`8000001P3oool2000000D0oooo2P0000020?ooo`800000103oool200000080oooo2P0000050?oo
o`8000001P3oool2000000@0oooo0P0000020?ooo`/0dLfY0P0000040?ooo`8000001P3oool60000
00@0oooo100000040?ooo`H000000P3oool5000000@0oooo0P0000060?ooo`8000000P3oool20000
00@0oooo100000060?ooo`/0dLfY0P3oool600000080oooo0P0000020?ooo`H000002@3oool20000
0080oooo0P0000080?ooo`8000000P3oool2000000X0oooo1@0000020?ooo`8000000P3oool60000
0080oooo2`3AcJT;0?ooo`@000000P3oool400000080oooo100000020?ooo`030000003oool0oooo
00@000001P3oool400000080oooo00<000000?ooo`3oool0100000020?ooo`@000000P3oool40000
00/0oooo3P3AcJT000`0dLfY1P0000070?ooo`@000000P3oool200000080oooo100000030?ooo`H0
00001P3oool700000080oooo100000020?ooo`8000000P3oool4000000L0oooo1P00000;0=7=Z@80
oooo0P0000040?ooo`8000001P3oool2000000D0oooo2P0000020?ooo`800000103oool200000080
oooo2P0000050?ooo`8000001P3oool2000000@0oooo0P0000020?ooo`/0dLfY0P0000040?ooo`80
00001P3oool6000000@0oooo100000040?ooo`H000000P3oool5000000@0oooo0P0000060?ooo`80
00000P3oool2000000@0oooo100000060?ooo`/0dLfY0P3oool600000080oooo0P0000020?ooo`H0
00002@3oool200000080oooo0P0000080?ooo`8000000P3oool2000000X0oooo1@0000020?ooo`80
00000P3oool600000080oooo2`3AcJT40?ooo`L00000103oool6000000H0oooo0P0000000`3oool0
0000000000040?ooo`@000000P3oool2000000@0oooo1`0000060?ooo`P000000`3oool6000000h0
dLfY000<0=7=Z@H000001`3oool400000080oooo0P0000020?ooo`@000000`3oool6000000H0oooo
1`0000020?ooo`@000000P3oool200000080oooo100000070?ooo`H000002`3AcJT2000000@0oooo
0P0000020?ooo`8000000P3oool200000080oooo1`0000040?ooo`8000000P3oool4000000@0oooo
100000020?ooo`800000103oool700000080oooo0P0000020?ooo`8000000P3oool2000000@0oooo
0P00000;0=7=Z@@0oooo0P0000020?ooo`H00000103oool2000000@0oooo0P0000040?oooa400000
103oool6000000@0oooo0P0000020?ooo`8000000P3oool8000000/0dLfY0P3oool200000080oooo
100000020?ooo`H000000P3oool300000080oooo0P0000040?ooo`800000303oool2000000@0oooo
0P0000020?ooo`@0000000<0oooo000000000000100000020?ooo`@000000P3oool200000080oooo
2`3AcJT40?ooo`L00000103oool6000000H0oooo0P0000000`3oool00000000000040?ooo`@00000
0P3oool2000000@0oooo1`0000060?ooo`P000000`3oool6000000h0dLfY000<0=7=Z@@000001`3o
ool600000080oooo0P0000020?ooo`@000001@3oool2000000@0oooo0P0000040?ooo`8000001@3o
ool400000080oooo0P0000020?ooo`H000001`3oool4000000/0dLfY0P0000040?ooo`8000000P3o
ool200000080oooo0P0000020?ooo`L00000103oool200000080oooo100000040?ooo`@000000P3o
ool2000000@0oooo1`0000020?ooo`8000000P3oool200000080oooo0P0000040?ooo`8000002`3A
cJT40?ooo`8000000P3oool6000000@0oooo0P0000040?ooo`800000103ooolA000000@0oooo1P00
00040?ooo`8000000P3oool200000080oooo2000000;0=7=Z@80oooo0P0000020?ooo`@000000P3o
ool600000080oooo0`0000020?ooo`800000103oool2000000`0oooo0P0000040?ooo`8000000P3o
ool4000000030?ooo`000000000000@000000P3oool400000080oooo0P0000020?ooo`/0dLfY0P00
00020?ooo`800000103oool9000000H0oooo0P0000050?ooo`h000001@3oool2000000H0oooo2P00
00030?ooo`8000000P3oool2000000h0dLfY000<0=7=Z@@000001`3oool600000080oooo0P000002
0?ooo`@000001@3oool2000000@0oooo0P0000040?ooo`8000001@3oool400000080oooo0P000002
0?ooo`H000001`3oool4000000/0dLfY0P3oool2000000P0oooo0P0000040?ooo`<00000103oool6
00000080oooo0P0000080?ooo`8000000P3oool6000000@0oooo0`0000040?ooo`800000203oool2
00000080oooo2`3AcJT80?ooo`8000000P3oool8000000@0oooo100000020?ooo`P000000P3oool7
00000080oooo100000020?ooo`@000000P3oool4000000X0oooo0P00000;0=7=Z@80oooo0P000004
0?ooo`8000000P3oool4000000@0oooo1@0000040?ooo`8000000P3oool<00000080oooo0P000004
0?ooo`H000000`3oool400000080oooo0P0000040?ooo`8000000P3oool;0=7=Z@8000000P3oool2
000000@0oooo2@0000060?ooo`8000001@3oool>000000D0oooo0P0000060?ooo`X000000`3oool2
00000080oooo0P00000>0=7=Z@00303AcJT40?ooo`@000000`3oool400000080oooo1P0000070?oo
o`H000001P3oool7000000H0oooo1P0000020?ooo`@000000`3oool4000000@0oooo2`3AcJT20?oo
o`800000203oool2000000@0oooo0`0000040?ooo`H000000P3oool2000000P0oooo0P0000020?oo
o`H00000103oool3000000@0oooo0P0000080?ooo`8000000P3oool;0=7=Z@P0oooo0P0000020?oo
o`P00000103oool400000080oooo200000020?ooo`L000000P3oool400000080oooo100000020?oo
o`@000002P3oool2000000/0dLfY0P3oool2000000@0oooo0P0000020?ooo`@00000103oool50000
00@0oooo0P0000020?ooo``000000P3oool2000000@0oooo1P0000030?ooo`@000000P3oool20000
00@0oooo0P0000020?ooo`/0dLfY0P3oool8000000D0oooo0P0000020?ooo`@00000103oool70000
0080oooo100000020?ooo`@000000`3oool800000080oooo200000050?ooo`8000000P3oool20000
00h0dLfY000<0=7=Z@@0oooo100000030?ooo`@000000P3oool6000000L0oooo1P0000060?ooo`L0
00001P3oool600000080oooo100000030?ooo`@00000103oool;0=7=Z@8000001P3oool400000080
oooo0P0000020?ooo`T00000103oool@000000@0oooo2@0000020?ooo`8000000P3oool4000000H0
oooo0P00000;0=7=Z@@00000103oool200000100oooo100000020?ooo`@000001@3oool400000080
oooo100000060?ooo`@000000P3oool6000000@0oooo1000000;0=7=Z@80oooo0P0000020?ooo`H0
0000103oool2000000<0oooo1P0000060?ooo`800000203oool2000000H0oooo1P0000030?ooo`80
0000103oool600000080oooo0P0000020?ooo`/0dLfY0P3oool8000000D0oooo0P0000020?ooo`@0
0000103oool700000080oooo100000020?ooo`@000000`3oool800000080oooo200000050?ooo`80
00000P3oool2000000h0dLfY000<0=7=Z@80oooo2@0000060?ooo`P000001@3oool6000000H0oooo
1`0000040?ooo`P000001P3oool900000080oooo2`3AcJT2000000H0oooo100000020?ooo`800000
0P3oool9000000@0oooo400000040?ooo`T000000P3oool200000080oooo100000060?ooo`800000
2`3AcJT4000000@0oooo0P00000@0?ooo`@000000P3oool4000000D0oooo100000020?ooo`@00000
1P3oool400000080oooo1P0000040?ooo`@000002`3AcJT20?ooo`8000000P3oool6000000@0oooo
0P0000030?ooo`H000001P3oool2000000P0oooo0P0000060?ooo`H000000`3oool2000000@0oooo
1P0000020?ooo`8000000P3oool;0=7=Z@H000000P3oool300000080oooo100000020?ooo`@00000
0P3oool4000001@0oooo100000020?ooo`@000000P3oool400000080oooo0`0000020?ooo`H00000
3P3AcJT000`0dLfY0P3oool9000000H0oooo200000050?ooo`H000001P3oool7000000@0oooo2000
00060?ooo`T000000P3oool;0=7=Z@80oooo100000020?ooo`@00000103oool2000000T0oooo2000
00080?ooo`P000002@3oool2000000@0oooo100000020?ooo`@000000P3oool;0=7=Z@@00000103o
ool2000000X0oooo1P0000020?ooo`8000001P3oool5000000H0oooo0P0000020?ooo`H000000P3o
ool2000000H0oooo0P0000040?ooo`8000000P3oool;0=7=Z@80oooo3P0000040?ooo`030000003o
ool0oooo00@000001P3oool4000000@0oooo100000060?ooo`@000000P3oool2000000<0oooo3P00
00020?ooo`/0dLfY100000060?ooo`D000000P3oool2000000@0oooo100000020?ooo`030000003o
ool0oooo0080oooo0P0000040?ooo`800000103oool2000000T0oooo0P0000080?ooo`D000001P3o
ool>0=7=Z@00303AcJT20?ooo`T000001P3oool8000000D0oooo1P0000060?ooo`L00000103oool8
000000H0oooo2@0000020?ooo`/0dLfY0P3oool400000080oooo100000040?ooo`8000002@3oool8
000000P0oooo200000090?ooo`800000103oool400000080oooo100000020?ooo`/0dLfY10000004
0?ooo`8000002P3oool600000080oooo0P0000060?ooo`D000001P3oool200000080oooo1P000002
0?ooo`8000001P3oool2000000@0oooo0P0000020?ooo`/0dLfY0P3oool>000000@0oooo00<00000
0?ooo`3oool0100000060?ooo`@00000103oool4000000H0oooo100000020?ooo`8000000`3oool>
00000080oooo2`3AcJT4000000H0oooo1@0000020?ooo`800000103oool400000080oooo00<00000
0?ooo`3oool00P3oool2000000@0oooo0P0000040?ooo`8000002@3oool2000000P0oooo1@000006
0?ooo`h0dLfY000<0=7=Z@80oooo2`0000060?ooo`H000001`3oool2000000@0oooo0P0000040?oo
o`8000001`3oool6000000H0oooo2`0000020?ooo`/0dLfY200000060?ooo`8000000P3oool30000
00@0oooo100000020?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`8000000P3oool40000
00@0oooo0`0000020?ooo`8000001P3oool8000000/0dLfY203oool200000080oooo1P0000020?oo
o`8000000P3oool200000080oooo0P0000040?ooo`@000000P3oool3000000@0oooo0P0000020?oo
o`8000000P3oool200000080oooo0P0000040?ooo`@00000103oool4000000/0dLfY1P3oool60000
0080oooo1000000;0?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000002`3oool40000
0080oooo1P0000060?ooo`/0dLfY103oool6000000T0oooo1P00000L0?ooo`H000002P3oool50000
00@0oooo3P3AcJT000`0dLfY0P3oool;000000H0oooo1P0000070?ooo`800000103oool2000000@0
oooo0P0000070?ooo`H000001P3oool;00000080oooo2`3AcJT8000000H0oooo0P0000020?ooo`<0
0000103oool400000080oooo0P0000020?ooo`800000103oool200000080oooo0P0000020?ooo`@0
0000103oool300000080oooo0P0000060?ooo`P000002`3AcJT80?ooo`8000000P3oool600000080
oooo0P0000020?ooo`8000000P3oool2000000@0oooo100000020?ooo`<00000103oool200000080
oooo0P0000020?ooo`8000000P3oool2000000@0oooo100000040?ooo`@000002`3AcJT60?ooo`H0
00000P3oool4000000/0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00000;0?ooo`@0
00000P3oool6000000H0oooo2`3AcJT40?ooo`H000002@3oool6000001`0oooo1P00000:0?ooo`D0
0000103oool>0=7=Z@00303AcJT40?ooo`T000000P3oool400000080oooo0P0000040?ooo`T00000
1P3oool9000000@0oooo0P0000020?ooo`@000000P3oool9000000@0oooo2`3AcJT:000000l0oooo
0P0000040?ooo`800000303oool2000000@0oooo0P00000?0?ooo`X000002`3AcJT40?ooo`800000
0P3oool600000080oooo1P0000020?ooo`H00000103oool2000000D0oooo0P0000040?ooo`H00000
0P3oool6000000@0oooo0P0000080?ooo`8000002`3AcJT200000080oooo0P0000020?ooo`800000
1P3oool2000000<0oooo0P00000:0?ooo`@00000103oool4000000X0oooo0P0000030?ooo`800000
1P3oool200000080oooo0P0000020?ooo`8000002`3AcJT20?ooo`@000000P3oool3000000@0oooo
1P0000040?ooo`@0000000<0oooo0000000000000P0000020?ooo`@000000P3oool400000080oooo
0`0000020?ooo`8000001P3oool8000000030?ooo`0000000000008000000P3oool2000000h0dLfY
000<0=7=Z@@0oooo2@0000020?ooo`@000000P3oool2000000@0oooo2@0000060?ooo`T00000103o
ool200000080oooo100000020?ooo`T00000103oool;0=7=Z@X000003`3oool2000000@0oooo0P00
000<0?ooo`800000103oool2000000l0oooo2P00000;0=7=Z@@0oooo0P0000020?ooo`H000000P3o
ool600000080oooo1P0000040?ooo`8000001@3oool2000000@0oooo1P0000020?ooo`H00000103o
ool2000000P0oooo0P00000;0=7=Z@8000000P3oool200000080oooo0P0000060?ooo`8000000`3o
ool2000000X0oooo100000040?ooo`@000002P3oool2000000<0oooo0P0000060?ooo`8000000P3o
ool200000080oooo0P00000;0=7=Z@80oooo100000020?ooo`<00000103oool6000000@0oooo1000
00000`3oool000000000000200000080oooo100000020?ooo`@000000P3oool300000080oooo0P00
00060?ooo`P0000000<0oooo0000000000000P0000020?ooo`8000003P3AcJT000`0dLfY10000002
0?ooo`D000000P3oool600000080oooo100000020?ooo`<000000P3oool4000000H0oooo10000003
0?ooo`8000000P3oool400000080oooo1P0000020?ooo`D000000P3oool4000000/0dLfY0P3oool8
00000080oooo0P0000020?ooo`8000000`3oool200000080oooo100000020?ooo`800000103oool4
000000@0oooo0P0000020?ooo`@000000P3oool2000000<0oooo0P0000020?ooo`8000000P3oool8
00000080oooo2`3AcJT2000000@0oooo0P00000>0?ooo`8000002P3oool9000000X0oooo0P00000:
0?ooo``000002`3AcJT20?ooo`800000103oool:000000L0oooo100000040?ooo`800000203oool2
000000@0oooo100000070?ooo`X00000103oool200000080oooo2`3AcJT20?ooo`8000001P3oool0
0`000000oooo0?ooo`020?ooo`800000103ooolT000000@0oooo0P0000040?ooo`8000001@3oool2
00000080oooo3P3AcJT000`0dLfY100000020?ooo`D000000P3oool600000080oooo100000020?oo
o`<000000P3oool4000000H0oooo100000030?ooo`8000000P3oool400000080oooo1P0000020?oo
o`D000000P3oool4000000/0dLfY0P3oool800000080oooo0P0000020?ooo`8000000`3oool20000
0080oooo100000020?ooo`800000103oool4000000@0oooo0P0000020?ooo`@000000P3oool20000
00<0oooo0P0000020?ooo`8000000P3oool800000080oooo2`3AcJT2000000@0oooo0P00000>0?oo
o`8000002P3oool9000000X0oooo0P00000:0?ooo``000002`3AcJT20?ooo`800000103oool:0000
00L0oooo100000040?ooo`800000203oool2000000@0oooo100000070?ooo`X00000103oool20000
0080oooo2`3AcJT20?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`800000103ooolT0000
00@0oooo0P0000040?ooo`8000001@3oool200000080oooo3P3AcJT000`0dLfY100000090?ooo`@0
00000P3oool200000080oooo1`0000080?ooo`8000002@3oool600000080oooo0P0000020?ooo`@0
00002@3oool4000000/0dLfY0P0000020?ooo`@000000P3oool200000080oooo0P0000020?ooo`<0
00000P3oool200000080oooo1P0000040?ooo`@00000103oool600000080oooo0P0000020?ooo`<0
00000P3oool200000080oooo0P0000020?ooo`@000000P3oool2000000/0dLfY103oool200000080
oooo0P0000040?ooo`800000103oool200000080oooo0P0000040?ooo`8000003@3oool2000000@0
oooo0P0000020?ooo`800000103oool2000000h0oooo2`3AcJT200000080oooo0P00000>0?ooo`03
0000003oool0oooo0080oooo100000040?ooo``00000103oool4000000@0oooo0P00000=0?ooo`80
00000P3oool2000000/0dLfY0P3oool9000000@0oooo200000020?ooo`@0000000<0oooo00000000
00000P0000020?ooo`@000000P3oool400000080oooo0`0000020?ooo`@00000103oool8000000<0
oooo0P0000020?ooo`8000003P3AcJT000`0dLfY100000090?ooo`@000000P3oool200000080oooo
1`0000080?ooo`8000002@3oool600000080oooo0P0000020?ooo`@000002@3oool4000000/0dLfY
0P0000020?ooo`@000000P3oool200000080oooo0P0000020?ooo`<000000P3oool200000080oooo
1P0000040?ooo`@00000103oool600000080oooo0P0000020?ooo`<000000P3oool200000080oooo
0P0000020?ooo`@000000P3oool2000000/0dLfY103oool200000080oooo0P0000040?ooo`800000
103oool200000080oooo0P0000040?ooo`8000003@3oool2000000@0oooo0P0000020?ooo`800000
103oool2000000h0oooo2`3AcJT200000080oooo0P00000>0?ooo`030000003oool0oooo0080oooo
100000040?ooo``00000103oool4000000@0oooo0P00000=0?ooo`8000000P3oool2000000/0dLfY
0P3oool9000000@0oooo200000020?ooo`@0000000<0oooo0000000000000P0000020?ooo`@00000
0P3oool400000080oooo0`0000020?ooo`@00000103oool8000000<0oooo0P0000020?ooo`800000
3P3AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfY
c03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfY
c03AcJT00?l0dLfYc03AcJT000`0dLfY0P0000050?ooo`<000001@3oool2000000D0oooo0P00000f
0?ooo`/0dLfY1@3oool2000000L0oooo0`0000070?ooo`8000000P3oool300000080oooo0P000003
0?ooo`8000009P3oool;0=7=Z@h0oooo2`0000020?ooo`L000000P3oool500000080oooo1`000002
0?ooo`/000003P3oool;0=7=Z@8000001`3oool200000100oooo0P0000040?ooo`D00000103oool3
000000T0oooo0P0000060?ooo`<000003@3oool;0=7=Z@8000000P3oool500000080oooo0P000002
0?ooo`8000000`3oool200000080oooo0P0000090?ooo`800000103oool2000000T0oooo0P000002
0?ooo`<000000P3oool200000080oooo0P0000020?ooo`D000000P3oool2000000h0dLfY000<0=7=
Z@8000001@3oool3000000D0oooo0P0000050?ooo`800000=P3oool;0=7=Z@D0oooo0P0000070?oo
o`<000001`3oool200000080oooo0`0000020?ooo`8000000`3oool2000002H0oooo2`3AcJT>0?oo
o`/000000P3oool700000080oooo1@0000020?ooo`L000000P3oool;000000h0oooo2`3AcJT20000
00L0oooo0P00000@0?ooo`800000103oool5000000@0oooo0`0000090?ooo`8000001P3oool30000
00d0oooo2`3AcJT200000080oooo1@0000020?ooo`8000000P3oool2000000<0oooo0P0000020?oo
o`8000002@3oool2000000@0oooo0P0000090?ooo`8000000P3oool300000080oooo0P0000020?oo
o`8000000P3oool500000080oooo0P00000>0=7=Z@00303AcJTK0?oooc<000002`3AcJT2000000L0
oooo0`0000070?ooo`8000001@3oool2000000<0oooo0P0000020?ooo`<000001@3ooolS000000/0
dLfY2`0000030?ooo`8000001`3oool6000000<0oooo3@0000030?ooo`H000001`3oool2000000<0
oooo2`00000;0=7=Z@@0oooo0`0000060?ooo``00000203oool5000000T0oooo100000070?ooo`80
00001`3oool;000000/0dLfY0P3oool900000080oooo0P0000020?ooo`<000000P3oool2000000@0
oooo1@00000=0?ooo`@00000103oool2000000<0oooo0P0000020?ooo`8000000P3oool900000080
oooo3P3AcJT000`0dLfY6`3ooolc000000/0dLfY0P0000070?ooo`<000001`3oool2000000D0oooo
0P0000030?ooo`8000000P3oool3000000D0oooo8`00000;0=7=Z@/000000`3oool2000000L0oooo
1P0000030?ooo`d000000`3oool6000000L0oooo0P0000030?ooo`/000002`3AcJT40?ooo`<00000
1P3oool<000000P0oooo1@0000090?ooo`@000001`3oool2000000L0oooo2`00000;0=7=Z@80oooo
2@0000020?ooo`8000000P3oool300000080oooo0P0000040?ooo`D000003@3oool4000000@0oooo
0P0000030?ooo`8000000P3oool200000080oooo2@0000020?ooo`h0dLfY000<0=7=ZA/0oooo<`00
000;0=7=Z@8000001`3oool3000000L0oooo0P0000050?ooo`8000000`3oool200000080oooo0`00
00050?ooob<000002`3AcJT;000000<0oooo0P0000070?ooo`H000000`3oool=000000<0oooo1P00
00070?ooo`8000000`3oool;000000/0dLfY3@3oool3000000H0oooo0`0000040?ooo`8000002@3o
ool2000000D0oooo1000000@0?ooo`8000001`3oool2000000/0dLfY2`00000=0?ooo`8000000P3o
ool5000000@0oooo100000050?ooo`@000000P3oool2000000d0oooo2`00000>0=7=Z@00303AcJT2
0?ooo`D000000`3oool500000080oooo1@0000050?ooo`800000;`3oool2000000/0dLfY603oool2
000000`0oooo0P0000030?ooo`8000007`3oool2000000/0dLfY0P0000070?ooo`T000000P3oool3
000000d0oooo1@00000=0?ooo`<000000P3oool9000000L0oooo0P00000;0=7=Z@d0oooo0`000006
0?ooo`<00000103oool2000000T0oooo0P0000050?ooo`@00000403oool2000000L0oooo0P00000;
0=7=Z@/000003@3oool200000080oooo1@0000040?ooo`@000001@3oool400000080oooo0P00000=
0?ooo`/000003P3AcJT000`0dLfY0P3oool5000000<0oooo1@0000020?ooo`D000001@3oool20000
02l0oooo0P00000;0=7=ZAP0oooo0P00000<0?ooo`8000000`3oool2000001l0oooo0P00000;0=7=
Z@8000001`3oool900000080oooo0`00000=0?ooo`D000003@3oool300000080oooo2@0000070?oo
o`8000002`3AcJT=0?ooo`<000001P3oool3000000@0oooo0P0000090?ooo`8000001@3oool40000
0100oooo0P0000070?ooo`8000002`3AcJT9000000H0oooo0P0000030?ooo`@000000P3oool20000
00T0oooo100000090?ooo`8000000P3oool500000080oooo0P0000060?ooo`T000003P3AcJT000`0
dLfY0P3ooolD000000D0oooo1@00000Y0?ooo`D000002`3AcJT20?ooo`L000000`3oool7000000L0
oooo1@0000020?ooo`D000000P3oool7000001X0oooo1@00000;0=7=Z@D000000P3oool2000000D0
oooo1P0000030?ooo`800000103oool300000080oooo0P0000050?ooo`8000000P3oool3000000@0
oooo0P0000030?ooo`H000001@3oool200000080oooo1@00000;0=7=Z@@000000`3oool400000080
oooo1@0000020?ooo`D000007@3oool400000080oooo1@0000020?ooo`@000000`3oool4000000/0
dLfY2@0000060?ooo`8000000`3oool400000080oooo0P0000090?ooo`@000002@3oool200000080
oooo1@0000020?ooo`8000001P3oool9000000h0dLfY000<0=7=Z@80oooo500000050?ooo`D00000
:@3oool5000000/0dLfY0P3oool7000000<0oooo1`0000070?ooo`D000000P3oool500000080oooo
1`00000J0?ooo`D000002`3AcJT500000080oooo0P0000050?ooo`H000000`3oool2000000@0oooo
0`0000020?ooo`8000001@3oool200000080oooo0`0000040?ooo`8000000`3oool6000000D0oooo
0P0000020?ooo`D000002`3AcJT4000000<0oooo100000020?ooo`D000000P3oool5000001d0oooo
100000020?ooo`D000000P3oool4000000<0oooo1000000;0=7=Z@T000001P3oool2000000<0oooo
100000020?ooo`8000002@3oool4000000T0oooo0P0000020?ooo`D000000P3oool2000000H0oooo
2@00000>0=7=Z@00303AcJT20?oooa@000001@3oool5000002T0oooo1@00000;0=7=Z@80oooo0`00
00020?ooo`L000000`3oool200000080oooo4@0000020?ooo`L000000`3ooolE00000080oooo0`00
00020?ooo`/0dLfY0P3oool500000080oooo1@0000020?ooo`@00000303oool200000080oooo1@00
00020?ooo`800000303oool400000080oooo1@0000020?ooo`D000000P3oool;0=7=Z@d000000`3o
ool6000000D0oooo0P0000020?ooo`T000000P3oool5000000L0oooo3@0000020?ooo`L000000P3o
ool;0=7=Z@80oooo1@0000020?ooo`@00000103oool7000000@0oooo0P0000030?ooo`800000203o
ool300000080oooo0P0000040?ooo`L00000103oool4000000<0oooo100000020?ooo`h0dLfY000<
0=7=Z@D0oooo0P0000030?ooo`D000000P3oool3000000T0oooo0`0000020?ooobD000000P3oool3
00000080oooo2`3AcJT20?ooo`<000000P3oool7000000<0oooo0P0000020?oooa4000000P3oool7
000000<0oooo5@0000020?ooo`<000000P3oool;0=7=Z@80oooo1@0000020?ooo`D000000P3oool4
000000`0oooo0P0000020?ooo`D000000P3oool2000000`0oooo100000020?ooo`D000000P3oool5
00000080oooo2`3AcJT=000000<0oooo1P0000050?ooo`8000000P3oool900000080oooo1@000007
0?ooo`d000000P3oool700000080oooo2`3AcJT20?ooo`D000000P3oool4000000@0oooo1`000004
0?ooo`8000000`3oool2000000P0oooo0`0000020?ooo`800000103oool7000000@0oooo10000003
0?ooo`@000000P3oool>0=7=Z@00303AcJT50?ooo`8000000`3oool500000080oooo0`0000090?oo
o`<000000P3ooolU00000080oooo0`0000020?ooo`/0dLfY0P3oool300000080oooo1`0000030?oo
o`8000000P3ooolA00000080oooo1`0000030?oooaD000000P3oool300000080oooo2`3AcJT20000
00<0oooo0P0000020?ooo`D000002`3oool7000000@0oooo1@0000040?ooo`L000002`3oool50000
0080oooo0P0000030?ooo`8000002`3AcJT20?ooo`8000000`3oool6000000T0oooo0`0000040?oo
o`@000001@3oool900000080oooo0P0000050?ooo`8000000P3oool7000000T0oooo0P00000;0=7=
Z@8000001`3oool400000080oooo1`0000040?ooo`8000000P3oool3000000d0oooo0P0000020?oo
o`800000103oool700000080oooo100000070?ooo`8000003P3AcJT000`0dLfY1`00000:0?oooa@0
00007`3oool:000000/0dLfY0P3oool3000000`0oooo1`0000020?ooo`D000000P3oool2000000<0
oooo0P0000030?ooo`8000000P3oool500000140oooo2@00000;0=7=Z@8000000`3oool200000080
oooo1@00000;0?ooo`L00000103oool5000000@0oooo1`00000;0?ooo`D000000P3oool2000000<0
oooo0P00000;0=7=Z@80oooo0P0000030?ooo`H000002@3oool3000000@0oooo100000050?ooo`T0
00000P3oool2000000D0oooo0P0000020?ooo`L000002@3oool2000000/0dLfY0P0000070?ooo`@0
00000P3oool7000000@0oooo0P0000020?ooo`<000003@3oool200000080oooo0P0000040?ooo`L0
00000P3oool4000000L0oooo0P00000>0=7=Z@00303AcJT7000000X0oooo5000000O0?ooo`X00000
2`3AcJT20?ooo`<00000303oool700000080oooo1@0000020?ooo`8000000`3oool2000000<0oooo
0P0000020?ooo`D000004@3oool9000000/0dLfY0P0000030?ooo`8000000P3oool5000000/0oooo
1`0000040?ooo`D00000103oool7000000/0oooo1@0000020?ooo`8000000`3oool2000000/0dLfY
100000050?ooo`8000002@3oool2000000D0oooo100000020?ooo`D00000103oool300000080oooo
0P0000050?ooo`@00000103oool3000000T0oooo0P0000020?ooo`/0dLfY0P3oool2000000T0oooo
1`0000020?ooo`8000002@3oool=000000P0oooo0P0000030?ooo`H000002@3oool200000080oooo
3P3AcJT000`0dLfY0P00000K0?ooo`<000001@3oool2000001/0oooo0P0000050?ooo`D000002`3A
cJT20?ooo`<00000703oool2000000P0oooo0P0000020?ooo`<000000P3oool2000000`0oooo0`00
00040?ooo`D000002`3AcJT50?ooo`@000002`3oool300000080oooo0P0000020?ooo`D000002@3o
ool500000080oooo0P0000020?ooo`<000002`3oool4000000D0oooo2`3AcJT4000000D0oooo0P00
00090?ooo`8000001@3oool400000080oooo1@0000040?ooo`<000000P3oool2000000D0oooo1000
00040?ooo`<000002@3oool200000080oooo2`3AcJT20?ooo`8000002@3oool700000080oooo0P00
00090?ooo`d00000203oool2000000<0oooo1P0000090?ooo`8000000P3oool>0=7=Z@00303AcJT2
000001/0oooo0`0000050?ooo`8000006`3oool2000000D0oooo1@00000;0=7=Z@80oooo0`00000L
0?ooo`800000203oool200000080oooo0`0000020?ooo`800000303oool3000000@0oooo1@00000;
0=7=Z@D0oooo1000000;0?ooo`<000000P3oool200000080oooo1@0000090?ooo`D000000P3oool2
00000080oooo0`00000;0?ooo`@000001@3oool;0=7=Z@8000001@3oool;000000@0oooo0`000002
0?ooo`800000103oool<000000@0oooo0P0000030?ooo`800000103oool;000000D0oooo0P00000;
0=7=Z@8000001@3oool200000080oooo1P00000;0?ooo`L00000203oool7000000/0oooo1P000002
0?ooo`<00000103oool2000000h0dLfY000<0=7=Z@8000006`3oool3000000D0oooo0P00000K0?oo
o`8000001@3oool5000000/0dLfY0P3oool300000080oooo2P0000070?ooo`8000001`3oool20000
00P0oooo1`0000070?ooo`L000001@3oool4000000D0oooo2`3AcJT70?ooo`@000000`3oool40000
00D0oooo100000050?ooo`8000002@3oool2000000D0oooo100000050?ooo`@000000`3oool40000
00L0oooo2`3AcJT2000000D0oooo2`0000040?ooo`<000000P3oool2000000@0oooo300000040?oo
o`8000000`3oool2000000@0oooo2`0000050?ooo`8000002`3AcJT2000000D0oooo0P0000020?oo
o`H000002`3oool7000000P0oooo1`00000;0?ooo`H000000P3oool3000000@0oooo0P00000>0=7=
Z@00303AcJT500000080oooo2P00000:0?ooo`X00000103ooolF000000D0oooo1@0000050?ooo`/0
dLfY0P3oool300000080oooo2P0000070?ooo`8000001`3oool2000000P0oooo1`0000070?ooo`L0
00001@3oool4000000D0oooo2`3AcJT70?ooo`@000000`3oool4000000D0oooo100000050?ooo`80
00002@3oool2000000D0oooo100000050?ooo`@000000`3oool4000000L0oooo2`3AcJT2000000D0
oooo2`0000040?ooo`<000000P3oool2000000@0oooo300000040?ooo`8000000`3oool2000000@0
oooo2`0000050?ooo`8000002`3AcJT20?ooo`8000001@3oool600000080oooo1@0000020?ooo`80
00000P3oool2000000D0oooo0P0000040?ooo`8000001@3oool200000080oooo0P0000020?ooo`D0
00000P3oool6000000D0oooo0P0000020?ooo`h0dLfY000<0=7=Z@D000000P3oool:000000X0oooo
2P0000040?oooaH000001@3oool5000000D0oooo2`3AcJT20?ooo`<000000P3oool:000000L0oooo
0P0000070?ooo`800000203oool7000000L0oooo1`0000050?ooo`@000001@3oool;0=7=Z@L00000
0P3oool900000080oooo1@0000040?ooo`D000000P3oool500000080oooo1@0000040?ooo`D00000
0P3oool900000080oooo1`00000;0=7=Z@@000000`3oool4000000D0oooo0P0000020?ooo`800000
0`3oool6000000D0oooo0P0000090?ooo`8000000P3oool700000080oooo1@0000040?ooo`800000
0`3oool200000080oooo2`3AcJT20?ooo`8000001@3oool600000080oooo1@0000020?ooo`800000
0P3oool2000000D0oooo0P0000040?ooo`8000001@3oool200000080oooo0P0000020?ooo`D00000
0P3oool6000000D0oooo0P0000020?ooo`h0dLfY000<0=7=Z@80oooo200000050?ooo`8000000`3o
ool4000000<0oooo1@0000020?ooo`D000000P3oool300000140oooo0P0000030?ooo`X000000P3o
ool;0=7=Z@80oooo1`0000050?ooo`<000000P3oool2000000L0oooo0`0000020?ooo`8000000`3o
ool200000140oooo0P0000020?ooo`<000000P3oool:00000080oooo2`3AcJT700000080oooo2@00
00020?ooo`D00000103oool500000080oooo1@0000020?ooo`D00000103oool500000080oooo2@00
00020?ooo`L000002`3AcJT4000000<0oooo100000050?ooo`8000000P3oool2000000<0oooo1P00
00050?ooo`8000002@3oool200000080oooo1`0000020?ooo`D00000103oool2000000<0oooo0P00
00020?ooo`/0dLfY0P0000050?ooo`H00000103oool700000080oooo2@0000080?ooo`T000000P3o
ool7000000@0oooo1`0000040?ooo`8000003P3AcJT000`0dLfY0P3oool8000000D0oooo0P000003
0?ooo`@000000`3oool500000080oooo1@0000020?ooo`<000004@3oool2000000<0oooo2P000002
0?ooo`/0dLfY0P3oool7000000D0oooo0`0000020?ooo`8000001`3oool300000080oooo0P000003
0?ooo`8000004@3oool200000080oooo0`0000020?ooo`X000000P3oool;0=7=Z@8000000`3oool2
000000L0oooo0P0000020?ooo`D000000P3oool200000080oooo0`0000020?ooo`T000000P3oool3
00000080oooo0P0000020?ooo`D000000P3oool2000000L0oooo0P0000030?ooo`8000002`3AcJT2
0?ooo`D00000103oool9000000D0oooo1P0000020?ooo`L000002`3oool9000000D0oooo2@000002
0?ooo`8000002`3AcJT2000000D0oooo1P0000040?ooo`L000000P3oool9000000P0oooo2@000002
0?ooo`L00000103oool7000000@0oooo0P00000>0=7=Z@00303AcJT20?ooo`P000001@3oool20000
00<0oooo100000030?ooo`D000000P3oool500000080oooo0`00000A0?ooo`8000000`3oool:0000
0080oooo2`3AcJT90?ooo`X00000303oool7000000`0oooo100000030?ooo`8000000P3oool?0000
0080oooo2`3AcJT2000000<0oooo0P0000070?ooo`8000000P3oool500000080oooo0P0000020?oo
o`<000000P3oool900000080oooo0`0000020?ooo`8000000P3oool500000080oooo0P0000070?oo
o`8000000`3oool2000000/0dLfY0P3oool5000000@0oooo2@0000050?ooo`H000000P3oool70000
00/0oooo2@0000050?ooo`T000000P3oool2000000/0dLfY0P3oool2000000<0oooo100000020?oo
o`8000001@3oool400000080oooo100000030?ooo`d000000P3oool400000080oooo1@0000040?oo
o`8000000P3oool500000080oooo0P0000020?ooo`h0dLfY000<0=7=Z@800000203ooolA000000X0
oooo2@00000=0?oooa4000000P3oool;0=7=Z@T0oooo2P00000<0?ooo`L00000303oool4000000<0
oooo0P0000020?ooo`l000000P3oool;0=7=Z@8000000`3oool2000000L0oooo0P0000020?ooo`D0
00000P3oool200000080oooo0`0000020?ooo`T000000P3oool300000080oooo0P0000020?ooo`D0
00000P3oool2000000L0oooo0P0000030?ooo`8000002`3AcJT200000080oooo2@0000030?ooo`H0
00001@3oool200000080oooo2@0000020?ooo`D000001`3oool=00000080oooo1@0000040?ooo`/0
dLfY0P3oool2000000<0oooo100000020?ooo`8000001@3oool400000080oooo100000030?ooo`d0
00000P3oool400000080oooo1@0000040?ooo`8000000P3oool500000080oooo0P0000020?ooo`h0
dLfY000<0=7=Z@800000203ooolA000000X0oooo2@00000=0?oooa4000000P3oool;0=7=Z@800000
1@3oool500000080oooo8@0000030?ooo`/000001@3oool7000000D0oooo2`3AcJT2000000<0oooo
0P0000040?ooo`D000000P3oool2000000L0oooo1@0000020?ooo`T000000P3oool5000000L0oooo
0P0000020?ooo`D00000103oool2000000<0oooo0P00000;0=7=Z@8000000P3oool9000000<0oooo
1P0000050?ooo`8000000P3oool900000080oooo1@0000070?ooo`d000000P3oool5000000@0oooo
2`3AcJT20?ooo`8000000`3oool400000080oooo0P0000050?ooo`@000000P3oool4000000<0oooo
3@0000020?ooo`@000000P3oool5000000@0oooo0P0000020?ooo`D000000P3oool200000080oooo
3P3AcJT000`0dLfY0P3oool300000080oooo1@0000030?ooo`8000000`3oool9000000<0oooo1@00
00040?ooo`D000000`3oool7000000<0oooo100000030?ooo`L000001@3oool;0=7=Z@8000001@3o
ool500000080oooo8@0000030?ooo`/000001@3oool7000000D0oooo2`3AcJT2000000<0oooo0P00
00040?ooo`D000000P3oool2000000L0oooo1@0000020?ooo`T000000P3oool5000000L0oooo0P00
00020?ooo`D00000103oool2000000<0oooo0P00000;0=7=ZA80oooo100000030?ooo`@000000P3o
ool700000080oooo1`0000020?ooo`D000000P3oool400000180oooo2`3AcJT200000080oooo0`00
000:0?ooo`<00000103oool2000001X0oooo0P0000050?ooo`8000002`3oool200000080oooo0P00
000>0=7=Z@00303AcJT20?ooo`<000000P3oool5000000<0oooo0P0000030?ooo`T000000`3oool5
000000@0oooo1@0000030?ooo`L000000`3oool4000000<0oooo1`0000050?ooo`/0dLfY0P000005
0?ooo`D000000P3ooolQ000000<0oooo2`0000050?ooo`L000001@3oool;0=7=Z@L00000103oool3
00000080oooo3@0000030?ooo`8000000P3oool500000080oooo0P0000030?ooo`d000000P3oool3
000000@0oooo1`00000;0=7=ZA80oooo100000030?ooo`@000000P3oool700000080oooo1`000002
0?ooo`D000000P3oool400000180oooo2`3AcJT200000080oooo0`00000:0?ooo`<00000103oool2
000001X0oooo0P0000050?ooo`8000002`3oool200000080oooo0P00000>0=7=Z@00303AcJT20000
00<0oooo1@0000050?ooo`8000001@3ooolC000000D0oooo1@0000030?ooo`D000002@3oool30000
0080oooo1@00000;0=7=Z@L0oooo0P0000080?ooo`800000303oool7000000L0oooo1@0000020?oo
o`8000000`3oool9000000<0oooo0P0000020?ooo`D000002`3AcJT7000000@0oooo0`0000020?oo
o`d000000`3oool200000080oooo1@0000020?ooo`8000000`3oool=00000080oooo0`0000040?oo
o`L000002`3AcJT20?ooo`8000002@3oool5000000@0oooo1@0000020?ooo`8000000P3oool30000
00@0oooo1@0000020?ooo`L000001P3oool2000000D0oooo0P0000050?ooo`@000002`3AcJT70?oo
o`8000000P3oool2000000L0oooo100000020?ooo`8000000P3oool3000000d0oooo0P0000020?oo
o`8000000P3oool5000000H0oooo0P0000020?ooo`<000001P3oool>0=7=Z@00303AcJT2000000<0
oooo1@0000050?ooo`8000001@3ooolC000000D0oooo1@0000030?ooo`D000002@3oool300000080
oooo1@00000;0=7=Z@L0oooo0P0000080?ooo`800000303oool7000000L0oooo1@0000020?ooo`80
00000`3oool9000000<0oooo0P0000020?ooo`D000002`3AcJT;0?ooo`<000000P3oool4000002D0
oooo100000020?ooo`<000002`3oool;0=7=Z@80oooo0P0000090?ooo`D00000103oool500000080
oooo0P0000020?ooo`<00000103oool500000080oooo1`0000060?ooo`8000001@3oool2000000D0
oooo1000000;0=7=Z@L0oooo0P0000020?ooo`8000001`3oool400000080oooo0P0000020?ooo`<0
00003@3oool200000080oooo0P0000020?ooo`D000001P3oool200000080oooo0`0000060?ooo`h0
dLfY000<0=7=Z@8000000`3oool5000000D0oooo0P0000050?oooa<000001@3oool5000000<0oooo
1@0000090?ooo`<000000P3oool5000000/0dLfY0P3oool300000080oooo3P0000070?ooo`<00000
0P3oool2000000<0oooo0P0000030?ooo`8000000P3oool300000080oooo0P0000050?ooo`800000
0`3oool2000000<0oooo0P0000020?ooo`D000002`3AcJT;0?ooo`<000000P3oool4000002D0oooo
100000020?ooo`<000002`3oool;0=7=Z@80oooo0P0000090?ooo`D00000103oool500000080oooo
0P0000020?ooo`<00000103oool500000080oooo1`0000060?ooo`8000001@3oool2000000D0oooo
1000000;0=7=Z@80oooo1@0000020?ooo`800000103oool9000000@0oooo0P0000050?ooo`P00000
1@3oool2000000@0oooo2@0000040?ooo`8000000`3oool400000080oooo3P3AcJT000`0dLfY1@3o
ool2000000<0oooo0P0000030?ooo`8000000`3oool200000080oooo1@0000030?ooo`D000000P3o
ool:000000L0oooo1@0000020?ooo`P000000P3oool5000000/0dLfY0P3oool300000080oooo3P00
00070?ooo`<000000P3oool2000000<0oooo0P0000030?ooo`8000000P3oool300000080oooo0P00
00050?ooo`8000000`3oool2000000<0oooo0P0000020?ooo`D000002`3AcJT70?ooo`8000000P3o
ool5000000@0oooo0`0000060?ooo`<000000P3oool2000000D0oooo0P0000020?ooo`<000001P3o
ool3000000@0oooo1@0000020?ooo`8000001`3oool;0=7=Z@L0oooo100000020?ooo``00000203o
ool5000000T0oooo100000070?ooo`8000003P3oool4000000/0dLfY0P3oool500000080oooo0P00
00040?ooo`T00000103oool2000000D0oooo200000050?ooo`800000103oool9000000@0oooo0P00
00030?ooo`@000000P3oool>0=7=Z@00303AcJT50?ooo`8000000`3oool2000000<0oooo0P000003
0?ooo`8000000P3oool5000000<0oooo1@0000020?ooo`X000001`3oool500000080oooo20000002
0?ooo`D000002`3AcJT50?ooo`8000002P3oool4000000<0oooo0P0000070?ooo`8000001@3oool3
000000@0oooo1`0000030?ooo`@000000`3oool9000000D0oooo2`3AcJT70?ooo`8000000P3oool5
000000@0oooo0`0000060?ooo`<000000P3oool2000000D0oooo0P0000020?ooo`<000001P3oool3
000000@0oooo1@0000020?ooo`8000001`3oool;0=7=Z@L0oooo100000020?ooo``00000203oool5
000000T0oooo100000070?ooo`8000003P3oool4000000/0dLfY0P3oool5000000@0oooo0P000002
0?ooo`8000000`3oool2000000@0oooo0P0000020?ooo`<000000P3oool2000000@0oooo0P000003
0?ooo`8000000P3oool2000000@0oooo0`0000020?ooo`8000000P3oool2000000D0oooo10000002
0?ooo`h0dLfY000<0=7=Z@D0oooo0P0000050?ooo`P000007@3oool7000000<0oooo1`0000050?oo
o`8000001@3oool;0=7=Z@D0oooo0P00000:0?ooo`@000000`3oool2000000L0oooo0P0000050?oo
o`<00000103oool7000000<0oooo100000030?ooo`T000001@3oool;0=7=Z@L0oooo0P0000020?oo
o`D00000103oool3000000H0oooo0`0000020?ooo`8000001@3oool200000080oooo0`0000060?oo
o`<00000103oool500000080oooo0P0000070?ooo`/0dLfY0P0000050?ooo`H000000`3oool20000
00L0oooo100000070?ooo`8000003@3oool5000000@0oooo1`0000020?ooo`8000001`3oool;0=7=
Z@80oooo1@0000040?ooo`8000000P3oool2000000<0oooo0P0000040?ooo`8000000P3oool30000
0080oooo0P0000040?ooo`8000000`3oool200000080oooo0P0000040?ooo`<000000P3oool20000
0080oooo0P0000050?ooo`@000000P3oool>0=7=Z@00303AcJT50?ooo`8000001@3oool8000001d0
oooo1`0000030?ooo`L000001@3oool2000000D0oooo2`3AcJT50?ooo`8000002P3oool4000000<0
oooo0P0000070?ooo`8000001@3oool3000000@0oooo1`0000030?ooo`@000000`3oool9000000D0
oooo2`3AcJT5000000@0oooo0P0000030?ooo`H000001@3oool2000000D0oooo0P0000090?ooo`80
00001@3oool2000000D0oooo1P0000030?ooo`800000103oool5000000/0dLfY0P0000050?ooo`H0
00000`3oool2000000L0oooo100000070?ooo`8000003@3oool5000000@0oooo1`0000020?ooo`80
00001`3oool;0=7=Z@T0oooo0P0000020?ooo`@000000`3oool4000000T0oooo3@0000080?ooo`D0
00000P3oool400000080oooo0P0000090?ooo`h0dLfY000<0=7=Z@D0oooo0P0000050?ooo`P00000
7@3oool7000000<0oooo1`0000050?ooo`8000001@3oool;0=7=Z@D000000P3oool2000000D0oooo
0`0000040?ooo`<000002@3oool2000000<0oooo0P0000030?ooo`8000002@3oool500000080oooo
0`0000050?ooo`L000000P3oool;0=7=Z@D00000103oool2000000<0oooo1P0000050?ooo`800000
1@3oool2000000T0oooo0P0000050?ooo`8000001@3oool6000000<0oooo0P0000040?ooo`D00000
2`3AcJT90?ooo`@000000`3oool400000080oooo1`0000020?ooo`L000000P3oool700000080oooo
1`0000020?ooo`@000000`3oool4000000T0oooo2`3AcJT90?ooo`8000000P3oool4000000<0oooo
100000090?ooo`d00000203oool500000080oooo100000020?ooo`8000002@3oool>0=7=Z@00303A
cJT2000000<0oooo0P0000030?ooo`h000001@3oool3000000D0oooo0P0000070?ooo`D000000`3o
ool2000000X0oooo1@0000020?ooo`<000000P3oool;0=7=Z@D000000P3oool2000000D0oooo0`00
00040?ooo`<000002@3oool2000000<0oooo0P0000030?ooo`8000002@3oool500000080oooo0`00
00050?ooo`L000000P3oool;0=7=Z@D000000P3oool2000000T0oooo1@0000060?ooo`<000000P3o
ool900000080oooo0`0000060?ooo`D000002@3oool200000080oooo1@00000;0=7=Z@T0oooo1000
00030?ooo`@000000P3oool700000080oooo1`0000020?ooo`L000000P3oool700000080oooo1000
00030?ooo`@000002@3oool;0=7=Z@8000002`3oool200000080oooo0`0000020?ooo`800000103o
ool9000000@0oooo2@0000040?ooo`8000000`3oool200000080oooo0P00000;0?ooo`8000003P3A
cJT000`0dLfY0P0000030?ooo`8000000`3oool>000000D0oooo0`0000050?ooo`8000001`3oool5
000000<0oooo0P00000:0?ooo`D000000P3oool300000080oooo2`3AcJT5000000`0oooo10000003
0?ooo`L000000P3oool5000000h0oooo1@0000070?ooo`D000000P3oool500000080oooo2`3AcJT5
00000080oooo0P0000090?ooo`D000001P3oool300000080oooo2@0000020?ooo`<000001P3oool5
000000T0oooo0P0000020?ooo`D000002`3AcJT20?ooo`L00000103oool300000080oooo2@000002
0?ooo`@000001@3oool4000000<0oooo2@0000020?ooo`@000001`3oool;000000/0dLfY0P00000;
0?ooo`8000000P3oool300000080oooo0P0000040?ooo`T00000103oool9000000@0oooo0P000003
0?ooo`8000000P3oool2000000/0oooo0P00000>0=7=Z@00303AcJT20?oooa8000000P3oool20000
0140oooo0`0000020?ooo`<000001@3oool2000000L0oooo200000070?ooo`/0dLfY1@00000<0?oo
o`@000000`3oool700000080oooo1@00000>0?ooo`D000001`3oool500000080oooo1@0000020?oo
o`/0dLfY1@3oool200000080oooo1@0000020?ooo`8000000P3oool3000000/0oooo0P0000050?oo
o`8000002`3oool300000080oooo0P0000020?ooo`D000000P3oool2000000D0oooo2`3AcJT20?oo
o`L00000103oool300000080oooo2@0000020?ooo`@000001@3oool4000000<0oooo2@0000020?oo
o`@000001`3oool;000000/0dLfY103oool5000000@0oooo0P0000070?ooo`800000103oool20000
00<0oooo0P0000020?ooo`@000000P3oool300000080oooo0P0000040?ooo`8000001`3oool20000
00@0oooo1@0000040?ooo`h0dLfY000<0=7=Z@80oooo4P0000020?ooo`8000004@3oool300000080
oooo0`0000050?ooo`8000001`3oool8000000L0oooo2`3AcJT90?ooo``000000`3oool200000080
oooo1@0000020?ooo`P000000P3oool500000080oooo0P0000030?ooo``000002@3oool;0=7=Z@D0
oooo0P0000020?ooo`D000000P3oool200000080oooo0`00000;0?ooo`8000001@3oool2000000/0
oooo0`0000020?ooo`8000000P3oool500000080oooo0P0000050?ooo`/0dLfY0P3oool2000000<0
oooo1P0000090?ooo`<00000103oool200000080oooo1`0000090?ooo`8000001@3oool200000080
oooo1`0000090?ooo`8000002`3AcJT40?ooo`D00000103oool2000000L0oooo0P0000040?ooo`80
00000`3oool200000080oooo100000020?ooo`<000000P3oool2000000@0oooo0P0000070?ooo`80
0000103oool5000000@0oooo3P3AcJT000`0dLfY0P3ooolB00000080oooo0P00000A0?ooo`<00000
0P3oool3000000D0oooo0P0000070?ooo`P000001`3oool;0=7=Z@T0oooo300000030?ooo`800000
0P3oool500000080oooo200000020?ooo`D000000P3oool2000000<0oooo300000090?ooo`/0dLfY
1@3oool200000080oooo1@0000020?ooo`8000000P3oool3000000/0oooo0P0000050?ooo`800000
2`3oool300000080oooo0P0000020?ooo`D000000P3oool2000000D0oooo2`3AcJT20?ooo`800000
0`3oool6000000T0oooo0`0000040?ooo`8000000P3oool7000000T0oooo0P0000050?ooo`800000
0P3oool7000000T0oooo0P00000;0=7=Z@@0oooo1@0000040?ooo`8000001`3oool2000000@0oooo
0P0000030?ooo`8000000P3oool400000080oooo0`0000020?ooo`800000103oool2000000L0oooo
0P0000040?ooo`D00000103oool>0=7=Z@00303AcJT7000000<0oooo1`0000050?ooo`8000000`3o
ool2000000<0oooo1@0000070?ooo`L000000`3oool2000000<0oooo0P0000020?ooo`D00000203o
ool2000000/0dLfY2@3oool<000000<0oooo0P0000020?ooo`D000000P3oool800000080oooo1@00
00020?ooo`8000000`3oool<000000T0oooo2`3AcJT20?ooo`<00000103oool7000000@0oooo0`00
00020?ooo`@000001@3oool9000000D0oooo100000020?ooo`<00000103oool7000000@0oooo0`00
00020?ooo`/0dLfY0P3oool2000000<0oooo1P0000090?ooo`<00000103oool200000080oooo1`00
00090?ooo`8000001@3oool200000080oooo1`0000090?ooo`8000002`3AcJT40?ooo`D00000103o
ool2000000L0oooo0P0000040?ooo`8000000`3oool200000080oooo100000020?ooo`<000000P3o
ool2000000@0oooo0P0000070?ooo`800000103oool5000000@0oooo3P3AcJT000`0dLfY1`000003
0?ooo`L000001@3oool2000000<0oooo0P0000030?ooo`D000001`3oool7000000<0oooo0P000003
0?ooo`8000000P3oool5000000P0oooo0P00000;0=7=Z@D0oooo0P0000020?ooo`<000001@3oool2
00000080oooo1@0000050?ooo`8000001`3oool>000000<0oooo0P0000050?ooo`8000002P3oool2
000000/0dLfY0P3oool3000000@0oooo1`0000040?ooo`<000000P3oool4000000D0oooo2@000005
0?ooo`@000000P3oool3000000@0oooo1`0000040?ooo`<000000P3oool;0=7=Z@80oooo0P000007
0?ooo`L000000P3oool700000080oooo0P0000020?ooo`<00000103oool500000080oooo1`000002
0?ooo`8000000P3oool2000000<0oooo100000050?ooo`@000002`3AcJT40?ooo`D00000103oool2
000000L0oooo0P0000040?ooo`8000000`3oool200000080oooo100000020?ooo`<000000P3oool2
000000@0oooo0P0000070?ooo`800000103oool5000000@0oooo3P3AcJT000`0dLfY1@0000070?oo
o`<000000P3oool300000080oooo1@0000020?ooo`P000000P3ooolD00000080oooo0P0000050?oo
o`D000001@3oool;0=7=Z@D0oooo0P0000020?ooo`<000001@3oool200000080oooo1@0000050?oo
o`8000001`3oool>000000<0oooo0P0000050?ooo`8000002P3oool2000000/0dLfY1@3oool20000
00@0oooo1`0000020?ooo`T000004`3oool900000080oooo1`0000040?ooo`8000001@3oool;0=7=
Z@80oooo0P0000070?ooo`L000000P3oool700000080oooo0P0000020?ooo`<00000103oool50000
0080oooo1`0000020?ooo`8000000P3oool2000000<0oooo100000050?ooo`@000002`3AcJT20000
00/0oooo0P0000020?ooo`<000000P3oool2000000@0oooo2@0000040?ooo`T00000103oool20000
00<0oooo0P0000020?ooo`8000002`3oool2000000h0dLfY000<0=7=Z@D000001`3oool300000080
oooo0`0000020?ooo`D000000P3oool800000080oooo500000020?ooo`8000001@3oool5000000D0
oooo2`3AcJT2000000D0oooo300000020?ooo`<00000103oool5000000D0oooo0P0000050?ooo`D0
0000103ooolC000000D0oooo2`3AcJT50?ooo`800000103oool700000080oooo2@00000C0?ooo`T0
00000P3oool7000000@0oooo0P0000050?ooo`/0dLfY0P3oool2000000D0oooo0P0000050?ooobh0
00001@3oool2000000D0oooo0P0000020?ooo`/0dLfY0P00000;0?ooo`8000000P3oool300000080
oooo0P0000040?ooo`T00000103oool9000000@0oooo0P0000030?ooo`8000000P3oool2000000/0
oooo0P00000>0=7=Z@00303AcJT50?ooo`X000001@3oool200000080oooo0`0000020?ooo`D00000
0`3oool4000000<0oooo1`0000030?ooo`D00000103oool:000000D0oooo2`3AcJT2000000D0oooo
300000020?ooo`<00000103oool5000000D0oooo0P0000050?ooo`D00000103ooolC000000D0oooo
2`3AcJT5000000@0oooo0P0000030?ooo`H000001@3oool2000000D0oooo0P0000090?ooo`800000
1@3oool2000000D0oooo1P0000030?ooo`800000103oool5000000/0dLfY0P3oool2000000D0oooo
0P0000050?ooobh000001@3oool2000000D0oooo0P0000020?ooo`/0dLfY2@3oool200000080oooo
100000030?ooo`@000002@3oool=000000P0oooo1@0000020?ooo`@000000P3oool2000000T0oooo
3P3AcJT000`0dLfY1@3oool:000000D0oooo0P0000020?ooo`<000000P3oool5000000<0oooo1000
00030?ooo`L000000`3oool5000000@0oooo2P0000050?ooo`/0dLfY1@3oool7000000L0oooo1`00
00020?ooo`<000002@3oool5000000D0oooo2@0000050?ooo`8000001@3oool2000000D0oooo2`3A
cJT5000000@0oooo0P0000030?ooo`H000001@3oool2000000D0oooo0P0000090?ooo`8000001@3o
ool2000000D0oooo1P0000030?ooo`800000103oool5000000/0dLfY0P3oool2000000L0oooo1@00
00040?ooo`L000000P3oool200000080oooo0`0000040?ooo`D000000P3oool700000080oooo0P00
00070?ooo`@000001@3oool4000000/0dLfY2@3oool200000080oooo100000030?ooo`@000002@3o
ool=000000P0oooo1@0000020?ooo`@000000P3oool2000000T0oooo3P3AcJT000`0dLfY1@3oool:
000000D0oooo0P0000020?ooo`<000000P3oool5000000<0oooo100000030?ooo`L000000`3oool5
000000@0oooo2P0000050?ooo`/0dLfY1@3oool7000000L0oooo1`0000020?ooo`<000002@3oool5
000000D0oooo2@0000050?ooo`8000001@3oool2000000D0oooo2`3AcJT7000000T0oooo3@000007
0?ooo`D000001`3oool=000000T0oooo1`00000;0=7=Z@80oooo0P0000070?ooo`D00000103oool7
00000080oooo0P0000020?ooo`<00000103oool500000080oooo1`0000020?ooo`8000001`3oool4
000000D0oooo1000000;0=7=Z@80oooo1@0000040?ooo`8000000P3oool2000000<0oooo0P000004
0?ooo`8000000P3oool300000080oooo0P0000040?ooo`8000000`3oool200000080oooo0P000004
0?ooo`<000000P3oool200000080oooo0P0000050?ooo`@000000P3oool>0=7=Z@00303AcJT20?oo
o`D000002P3oool3000000@0oooo1@0000080?ooo`8000001`3oool3000000`0oooo1@0000020?oo
o`<000001@3oool2000000/0dLfY1@3oool7000000L0oooo1`0000020?ooo`<000002@3oool50000
00D0oooo2@0000050?ooo`8000001@3oool2000000D0oooo2`3AcJT7000000T0oooo3@0000070?oo
o`D000001`3oool=000000T0oooo1`00000;0=7=Z@80oooo0P0000030?ooo`d000000P3oool30000
00@0oooo0P0000020?ooo`L000002@3oool2000000D0oooo100000050?ooo`8000002@3oool20000
00/0dLfY0P3oool5000000@0oooo0P0000020?ooo`8000000`3oool2000000@0oooo0P0000020?oo
o`<000000P3oool2000000@0oooo0P0000030?ooo`8000000P3oool2000000@0oooo0`0000020?oo
o`8000000P3oool2000000D0oooo100000020?ooo`h0dLfY000<0=7=Z@80oooo1@00000:0?ooo`<0
0000103oool5000000P0oooo0P0000070?ooo`<00000303oool500000080oooo0`0000050?ooo`80
00002`3AcJT50?ooo`@000000`3oool2000000<0oooo8`0000020?ooo`<000000P3oool>000000<0
oooo0P00000;0=7=Z@L000002@3oool=000000L0oooo1@0000070?ooo`d000002@3oool7000000/0
dLfY0P3oool2000000<0oooo3@0000020?ooo`<00000103oool200000080oooo1`0000090?ooo`80
00001@3oool4000000D0oooo0P0000090?ooo`8000002`3AcJT20?ooo`D000000P3oool2000000@0
oooo2@0000040?ooo`8000001@3oool8000000D0oooo0P0000040?ooo`T00000103oool2000000<0
oooo100000020?ooo`h0dLfY000<0=7=Z@80oooo0`0000020?ooo`<000002P3oool2000000D0oooo
1@0000050?oooa4000001`3oool2000000D0oooo1@0000050?ooo`/0dLfY1@3oool4000000<0oooo
0P0000030?ooob<000000P3oool300000080oooo3P0000030?ooo`8000002`3AcJT20?ooo`D00000
103oool500000080oooo0P0000050?ooo`@000001`3oool5000000L0oooo100000050?ooo`800000
0P3oool5000000@0oooo1@0000020?ooo`/0dLfY0P3oool700000080oooo1@0000020?ooo`800000
0P3oool500000080oooo100000050?ooo`@000000`3oool9000000@0oooo0P0000050?ooo`d00000
2`3AcJT20?ooo`D000000P3oool2000000@0oooo2@0000040?ooo`8000001@3oool8000000D0oooo
0P0000040?ooo`T00000103oool2000000<0oooo100000020?ooo`h0dLfY000<0=7=Z@80oooo0`00
00020?ooo`<000002P3oool2000000D0oooo1@0000050?oooa4000001`3oool2000000D0oooo1@00
00050?ooo`/0dLfY0P00000<0?ooo``000000P3oool3000000T0oooo1@0000090?ooo`<000000P3o
ool2000000<0oooo0P0000070?ooo`<000000P3oool;0=7=Z@80oooo1@0000040?ooo`D000000P3o
ool2000000D0oooo100000070?ooo`D000001`3oool4000000D0oooo0P0000020?ooo`D00000103o
ool500000080oooo2`3AcJT20?ooo`L000000P3oool500000080oooo0P0000020?ooo`D000000P3o
ool4000000D0oooo100000030?ooo`T00000103oool2000000D0oooo3@00000;0=7=Z@L0oooo0P00
00020?ooo`8000001`3oool400000080oooo0P0000020?ooo`<000003@3oool200000080oooo0P00
00020?ooo`D000001P3oool200000080oooo0`0000060?ooo`h0dLfY000<0=7=Z@80oooo0`000002
0?ooo`<000002P3oool2000000D0oooo1@0000050?oooa4000001`3oool2000000D0oooo1@000005
0?ooo`/0dLfY0P00000<0?ooo``000000P3oool3000000T0oooo1@0000090?ooo`<000000P3oool2
000000<0oooo0P0000070?ooo`<000000P3oool;0=7=Z@8000002@3oool500000080oooo1`000007
0?ooo`8000002@3oool2000000L0oooo1`0000020?ooo`D000002@3oool2000000/0dLfY0P3oool7
00000080oooo1@0000020?ooo`8000000P3oool500000080oooo100000050?ooo`@000000`3oool9
000000@0oooo0P0000050?ooo`d000002`3AcJT70?ooo`8000000P3oool2000000L0oooo10000002
0?ooo`8000000P3oool3000000d0oooo0P0000020?ooo`8000000P3oool5000000H0oooo0P000002
0?ooo`<000001P3oool>0=7=Z@00303AcJT20?ooo`<000001`3oool8000000@0oooo0`0000020?oo
o`<000003P3oool300000080oooo0`0000020?ooo`<000000P3oool5000000D0oooo0P0000050?oo
o`/0dLfY2@3oool?000000@0oooo1@0000050?ooo`8000001@3oool2000000L0oooo1`0000030?oo
o`D000000P3oool2000000<0oooo0P00000;0=7=Z@8000002@3oool500000080oooo1`0000070?oo
o`8000002@3oool2000000L0oooo1`0000020?ooo`D000002@3oool2000000/0dLfY4P3oool40000
00<0oooo100000020?ooo`L000000P3oool700000080oooo1@0000020?ooo`@000004P3oool;0=7=
Z@8000000P3oool3000000X0oooo0`0000040?ooo`8000006P3oool2000000D0oooo0P00000;0?oo
o`8000000P3oool2000000h0dLfY000<0=7=Z@80oooo0`0000070?ooo`P00000103oool300000080
oooo0`00000>0?ooo`<000000P3oool300000080oooo0`0000020?ooo`D000001@3oool2000000D0
oooo2`3AcJT90?ooo`l00000103oool5000000D0oooo0P0000050?ooo`8000001`3oool7000000<0
oooo1@0000020?ooo`8000000`3oool2000000/0dLfY0P3oool300000080oooo0P0000070?ooo`80
00001@3oool4000001L0oooo100000050?ooo`8000001`3oool200000080oooo0`0000020?ooo`/0
dLfY4P3oool4000000<0oooo100000020?ooo`L000000P3oool700000080oooo1@0000020?ooo`@0
00004P3oool;0=7=Z@8000000P3oool3000000X0oooo0`0000040?ooo`8000006P3oool2000000D0
oooo0P00000;0?ooo`8000000P3oool2000000h0dLfY000<0=7=Z@80oooo0`0000070?ooo`<00000
0P3oool5000000L0oooo0`0000020?ooo`<000001`3oool500000080oooo1@0000030?ooo`800000
0P3oool300000080oooo1@0000030?ooo`8000002`3AcJT90?ooo`l00000103oool5000000D0oooo
0P0000050?ooo`8000001`3oool7000000<0oooo1@0000020?ooo`8000000`3oool2000000/0dLfY
0P3oool300000080oooo0P0000070?ooo`8000001@3oool4000001L0oooo100000050?ooo`800000
1`3oool200000080oooo0`0000020?ooo`/0dLfY0P0000070?ooo`8000002@3oool2000000D0oooo
0P0000070?ooo`800000403oool4000000@0oooo0`00000=0?ooo`/0dLfY0P3oool2000000<0oooo
100000020?ooo`8000001@3oool400000080oooo100000030?ooo`d000000P3oool400000080oooo
1@0000040?ooo`8000000P3oool500000080oooo0P0000020?ooo`h0dLfY000<0=7=Z@80oooo0`00
00070?ooo`<000000P3oool5000000L0oooo0`0000020?ooo`<000001`3oool500000080oooo1@00
00030?ooo`8000000P3oool300000080oooo1@0000030?ooo`8000002`3AcJT20?ooo`D000000P3o
ool300000080oooo1`0000030?ooo`8000001@3oool2000000L0oooo1@0000050?ooo`8000002@3o
ool300000080oooo1@0000070?ooo`/0dLfY0P0000030?ooo`8000001`3oool200000080oooo1@00
00020?ooo`8000000P3oool300000080oooo2@0000020?ooo`<000000P3oool200000080oooo1@00
00020?ooo`8000001`3oool2000000<0oooo0P00000;0=7=Z@8000001`3oool2000000T0oooo0P00
00050?ooo`8000001`3oool200000100oooo100000040?ooo`<000003@3oool;0=7=Z@80oooo0P00
00030?ooo`@000000P3oool2000000D0oooo100000020?ooo`@000000`3oool=00000080oooo1000
00020?ooo`D00000103oool200000080oooo1@0000020?ooo`8000000P3oool>0=7=Z@00303AcJT2
0?ooo`<000000P3oool300000080oooo0`0000050?ooo`8000001`3oool5000000D0oooo0P000003
0?ooo`8000000`3oool2000000<0oooo0P0000070?ooo`P000000P3oool300000080oooo2`3AcJT2
0?ooo`D000000P3oool300000080oooo1`0000030?ooo`8000001@3oool2000000L0oooo1@000005
0?ooo`8000002@3oool300000080oooo1@0000070?ooo`/0dLfY0P0000030?ooo`8000001`3oool2
00000080oooo1@0000020?ooo`8000000P3oool300000080oooo2@0000020?ooo`<000000P3oool2
00000080oooo1@0000020?ooo`8000001`3oool2000000<0oooo0P00000;0=7=Z@@0oooo0`000006
0?ooo`T000000`3oool4000000@0oooo1@0000090?ooo`8000000P3oool500000080oooo0P000007
0?ooo`/000002`3AcJT20?ooo`8000000`3oool400000080oooo0P0000050?ooo`@000000P3oool4
000000<0oooo3@0000020?ooo`@000000P3oool5000000@0oooo0P0000020?ooo`D000000P3oool2
00000080oooo3P3AcJT000`0dLfY0P3oool300000080oooo0`0000020?ooo`<000001@3oool20000
00L0oooo1@0000050?ooo`8000000`3oool2000000<0oooo0P0000030?ooo`8000001`3oool80000
0080oooo0`0000020?ooo`/0dLfY0P3oool:000000D0oooo0P0000090?ooo`D000000P3oool<0000
00`0oooo0P0000080?ooo`L000000P3oool;0=7=Z@8000000`3oool2000000L0oooo0P0000020?oo
o`D000000P3oool200000080oooo0`0000020?ooo`T000000P3oool300000080oooo0P0000020?oo
o`D000000P3oool2000000L0oooo0P0000030?ooo`8000002`3AcJT40?ooo`<000001P3oool90000
00<0oooo100000040?ooo`D000002@3oool200000080oooo1@0000020?ooo`8000001`3oool;0000
00/0dLfY0P0000050?ooo`H00000103oool700000080oooo2@0000080?ooo`T000000P3oool70000
00@0oooo1`0000040?ooo`8000003P3AcJT000`0dLfY0P3oool300000080oooo0`0000020?ooo`<0
00001@3oool2000000L0oooo1@0000050?ooo`8000000`3oool2000000<0oooo0P0000030?ooo`80
00001`3oool800000080oooo0`0000020?ooo`/0dLfY0P3oool:000000D0oooo0P0000090?ooo`D0
00000P3oool<000000`0oooo0P0000080?ooo`L000000P3oool;0=7=Z@L0oooo100000070?ooo`D0
00000P3oool4000000<0oooo100000050?ooo`@000000`3oool400000080oooo1@0000070?ooo`@0
00001`3oool;0=7=Z@d0oooo0`0000060?ooo`D000001P3oool3000000@0oooo1@0000040?ooo`D0
00003@3oool2000000L0oooo0P00000;0=7=Z@8000001@3oool6000000@0oooo1`0000020?ooo`T0
0000203oool900000080oooo1`0000040?ooo`L00000103oool2000000h0dLfY000<0=7=Z@80oooo
1@0000030?ooo`D000000P3oool500000080oooo0`0000050?ooo`D00000103oool5000000P0oooo
0P00000D0?ooo`8000002`3AcJT50?ooo`8000001`3oool:000000@0oooo0`0000020?ooo`D00000
0P3oool7000000D0oooo1@0000040?ooo`P00000103oool300000080oooo2`3AcJT70?ooo`@00000
1`3oool500000080oooo100000030?ooo`@000001@3oool4000000<0oooo100000020?ooo`D00000
1`3oool4000000L0oooo2`3AcJT=0?ooo`<000001P3oool5000000H0oooo0`0000040?ooo`D00000
103oool5000000d0oooo0P0000070?ooo`8000002`3AcJT20?ooo`8000001@3oool600000080oooo
1@0000020?ooo`8000000P3oool2000000D0oooo0P0000040?ooo`8000001@3oool200000080oooo
0P0000020?ooo`D000000P3oool6000000D0oooo0P0000020?ooo`h0dLfY000<0=7=Z@80oooo1@00
00030?ooo`D000000P3oool500000080oooo0`0000050?ooo`D00000103oool5000000P0oooo0P00
000D0?ooo`8000002`3AcJT50?ooo`8000001`3oool:000000@0oooo0`0000020?ooo`D000000P3o
ool7000000D0oooo1@0000040?ooo`P00000103oool300000080oooo2`3AcJT20?ooo`T00000303o
ool200000080oooo0P0000030?ooo`8000000P3oool500000080oooo0P0000030?ooo`8000000P3o
ool2000000`0oooo2@0000020?ooo`/0dLfY100000030?ooo`@000000P3oool500000080oooo1@00
00020?ooo`@000000P3oool500000080oooo1@0000020?ooo`@000000`3oool400000080oooo1@00
00020?ooo`@000000`3oool4000000/0dLfY0P3oool2000000D0oooo1P0000020?ooo`D000000P3o
ool200000080oooo0P0000050?ooo`800000103oool2000000D0oooo0P0000020?ooo`8000000P3o
ool500000080oooo1P0000050?ooo`8000000P3oool>0=7=Z@00303AcJT50?ooo`8000000`3oool2
000000<0oooo1@0000020?ooo`8000001@3oool300000080oooo0`0000020?ooo`D000002P3oool2
000000<0oooo100000080?ooo`D000000P3oool;0=7=Z@D0oooo0P0000070?ooo`X00000103oool3
00000080oooo1@0000020?ooo`L000001@3oool5000000@0oooo200000040?ooo`<000000P3oool;
0=7=Z@80oooo2@00000<0?ooo`8000000P3oool2000000<0oooo0P0000020?ooo`D000000P3oool2
000000<0oooo0P0000020?ooo`800000303oool900000080oooo2`3AcJT4000000<0oooo10000002
0?ooo`D000000P3oool500000080oooo100000020?ooo`D000000P3oool500000080oooo10000003
0?ooo`@000000P3oool500000080oooo100000030?ooo`@000002`3AcJT2000000D0oooo0P000002
0?ooo`H000002`3oool7000000P0oooo1`00000;0?ooo`H000000P3oool3000000@0oooo0P00000>
0=7=Z@00303AcJT50?ooo`8000000`3oool2000000<0oooo1@0000020?ooo`8000001@3oool30000
0080oooo0`0000020?ooo`D000002P3oool2000000<0oooo100000080?ooo`D000000P3oool;0=7=
Z@T000001@3oool500000080oooo0`0000040?ooo`<000000P3oool2000000P0oooo0P0000070?oo
o`D000000P3oool500000080oooo2P0000020?ooo`/0dLfY0P3oool300000080oooo0P0000050?oo
o`@000000P3oool3000000@0oooo1`0000020?ooo`D000000P3oool7000000@0oooo0`0000020?oo
o`@000001@3oool200000080oooo0`0000020?ooo`/0dLfY100000030?ooo`@000000P3oool50000
0080oooo1@0000020?ooo`@000000P3oool500000080oooo1@0000020?ooo`@000000`3oool40000
0080oooo1@0000020?ooo`@000000`3oool4000000/0dLfY0P0000050?ooo`8000000P3oool60000
00/0oooo1`0000080?ooo`L000002`3oool600000080oooo0`0000040?ooo`8000003P3AcJT000`0
dLfY1@3oool2000000<0oooo0P0000030?ooo`D000000P3oool2000000D0oooo0`0000020?ooo`<0
00000P3oool5000000X0oooo0P0000030?ooo`@00000203oool500000080oooo2`3AcJT9000000D0
oooo1@0000020?ooo`<00000103oool300000080oooo0P0000080?ooo`8000001`3oool500000080
oooo1@0000020?ooo`X000000P3oool;0=7=Z@80oooo0`0000020?ooo`8000001@3oool400000080
oooo0`0000040?ooo`L000000P3oool500000080oooo1`0000040?ooo`<000000P3oool4000000D0
oooo0P0000020?ooo`<000000P3oool;0=7=Z@d000000`3oool6000000D0oooo1P0000030?ooo`@0
00001@3oool4000000D0oooo3@0000020?ooo`L000000P3oool;0=7=Z@80oooo0P0000090?ooo`L0
00000P3oool2000000T0oooo3@0000080?ooo`8000000`3oool6000000T0oooo0P0000020?ooo`h0
dLfY000<0=7=Z@`000000`3oool2000000L0oooo0`0000070?ooo`L000000`3oool7000000<0oooo
2@0000030?ooo`8000000`3oool7000000/0dLfY0P0000030?ooo`@00000303oool3000000@0oooo
5P0000070?ooo`@000004@3oool;0=7=Z@80oooo0`0000020?ooo`@000000`3oool6000000<0oooo
0P0000090?ooo`8000001@3oool2000000T0oooo0P0000030?ooo`H000000`3oool400000080oooo
0`0000020?ooo`/0dLfY3@0000030?ooo`H000001@3oool6000000<0oooo100000050?ooo`@00000
1@3oool=00000080oooo1`0000020?ooo`/0dLfY0P3oool2000000T0oooo1`0000020?ooo`800000
2@3oool=000000P0oooo0P0000030?ooo`H000002@3oool200000080oooo3P3AcJT000`0dLfY3000
00030?ooo`8000001`3oool3000000L0oooo1`0000030?ooo`L000000`3oool9000000<0oooo0P00
00030?ooo`L000002`3AcJT2000000<0oooo1000000<0?ooo`<00000103ooolF000000L0oooo1000
000A0?ooo`/0dLfY0P3oool300000080oooo100000030?ooo`H000000`3oool2000000T0oooo0P00
00050?ooo`8000002@3oool2000000<0oooo1P0000030?ooo`@000000P3oool300000080oooo2`3A
cJT20?ooo`8000000`3oool6000000T0oooo0`0000040?ooo`@000001@3oool900000080oooo0P00
00050?ooo`8000000P3oool7000000T0oooo0P00000;0=7=Z@8000001`3oool400000080oooo1`00
00040?ooo`8000000P3oool3000000d0oooo0P0000020?ooo`800000103oool700000080oooo1000
00070?ooo`8000003P3AcJT000`0dLfY0P0000030?ooo`8000001@3oool<000001@0oooo0P000003
0?ooo`D000001@3oool200000080oooo0`0000020?ooo`<000000P3oool5000000/0dLfY0P00000:
0?ooo`8000001`3oool3000000T0oooo0P0000080?ooo`8000000P3oool3000000@0oooo1@000002
0?ooo`D000002P3oool2000000/0dLfY0P3oool300000080oooo100000030?ooo`H000000`3oool2
000000T0oooo0P0000050?ooo`8000002@3oool2000000<0oooo1P0000030?ooo`@000000P3oool3
00000080oooo2`3AcJT20?ooo`8000000`3oool6000000T0oooo0`0000040?ooo`@000001@3oool9
00000080oooo0P0000050?ooo`8000000P3oool7000000T0oooo0P00000;0=7=Z@8000001`3oool4
00000080oooo1`0000040?ooo`8000000P3oool3000000d0oooo0P0000020?ooo`800000103oool7
00000080oooo100000070?ooo`8000003P3AcJT000`0dLfY0P0000030?ooo`8000001@3oool<0000
01@0oooo0P0000030?ooo`D000001@3oool200000080oooo0`0000020?ooo`<000000P3oool50000
00/0dLfY0P00000:0?ooo`8000001`3oool3000000T0oooo0P0000080?ooo`8000000P3oool30000
00@0oooo1@0000020?ooo`D000002P3oool2000000/0dLfY0P3oool500000080oooo1@0000020?oo
o`@00000303oool200000080oooo1@0000020?ooo`800000303oool400000080oooo1@0000020?oo
o`D000000P3oool;0=7=Z@@000001@3oool2000000T0oooo0P0000050?ooo`8000001`3oool20000
0100oooo100000040?ooo`<000002@3oool200000080oooo2`3AcJT20?ooo`D000000P3oool40000
00@0oooo1`0000040?ooo`8000000`3oool2000000P0oooo0`0000020?ooo`800000103oool70000
00@0oooo100000030?ooo`@000000P3oool>0=7=Z@00303AcJT2000000<0oooo300000050?ooo``0
00002P3oool2000000D0oooo2P00000A0?ooo`/0dLfY0P00000:0?ooo`8000001`3oool3000000T0
oooo0P0000080?ooo`8000000P3oool3000000@0oooo1@0000020?ooo`D000002P3oool2000000/0
dLfY0P3oool500000080oooo1@0000020?ooo`@00000303oool200000080oooo1@0000020?ooo`80
0000303oool400000080oooo1@0000020?ooo`D000000P3oool;0=7=Z@@000001@3oool2000000T0
oooo0P0000050?ooo`8000001`3oool200000100oooo100000040?ooo`<000002@3oool200000080
oooo2`3AcJT20?ooo`D000000P3oool4000000@0oooo1`0000040?ooo`8000000`3oool2000000P0
oooo0`0000020?ooo`800000103oool7000000@0oooo100000030?ooo`@000000P3oool>0=7=Z@00
303AcJT2000000<0oooo300000050?ooo``000002P3oool2000000D0oooo2P00000A0?ooo`/0dLfY
0P00000?0?ooo`8000000P3oool300000080oooo0P0000030?ooo`L000000P3oool500000080oooo
0`0000040?ooo`<00000103oool5000000<0oooo100000050?ooo`/0dLfY1@3oool2000000@0oooo
0`00000;0?ooo`@000001`3oool5000000L0oooo1000000;0?ooo`<00000103oool2000000D0oooo
2`3AcJT2000000D0oooo2`0000040?ooo`<00000103oool2000000L0oooo0P0000070?ooo`800000
1@3oool2000000@0oooo2`0000050?ooo`8000002`3AcJT9000000H0oooo0P0000030?ooo`@00000
0P3oool2000000T0oooo100000090?ooo`8000000P3oool500000080oooo0P0000060?ooo`T00000
3P3AcJT000`0dLfY0P0000030?ooo``000001@3oool<000000X0oooo0P0000050?ooo`X000004@3o
ool;0=7=Z@8000003`3oool200000080oooo0`0000020?ooo`8000000`3oool700000080oooo1@00
00020?ooo`<00000103oool3000000@0oooo1@0000030?ooo`@000001@3oool;0=7=Z@D0oooo0P00
00040?ooo`<000002`3oool4000000L0oooo1@0000070?ooo`@000002`3oool3000000@0oooo0P00
00050?ooo`/0dLfY0P0000050?ooo`/00000103oool3000000@0oooo0P0000070?ooo`8000001`3o
ool2000000D0oooo0P0000040?ooo`/000001@3oool2000000/0dLfY2@0000060?ooo`8000000`3o
ool400000080oooo0P0000090?ooo`@000002@3oool200000080oooo1@0000020?ooo`8000001P3o
ool9000000h0dLfY000<0=7=Z@D000001`3oool300000080oooo1@00000:0?ooo`8000000`3oool4
000000<0oooo0P0000030?ooo`8000003`3oool2000000<0oooo0P0000050?ooo`/0dLfY0P000003
0?ooo`L000001`3oool700000080oooo3`0000020?ooo`D00000103oool5000000L0oooo1`000005
0?ooo`/0dLfY1`0000020?ooo`D000001P3oool300000080oooo1000000C0?ooo`@000000P3oool3
000000H0oooo1@0000020?ooo`L000002`3AcJT4000000<0oooo100000050?ooo`8000000P3oool2
000000D0oooo0P0000040?ooo`D00000103oool3000000T0oooo100000020?ooo`D00000103oool2
000000<0oooo0P0000020?ooo`/0dLfY2@0000060?ooo`8000000`3oool400000080oooo0P000009
0?ooo`@000002@3oool200000080oooo1@0000020?ooo`8000001P3oool9000000h0dLfY000<0=7=
Z@D000001`3oool300000080oooo1@00000:0?ooo`8000000`3oool4000000<0oooo0P0000030?oo
o`8000003`3oool2000000<0oooo0P0000050?ooo`/0dLfY0P0000030?ooo`L000001`3oool70000
0080oooo3`0000020?ooo`D00000103oool5000000L0oooo1`0000050?ooo`/0dLfY1`0000020?oo
o`D000001P3oool300000080oooo1000000C0?ooo`@000000P3oool3000000H0oooo1@0000020?oo
o`L000002`3AcJT4000000<0oooo100000050?ooo`8000000P3oool2000000D0oooo0P0000040?oo
o`D00000103oool3000000T0oooo100000020?ooo`D00000103oool2000000<0oooo0P0000020?oo
o`/0dLfY2`00000=0?ooo`8000000P3oool5000000@0oooo100000050?ooo`@000000P3oool20000
00d0oooo2`00000>0=7=Z@00303AcJT20?ooo`D000000`3oool500000080oooo1`0000050?oooa@0
00000P3oool3000000L0oooo0P0000050?ooo`<000001@3oool2000000/0dLfY1`0000020?ooo`<0
00000P3oool<00000080oooo2P0000070?ooo`8000002P3oool2000000D0oooo1`0000050?ooo`80
00002`3AcJT2000000D0oooo100000050?ooo`8000001@3oool2000000L0oooo100000050?ooo`@0
00001`3oool2000000D0oooo0P0000050?ooo`@000001@3oool2000000/0dLfY100000030?ooo`@0
00001@3oool200000080oooo0P0000050?ooo`800000103oool5000000@0oooo0`0000090?ooo`@0
00000P3oool5000000@0oooo0P0000030?ooo`8000000P3oool;0=7=Z@/000003@3oool200000080
oooo1@0000040?ooo`@000001@3oool400000080oooo0P00000=0?ooo`/000003P3AcJT000`0dLfY
0P3oool5000000<0oooo1@0000020?ooo`L000001@3ooolD00000080oooo0`0000070?ooo`800000
1@3oool3000000D0oooo0P00000;0=7=Z@L000000P3oool300000080oooo300000020?ooo`X00000
1`3oool2000000X0oooo0P0000050?ooo`L000001@3oool2000000/0dLfY0P0000050?ooo`@00000
1@3oool2000000D0oooo0P0000070?ooo`@000001@3oool4000000L0oooo0P0000050?ooo`800000
1@3oool4000000D0oooo0P00000;0=7=Z@80oooo1@0000040?ooo`T000000P3oool3000000@0oooo
0P0000020?ooo`L000002@3oool2000000D0oooo100000050?ooo`T000000P3oool2000000/0dLfY
0P3oool900000080oooo0P0000020?ooo`<000000P3oool2000000@0oooo1@00000=0?ooo`@00000
103oool2000000<0oooo0P0000020?ooo`8000000P3oool900000080oooo3P3AcJT000`0dLfY0P3o
ool5000000<0oooo1@0000020?ooo`L000001@3ooolD00000080oooo0`0000070?ooo`8000001@3o
ool3000000D0oooo0P00000;0=7=Z@L000000P3oool300000080oooo300000020?ooo`X000001`3o
ool2000000X0oooo0P0000050?ooo`L000001@3oool2000000/0dLfY0P0000050?ooo`@000001@3o
ool2000000D0oooo0P0000070?ooo`@000001@3oool4000000L0oooo0P0000050?ooo`8000001@3o
ool4000000D0oooo0P00000;0=7=Z@80oooo1@0000040?ooo`T000000P3oool3000000@0oooo0P00
00020?ooo`L000002@3oool2000000D0oooo100000050?ooo`T000000P3oool2000000/0dLfY0P3o
ool900000080oooo0P0000020?ooo`<000000P3oool2000000@0oooo1@00000=0?ooo`@00000103o
ool2000000<0oooo0P0000020?ooo`8000000P3oool900000080oooo3P3AcJT000`0dLfY0P000003
0?ooo`L000000`3oool2000000<0oooo100000050?ooo`D000000`3oool4000000<0oooo1@000007
0?ooo`<000001`3oool2000000<0oooo0P0000050?ooo`/0dLfY2@3oool800000080oooo1@000002
0?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`h000001@3oool500000080oooo0P000005
0?ooo`/0dLfY2@0000020?ooo`<000001P3oool300000080oooo0P0000050?ooo`@000001@3oool4
000000D0oooo0P0000020?ooo`<000001P3oool300000080oooo2@00000;0=7=Z@8000000P3oool9
000000<0oooo100000070?ooo`8000000P3oool2000000<0oooo100000050?ooo`8000001`3oool2
00000080oooo2@0000020?ooo`D00000103oool;0=7=Z@8000000P3oool500000080oooo0P000002
0?ooo`8000000`3oool200000080oooo0P0000090?ooo`800000103oool2000000T0oooo0P000002
0?ooo`<000000P3oool200000080oooo0P0000020?ooo`D000000P3oool2000000h0dLfY000<0=7=
Z@8000000`3oool7000000<0oooo0P0000030?ooo`@000001@3oool5000000<0oooo100000030?oo
o`D000001`3oool3000000L0oooo0P0000030?ooo`8000001@3oool;0=7=Z@T0oooo200000020?oo
o`D000000P3oool2000000<0oooo100000030?ooo`8000001@3oool>000000D0oooo1@0000020?oo
o`8000001@3oool;0=7=Z@T000000P3oool3000000H0oooo0`0000020?ooo`8000001@3oool40000
00D0oooo100000050?ooo`8000000P3oool3000000H0oooo0`0000020?ooo`T000002`3AcJT20000
0080oooo2@0000030?ooo`@000001`3oool200000080oooo0P0000030?ooo`@000001@3oool20000
00L0oooo0P0000020?ooo`T000000P3oool5000000@0oooo2`3AcJT200000080oooo1@0000020?oo
o`8000000P3oool2000000<0oooo0P0000020?ooo`8000002@3oool2000000@0oooo0P0000090?oo
o`8000000P3oool300000080oooo0P0000020?ooo`8000000P3oool500000080oooo0P00000>0=7=
Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=
Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=
Z@00o`3AcJW<0=7=Z@00_P3AcJT3000000D0oooo1@0000030?ooo`<000001@3oool300000080oooo
1P0000020?ooo`H000001@3oool2000001/0oooo`03AcJT000`0dLfY0`0000030?ooo`H000001@3o
ool3000000<0oooo0`0000060?ooo`H000000P3oool6000000H0oooo0`0000030?ooo`<000001@3o
ool6000000<0oooo0`00000;0=7=Z@<000000`3oool5000000<0oooo0`0000030?ooo`8000001P3o
ool3000000D0oooo1P0000050?ooo`<000001P3oool300000080oooo0`0000030?ooo`D000000`3o
ool3000000/0dLfY0`0000050?ooo`D000000`3oool3000000D0oooo0`0000020?ooo`H000000P3o
ool6000000D0oooo0P00000K0?ooo`/0dLfY0`0000020?ooo`P000000`3oool7000003L0oooo2`3A
cJT5000000<0oooo0P0000030?ooo`L000000`3oool2000000D0oooo1@0000030?ooo`8000000`3o
ool5000000D0oooo0P0000030?ooo`L000000`3oool2000000<0oooo1@00000>0=7=Z@00303AcJT3
000000<0oooo1P0000050?ooo`<000000`3oool3000000H0oooo1P0000020?ooo`H000001P3oool3
000000<0oooo0`0000050?ooo`H000000`3oool3000000/0dLfY0`0000030?ooo`D000000`3oool3
000000<0oooo0P0000060?ooo`<000001@3oool6000000D0oooo0`0000060?ooo`<000000P3oool3
000000<0oooo1@0000030?ooo`<000002`3AcJT3000000D0oooo1@0000030?ooo`<000001@3oool3
00000080oooo1P0000020?ooo`H000001@3oool2000001/0oooo2`3AcJT300000080oooo20000003
0?ooo`L00000=`3oool;0=7=Z@D000000`3oool2000000<0oooo1`0000030?ooo`8000001@3oool5
000000<0oooo0P0000030?ooo`D000001@3oool2000000<0oooo1`0000030?ooo`8000000`3oool5
000000h0dLfY000<0=7=Z@<000000`3oool6000000D0oooo0`0000030?ooo`<000001P3oool60000
0080oooo1P0000060?ooo`<000000`3oool3000000D0oooo1P0000030?ooo`<000002`3AcJT30000
00<0oooo1@0000030?ooo`<000000`3oool2000000H0oooo0`0000050?ooo`H000001@3oool30000
00H0oooo0`0000020?ooo`<000000`3oool5000000<0oooo0`00000;0=7=Z@P0oooo2000000;0?oo
oa0000002P3ooolH000000/0dLfY0`0000020?ooo`P000000`3oool7000003L0oooo2`3AcJT80000
0080oooo1@0000030?ooo`D000001`3oool800000080oooo200000070?ooo`D000000`3oool50000
0080oooo2000000>0=7=Z@00303AcJT30?ooo`T00000203oool3000000T0oooo3P0000090?ooo`<0
0000203oool9000000<0oooo2`3AcJT30?ooo`/000000`3oool300000100oooo1P00000A0?ooo`80
00000`3oool;000000<0oooo2`3AcJT80?ooo`P000002`3oool@000000X0oooo6000000;0=7=Z@<0
oooo1@0000020?ooo`P000000`3oool2000000<0oooo=000000;0=7=Z@P000000P3oool5000000<0
oooo1@0000070?ooo`P000000P3oool8000000L0oooo1@0000030?ooo`D000000P3oool8000000h0
dLfY000<0=7=Z@<0oooo2@0000080?ooo`<000002@3oool>000000T0oooo0`0000080?ooo`T00000
0`3oool;0=7=Z@<0oooo2`0000030?ooo`<00000403oool600000140oooo0P0000030?ooo`/00000
0`3oool;0=7=Z@<0oooo0P0000060?oooaP000000P3oool3000000D0oooo0`0000050?ooo`<00000
4P3oool3000000/0dLfY0`3oool500000080oooo200000030?ooo`8000000`3ooold000000/0dLfY
200000020?ooo`D000000`3oool5000000L0oooo200000020?ooo`P000001`3oool5000000<0oooo
1@0000020?ooo`P000003P3AcJT000`0dLfY0`3oool9000000P0oooo0`0000090?ooo`h000002@3o
ool3000000P0oooo2@0000030?ooo`/0dLfY0`3oool;000000<0oooo0`00000@0?ooo`H000004@3o
ool2000000<0oooo2`0000030?ooo`/0dLfY0`3oool2000000H0oooo600000020?ooo`<000001@3o
ool3000000D0oooo0`00000B0?ooo`<000002`3AcJT500000100oooo2000000^0?ooo`<000002`3A
cJT30?ooo`D000000P3oool3000000L0oooo200000050?ooo`D000000P3oool5000000D0oooo2000
00070?ooo`<000000P3oool600000080oooo3P3AcJT000`0dLfY2@0000050?ooo`H000000`3oool6
000000H0oooo0`0000020?ooo`<000001P3oool6000000<0oooo1P0000050?ooo`T000002`3AcJT>
000000H0oooo200000030?ooo`800000303oool2000000<0oooo2@0000050?ooo`h000002`3AcJT3
0?ooo`8000001P3ooolH00000080oooo0`0000050?ooo`<000001@3oool300000180oooo0`00000;
0=7=Z@D00000403oool8000002h0oooo0`00000;0=7=Z@<0oooo1@0000020?ooo`<000001`3oool8
000000D0oooo1@0000020?ooo`D000001@3oool8000000L0oooo0`0000020?ooo`H000000P3oool>
0=7=Z@00303AcJT9000000D0oooo1P0000030?ooo`H000001P3oool300000080oooo0`0000060?oo
o`H000000`3oool6000000D0oooo2@00000;0=7=Z@h000001P3oool8000000<0oooo0P00000<0?oo
o`8000000`3oool9000000D0oooo3P00000;0=7=Z@P0oooo0`0000020?ooo`<000002`3oool50000
00D0oooo1P00000:0?ooo`D000003P3oool5000000/0dLfY1@00000@0?ooo`P00000;P3oool30000
00/0dLfY0`0000050?ooo``000001@3oool300000080oooo0`0000050?ooo`8000001@3oool30000
0080oooo0`0000050?ooo``000001P3oool2000000h0dLfY000<0=7=Z@T000001@3oool6000000<0
oooo1P0000060?ooo`<000000P3oool3000000H0oooo1P0000030?ooo`H000001@3oool9000000/0
dLfY2`0000060?ooo`D000000`3oool600000100oooo1P0000030?ooo`D000001P3oool;000000/0
dLfY203oool300000080oooo0`00000;0?ooo`D000001@3oool6000000X0oooo1@00000>0?ooo`D0
00002`3AcJT300000080oooo1@00000C0?ooo`800000:P3oool5000000/0dLfY0`0000050?ooo``0
00001@3oool300000080oooo0`0000050?ooo`8000001@3oool300000080oooo0`0000050?ooo``0
00001P3oool2000000h0dLfY000<0=7=Z@H000000`3oool300000080oooo1P0000030?ooo`H00000
0`3oool600000080oooo1P0000030?ooo`H000000`3oool600000080oooo0`0000030?ooo`H00000
2`3AcJT;000000H0oooo1@0000030?ooo`H00000403oool6000000<0oooo1@0000060?ooo`/00000
2`3AcJT80?ooo`<000000P3oool3000000/0oooo1@0000050?ooo`H000002P3oool5000000h0oooo
1@00000;0=7=Z@<000000P3oool5000001<0oooo0P00000Z0?ooo`D000002`3AcJT3000000D0oooo
300000050?ooo`<000000P3oool3000000D0oooo0P0000050?ooo`<000000P3oool3000000D0oooo
300000060?ooo`8000003P3AcJT000`0dLfY1P0000030?ooo`<000000P3oool6000000<0oooo1P00
00030?ooo`H000000P3oool6000000<0oooo1P0000030?ooo`H000000P3oool3000000<0oooo1P00
000;0=7=Z@/000001P3oool5000000<0oooo1P00000@0?ooo`H000000`3oool5000000H0oooo2`00
000;0=7=Z@<000002P3oool6000000D0oooo0`0000050?ooo`<000001@3oool3000000D0oooo0P00
00060?ooo`8000000`3oool8000000<0oooo0P0000030?ooo`/0dLfY0`0000020?ooo`D000000`3o
ool8000000D0oooo0`0000050?ooob@000000`3oool2000000<0oooo2`3AcJT30?ooo`X000001@3o
ool<000000<0oooo1@0000020?ooo`D000000`3oool<000000D0oooo2`0000020?ooo`h0dLfY000<
0=7=Z@`0oooo0P0000060?ooo`<000001P3oool6000000<0oooo0P0000030?ooo`H000001P3oool3
000000H0oooo0P00000<0?ooo`/0dLfY0`3oool5000000<0oooo0`0000030?ooo`<00000203ooolF
000000T0oooo0P0000030?ooo`<000000`3oool5000000<0oooo2`3AcJT3000000X0oooo1P000005
0?ooo`<000001@3oool3000000D0oooo0`0000050?ooo`8000001P3oool2000000<0oooo20000003
0?ooo`8000000`3oool;0=7=Z@<000000P3oool5000000<0oooo200000050?ooo`<000001@3ooolT
000000<0oooo0P0000030?ooo`/0dLfY0`3oool:000000D0oooo300000030?ooo`D000000P3oool5
000000<0oooo300000050?ooo`/000000P3oool>0=7=Z@00303AcJT<0?ooo`8000001P3oool30000
00H0oooo1P0000030?ooo`8000000`3oool6000000H0oooo0`0000060?ooo`800000303oool;0=7=
Z@<0oooo1@0000030?ooo`<000000`3oool3000000P0oooo5P0000090?ooo`8000000`3oool30000
00<0oooo1@0000030?ooo`/0dLfY1@3oool3000000P0oooo0`0000080?ooo`D000001@3oool60000
00X0oooo2`0000020?ooo`/000002`3AcJT300000080oooo1@0000030?ooo`P000001@3oool30000
00D0oooo900000030?ooo`8000000`3oool;0=7=Z@D000000`3oool2000000<0oooo1@0000070?oo
o`D000000`3oool500000080oooo1@0000030?ooo`D000001`3oool5000000<0oooo0P0000030?oo
o`D000003P3AcJT000`0dLfY303oool2000000H0oooo0`0000060?ooo`H000000`3oool2000000<0
oooo1P0000060?ooo`<000001P3oool2000000`0oooo2`3AcJT30?ooo`D000000`3oool3000000<0
oooo0`0000080?oooaH000002@3oool2000000<0oooo0`0000030?ooo`D000000`3oool;0=7=Z@D0
oooo0`0000080?ooo`<00000203oool5000000D0oooo1P00000:0?ooo`/000000P3oool;000000/0
dLfY1@0000050?ooo`H000000P3oool3000000P0oooo0P0000030?ooo`800000803oool:000000/0
dLfY1@0000030?ooo`8000000`3oool5000000L0oooo1@0000030?ooo`D000000P3oool5000000<0
oooo1@0000070?ooo`D000000`3oool2000000<0oooo1@00000>0=7=Z@00303AcJT60?ooo`H00000
0P3oool6000000<0oooo2@00000>0?ooo`T000000`3oool600000080oooo1P0000060?ooo`/0dLfY
0`00000;0?ooo`h000005P3oool>000000/0oooo0`00000;0=7=Z@D0oooo0`0000080?ooo`<00000
203oool5000000D0oooo1P00000:0?ooo`/000000P3oool;000000/0dLfY1@0000050?ooo`H00000
0P3oool3000000P0oooo0P0000030?ooo`800000803oool:000000/0dLfY1@0000030?ooo`800000
0`3oool5000000L0oooo1@0000030?ooo`D000000P3oool5000000<0oooo1@0000070?ooo`D00000
0`3oool2000000<0oooo1@00000>0=7=Z@00303AcJT60?ooo`H000000P3oool6000000<0oooo2@00
000>0?ooo`T000000`3oool600000080oooo1P0000060?ooo`/0dLfY0`00000;0?ooo`h000005P3o
ool>000000/0oooo0`00000;0=7=Z@/0oooo200000020?ooo`h000000P3oool3000000D0oooo0`00
00050?ooo`D000003P3oool5000000/0dLfY0`3oool:000000D0oooo0`0000020?ooo`H000000P3o
ool8000001X0oooo0`0000050?ooo`D000002`3AcJT3000000D0oooo0P0000030?ooo`L000000`3o
ool2000000D0oooo0`0000050?ooo`8000001@3oool3000000D0oooo0P0000030?ooo`L000000`3o
ool2000000H0oooo0P00000>0=7=Z@00303AcJT60?ooo`H000000P3oool6000000<0oooo2@00000>
0?ooo`T000000`3oool600000080oooo1P0000060?ooo`/0dLfY0`00000;0?ooo`h000005P3oool>
000000/0oooo0`00000;0=7=Z@/0oooo200000020?ooo`h000000P3oool3000000D0oooo0`000005
0?ooo`D000003P3oool5000000/0dLfY0`3oool:000000D0oooo0`0000020?ooo`H000000P3oool8
000001X0oooo0`0000050?ooo`D000002`3AcJT3000000D0oooo0P0000030?ooo`L000000`3oool2
000000D0oooo0`0000050?ooo`8000001@3oool3000000D0oooo0P0000030?ooo`L000000`3oool2
000000H0oooo0P00000>0=7=Z@00303AcJT3000000<0oooo1P0000020?ooo`H000000`3oool30000
00H0oooo1P0000020?ooo`H000001P3oool3000000<0oooo1P0000020?ooo`H000000`3oool30000
00/0dLfY0`3oool300000080oooo300000050?ooo`H00000403oool6000000H0oooo2`0000020?oo
o`<000000`3oool;0=7=Z@/0oooo200000020?ooo`h000000P3oool3000000D0oooo0`0000050?oo
o`D000003P3oool5000000/0dLfY0`3oool:000000D0oooo0`0000020?ooo`H000000P3oool80000
01X0oooo0`0000050?ooo`D000002`3AcJT5000000<0oooo1@0000020?ooo`P000000P3oool50000
00<0oooo1@0000020?ooo`D000000`3oool500000080oooo200000020?ooo`D000000`3oool50000
00h0dLfY000<0=7=Z@<000000`3oool600000080oooo1P0000030?ooo`<000001P3oool600000080
oooo1P0000060?ooo`<000000`3oool600000080oooo1P0000030?ooo`<000002`3AcJT30?ooo`<0
00000P3oool<000000D0oooo1P00000@0?ooo`H000001P3oool;00000080oooo0`0000030?ooo`/0
dLfY1@0000060?ooo`8000001P3oool5000000<0oooo4000000?0?ooo`<000000`3oool2000000<0
oooo0`0000050?ooo`/0dLfY0`00000:0?ooo`<000000P3oool;00000080oooo200000030?oooa@0
00001P3oool5000000D0oooo2`3AcJT5000000<0oooo1@0000020?ooo`P000000P3oool5000000<0
oooo1@0000020?ooo`D000000`3oool500000080oooo200000020?ooo`D000000`3oool5000000h0
dLfY000<0=7=Z@<000000`3oool600000080oooo1P0000030?ooo`<000001P3oool600000080oooo
1P0000060?ooo`<000000`3oool600000080oooo1P0000030?ooo`<000002`3AcJT3000000<0oooo
1@0000030?ooo`<000000`3oool5000000<0oooo0`0000020?ooo``000000P3oool3000000<0oooo
1P0000020?ooo`<000000`3oool5000000<0oooo0`00000;0=7=Z@D000001P3oool2000000H0oooo
1@0000030?oooa0000003`3oool3000000<0oooo0P0000030?ooo`<000001@3oool;0=7=Z@<00000
2P3oool300000080oooo2`0000020?ooo`P000000`3ooolD000000H0oooo1@0000050?ooo`/0dLfY
1@0000030?ooo`D000000P3oool800000080oooo1@0000030?ooo`D000000P3oool5000000<0oooo
1@0000020?ooo`P000000P3oool5000000<0oooo1@00000>0=7=Z@00303AcJT30?ooo`<000001P3o
ool2000000H0oooo9P0000060?ooo`8000001P3oool3000000<0oooo2`3AcJT3000000<0oooo1@00
00030?ooo`<000000`3oool5000000<0oooo0`0000020?ooo``000000P3oool3000000<0oooo1P00
00020?ooo`<000000`3oool5000000<0oooo0`00000;0=7=Z@D000001P3oool2000000H0oooo1@00
00030?oooa0000003`3oool3000000<0oooo0P0000030?ooo`<000001@3oool;0=7=Z@<000002P3o
ool300000080oooo2`0000020?ooo`P000000`3ooolD000000H0oooo1@0000050?ooo`/0dLfY0`3o
ool500000080oooo0`0000050?ooo`D000000P3oool5000000<0oooo1@0000020?ooo`D000000`3o
ool500000080oooo1@0000050?ooo`<000000P3oool600000080oooo3P3AcJT000`0dLfY0`3oool3
000000H0oooo0P0000060?ooobH000001P3oool2000000H0oooo0`0000030?ooo`/0dLfY0`000003
0?ooo`D000000`3oool3000000<0oooo1@0000030?ooo`<000000P3oool<00000080oooo0`000003
0?ooo`H000000P3oool3000000<0oooo1@0000030?ooo`<000002`3AcJT5000000H0oooo2P000008
0?ooo`H000000P3oool6000000D0oooo1@0000030?ooo`8000000`3oool300000080oooo0`000003
0?ooo`8000000`3oool;0=7=Z@<0oooo0P0000050?ooo`<000000`3oool2000000D0oooo0`000003
0?ooo`8000000`3oool2000000<0oooo1@00000@0?ooo`8000000`3oool:000000<0oooo2`3AcJT3
0?ooo`D000000P3oool3000000D0oooo1@0000020?ooo`D000000`3oool500000080oooo1@000003
0?ooo`D000000P3oool5000000D0oooo0`0000020?ooo`H000000P3oool>0=7=Z@00303AcJT30?oo
o`<000001P3oool2000000H0oooo9P0000060?ooo`8000001P3oool3000000<0oooo2`3AcJT60?oo
o`8000001P3oool3000000<0oooo1@0000030?ooo`P000001P3oool8000000<0oooo1P0000020?oo
o`<000001P3oool2000000H0oooo2`3AcJT5000000H0oooo2P0000080?ooo`H000000P3oool60000
00D0oooo1@0000030?ooo`8000000`3oool300000080oooo0`0000030?ooo`8000000`3oool;0=7=
Z@<0oooo0P0000050?ooo`<000000`3oool2000000D0oooo0`0000030?ooo`8000000`3oool20000
00<0oooo1@00000@0?ooo`8000000`3oool:000000<0oooo2`3AcJT300000080oooo0`0000020?oo
o`<000000P3oool3000000D0oooo0P0000050?ooo`<000001@3oool2000000D0oooo0`0000050?oo
o`8000001@3oool300000080oooo0`0000020?ooo`<000000`3oool2000000h0dLfY000<0=7=Z@<0
00000`3oool600000080oooo300000060?ooo`H000000P3oool6000000H0oooo300000020?ooo`H0
00000`3oool3000000/0dLfY1P3oool2000000H0oooo0`0000030?ooo`D000000`3oool8000000H0
oooo200000030?ooo`H000000P3oool3000000H0oooo0P0000060?ooo`/0dLfY5@3oool8000001<0
oooo2000000E0?ooo`/0dLfY0`00000?0?ooo`P00000203oool2000000<0oooo0`0000020?ooo`<0
00002P3ooolB000000<0oooo2`3AcJT300000080oooo0`0000020?ooo`<000000P3oool3000000D0
oooo0P0000050?ooo`<000001@3oool2000000D0oooo0`0000050?ooo`8000001@3oool300000080
oooo0`0000020?ooo`<000000`3oool2000000h0dLfY000<0=7=Z@<000000`3oool600000080oooo
300000060?ooo`H000000P3oool6000000H0oooo300000020?ooo`H000000`3oool3000000/0dLfY
1P3oool2000000H0oooo0`0000030?ooo`D000000`3oool8000000H0oooo200000030?ooo`H00000
0P3oool3000000H0oooo0P0000060?ooo`/0dLfY5@3oool8000001<0oooo2000000E0?ooo`/0dLfY
0`00000?0?ooo`P00000203oool2000000<0oooo0`0000020?ooo`<000002P3ooolB000000<0oooo
2`3AcJT300000080oooo0`0000020?ooo`<000000P3oool3000000D0oooo0P0000050?ooo`<00000
1@3oool2000000D0oooo0`0000050?ooo`8000001@3oool300000080oooo0`0000020?ooo`<00000
0`3oool2000000h0dLfY000<0=7=Z@<000000`3oool600000080oooo300000060?ooo`H000000P3o
ool6000000H0oooo300000020?ooo`H000000`3oool3000000/0dLfY1P3oool5000000<0oooo1P00
00050?ooo`<00000203oool6000000P0oooo0`0000060?ooo`D000000`3oool5000000H0oooo2`3A
cJTE0?ooo`P000004`3oool8000001D0oooo2`3AcJT3000000l0oooo200000080?ooo`8000000`3o
ool300000080oooo0`00000:0?oooa8000000`3oool;0=7=Z@D0oooo2P0000030?ooo`D000000P3o
ool5000000<0oooo1@0000020?ooo`D000000`3oool500000080oooo1@0000030?ooo`X000001@3o
ool>0=7=Z@00303AcJT60?ooo`H000000P3oool3000000<0oooo0`0000030?ooo`H000003P3oool6
000000<0oooo0`0000030?ooo`<000000P3oool6000000H0oooo2`3AcJT60?ooo`D000000`3oool6
000000D0oooo0`0000080?ooo`H00000203oool3000000H0oooo1@0000030?ooo`D000001P3oool;
0=7=Z@D0oooo1P0000080?ooo`D000000`3oool5000000<0oooo0P0000060?ooo`8000001@3oool;
000000<0oooo0P0000030?ooo`<000000P3oool3000000/0dLfY0`3oool7000000<0oooo2000000=
0?ooo`P000001`3oool600000080oooo1@0000030?ooo`P000001@3oool;0=7=Z@D0oooo2P000003
0?ooo`D000000P3oool5000000<0oooo1@0000020?ooo`D000000`3oool500000080oooo1@000003
0?ooo`X000001@3oool>0=7=Z@00303AcJT60?ooo`H000000P3oool3000000<0oooo0`0000030?oo
o`H000003P3oool6000000<0oooo0`0000030?ooo`<000000P3oool6000000H0oooo2`3AcJT60?oo
o`D000000`3oool6000000D0oooo0`0000080?ooo`H00000203oool3000000H0oooo1@0000030?oo
o`D000001P3oool;0=7=Z@D0oooo1P0000080?ooo`D000000`3oool5000000<0oooo0P0000060?oo
o`8000001@3oool;000000<0oooo0P0000030?ooo`<000000P3oool3000000/0dLfY0`3oool70000
00<0oooo2000000=0?ooo`P000001`3oool600000080oooo1@0000030?ooo`P000001@3oool;0=7=
Z@X0oooo1@0000030?ooo`D000000P3oool5000000<0oooo1@0000020?ooo`D000000`3oool50000
0080oooo1@0000030?ooo`D000002P3oool>0=7=Z@00303AcJT60?ooo`H000000P3oool3000000<0
oooo0`0000030?ooo`H000003P3oool6000000<0oooo0`0000030?ooo`<000000P3oool6000000H0
oooo2`3AcJT3000000D0oooo1P0000030?ooo`P000000`3oool300000080oooo300000020?ooo`<0
00000`3oool8000000<0oooo1P0000050?ooo`<000002`3AcJT50?ooo`H00000203oool5000000<0
oooo1@0000030?ooo`8000001P3oool2000000D0oooo2`0000030?ooo`8000000`3oool300000080
oooo0`00000;0=7=Z@D000000`3oool8000000D0oooo0P0000030?ooo`D000004P3oool8000000/0
oooo0P0000030?ooo`D000002`3AcJT:0?ooo`D000000`3oool500000080oooo1@0000030?ooo`D0
00000P3oool5000000<0oooo1@0000020?ooo`D000000`3oool5000000X0oooo3P3AcJT000`0dLfY
303oool5000000<0oooo0`0000030?ooo`T000000`3oool2000000<0oooo2@0000030?ooo`<00000
0`3oool5000000`0oooo2`3AcJT3000000D0oooo1P0000030?ooo`P000000`3oool300000080oooo
300000020?ooo`<000000`3oool8000000<0oooo1P0000050?ooo`<000002`3AcJT300000080oooo
1P0000020?ooo`<000000`3oool2000000P0oooo1P00000=0?ooo`8000000`3oool300000080oooo
1P0000020?ooo`<000000`3oool2000000<0oooo2`3AcJT5000000<0oooo200000050?ooo`800000
0`3oool500000180oooo2000000;0?ooo`8000000`3oool5000000/0dLfY2P3oool5000000<0oooo
1@0000020?ooo`D000000`3oool500000080oooo1@0000030?ooo`D000000P3oool5000000<0oooo
1@00000:0?ooo`h0dLfY000<0=7=Z@`0oooo1@0000030?ooo`<000000`3oool9000000<0oooo0P00
00030?ooo`T000000`3oool3000000<0oooo1@00000<0?ooo`/0dLfY1P3oool2000000<0oooo0`00
00080?ooo`<000001P3oool@000000H0oooo0`0000080?ooo`<000000`3oool2000000H0oooo2`3A
cJT300000080oooo1P0000020?ooo`<000000`3oool2000000P0oooo1P00000=0?ooo`8000000`3o
ool300000080oooo1P0000020?ooo`<000000`3oool2000000<0oooo2`3AcJT5000000<0oooo2000
00050?ooo`8000000`3oool500000180oooo2000000;0?ooo`8000000`3oool5000000/0dLfY1@00
00030?ooo`8000001@3oool3000000D0oooo0P0000050?ooo`<000001@3oool2000000D0oooo0`00
00050?ooo`8000001@3oool3000000D0oooo0P0000030?ooo`D000003P3AcJT000`0dLfY1P000003
0?ooo`D000000`3oool9000000<0oooo2@0000020?ooo`T000000`3oool9000000<0oooo1@000003
0?ooo`H000002`3AcJT60?ooo`8000000`3oool3000000P0oooo0`0000060?oooa0000001P3oool3
000000P0oooo0`0000030?ooo`8000001P3oool;0=7=Z@<0oooo0P0000060?ooo`8000000`3oool=
000000<0oooo2`00000:0?ooo`<000001@3oool3000000X0oooo0`00000;0=7=Z@<000003@3oool5
00000080oooo2000000;0?ooo`D000001@3oool800000080oooo200000030?ooo`D000002`3AcJT5
000000<0oooo0P0000050?ooo`<000001@3oool2000000D0oooo0`0000050?ooo`8000001@3oool3
000000D0oooo0P0000050?ooo`<000001@3oool2000000<0oooo1@00000>0=7=Z@00303AcJT60000
00<0oooo1@0000030?ooo`T000000`3oool900000080oooo2@0000030?ooo`T000000`3oool50000
00<0oooo1P00000;0=7=Z@H0oooo0P0000030?ooo`<00000203oool3000000H0oooo400000060?oo
o`<00000203oool3000000<0oooo0P0000060?ooo`/0dLfY0`3oool2000000H0oooo0P0000030?oo
o`d000000`3oool;000000X0oooo0`0000050?ooo`<000002P3oool3000000/0dLfY0`00000=0?oo
o`D000000P3oool8000000/0oooo1@0000050?ooo`P000000P3oool8000000<0oooo1@00000;0=7=
Z@P000000P3oool5000000<0oooo1@0000020?ooo`D000000`3oool500000080oooo1@0000030?oo
o`D000000P3oool5000000<0oooo1@0000020?ooo`P000003P3AcJT000`0dLfY1P0000030?ooo`D0
00000`3oool9000000<0oooo2@0000020?ooo`T000000`3oool9000000<0oooo1@0000030?ooo`H0
00002`3AcJT;0?ooo`<000001P3oool5000000<0oooo5P0000030?ooo`H000001@3oool3000000/0
oooo2`3AcJT30?ooo`8000001P3oool2000000<0oooo3@0000030?ooo`/000002P3oool3000000D0
oooo0`00000:0?ooo`<000002`3AcJT8000000D0oooo200000020?ooo`H000001@3oool5000000<0
oooo1@0000020?ooo`<000000`3oool:000000D0oooo0`0000050?ooo`/0dLfY200000020?ooo`D0
00000`3oool500000080oooo1@0000030?ooo`D000000P3oool5000000<0oooo1@0000020?ooo`D0
00000`3oool500000080oooo2000000>0=7=Z@00303AcJT<000000D0oooo2@0000060?ooo`H00000
0P3oool6000000H0oooo2@0000050?ooo``000002`3AcJT;0?ooo`<000001P3oool5000000<0oooo
5P0000030?ooo`H000001@3oool3000000/0oooo2`3AcJT300000080oooo1P0000050?ooo`D00000
1P3oool2000000/0oooo0`0000020?ooo`<000001@3oool300000080oooo1P0000050?ooo`D00000
0`3oool;0=7=Z@P000001@3oool800000080oooo1P0000050?ooo`D000000`3oool500000080oooo
0`0000030?ooo`X000001@3oool3000000D0oooo2`3AcJT800000080oooo1@0000030?ooo`D00000
0P3oool5000000<0oooo1@0000020?ooo`D000000`3oool500000080oooo1@0000030?ooo`D00000
0P3oool8000000h0dLfY000<0=7=Z@`000001@3oool9000000H0oooo1P0000020?ooo`H000001P3o
ool9000000D0oooo3000000;0=7=Z@/0oooo0`0000060?ooo`D000000`3ooolF000000<0oooo1P00
00050?ooo`<000002`3oool;0=7=Z@<000000P3oool6000000D0oooo1@0000060?ooo`8000002`3o
ool300000080oooo0`0000050?ooo`<000000P3oool6000000D0oooo1@0000030?ooo`/0dLfY2000
00050?ooo`P000000P3oool6000000D0oooo1@0000030?ooo`D000000P3oool3000000<0oooo2P00
00050?ooo`<000001@3oool;0=7=Z@<0oooo1@0000020?ooo`D000000`3oool500000080oooo1@00
00030?ooo`D000000P3oool5000000<0oooo1@0000020?ooo`D000000`3oool500000080oooo1P00
00020?ooo`h0dLfY000<0=7=Z@`000001@3oool9000000H0oooo1P0000020?ooo`H000001P3oool9
000000D0oooo3000000;0=7=Z@H000001@3oool3000000H0oooo0P0000030?oooa`000000`3oool3
000000D0oooo0`0000050?ooo`H000002`3AcJT300000080oooo1P0000050?ooo`D000001P3oool2
000000/0oooo0`0000020?ooo`<000001@3oool300000080oooo1P0000050?ooo`D000000`3oool;
0=7=Z@D0oooo0`0000050?ooo`D000000`3oool2000000H0oooo0P0000030?ooo`P000001@3oool2
000000P0oooo0`0000050?ooo`D000000`3oool2000000<0oooo2`3AcJT30?ooo`D000000P3oool5
000000<0oooo1@0000020?ooo`D000000`3oool500000080oooo1@0000030?ooo`D000000P3oool5
000000<0oooo1@0000020?ooo`H000000P3oool>0=7=Z@00303AcJT30?ooo`<000001P3oool20000
00H0oooo0`0000060?ooo`<000001P3oool2000000H0oooo0`0000060?ooo`<000001P3oool20000
00H0oooo0`0000030?ooo`/0dLfY1P0000050?ooo`<000001P3oool2000000<0oooo700000030?oo
o`<000001@3oool3000000D0oooo1P00000;0=7=Z@D0oooo200000080?ooo`P00000203oool80000
00P0oooo200000080?ooo`P000002`3AcJT50?ooo`<000001@3oool5000000<0oooo0P0000060?oo
o`8000000`3oool8000000D0oooo0P0000080?ooo`<000001@3oool5000000<0oooo0P0000030?oo
o`/0dLfY0`0000050?ooo`8000001@3oool3000000D0oooo0P0000050?ooo`<000001@3oool20000
00D0oooo0`0000050?ooo`8000001@3oool3000000D0oooo0P0000060?ooo`8000003P3AcJT000`0
dLfY0`3oool3000000H0oooo0P0000060?ooo`<000001P3oool3000000H0oooo0P0000060?ooo`<0
00001P3oool3000000H0oooo0P0000060?ooo`<000000`3oool;0=7=Z@H000001@3oool3000000H0
oooo0P0000030?oooa`000000`3oool3000000D0oooo0`0000050?ooo`H000002`3AcJT50?ooo`P0
0000203oool8000000P0oooo200000080?ooo`P00000203oool8000000/0dLfY1@3oool3000000D0
oooo1@0000030?ooo`8000001P3oool2000000<0oooo200000050?ooo`800000203oool3000000D0
oooo1@0000030?ooo`8000000`3oool;0=7=Z@<000001@3oool2000000D0oooo0`0000050?ooo`80
00001@3oool3000000D0oooo0P0000050?ooo`<000001@3oool2000000D0oooo0`0000050?ooo`80
00001P3oool2000000h0dLfY000<0=7=Z@<0oooo0`0000060?ooo`8000001P3oool3000000H0oooo
0`0000060?ooo`8000001P3oool3000000H0oooo0`0000060?ooo`8000001P3oool3000000<0oooo
2`3AcJT6000000D0oooo0`0000060?ooo`8000000`3ooolL000000<0oooo0`0000050?ooo`<00000
1@3oool6000000/0dLfY203oool5000000H0oooo1@0000080?ooo`<000000P3oool=000000/0oooo
1@0000060?ooo`D000002`3AcJT30?ooo`D000003`3oool600000080oooo0`0000020?ooo`/00000
0P3ooolE000000P0oooo2`3AcJT3000000D0oooo0P0000050?ooo`<000001@3oool2000000D0oooo
0`0000050?ooo`8000001@3oool3000000D0oooo0P0000050?ooo`<000001@3oool2000000H0oooo
0P00000>0=7=Z@00303AcJT<000000D0oooo2@0000060?ooo`H000000P3oool6000000H0oooo2@00
00050?ooo``000002`3AcJT6000000D0oooo0`0000060?ooo`8000000`3ooolL000000<0oooo0`00
00050?ooo`<000001@3oool6000000/0dLfY203oool5000000H0oooo1@0000080?ooo`<000000P3o
ool=000000/0oooo1@0000060?ooo`D000002`3AcJT30?ooo`D000003`3oool600000080oooo0`00
00020?ooo`/000000P3ooolE000000P0oooo2`3AcJT30?ooo`D000000P3oool5000000<0oooo1@00
00020?ooo`D000000`3oool500000080oooo1@0000030?ooo`D000000P3oool5000000<0oooo1@00
00020?ooo`H000000P3oool>0=7=Z@00303AcJT<000000D0oooo2@0000060?ooo`H000000P3oool6
000000H0oooo2@0000050?ooo``000002`3AcJT;0?ooo`<000001P3oool5000000<0oooo5P000003
0?ooo`H000001@3oool3000000/0oooo2`3AcJT80?ooo`D000001P3oool5000000P0oooo0`000002
0?ooo`d000002`3oool5000000H0oooo1@00000;0=7=Z@<0oooo0P0000050?ooo`<000001@3oool;
000000X0oooo0`0000020?ooo`<000000P3oool3000000D0oooo0`0000050?ooo`<000001`3oool3
000000/0dLfY0`3oool500000080oooo1@0000030?ooo`D000000P3oool5000000<0oooo1@000002
0?ooo`D000000`3oool500000080oooo1@0000030?ooo`D000000P3oool600000080oooo3P3AcJT0
00`0dLfY300000050?ooo`T000001P3oool600000080oooo1P0000060?ooo`T000001@3oool<0000
00/0dLfY2`3oool3000000H0oooo1@0000030?oooaH000000`3oool6000000D0oooo0`00000;0?oo
o`/0dLfY2000000;0?ooo`8000000`3oool3000000P0oooo0P0000030?ooo`D000000`3oool20000
00P0oooo200000030?ooo`<000001@3oool;0=7=Z@<0oooo0P0000050?ooo`<000001@3oool;0000
00X0oooo0`0000020?ooo`<000000P3oool3000000D0oooo0`0000050?ooo`<000001`3oool30000
00/0dLfY200000020?ooo`D000000`3oool500000080oooo1@0000030?ooo`D000000P3oool50000
00<0oooo1@0000020?ooo`D000000`3oool500000080oooo2000000>0=7=Z@00303AcJT6000000<0
oooo1@0000030?ooo`T000000`3oool900000080oooo2@0000030?ooo`T000000`3oool5000000<0
oooo1P00000;0=7=Z@/0oooo0`0000060?ooo`D000000`3ooolF000000<0oooo1P0000050?ooo`<0
00002`3oool;0=7=Z@P000002`3oool2000000<0oooo0`0000080?ooo`8000000`3oool5000000<0
oooo0P0000080?ooo`P000000`3oool3000000D0oooo2`3AcJT30?ooo`8000001@3oool3000000D0
oooo2`00000:0?ooo`<000000P3oool300000080oooo0`0000050?ooo`<000001@3oool3000000L0
oooo0`00000;0=7=Z@P000000P3oool5000000<0oooo1@0000020?ooo`D000000`3oool500000080
oooo1@0000030?ooo`D000000P3oool5000000<0oooo1@0000020?ooo`P000003P3AcJT000`0dLfY
1P0000030?ooo`D000000`3oool9000000<0oooo2@0000020?ooo`T000000`3oool9000000<0oooo
1@0000030?ooo`H000002`3AcJT60?ooo`8000000`3oool3000000P0oooo0`0000060?oooa000000
1P3oool3000000P0oooo0`0000030?ooo`8000001P3oool;0=7=Z@P000002`3oool2000000<0oooo
0`0000080?ooo`8000000`3oool5000000<0oooo0P0000080?ooo`P000000`3oool3000000D0oooo
2`3AcJT30?ooo`D000002P3oool300000080oooo0`0000080?ooo`P000000P3ooolM000000D0oooo
2`3AcJT800000080oooo1@0000030?ooo`D000000P3oool5000000<0oooo1@0000020?ooo`D00000
0`3oool500000080oooo1@0000030?ooo`D000000P3oool8000000h0dLfY000<0=7=Z@H000000`3o
ool5000000<0oooo2@0000030?ooo`T000000P3oool9000000<0oooo2@0000030?ooo`D000000`3o
ool6000000/0dLfY1P3oool2000000<0oooo0`0000080?ooo`<000001P3oool@000000H0oooo0`00
00080?ooo`<000000`3oool2000000H0oooo2`3AcJT300000080oooo1P0000020?ooo`<000000`3o
ool2000000P0oooo1P00000=0?ooo`8000000`3oool300000080oooo1P0000020?ooo`<000000`3o
ool2000000<0oooo2`3AcJT30?ooo`D000002P3oool300000080oooo0`0000080?ooo`P000000P3o
oolM000000D0oooo2`3AcJT5000000<0oooo0P0000050?ooo`<000001@3oool2000000D0oooo0`00
00050?ooo`8000001@3oool3000000D0oooo0P0000050?ooo`<000001@3oool2000000<0oooo1@00
000>0=7=Z@00303AcJT<0?ooo`D000000`3oool3000000<0oooo2@0000030?ooo`8000000`3oool9
000000<0oooo0`0000030?ooo`D00000303oool;0=7=Z@H0oooo0P0000030?ooo`<00000203oool3
000000H0oooo400000060?ooo`<00000203oool3000000<0oooo0P0000060?ooo`/0dLfY0`000002
0?ooo`H000000P3oool3000000<0oooo0P0000080?ooo`H000003@3oool2000000<0oooo0`000002
0?ooo`H000000P3oool3000000<0oooo0P0000030?ooo`/0dLfY1@3oool3000000D0oooo0`000002
0?ooo`<000000P3oool8000000<0oooo0P0000060?ooo`8000001@3oool3000000D0oooo0`000005
0?ooo`<000000P3oool3000000D0oooo2`3AcJT5000000<0oooo0P0000050?ooo`<000001@3oool2
000000D0oooo0`0000050?ooo`8000001@3oool3000000D0oooo0P0000050?ooo`<000001@3oool2
000000<0oooo1@00000>0=7=Z@00303AcJT<0?ooo`D000000`3oool3000000<0oooo2@0000030?oo
o`8000000`3oool9000000<0oooo0`0000030?ooo`D00000303oool;0=7=Z@<000001@3oool60000
00<0oooo200000030?ooo`<000000P3oool<00000080oooo0`0000030?ooo`P000000`3oool60000
00D0oooo0`00000;0=7=Z@<000001@3oool5000000<0oooo1@0000080?ooo`/00000203oool50000
00<0oooo0P00000C0?ooo`/0dLfY1@3oool3000000D0oooo0`0000020?ooo`<000000P3oool80000
00<0oooo0P0000060?ooo`8000001@3oool3000000D0oooo0`0000050?ooo`<000000P3oool30000
00D0oooo2`3AcJT:0?ooo`D000000`3oool500000080oooo1@0000030?ooo`D000000P3oool50000
00<0oooo1@0000020?ooo`D000000`3oool5000000X0oooo3P3AcJT000`0dLfY1P3oool600000080
oooo0`0000030?ooo`<000000`3oool6000000h0oooo1P0000030?ooo`<000000`3oool300000080
oooo1P0000060?ooo`/0dLfY0`0000050?ooo`H000000`3oool8000000<0oooo0`0000020?ooo``0
00000P3oool3000000<0oooo200000030?ooo`H000001@3oool3000000/0dLfY0`0000050?ooo`D0
00000`3oool5000000P0oooo2`0000080?ooo`D000000`3oool2000001<0oooo2`3AcJT50?ooo`<0
00001@3oool300000080oooo0`0000020?ooo`P000000`3oool2000000H0oooo0P0000050?ooo`<0
00001@3oool3000000D0oooo0`0000020?ooo`<000001@3oool;0=7=Z@X0oooo1@0000030?ooo`D0
00000P3oool5000000<0oooo1@0000020?ooo`D000000`3oool500000080oooo1@0000030?ooo`D0
00002P3oool>0=7=Z@00303AcJT60?ooo`H000000P3oool3000000<0oooo0`0000030?ooo`H00000
3P3oool6000000<0oooo0`0000030?ooo`<000000P3oool6000000H0oooo2`3AcJT3000000D0oooo
1P0000030?ooo`P000000`3oool300000080oooo300000020?ooo`<000000`3oool8000000<0oooo
1P0000050?ooo`<000002`3AcJT3000000D0oooo1@0000030?ooo`D00000203oool;000000P0oooo
1@0000030?ooo`8000004`3oool;0=7=Z@P00000203oool7000000H0oooo3@0000020?oooaP00000
0P3oool300000080oooo0`00000;0=7=Z@X0oooo1@0000030?ooo`D000000P3oool5000000<0oooo
1@0000020?ooo`D000000`3oool500000080oooo1@0000030?ooo`D000002P3oool>0=7=Z@00303A
cJT60?ooo`H000000P3oool3000000<0oooo0`0000030?ooo`H000003P3oool6000000<0oooo0`00
00030?ooo`<000000P3oool6000000H0oooo2`3AcJT60?ooo`D000000`3oool6000000D0oooo0`00
00080?ooo`H00000203oool3000000H0oooo1@0000030?ooo`D000001P3oool;0=7=Z@<000000P3o
ool3000000<0oooo0P0000030?ooo`<000001@3oool3000000D0oooo0`0000020?ooo`<000000`3o
ool2000000D0oooo0`0000050?ooo`<000000`3oool2000000<0oooo0`0000020?ooo`<000002`3A
cJT8000000P0oooo1`0000060?ooo`d000000P3ooolH00000080oooo0`0000020?ooo`<000002`3A
cJT50?ooo`X000000`3oool500000080oooo1@0000030?ooo`D000000P3oool5000000<0oooo1@00
00020?ooo`D000000`3oool:000000D0oooo3P3AcJT000`0dLfY0`0000030?ooo`H000000P3oool<
000000H0oooo1P0000020?ooo`H000001P3oool<00000080oooo1P0000030?ooo`<000002`3AcJT6
0?ooo`D000000`3oool6000000D0oooo0`0000080?ooo`H00000203oool3000000H0oooo1@000003
0?ooo`D000001P3oool;0=7=Z@<000000P3oool3000000<0oooo0P0000030?ooo`<000001@3oool3
000000D0oooo0`0000020?ooo`<000000`3oool2000000D0oooo0`0000050?ooo`<000000`3oool2
000000<0oooo0`0000020?ooo`<000002`3AcJT3000000L0oooo4`0000050?ooo`8000000`3oool3
00000080oooo0`0000020?ooo`<000001@3oool3000000P0oooo1`0000030?ooo`/0dLfY1@3oool:
000000<0oooo1@0000020?ooo`D000000`3oool500000080oooo1@0000030?ooo`D000000P3oool5
000000<0oooo2P0000050?ooo`h0dLfY000<0=7=Z@<000000`3oool600000080oooo300000060?oo
o`H000000P3oool6000000H0oooo300000020?ooo`H000000`3oool3000000/0dLfY1P3oool20000
00H0oooo0`0000030?ooo`D000000`3oool8000000H0oooo200000030?ooo`H000000P3oool30000
00H0oooo0P0000060?ooo`/0dLfY0`0000020?ooo`<000000`3oool2000000<0oooo0`0000050?oo
o`<000001@3oool300000080oooo0`0000030?ooo`8000001@3oool3000000D0oooo0`0000030?oo
o`8000000`3oool300000080oooo0`00000;0=7=Z@<000001`3ooolC000000D0oooo0P0000030?oo
o`<000000P3oool300000080oooo0`0000050?ooo`<00000203oool7000000<0oooo2`3AcJT30000
0080oooo0`0000020?ooo`<000000P3oool3000000D0oooo0P0000050?ooo`<000001@3oool20000
00D0oooo0`0000050?ooo`8000001@3oool300000080oooo0`0000020?ooo`<000000`3oool20000
00h0dLfY000<0=7=Z@<000000`3oool600000080oooo300000060?ooo`H000000P3oool6000000H0
oooo300000020?ooo`H000000`3oool3000000/0dLfY1P3oool2000000H0oooo0`0000030?ooo`D0
00000`3oool8000000H0oooo200000030?ooo`H000000P3oool3000000H0oooo0P0000060?ooo`/0
dLfY1@0000060?ooo`X00000203oool600000080oooo1P0000050?ooo`D000000`3oool2000000<0
oooo0`0000020?ooo`<000000`3oool2000000<0oooo2`3AcJT3000000L0oooo4`0000050?ooo`80
00000`3oool300000080oooo0`0000020?ooo`<000001@3oool3000000P0oooo1`0000030?ooo`/0
dLfY0`0000020?ooo`<000000P3oool300000080oooo0`0000050?ooo`8000001@3oool3000000D0
oooo0P0000050?ooo`<000001@3oool2000000D0oooo0`0000020?ooo`<000000P3oool3000000<0
oooo0P00000>0=7=Z@00303AcJT30?ooo`<000001P3oool2000000H0oooo9P0000060?ooo`800000
1P3oool3000000<0oooo2`3AcJT60?ooo`8000001P3oool3000000<0oooo1@0000030?ooo`P00000
1P3oool8000000<0oooo1P0000020?ooo`<000001P3oool2000000H0oooo2`3AcJT5000000H0oooo
2P0000080?ooo`H000000P3oool6000000D0oooo1@0000030?ooo`8000000`3oool300000080oooo
0`0000030?ooo`8000000`3oool;0=7=Z@D000001@3oool3000000<0oooo1`0000030?ooo`X00000
0`3oool800000080oooo3@0000030?ooo`d000002`3AcJT300000080oooo0`0000020?ooo`<00000
0P3oool3000000D0oooo0P0000050?ooo`<000001@3oool2000000D0oooo0`0000050?ooo`800000
1@3oool300000080oooo0`0000020?ooo`<000000`3oool2000000h0dLfY000<0=7=Z@<0oooo0`00
00060?ooo`8000001P3ooolV000000H0oooo0P0000060?ooo`<000000`3oool;0=7=Z@<000000`3o
ool5000000<0oooo0`0000030?ooo`D000000`3oool300000080oooo300000020?ooo`<000000`3o
ool600000080oooo0`0000030?ooo`D000000`3oool3000000/0dLfY0`3oool5000000P0oooo1@00
00080?ooo`<000000`3oool2000000<0oooo1@0000030?ooo`8000000`3oool300000180oooo0`00
000;0=7=Z@D000001@3oool3000000<0oooo1`0000030?ooo`X000000`3oool800000080oooo3@00
00030?ooo`d000002`3AcJT30?ooo`D000000P3oool3000000D0oooo1@0000020?ooo`D000000`3o
ool500000080oooo1@0000030?ooo`D000000P3oool5000000D0oooo0`0000020?ooo`H000000P3o
ool>0=7=Z@00303AcJT30?ooo`<000001P3oool2000000H0oooo9P0000060?ooo`8000001P3oool3
000000<0oooo2`3AcJT3000000<0oooo1@0000030?ooo`<000000`3oool5000000<0oooo0`000002
0?ooo``000000P3oool3000000<0oooo1P0000020?ooo`<000000`3oool5000000<0oooo0`00000;
0=7=Z@<0oooo1@0000080?ooo`D00000203oool3000000<0oooo0P0000030?ooo`D000000`3oool2
000000<0oooo0`00000B0?ooo`<000002`3AcJT30?ooo`8000001@3oool3000000D0oooo0`00000?
0?ooo`<00000203oool2000000P0oooo5@00000;0=7=Z@<0oooo1@0000020?ooo`<000001@3oool5
00000080oooo1@0000030?ooo`D000000P3oool5000000<0oooo1@0000020?ooo`D000001@3oool3
00000080oooo1P0000020?ooo`h0dLfY000<0=7=Z@<000000`3oool600000080oooo1P0000030?oo
o`<000001P3oool600000080oooo1P0000060?ooo`<000000`3oool600000080oooo1P0000030?oo
o`<000002`3AcJT3000000<0oooo1@0000030?ooo`<000000`3oool5000000<0oooo0`0000020?oo
o``000000P3oool3000000<0oooo1P0000020?ooo`<000000`3oool5000000<0oooo0`00000;0=7=
Z@<0oooo1@0000080?ooo`D00000203oool3000000<0oooo0P0000030?ooo`D000000`3oool20000
00<0oooo0`00000B0?ooo`<000002`3AcJT30?ooo`8000001@3oool3000000D0oooo0`00000?0?oo
o`<00000203oool2000000P0oooo5@00000;0=7=Z@D000000`3oool500000080oooo200000020?oo
o`D000000`3oool500000080oooo1@0000030?ooo`D000000P3oool800000080oooo1@0000030?oo
o`D000003P3AcJT000`0dLfY0`0000030?ooo`H000000P3oool6000000<0oooo0`0000060?ooo`H0
00000P3oool6000000H0oooo0`0000030?ooo`H000000P3oool6000000<0oooo0`00000;0=7=Z@<0
oooo0`0000020?ooo``000001@3oool600000100oooo1P0000060?ooo`/000000P3oool3000000<0
oooo2`3AcJT300000080oooo0`0000050?ooo`<00000203oool300000080oooo0`00000;0?ooo`L0
00001P3oool5000000<0oooo0P0000030?ooo`D000000`3oool;0=7=Z@<0oooo0P0000050?ooo`<0
00001@3oool3000000l0oooo0`0000080?ooo`800000203ooolE000000/0dLfY1@0000030?ooo`D0
00000P3oool800000080oooo1@0000030?ooo`D000000P3oool5000000<0oooo1@0000020?ooo`P0
00000P3oool5000000<0oooo1@00000>0=7=Z@00303AcJT3000000<0oooo1P0000020?ooo`H00000
0`3oool3000000H0oooo1P0000020?ooo`H000001P3oool3000000<0oooo1P0000020?ooo`H00000
0`3oool3000000/0dLfY0`3oool300000080oooo300000050?ooo`H00000403oool6000000H0oooo
2`0000020?ooo`<000000`3oool;0=7=Z@<000000P3oool3000000D0oooo0`0000080?ooo`<00000
0P3oool3000000/0oooo1`0000060?ooo`D000000`3oool2000000<0oooo1@0000030?ooo`/0dLfY
1@0000050?ooo`<000000`3oool:000000P0oooo0P0000030?ooo`<000000P3oool300000080oooo
0`0000030?ooo`8000000`3oool2000000<0oooo2P0000030?ooo`/0dLfY1@0000030?ooo`D00000
0P3oool800000080oooo1@0000030?ooo`D000000P3oool5000000<0oooo1@0000020?ooo`P00000
0P3oool5000000<0oooo1@00000>0=7=Z@00303AcJT60?ooo`H000000P3oool6000000<0oooo2@00
000>0?ooo`T000000`3oool600000080oooo1P0000060?ooo`/0dLfY0`3oool300000080oooo3000
00050?ooo`H00000403oool6000000H0oooo2`0000020?ooo`<000000`3oool;0=7=Z@<000000P3o
ool3000000D0oooo0`0000080?ooo`<000000P3oool3000000/0oooo1`0000060?ooo`D000000`3o
ool2000000<0oooo1@0000030?ooo`/0dLfY1@0000050?ooo`<000000`3oool:000000P0oooo0P00
00030?ooo`<000000P3oool300000080oooo0`0000030?ooo`8000000`3oool2000000<0oooo2P00
00030?ooo`/0dLfY0`0000050?ooo`8000000`3oool7000000<0oooo0P0000050?ooo`<000001@3o
ool2000000D0oooo0`0000050?ooo`8000000`3oool7000000<0oooo0P0000060?ooo`8000003P3A
cJT000`0dLfY1P3oool600000080oooo1P0000030?ooo`T000003P3oool9000000<0oooo1P000002
0?ooo`H000001P3oool;0=7=Z@<000002`3oool>000001H0oooo3P00000;0?ooo`<000002`3AcJT5
0?ooo`<00000203oool3000000P0oooo1@0000050?ooo`H000002P3oool;00000080oooo2`00000;
0=7=Z@D000001@3oool3000000<0oooo2P0000080?ooo`8000000`3oool300000080oooo0`000002
0?ooo`<000000`3oool2000000<0oooo0P0000030?ooo`X000000`3oool;0=7=Z@<000001@3oool2
000000<0oooo1`0000030?ooo`8000001@3oool3000000D0oooo0P0000050?ooo`<000001@3oool2
000000<0oooo1`0000030?ooo`8000001P3oool2000000h0dLfY000<0=7=Z@H0oooo1P0000020?oo
o`H000000`3oool9000000h0oooo2@0000030?ooo`H000000P3oool6000000H0oooo2`3AcJT30000
00/0oooo3P00000F0?ooo`h000002`3oool3000000/0dLfY1@3oool3000000P0oooo0`0000080?oo
o`D000001@3oool6000000X0oooo2`0000020?ooo`/000002`3AcJT3000000L0oooo2`0000020?oo
o`<000000`3oool2000000/0oooo0P0000080?ooo`<000001@3oool2000000H0oooo1@0000020?oo
o`<000002`3AcJT5000000<0oooo0P0000030?ooo`D000001`3oool5000000<0oooo1@0000020?oo
o`D000000`3oool5000000L0oooo1@0000030?ooo`8000000`3oool5000000h0dLfY000<0=7=Z@`0
oooo0P0000060?ooo`<000001P3oool6000000<0oooo0P0000030?ooo`H000001P3oool3000000H0
oooo0P00000<0?ooo`/0dLfY0`3oool5000000<0oooo0`0000030?ooo`<00000203ooolF000000T0
oooo0P0000030?ooo`<000000`3oool5000000<0oooo2`3AcJT50?ooo`<00000203oool3000000P0
oooo1@0000050?ooo`H000002P3oool;00000080oooo2`00000;0=7=Z@<000001`3oool;00000080
oooo0`0000030?ooo`8000002`3oool2000000P0oooo0`0000050?ooo`8000001P3oool500000080
oooo0`00000;0=7=Z@D000000`3oool2000000<0oooo1@0000070?ooo`D000000`3oool500000080
oooo1@0000030?ooo`D000001`3oool5000000<0oooo0P0000030?ooo`D000003P3AcJT000`0dLfY
303oool2000000H0oooo0`0000060?ooo`H000000`3oool2000000<0oooo1P0000060?ooo`<00000
1P3oool2000000`0oooo2`3AcJT30?ooo`D000000`3oool3000000<0oooo0`0000080?oooaH00000
2@3oool2000000<0oooo0`0000030?ooo`D000000`3oool;0=7=Z@D0oooo0`0000030?ooo`D00000
1@3oool8000000P0oooo200000080?ooo`/000000P3oool;000000/0dLfY200000080?ooo`800000
1@3oool6000000L0oooo1P0000020?ooo`P000000`3oool2000000<0oooo0P0000030?ooo`<00000
2P3oool;0=7=Z@D000000`3oool2000000<0oooo1@0000070?ooo`D000000`3oool500000080oooo
1@0000030?ooo`D000001`3oool5000000<0oooo0P0000030?ooo`D000003P3AcJT000`0dLfY303o
ool2000000H0oooo0`0000060?ooo`H000000`3oool2000000<0oooo1P0000060?ooo`<000001P3o
ool2000000`0oooo2`3AcJT30?ooo`D000000`3oool3000000<0oooo0`0000080?oooaH000002@3o
ool2000000<0oooo0`0000030?ooo`D000000`3oool;0=7=Z@D0oooo0`0000030?ooo`D000001@3o
ool8000000P0oooo200000080?ooo`/000000P3oool;000000/0dLfY200000080?ooo`8000001@3o
ool6000000L0oooo1P0000020?ooo`P000000`3oool2000000<0oooo0P0000030?ooo`<000002P3o
ool;0=7=Z@<0oooo2P0000050?ooo``000000`3oool500000080oooo1@0000030?ooo``000001@3o
ool;00000080oooo3P3AcJT000`0dLfY1P0000030?ooo`<000000P3oool6000000<0oooo1P000003
0?ooo`H000000P3oool6000000<0oooo1P0000030?ooo`H000000P3oool3000000<0oooo1P00000;
0=7=Z@/000001P3oool5000000<0oooo1P00000@0?ooo`H000000`3oool5000000H0oooo2`00000;
0=7=Z@<000000P3oool>00000080oooo0`0000050?ooo`H000001@3oool5000000<0oooo0P000006
0?ooo`D000000`3oool2000000<0oooo1@0000030?ooo`/0dLfY200000080?ooo`8000001@3oool6
000000L0oooo1P0000020?ooo`P000000`3oool2000000<0oooo0P0000030?ooo`<000002P3oool;
0=7=Z@<0oooo2P0000050?ooo``000000`3oool500000080oooo1@0000030?ooo``000001@3oool;
00000080oooo3P3AcJT000`0dLfY1P0000030?ooo`<000000P3oool6000000<0oooo1P0000030?oo
o`H000000P3oool6000000<0oooo1P0000030?ooo`H000000P3oool3000000<0oooo1P00000;0=7=
Z@/000001P3oool5000000<0oooo1P00000@0?ooo`H000000`3oool5000000H0oooo2`00000;0=7=
Z@<000000P3oool>00000080oooo0`0000050?ooo`H000001@3oool5000000<0oooo0P0000060?oo
o`D000000`3oool2000000<0oooo1@0000030?ooo`/0dLfY1@3oool3000000D0oooo200000050?oo
o`P000000P3oool600000080oooo0`0000020?ooo`<000001@3oool8000000<0oooo0P0000030?oo
o`8000000`3oool;0=7=Z@<000001@3oool<000000D0oooo0`0000020?ooo`<000001@3oool20000
00D0oooo0`0000020?ooo`<000001@3oool<000000H0oooo0P00000>0=7=Z@00303AcJT9000000D0
oooo1P0000030?ooo`H000001P3oool300000080oooo0`0000060?ooo`H000000`3oool6000000D0
oooo2@00000;0=7=Z@/000001P3oool5000000<0oooo1P00000@0?ooo`H000000`3oool5000000H0
oooo2`00000;0=7=Z@<000000P3oool>00000080oooo0`0000050?ooo`H000001@3oool5000000<0
oooo0P0000060?ooo`D000000`3oool2000000<0oooo1@0000030?ooo`/0dLfY1@3oool3000000D0
oooo200000050?ooo`P000000P3oool600000080oooo0`0000020?ooo`<000001@3oool8000000<0
oooo0P0000030?ooo`8000000`3oool;0=7=Z@<000001@3oool<000000D0oooo0`0000020?ooo`<0
00001@3oool2000000D0oooo0`0000020?ooo`<000001@3oool<000000H0oooo0P00000>0=7=Z@00
303AcJT9000000D0oooo1P0000030?ooo`H000001P3oool300000080oooo0`0000060?ooo`H00000
0`3oool6000000D0oooo2@00000;0=7=Z@h000001P3oool8000000<0oooo0P00000<0?ooo`800000
0`3oool9000000D0oooo3P00000;0=7=Z@<0oooo0P0000060?oooaP000000P3oool3000000D0oooo
0`0000050?ooo`<000004P3oool3000000/0dLfY0`3oool5000000D0oooo200000020?ooo`<00000
1@3oool5000000H0oooo1@0000020?ooo`<000000`3oool:000000D0oooo0`0000050?ooo`/0dLfY
0`0000050?ooo``000001@3oool300000080oooo0`0000050?ooo`8000001@3oool300000080oooo
0`0000050?ooo``000001P3oool2000000h0dLfY000<0=7=Z@T000001@3oool6000000<0oooo1P00
00060?ooo`<000000P3oool3000000H0oooo1P0000030?ooo`H000001@3oool9000000/0dLfY3P00
00060?ooo`P000000`3oool2000000`0oooo0P0000030?ooo`T000001@3oool>000000/0dLfY0`3o
ool2000000H0oooo600000020?ooo`<000001@3oool3000000D0oooo0`00000B0?ooo`<000002`3A
cJT30?ooo`D000001@3oool800000080oooo0`0000050?ooo`D000001P3oool500000080oooo0`00
00030?ooo`X000001@3oool3000000D0oooo2`3AcJT30?ooo`D000000P3oool3000000L0oooo2000
00050?ooo`D000000P3oool5000000D0oooo200000070?ooo`<000000P3oool600000080oooo3P3A
cJT000`0dLfY0`3oool9000000P0oooo0`0000090?ooo`h000002@3oool3000000P0oooo2@000003
0?ooo`/0dLfY3P0000060?ooo`P000000`3oool2000000`0oooo0P0000030?ooo`T000001@3oool>
000000/0dLfY0`3oool2000000H0oooo600000020?ooo`<000001@3oool3000000D0oooo0`00000B
0?ooo`<000002`3AcJT30?ooo`D000001@3oool800000080oooo0`0000050?ooo`D000001P3oool5
00000080oooo0`0000030?ooo`X000001@3oool3000000D0oooo2`3AcJT30?ooo`D000000P3oool3
000000L0oooo200000050?ooo`D000000P3oool5000000D0oooo200000070?ooo`<000000P3oool6
00000080oooo3P3AcJT000`0dLfY0`3oool9000000P0oooo0`0000090?ooo`h000002@3oool30000
00P0oooo2@0000030?ooo`/0dLfY0`3oool;000000<0oooo0`00000@0?ooo`H000004@3oool20000
00<0oooo2`0000030?ooo`/0dLfY0`0000020?ooo`H000000P3oool600000080oooo0`0000050?oo
o`<000000`3oool2000000<0oooo1@0000030?ooo`8000001P3oool2000000<0oooo0`0000020?oo
o`<000000`3oool2000000<0oooo2`3AcJT30?ooo`8000002`3oool2000000<0oooo0P0000030?oo
o`D000000`3oool:000000<0oooo3`0000060?ooo`8000000`3oool5000000/0dLfY200000020?oo
o`D000000`3oool5000000L0oooo200000020?ooo`P000001`3oool5000000<0oooo1@0000020?oo
o`P000003P3AcJT000`0dLfY0`3oool9000000P0oooo0`0000090?ooo`h000002@3oool3000000P0
oooo2@0000030?ooo`/0dLfY0`3oool;000000<0oooo0`00000@0?ooo`H000004@3oool2000000<0
oooo2`0000030?ooo`/0dLfY0`0000020?ooo`H000000P3oool600000080oooo0`0000050?ooo`<0
00000`3oool2000000<0oooo1@0000030?ooo`8000001P3oool2000000<0oooo0`0000020?ooo`<0
00000`3oool2000000<0oooo2`3AcJT30?ooo`8000002`3oool2000000<0oooo0P0000030?ooo`D0
00000`3oool:000000<0oooo3`0000060?ooo`8000000`3oool5000000/0dLfY200000020?ooo`D0
00000`3oool5000000L0oooo200000020?ooo`P000001`3oool5000000<0oooo1@0000020?ooo`P0
00003P3AcJT000`0dLfY0`0000030?ooo`H000001@3oool3000000<0oooo0`0000060?ooo`H00000
0P3oool6000000H0oooo0`0000030?ooo`<000001@3oool6000000<0oooo0`00000;0=7=Z@<00000
0`3oool5000000<0oooo0`0000030?ooo`8000001P3oool3000000D0oooo1P0000050?ooo`<00000
1P3oool300000080oooo0`0000030?ooo`D000000`3oool3000000/0dLfY1@3oool6000000X0oooo
2`0000080?ooo`D00000203oool300000080oooo0`0000030?ooo`8000000`3oool300000080oooo
0`00000;0=7=Z@<0oooo3`0000080?ooo`D00000403oool5000000<0oooo1@0000020?ooo`<00000
203oool5000000/0dLfY200000020?ooo`D000000`3oool5000000L0oooo200000020?ooo`P00000
1`3oool5000000<0oooo1@0000020?ooo`P000003P3AcJT000`0dLfY0`0000030?ooo`H000001@3o
ool3000000<0oooo0`0000060?ooo`H000000P3oool6000000H0oooo0`0000030?ooo`<000001@3o
ool6000000<0oooo0`00000;0=7=Z@<000000`3oool5000000<0oooo0`0000030?ooo`8000001P3o
ool3000000D0oooo1P0000050?ooo`<000001P3oool300000080oooo0`0000030?ooo`D000000`3o
ool3000000/0dLfY1@3oool6000000X0oooo2`0000080?ooo`D00000203oool300000080oooo0`00
00030?ooo`8000000`3oool300000080oooo0`00000;0=7=Z@<0oooo3`0000080?ooo`D00000403o
ool5000000<0oooo1@0000020?ooo`<00000203oool5000000/0dLfY1@0000030?ooo`8000000`3o
ool7000000<0oooo0P0000050?ooo`D000000`3oool2000000<0oooo1@0000050?ooo`8000000`3o
ool7000000<0oooo0P0000030?ooo`D000003P3AcJT000`0dLfY0`0000030?ooo`H000001@3oool3
000000<0oooo0`0000060?ooo`H000000P3oool6000000H0oooo0`0000030?ooo`<000001@3oool6
000000<0oooo0`00000;0=7=Z@<000000`3oool5000000<0oooo0`0000030?ooo`8000001P3oool3
000000D0oooo1P0000050?ooo`<000001P3oool300000080oooo0`0000030?ooo`D000000`3oool3
000000/0dLfY1@3oool6000000X0oooo2`0000080?ooo`D00000203oool300000080oooo0`000003
0?ooo`8000000`3oool300000080oooo0`00000;0=7=Z@<0oooo3`0000080?ooo`D00000403oool5
000000<0oooo1@0000020?ooo`<00000203oool5000000/0dLfY1@0000030?ooo`8000000`3oool7
000000<0oooo0P0000050?ooo`D000000`3oool2000000<0oooo1@0000050?ooo`8000000`3oool7
000000<0oooo0P0000030?ooo`D000003P3AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfY
c03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfY
c03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT000`0dLfY1`00000;ooooo`<0
00001?ooool7000000kooooo20000003ooooo`@000002_ooool8000000X0dLfY0`000004ooooo`H0
00001oooool7000003?ooooo2`3AcJT3000000Kooooo10000003ooooo`X000000oooool3000000Co
oooo5`00000Cooooo`X0dLfY1`000003ooooo`<000000oooool6000000Oooooo0`000006ooooo`<0
00001oooool3000000Kooooo1P000004ooooo`<000000oooool6000000X0dLfY0`0000030?ooo`<0
00001P3oool6000000<0oooo0`0000060?ooo``000001P3oool3000000<0oooo1P0000060?ooo`<0
00000`3oool3000000h0dLfY000<0=7=Z@L000002oooool3000000Cooooo1`00000>ooooo`P00000
0oooool4000000[ooooo2000000:0=7=Z@<000001?ooool6000000Oooooo1`00000cooooo`/0dLfY
0`000006ooooo`@000000oooool:000000?ooooo0`000004oooooaL000004oooool:0=7=Z@L00000
0oooool3000000?ooooo1P000007ooooo`<000001_ooool3000000Oooooo0`000006ooooo`H00000
1?ooool3000000?ooooo1P00000:0=7=Z@<000000`3oool3000000H0oooo1P0000030?ooo`<00000
1P3oool<000000H0oooo0`0000030?ooo`H000001P3oool3000000<0oooo0`00000>0=7=Z@00303A
cJT7000000_ooooo0`000004ooooo`L000003_ooool8000000?ooooo1000000:ooooo`P000002P3A
cJT3000000Cooooo1P000007ooooo`L00000<oooool;0=7=Z@<000001_ooool4000000?ooooo2P00
0003ooooo`<000001?oooolG000001?ooooo2P3AcJT7000000?ooooo0`000003ooooo`H000001ooo
ool3000000Kooooo0`000007ooooo`<000001_ooool6000000Cooooo0`000003ooooo`H000002P3A
cJT3000000<0oooo0`0000060?ooo`H000000`3oool3000000H0oooo300000060?ooo`<000000`3o
ool6000000H0oooo0`0000030?ooo`<000003P3AcJT000`0dLfY1`00000;ooooo`<000001?ooool7
000000kooooo20000003ooooo`@000002_ooool8000000X0dLfY0`000004ooooo`H000001oooool7
000003?ooooo2`3AcJT3000000Kooooo10000003ooooo`X000000oooool3000000Cooooo5`00000C
ooooo`X0dLfY1`000003ooooo`<000000oooool6000000Oooooo0`000006ooooo`<000001oooool3
000000Kooooo1P000004ooooo`<000000oooool6000000X0dLfY0`3oool3000000T0oooo2@000009
0?ooo`<000001P3oool3000000T0oooo2@0000090?ooo`<000000`3oool>0=7=Z@00303AcJT70000
00Cooooo0`000007ooooo`/000001?ooool7000000?ooooo2`000007ooooo`@000000oooool80000
00X0dLfY0oooool:000000Oooooo1`000004ooooobl000002`3AcJT=ooooo`H000001?ooool60000
00?ooooo1`00000@ooooo`@000000oooool@000000X0dLfY2P000003ooooo`T000008oooool:0000
00?ooooo2@00000:0=7=Z@<0oooo0`0000090?ooo`T000002@3oool3000000H0oooo0`0000090?oo
o`T000002@3oool3000000<0oooo3P3AcJT000`0dLfY1`000004ooooo`<000001oooool;000000Co
oooo1`000003ooooo`/000001oooool4000000?ooooo2000000:0=7=Z@?ooooo2P000007ooooo`L0
00001?ooool_000000/0dLfY3Oooool6000000Cooooo1P000003ooooo`L000004?ooool4000000?o
oooo4000000:0=7=Z@X000000oooool9000002?ooooo2P000003ooooo`T000002P3AcJT30?ooo`<0
00002@3oool9000000T0oooo0`0000060?ooo`<000002@3oool9000000T0oooo0`0000030?ooo`h0
dLfY000<0=7=Z@L000001?ooool3000000Oooooo2`000004ooooo`L000000oooool;000000Oooooo
10000003ooooo`P000002P3AcJT3ooooo`X000001oooool7000000Cooooo;`00000;0=7=Z@gooooo
1P000004ooooo`H000000oooool70000013ooooo10000003oooooa0000002P3AcJT:000000?ooooo
2@00000Sooooo`X000000oooool9000000X0dLfY0`0000030?ooo`H000001P3oool<000000<0oooo
300000030?ooo``000001P3oool6000000<0oooo0`00000>0=7=Z@00303AcJT7ooooo`@000001ooo
ool:000000Cooooo3P000004ooooo`/000001oooool3000000Sooooo2P3AcJT:0000017ooooo1`00
000Yooooo`<000002`3AcJT3ooooo`d000002_ooool3000000?ooooo10000003ooooo`<000002_oo
ool=000000[ooooo0`00000:0=7=Z@Cooooo1P000003ooooo`H000001oooool3000000?ooooo1P00
0003ooooo`L000000oooool3000000Kooooo1`000003ooooo`H000000oooool:0=7=Z@<000000`3o
ool6000000H0oooo300000030?ooo``000000`3oool<000000H0oooo1P0000030?ooo`<000003P3A
cJT000`0dLfY1oooool4000000Oooooo2P000004ooooo`h000001?ooool;000000Oooooo0`000008
ooooo`X0dLfY2P00000Aooooo`L00000:Oooool3000000/0dLfY0oooool=000000[ooooo0`000003
ooooo`@000000oooool3000000[ooooo3@00000:ooooo`<000002P3AcJT4ooooo`H000000oooool6
000000Oooooo0`000003ooooo`H000000oooool7000000?ooooo0`000006ooooo`L000000oooool6
000000?ooooo2P3AcJT3000000<0oooo1P0000060?ooo``000000`3oool<000000<0oooo30000006
0?ooo`H000000`3oool3000000h0dLfY000<0=7=Z@Oooooo10000007ooooo`X000001?ooool>0000
00Cooooo2`000007ooooo`<000002?ooool:0=7=Z@X000004Oooool7000002Wooooo0`00000;0=7=
Z@?ooooo3@00000:ooooo`<000000oooool4000000?ooooo0`00000:ooooo`d000002_ooool30000
00X0dLfY1?ooool6000000?ooooo1P000007ooooo`<000000oooool6000000?ooooo1`000003oooo
o`<000001_ooool7000000?ooooo1P000003ooooo`X0dLfY1P3oool6000000<0oooo0`0000030?oo
o`<000000`3oool6000000`0oooo1P0000030?ooo`<000000`3oool3000000<0oooo1P0000060?oo
o`h0dLfY000<0=7=Z@Oooooo10000007ooooo`X000001?ooool>000000Cooooo2`000007ooooo`<0
00002?ooool:0=7=Z@L000000oooool:000000Cooooo1`000003ooooo`<000008oooool6000000/0
dLfY0oooool3000000[ooooo50000009ooooo`@000000oooool7000000Kooooo0`000004ooooo`H0
00002P3AcJT4000000Kooooo0`000006ooooo`<000001ooooolF000000Kooooo0`000007ooooo`<0
00001_ooool3000000X0dLfY1P3oool6000000<0oooo0`0000030?ooo`<000000`3oool6000000`0
oooo1P0000030?ooo`<000000`3oool3000000<0oooo1P0000060?ooo`h0dLfY000<0=7=Z@?ooooo
10000004ooooo`<000001?ooool7000000Oooooo3P000008ooooo`L000000oooool4000000?ooooo
10000004ooooo`X0dLfY1`000003ooooo`X000001?ooool7000000?ooooo0`00000Sooooo`H00000
2`3AcJT3ooooo`<000002_oooolD000000Wooooo10000003ooooo`L000001_ooool3000000Cooooo
1P00000:0=7=Z@@000001_ooool3000000Kooooo0`000007oooooaH000001_ooool3000000Oooooo
0`000006ooooo`<000002P3AcJT60?ooo`H000000`3oool3000000<0oooo0`0000030?ooo`H00000
303oool6000000<0oooo0`0000030?ooo`<000000`3oool6000000H0oooo3P3AcJT000`0dLfY0ooo
ool4000000Cooooo0`000004ooooo`L000001oooool>000000Sooooo1`000003ooooo`@000000ooo
ool4000000Cooooo2P3AcJT7000000?ooooo2P000004ooooo`L000000oooool3000002?ooooo1P00
000;0=7=Z@?ooooo0`00000:oooooa@000002Oooool4000000?ooooo1`000006ooooo`<000001?oo
ool6000000X0dLfY10000006ooooo`<000001_ooool3000000Oooooo5P000006ooooo`<000001ooo
ool3000000Kooooo0`00000:0=7=Z@`0oooo0`0000060?ooo`<000001P3oool6000000H0oooo1P00
00060?ooo`<000001P3oool3000000`0oooo3P3AcJT000`0dLfY0oooool4000000Cooooo0`000004
ooooo`L000001oooool>000000Sooooo1`000003ooooo`@000000oooool4000000Cooooo2P3AcJT7
000000?ooooo2P000004ooooo`L000000oooool3000002?ooooo1P00000;0=7=Z@?ooooo1P000004
ooooo`H000001oooool3000001Cooooo0`000007ooooo`H000000oooool7000000?ooooo2P3AcJT4
ooooo`H000000oooool6000000Oooooo30000003ooooo`d000001_ooool7000000?ooooo1P000003
ooooo`X0dLfY303oool3000000H0oooo0`0000060?ooo`H000001P3oool6000000H0oooo0`000006
0?ooo`<00000303oool>0=7=Z@00303AcJT>ooooo`@000001oooool3000000Sooooo1`000007oooo
o`@000001oooool3000000oooooo2P3AcJT:ooooo`<000001?ooool:000000kooooo6`000004oooo
o`<000000oooool;0=7=Z@?ooooo1P000004ooooo`H000001oooool3000001Cooooo0`000007oooo
o`H000000oooool7000000?ooooo2P3AcJT4ooooo`H000000oooool6000000Oooooo30000003oooo
o`d000001_ooool7000000?ooooo1P000003ooooo`X0dLfY303oool3000000H0oooo0`0000060?oo
o`H000001P3oool6000000H0oooo0`0000060?ooo`<00000303oool>0=7=Z@00303AcJT>ooooo`@0
00001oooool3000000Sooooo1`000007ooooo`@000001oooool3000000oooooo2P3AcJT:ooooo`<0
00001?ooool:000000kooooo6`000004ooooo`<000000oooool;0=7=Z@?ooooo1P000004ooooo`H0
00001oooool3000001Cooooo0`000007ooooo`H000000oooool7000000?ooooo2P3AcJT4ooooo`H0
00000oooool6000000Oooooo30000003ooooo`d000001_ooool7000000?ooooo1P000003ooooo`X0
dLfY1P0000030?ooo`<000000`3oool3000000<0oooo0`0000030?ooo`<000000`3oool3000000H0
oooo0`0000030?ooo`<000000`3oool3000000<0oooo0`0000030?ooo`<000000`3oool6000000h0
dLfY000<0=7=Z@kooooo10000007ooooo`<000002?ooool7000000Oooooo10000007ooooo`<00000
3oooool:0=7=Z@[ooooo0`000004ooooo`X000003_oooolK000000Cooooo0`000003ooooo`/0dLfY
1_ooool:000000?ooooo3@000004ooooo`d000000oooool=000000?ooooo10000003ooooo`<00000
2P3AcJT:000000?ooooo2@000004ooooo`T000002_ooool9000000?ooooo2P000003ooooo`T00000
2P3AcJT6000000<0oooo0`0000030?ooo`<000000`3oool3000000<0oooo0`0000030?ooo`<00000
1P3oool3000000<0oooo0`0000030?ooo`<000000`3oool3000000<0oooo0`0000030?ooo`H00000
3P3AcJT000`0dLfY3_ooool4000000Oooooo0`000008ooooo`L000001oooool4000000Oooooo0`00
000?ooooo`X0dLfY2_ooool3000000kooooo1`000007ooooo`<000005Oooool=000000/0dLfY1_oo
ool:000000?ooooo3@000004ooooo`d000000oooool=000000?ooooo10000003ooooo`<000002P3A
cJT:000000?ooooo2@000004ooooo`T000002_ooool9000000?ooooo2P000003ooooo`T000002P3A
cJT6000000<0oooo0`0000030?ooo`<000000`3oool3000000<0oooo0`0000030?ooo`<000001P3o
ool3000000<0oooo0`0000030?ooo`<000000`3oool3000000<0oooo0`0000030?ooo`H000003P3A
cJT000`0dLfY0`000004ooooo`L000001?ooool7000000Oooooo10000007ooooo`<000002?ooool7
000000?ooooo1`000004ooooo`@000002P3AcJT:ooooo`<000003_ooool7000000Oooooo0`00000E
ooooo`d000002`3AcJT6ooooo`X000000oooool=000000Cooooo3@000003ooooo`d000000oooool4
000000?ooooo0`00000:0=7=Z@X000000oooool9000000Cooooo2@00000:ooooo`T000000oooool:
000000?ooooo2@00000:0=7=Z@T000002@3oool9000000H0oooo0`0000060?ooo`<000001P3oool9
000000T0oooo2@00000>0=7=Z@00303AcJT3000000Cooooo1`000004ooooo`L000001oooool40000
00Oooooo0`000008ooooo`L000000oooool7000000Cooooo1000000:0=7=Z@[ooooo0`00000>oooo
o`L000001oooool3000001Gooooo3@00000;0=7=Z@Kooooo2P000003ooooo`d000001?ooool=0000
00?ooooo3@000003ooooo`@000000oooool3000000X0dLfY1`000003ooooo`<000000oooool:0000
00?ooooo0`000003ooooo`X000000oooool3000000?ooooo2@000004ooooo`<000000oooool60000
00X0dLfY2@0000090?ooo`T000001P3oool3000000H0oooo0`0000060?ooo`T000002@3oool90000
00h0dLfY000<0=7=Z@<000001?ooool7000000Cooooo1`000007ooooo`@000001oooool3000000So
oooo1`000003ooooo`L000001?ooool4000000X0dLfY1`000003ooooo`<000002oooool:000000Oo
oooo1`00000=ooooo`@000001oooool6000000/0dLfY1P00000=ooooo`@000000oooool=000000Ko
oooo10000003ooooo`<000001?ooool3000000?ooooo1`000006ooooo`X0dLfY1`000003ooooo`<0
00000oooool:000000?ooooo0`000003ooooo`X000000oooool3000000?ooooo2@000004ooooo`<0
00000oooool6000000X0dLfY2@0000090?ooo`T000001P3oool3000000H0oooo0`0000060?ooo`T0
00002@3oool9000000h0dLfY000<0=7=Z@?ooooo2`000004ooooo`X000002?ooool7000000Oooooo
2`000003ooooo`/000001?ooool:0=7=Z@L000000oooool3000000_ooooo2P000007ooooo`L00000
3Oooool4000000Oooooo1P00000;0=7=Z@H000003Oooool4000000?ooooo3@000006ooooo`@00000
0oooool3000000Cooooo0`000003ooooo`L000001_ooool:0=7=Z@L000000oooool3000000?ooooo
2P000003ooooo`<000000oooool:000000?ooooo0`000003ooooo`T000001?ooool3000000?ooooo
1P00000:0=7=Z@<0oooo6`0000030?ooo`<000001P3oool3000000<0oooo6`0000030?ooo`h0dLfY
000<0=7=Z@?ooooo2`000004ooooo`X000002?ooool7000000Oooooo2`000003ooooo`/000001?oo
ool:0=7=Z@L000000oooool3000000_ooooo2P000007ooooo`L000003Oooool4000000Oooooo1P00
000;0=7=Z@H000003Oooool4000000?ooooo3@000006ooooo`@000000oooool3000000Cooooo0`00
0003ooooo`L000001_ooool:0=7=ZA?ooooo1`000003ooooo`<000000oooool3000000?ooooo1000
0003ooooo`<000000oooool6000001?ooooo2P3AcJT30?oooa/000000`3oool3000000H0oooo0`00
00030?oooa/000000`3oool>0=7=Z@00303AcJT3ooooo`/000001?ooool:000000Sooooo1`000007
ooooo`/000000oooool;000000Cooooo2P3AcJT7000000?ooooo0`00000;ooooo`X000001oooool7
000000gooooo10000007ooooo`H000002`3AcJT9000000[ooooo10000006ooooo`<000001oooool@
000000Cooooo0`000003ooooo`<000002_ooool:0=7=ZA?ooooo1`000003ooooo`<000000oooool3
000000?ooooo10000003ooooo`<000000oooool6000001?ooooo2P3AcJT30?oooa/000000`3oool3
000000H0oooo0`0000030?oooa/000000`3oool>0=7=Z@00303AcJT3ooooo`/000001?ooool:0000
00Sooooo1`000007ooooo`/000000oooool;000000Cooooo2P3AcJT=000000Cooooo0`000004oooo
o`L000003Oooool4000000?ooooo1`000007ooooo`L000001_ooool;0=7=Z@T000002_ooool40000
00Kooooo0`000007oooooa0000001?ooool3000000?ooooo0`00000:ooooo`X0dLfY4oooool70000
00?ooooo0`000003ooooo`<000000oooool4000000?ooooo0`000003ooooo`H000004oooool:0=7=
Z@<000000`3oool3000000T0oooo4P0000060?oooa8000002@3oool3000000<0oooo0`00000>0=7=
Z@00303AcJT;000000?ooooo10000003ooooo`L000001?ooool>000000Cooooo1`000004ooooo`<0
00001?ooool;000000X0dLfY3@000004ooooo`<000001?ooool7000000gooooo10000003ooooo`L0
00001oooool7000000Kooooo2`3AcJT9000000[ooooo10000006ooooo`<000001oooool@000000Co
oooo0`000003ooooo`<000002_ooool:0=7=Z@Oooooo0`000003ooooo`H000001oooool<000000?o
oooo3@000006ooooo`L000000oooool3000000Kooooo2P3AcJT3000000<0oooo0`0000090?oooa80
00001P3ooolB000000T0oooo0`0000030?ooo`<000003P3AcJT000`0dLfY2`000003ooooo`@00000
0oooool7000000Cooooo3P000004ooooo`L000001?ooool3000000Cooooo2`00000:0=7=Z@d00000
1?ooool3000000Cooooo1`00000=ooooo`@000000oooool7000000Oooooo1`000006ooooo`/0dLfY
0oooool6000000Cooooo0`000003ooooo`@000000oooool@000000?ooooo10000006oooooaL00000
2P3AcJT7ooooo`<000000oooool6000000Oooooo30000003ooooo`d000001_ooool7000000?ooooo
0`000006ooooo`X0dLfY0`0000030?ooo`<000002@3ooolB000000H0oooo4P0000090?ooo`<00000
0`3oool3000000h0dLfY000<0=7=Z@/000000oooool4000000?ooooo1`000004ooooo`h000001?oo
ool7000000Cooooo0`000004ooooo`/000002P3AcJT3ooooo`@000001_ooool4000000?ooooo1000
0007oooooa/000000oooool>000000?ooooo2`3AcJT3ooooo`H000001?ooool3000000?ooooo1000
0003oooooa0000000oooool4000000Kooooo5`00000:0=7=Z@Oooooo0`000003ooooo`H000001ooo
ool<000000?ooooo3@000006ooooo`L000000oooool3000000Kooooo2P3AcJT60?ooo`H000000`3o
ool3000000<0oooo2@00000B0?ooo`T000000`3oool3000000<0oooo1P0000060?ooo`h0dLfY000<
0=7=Z@L000005OoooolF000001Gooooo2000000:0=7=Z@?ooooo10000006ooooo`@000000oooool4
000000Oooooo6`000003ooooo`h000000oooool;0=7=Z@?ooooo1P000004ooooo`<000000oooool4
000000?ooooo40000003ooooo`@000001_oooolG000000X0dLfY10000006oooooaH000001_ooool3
000000Oooooo5P000006ooooo`<000002P3AcJT60?ooo`H000000`3oool3000000<0oooo2@00000B
0?ooo`T000000`3oool3000000<0oooo1P0000060?ooo`h0dLfY000<0=7=Z@L000005OoooolF0000
01Gooooo2000000:0=7=Z@?ooooo10000006ooooo`@000000oooool4000000Oooooo6`000003oooo
o`h000000oooool;0=7=Z@<000001_ooool4000000?ooooo4000000=oooooa4000000oooool30000
00Oooooo0`00000:0=7=Z@@000001_oooolF000000Kooooo0`000007oooooaH000001_ooool30000
00X0dLfY1P3oool6000000<0oooo0`0000030?ooo`T000004P3oool9000000<0oooo0`0000030?oo
o`H000001P3oool>0=7=Z@00303AcJT7000001Gooooo5P00000Eooooo`P000002P3AcJT=000000_o
oooo2P00000:ooooo`@000000oooool3000000Cooooo4@000003ooooo`/0dLfY0`000006ooooo`@0
00000oooool@000000gooooo4@000003ooooo`<000001oooool3000000X0dLfY10000006oooooaH0
00001_ooool3000000Oooooo5P000006ooooo`<000002P3AcJT90?ooo`H000002@3oool3000000<0
oooo0`0000030?ooo`H000000`3oool3000000<0oooo0`0000090?ooo`H000002@3oool>0=7=Z@00
303AcJT7000001Gooooo5P00000Eooooo`P000002P3AcJT=000000_ooooo2P00000:ooooo`@00000
0oooool3000000Cooooo4@000003ooooo`/0dLfY0`000006ooooo`@000000oooool@000000gooooo
4@000003ooooo`<000001oooool3000000X0dLfY1oooool<000000Oooooo0`000003ooooo`H00000
0oooool7000000?ooooo0`000006ooooo`d000001_ooool:0=7=Z@T0oooo1P0000090?ooo`<00000
0`3oool3000000<0oooo1P0000030?ooo`<000000`3oool3000000T0oooo1P0000090?ooo`h0dLfY
000<0=7=Z@Oooooo1`000004ooooo`<000001?oooolM000000?ooooo10000003ooooo`L000002?oo
ool:0=7=Z@d000002oooool:000000[ooooo10000003ooooo`<000001?oooolA000000?ooooo2`3A
cJT3ooooo`H000001oooool7000000?ooooo0`000003ooooo`@000004oooool4000000Kooooo3@00
000:0=7=Z@Oooooo30000007ooooo`<000000oooool6000000?ooooo1`000003ooooo`<000001_oo
ool=000000Kooooo2P3AcJT90?ooo`H000002@3oool3000000<0oooo0`0000030?ooo`H000000`3o
ool3000000<0oooo0`0000090?ooo`H000002@3oool>0=7=Z@00303AcJT7ooooo`L000001?ooool3
000000Cooooo7@000003ooooo`@000000oooool7000000Sooooo2P3AcJT=000000_ooooo2P00000:
ooooo`@000000oooool3000000Cooooo4@000003ooooo`/0dLfY0oooool6000000Oooooo1`000003
ooooo`<000000oooool4000001?ooooo10000006ooooo`d000002P3AcJT7ooooo``000001oooool3
000000?ooooo1P000003ooooo`L000000oooool3000000Kooooo3@000006ooooo`X0dLfY2@000003
0?ooo`l000001P3oool<000000H0oooo3`0000030?ooo`T000003P3AcJT000`0dLfY1oooool70000
00Cooooo0`000004oooooad000000oooool4000000?ooooo1`000008ooooo`X0dLfY1`000003oooo
oa4000001oooool3000000Cooooo1`000003ooooo`<000001?ooool>000000Kooooo2`3AcJT3oooo
o`H000001oooool7000000?ooooo0`000003ooooo`@000004oooool4000000Kooooo3@00000:0=7=
Z@Oooooo2@000003ooooo`X000000oooool6000000?ooooo1`000003ooooo`T000000oooool:0000
00Kooooo2P3AcJT9000000<0oooo3`0000060?ooo``000001P3oool?000000<0oooo2@00000>0=7=
Z@00303AcJT3ooooo`l000000ooooolT000000Cooooo3P000004ooooo`X0dLfY1`000003oooooa40
00001oooool3000000Cooooo1`000003ooooo`<000001?ooool>000000Kooooo2`3AcJT3ooooo`H0
00001oooool7000000?ooooo0`000003ooooo`@000004oooool4000000Kooooo3@00000:0=7=Z@Oo
oooo2@000003ooooo`X000000oooool6000000?ooooo1`000003ooooo`T000000oooool:000000Ko
oooo2P3AcJT9000000<0oooo3`0000060?ooo``000001P3oool?000000<0oooo2@00000>0=7=Z@00
303AcJT3ooooo`l000000ooooolT000000Cooooo3P000004ooooo`X0dLfY1`000003oooooa400000
1oooool3000000Cooooo1`000003ooooo`<000001?ooool>000000Kooooo2`3AcJT=000000gooooo
0`00000:ooooo`H000001oooool:0000013ooooo2P3AcJT7ooooo`T000000oooool:000000?ooooo
1P000003ooooo`L000000oooool9000000?ooooo2P000006ooooo`X0dLfY0`0000030?ooo`<00000
5@3ooolB000001D0oooo0`0000030?ooo`<000003P3AcJT000`0dLfY0oooool?000000?ooooo9000
0004ooooo`h000001?ooool:0=7=ZA_ooooo1`000003ooooo`L000001?ooool:000000?ooooo1`00
0004ooooo`H000002`3AcJT=000000gooooo0`00000:ooooo`H000001oooool:0000013ooooo2P3A
cJT4000000Kooooo0`000006ooooo`<000001oooool3000000Kooooo0`000007ooooo`<000001_oo
ool3000000Oooooo0`000006ooooo`<000002P3AcJT3000000<0oooo0`00000E0?oooa8000005@3o
ool3000000<0oooo0`00000>0=7=Z@00303AcJT3ooooo`l000000ooooolT000000Cooooo3P000004
ooooo`X0dLfY6oooool7000000?ooooo1`000004ooooo`X000000oooool7000000Cooooo1P00000;
0=7=Z@d000003Oooool3000000[ooooo1P000007ooooo`X000004?ooool:0=7=Z@@000001_ooool3
000000Kooooo0`000007ooooo`<000001_ooool3000000Oooooo0`000006ooooo`<000001oooool3
000000Kooooo0`00000:0=7=Z@<000000`3oool3000001D0oooo4P00000E0?ooo`<000000`3oool3
000000h0dLfY000<0=7=Z@?ooooo3`000003ooooob@000001?ooool>000000Cooooo2P3AcJTKoooo
o`L000000oooool7000000Cooooo2P000003ooooo`L000001?ooool6000000/0dLfY3@00000=oooo
o`<000002_ooool6000000Oooooo2P00000@ooooo`X0dLfY10000006ooooo`<000001_ooool30000
00Oooooo0`000006ooooo`<000001oooool3000000Kooooo0`000007ooooo`<000001_ooool30000
00X0dLfY0`0000030?ooo`<000005@3ooolB000001D0oooo0`0000030?ooo`<000003P3AcJT000`0
dLfY0oooool?000000?ooooo90000004ooooo`h000001?ooool:0=7=Z@Oooooo0`00000>ooooo`X0
00000oooool4000000Oooooo2P00000>ooooo`H000002`3AcJT=000000gooooo0`00000:ooooo`H0
00001oooool:0000013ooooo2P3AcJT7ooooo`T000000oooool:000000?ooooo1P000003ooooo`L0
00000oooool9000000?ooooo2P000006ooooo`X0dLfY0`0000030?ooo`<000005@3ooolB000001D0
oooo0`0000030?ooo`<000003P3AcJT000`0dLfY0oooool?000000?ooooo90000004ooooo`h00000
1?ooool:0=7=Z@Oooooo0`00000>ooooo`X000000oooool4000000Oooooo2P00000>ooooo`H00000
2`3AcJT=000000gooooo0`00000:ooooo`H000001oooool:0000013ooooo2P3AcJT7ooooo`T00000
0oooool:000000?ooooo1P000003ooooo`L000000oooool9000000?ooooo2P000006ooooo`X0dLfY
0`0000030?ooo`<000005@3ooolB000001D0oooo0`0000030?ooo`<000003P3AcJT000`0dLfY1ooo
ool7000000Cooooo0`000004oooooad000000oooool4000000?ooooo1`000008ooooo`X0dLfY1ooo
ool3000000kooooo2P000003ooooo`@000001oooool:000000kooooo1P00000;0=7=Z@?ooooo1P00
0007ooooo`L000000oooool3000000?ooooo1000000Cooooo`@000001_ooool=000000X0dLfY1ooo
ool9000000?ooooo2P000003ooooo`H000000oooool7000000?ooooo2@000003ooooo`X000001_oo
ool:0=7=Z@T000000`3oool?000000H0oooo300000060?ooo`l000000`3oool9000000h0dLfY000<
0=7=Z@Oooooo1`000004ooooo`<000001?oooolM000000?ooooo10000003ooooo`L000002?ooool:
0=7=Z@Oooooo0`00000>ooooo`X000000oooool4000000Oooooo2P00000>ooooo`H000002`3AcJT3
ooooo`H000001oooool7000000?ooooo0`000003ooooo`@000004oooool4000000Kooooo3@00000:
0=7=Z@Oooooo30000007ooooo`<000000oooool6000000?ooooo1`000003ooooo`<000001_ooool=
000000Kooooo2P3AcJT9000000<0oooo3`0000060?ooo``000001P3oool?000000<0oooo2@00000>
0=7=Z@00303AcJT7ooooo`L000001?ooool3000000Cooooo7@000003ooooo`@000000oooool70000
00Sooooo2P3AcJT3000000[ooooo1`000004ooooo`L000000oooool:000000Oooooo0`00000Hoooo
o`/0dLfY0oooool6000000Oooooo1`000003ooooo`<000000oooool4000001?ooooo10000006oooo
o`d000002P3AcJT7ooooo``000001oooool3000000?ooooo1P000003ooooo`L000000oooool30000
00Kooooo3@000006ooooo`X0dLfY2@0000030?ooo`l000001P3oool<000000H0oooo3`0000030?oo
o`T000003P3AcJT000`0dLfY1oooool7000000Cooooo0`000004oooooad000000oooool4000000?o
oooo1`000008ooooo`X0dLfY0`00000:ooooo`L000001?ooool7000000?ooooo2P000007ooooo`<0
00006?ooool;0=7=Z@<000001_ooool4000000?ooooo4000000=oooooa4000000oooool3000000Oo
oooo0`00000:0=7=Z@Oooooo30000007ooooo`<000000oooool6000000?ooooo1`000003ooooo`<0
00001_ooool=000000Kooooo2P3AcJT90?ooo`H000002@3oool3000000<0oooo0`0000030?ooo`H0
00000`3oool3000000<0oooo0`0000090?ooo`H000002@3oool>0=7=Z@00303AcJT7000001Gooooo
5P00000Eooooo`P000002P3AcJT3000000[ooooo1`000004ooooo`L000000oooool:000000Oooooo
0`00000Hooooo`/0dLfY0`000006ooooo`@000000oooool@000000gooooo4@000003ooooo`<00000
1oooool3000000X0dLfY10000006oooooaH000001_ooool3000000Oooooo5P000006ooooo`<00000
2P3AcJT90?ooo`H000002@3oool3000000<0oooo0`0000030?ooo`H000000`3oool3000000<0oooo
0`0000090?ooo`H000002@3oool>0=7=Z@00303AcJT7000001Gooooo5P00000Eooooo`P000002P3A
cJT=ooooo`/000002_ooool:000000Cooooo60000006ooooo`/0dLfY0`000006ooooo`@000000ooo
ool@000000gooooo4@000003ooooo`<000001oooool3000000X0dLfY10000006oooooaH000001_oo
ool3000000Oooooo5P000006ooooo`<000002P3AcJT90?ooo`H000002@3oool3000000<0oooo0`00
00030?ooo`H000000`3oool3000000<0oooo0`0000090?ooo`H000002@3oool>0=7=Z@00303AcJT7
000001Gooooo5P00000Eooooo`P000002P3AcJT=ooooo`/000002_ooool:000000Cooooo60000006
ooooo`/0dLfY0oooool6000000Cooooo0`000003ooooo`@000000oooool@000000?ooooo10000006
oooooaL000002P3AcJT4000000Kooooo5P000006ooooo`<000001ooooolF000000Kooooo0`00000:
0=7=Z@H0oooo1P0000030?ooo`<000000`3oool900000180oooo2@0000030?ooo`<000000`3oool6
000000H0oooo3P3AcJT000`0dLfY2`000003ooooo`@000000oooool7000000Cooooo3P000004oooo
o`L000001?ooool3000000Cooooo2`00000:0=7=Z@gooooo2`00000:ooooo`X000001?oooolH0000
00Kooooo2`3AcJT3ooooo`H000001?ooool3000000?ooooo10000003oooooa0000000oooool40000
00Kooooo5`00000:0=7=Z@@000001_oooolF000000Kooooo0`000007oooooaH000001_ooool30000
00X0dLfY1P3oool6000000<0oooo0`0000030?ooo`T000004P3oool9000000<0oooo0`0000030?oo
o`H000001P3oool>0=7=Z@00303AcJT;000000?ooooo10000003ooooo`L000001?ooool>000000Co
oooo1`000004ooooo`<000001?ooool;000000X0dLfY0oooool7000000Oooooo2P00000:ooooo`@0
00000oooool:000000kooooo10000003ooooo`<000002`3AcJT3ooooo`H000001?ooool3000000?o
oooo10000003oooooa0000000oooool4000000Kooooo5`00000:0=7=Z@Oooooo0`000003ooooo`H0
00001oooool<000000?ooooo3@000006ooooo`L000000oooool3000000Kooooo2P3AcJT60?ooo`H0
00000`3oool3000000<0oooo2@00000B0?ooo`T000000`3oool3000000<0oooo1P0000060?ooo`h0
dLfY000<0=7=Z@/000000oooool4000000?ooooo1`000004ooooo`h000001?ooool7000000Cooooo
0`000004ooooo`/000002P3AcJT3ooooo`L000001oooool:000000[ooooo10000003ooooo`X00000
3_ooool4000000?ooooo0`00000;0=7=Z@?ooooo1P000004ooooo`<000000oooool4000000?ooooo
40000003ooooo`@000001_oooolG000000X0dLfY1oooool3000000?ooooo1P000007ooooo``00000
0oooool=000000Kooooo1`000003ooooo`<000001_ooool:0=7=Z@<000000`3oool3000000T0oooo
4P0000060?oooa8000002@3oool3000000<0oooo0`00000>0=7=Z@00303AcJT;000000?ooooo1000
0003ooooo`L000001?ooool>000000Cooooo1`000004ooooo`<000001?ooool;000000X0dLfY0ooo
ool7000000Oooooo2P00000:ooooo`@000000oooool:000000kooooo10000003ooooo`<000002`3A
cJT9000000[ooooo10000006ooooo`<000001oooool@000000Cooooo0`000003ooooo`<000002_oo
ool:0=7=Z@Oooooo0`000003ooooo`H000001oooool<000000?ooooo3@000006ooooo`L000000ooo
ool3000000Kooooo2P3AcJT3000000<0oooo0`0000090?oooa8000001P3ooolB000000T0oooo0`00
00030?ooo`<000003P3AcJT000`0dLfY0oooool;000000Cooooo2P000008ooooo`L000001oooool;
000000?ooooo2`000004ooooo`X0dLfY0oooool7000000Oooooo2P00000:ooooo`@000000oooool:
000000kooooo10000003ooooo`<000002`3AcJT9000000[ooooo10000006ooooo`<000001oooool@
000000Cooooo0`000003ooooo`<000002_ooool:0=7=ZA?ooooo1`000003ooooo`<000000oooool3
000000?ooooo10000003ooooo`<000000oooool6000001?ooooo2P3AcJT3000000<0oooo0`000009
0?oooa8000001P3ooolB000000T0oooo0`0000030?ooo`<000003P3AcJT000`0dLfY0oooool;0000
00Cooooo2P000008ooooo`L000001oooool;000000?ooooo2`000004ooooo`X0dLfY0oooool70000
00?ooooo10000003ooooo`L000001?ooool:000000?ooooo1`000003ooooo`@000001oooool:0000
00?ooooo2`3AcJT9000000[ooooo10000006ooooo`<000001oooool@000000Cooooo0`000003oooo
o`<000002_ooool:0=7=ZA?ooooo1`000003ooooo`<000000oooool3000000?ooooo10000003oooo
o`<000000oooool6000001?ooooo2P3AcJT30?oooa/000000`3oool3000000H0oooo0`0000030?oo
oa/000000`3oool>0=7=Z@00303AcJT3ooooo`/000001?ooool:000000Sooooo1`000007ooooo`/0
00000oooool;000000Cooooo2P3AcJT3ooooo`L000000oooool4000000?ooooo1`000004ooooo`X0
00000oooool7000000?ooooo10000007ooooo`X000000oooool;0=7=Z@H000003Oooool4000000?o
oooo3@000006ooooo`@000000oooool3000000Cooooo0`000003ooooo`L000001_ooool:0=7=ZA?o
oooo1`000003ooooo`<000000oooool3000000?ooooo10000003ooooo`<000000oooool6000001?o
oooo2P3AcJT30?oooa/000000`3oool3000000H0oooo0`0000030?oooa/000000`3oool>0=7=Z@00
303AcJT3000000Cooooo1`000004ooooo`L000001oooool4000000Oooooo0`000008ooooo`L00000
0oooool7000000Cooooo1000000:0=7=Z@?ooooo1`000003ooooo`@000000oooool7000000Cooooo
2P000003ooooo`L000000oooool4000000Oooooo2P000003ooooo`/0dLfY1P00000=ooooo`@00000
0oooool=000000Kooooo10000003ooooo`<000001?ooool3000000?ooooo1`000006ooooo`X0dLfY
1`000003ooooo`<000000oooool:000000?ooooo0`000003ooooo`X000000oooool3000000?ooooo
2@000004ooooo`<000000oooool6000000X0dLfY0`3ooolK000000<0oooo0`0000060?ooo`<00000
0`3ooolK000000<0oooo3P3AcJT000`0dLfY0`000004ooooo`L000001?ooool7000000Oooooo1000
0007ooooo`<000002?ooool7000000?ooooo1`000004ooooo`@000002P3AcJT:ooooo`<000003_oo
ool7000000Oooooo0`00000Eooooo`d000002`3AcJT6000000gooooo10000003ooooo`d000001_oo
ool4000000?ooooo0`000004ooooo`<000000oooool7000000Kooooo2P3AcJT7000000?ooooo0`00
0003ooooo`X000000oooool3000000?ooooo2P000003ooooo`<000000oooool9000000Cooooo0`00
0003ooooo`H000002P3AcJT9000000T0oooo2@0000060?ooo`<000001P3oool3000000H0oooo2@00
00090?ooo`T000003P3AcJT000`0dLfY0`000004ooooo`L000001?ooool7000000Oooooo10000007
ooooo`<000002?ooool7000000?ooooo1`000004ooooo`@000002P3AcJT:ooooo`<000003_ooool7
000000Oooooo0`00000Eooooo`d000002`3AcJT6ooooo`X000000oooool=000000Cooooo3@000003
ooooo`d000000oooool4000000?ooooo0`00000:0=7=Z@L000000oooool3000000?ooooo2P000003
ooooo`<000000oooool:000000?ooooo0`000003ooooo`T000001?ooool3000000?ooooo1P00000:
0=7=Z@T000002@3oool9000000H0oooo0`0000060?ooo`<000001P3oool9000000T0oooo2@00000>
0=7=Z@00303AcJT3000000Cooooo1`000004ooooo`L000001oooool4000000Oooooo0`000008oooo
o`L000000oooool7000000Cooooo1000000:0=7=Z@[ooooo0`00000>ooooo`L000001oooool30000
01Gooooo3@00000;0=7=Z@Kooooo2P000003ooooo`d000001?ooool=000000?ooooo3@000003oooo
o`@000000oooool3000000X0dLfY2P000003ooooo`T000001?ooool9000000[ooooo2@000003oooo
o`X000000oooool9000000X0dLfY2@0000090?ooo`T000001P3oool3000000H0oooo0`0000060?oo
o`T000002@3oool9000000h0dLfY000<0=7=Z@kooooo10000007ooooo`<000002?ooool7000000Oo
oooo10000007ooooo`<000003oooool:0=7=Z@<000001?ooool3000000?ooooo1`000004ooooo`L0
00000oooool7000000?ooooo10000003ooooo`<000001?ooool3000000Oooooo2P00000;0=7=Z@Ko
oooo2P000003ooooo`d000001?ooool=000000?ooooo3@000003ooooo`@000000oooool3000000X0
dLfY2P000003ooooo`T000001?ooool9000000[ooooo2@000003ooooo`X000000oooool9000000X0
dLfY1P0000030?ooo`<000000`3oool3000000<0oooo0`0000030?ooo`<000000`3oool3000000H0
oooo0`0000030?ooo`<000000`3oool3000000<0oooo0`0000030?ooo`<000000`3oool6000000h0
dLfY000<0=7=Z@kooooo10000007ooooo`<000002?ooool7000000Oooooo10000007ooooo`<00000
3oooool:0=7=Z@<000001?ooool3000000?ooooo1`000004ooooo`L000000oooool7000000?ooooo
10000003ooooo`<000001?ooool3000000Oooooo2P00000;0=7=Z@?ooooo1P000004ooooo`H00000
1oooool3000001Cooooo0`000007ooooo`H000000oooool7000000?ooooo2P3AcJT:000000?ooooo
2@000004ooooo`T000002_ooool9000000?ooooo2P000003ooooo`T000002P3AcJT6000000<0oooo
0`0000030?ooo`<000000`3oool3000000<0oooo0`0000030?ooo`<000001P3oool3000000<0oooo
0`0000030?ooo`<000000`3oool3000000<0oooo0`0000030?ooo`H000003P3AcJT000`0dLfY3_oo
ool4000000Oooooo0`000008ooooo`L000001oooool4000000Oooooo0`00000?ooooo`X0dLfY0`00
0004ooooo`<000000oooool7000000Cooooo1`000003ooooo`L000000oooool4000000?ooooo0`00
0004ooooo`<000001oooool:000000/0dLfY0oooool6000000Cooooo1P000007ooooo`<000005?oo
ool3000000Oooooo1P000003ooooo`L000000oooool:0=7=Z@Cooooo1P000003ooooo`H000001ooo
ool<000000?ooooo3@000006ooooo`L000000oooool6000000?ooooo2P3AcJT6000000<0oooo0`00
00030?ooo`<000000`3oool3000000<0oooo0`0000030?ooo`<000001P3oool3000000<0oooo0`00
00030?ooo`<000000`3oool3000000<0oooo0`0000030?ooo`H000003P3AcJT000`0dLfY0oooool4
000000Cooooo0`000004ooooo`L000001oooool>000000Sooooo1`000003ooooo`@000000oooool4
000000Cooooo2P3AcJT3000000Cooooo0`000003ooooo`L000001?ooool7000000?ooooo1`000003
ooooo`@000000oooool3000000Cooooo0`000007ooooo`X000002`3AcJT3ooooo`H000001?ooool6
000000Oooooo0`00000Dooooo`<000001oooool6000000?ooooo1`000003ooooo`X0dLfY1?ooool6
000000?ooooo1P000007ooooo``000000oooool=000000Kooooo1`000003ooooo`H000000oooool:
0=7=Z@`0oooo0`0000060?ooo`<000001P3oool6000000H0oooo1P0000060?ooo`<000001P3oool3
000000`0oooo3P3AcJT000`0dLfY0oooool4000000Cooooo0`000004ooooo`L000001oooool>0000
00Sooooo1`000003ooooo`@000000oooool4000000Cooooo2P3AcJT3ooooo`@000001_ooool>0000
00Oooooo1`000007ooooo`<000000oooool4000000Oooooo0`000004ooooo`<000000oooool;0=7=
Z@?ooooo0`00000:oooooa@000002Oooool4000000?ooooo1`000006ooooo`<000001?ooool60000
00X0dLfY1?ooool6000000?ooooo1P000007ooooo``000000oooool=000000Kooooo1`000003oooo
o`H000000oooool:0=7=Z@`0oooo0`0000060?ooo`<000001P3oool6000000H0oooo1P0000060?oo
o`<000001P3oool3000000`0oooo3P3AcJT000`0dLfY0oooool4000000Cooooo0`000004ooooo`L0
00001oooool>000000Sooooo1`000003ooooo`@000000oooool4000000Cooooo2P3AcJT3ooooo`@0
00001_ooool>000000Oooooo1`000007ooooo`<000000oooool4000000Oooooo0`000004ooooo`<0
00000oooool;0=7=Z@?ooooo0`00000:oooooa@000002Oooool4000000?ooooo1`000006ooooo`<0
00001?ooool6000000X0dLfY10000006ooooo`<000001_ooool3000000Oooooo5P000006ooooo`<0
00001oooool3000000Kooooo0`00000:0=7=Z@`0oooo0`0000060?ooo`<000001P3oool6000000H0
oooo1P0000060?ooo`<000001P3oool3000000`0oooo3P3AcJT000`0dLfY0oooool4000000Cooooo
0`000004ooooo`L000001oooool>000000Sooooo1`000003ooooo`@000000oooool4000000Cooooo
2P3AcJT3ooooo`@000001_ooool>000000Oooooo1`000007ooooo`<000000oooool4000000Oooooo
0`000004ooooo`<000000oooool;0=7=Z@?ooooo0`00000:oooooa@000002Oooool4000000?ooooo
1`000006ooooo`<000001?ooool6000000X0dLfY10000006ooooo`<000001_ooool3000000Oooooo
5P000006ooooo`<000001oooool3000000Kooooo0`00000:0=7=Z@H0oooo1P0000030?ooo`<00000
0`3oool3000000<0oooo1P00000<0?ooo`H000000`3oool3000000<0oooo0`0000030?ooo`H00000
1P3oool>0=7=Z@00303AcJT7ooooo`@000001oooool:000000Cooooo3P000004ooooo`/000001ooo
ool3000000Sooooo2P3AcJT3000000Cooooo0`000007ooooo`<000001oooool4000000gooooo1000
000:ooooo`<000002oooool6000000/0dLfY0oooool3000000[ooooo50000009ooooo`@000000ooo
ool7000000Kooooo0`000004ooooo`H000002P3AcJT4000000Kooooo0`000006ooooo`<000001ooo
oolF000000Kooooo0`000007ooooo`<000001_ooool3000000X0dLfY1P3oool6000000<0oooo0`00
00030?ooo`<000000`3oool6000000`0oooo1P0000030?ooo`<000000`3oool3000000<0oooo1P00
00060?ooo`h0dLfY000<0=7=Z@Oooooo10000007ooooo`X000001?ooool>000000Cooooo2`000007
ooooo`<000002?ooool:0=7=Z@<000001?ooool3000000Oooooo0`000007ooooo`@000003Oooool4
000000[ooooo0`00000;ooooo`H000002`3AcJT3ooooo`d000002_ooool3000000?ooooo10000003
ooooo`<000002_ooool=000000[ooooo0`00000:0=7=Z@Cooooo1P000003ooooo`H000001oooool3
000000?ooooo1P000003ooooo`L000000oooool3000000Kooooo1`000003ooooo`H000000oooool:
0=7=Z@H0oooo1P0000030?ooo`<000000`3oool3000000<0oooo1P00000<0?ooo`H000000`3oool3
000000<0oooo0`0000030?ooo`H000001P3oool>0=7=Z@00303AcJT7ooooo`@000001oooool:0000
00Cooooo3P000004ooooo`/000001oooool3000000Sooooo2P3AcJT3000000Cooooo0`000007oooo
o`<000001oooool4000000gooooo1000000:ooooo`<000002oooool6000000/0dLfY0oooool=0000
00[ooooo0`000003ooooo`@000000oooool3000000[ooooo3@00000:ooooo`<000002P3AcJT4oooo
o`H000000oooool6000000Oooooo0`000003ooooo`H000000oooool7000000?ooooo0`000006oooo
o`L000000oooool6000000?ooooo2P3AcJT3000000<0oooo1P0000060?ooo``000000`3oool<0000
00<0oooo300000060?ooo`H000000`3oool3000000h0dLfY000<0=7=Z@L000001?ooool3000000Oo
oooo2`000004ooooo`L000000oooool;000000Oooooo10000003ooooo`P000002P3AcJT=ooooo`h0
00005Oooool:0000017ooooo0`00000;0=7=Z@?ooooo3@00000:ooooo`<000000oooool4000000?o
oooo0`00000:ooooo`d000002_ooool3000000X0dLfY1?ooool6000000?ooooo1P000007ooooo`<0
00000oooool6000000?ooooo1`000003ooooo`<000001_ooool7000000?ooooo1P000003ooooo`X0
dLfY0`0000030?ooo`H000001P3oool<000000<0oooo300000030?ooo``000001P3oool6000000<0
oooo0`00000>0=7=Z@00303AcJT7000000Cooooo0`000007ooooo`/000001?ooool7000000?ooooo
2`000007ooooo`@000000oooool8000000X0dLfY3Oooool>000001Gooooo2P00000Aooooo`<00000
2`3AcJT=ooooo`H000001?ooool6000000?ooooo1`00000@ooooo`@000000oooool@000000X0dLfY
2P000003ooooo`T000008oooool:000000?ooooo2@00000:0=7=Z@<000000`3oool6000000H0oooo
300000030?ooo``000000`3oool<000000H0oooo1P0000030?ooo`<000003P3AcJT000`0dLfY1`00
0004ooooo`<000001oooool;000000Cooooo1`000003ooooo`/000001oooool4000000?ooooo2000
000:0=7=Z@gooooo3P00000Eooooo`X000004Oooool3000000/0dLfY3Oooool6000000Cooooo1P00
0003ooooo`L000004?ooool4000000?ooooo4000000:0=7=Z@X000000oooool9000002?ooooo2P00
0003ooooo`T000002P3AcJT30?ooo`<000002@3oool9000000T0oooo0`0000060?ooo`<000002@3o
ool9000000T0oooo0`0000030?ooo`h0dLfY000<0=7=Z@L000001?ooool3000000Oooooo2`000004
ooooo`L000000oooool;000000Oooooo10000003ooooo`P000002P3AcJT=ooooo`h000005Oooool:
0000017ooooo0`00000;0=7=Z@gooooo1P000004ooooo`H000000oooool70000013ooooo10000003
oooooa0000002P3AcJT:000000?ooooo2@00000Sooooo`X000000oooool9000000X0dLfY0`3oool3
000000T0oooo2@0000090?ooo`<000001P3oool3000000T0oooo2@0000090?ooo`<000000`3oool>
0=7=Z@00303AcJT7000000_ooooo0`000004ooooo`L000003_ooool8000000?ooooo1000000:oooo
o`P000002P3AcJT3ooooo`@000001_ooool7000000Cooooo6`000003oooooaP000002`3AcJT30000
00Kooooo10000003ooooo`X000000oooool3000000Cooooo5`00000Cooooo`X0dLfY1`000003oooo
o`<000000oooool6000000Oooooo0`000006ooooo`<000001oooool3000000Kooooo1P000004oooo
o`<000000oooool6000000X0dLfY0`3oool3000000T0oooo2@0000090?ooo`<000001P3oool30000
00T0oooo2@0000090?ooo`<000000`3oool>0=7=Z@00303AcJT7000000_ooooo0`000004ooooo`L0
00003_ooool8000000?ooooo1000000:ooooo`P000002P3AcJT3ooooo`@000001_ooool7000000Co
oooo6`000003oooooaP000002`3AcJT3000000Kooooo10000003ooooo`X000000oooool3000000Co
oooo5`00000Cooooo`X0dLfY1`000003ooooo`<000000oooool6000000Oooooo0`000006ooooo`<0
00001oooool3000000Kooooo1P000004ooooo`<000000oooool6000000X0dLfY0`0000030?ooo`<0
00001P3oool6000000<0oooo0`0000060?ooo``000001P3oool3000000<0oooo1P0000060?ooo`<0
00000`3oool3000000h0dLfY000<0=7=Z@L000002oooool3000000Cooooo1`00000>ooooo`P00000
0oooool4000000[ooooo2000000:0=7=Z@?ooooo10000006ooooo`L000001?oooolK000000?ooooo
6000000;0=7=Z@<000001_ooool4000000?ooooo2P000003ooooo`<000001?oooolG000001?ooooo
2P3AcJT7000000?ooooo0`000003ooooo`H000001oooool3000000Kooooo0`000007ooooo`<00000
1_ooool6000000Cooooo0`000003ooooo`H000002P3AcJT3000000<0oooo0`0000060?ooo`H00000
0`3oool3000000H0oooo300000060?ooo`<000000`3oool6000000H0oooo0`0000030?ooo`<00000
3P3AcJT00?l0dLfYL03AcJT3000000<0oooo0`0000060?ooo`H000000`3oool3000000H0oooo3000
00060?ooo`<000000`3oool6000000H0oooo0`0000030?ooo`<000003P3AcJT00?l0dLfYc03AcJT0
0?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT0
0?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT0
00`0dLfY2@00000Cooooo`@000002_ooool4000000Wooooo2P00000>ooooo`X0dLfY20000005oooo
o`@000001Oooool=000000Sooooo3P000004ooooo`@000001Oooool8000000/0dLfY1?ooool40000
04Kooooo2P3AcJT4000000Cooooo10000008ooooobL000002?ooool4000000Cooooo1000000:0=7=
Z@@000001?ooool4000000Oooooo3`00000;ooooo`l000002?ooool4000000?ooooo1000000=0=7=
Z@00303AcJT9000001?ooooo1000000:ooooo`@000002Oooool:000000kooooo2P3AcJT8000000Go
oooo10000005ooooo`d000002?ooool>000000Cooooo10000005ooooo`P000002`3AcJT4ooooo`@0
0000A_ooool:0=7=Z@@000001?ooool4000000Sooooo9`000008ooooo`@000001?ooool4000000X0
dLfY10000004ooooo`@000001oooool?000000_ooooo3`000008ooooo`@000000oooool4000000d0
dLfY000<0=7=Z@T000004oooool4000000[ooooo10000009ooooo`X000003_ooool:0=7=Z@P00000
1Oooool4000000Gooooo3@000008ooooo`h000001?ooool4000000Gooooo2000000;0=7=Z@Cooooo
10000016ooooo`X0dLfY10000004ooooo`@000002?oooolW000000Sooooo10000004ooooo`@00000
2P3AcJT4000000Cooooo10000007ooooo`l000002oooool?000000Sooooo10000003ooooo`@00000
3@3AcJT000`0dLfY2@00000Cooooo`@000002_ooool4000000Wooooo2P00000>ooooo`X0dLfY2000
0005ooooo`@000001Oooool=000000Sooooo3P000004ooooo`@000001Oooool8000000/0dLfY1?oo
ool4000004Kooooo2P3AcJT4000000Cooooo10000008ooooobL000002?ooool4000000Cooooo1000
000:0=7=Z@@000001?ooool4000000Oooooo3`00000;ooooo`l000002?ooool4000000?ooooo1000
000=0=7=Z@00303AcJT9000001?ooooo1000000:ooooo`@000002Oooool:000000kooooo2P3AcJT8
000000Gooooo10000005ooooo`d000002?ooool>000000Cooooo10000005ooooo`P000002`3AcJT<
oooood8000002P3AcJT4ooooo`@000003?ooool40000023ooooo0`00000<ooooo`@000001?ooool:
0=7=Z@Cooooo1000000;ooooo`@000001oooool4000000Cooooo10000003ooooo`@000002?ooool3
000000cooooo0`000004ooooo`d0dLfY000<0=7=Z@T000001Oooool90000023ooooo2P000004oooo
o`X000002P3AcJT=000000Cooooo2@000004ooooo`D000002?ooool5000000Cooooo2@000004oooo
o`d000002`3AcJT<oooood8000002P3AcJT4ooooo`@000003?ooool40000023ooooo0`00000<oooo
o`@000001?ooool:0=7=Z@Cooooo1000000;ooooo`@000001oooool4000000Cooooo10000003oooo
o`@000002?ooool3000000cooooo0`000004ooooo`d0dLfY000<0=7=Z@T000001Oooool90000023o
oooo2P000004ooooo`X000002P3AcJT=000000Cooooo2@000004ooooo`D000002?ooool5000000Co
oooo2@000004ooooo`d000002`3AcJT<oooood8000002P3AcJT4ooooo`@000003?ooool40000023o
oooo0`00000<ooooo`@000001?ooool:0=7=Z@Cooooo1000000;ooooo`@000001oooool4000000Co
oooo10000003ooooo`@000002?ooool3000000cooooo0`000004ooooo`d0dLfY000<0=7=Z@T00000
1Oooool90000023ooooo2P000004ooooo`X000002P3AcJT=000000Cooooo2@000004ooooo`D00000
2?ooool5000000Cooooo2@000004ooooo`d000002`3AcJT<oooood8000002P3AcJT4ooooo`@00000
3?ooool40000023ooooo0`00000<ooooo`@000001?ooool:0=7=Z@Cooooo1000000;ooooo`@00000
1oooool4000000Cooooo10000003ooooo`@000002?ooool3000000cooooo0`000004ooooo`d0dLfY
000<0=7=Z@T000001Oooool90000023ooooo2P000004ooooo`X000002P3AcJT=000000Cooooo2@00
0004ooooo`D000002?ooool5000000Cooooo2@000004ooooo`d000002`3AcJT4000000Sooooo1000
000jooooo`@000002P3AcJT4000000Cooooo20000004ooooo`P000006?ooool7000000Cooooo2000
0004ooooo`@000002P3AcJT4000000Cooooo1`000004oooooa<000001?oooolB000000Cooooo2000
0003ooooo`@000003@3AcJT000`0dLfY2Oooool>000000Wooooo2P000004ooooo`D000003_ooool>
000000X0dLfY1?ooool9000000Cooooo1@000008ooooo`D000002?ooool5000000Wooooo10000004
ooooo`T000001?ooool;0=7=Z@@000002?ooool4000003[ooooo1000000:0=7=Z@@000001?ooool8
000000Cooooo2000000Hooooo`L000001?ooool8000000Cooooo1000000:0=7=Z@@000001?ooool7
000000Cooooo4`000004oooooa8000001?ooool8000000?ooooo1000000=0=7=Z@00303AcJT9oooo
o`h000002Oooool:000000Cooooo1@00000>ooooo`h000002P3AcJT4ooooo`T000001?ooool50000
00Sooooo1@000008ooooo`D000002Oooool4000000Cooooo2@000004ooooo`/0dLfY10000008oooo
o`@00000>_ooool4000000X0dLfY10000004ooooo`P000001?ooool8000001Sooooo1`000004oooo
o`P000001?ooool4000000X0dLfY10000004ooooo`L000001?oooolC000000Cooooo4P000004oooo
o`P000000oooool4000000d0dLfY000<0=7=Z@Wooooo3P000009ooooo`X000001?ooool5000000ko
oooo3P00000:0=7=Z@Cooooo2@000004ooooo`D000002?ooool5000000Sooooo1@000009ooooo`@0
00001?ooool9000000Cooooo2`3AcJT4000000Sooooo1000000jooooo`@000002P3AcJT4000000Co
oooo20000004ooooo`P000006?ooool7000000Cooooo20000004ooooo`@000002P3AcJT8ooooo`/0
00002oooool8000000Cooooo1`00000;ooooo``000001oooool=0=7=Z@00303AcJT9ooooo`h00000
2Oooool:000000Cooooo1@00000>ooooo`h000002P3AcJT4ooooo`T000001?ooool5000000Sooooo
1@000008ooooo`D000002Oooool4000000Cooooo2@000004ooooo`/0dLfY3?ooool8000003;ooooo
2000000:0=7=Z@Sooooo30000004ooooo`@000001?ooool@000000Cooooo10000003ooooo``00000
2?ooool:0=7=Z@Sooooo2`00000;ooooo`P000001?ooool7000000_ooooo30000007ooooo`d0dLfY
000<0=7=Z@Wooooo3P000009ooooo`X000001?ooool5000000kooooo3P00000:0=7=Z@@000002Ooo
ool=000000Cooooo1@000008ooooo`D000001?ooool=000000Wooooo1000000;0=7=Z@cooooo2000
000booooo`P000002P3AcJT8ooooo``000001?ooool4000000Cooooo40000004ooooo`@000000ooo
ool<000000Sooooo2P3AcJT8ooooo`/000002oooool8000000Cooooo1`00000;ooooo``000001ooo
ool=0=7=Z@00303AcJT5ooooo`d000003_ooool>000000kooooo3P000005ooooo`X0dLfY10000009
ooooo`d000001?ooool5000000Sooooo1@000004ooooo`d000002Oooool4000000/0dLfY3?ooool8
000003;ooooo2000000:0=7=Z@Sooooo30000004ooooo`@000001?ooool@000000Cooooo10000003
ooooo``000002?ooool:0=7=Z@Sooooo2`00000;ooooo`P000001?ooool7000000_ooooo30000007
ooooo`d0dLfY000<0=7=Z@Gooooo3@00000>ooooo`h000003_ooool>000000Gooooo2P3AcJT40000
00Wooooo3@000004ooooo`D000002?ooool5000000Cooooo3@000009ooooo`@000002`3AcJT<oooo
o`P00000<_ooool8000000X0dLfY2?ooool<000000Cooooo10000004oooooa0000001?ooool40000
00?ooooo30000008ooooo`X0dLfY3?ooool;000000Cooooo0`000008ooooo`@000001oooool40000
00Cooooo2`00000;ooooo`d0dLfY000<0=7=Z@Gooooo3@00000>ooooo`h000003_ooool>000000Go
oooo2P3AcJT4000000Wooooo3@000004ooooo`D000002?ooool5000000Cooooo3@000009ooooo`@0
00002`3AcJT4ooooo`@000002?ooool4000000Cooooo:P000004ooooo`@000001?ooool:0=7=Z@co
oooo20000004ooooo``000002?ooool<000000?ooooo2000000<ooooo`X0dLfY3?ooool;000000Co
oooo0`000008ooooo`@000001oooool4000000Cooooo2`00000;ooooo`d0dLfY000<0=7=Z@Gooooo
3@00000>ooooo`h000003_ooool>000000Gooooo2P3AcJT4oooooal000002?oooolO000000Cooooo
2`3AcJT4ooooo`@000002?ooool4000000Cooooo:P000004ooooo`@000001?ooool:0=7=Z@cooooo
20000004ooooo``000002?ooool<000000?ooooo2000000<ooooo`X0dLfY3?ooool;000000Cooooo
0`000008ooooo`@000001oooool4000000Cooooo2`00000;ooooo`d0dLfY000<0=7=Z@Gooooo2@00
0004ooooo`X000002OoooolB000000Gooooo2@000005ooooo`D000002P3AcJT4oooooal000002?oo
oolO000000Cooooo2`3AcJT4ooooo`@000002?ooool4000000Cooooo:P000004ooooo`@000001?oo
ool:0=7=Z@cooooo20000004ooooo``000002?ooool<000000?ooooo2000000<ooooo`X0dLfY3?oo
ool;000000Cooooo0`000008ooooo`@000001oooool4000000Cooooo2`00000;ooooo`d0dLfY000<
0=7=Z@Gooooo2@000004ooooo`X000002OoooolB000000Gooooo2@000005ooooo`D000002P3AcJT4
oooooal000002?oooolO000000Cooooo2`3AcJT4ooooo`@000002?ooool4000000Cooooo:P000004
ooooo`@000001?ooool:0=7=Z@`000002?ooool4000000cooooo2000000<ooooo`<000002?ooool<
000000X0dLfY30000003ooooo``000000oooool8000000Cooooo1`000004ooooo`/000001?ooool;
000000d0dLfY000<0=7=Z@Gooooo2@000004ooooo`X000002OoooolB000000Gooooo2@000005oooo
o`D000002P3AcJT4oooooal000002?oooolO000000Cooooo2`3AcJT<oooooa4000008Oooool@0000
00X0dLfY30000008ooooo`@000003?ooool8000000cooooo0`000008ooooo``000002P3AcJT<0000
00?ooooo30000003ooooo`P000001?ooool7000000Cooooo2`000004ooooo`/000003@3AcJT000`0
dLfY1Oooool9000000Cooooo2P000009oooooa8000001Oooool9000000Gooooo1@00000:0=7=Z@Co
oooo7`000008oooooal000001?ooool;0=7=Z@cooooo4@00000Qoooooa0000002P3AcJT<000000So
oooo1000000<ooooo`P000003?ooool3000000Sooooo3000000:0=7=Z@`000000oooool<000000?o
oooo20000004ooooo`L000001?ooool;000000Cooooo2`00000=0=7=Z@00303AcJT5ooooo`T00000
1?ooool:000000Wooooo4P000005ooooo`T000001Oooool5000000X0dLfY20000005ooooo`d00000
6_ooool=000000Gooooo2000000;0=7=Z@cooooo4@00000Qoooooa0000002P3AcJT<000000Sooooo
1000000<ooooo`P000003?ooool3000000Sooooo3000000:0=7=Z@@000001?ooool4000000Oooooo
20000003ooooo`P000001?ooool7000000Cooooo1`000008ooooo`@000000oooool4000000d0dLfY
000<0=7=ZA;ooooo2P000004ooooo`D000001Oooool4000000Gooooo2@00000Cooooo`X0dLfY2000
0005ooooo`d000006_ooool=000000Gooooo2000000;0=7=Z@cooooo4@00000Qoooooa0000002P3A
cJT4000000Cooooo30000004ooooo`@000001?ooool@000000Cooooo10000003ooooo``000001?oo
ool4000000X0dLfY10000004ooooo`@000001oooool8000000?ooooo20000004ooooo`L000001?oo
ool7000000Sooooo10000003ooooo`@000003@3AcJT000`0dLfY4_ooool:000000Cooooo1@000005
ooooo`@000001Oooool9000001?ooooo2P3AcJT8000000Gooooo3@00000Jooooo`d000001Oooool8
000000/0dLfY3?oooolA0000027ooooo4000000:0=7=Z@@000001?ooool<000000Cooooo10000004
oooooa0000001?ooool4000000?ooooo30000004ooooo`@000002P3AcJT4000000Cooooo10000007
ooooo`P000000oooool8000000Cooooo1`000004ooooo`L000002?ooool4000000?ooooo1000000=
0=7=Z@00303AcJTBooooo`X000001?ooool5000000Gooooo10000005ooooo`T000004oooool:0=7=
Z@P000001Oooool=000001[ooooo3@000005ooooo`P000002`3AcJT4000000Sooooo20000009oooo
o`@000006Oooool4000000Sooooo2000000:0=7=Z@@000001?ooool<000000Cooooo10000004oooo
oa0000001?ooool4000000?ooooo30000004ooooo`@000002P3AcJT4000000Cooooo10000007oooo
o`P000000oooool8000000Cooooo1`000004ooooo`L000002?ooool4000000?ooooo1000000=0=7=
Z@00303AcJTBooooo`X000001?ooool5000000Gooooo10000005ooooo`T000004oooool:0=7=Z@@0
00003Oooool5000000Cooooo10000005ooooo`P000001Oooool4000000Gooooo1000000=ooooo`@0
00002`3AcJT4000000Sooooo20000009ooooo`@000006Oooool4000000Sooooo2000000:0=7=Z@@0
00001?ooool<000000Cooooo10000004oooooa0000001?ooool4000000?ooooo30000004ooooo`@0
00002P3AcJT4000000Cooooo10000003ooooo`@000002?ooool3000000Sooooo10000007ooooo`@0
00001oooool4000000Cooooo10000003ooooo`@000003@3AcJT000`0dLfY1@00000Gooooo`@00000
2_ooool4000000Wooooo2P000004ooooo`D000001Oooool:0=7=Z@@000003Oooool5000000Cooooo
10000005ooooo`P000001Oooool4000000Gooooo1000000=ooooo`@000002`3AcJT4000000Sooooo
20000009ooooo`@000006Oooool4000000Sooooo2000000:0=7=Z@@000003?ooool4000000Sooooo
60000007ooooo`@000003?ooool4000000X0dLfY10000004ooooo`@000000oooool4000000Sooooo
0`000008ooooo`@000001oooool4000000Oooooo10000004ooooo`@000000oooool4000000d0dLfY
000<0=7=Z@D000005oooool4000000[ooooo10000009ooooo`X000001?ooool5000000Gooooo2P3A
cJT4000000gooooo1@000004ooooo`@000001Oooool8000000Gooooo10000005ooooo`@000003Ooo
ool4000000/0dLfY10000008ooooo`P000002Oooool4000001Wooooo10000008ooooo`P000002P3A
cJT4000000cooooo10000008oooooaP000001oooool4000000cooooo1000000:0=7=Z@@000001?oo
ool4000000?ooooo10000008ooooo`<000002?ooool4000000Oooooo10000007ooooo`@000001?oo
ool4000000?ooooo1000000=0=7=Z@00303AcJT5000001Oooooo1000000:ooooo`@000002Oooool:
000000Cooooo1@000005ooooo`X0dLfY1000000=ooooo`D000001?ooool4000000Gooooo20000005
ooooo`@000001Oooool4000000gooooo1000000;0=7=ZACooooo2@000008oooooa0000002Oooool8
000000Sooooo2P3AcJT4000000cooooo10000008oooooaP000001oooool4000000cooooo1000000:
0=7=Z@@000001?ooool4000000?ooooo10000008ooooo`<000002?ooool4000000Oooooo10000007
ooooo`@000001?ooool4000000?ooooo1000000=0=7=Z@00303AcJT5000001Oooooo1000000:oooo
o`@000002Oooool:000000Cooooo1@000005ooooo`X0dLfY5P000008oooooa8000002OoooolE0000
00/0dLfY5?ooool9000000Sooooo40000009ooooo`P000002?ooool:0=7=Z@@000003?ooool40000
00Sooooo60000007ooooo`@000003?ooool4000000X0dLfY3`000004ooooo`P000000oooool80000
00Cooooo1`000004ooooo`L000001?ooool?000000d0dLfY000<0=7=Z@D000005oooool4000000[o
oooo10000009ooooo`X000001?ooool5000000Gooooo2P3AcJTF000000Sooooo4P000009oooooaD0
00002`3AcJTDooooo`T000002?ooool@000000Wooooo20000008ooooo`X0dLfY10000008ooooo`P0
00001?oooolP000000?ooooo20000008ooooo`@000002P3AcJT?000000Cooooo20000003ooooo`P0
00001?ooool7000000Cooooo1`000004ooooo`l000003@3AcJT000`0dLfY2Oooool9000000Gooooo
1@000004ooooo`D000001Oooool4000000Gooooo10000005ooooo`T000002_ooool:0=7=ZAH00000
2?oooolB000000Wooooo5@00000;0=7=ZACooooo2@000008oooooa0000002Oooool8000000Sooooo
2P3AcJT4000000Sooooo20000004ooooob0000000oooool8000000Sooooo1000000:0=7=Z@l00000
1?ooool8000000?ooooo20000004ooooo`L000001?ooool7000000Cooooo3`00000=0=7=Z@00303A
cJT9ooooo`T000001Oooool5000000Cooooo1@000005ooooo`@000001Oooool4000000Gooooo2@00
000:ooooo`X0dLfY5P000008oooooa8000002OoooolE000000/0dLfY1?ooool8000000Cooooo4@00
0004ooooo`@000002?ooool4000000Gooooo40000004ooooo`X0dLfY10000008ooooo`P000001?oo
oolP000000?ooooo20000008ooooo`@000002P3AcJT8ooooo`L000001?ooool8000000?ooooo2000
0004ooooo`L000001?ooool7000000Cooooo20000007ooooo`d0dLfY000<0=7=Z@Wooooo2@000005
ooooo`D000001?ooool5000000Gooooo10000005ooooo`@000001Oooool9000000[ooooo2P3AcJTJ
oooooaX000006_ooool;0=7=Z@Cooooo20000004oooooa4000001?ooool4000000Sooooo10000005
oooooa0000001?ooool:0=7=Z@@000002?ooool8000000Cooooo80000003ooooo`P000002?ooool4
000000X0dLfY2?ooool7000000Cooooo20000003ooooo`P000001?ooool7000000Cooooo1`000004
ooooo`P000001oooool=0=7=Z@00303AcJT9ooooo`T000001Oooool5000000Cooooo1@000005oooo
o`@000001Oooool4000000Gooooo2@00000:ooooo`X0dLfY6_oooolJ000001[ooooo2`3AcJT4oooo
o`P000001?oooolA000000Cooooo10000008ooooo`@000001Oooool@000000Cooooo2P3AcJT40000
00Sooooo10000004ooooobL000001?ooool4000000Sooooo1000000:0=7=Z@Sooooo1`000004oooo
o`P000000oooool8000000Cooooo1`000004ooooo`L000001?ooool8000000Oooooo3@3AcJT000`0
dLfY2Oooool>000000kooooo3P00000>ooooo`h000002P3AcJTJoooooaX000006_ooool;0=7=Z@Co
oooo20000004oooooa4000001?ooool4000000Sooooo10000005oooooa0000001?ooool:0=7=Z@@0
00002?ooool4000000Cooooo9`000004ooooo`@000002?ooool4000000X0dLfY2?ooool7000000Co
oooo20000003ooooo`P000001?ooool7000000Cooooo1`000004ooooo`P000001oooool=0=7=Z@00
303AcJT9ooooo`h000003_ooool>000000kooooo3P00000:0=7=ZA[ooooo6P00000Jooooo`/0dLfY
1?oooom6000000Cooooo2P3AcJT4000000Sooooo10000004ooooobL000001?ooool4000000Sooooo
1000000:0=7=Z@Cooooo10000007ooooo`@000002?ooool3000000Sooooo10000007ooooo`@00000
1oooool4000000Sooooo0`000004ooooo`d0dLfY000<0=7=Z@Wooooo3P00000>ooooo`h000003_oo
ool>000000X0dLfY6_oooolJ000001[ooooo2`3AcJT4ooooodH000001?ooool:0=7=Z@@000002?oo
ool4000000Cooooo9`000004ooooo`@000002?ooool4000000X0dLfY1?ooool4000000Oooooo1000
0008ooooo`<000002?ooool4000000Oooooo10000007ooooo`@000002?ooool3000000Cooooo3@3A
cJT000`0dLfY2Oooool>000000kooooo3P00000>ooooo`h000002P3AcJTJoooooaX000006_ooool;
0=7=Z@CoooooAP000004ooooo`X0dLfY10000008ooooo`@000001?oooolW000000Cooooo10000008
ooooo`@000002P3AcJT4ooooo`@000001oooool4000000Sooooo0`000008ooooo`@000001oooool4
000000Oooooo10000008ooooo`<000001?ooool=0=7=Z@00303AcJT9ooooo`h000003_ooool>0000
00kooooo3P00000:0=7=ZA[ooooo6P00000Jooooo`/0dLfY1?oooom6000000Cooooo2P3AcJT40000
00Sooooo10000004ooooobL000001?ooool4000000Sooooo1000000:0=7=Z@Sooooo1`000004oooo
o`P000000oooool8000000Cooooo1`000004ooooo`L000001?ooool8000000Oooooo3@3AcJT000`0
dLfY1@000009oooooc<000002Oooool5000000X0dLfY6_oooolJ000001[ooooo2`3AcJT8ooooo`@0
00001?oooolA000000Cooooo10000008ooooo`@000001Oooool<000000Sooooo2P3AcJT4000000So
oooo10000004ooooobL000001?ooool4000000Sooooo1000000:0=7=Z@Sooooo1`000004ooooo`P0
00000oooool8000000Cooooo1`000004ooooo`L000001?ooool8000000Oooooo3@3AcJT000`0dLfY
1@000009oooooc<000002Oooool5000000X0dLfY6_oooolJ000001[ooooo2`3AcJT8ooooo`@00000
1?oooolA000000Cooooo10000008ooooo`@000001Oooool<000000Sooooo2P3AcJT4000000Sooooo
20000004ooooob0000000oooool8000000Sooooo1000000:0=7=Z@Sooooo1`000004ooooo`P00000
0oooool8000000Cooooo1`000004ooooo`L000001?ooool8000000Oooooo3@3AcJT000`0dLfY1@00
0009oooooc<000002Oooool5000000X0dLfY5P000008oooooa8000002OoooolE000000/0dLfY2?oo
ool4000000Cooooo4@000004ooooo`@000002?ooool4000000Gooooo30000008ooooo`X0dLfY1000
0008ooooo`P000001?oooolP000000?ooooo20000008ooooo`@000002P3AcJT8ooooo`L000001?oo
ool8000000?ooooo20000004ooooo`L000001?ooool7000000Cooooo20000007ooooo`d0dLfY000<
0=7=Z@D000002Ooooolc000000Wooooo1@00000:0=7=ZAH000002?oooolB000000Wooooo5@00000;
0=7=Z@Sooooo10000004oooooa4000001?ooool4000000Sooooo10000005ooooo``000002?ooool:
0=7=Z@@000002?ooool8000000Cooooo80000003ooooo`P000002?ooool4000000X0dLfY3`000004
ooooo`P000000oooool8000000Cooooo1`000004ooooo`L000001?ooool?000000d0dLfY000<0=7=
Z@Wooooo1@000004ooooo`D000003_ooool>000000Wooooo4`00000:0=7=ZAH000002?oooolB0000
00Wooooo5@00000;0=7=Z@`000002?ooool9000000Sooooo40000009ooooo`@000001?ooool80000
00X0dLfY10000008ooooo`P000001?oooolP000000?ooooo20000008ooooo`@000002P3AcJT?0000
00Cooooo20000003ooooo`P000001?ooool7000000Cooooo1`000004ooooo`l000003@3AcJT000`0
dLfY2Oooool5000000Cooooo1@00000>ooooo`h000002OoooolC000000X0dLfY5P000008oooooa80
00002OoooolE000000/0dLfY30000008ooooo`T000002?ooool@000000Wooooo10000004ooooo`P0
00002P3AcJT4000000cooooo10000008oooooaP000001oooool4000000cooooo1000000:0=7=Z@l0
00001?ooool8000000?ooooo20000004ooooo`L000001?ooool7000000Cooooo3`00000=0=7=Z@00
303AcJT9ooooo`D000001?ooool5000000kooooo3P000009oooooa<000002P3AcJT4000000gooooo
1@000004ooooo`@000001Oooool8000000Gooooo10000005ooooo`@000003Oooool4000000/0dLfY
30000008ooooo`T000002?ooool@000000Wooooo10000004ooooo`P000002P3AcJT4000000cooooo
10000008oooooaP000001oooool4000000cooooo1000000:0=7=Z@l000001?ooool8000000?ooooo
20000004ooooo`L000001?ooool7000000Cooooo3`00000=0=7=Z@00303AcJT9ooooo`D000001?oo
ool5000000kooooo3P000009oooooa<000002P3AcJT4000000gooooo1@000004ooooo`@000001Ooo
ool8000000Gooooo10000005ooooo`@000003Oooool4000000/0dLfY30000008ooooo`T000002?oo
ool@000000Wooooo10000004ooooo`P000002P3AcJT4000000cooooo10000008oooooaP000001ooo
ool4000000cooooo1000000:0=7=Z@@000001?ooool4000000?ooooo10000008ooooo`<000002?oo
ool4000000Oooooo10000007ooooo`@000001?ooool4000000?ooooo1000000=0=7=Z@00303AcJT9
ooooo`D000001?ooool5000000kooooo3P000009oooooa<000002P3AcJT4000000gooooo1@000004
ooooo`@000001Oooool8000000Gooooo10000005ooooo`@000003Oooool4000000/0dLfY1000000<
ooooo`@000002Oooool4000001Wooooo20000004ooooo`P000002P3AcJT4000000cooooo10000008
oooooaP000001oooool4000000cooooo1000000:0=7=Z@@000001?ooool4000000?ooooo10000008
ooooo`<000002?ooool4000000Oooooo10000007ooooo`@000001?ooool4000000?ooooo1000000=
0=7=Z@00303AcJTBooooo`X000001?ooool5000000Gooooo10000005ooooo`T000004oooool:0=7=
Z@@000003Oooool5000000Cooooo10000005ooooo`P000001Oooool4000000Gooooo1000000=oooo
o`@000002`3AcJT4000000cooooo10000009ooooo`@000006Oooool8000000Cooooo2000000:0=7=
Z@@000001?ooool<000000Cooooo10000004oooooa0000001?ooool4000000?ooooo30000004oooo
o`@000002P3AcJT4000000Cooooo10000003ooooo`@000002?ooool3000000Sooooo10000007oooo
o`@000001oooool4000000Cooooo10000003ooooo`@000003@3AcJT000`0dLfY4_ooool:000000Co
oooo1@000005ooooo`@000001Oooool9000001?ooooo2P3AcJT8000000Gooooo3@00000Jooooo`d0
00001Oooool8000000/0dLfY1000000<ooooo`@000002Oooool4000001Wooooo20000004ooooo`P0
00002P3AcJT4000000Cooooo30000004ooooo`@000001?ooool@000000Cooooo10000003ooooo``0
00001?ooool4000000X0dLfY10000004ooooo`@000001oooool8000000?ooooo20000004ooooo`L0
00001?ooool7000000Sooooo10000003ooooo`@000003@3AcJT000`0dLfY4_ooool:000000Cooooo
1@000005ooooo`@000001Oooool9000001?ooooo2P3AcJT8000000Gooooo3@00000Jooooo`d00000
1Oooool8000000/0dLfY1000000<ooooo`@000002Oooool4000001Wooooo20000004ooooo`P00000
2P3AcJT4000000Cooooo30000004ooooo`@000001?ooool@000000Cooooo10000003ooooo``00000
1?ooool4000000X0dLfY10000004ooooo`@000001oooool8000000?ooooo20000004ooooo`L00000
1?ooool7000000Sooooo10000003ooooo`@000003@3AcJT000`0dLfY4_ooool:000000Cooooo1@00
0005ooooo`@000001Oooool9000001?ooooo2P3AcJT8000000Gooooo3@00000Jooooo`d000001Ooo
ool8000000/0dLfY2000000<ooooo`T000007Oooool4000000Cooooo10000008ooooo`X0dLfY1000
0004ooooo``000001?ooool4000000Cooooo40000004ooooo`@000000oooool<000000Cooooo1000
000:0=7=Z@@000001?ooool4000000Oooooo20000003ooooo`P000001?ooool7000000Cooooo1`00
0008ooooo`@000000oooool4000000d0dLfY000<0=7=Z@T000003_ooool9000000[ooooo10000005
ooooo`h000003_ooool:0=7=Z@P000001Oooool=000001[ooooo3@000005ooooo`P000002`3AcJT8
000000cooooo2@00000Mooooo`@000001?ooool4000000Sooooo2P3AcJT<000000Sooooo1000000<
ooooo`P000003?ooool3000000Sooooo3000000:0=7=Z@@000001?ooool4000000Oooooo20000003
ooooo`P000001?ooool7000000Cooooo1`000008ooooo`@000000oooool4000000d0dLfY000<0=7=
Z@T000003_ooool9000000[ooooo10000005ooooo`h000003_ooool:0=7=Z@P000001Oooool=0000
01[ooooo3@000005ooooo`P000002`3AcJT8000000cooooo2@00000Mooooo`@000001?ooool40000
00Sooooo2P3AcJT<000000Sooooo1000000<ooooo`P000003?ooool3000000Sooooo3000000:0=7=
Z@`000000oooool<000000?ooooo20000004ooooo`L000001?ooool;000000Cooooo2`00000=0=7=
Z@00303AcJT9000000kooooo2@00000:ooooo`@000001Oooool>000000kooooo2P3AcJT4oooooal0
00002?oooolO000000Cooooo2`3AcJT8000000cooooo2@00000Mooooo`@000001?ooool4000000So
oooo2P3AcJT<000000Sooooo1000000<ooooo`P000003?ooool3000000Sooooo3000000:0=7=Z@`0
00000oooool<000000?ooooo20000004ooooo`L000001?ooool;000000Cooooo2`00000=0=7=Z@00
303AcJT9000000kooooo2@00000:ooooo`@000001Oooool>000000kooooo2P3AcJT4oooooal00000
2?oooolO000000Cooooo2`3AcJT4ooooo`@000001?oooolY000000Gooooo10000008ooooo`@00000
1?ooool:0=7=Z@`000002?ooool4000000cooooo2000000<ooooo`<000002?ooool<000000X0dLfY
30000003ooooo``000000oooool8000000Cooooo1`000004ooooo`/000001?ooool;000000d0dLfY
000<0=7=Z@T000003_ooool9000000[ooooo10000005ooooo`h000003_ooool:0=7=Z@Cooooo7`00
0008oooooal000001?ooool;0=7=Z@Cooooo10000004ooooobT000001Oooool4000000Sooooo1000
0004ooooo`X0dLfY3?ooool8000000Cooooo30000008ooooo``000000oooool8000000cooooo2P3A
cJT<000000?ooooo30000003ooooo`P000001?ooool7000000Cooooo2`000004ooooo`/000003@3A
cJT000`0dLfY2@000005ooooo`T000001Oooool9000000Gooooo2@000004ooooo`X000001?ooool:
000000X0dLfY1?oooolO000000Sooooo7`000004ooooo`/0dLfY1?ooool4000000Cooooo:@000005
ooooo`@000002?ooool4000000Cooooo2P3AcJT<ooooo`P000001?ooool<000000Sooooo30000003
ooooo`P000003?ooool:0=7=Z@cooooo2`000004ooooo`<000002?ooool4000000Oooooo10000004
ooooo`/000002oooool=0=7=Z@00303AcJT9000000Gooooo2@000005ooooo`T000001Oooool90000
00Cooooo2P000004ooooo`X000002P3AcJT4000000Wooooo3@000004ooooo`D000002?ooool50000
00Cooooo3@000009ooooo`@000002`3AcJT4ooooo`@000001?oooolY000000Gooooo10000008oooo
o`@000001?ooool:0=7=Z@cooooo20000004ooooo``000002?ooool<000000?ooooo2000000<oooo
o`X0dLfY3?ooool;000000Cooooo0`000008ooooo`@000001oooool4000000Cooooo2`00000;oooo
o`d0dLfY000<0=7=Z@T000001Oooool9000000Gooooo2@000005ooooo`T000001?ooool:000000Co
oooo2P00000:0=7=Z@@000002Oooool=000000Cooooo1@000008ooooo`D000001?ooool=000000Wo
oooo1000000;0=7=ZA0000001?ooool9000001Cooooo3@000004ooooo`@000002?ooool:0=7=Z@co
oooo20000004ooooo``000002?ooool<000000?ooooo2000000<ooooo`X0dLfY3?ooool;000000Co
oooo0`000008ooooo`@000001oooool4000000Cooooo2`00000;ooooo`d0dLfY000<0=7=Z@T00000
1Oooool9000000Gooooo2@000005ooooo`T000001?ooool:000000Cooooo2P00000:0=7=Z@@00000
2Oooool=000000Cooooo1@000008ooooo`D000001?ooool=000000Wooooo1000000;0=7=ZA000000
1?ooool9000001Cooooo3@000004ooooo`@000002?ooool:0=7=Z@Sooooo30000004ooooo`@00000
1?ooool@000000Cooooo10000003ooooo``000002?ooool:0=7=Z@Sooooo2`00000;ooooo`P00000
1?ooool7000000_ooooo30000007ooooo`d0dLfY000<0=7=Z@Wooooo3P000009ooooo`X000001?oo
ool5000000kooooo3P00000:0=7=Z@@000002Oooool=000000Cooooo1@000008ooooo`D000001?oo
ool=000000Wooooo1000000;0=7=ZA0000001?ooool9000001Cooooo3@000004ooooo`@000002?oo
ool:0=7=Z@Sooooo30000004ooooo`@000001?ooool@000000Cooooo10000003ooooo``000002?oo
ool:0=7=Z@Sooooo2`00000;ooooo`P000001?ooool7000000_ooooo30000007ooooo`d0dLfY000<
0=7=Z@Wooooo3P000009ooooo`X000001?ooool5000000kooooo3P00000:0=7=Z@Cooooo2@000004
ooooo`D000002?ooool5000000Sooooo1@000009ooooo`@000001?ooool9000000Cooooo2`3AcJT@
000000Cooooo2@00000Dooooo`d000001?ooool4000000Sooooo2P3AcJT8ooooo``000001?ooool4
000000Cooooo40000004ooooo`@000000oooool<000000Sooooo2P3AcJT8ooooo`/000002oooool8
000000Cooooo1`00000;ooooo``000001oooool=0=7=Z@00303AcJT9ooooo`h000002Oooool:0000
00Cooooo1@00000>ooooo`h000002P3AcJT4ooooo`T000001?ooool5000000Sooooo1@000008oooo
o`D000002Oooool4000000Cooooo2@000004ooooo`/0dLfY2000000Eooooo`@000003?ooool40000
00gooooo10000004ooooo`P000002P3AcJT4000000Cooooo20000004ooooo`P000006?ooool70000
00Cooooo20000004ooooo`@000002P3AcJT8ooooo`/000002oooool8000000Cooooo1`00000;oooo
o``000001oooool=0=7=Z@00303AcJT9ooooo`h000002Oooool:000000Cooooo1@00000>ooooo`h0
00002P3AcJT4ooooo`T000001?ooool5000000Sooooo1@000008ooooo`D000002Oooool4000000Co
oooo2@000004ooooo`/0dLfY2000000Eooooo`@000003?ooool4000000gooooo10000004ooooo`P0
00002P3AcJT4000000Cooooo20000004ooooo`P000006?ooool7000000Cooooo20000004ooooo`@0
00002P3AcJT4000000Cooooo1`000004oooooa<000001?oooolB000000Cooooo20000003ooooo`@0
00003@3AcJT000`0dLfY2Oooool>000000Wooooo2P000004ooooo`D000003_ooool>000000X0dLfY
1?ooool9000000Cooooo1@000008ooooo`D000002?ooool5000000Wooooo10000004ooooo`T00000
1?ooool;0=7=Z@P000005Oooool4000000cooooo1000000=ooooo`@000001?ooool8000000X0dLfY
10000004ooooo`P000001?ooool8000001Sooooo1`000004ooooo`P000001?ooool4000000X0dLfY
10000004ooooo`L000001?oooolC000000Cooooo4P000004ooooo`P000000oooool4000000d0dLfY
000<0=7=Z@Gooooo3@00000:ooooo`@000001Oooool5000000Cooooo1@000009ooooo`h000001Ooo
ool:0=7=Z@d000001?ooool9000000Cooooo1@000008ooooo`D000001?ooool9000000Cooooo3@00
000;0=7=Z@P000005Oooool4000000cooooo1000000=ooooo`@000001?ooool8000000X0dLfY1000
0004ooooo`P000001?ooool8000001Sooooo1`000004ooooo`P000001?ooool4000000X0dLfY1000
0004ooooo`L000001?oooolC000000Cooooo4P000004ooooo`P000000oooool4000000d0dLfY000<
0=7=Z@Gooooo3@00000:ooooo`@000001Oooool5000000Cooooo1@000009ooooo`h000001Oooool:
0=7=Z@d000001?ooool9000000Cooooo1@000008ooooo`D000001?ooool9000000Cooooo3@00000;
0=7=Z@Sooooo10000004ooooo`@000001?ooool5000000Sooooo10000008ooooo`@000001Oooool4
000000Sooooo2000000:0=7=Z@Cooooo1000000<ooooo`@000008?ooool3000000cooooo10000004
ooooo`X0dLfY10000004ooooo`L000001?oooolC000000Cooooo4P000004ooooo`P000000oooool4
000000d0dLfY000<0=7=Z@Gooooo3@00000:ooooo`@000001Oooool5000000Cooooo1@000009oooo
o`h000001Oooool:0=7=Z@d000001?ooool9000000Cooooo1@000008ooooo`D000001?ooool90000
00Cooooo3@00000;0=7=Z@Sooooo10000004ooooo`@000001?ooool5000000Sooooo10000008oooo
o`@000001Oooool4000000Sooooo2000000:0=7=Z@Cooooo1000000<ooooo`@000008?ooool30000
00cooooo10000004ooooo`X0dLfY1?ooool4000000_ooooo10000007ooooo`@000001?ooool40000
00?ooooo10000008ooooo`<000003?ooool3000000Cooooo3@3AcJT000`0dLfY1Oooool=000000[o
oooo10000005ooooo`D000001?ooool5000000Wooooo3P000005ooooo`X0dLfY3@000004ooooo`T0
00001?ooool5000000Sooooo1@000004ooooo`T000001?ooool=000000/0dLfY2?ooool4000000Co
oooo10000004ooooo`D000002?ooool4000000Sooooo10000005ooooo`@000002?ooool8000000X0
dLfY1?ooool4000000cooooo1000000Pooooo`<000003?ooool4000000Cooooo2P3AcJT4ooooo`@0
00002oooool4000000Oooooo10000004ooooo`@000000oooool4000000Sooooo0`00000<ooooo`<0
00001?ooool=0=7=Z@00303AcJT5ooooo`T000001?ooool5000000kooooo3P000009ooooo`T00000
1Oooool5000000X0dLfY3@000004ooooo`T000001?ooool5000000Sooooo1@000004ooooo`T00000
1?ooool=000000/0dLfY2?ooool4000000Cooooo10000004ooooo`D000002?ooool4000000Sooooo
10000005ooooo`@000002?ooool8000000X0dLfY1?ooool4000000cooooo1000000Pooooo`<00000
3?ooool4000000Cooooo2P3AcJT4ooooo`@000002oooool4000000Oooooo10000004ooooo`@00000
0oooool4000000Sooooo0`00000<ooooo`<000001?ooool=0=7=Z@00303AcJT5ooooo`T000001?oo
ool5000000kooooo3P000009ooooo`T000001Oooool5000000X0dLfY20000005ooooo`@000001Ooo
ool=000000Sooooo3P000004ooooo`@000001Oooool8000000/0dLfY1?ooool4000000Cooooo1000
0004ooooo`@000001Oooool4000000cooooo10000004ooooo`D000001?ooool4000000cooooo2P3A
cJT4000000Cooooo10000008ooooobL000002?ooool4000000Cooooo1000000:0=7=Z@@000001?oo
ool4000000Oooooo3`00000;ooooo`l000002?ooool4000000?ooooo1000000=0=7=Z@00303AcJT5
ooooo`T000001?ooool5000000kooooo3P000009ooooo`T000001Oooool5000000X0dLfY20000005
ooooo`@000001Oooool=000000Sooooo3P000004ooooo`@000001Oooool8000000/0dLfY1?ooool4
000000Cooooo10000004ooooo`@000001Oooool4000000cooooo10000004ooooo`D000001?ooool4
000000cooooo2P3AcJT4000000Cooooo10000008ooooobL000002?ooool4000000Cooooo1000000:
0=7=Z@@000001?ooool4000000Oooooo3`00000;ooooo`l000002?ooool4000000?ooooo1000000=
0=7=Z@00303AcJT5ooooo`T000001?ooool5000000kooooo3P000009ooooo`T000001Oooool50000
00X0dLfY20000005ooooo`@000001Oooool=000000Sooooo3P000004ooooo`@000001Oooool80000
00/0dLfY1?ooool4000000Cooooo10000004ooooo`@000001Oooool4000000cooooo10000004oooo
o`D000001?ooool4000000cooooo2P3AcJT4000000Cooooo10000008ooooobL000002?ooool40000
00Cooooo1000000:0=7=Z@@000001?ooool4000000Oooooo3`00000;ooooo`l000002?ooool40000
00?ooooo1000000=0=7=Z@00303AcJT5ooooo`T000001?ooool5000000kooooo3P000009ooooo`T0
00001Oooool5000000X0dLfY20000005ooooo`@000001Oooool=000000Sooooo3P000004ooooo`@0
00001Oooool8000000/0dLfY1?ooool4000000Cooooo10000004ooooo`@000001Oooool4000000co
oooo10000004ooooo`D000001?ooool4000000cooooo2P3AcJT4000000Cooooo10000008ooooobL0
00002?ooool4000000Cooooo1000000:0=7=Z@@000001?ooool4000000Oooooo3`00000;ooooo`l0
00002?ooool4000000?ooooo1000000=0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<
0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<
0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00o`3AcJW<0=7=Z@00303AcJT6
000000Oooooo1`00000Wooooo`H000001oooool7000000X0dLfY30000006ooooo`H000001_oooolB
000000Kooooo1P000006ooooo``000002`3AcJT5000000_ooooo1P00000Gooooo`D000007?ooool:
0=7=Z@H000001Oooool:000000_ooooo1@000005ooooo`H000002_ooool;000000Gooooo1@00000:
0=7=Z@Gooooo2P00000:ooooo`D000001Oooool5000002Oooooo3@3AcJT000`0dLfY1P000007oooo
o`L000009oooool6000000Oooooo1`00000:0=7=Z@`000001_ooool6000000Kooooo4P000006oooo
o`H000001_ooool<000000/0dLfY1@00000;ooooo`H000005oooool5000001cooooo2P3AcJT60000
00Gooooo2P00000;ooooo`D000001Oooool6000000[ooooo2`000005ooooo`D000002P3AcJT5oooo
o`X000002_ooool5000000Gooooo1@00000Wooooo`d0dLfY000<0=7=Z@H000001oooool7000002Oo
oooo1P000007ooooo`L000002P3AcJT<000000Kooooo1P000006oooooa8000001_ooool6000000Ko
oooo3000000;0=7=Z@D000002oooool6000001Oooooo1@00000Looooo`X0dLfY1P000005ooooo`X0
00002oooool5000000Gooooo1P00000:ooooo`/000001Oooool5000000X0dLfY1Oooool:000000[o
oooo1@000005ooooo`D000009oooool=0=7=Z@00303AcJT6000000Oooooo1`00000Wooooo`H00000
1oooool7000000X0dLfY30000006ooooo`H000001_oooolB000000Kooooo1P000006ooooo``00000
2`3AcJT5000000_ooooo1P00000Gooooo`D000007?ooool:0=7=Z@H000001Oooool:000000_ooooo
1@000005ooooo`H000002_ooool;000000Gooooo1@00000:0=7=Z@Gooooo2P00000:ooooo`D00000
1Oooool5000002Oooooo3@3AcJT000`0dLfY1P000007ooooo`L000009oooool6000000Oooooo1`00
000:0=7=Z@`000001_ooool6000000Kooooo4P000006ooooo`H000001_ooool<000000/0dLfY1@00
000;ooooo`H000005oooool5000001cooooo2P3AcJT6000000Gooooo2P00000;ooooo`D000001Ooo
ool6000000[ooooo2`000005ooooo`D000002P3AcJT5ooooo`X000002_ooool5000000Gooooo1@00
000Wooooo`d0dLfY000<0=7=Z@H000001oooool7000002Oooooo1P000007ooooo`L000002P3AcJT<
000000Kooooo1P000006oooooa8000001_ooool6000000Kooooo3000000;0=7=Z@D000002oooool6
000001Oooooo1@00000Looooo`X0dLfY1_ooool?0000013ooooo1@00000@oooooa0000001Oooool:
0=7=Z@Gooooo2P00000?ooooo`D000002_oooolR000000d0dLfY000<0=7=Z@H000001oooool70000
02Oooooo1P000007ooooo`L000002P3AcJTB000000Kooooo30000006ooooo``000001_oooolB0000
00/0dLfY7?ooool;0000017ooooo5P00000:0=7=Z@Kooooo3`00000@ooooo`D000004?ooool@0000
00Gooooo2P3AcJT5ooooo`X000003oooool5000000[ooooo8P00000=0=7=Z@00303AcJT6ooooo`L0
00003OoooolJ000000gooooo1`000007ooooo`X0dLfY4P000006ooooo``000001_ooool<000000Ko
oooo4P00000;0=7=ZAcooooo2`00000AoooooaH000002P3AcJT6ooooo`l000004?ooool50000013o
oooo40000005ooooo`X0dLfY1Oooool:000000oooooo1@00000:ooooob8000003@3AcJT000`0dLfY
1_ooool7000000gooooo6P00000=ooooo`L000001oooool:0=7=ZA8000001_ooool<000000Kooooo
30000006oooooa8000002`3AcJTLooooo`/000004OoooolF000000X0dLfY1_ooool?0000013ooooo
1@00000@oooooa0000001Oooool:0=7=Z@Gooooo2P00000?ooooo`D000002_oooolR000000d0dLfY
000<0=7=Z@Kooooo1`00000=oooooaX000003Oooool7000000Oooooo2P3AcJTB000000Kooooo3000
0006ooooo``000001_oooolB000000/0dLfY7?ooool;0000017ooooo5P00000:0=7=Z@Kooooo3`00
000@ooooo`D000004?ooool@000000Gooooo2P3AcJT5ooooo`X000003oooool5000000[ooooo8P00
000=0=7=Z@00303AcJT6ooooo`L000003OoooolJ000000gooooo1`000007ooooo`X0dLfY4P000006
ooooo``000001_ooool<000000Kooooo4P00000;0=7=ZAcooooo2`00000AoooooaH000002P3AcJT@
000000_ooooo2P000005ooooo`/000002_ooool@000000X0dLfY5?ooool:000000Gooooo1@000005
ooooo`@000006Oooool5000000d0dLfY000<0=7=Z@Kooooo1`00000=oooooaX000003Oooool70000
00Oooooo2P3AcJTB000000Kooooo30000006ooooo``000001_oooolB000000/0dLfY1Oooool;0000
00cooooo2`00000Aooooo`D000003?ooool5000000X0dLfY4000000;ooooo`X000001Oooool;0000
00[ooooo4000000:0=7=ZACooooo2P000005ooooo`D000001Oooool4000001Wooooo1@00000=0=7=
Z@00303AcJT6ooooo`L000003OoooolJ000000gooooo1`000007ooooo`X0dLfY1_ooool<000000Ko
oooo1P00000Booooo`H000001_ooool<000000Kooooo2`3AcJT5ooooo`/000003?ooool;0000017o
oooo1@00000<ooooo`D000002P3AcJT@000000_ooooo2P000005ooooo`/000002_ooool@000000X0
dLfY5?ooool:000000Gooooo1@000005ooooo`@000006Oooool5000000d0dLfY000<0=7=Z@H00000
1oooool7000000Kooooo1`00000=ooooo`H000001oooool6000000Oooooo1`00000:0=7=Z@Kooooo
30000006ooooo`H000004_ooool6000000Kooooo30000006ooooo`/0dLfY1Oooool;000000cooooo
2`00000Aooooo`D000003?ooool5000000X0dLfY4000000;ooooo`X000001Oooool;000000[ooooo
4000000:0=7=ZACooooo2P000005ooooo`D000001Oooool4000001Wooooo1@00000=0=7=Z@00303A
cJT6000000Oooooo1`000006ooooo`L000003Oooool6000000Oooooo1P000007ooooo`L000002P3A
cJT6ooooo``000001_ooool6000001;ooooo1P000006ooooo``000001_ooool;0=7=Z@Gooooo2`00
000<ooooo`/000004Oooool5000000cooooo1@00000:0=7=ZA0000002oooool:000000Gooooo2`00
000:oooooa0000002P3AcJTDooooo`X000001Oooool5000000Gooooo1000000Iooooo`D000003@3A
cJT000`0dLfY1P000007ooooo`L000001_ooool7000000gooooo1P000007ooooo`H000001oooool7
000000X0dLfY1_ooool<000000Kooooo1P00000Booooo`H000001_ooool<000000Kooooo2`3AcJT5
ooooo`/000003?ooool;0000017ooooo1@00000<ooooo`D000002P3AcJT@000000_ooooo2P000005
ooooo`/000002_ooool@000000X0dLfY1@00000?ooooo`X000002_ooool>000000oooooo2P00000=
0=7=Z@00303AcJT6000000Oooooo1`000006ooooo`L000003Oooool6000000Oooooo1P000007oooo
o`L000002P3AcJT6ooooo``000001_ooool6000001;ooooo1P000006ooooo``000001_ooool;0=7=
Z@Gooooo2`00000<ooooo`/000004Oooool5000000cooooo1@00000:0=7=Z@/000001Oooool50000
00Kooooo2P000005ooooo`/000001Oooool5000000Kooooo2P00000:0=7=Z@D000003oooool:0000
00[ooooo3P00000?ooooo`X000003@3AcJT000`0dLfY1P000007ooooo`L000001_ooool7000000go
oooo1P000007ooooo`H000001oooool7000000X0dLfY1_ooool<000000Kooooo1P00000Booooo`H0
00001_ooool<000000Kooooo2`3AcJT5ooooo`/000007Oooool5000000Kooooo5P00000:0=7=Z@/0
00001Oooool5000000Kooooo2P000005ooooo`/000001Oooool5000000Kooooo2P00000:0=7=Z@D0
00003oooool:000000[ooooo3P00000?ooooo`X000003@3AcJT000`0dLfY1P000007ooooo`L00000
1_ooool7000000gooooo1P000007ooooo`H000001oooool7000000X0dLfY1P00000<ooooobX00000
3?ooool6000000/0dLfY1Oooool;000001gooooo1@000006oooooaH000002P3AcJT;000000Gooooo
1@000006ooooo`X000001Oooool;000000Gooooo1@000006ooooo`X000002P3AcJT5000000oooooo
2P00000:ooooo`h000003oooool:000000d0dLfY000<0=7=ZACooooo9`00000Dooooo`X0dLfY1P00
000<ooooobX000003?ooool6000000/0dLfY1Oooool;000001gooooo1@000006oooooaH000002P3A
cJT;000000Gooooo1@000006ooooo`X000001Oooool;000000Gooooo1@000006ooooo`X000002P3A
cJT:ooooo`D000005?oooolC000000Gooooo1@000005ooooo`D000001Oooool=0=7=Z@00303AcJTD
ooooobL000005?ooool:0=7=Z@H000003?oooolZ000000cooooo1P00000;0=7=Z@Gooooo2`00000M
ooooo`D000001_oooolF000000X0dLfY2`000005ooooo`D000001_ooool:000000Gooooo2`000005
ooooo`D000001_ooool:000000X0dLfY2_ooool5000001Cooooo4`000005ooooo`D000001Oooool5
000000Gooooo3@3AcJT000`0dLfY5?oooolW000001Cooooo2P3AcJT6000000cooooo:P00000<oooo
o`H000002`3AcJT5ooooo`/000007Oooool5000000Kooooo5P00000:0=7=ZAGooooo1P00000:oooo
o`D000002oooool5000001Gooooo2P3AcJT:ooooo`D000005?oooolC000000Gooooo1@000005oooo
o`D000001Oooool=0=7=Z@00303AcJTDooooobL000005?ooool:0=7=Z@H000003?oooolZ000000co
oooo1P00000;0=7=ZAKooooo1P00000Fooooo`H000005_ooool:0=7=ZAGooooo1P00000:ooooo`D0
00002oooool5000001Gooooo2P3AcJT:ooooo`D000005?oooolC000000Gooooo1@000005ooooo`D0
00001Oooool=0=7=Z@00303AcJTDooooobL000005?ooool:0=7=Z@H000003?oooolZ000000cooooo
1P00000;0=7=ZAKooooo1P00000Fooooo`H000005_ooool:0=7=ZAGooooo1P00000:ooooo`D00000
2oooool5000001Gooooo2P3AcJT:ooooo`D000005?oooolC000000Gooooo1@000005ooooo`D00000
1Oooool=0=7=Z@00303AcJTDooooobL000005?ooool:0=7=Z@Kooooo6000000BoooooaP000001_oo
ool;0=7=ZAKooooo1P00000Fooooo`H000005_ooool:0=7=ZAGooooo1P00000:ooooo`D000002ooo
ool5000001Gooooo2P3AcJTSooooo`h000001Oooool5000000Gooooo3`00000=0=7=Z@00303AcJTD
ooooobL000005?ooool:0=7=Z@Kooooo6000000BoooooaP000001_ooool;0=7=ZAKooooo1P00000F
ooooo`H000005_ooool:0=7=ZAGooooo1P00000:ooooo`D000002oooool5000001Gooooo2P3AcJTS
ooooo`h000001Oooool5000000Gooooo3`00000=0=7=Z@00303AcJT6oooooa/000003OoooolJ0000
00Oooooo2P3AcJT6oooooaP000004_oooolH000000Kooooo2`3AcJTFooooo`H000005_ooool60000
01Kooooo2P3AcJT;ooooo`X000001_ooool:000000Gooooo2`000005ooooo`/000002_ooool:0=7=
ZB?ooooo3P000005ooooo`D000001Oooool?000000d0dLfY000<0=7=Z@Kooooo6`00000=oooooaX0
00001oooool:0=7=Z@Kooooo6000000BoooooaP000001_ooool;0=7=ZAKooooo1P00000Fooooo`H0
00005_ooool:0=7=Z@_ooooo2P000006ooooo`X000001Oooool;000000Gooooo2`00000:ooooo`X0
dLfY8oooool>000000Gooooo1@000005ooooo`l000003@3AcJT000`0dLfY1_oooolK000000gooooo
6P000007ooooo`X0dLfY1_oooolH000001;ooooo60000006ooooo`/0dLfY1@00000Loooooa400000
1_ooool50000017ooooo2P3AcJT;ooooo`X000001_ooool:000000Gooooo2`000005ooooo`/00000
2_ooool:0=7=ZB?ooooo3P000005ooooo`D000001Oooool?000000d0dLfY000<0=7=Z@Kooooo6`00
000=oooooaX000001oooool:0=7=Z@Kooooo6000000BoooooaP000001_ooool;0=7=Z@D000007?oo
oolA000000Kooooo1@00000Aooooo`X0dLfY2oooool:000000Kooooo2P000005ooooo`/000001Ooo
ool;000000[ooooo2P3AcJT:000000Gooooo3`00000:ooooo`D000004oooool?000000d0dLfY000<
0=7=Z@Kooooo6`00000=oooooaX000001oooool:0=7=Z@`000001_ooool6000000Kooooo1P000006
ooooo`H000001_ooool6000000Kooooo3000000;0=7=Z@D000007?oooolA000000Kooooo1@00000A
ooooo`X0dLfY2oooool:000000Kooooo2P000005ooooo`/000001Oooool;000000[ooooo2P3AcJT:
000000Gooooo3`00000:ooooo`D000004oooool?000000d0dLfY000<0=7=Z@Kooooo6`00000=oooo
oaX000001oooool:0=7=Z@`000001_ooool6000000Kooooo1P000006ooooo`H000001_ooool60000
00Kooooo3000000;0=7=Z@D000007?oooolA000000Kooooo1@00000Aooooo`X0dLfY1P000005oooo
o`X000001_ooool:000000Gooooo2`000005ooooo`/000001Oooool5000000X0dLfY2P000005oooo
o`l000002_ooool5000001?ooooo3`00000=0=7=Z@00303AcJT6ooooo`L000001oooool6000000Oo
oooo3@000006ooooo`L000001_ooool7000000Oooooo2P3AcJT<000000Kooooo1P000006ooooo`H0
00001_ooool6000000Kooooo1P000006ooooo``000002`3AcJT5000001cooooo4@000006ooooo`D0
00004Oooool:0=7=Z@H000001Oooool:000000Kooooo2P000005ooooo`/000001Oooool;000000Go
oooo1@00000:0=7=Z@X000001Oooool?000000[ooooo1@00000Cooooo`l000003@3AcJT000`0dLfY
1_ooool7000000Oooooo1P000007ooooo`d000001_ooool7000000Kooooo1`000007ooooo`X0dLfY
30000006ooooo`H000001_ooool6000000Kooooo1P000006ooooo`H000001_ooool<000000/0dLfY
2oooool;000000_ooooo1P000006ooooo`D000004Oooool;000000X0dLfY1P000005ooooo`X00000
1_ooool:000000Gooooo2`000005ooooo`/000001Oooool5000000X0dLfY2P000005ooooo`l00000
2_ooool5000001?ooooo3`00000=0=7=Z@00303AcJT6ooooo`L000001oooool6000000Oooooo3@00
0006ooooo`L000001_ooool7000000Oooooo2P3AcJT<000000Kooooo1P000006ooooo`H000001_oo
ool6000000Kooooo1P000006ooooo``000002`3AcJT;ooooo`/000002oooool6000000Kooooo1@00
000Aooooo`/000002P3AcJT6000000Gooooo2P000006ooooo`X000001Oooool;000000Gooooo2`00
0005ooooo`D000002P3AcJTD000000Gooooo1@000005oooooa<000003oooool5000000Gooooo3@3A
cJT000`0dLfY1_ooool7000000Oooooo1P000007ooooo`d000001_ooool7000000Kooooo1`000007
ooooo`X0dLfY30000006ooooo`H000001_ooool6000000Kooooo1P000006ooooo`H000001_ooool<
000000/0dLfY2oooool;000000_ooooo1P000006ooooo`D000004Oooool;000000X0dLfY1P000005
ooooo`X000001_ooool:000000Gooooo2`000005ooooo`/000001Oooool5000000X0dLfY50000005
ooooo`D000001OoooolC000000oooooo1@000005ooooo`d0dLfY000<0=7=Z@Kooooo1`000007oooo
o`H000001oooool=000000Kooooo1`000006ooooo`L000001oooool:0=7=Z@H000003?ooool60000
00cooooo1P00000<ooooo`H000003?ooool6000000/0dLfY2oooool;000000_ooooo1P000006oooo
o`D000004Oooool;000000X0dLfY1_ooool5000000[ooooo1P00000:ooooo`D000002oooool50000
00_ooooo1@000005ooooo`X0dLfY50000005ooooo`D000001OoooolC000000oooooo1@000005oooo
o`d0dLfY000<0=7=Z@Kooooo1`000007ooooo`H000001oooool=000000Kooooo1`000006ooooo`L0
00001oooool:0=7=Z@H000003?ooool6000000cooooo1P00000<ooooo`H000003?ooool6000000/0
dLfY2oooool;000000_ooooo1P000006ooooo`D000004Oooool;000000X0dLfY1_ooool5000000[o
oooo1P00000:ooooo`D000002oooool5000000_ooooo1@000005ooooo`X0dLfY50000005ooooo`D0
00001OoooolC000000oooooo1@000005ooooo`d0dLfY000<0=7=Z@Kooooo1`000007ooooo`H00000
1oooool=000000Kooooo1`000006ooooo`L000001oooool:0=7=Z@H000003?ooool6000000cooooo
1P00000<ooooo`H000003?ooool6000000/0dLfY2oooool;000000_ooooo1P000006ooooo`D00000
4Oooool;000000X0dLfY1_ooool5000000[ooooo1P00000:ooooo`D000002oooool5000000_ooooo
1@000005ooooo`X0dLfY1Oooool5000000oooooo50000004ooooo`D000001OoooolD000000d0dLfY
000<0=7=Z@Kooooo1`000007ooooo`H000001oooool=000000Kooooo1`000006ooooo`L000001ooo
ool:0=7=Z@H000003?ooool6000000cooooo1P00000<ooooo`H000003?ooool6000000/0dLfY2ooo
ool;000000_ooooo1P000006ooooo`D000004Oooool;000000X0dLfY1_ooool5000000[ooooo1P00
000:ooooo`D000002oooool5000000_ooooo1@000005ooooo`X0dLfY1Oooool5000000oooooo5000
0004ooooo`D000001OoooolD000000d0dLfY000<0=7=Z@Kooooo1`000007ooooo`H000001oooool=
000000Kooooo1`000006ooooo`L000001oooool:0=7=Z@H000003?ooool6000000cooooo1P00000<
ooooo`H000003?ooool6000000/0dLfY2oooool;000000_ooooo1P000006ooooo`D000004Oooool;
000000X0dLfY1_ooool5000000[ooooo1P00000:ooooo`D000002oooool5000000_ooooo1@000005
ooooo`X0dLfY1Oooool5000000oooooo50000004ooooo`D000001OoooolD000000d0dLfY000<0=7=
Z@Kooooo1`000007ooooo`H000001oooool=000000Kooooo1`000006ooooo`L000001oooool:0=7=
Z@`000001_ooool6000000Kooooo1P000006ooooo`H000001_ooool6000000Kooooo3000000;0=7=
Z@_ooooo2`00000;ooooo`H000001_ooool50000017ooooo2`00000:0=7=Z@H000001Oooool:0000
00Kooooo2P000005ooooo`/000001Oooool;000000Gooooo1@00000:0=7=Z@Gooooo1@00000?oooo
oa@000001?ooool5000000Gooooo5000000=0=7=Z@00303AcJT6ooooo`L000001oooool6000000Oo
oooo3@000006ooooo`L000001_ooool7000000Oooooo2P3AcJT<000000Kooooo1P000006ooooo`H0
00001_ooool6000000Kooooo1P000006ooooo``000002`3AcJT;ooooo`/000002oooool6000000Ko
oooo1@00000Aooooo`/000002P3AcJT6000000Gooooo2P000006ooooo`X000001Oooool;000000Go
oooo2`000005ooooo`D000002P3AcJT5ooooo`D000003ooooolD000000Cooooo1@000005oooooa@0
00003@3AcJT000`0dLfY1_ooool7000000Oooooo1P000007ooooo`d000001_ooool7000000Kooooo
1`000007ooooo`X0dLfY30000006ooooo`H000001_ooool6000000Kooooo1P000006ooooo`H00000
1_ooool<000000/0dLfY2oooool;000000_ooooo1P000006ooooo`D000004Oooool;000000X0dLfY
1P000005ooooo`X000001_ooool:000000Gooooo2`000005ooooo`/000001Oooool5000000X0dLfY
3`00000Dooooo`D000002Oooool?000000Gooooo2P00000=0=7=Z@00303AcJT6ooooo`L000001ooo
ool6000000Oooooo3@000006ooooo`L000001_ooool7000000Oooooo2P3AcJT<000000Kooooo1P00
0006ooooo`H000001_ooool6000000Kooooo1P000006ooooo``000002`3AcJT5000001cooooo4@00
0006ooooo`D000004Oooool:0=7=Z@H000001Oooool:000000Kooooo2P000005ooooo`/000001Ooo
ool;000000Gooooo1@00000:0=7=Z@l000005?ooool5000000Wooooo3`000005ooooo`X000003@3A
cJT000`0dLfY1_oooolK000000gooooo6P000007ooooo`X0dLfY30000006ooooo`H000001_ooool6
000000Kooooo1P000006ooooo`H000001_ooool<000000/0dLfY1@00000Loooooa4000001_ooool5
0000017ooooo2P3AcJT6000000Gooooo2P000006ooooo`X000001Oooool;000000Gooooo2`000005
ooooo`D000002P3AcJT?000001Cooooo1@000009ooooo`l000001Oooool:000000d0dLfY000<0=7=
Z@Kooooo6`00000=oooooaX000001oooool:0=7=Z@`000001_ooool6000000Kooooo1P000006oooo
o`H000001_ooool6000000Kooooo3000000;0=7=Z@D000007?oooolA000000Kooooo1@00000Aoooo
o`X0dLfY2oooool:000000Kooooo2P000005ooooo`/000001Oooool;000000[ooooo2P3AcJT?0000
01Cooooo1@000009ooooo`l000001Oooool:000000d0dLfY000<0=7=Z@Kooooo6`00000=oooooaX0
00001oooool:0=7=Z@Kooooo6000000BoooooaP000001_ooool;0=7=Z@D000007?oooolA000000Ko
oooo1@00000Aooooo`X0dLfY2oooool:000000Kooooo2P000005ooooo`/000001Oooool;000000[o
oooo2P3AcJT?000001Cooooo1@000009ooooo`l000001Oooool:000000d0dLfY000<0=7=Z@Kooooo
6`00000=oooooaX000001oooool:0=7=Z@Kooooo6000000BoooooaP000001_ooool;0=7=Z@D00000
7?oooolA000000Kooooo1@00000Aooooo`X0dLfY2oooool:000000Kooooo2P000005ooooo`/00000
1Oooool;000000[ooooo2P3AcJT?000000Gooooo1@000005ooooo`l000008_ooool=0=7=Z@00303A
cJT6oooooa/000003OoooolJ000000Oooooo2P3AcJT6oooooaP000004_oooolH000000Kooooo2`3A
cJTFooooo`H000005_ooool6000001Kooooo2P3AcJT;ooooo`X000001_ooool:000000Gooooo2`00
0005ooooo`/000002_ooool:0=7=Z@l000001Oooool5000000Gooooo3`00000Rooooo`d0dLfY000<
0=7=Z@Kooooo6`00000=oooooaX000001oooool:0=7=Z@Kooooo6000000BoooooaP000001_ooool;
0=7=ZAKooooo1P00000Fooooo`H000005_ooool:0=7=Z@_ooooo2P000006ooooo`X000001Oooool;
000000Gooooo2`00000:ooooo`X0dLfY3`000005ooooo`D000001Oooool?000002;ooooo3@3AcJT0
00`0dLfY5?oooolW000001Cooooo2P3AcJT6oooooaP000004_oooolH000000Kooooo2`3AcJTFoooo
o`H000005_ooool6000001Kooooo2P3AcJTEooooo`H000002_ooool5000000_ooooo1@00000Eoooo
o`X0dLfY3`000005ooooo`D000001Oooool?000002;ooooo3@3AcJT000`0dLfY5?oooolW000001Co
oooo2P3AcJT6oooooaP000004_oooolH000000Kooooo2`3AcJTFooooo`H000005_ooool6000001Ko
oooo2P3AcJTEooooo`H000002_ooool5000000_ooooo1@00000Eooooo`X0dLfY3`000005ooooo`D0
00001Oooool?000002;ooooo3@3AcJT000`0dLfY5?oooolW000001Cooooo2P3AcJT6000000cooooo
:P00000<ooooo`H000002`3AcJTFooooo`H000005_ooool6000001Kooooo2P3AcJTEooooo`H00000
2_ooool5000000_ooooo1@00000Eooooo`X0dLfY1Oooool5000000Gooooo1@000005oooooa@00000
4oooool5000000[ooooo3@3AcJT000`0dLfY5?oooolW000001Cooooo2P3AcJT6000000cooooo:P00
000<ooooo`H000002`3AcJTFooooo`H000005_ooool6000001Kooooo2P3AcJTEooooo`H000002_oo
ool5000000_ooooo1@00000Eooooo`X0dLfY1Oooool5000000Gooooo1@000005oooooa@000004ooo
ool5000000[ooooo3@3AcJT000`0dLfY5?oooolW000001Cooooo2P3AcJT6000000cooooo:P00000<
ooooo`H000002`3AcJT5ooooo`/000007Oooool5000000Kooooo5P00000:0=7=ZAGooooo1P00000:
ooooo`D000002oooool5000001Gooooo2P3AcJT5ooooo`D000001Oooool5000000Gooooo5000000C
ooooo`D000002_ooool=0=7=Z@00303AcJTDooooobL000005?ooool:0=7=Z@H000003?oooolZ0000
00cooooo1P00000;0=7=Z@Gooooo2`00000Mooooo`D000001_oooolF000000X0dLfY2`000005oooo
o`D000001_ooool:000000Gooooo2`000005ooooo`D000001_ooool:000000X0dLfY1Oooool50000
00Gooooo1@000005oooooa@000004oooool5000000[ooooo3@3AcJT000`0dLfY5?oooolW000001Co
oooo2P3AcJT6000000cooooo:P00000<ooooo`H000002`3AcJT5ooooo`/000007Oooool5000000Ko
oooo5P00000:0=7=Z@/000001Oooool5000000Kooooo2P000005ooooo`/000001Oooool5000000Ko
oooo2P00000:0=7=Z@Gooooo1@000005ooooo`D000001OoooolD000001?ooooo1@00000:ooooo`d0
dLfY000<0=7=Z@H000001oooool7000000Kooooo1`00000=ooooo`H000001oooool6000000Oooooo
1`00000:0=7=Z@H000003?oooolZ000000cooooo1P00000;0=7=Z@Gooooo2`00000Mooooo`D00000
1_oooolF000000X0dLfY2`000005ooooo`D000001_ooool:000000Gooooo2`000005ooooo`D00000
1_ooool:000000X0dLfY2P00000?ooooo`l000002Oooool:000000oooooo1@00000=0=7=Z@00303A
cJT6000000Oooooo1`000006ooooo`L000003Oooool6000000Oooooo1P000007ooooo`L000002P3A
cJT6ooooo``000001_ooool6000001;ooooo1P000006ooooo``000001_ooool;0=7=Z@Gooooo2`00
000Mooooo`D000001_oooolF000000X0dLfY2`000005ooooo`D000001_ooool:000000Gooooo2`00
0005ooooo`D000001_ooool:000000X0dLfY2P00000?ooooo`l000002Oooool:000000oooooo1@00
000=0=7=Z@00303AcJT6000000Oooooo1`000006ooooo`L000003Oooool6000000Oooooo1P000007
ooooo`L000002P3AcJT6ooooo``000001_ooool6000001;ooooo1P000006ooooo``000001_ooool;
0=7=Z@Gooooo2`00000<ooooo`/000004Oooool5000000cooooo1@00000:0=7=Z@/000001Oooool5
000000Kooooo2P000005ooooo`/000001Oooool5000000Kooooo2P00000:0=7=Z@X000003oooool?
000000Wooooo2P00000?ooooo`D000003@3AcJT000`0dLfY1P000007ooooo`L000001_ooool70000
00gooooo1P000007ooooo`H000001oooool7000000X0dLfY1_ooool<000000Kooooo1P00000Boooo
o`H000001_ooool<000000Kooooo2`3AcJT5ooooo`/000003?ooool;0000017ooooo1@00000<oooo
o`D000002P3AcJT@000000_ooooo2P000005ooooo`/000002_ooool@000000X0dLfY2P00000?oooo
o`l000002Oooool:000000oooooo1@00000=0=7=Z@00303AcJT6000000Oooooo1`000006ooooo`L0
00003Oooool6000000Oooooo1P000007ooooo`L000002P3AcJT6ooooo``000001_ooool6000001;o
oooo1P000006ooooo``000001_ooool;0=7=Z@Gooooo2`00000<ooooo`/000004Oooool5000000co
oooo1@00000:0=7=ZA0000002oooool:000000Gooooo2`00000:oooooa0000002P3AcJT5000001Wo
oooo1@000005ooooo`D000001?ooool:000001Cooooo3@3AcJT000`0dLfY1P000007ooooo`L00000
1_ooool7000000gooooo1P000007ooooo`H000001oooool7000000X0dLfY1_ooool<000000Kooooo
1P00000Booooo`H000001_ooool<000000Kooooo2`3AcJT5ooooo`/000003?ooool;0000017ooooo
1@00000<ooooo`D000002P3AcJT@000000_ooooo2P000005ooooo`/000002_ooool@000000X0dLfY
1@00000Iooooo`D000001Oooool5000000Cooooo2P00000Dooooo`d0dLfY000<0=7=Z@Kooooo1`00
000=oooooaX000003Oooool7000000Oooooo2P3AcJT6ooooo``000001_ooool6000001;ooooo1P00
0006ooooo``000001_ooool;0=7=Z@Gooooo2`00000<ooooo`/000004Oooool5000000cooooo1@00
000:0=7=ZA0000002oooool:000000Gooooo2`00000:oooooa0000002P3AcJT5000001Wooooo1@00
0005ooooo`D000001?ooool:000001Cooooo3@3AcJT000`0dLfY1_ooool7000000gooooo6P00000=
ooooo`L000001oooool:0=7=ZA8000001_ooool<000000Kooooo30000006oooooa8000002`3AcJT5
ooooo`/000003?ooool;0000017ooooo1@00000<ooooo`D000002P3AcJT@000000_ooooo2P000005
ooooo`/000002_ooool@000000X0dLfY1@00000Iooooo`D000001Oooool5000000Cooooo2P00000D
ooooo`d0dLfY000<0=7=Z@Kooooo1`00000=oooooaX000003Oooool7000000Oooooo2P3AcJTB0000
00Kooooo30000006ooooo``000001_oooolB000000/0dLfY7?ooool;0000017ooooo5P00000:0=7=
ZA0000002oooool:000000Gooooo2`00000:oooooa0000002P3AcJT5000001Wooooo1@000005oooo
o`D000001?ooool:000001Cooooo3@3AcJT000`0dLfY1_ooool7000000gooooo6P00000=ooooo`L0
00001oooool:0=7=ZA8000001_ooool<000000Kooooo30000006oooooa8000002`3AcJTLooooo`/0
00004OoooolF000000X0dLfY1_ooool?0000013ooooo1@00000@oooooa0000001Oooool:0=7=ZB<0
00002_ooool4000000oooooo2P000005ooooo`d0dLfY000<0=7=Z@Kooooo1`00000=oooooaX00000
3Oooool7000000Oooooo2P3AcJTB000000Kooooo30000006ooooo``000001_oooolB000000/0dLfY
7?ooool;0000017ooooo5P00000:0=7=Z@Kooooo3`00000@ooooo`D000004?ooool@000000Gooooo
2P3AcJTS000000[ooooo1000000?ooooo`X000001Oooool=0=7=Z@00303AcJT6ooooo`L000003Ooo
oolJ000000gooooo1`000007ooooo`X0dLfY4P000006ooooo``000001_ooool<000000Kooooo4P00
000;0=7=ZAcooooo2`00000AoooooaH000002P3AcJT6ooooo`l000004?ooool50000013ooooo4000
0005ooooo`X0dLfY8`00000:ooooo`@000003oooool:000000Gooooo3@3AcJT000`0dLfY1P000007
ooooo`L000009oooool6000000Oooooo1`00000:0=7=ZA8000001_ooool<000000Kooooo30000006
oooooa8000002`3AcJTLooooo`/000004OoooolF000000X0dLfY1_ooool?0000013ooooo1@00000@
oooooa0000001Oooool:0=7=ZB<000002_ooool4000000oooooo2P000005ooooo`d0dLfY000<0=7=
Z@H000001oooool7000002Oooooo1P000007ooooo`L000002P3AcJT<000000Kooooo1P000006oooo
oa8000001_ooool6000000Kooooo3000000;0=7=Z@D000002oooool6000001Oooooo1@00000Loooo
o`X0dLfY1_ooool?0000013ooooo1@00000@oooooa0000001Oooool:0=7=ZB<000002_ooool40000
00oooooo2P000005ooooo`d0dLfY000<0=7=Z@H000001oooool7000002Oooooo1P000007ooooo`L0
00002P3AcJT<000000Kooooo1P000006oooooa8000001_ooool6000000Kooooo3000000;0=7=Z@D0
00002oooool6000001Oooooo1@00000Looooo`X0dLfY1P000005ooooo`X000002oooool5000000Go
oooo1P00000:ooooo`/000001Oooool5000000X0dLfY:?ooool5000000Cooooo1@00000:ooooo`X0
00001Oooool=0=7=Z@00303AcJT6000000Oooooo1`00000Wooooo`H000001oooool7000000X0dLfY
30000006ooooo`H000001_oooolB000000Kooooo1P000006ooooo``000002`3AcJT5000000_ooooo
1P00000Gooooo`D000007?ooool:0=7=Z@H000001Oooool:000000_ooooo1@000005ooooo`H00000
2_ooool;000000Gooooo1@00000:0=7=ZBSooooo1@000004ooooo`D000002_ooool:000000Gooooo
3@3AcJT000`0dLfY1P000007ooooo`L000009oooool6000000Oooooo1`00000:0=7=Z@`000001_oo
ool6000000Kooooo4P000006ooooo`H000001_ooool<000000/0dLfY1@00000;ooooo`H000005ooo
ool5000001cooooo2P3AcJT6000000Gooooo2P00000;ooooo`D000001Oooool6000000[ooooo2`00
0005ooooo`D000002P3AcJTXooooo`D000001?ooool5000000[ooooo2P000005ooooo`d0dLfY000<
0=7=Z@H000001oooool7000002Oooooo1P000007ooooo`L000002P3AcJT<000000Kooooo1P000006
oooooa8000001_ooool6000000Kooooo3000000;0=7=Z@D000002oooool6000001Oooooo1@00000L
ooooo`X0dLfY1P000005ooooo`X000002oooool5000000Gooooo1P00000:ooooo`/000001Oooool5
000000X0dLfY:?ooool5000000Cooooo1@00000:ooooo`X000001Oooool=0=7=Z@00303AcJT60000
00Oooooo1`00000Wooooo`H000001oooool7000000X0dLfY30000006ooooo`H000001_oooolB0000
00Kooooo1P000006ooooo``000002`3AcJT5000000_ooooo1P00000Gooooo`D000007?ooool:0=7=
Z@H000001Oooool:000000_ooooo1@000005ooooo`H000002_ooool;000000Gooooo1@00000:0=7=
ZBSooooo1@000004ooooo`D000002_ooool:000000Gooooo3@3AcJT00?l0dLfYc03AcJT00?l0dLfY
c03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfY
c03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfYc03AcJT00?l0dLfY
c03AcJT000`0dLfY5P00000<ooooo`/000002ooooolG000000X0dLfY4`00000Xoooooa<000002`3A
cJU>ooooo`X0dLfY20000008ooooo`P000008?ooool7000000Sooooo2000000:0=7=Z@L000005_oo
ool7000002_ooooo3@3AcJT000`0dLfY5P00000<ooooo`/000002ooooolG000000X0dLfY4`00000X
oooooa<000002`3AcJU>ooooo`X0dLfY20000008ooooo`P000008?ooool7000000Sooooo2000000:
0=7=Z@L000005_ooool7000002_ooooo3@3AcJT000`0dLfY5P00000<ooooo`/000002ooooolG0000
00X0dLfY4`00000Xoooooa<000002`3AcJU>ooooo`X0dLfY20000008ooooo`P000008?ooool70000
00Sooooo2000000:0=7=Z@L000005_ooool7000002_ooooo3@3AcJT000`0dLfY5P00000<ooooo`/0
00002ooooolG000000X0dLfY4`00000Xoooooa<000002`3AcJU>ooooo`X0dLfY20000008ooooo`P0
00008?ooool7000000Sooooo2000000:0=7=Z@L000005_ooool7000002_ooooo3@3AcJT000`0dLfY
5P00000<ooooo`/000002ooooolG000000X0dLfY4`00000Xoooooa<000002`3AcJU>ooooo`X0dLfY
20000008ooooo`P000008?ooool7000000Sooooo2000000:0=7=Z@L000005_ooool7000002_ooooo
3@3AcJT000`0dLfY5P00000<ooooo`/000002ooooolG000000X0dLfY4`00000Xoooooa<000002`3A
cJU>ooooo`X0dLfY20000008ooooo`P000008?ooool7000000Sooooo2000000:0=7=Z@L000005_oo
ool7000002_ooooo3@3AcJT000`0dLfY5P00000<ooooo`/000002ooooolG000000X0dLfY4`00000X
oooooa<000002`3AcJU>ooooo`X0dLfY20000008ooooo`P000008?ooool7000000Sooooo2000000:
0=7=Z@L000005_ooool7000002_ooooo3@3AcJT000`0dLfY5P00000<ooooo`/000002ooooolG0000
00X0dLfY4`00000Xoooooa<000002`3AcJU>ooooo`X0dLfY20000008ooooo`P000008?ooool70000
00Sooooo2000000:0=7=Z@oooooo1`00000Eooooob@000003@3AcJT000`0dLfY5P00000<ooooo`/0
00002ooooolG000000X0dLfY4`00000Xoooooa<000002`3AcJU>ooooo`X0dLfY2?ooool80000013o
oooo4000000?ooooo`P000002?ooool:0=7=Z@oooooo1`00000Eooooob@000003@3AcJT000`0dLfY
5P00000<ooooo`/000002ooooolG000000X0dLfY4`00000Xoooooa<000002`3AcJU>000000X0dLfY
2?ooool80000013ooooo4000000?ooooo`P000002?ooool:0=7=Z@oooooo1`00000Eooooob@00000
3@3AcJT000`0dLfY5P00000<ooooo`/000002ooooolG000000X0dLfY4`00000:oooooa@000002_oo
oolC000000/0dLfYCP00000:0=7=Z@Sooooo2000000@oooooa0000003oooool8000000Sooooo2P3A
cJT?ooooo`L000005OoooolT000000d0dLfY000<0=7=ZB8000002ooooolR000000X0dLfY4`00000:
oooooa@000002_oooolC000000/0dLfYCP00000:0=7=Z@Sooooo2000000@oooooa0000003oooool8
000000Sooooo2P3AcJT?ooooo`L000005OoooolT000000d0dLfY000<0=7=ZB8000002ooooolR0000
00X0dLfY4`00000:oooooa@000002_oooolC000000/0dLfYCP00000:0=7=Z@Sooooo2000000@oooo
oa0000003oooool8000000Sooooo2P3AcJT?ooooo`L000005OoooolT000000d0dLfY000<0=7=ZB80
00002ooooolR000000X0dLfY4`00000:oooooa@000002_oooolC000000/0dLfYCP00000:0=7=Z@So
oooo2000000@oooooa0000003oooool8000000Sooooo2P3AcJT?ooooo`L000005OoooolT000000d0
dLfY000<0=7=ZB8000002ooooolR000000X0dLfY4`00000:oooooa@000002_oooolC000000/0dLfY
CP00000:0=7=Z@Sooooo2000000@oooooa0000003oooool8000000Sooooo2P3AcJT[ooooo`L00000
5_ooool7000000d0dLfY000<0=7=ZB8000002ooooolR000000X0dLfY4`00000:oooooa@000002_oo
oolC000000/0dLfYCP00000:0=7=Z@P000002?ooool8000000Sooooo40000008ooooo`L000002?oo
ool8000000X0dLfY:oooool7000001Kooooo1`00000=0=7=Z@00303AcJTR000000_ooooo8P00000:
0=7=ZA<000002_oooolD000000[ooooo4`00000;0=7=ZDh000002P3AcJT8000000Sooooo20000008
oooooa0000002?ooool7000000Sooooo2000000:0=7=ZB_ooooo1`00000Fooooo`L000003@3AcJT0
00`0dLfY8P00000;ooooob8000002P3AcJTC000000[ooooo5000000:oooooa<000002`3AcJT80000
03kooooo2000000:0=7=Z@P000002?ooool8000000Sooooo40000008ooooo`L000002?ooool80000
00X0dLfY:oooool7000001Kooooo1`00000=0=7=Z@00303AcJTR000000_ooooo8P00000:0=7=ZA<0
00002_oooolD000000[ooooo4`00000;0=7=Z@P00000?_ooool8000000X0dLfY20000008ooooo`P0
00002?ooool@000000Sooooo1`000008ooooo`P000002P3AcJT[ooooo`L000005_ooool7000000d0
dLfY000<0=7=ZB8000002ooooolR000000X0dLfY4ooooolX000001?ooooo2`3AcJT8000003kooooo
2000000:0=7=Z@P000002?ooool8000000Sooooo40000008ooooo`L000002?ooool8000000X0dLfY
:oooool7000001Kooooo1`00000=0=7=Z@00303AcJTR000000_ooooo8P00000:0=7=ZA?ooooo:000
000Cooooo`/0dLfY2000000nooooo`P000002P3AcJT8000000Sooooo20000008oooooa0000002?oo
ool7000000Sooooo2000000:0=7=ZB_ooooo1`00000Fooooo`L000003@3AcJT000`0dLfY8P00000;
ooooob8000002P3AcJTCooooobP000004oooool;0=7=Z@P00000?_ooool8000000X0dLfY20000008
ooooo`P000002?ooool@000000Sooooo1`000008ooooo`P000002P3AcJT?000000Oooooo3P000007
ooooo`l000001oooool>000000d0dLfY000<0=7=Z@_ooooo5`00000;oooooaH000003?ooool:0=7=
ZA?ooooo:000000Cooooo`/0dLfY2000000nooooo`P000002P3AcJT8000000Sooooo20000008oooo
oa0000002?ooool7000000Sooooo2000000:0=7=Z@l000001oooool>000000Oooooo3`000007oooo
o`h000003@3AcJT000`0dLfY2ooooolG000000_ooooo5P00000<ooooo`X0dLfY4ooooolX000001?o
oooo2`3AcJT8000003kooooo2000000:0=7=ZASooooo2000000@ooooo`P000005oooool:0=7=Z@l0
00001oooool>000000Oooooo3`000007ooooo`h000003@3AcJT000`0dLfY2ooooolG000000_ooooo
5P00000<ooooo`X0dLfY4ooooolX000001?ooooo2`3AcJT8000003kooooo2000000:0=7=ZASooooo
2000000@ooooo`P000005oooool:0=7=Z@l000001oooool>000000Oooooo3`000007ooooo`h00000
3@3AcJT000`0dLfY2ooooolG000000_ooooo5P00000<ooooo`X0dLfY4ooooolX000001?ooooo2`3A
cJT8000003kooooo2000000:0=7=ZASooooo2000000@ooooo`P000005oooool:0=7=Z@l000001ooo
ool>000000Oooooo3`000007ooooo`h000003@3AcJT000`0dLfY2ooooolG000000_ooooo5P00000<
ooooo`X0dLfY4ooooolX000001?ooooo2`3AcJTA000002cooooo4@00000:0=7=ZASooooo2000000@
ooooo`P000005oooool:0=7=Z@l000001oooool>000000Oooooo3`000007ooooo`h000003@3AcJT0
00`0dLfY2ooooolG000000_ooooo5P00000<ooooo`X0dLfY4ooooolX000001?ooooo2`3AcJTA0000
02cooooo4@00000:0=7=ZASooooo2000000@ooooo`P000005oooool:0=7=Z@l000001oooool>0000
00Oooooo3`000007ooooo`h000003@3AcJT000`0dLfY2ooooolG000000_ooooo5P00000<ooooo`X0
dLfY4ooooolX000001?ooooo2`3AcJTA000002cooooo4@00000:0=7=ZASooooo2000000@ooooo`P0
00005oooool:0=7=ZB/000001ooooolF000000Oooooo3@3AcJT000`0dLfY2ooooolG000000_ooooo
5P00000<ooooo`X0dLfY2_oooolk000000Wooooo2`3AcJTA000002cooooo4@00000:0=7=ZASooooo
2000000@ooooo`P000005oooool:0=7=ZB/000001ooooolF000000Oooooo3@3AcJT000`0dLfY2ooo
oolG000000_ooooo5P00000<ooooo`X0dLfY2_oooolk000000Wooooo2`3AcJTA000002cooooo4@00
000:0=7=ZASooooo2000000@ooooo`P000005oooool:0=7=ZB/000001ooooolF000000Oooooo3@3A
cJT000`0dLfY2ooooolG000000_ooooo5P00000<ooooo`X0dLfY2_oooolk000000Wooooo2`3AcJTA
000002cooooo4@00000:0=7=Z@Sooooo40000008oooooa0000002?ooool?000000Sooooo2P3AcJT[
000000Oooooo5P000007ooooo`d0dLfY000<0=7=Z@_ooooo5`00000;oooooaH000003?ooool:0=7=
Z@[ooooo>`000009ooooo`/0dLfY4@00000/oooooa4000002P3AcJT8oooooa0000002?ooool@0000
00Sooooo3`000008ooooo`X0dLfY:`000007oooooaH000001oooool=0=7=Z@00303AcJT;000001Oo
oooo2`00000Fooooo``000002P3AcJT:oooooc/000002Oooool;0=7=ZA400000;?oooolA000000X0
dLfY2?ooool@000000Sooooo40000008ooooo`l000002?ooool:0=7=ZB/000001ooooolF000000Oo
oooo3@3AcJT000`0dLfY2`00000Gooooo`/000005_ooool<000000X0dLfY2_oooolk000000Wooooo
2`3AcJT8ooooo`T000002OoooolJ000000Wooooo2@000008ooooo`X0dLfY2?ooool@000000Sooooo
40000008ooooo`l000002?ooool:0=7=ZB/000001ooooolF000000Oooooo3@3AcJT000`0dLfY2`00
000Gooooo`/000005_ooool<000000X0dLfY2_oooolk000000Wooooo2`3AcJT8ooooo`T000002Ooo
oolJ000000Wooooo2@000008ooooo`X0dLfY2?ooool@000000Sooooo40000008ooooo`l000002?oo
ool:0=7=Z@Oooooo20000007oooooaD000007Oooool7000000d0dLfY000<0=7=Z@/000005oooool;
000001Kooooo3000000:0=7=Z@[ooooo>`000009ooooo`/0dLfY2?ooool9000000Wooooo6P000009
ooooo`T000002?ooool:0=7=Z@Sooooo40000008oooooa0000002?ooool?000000Sooooo2P3AcJT7
ooooo`P000001ooooolE000001gooooo1`00000=0=7=Z@00303AcJT;000001Oooooo2`00000Foooo
o``000002P3AcJT:oooooc/000002Oooool;0=7=Z@Sooooo2@000009oooooaX000002Oooool90000
00Sooooo2P3AcJT8oooooa0000002?ooool@000000Sooooo3`000008ooooo`X0dLfY1oooool80000
00Oooooo5@00000Mooooo`L000003@3AcJT000`0dLfY2`00000Gooooo`/000005_ooool<000000X0
dLfY2_oooolk000000Wooooo2`3AcJT8ooooo`T000002OoooolJ000000Wooooo2@000008ooooo`X0
dLfY2?ooool@000000Sooooo40000008ooooo`l000002?ooool:0=7=Z@Oooooo20000007oooooaD0
00007Oooool7000000d0dLfY000<0=7=Z@/000005oooool;000001Kooooo3000000:0=7=Z@[ooooo
>`000009ooooo`/0dLfY2?ooool9000000Wooooo6P000009ooooo`T000002?ooool:0=7=Z@Sooooo
40000008oooooa0000002?ooool?000000Sooooo2P3AcJT7ooooo`P000001ooooolE000001gooooo
1`00000=0=7=Z@00303AcJT;000001Oooooo2`00000Fooooo``000002P3AcJT:oooooc/000002Ooo
ool;0=7=Z@Sooooo2@000009oooooaX000002Oooool9000000Sooooo2P3AcJT8oooooa0000002?oo
ool@000000Sooooo3`000008ooooo`X0dLfY1oooool8000000Oooooo5@00000Mooooo`L000003@3A
cJT000`0dLfY2`00000Gooooo`/000005_ooool<000000X0dLfY2_oooolk000000Wooooo2`3AcJT8
ooooo`T000002OoooolJ000000Wooooo2@000008ooooo`X0dLfY2?ooool@000000Sooooo40000008
ooooo`l000002?ooool:0=7=Z@Oooooo20000007oooooaD000007Oooool7000000d0dLfY000<0=7=
Z@/000005oooool;000001Kooooo3000000:0=7=Z@[ooooo>`000009ooooo`/0dLfY2?ooool90000
00Wooooo6P000009ooooo`T000002?ooool:0=7=Z@Sooooo40000008oooooa0000002?ooool?0000
00Sooooo2P3AcJT?000000kooooo1`00000Mooooo`L000001oooool=0=7=Z@00303AcJT;000001Oo
oooo2`00000Fooooo``000002P3AcJT:oooooc/000002Oooool;0=7=ZB<000002?oooolS000000X0
dLfY2?ooool@000000Sooooo40000008ooooo`l000002?ooool:0=7=Z@l000003_ooool7000001go
oooo1`000007ooooo`d0dLfY000<0=7=Z@_ooooo5`00000;oooooaH000003?ooool:0=7=Z@[ooooo
>`000009ooooo`/0dLfY8`000008ooooob<000002P3AcJT8oooooa0000002?ooool@000000Sooooo
3`000008ooooo`X0dLfY3`00000>ooooo`L000007Oooool7000000Oooooo3@3AcJT000`0dLfY2ooo
oolG000000_ooooo5P00000<ooooo`X0dLfY2_oooolk000000Wooooo2`3AcJTS000000Sooooo8`00
000:0=7=Z@Sooooo40000008oooooa0000002?ooool?000000Sooooo2P3AcJT?000000kooooo1`00
000Mooooo`L000001oooool=0=7=Z@00303AcJT;oooooaL000002ooooolF000000cooooo2P3AcJT:
oooooc/000002Oooool;0=7=ZB<000002?oooolS000000X0dLfY6?ooool80000013ooooo2000000G
ooooo`X0dLfY3`00000>ooooo`L000007Oooool7000000Oooooo3@3AcJT000`0dLfY2ooooolG0000
00_ooooo5P00000<ooooo`X0dLfY2_oooolk000000Wooooo2`3AcJTS000000Sooooo8`00000:0=7=
ZASooooo2000000@ooooo`P000005oooool:0=7=Z@l000003_ooool7000001gooooo1`000007oooo
o`d0dLfY000<0=7=Z@_ooooo5`00000;oooooaH000003?ooool:0=7=ZA?ooooo:000000Cooooo`/0
dLfY8`000008ooooob<000002P3AcJTHooooo`P000004?ooool8000001Oooooo2P3AcJT?000000ko
oooo1`00000Mooooo`L000001oooool=0=7=Z@00303AcJT;oooooaL000002ooooolF000000cooooo
2P3AcJTCooooobP000004oooool;0=7=ZB<000002?oooolS000000X0dLfY6?ooool80000013ooooo
2000000Gooooo`X0dLfY1`00000?ooooob@000003_ooool7000000d0dLfY000<0=7=Z@_ooooo5`00
000;oooooaH000003?ooool:0=7=ZA?ooooo:000000Cooooo`/0dLfY8`000008ooooob<000002P3A
cJTHooooo`P000004?ooool8000001Oooooo2P3AcJT7000000oooooo9000000>ooooo`L000003@3A
cJT000`0dLfY2ooooolG000000_ooooo5P00000<ooooo`X0dLfY4ooooolX000001?ooooo2`3AcJTA
000002cooooo4@00000:0=7=ZASooooo2000000@ooooo`P000005oooool:0=7=Z@L000003ooooolT
000000kooooo1`00000=0=7=Z@00303AcJT;oooooaL000002ooooolF000000cooooo2P3AcJTCoooo
obP000004oooool;0=7=ZA400000;?oooolA000000X0dLfY6?ooool80000013ooooo2000000Goooo
o`X0dLfY1`00000?ooooob@000003_ooool7000000d0dLfY000<0=7=Z@_ooooo5`00000;oooooaH0
00003?ooool:0=7=ZA?ooooo:000000Cooooo`/0dLfY4@00000/oooooa4000002P3AcJTHooooo`P0
00004?ooool8000001Oooooo2P3AcJT7000000oooooo9000000>ooooo`L000003@3AcJT000`0dLfY
2ooooolG000000_ooooo5P00000<ooooo`X0dLfY4ooooolX000001?ooooo2`3AcJTA000002cooooo
4@00000:0=7=Z@P000002?ooool8000000Sooooo40000008ooooo`L000002?ooool8000000X0dLfY
1`00000?ooooob@000003_ooool7000000d0dLfY000<0=7=ZB8000002ooooolR000000X0dLfY4ooo
oolX000001?ooooo2`3AcJTA000002cooooo4@00000:0=7=Z@P000002?ooool8000000Sooooo4000
0008ooooo`L000002?ooool8000000X0dLfY1`00000?ooooob@000003_ooool7000000d0dLfY000<
0=7=ZB8000002ooooolR000000X0dLfY4ooooolX000001?ooooo2`3AcJTA000002cooooo4@00000:
0=7=Z@P000002?ooool8000000Sooooo40000008ooooo`L000002?ooool8000000X0dLfY3`000007
ooooo`h000003_ooool8000000Oooooo1`000007ooooo`d0dLfY000<0=7=ZB8000002ooooolR0000
00X0dLfY4ooooolX000001?ooooo2`3AcJTA000002cooooo4@00000:0=7=Z@P000002?ooool80000
00Sooooo40000008ooooo`L000002?ooool8000000X0dLfY3`000007ooooo`h000003_ooool80000
00Oooooo1`000007ooooo`d0dLfY000<0=7=ZB8000002ooooolR000000X0dLfY4`00000:oooooa@0
00002_oooolC000000/0dLfY4@00000/oooooa4000002P3AcJT8000000Sooooo20000008oooooa00
00002?ooool7000000Sooooo2000000:0=7=Z@l000001oooool>000000kooooo20000007ooooo`L0
00001oooool=0=7=Z@00303AcJTR000000_ooooo8P00000:0=7=ZA<000002_oooolD000000[ooooo
4`00000;0=7=ZA400000;?oooolA000000X0dLfY20000008ooooo`P000002?ooool@000000Sooooo
1`000008ooooo`P000002P3AcJT?000000Oooooo3P00000>ooooo`P000001oooool7000000Oooooo
3@3AcJT000`0dLfY8P00000;ooooob8000002P3AcJTC000000[ooooo5000000:oooooa<000002`3A
cJTAooooo`T000002Oooool8000000Wooooo2@00000Aooooo`X0dLfY20000008ooooo`P000002?oo
ool@000000Sooooo1`000008ooooo`P000002P3AcJT?000000Oooooo3P00000>ooooo`P000001ooo
ool7000000Oooooo3@3AcJT000`0dLfY8P00000;ooooob8000002P3AcJTC000000[ooooo5000000:
oooooa<000002`3AcJTAooooo`T000002Oooool8000000Wooooo2@00000Aooooo`X0dLfY2?ooool8
0000013ooooo4000000?ooooo`P000002?ooool:0=7=Z@l000001oooool>000000kooooo20000007
ooooo`L000001oooool=0=7=Z@00303AcJTR000000_ooooo8P00000:0=7=ZA<000002_oooolD0000
00[ooooo4`00000;0=7=ZA7ooooo2@000009ooooo`P000002Oooool90000017ooooo2P3AcJT8oooo
o`P000004?ooool@000000oooooo20000008ooooo`X0dLfY3`000007ooooo`h000003_ooool80000
00Oooooo1`000007ooooo`d0dLfY000<0=7=ZB8000002ooooolR000000X0dLfY4`00000:oooooa@0
00002_oooolC000000/0dLfY4Oooool9000000Wooooo20000009ooooo`T000004Oooool:0=7=Z@So
oooo2000000@oooooa0000003oooool8000000Sooooo2P3AcJT7ooooo`l000003_oooolM000000Oo
oooo1`00000=0=7=Z@00303AcJTR000000_ooooo8P00000:0=7=ZA<000002_oooolD000000[ooooo
4`00000;0=7=ZA7ooooo2@000009ooooo`P000002Oooool90000017ooooo2P3AcJT8ooooo`P00000
4?ooool@000000oooooo20000008ooooo`X0dLfY1oooool?000000kooooo7@000007ooooo`L00000
3@3AcJT000`0dLfY8P00000;ooooob8000002P3AcJTC000000[ooooo5000000:oooooa<000002`3A
cJTAooooo`T000002Oooool8000000Wooooo2@00000Aooooo`X0dLfY2?ooool80000013ooooo4000
000?ooooo`P000002?ooool:0=7=Z@Oooooo3`00000>oooooad000001oooool7000000d0dLfY000<
0=7=ZAH000003?ooool;000000_ooooo5`00000:0=7=ZA<000002_oooolD000000[ooooo4`00000;
0=7=ZA7ooooo2@000009ooooo`P000002Oooool90000017ooooo2P3AcJT8ooooo`P000004?ooool@
000000oooooo20000008ooooo`X0dLfY1oooool?000000kooooo7@000007ooooo`L000003@3AcJT0
00`0dLfY5P00000<ooooo`/000002ooooolG000000X0dLfY4`00000Xoooooa<000002`3AcJTAoooo
o`T000002Oooool8000000Wooooo2@00000Aooooo`X0dLfY2?ooool80000013ooooo4000000?oooo
o`P000002?ooool:0=7=Z@Oooooo3`00000>oooooad000001oooool7000000d0dLfY000<0=7=ZAH0
00003?ooool;000000_ooooo5`00000:0=7=ZA<00000:?oooolC000000/0dLfY2?ooool9000000Wo
oooo2@000008ooooo`T000002Oooool9000000Sooooo2P3AcJT8ooooo`P000004?ooool@000000oo
oooo20000008ooooo`X0dLfY1oooool?000000kooooo7@000007ooooo`L000003@3AcJT000`0dLfY
5P00000<ooooo`/000002ooooolG000000X0dLfY4`00000Xoooooa<000002`3AcJT8ooooo`T00000
2Oooool9000000Sooooo2@000009ooooo`T000002?ooool:0=7=Z@P000002?ooool80000023ooooo
1`000008ooooo`P000002P3AcJT7ooooo`l000003_oooolM000000Oooooo1`00000=0=7=Z@00303A
cJTF000000cooooo2`00000;oooooaL000002P3AcJTC000002Sooooo4`00000;0=7=Z@Sooooo2@00
0009ooooo`T000002?ooool9000000Wooooo2@000008ooooo`X0dLfY20000008ooooo`P000008?oo
ool7000000Sooooo2000000:0=7=Z@L000002?oooolL000000Oooooo3`00000>ooooo`d0dLfY000<
0=7=ZAH000003?ooool;000000_ooooo5`00000:0=7=ZA<00000:?oooolC000000/0dLfY2?ooool9
000000Wooooo2@000008ooooo`T000002Oooool9000000Sooooo2P3AcJT8000000Sooooo2000000P
ooooo`L000002?ooool8000000X0dLfY1`000008oooooa`000001oooool?000000kooooo3@3AcJT0
00`0dLfY5P00000<ooooo`/000002ooooolG000000X0dLfY4`00000Xoooooa<000002`3AcJT8oooo
o`T000002Oooool9000000Sooooo2@000009ooooo`T000002?ooool:0=7=Z@P000002?ooool80000
023ooooo1`000008ooooo`P000002P3AcJT7000000Sooooo70000007ooooo`l000003_ooool=0=7=
Z@00303AcJTF000000cooooo2`00000;oooooaL000002P3AcJTC000002Sooooo4`00000;0=7=Z@So
oooo2@000009ooooo`T000002?ooool9000000Wooooo2@000008ooooo`X0dLfY20000008ooooo`P0
00008?ooool7000000Sooooo2000000:0=7=Z@L000002?oooolL000000Oooooo3`00000>ooooo`d0
dLfY000<0=7=ZAH000003?ooool;000000_ooooo5`00000:0=7=ZA<00000:?oooolC000000/0dLfY
2?ooool9000000Wooooo2@000008ooooo`T000002Oooool9000000Sooooo2P3AcJT8000000Sooooo
2000000Pooooo`L000002?ooool8000000X0dLfY1`000008oooooa`000001oooool?000000kooooo
3@3AcJT000`0dLfY5P00000<ooooo`/000002ooooolG000000X0dLfY4`00000Xoooooa<000002`3A
cJT8ooooo`T000002Oooool9000000Sooooo2@000009ooooo`T000002?ooool:0=7=Z@P000002?oo
ool80000023ooooo1`000008ooooo`P000002P3AcJT7000000Sooooo70000007ooooo`l000003_oo
ool=0=7=Z@00303AcJTF000000cooooo2`00000;oooooaL000002P3AcJTC000002Sooooo4`00000;
0=7=Z@Sooooo2@000009ooooo`T000002?ooool9000000Wooooo2@000008ooooo`X0dLfY20000008
ooooo`P000008?ooool7000000Sooooo2000000:0=7=Z@L000002?oooolL000000Oooooo3`00000>
ooooo`d0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o
0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o
0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY000<0=7=ZDl0P8202P3AcJTJ000001[ooooo
6P00000;0=7=ZDkooooo2P3AcJTP000002oooooo2P3AcJT=000000kooooo6P00000=ooooo`d00000
3@3AcJT000`0dLfYC`20P80:0=7=ZAX000006_oooolJ000000/0dLfYC_ooool:0=7=ZB000000;ooo
ool:0=7=Z@d000003_oooolJ000000gooooo3@00000=0=7=Z@00303AcJU?0820P0X0dLfY6P00000J
oooooaX000002`3AcJU>ooooo`X0dLfY8000000_ooooo`X0dLfY3@00000>oooooaX000003Oooool=
000000d0dLfY000<0=7=ZDl0P8202P3AcJTJ000001[ooooo6P00000;0=7=ZDkooooo2P3AcJTP0000
02oooooo2P3AcJT=000000kooooo6P00000=ooooo`d000003@3AcJT000`0dLfYC`20P80:0=7=ZAX0
00006_oooolJ000000/0dLfYC_ooool:0=7=ZB000000;oooool:0=7=Z@d000003_oooolJ000000go
oooo3@00000=0=7=Z@00303AcJU?0820P0X0dLfY6P00000JoooooaX000002`3AcJU>ooooo`X0dLfY
8000000_ooooo`X0dLfY3@00000>oooooaX000003Oooool=000000d0dLfY000<0=7=ZDl0P8202P3A
cJTJ000001[ooooo6P00000;0=7=ZDkooooo2P3AcJTP000002oooooo2P3AcJT=000000kooooo6P00
000=ooooo`d000003@3AcJT000`0dLfYC`20P80:0=7=ZAX000006_oooolJ000000/0dLfYC_ooool:
0=7=ZB000000;oooool:0=7=Z@d000003_oooolJ000000gooooo3@00000=0=7=Z@00303AcJU?0820
P0X0dLfY6P00000JoooooaX000002`3AcJU>ooooo`X0dLfY8000000_ooooo`X0dLfY3@00000>oooo
oaX000003Oooool=000000d0dLfY000<0=7=ZDl0P8202P3AcJTJ000001[ooooo6P00000;0=7=ZDko
oooo2P3AcJTP000002oooooo2P3AcJT=000000kooooo6P00000=ooooo`d000003@3AcJT000`0dLfY
C`20P80:0=7=ZAX000006_oooolJ000000/0dLfYC_ooool:0=7=ZB000000;oooool:0=7=Z@d00000
3_oooolJ000000gooooo3@00000=0=7=Z@00303AcJU?0820P0X0dLfY6P00000JoooooaX000002`3A
cJU>ooooo`X0dLfY8000000_ooooo`X0dLfY3@00000>oooooaX000003Oooool=000000d0dLfY000<
0=7=ZDl0P8202P3AcJTJ000001[ooooo6P00000;0=7=ZDkooooo2P3AcJTP000002oooooo2P3AcJT=
000000kooooo6P00000=ooooo`d000003@3AcJT000`0dLfYC`20P80:0=7=ZAX000006_oooolJ0000
00/0dLfYC_ooool:0=7=ZB000000;oooool:0=7=Z@gooooo=@00000=ooooo`d0dLfY000<0=7=ZDl0
P8202P3AcJTJ000001[ooooo6P00000;0=7=ZDkooooo2P3AcJTP000002oooooo2P3AcJT=ooooocD0
00003Oooool=0=7=Z@00303AcJU?0820P0X0dLfY6P00000JoooooaX000002`3AcJU>ooooo`X0dLfY
8000000@oooooal000002P3AcJT=ooooocD000003Oooool=0=7=Z@00303AcJU?0820P0X0dLfY6P00
000JoooooaX000002`3AcJU>ooooo`X0dLfY8000000@oooooal000002P3AcJT=ooooocD000003Ooo
ool=0=7=Z@00303AcJU?0820P0X0dLfY6P00000JoooooaX000002`3AcJU>ooooo`X0dLfY8000000@
oooooal000002P3AcJT=ooooocD000003Oooool=0=7=Z@00303AcJU?0820P0X0dLfY6P00000Joooo
oaX000002`3AcJU>ooooo`X0dLfY8000000@oooooal000002P3AcJT=ooooocD000003Oooool=0=7=
Z@00303AcJU?0820P0X0dLfY6P00000JoooooaX000002`3AcJU>000000X0dLfY8000000@oooooal0
00002P3AcJT=ooooocD000003Oooool=0=7=Z@00303AcJU?0820P0X0dLfY6P00000JoooooaX00000
2`3AcJU>000000X0dLfY8000000@oooooal000002P3AcJT=ooooocD000003Oooool=0=7=Z@00303A
cJU?0820P0X0dLfY6P00000JoooooaX000002`3AcJU>000000X0dLfY8000000@oooooal000002P3A
cJT=ooooocD000003Oooool=0=7=Z@00303AcJU?0820P0X0dLfY6P00000JoooooaX000002`3AcJU>
000000X0dLfY8000000@oooooal000002P3AcJT=ooooocD000003Oooool=0=7=Z@00303AcJU?0820
P0X0dLfY6P00000JoooooaX000002`3AcJU>000000X0dLfY8000000@oooooal000002P3AcJT=oooo
ocD000003Oooool=0=7=Z@00303AcJU?0820P0X0dLfY6P00000JoooooaX000002`3AcJU>000000X0
dLfY8000000@oooooal000002P3AcJT=ooooocD000003Oooool=0=7=Z@00303AcJU?0820P0X0dLfY
6_oooolJ000001[ooooo2`3AcJU>000000X0dLfY8000000@oooooal000002P3AcJU?000000d0dLfY
000<0=7=ZDl0P8202P3AcJTJoooooaX000006_ooool;0=7=ZDh000002P3AcJTP0000013ooooo7`00
000:0=7=ZDl000003@3AcJT000`0dLfYC`20P80:0=7=ZA[ooooo6P00000Jooooo`/0dLfYCP00000:
0=7=ZB0000004?oooolO000000X0dLfYC`00000=0=7=Z@00303AcJU?0820P0X0dLfY6_oooolJ0000
01[ooooo2`3AcJU>000000X0dLfY8000000@oooooal000002P3AcJU?000000d0dLfY000<0=7=ZDl0
P8202P3AcJTJoooooaX000006_ooool;0=7=ZDh000002P3AcJTP0000013ooooo7`00000:0=7=ZDl0
00003@3AcJT000`0dLfYC`20P80:0=7=ZA[ooooo6P00000Jooooo`/0dLfYCP00000:0=7=ZB000000
4?oooolO000000X0dLfYC`00000=0=7=Z@00303AcJU?0820P0X0dLfY6_oooolJ000001[ooooo2`3A
cJU>000000X0dLfY8?ooool_000000X0dLfYC`00000=0=7=Z@00303AcJU?0820P0X0dLfY6_oooolJ
000001[ooooo2`3AcJU>000000X0dLfY8?ooool_000000X0dLfYC`00000=0=7=Z@00303AcJU?0820
P0X0dLfY6_oooolJ000001[ooooo2`3AcJU>000000X0dLfY8?ooool_000000X0dLfYC`00000=0=7=
Z@00303AcJU?0820P0X0dLfY6_oooolJ000001[ooooo2`3AcJU>000000X0dLfY8?ooool_000000X0
dLfYC`00000=0=7=Z@00303AcJU?0820P0X0dLfY6_oooolJ000001[ooooo2`3AcJU>000000X0dLfY
8?ooool_000000X0dLfYC`00000=0=7=Z@00303AcJU?0820P0X0dLfY6_oooolJ000001[ooooo2`3A
cJU>000000X0dLfY8?ooool_000000X0dLfYC`00000=0=7=Z@00303AcJU?0820P0X0dLfY6_oooolJ
000001[ooooo2`3AcJU>000000X0dLfY8?ooool_000000X0dLfYC`00000=0=7=Z@00303AcJU?0820
P0X0dLfY6_oooolJ000001[ooooo2`3AcJTC000002Sooooo4`00000:0=7=ZB3ooooo;`00000:0=7=
ZDl000003@3AcJT000`0dLfYC`20P80:0=7=ZA[ooooo6P00000Jooooo`/0dLfY4`00000Xoooooa<0
00002P3AcJTPooooobl000002P3AcJU?000000d0dLfY000<0=7=ZDl0P8202P3AcJTJoooooaX00000
6_ooool;0=7=ZA<00000:?oooolC000000X0dLfY8?ooool_000000X0dLfYC`00000=0=7=Z@00303A
cJU?0820P0X0dLfY6_oooolJ000001[ooooo2`3AcJTC000002Sooooo4`00000:0=7=ZB3ooooo;`00
000:0=7=ZDl000003@3AcJT000`0dLfYC`20P80:0=7=ZA[ooooo6P00000Jooooo`/0dLfY4`00000X
oooooa<000002P3AcJTPooooobl000002P3AcJU?000000d0dLfY000<0=7=ZDl0P8202P3AcJTJoooo
oaX000006_ooool;0=7=ZA<00000:?oooolC000000X0dLfY8?ooool_000000X0dLfYC`00000=0=7=
Z@00303AcJU?0820P0X0dLfY6_oooolJ000001[ooooo2`3AcJTC000002Sooooo4`00000:0=7=ZB3o
oooo;`00000:0=7=ZDl000003@3AcJT000`0dLfYC`20P80:0=7=ZA[ooooo6P00000Jooooo`/0dLfY
4`00000Xoooooa<000002P3AcJTPooooobl000002P3AcJU?000000d0dLfY000<0=7=ZDl0P8202P3A
cJTJoooooaX000006_ooool;0=7=ZA<00000:?oooolC000000X0dLfY4?ooool_0000013ooooo2P3A
cJU?000000d0dLfY000<0=7=ZDl0P8202P3AcJTJoooooaX000006_ooool;0=7=ZA<00000:?oooolC
000000X0dLfY4?ooool_0000013ooooo2P3AcJU?000000d0dLfY000<0=7=ZDl0P8202P3AcJTJoooo
oaX000006_ooool;0=7=ZA<00000:?oooolC000000X0dLfY4?ooool_0000013ooooo2P3AcJU?0000
00d0dLfY000<0=7=ZDl0P8202P3AcJTJoooooaX000006_ooool;0=7=ZA<00000:?oooolC000000X0
dLfY4?ooool_0000013ooooo2P3AcJU?000000d0dLfY000<0=7=ZDl0P8202P3AcJTJoooooaX00000
6_ooool;0=7=ZA<00000:?oooolC000000X0dLfY4?ooool_0000013ooooo2P3AcJU?000000d0dLfY
000<0=7=ZDl0P8202P3AcJTJ000001[ooooo6P00000;0=7=ZA<00000:?oooolC000000X0dLfY4?oo
ool_0000013ooooo2P3AcJT=ooooocD000003Oooool=0=7=Z@00303AcJU?0820P0X0dLfY6P00000J
oooooaX000002`3AcJTC000002Sooooo4`00000:0=7=ZA3ooooo;`00000@ooooo`X0dLfY3Ooooole
000000gooooo3@3AcJT000`0dLfYC`20P80:0=7=ZAX000006_oooolJ000000/0dLfY4`00000Xoooo
oa<000002P3AcJT@ooooobl000004?ooool:0=7=Z@gooooo=@00000=ooooo`d0dLfY000<0=7=ZDl0
P8202P3AcJTJ000001[ooooo6P00000;0=7=ZA<00000:?oooolC000000X0dLfY4?ooool_0000013o
oooo2P3AcJT=ooooocD000003Oooool=0=7=Z@00303AcJU?0820P0X0dLfY6P00000JoooooaX00000
2`3AcJTC000002Sooooo4`00000:0=7=ZA3ooooo;`00000@ooooo`X0dLfY3Ooooole000000gooooo
3@3AcJT000`0dLfYC`20P80:0=7=ZAX000006_oooolJ000000/0dLfY4`00000Xoooooa<000002P3A
cJT@ooooobl000004?ooool:0=7=Z@gooooo=@00000=ooooo`d0dLfY000<0=7=ZDl0P8202P3AcJTJ
000001[ooooo6P00000;0=7=ZDh000002P3AcJT@ooooobl000004?ooool:0=7=Z@gooooo=@00000=
ooooo`d0dLfY000<0=7=ZDl0P8202P3AcJTJ000001[ooooo6P00000;0=7=ZDh000002P3AcJT@oooo
obl000004?ooool:0=7=Z@gooooo=@00000=ooooo`d0dLfY000<0=7=ZDl0P8202P3AcJTJ000001[o
oooo6P00000;0=7=ZDh000002P3AcJT@ooooobl000004?ooool:0=7=Z@gooooo=@00000=ooooo`d0
dLfY000<0=7=ZDl0P8202P3AcJTJ000001[ooooo6P00000;0=7=ZDh000002P3AcJT@ooooobl00000
4?ooool:0=7=Z@gooooo=@00000=ooooo`d0dLfY000<0=7=ZDl0P8202P3AcJTJ000001[ooooo6P00
000;0=7=ZDh000002P3AcJT@ooooob0000003oooool@000000X0dLfY3Ooooole000000gooooo3@3A
cJT000`0dLfYC`20P80:0=7=ZAX000006_oooolJ000000/0dLfYCP00000:0=7=ZA3ooooo8000000?
oooooa0000002P3AcJT=ooooocD000003Oooool=0=7=Z@00303AcJU?0820P0X0dLfY6P00000Joooo
oaX000002`3AcJU>000000X0dLfY4?oooolP000000oooooo4000000:0=7=Z@gooooo=@00000=oooo
o`d0dLfY000<0=7=ZDl0P8202P3AcJTJ000001[ooooo6P00000;0=7=ZDh000002P3AcJT@ooooob00
00003oooool@000000X0dLfY3@00000>oooooaX000003Oooool=000000d0dLfY000<0=7=ZDl0P820
2P3AcJTJ000001[ooooo6P00000;0=7=ZDh000002P3AcJT@ooooob0000003oooool@000000X0dLfY
3@00000>oooooaX000003Oooool=000000d0dLfY000<0=7=ZDl0P8202P3AcJTJ000001[ooooo6P00
000;0=7=ZDh000002P3AcJT@ooooob0000003oooool@000000X0dLfY3@00000>oooooaX000003Ooo
ool=000000d0dLfY000<0=7=ZDl0P8202P3AcJTJ000001[ooooo6P00000;0=7=ZDh000002P3AcJT@
ooooob0000003oooool@000000X0dLfY3@00000>oooooaX000003Oooool=000000d0dLfY000<0=7=
ZDl0P8202P3AcJTJ000001[ooooo6P00000;0=7=ZDh000002P3AcJT@ooooob0000003oooool@0000
00X0dLfY3@00000>oooooaX000003Oooool=000000d0dLfY000<0=7=ZDl0P8202P3AcJTJ000001[o
oooo6P00000;0=7=ZDh000002P3AcJT@ooooob0000003oooool@000000X0dLfY3@00000>oooooaX0
00003Oooool=000000d0dLfY000<0=7=ZDl0P8202P3AcJTJ000001[ooooo6P00000;0=7=ZDh00000
2P3AcJT@ooooob0000003oooool@000000X0dLfY3@00000>oooooaX000003Oooool=000000d0dLfY
000<0=7=ZDl0P8202P3AcJTJ000001[ooooo6P00000;0=7=ZDh000002P3AcJT@ooooob0000003ooo
ool@000000X0dLfY3@00000>oooooaX000003Oooool=000000d0dLfY000<0=7=ZDl0P8202P3AcJTJ
000001[ooooo6P00000;0=7=ZDh000002P3AcJT@ooooob0000003oooool@000000X0dLfY3@00000>
oooooaX000003Oooool=000000d0dLfY000<0=7=ZDl0P8202P3AcJTJ000001[ooooo6P00000;0=7=
ZDh000002P3AcJT@ooooob0000003oooool@000000X0dLfY3@00000>oooooaX000003Oooool=0000
00d0dLfY000<0=7=ZDl0P8202P3AcJTJ000001[ooooo6P00000;0=7=ZDh000002P3AcJT@ooooob00
00003oooool@000000X0dLfY3@00000>oooooaX000003Oooool=000000d0dLfY000<0=7=ZDl0P820
2P3AcJTJ000001[ooooo6P00000;0=7=ZDh000002P3AcJT@ooooob0000003oooool@000000X0dLfY
3@00000>oooooaX000003Oooool=000000d0dLfY000<0=7=ZDl0P8202P3AcJTJ000001[ooooo6P00
000;0=7=ZDh000002P3AcJT@ooooob0000003oooool@000000X0dLfY3@00000>oooooaX000003Ooo
ool=000000d0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY
003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY
003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY
003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY
003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY003o0=7=ZL`0dLfY
0000\
\>"],
  ImageRangeCache->{{{0, 458}, {925.375, 0}} -> {-0.125026, -0.257486, \
0.011463, 0.011463}, {{10.875, 91.625}, {902.875, 822.125}} -> {-7.52321, \
-14.5602, 0.60533, 0.60533}, {{99.75, 180.5}, {902.875, 822.125}} -> \
{-62.6266, -14.87, 0.618209, 0.618209}, {{188.563, 269.375}, {902.875, \
822.125}} -> {-120, -15.1798, 0.631091, 0.631091}, {{277.438, 358.188}, \
{902.875, 822.125}} -> {-179.661, -15.4895, 0.643968, 0.643968}, {{366.313, \
447.063}, {902.875, 822.125}} -> {-241.632, -15.7994, 0.656848, 0.656848}, \
{{10.875, 91.625}, {814, 733.25}} -> {-6.72287, -61.0867, 0.540934, \
0.540934}, {{99.75, 180.5}, {814, 733.25}} -> {-56.103, -62.5411, 0.553813, \
0.553813}, {{188.563, 269.375}, {814, 733.25}} -> {-107.755, -63.9958, \
0.566694, 0.566694}, {{277.438, 358.188}, {814, 733.25}} -> {-161.696, \
-65.4502, 0.579573, 0.579573}, {{366.313, 447.063}, {814, 733.25}} -> \
{-217.943, -66.9046, 0.592452, 0.592452}, {{10.875, 91.625}, {725.188, \
644.375}} -> {-5.92254, -96.152, 0.476538, 0.476538}, {{99.75, 180.5}, \
{725.188, 644.375}} -> {-49.5796, -98.7508, 0.489417, 0.489417}, {{188.563, \
269.375}, {725.188, 644.375}} -> {-95.4213, -101.256, 0.501908, 0.501908}, \
{{277.438, 358.188}, {725.188, 644.375}} -> {-143.729, -103.948, 0.515175, \
0.515175}, {{366.313, 447.063}, {725.188, 644.375}} -> {-194.253, -106.546, \
0.528054, 0.528054}, {{10.875, 91.625}, {636.313, 555.563}} -> {-5.12219, \
-119.774, 0.41214, 0.41214}, {{99.75, 180.5}, {636.313, 555.563}} -> \
{-43.0559, -123.518, 0.42502, 0.42502}, {{188.563, 269.375}, {636.313, \
555.563}} -> {-83.2653, -127.261, 0.4379, 0.4379}, {{277.438, 358.188}, \
{636.313, 555.563}} -> {-125.763, -131.003, 0.450779, 0.450779}, {{366.313, \
447.063}, {636.313, 555.563}} -> {-170.564, -134.746, 0.463658, 0.463658}, \
{{10.875, 91.625}, {547.5, 466.688}} -> {-4.32186, -131.955, 0.347744, \
0.347744}, {{99.75, 180.5}, {547.5, 466.688}} -> {-36.5322, -136.842, \
0.360622, 0.360622}, {{188.563, 269.375}, {547.5, 466.688}} -> {-70.9542, \
-141.608, 0.373213, 0.373213}, {{277.438, 358.188}, {547.5, 466.688}} -> \
{-107.797, -146.616, 0.386381, 0.386381}, {{366.313, 447.063}, {547.5, \
466.688}} -> {-146.874, -151.503, 0.399261, 0.399261}, {{10.875, 91.625}, \
{458.625, 377.875}} -> {-3.52151, -132.692, 0.283346, 0.283346}, {{99.75, \
180.5}, {458.625, 377.875}} -> {-30.0087, -138.724, 0.296226, 0.296226}, \
{{188.563, 269.375}, {458.625, 377.875}} -> {-58.7754, -144.755, 0.309105, \
0.309105}, {{277.438, 358.188}, {458.625, 377.875}} -> {-89.8308, -150.787, \
0.321985, 0.321985}, {{366.313, 447.063}, {458.625, 377.875}} -> {-123.185, \
-156.818, 0.334864, 0.334864}, {{10.875, 91.625}, {369.75, 289}} -> \
{-2.72116, -121.994, 0.218949, 0.218949}, {{99.75, 180.5}, {369.75, 289}} -> \
{-23.485, -129.17, 0.231829, 0.231829}, {{188.563, 269.375}, {369.75, 289}} -> \
{-46.5305, -136.346, 0.244708, 0.244708}, {{277.438, 358.188}, {369.75, 289}} -> \
{-71.8646, -143.522, 0.257588, 0.257588}, {{366.313, 447.063}, {369.75, 289}} -> \
{-99.4957, -150.699, 0.270467, 0.270467}, {{10.875, 91.625}, {280.938, \
200.125}} -> {-1.92082, -99.8444, 0.154553, 0.154553}, {{99.75, 180.5}, \
{280.938, 200.125}} -> {-16.9614, -108.165, 0.167432, 0.167432}, {{188.563, \
269.375}, {280.938, 200.125}} -> {-34.2538, -116.39, 0.180172, 0.180172}, \
{{277.438, 358.188}, {280.938, 200.125}} -> {-53.8984, -124.805, 0.193191, \
0.193191}, {{366.313, 447.063}, {280.938, 200.125}} -> {-75.8061, -133.126, \
0.20607, 0.20607}, {{10.875, 91.625}, {192.063, 111.313}} -> {-1.12048, \
-66.2522, 0.0901555, 0.0901555}, {{99.75, 180.5}, {192.063, 111.313}} -> \
{-10.4378, -75.7172, 0.103035, 0.103035}, {{188.563, 269.375}, {192.063, \
111.313}} -> {-22.0407, -85.1813, 0.115914, 0.115914}, {{277.438, 358.188}, \
{192.063, 111.313}} -> {-35.9323, -94.6462, 0.128794, 0.128794}, {{366.313, \
447.063}, {192.063, 111.313}} -> {-52.1167, -104.111, 0.141673, 0.141673}, \
{{10.875, 91.625}, {103.188, 22.4375}} -> {-0.320137, -21.2186, 0.0257588, \
0.0257588}, {{99.75, 180.5}, {103.188, 22.4375}} -> {-3.91417, -31.8278, \
0.0386381, 0.0386381}, {{188.563, 269.375}, {103.188, 22.4375}} -> {-9.79589, \
-42.437, 0.0515175, 0.0515175}, {{277.438, 358.188}, {103.188, 22.4375}} -> \
{-17.9661, -53.0463, 0.0643968, 0.0643968}, {{366.313, 447.063}, {103.188, \
22.4375}} -> {-28.4274, -63.6558, 0.0772765, 0.0772765}}]
}, Open  ]],

Cell["\<\
Note that a solution for the 6x6 grid is contained in the solution to the 8x8 \
grid. Note also that not all display central symmetry or even bilateral \
symmetry. As expected, some prime number order display this lack of symmetry \
but other behave in a uniform fashion. We include the data above in file \
allOnes4.\
\>", "Text"],

Cell[CellGroupData[{

Cell["TOROIDAL DOMAINS", "Subsection"],

Cell["\<\
Consider the All-Ones problem on a toroidal boundary. Most of the solutions \
require touching all squares and are omitted from the graphical output but \
accounted for in the list allOnes below.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(wrap[i_, n_] := 
      Which[i > n, 1, i < 1, n, True, i]\[IndentingNewLine]\), "\n", 
    \(\(ans4 = {};\)\), "\n", 
    \(\(allOnes = {};\)\), "\n", 
    \(\(Do[\[IndentingNewLine]A = 
          Table[0, {n\^2}, {n\^2}]; \[IndentingNewLine]Do[
          i = 1 + \[LeftFloor]\(r - 1\)\/n\[RightFloor]; \[IndentingNewLine]j \
= r - \((i - 1)\) n; \[IndentingNewLine]neigh = {{i, wrap[j - 1, n]}, {i, 
                j}, {i, wrap[j + 1, n]}, {wrap[i - 1, n], 
                j}, {wrap[i + 1, n], 
                j}}; \[IndentingNewLine]\(\((A\[LeftDoubleBracket]
                    r, #\[RightDoubleBracket] = 
                  1)\) &\)\  /@ \ \((\(\((\((First[#] - 1)\) n + 
                      Last[#])\) &\)\  /@ \ neigh)\), {r, 
            n\^2}]; \[IndentingNewLine]\[IndentingNewLine]X = 
          LinearSolve[A, Table[1, {n\^2}], 
            Modulus \[Rule] 
              2]; \[IndentingNewLine]sol = \({i = 
                  1 + \[LeftFloor]\(# - 1\)\/n\[RightFloor], # - \((i - 1)\) 
                    n} &\)\  /@ \ 
            Flatten[Position[X, 1]]; \[IndentingNewLine]B = 
          Table[0, {n}, {n}]; \[IndentingNewLine]\(\((B\[LeftDoubleBracket]
                  First[#], Last[#]\[RightDoubleBracket] = 1)\) &\)\  /@ \ 
          sol; \[IndentingNewLine]If[\((Plus\  @@ \ Flatten[B])\) \[Equal] 
            n\^2, AppendTo[allOnes, n], \[IndentingNewLine]AppendTo[ans4, 
            ListDensityPlot[Reverse[\(-B\)]\ , FrameTicks \[Rule] None, 
              Frame \[Rule] False, Mesh \[Rule] False, 
              AspectRatio \[Rule] Automatic, 
              DisplayFunction \[Rule] Identity, 
              PlotLabel \[Rule] ToString[n]]]], {n, 2, 51}];\)\), "\n", 
    \(Length[ans4]\), "\n", 
    \(\(Show[GraphicsArray[Partition[ans4, 5]]];\)\), "\n", 
    \(allOnes\)}], "Input"],

Cell[BoxData[
    \(27\)], "Output",
  CellLabel->"Out[121]="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0238095 0.190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.200176 0.200176 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0246548 0.0192308 0.0246548 [
[.5 1.0125 -8 0 ]
[.5 1.0125 8 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(39) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
39 string
39 39 8 [39 0 0 39 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.0238095 0.39418 0.200176 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[.5 1.0125 -8 0 ]
[.5 1.0125 8 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF
FF000000000000FFFF000000000000000000000000000000000000000000000000000000
000000FF
00FF00000000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF
FFFFFF0000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000
000000FFFF000000000000FF000000000000000000000000000000000000000000000000
FF000000
FFFF00000000FFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF0000
0000FFFFFFFF0000FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FFFFFF
000000FFFF00000000FFFF00FFFFFF000000000000000000000000000000000000FFFFFF
00FFFF00
000000FFFF00000000FFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
00FFFF00
0000FFFFFFFF0000FFFFFF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF
00FFFFFF
FFFF00000000FFFF0000FF0000FF00FF00FF000000000000000000000000FF00FF00FF00
00FF0000
000000FFFF000000000000FF00FFFFFF000000FFFFFFFFFFFFFFFFFFFF000000FFFFFF00
FF000000
FFFFFF0000FFFFFF000000FF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFF00
FF000000
00FF00000000FF00FF00FF0000FF0000FFFF00FFFF000000000000FFFF00FFFF0000FF00
00FF00FF
FF000000000000FFFF00FF00FF000000FFFFFF00FF00FFFFFFFF00FF00FFFFFF000000FF
00FF00FF
0000000000000000FF000000FF0000FFFF0000FF000000FFFF000000FF0000FFFF0000FF
000000FF
000000000000000000FFFFFF00FFFF00FF0000FF000000FFFF000000FF0000FF00FFFF00
FFFFFF00
00000000000000000000FF00FF0000FF00FFFF00FF00FFFFFFFF00FF00FFFF00FF0000FF
00FF0000
0000000000000000000000FFFF0000FFFF0000FFFF000000000000FFFF0000FFFF0000FF
FF000000
000000000000000000000000FFFFFFFF00000000FFFFFFFFFFFFFFFF00000000FFFFFFFF
00000000
000000000000000000000000FFFFFFFF00000000FFFFFFFFFFFFFFFF00000000FFFFFFFF
00000000
0000000000000000000000FFFF0000FFFF0000FFFF000000000000FFFF0000FFFF0000FF
FF000000
00000000000000000000FF00FF0000FF00FFFF00FF00FFFFFFFF00FF00FFFF00FF0000FF
00FF0000
000000000000000000FFFFFF00FFFF00FF0000FF000000FFFF000000FF0000FF00FFFF00
FFFFFF00
0000000000000000FF000000FF0000FFFF0000FF000000FFFF000000FF0000FFFF0000FF
000000FF
FF000000000000FFFF00FF00FF000000FFFFFF00FF00FFFFFFFF00FF00FFFFFF000000FF
00FF00FF
00FF00000000FF00FF00FF0000FF0000FFFF00FFFF000000000000FFFF00FFFF0000FF00
00FF00FF
FFFFFF0000FFFFFF000000FF00FFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFF00
FF000000
000000FFFF000000000000FF00FFFFFF000000FFFFFFFFFFFFFFFFFFFF000000FFFFFF00
FF000000
FFFF00000000FFFF0000FF0000FF00FF00FF000000000000000000000000FF00FF00FF00
00FF0000
0000FFFFFFFF0000FFFFFF00FF00FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FF
00FFFFFF
000000FFFF00000000FFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
00FFFF00
000000FFFF00000000FFFF00FFFFFF000000000000000000000000000000000000FFFFFF
00FFFF00
0000FFFFFFFF0000FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
00FFFFFF
FFFF00000000FFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF0000
000000FFFF000000000000FF000000000000000000000000000000000000000000000000
FF000000
FFFFFF0000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000
00FF00000000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF
FF000000000000FFFF000000000000000000000000000000000000000000000000000000
000000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.0238095 0.588183 0.200176 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0228938 0.0192308 0.0228938 [
[.5 1.0125 -8 0 ]
[.5 1.0125 8 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(42) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
42 string
42 42 8 [42 0 0 42 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.0238095 0.782187 0.200176 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0213675 0.0192308 0.0213675 [
[.5 1.0125 -8 0 ]
[.5 1.0125 8 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
45 string
45 45 8 [45 0 0 45 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.0238095 0.97619 0.200176 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0200321 0.0192308 0.0200321 [
[.5 1.0125 -8 0 ]
[.5 1.0125 8 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(48) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
48 string
48 48 8 [48 0 0 48 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.217813 0.200176 0.39418 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0310174 0.0192308 0.0310174 [
[.5 1.0125 -8 0 ]
[.5 1.0125 8 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(31) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
31 string
31 31 8 [31 0 0 31 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF0000FF00FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF0000FF00FF0000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFF000000FFFF0000FF000000000000000000000000000000000000FF
FF000000000000000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFF000000FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FFFFFF00FF00FF00FFFFFF00FFFFFF000000000000000000000000FFFFFF00
FF00FFFFFF00FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFF00
00FFFFFFFF00FFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFF0000FF00FF00
00000000FF00FF00000000FF00FF00FF00FF000000000000FF00FF00FF00FF
FFFFFF0000000000FFFFFFFFFFFFFFFF000000FFFFFFFF000000FFFFFFFFFF
FFFF00FFFF00FFFF00FFFF00FF00FFFFFFFFFF00FFFF00FFFFFFFFFF00FF00
FFFFFF0000000000FFFFFFFF00FFFF00FFFF00FFFFFFFF00FFFF00FFFF00FF
00000000FF00FF0000000000FF00FFFFFFFFFF00000000FFFFFFFFFF00FF00
FFFFFFFFFF00FFFFFFFFFF00FFFFFFFF00000000FFFF00000000FFFFFFFF00
00FFFFFFFF00FFFFFFFF0000FFFF00FF00FFFFFF0000FFFFFF00FF00FFFF00
00FF0000FF00FF0000FF00FFFFFFFF000000FF00000000FF000000FFFFFFFF
00000000000000000000000000000000000000000000000000000000000000
00FF0000FF00FF0000FF00FFFFFFFF000000FF00000000FF000000FFFFFFFF
00FFFFFFFF00FFFFFFFF0000FFFF00FF00FFFFFF0000FFFFFF00FF00FFFF00
FFFFFFFFFF00FFFFFFFFFF00FFFFFFFF00000000FFFF00000000FFFFFFFF00
00000000FF00FF0000000000FF00FFFFFFFFFF00000000FFFFFFFFFF00FF00
FFFFFF0000000000FFFFFFFF00FFFF00FFFF00FFFFFFFF00FFFF00FFFF00FF
FFFF00FFFF00FFFF00FFFF00FF00FFFFFFFFFF00FFFF00FFFFFFFFFF00FF00
FFFFFF0000000000FFFFFFFFFFFFFFFF000000FFFFFFFF000000FFFFFFFFFF
00000000FF00FF00000000FF00FF00FF00FF000000000000FF00FF00FF00FF
00FFFFFFFF00FFFFFFFF0000FF00FF0000FFFFFFFFFFFFFFFF0000FF00FF00
FF00FFFFFF00FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFF00FFFFFF00
FFFFFF00FF00FF00FFFFFF00FFFFFF000000000000000000000000FFFFFF00
FFFFFFFF000000FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00
FF000000000000000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFF000000FFFF0000FF000000000000000000000000000000000000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.217813 0.39418 0.39418 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0291375 0.0192308 0.0291375 [
[.5 1.0125 -8 0 ]
[.5 1.0125 8 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(33) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
33 string
33 33 8 [33 0 0 33 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.217813 0.588183 0.39418 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0282805 0.0192308 0.0282805 [
[.5 1.0125 -8 0 ]
[.5 1.0125 8 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(34) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
34 string
34 34 8 [34 0 0 34 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.217813 0.782187 0.39418 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0274725 0.0192308 0.0274725 [
[.5 1.0125 -8 0 ]
[.5 1.0125 8 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(35) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
35 string
35 35 8 [35 0 0 35 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.217813 0.97619 0.39418 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0267094 0.0192308 0.0267094 [
[.5 1.0125 -8 0 ]
[.5 1.0125 8 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(36) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
36 string
36 36 8 [36 0 0 36 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.411817 0.200176 0.588183 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0457875 0.0192308 0.0457875 [
[.5 1.0125 -8 0 ]
[.5 1.0125 8 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
21 string
21 21 8 [21 0 0 21 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.411817 0.39418 0.588183 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0400641 0.0192308 0.0400641 [
[.5 1.0125 -8 0 ]
[.5 1.0125 8 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
24 string
24 24 8 [24 0 0 24 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.411817 0.588183 0.588183 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0384615 0.0192308 0.0384615 [
[.5 1.0125 -8 0 ]
[.5 1.0125 8 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
25 string
25 25 8 [25 0 0 25 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFF
00FFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFF
00FF0000FF00FF0000FF00FF0000FF00FF0000FF00FF0000FF
00000000000000000000000000000000000000000000000000
00FF0000FF00FF0000FF00FF0000FF00FF0000FF00FF0000FF
00FFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFF
00FFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFF
00FF0000FF00FF0000FF00FF0000FF00FF0000FF00FF0000FF
00000000000000000000000000000000000000000000000000
00FF0000FF00FF0000FF00FF0000FF00FF0000FF00FF0000FF
00FFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFF
00FFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFF
00FF0000FF00FF0000FF00FF0000FF00FF0000FF00FF0000FF
00000000000000000000000000000000000000000000000000
00FF0000FF00FF0000FF00FF0000FF00FF0000FF00FF0000FF
00FFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFF
00FFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFF
00FF0000FF00FF0000FF00FF0000FF00FF0000FF00FF0000FF
00000000000000000000000000000000000000000000000000
00FF0000FF00FF0000FF00FF0000FF00FF0000FF00FF0000FF
00FFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFF
00FFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFF
00FF0000FF00FF0000FF00FF0000FF00FF0000FF00FF0000FF
00000000000000000000000000000000000000000000000000
00FF0000FF00FF0000FF00FF0000FF00FF0000FF00FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.411817 0.782187 0.588183 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0356125 0.0192308 0.0356125 [
[.5 1.0125 -8 0 ]
[.5 1.0125 8 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(27) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
27 string
27 27 8 [27 0 0 27 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.411817 0.97619 0.588183 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0320513 0.0192308 0.0320513 [
[.5 1.0125 -8 0 ]
[.5 1.0125 8 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
30 string
30 30 8 [30 0 0 30 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.60582 0.200176 0.782187 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0801282 0.0192308 0.0801282 [
[.5 1.0125 -8 0 ]
[.5 1.0125 8 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
12 string
12 12 8 [12 0 0 12 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.60582 0.39418 0.782187 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0641026 0.0192308 0.0641026 [
[.5 1.0125 -8 0 ]
[.5 1.0125 8 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
15 string
15 15 8 [15 0 0 15 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.60582 0.588183 0.782187 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0565611 0.0192308 0.0565611 [
[.5 1.0125 -8 0 ]
[.5 1.0125 8 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(17) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
17 string
17 17 8 [17 0 0 17 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000FF00FF000000FFFFFFFFFFFFFFFF
000000FF00FF000000FFFFFFFFFFFFFFFF
FF00FF000000FF00FFFF000000000000FF
0000FF000000FF0000FF00FFFFFFFF00FF
00FF00FF00FF00FF00000000FFFF000000
FFFFFFFF00FFFFFFFFFF0000FFFF0000FF
FF00FFFF00FFFF00FF00FFFFFFFFFFFF00
00FFFFFF00FFFFFF00FF00FF0000FF00FF
FF0000FF00FF0000FFFFFF00000000FFFF
0000000000000000000000000000000000
FF0000FF00FF0000FFFFFF00000000FFFF
00FFFFFF00FFFFFF00FF00FF0000FF00FF
FF00FFFF00FFFF00FF00FFFFFFFFFFFF00
FFFFFFFF00FFFFFFFFFF0000FFFF0000FF
00FF00FF00FF00FF00000000FFFF000000
0000FF000000FF0000FF00FFFFFFFF00FF
FF00FF000000FF00FFFF000000000000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.60582 0.782187 0.782187 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0534188 0.0192308 0.0534188 [
[.5 1.0125 -8 0 ]
[.5 1.0125 8 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(18) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
18 string
18 18 8 [18 0 0 18 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.60582 0.97619 0.782187 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0480769 0.0192308 0.0480769 [
[.5 1.0125 -8 0 ]
[.5 1.0125 8 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
20 string
20 20 8 [20 0 0 20 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFF0000000000000000000000000000FF
00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF00FF
FF0000FF000000FFFFFFFFFFFFFFFFFFFF000000
FF0000FF000000FF0000000000000000FF000000
00FFFF00FF00FF0000FFFFFFFFFFFF0000FF00FF
FF0000FFFF00FF00FF00FFFFFFFF00FF00FF00FF
00000000FF000000FFFFFF0000FFFFFF000000FF
0000000000FFFFFFFFFFFF0000FFFFFFFFFFFF00
000000000000FFFF0000FFFFFFFF0000FFFF0000
000000000000FFFF0000FFFFFFFF0000FFFF0000
0000000000FFFFFFFFFFFF0000FFFFFFFFFFFF00
00000000FF000000FFFFFF0000FFFFFF000000FF
FF0000FFFF00FF00FF00FFFFFFFF00FF00FF00FF
00FFFF00FF00FF0000FFFFFFFFFFFF0000FF00FF
FF0000FF000000FF0000000000000000FF000000
FF0000FF000000FFFFFFFFFFFFFFFFFFFF000000
00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFF00FF
FF0000FFFF0000000000000000000000000000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.799824 0.200176 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.320513 0.0192308 0.320513 [
[.5 1.0125 -5 0 ]
[.5 1.0125 5 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
3 string
3 3 8 [3 0 0 3 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFF
FFFFFF
000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.799824 0.39418 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.192308 0.0192308 0.192308 [
[.5 1.0125 -5 0 ]
[.5 1.0125 5 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
5 string
5 5 8 [5 0 0 5 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFFFFFF
00FFFFFFFF
00FF0000FF
0000000000
00FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.799824 0.588183 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.160256 0.0192308 0.160256 [
[.5 1.0125 -5 0 ]
[.5 1.0125 5 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
6 string
6 6 8 [6 0 0 6 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFF
FFFFFFFFFFFF
000000000000
FFFFFFFFFFFF
FFFFFFFFFFFF
000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.799824 0.782187 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.106838 0.0192308 0.106838 [
[.5 1.0125 -5 0 ]
[.5 1.0125 5 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
9 string
9 9 8 [9 0 0 9 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.799824 0.97619 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0961538 0.0192308 0.0961538 [
[.5 1.0125 -8 0 ]
[.5 1.0125 8 12.875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
10 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFF
FFFFFF000000000000FF
FFFFFF00FFFFFFFF00FF
0000FF0000FFFF0000FF
000000FF00FFFF00FF00
000000FF00FFFF00FF00
0000FF0000FFFF0000FF
FFFFFF00FFFFFFFF00FF
FFFFFF000000000000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{531.875, 531.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008C00024b000`400?l00000o`00003oo`3AcJWo
0=7=ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY
003o0=7=ZOl0dLfY5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0
dLfY5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT0
0?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT00?l0dLfYo`3A
cJTE0=7=Z@005@3AcJU<0?oooa/0dLfY3`00000m0?oooa/0dLfYC03ooolK0=7=ZD`0oooo6`3AcJU<
0?oooaH0dLfY000E0=7=ZD`0oooo6`3AcJT?000003d0oooo6`3AcJU<0?oooa/0dLfYC03ooolK0=7=
ZD`0oooo5P3AcJT001D0dLfYC03ooolK0=7=Z@l00000?@3ooolK0=7=ZD`0oooo6`3AcJU<0?oooa/0
dLfYC03ooolF0=7=Z@005@3AcJU<0?oooa/0dLfY3`00000m0?oooa/0dLfYC03ooolK0=7=ZD`00000
6`3AcJU<000001H0dLfY000E0=7=ZD`000006`3AcJT20?ooo`/00000103oooli00000080oooo6`3A
cJU<000001/0dLfYC000000K0=7=ZD`000005P3AcJT001D0dLfYC000000K0=7=Z@80oooo2`000004
0?ooocT000000P3ooolK0=7=ZD`000006`3AcJU<0?oooa/0dLfYC03ooolF0=7=Z@005@3AcJU<0?oo
oa/0dLfY0P0000020?ooo`L000000P3oool200000080oooo0P00000e0?ooo`8000000P3ooolK0=7=
ZD`0oooo6`3AcJU<0?oooa/0dLfYC03ooolF0=7=Z@005@3AcJU<0?oooa/0dLfY0P0000020?ooo`L0
00000P3oool200000080oooo0P00000e0?ooo`8000000P3ooolK0=7=ZD`0oooo6`3AcJU<0?oooa/0
dLfYC03ooolF0=7=Z@005@3AcJU<0?oooa/0dLfY1P3oool4000000D0oooo1P00000a0?ooo`H00000
6`3AcJU<0?oooa/0dLfYC03ooolK0=7=ZD`000005P3AcJT001D0dLfYC03ooolK0=7=Z@H0oooo1000
00050?ooo`H00000<@3oool6000001/0dLfYC000000K0=7=ZD`000006`3AcJU<000001H0dLfY000E
0=7=ZD`000006`3AcJT6000000@0oooo2`0000020?ooobd000000P3oool6000001/0dLfYC000000K
0=7=ZD`0oooo6`3AcJU<0?oooaH0dLfY000E0=7=ZD`000006`3AcJT6000000@0oooo2`0000020?oo
obd000000P3oool6000001/0dLfYC03ooolK0=7=ZD`0oooo6`3AcJU<0?oooaH0dLfY000E0=7=ZD`0
oooo6`3AcJT40?ooo`L00000103oool400000080oooo1000000Z0?ooo`<000000P3oool4000001/0
dLfYC03ooolK0=7=ZD`0oooo6`3AcJU<0?oooaH0dLfY000E0=7=ZD`0oooo6`3AcJT4000000L0oooo
100000060?ooo`8000000P3oool2000002H0oooo0P0000000`3oool00000000000060?oooa/0dLfY
C03ooolK0=7=ZD`0oooo6`3AcJU<000001H0dLfY000E0=7=ZD`0oooo6`3AcJT4000000L0oooo1000
00060?ooo`8000000P3oool2000002H0oooo0P0000000`3oool00000000000060?oooa/0dLfYC03o
oolK0=7=ZD`000006`3AcJU<0?oooaH0dLfY000E0=7=ZD`0oooo6`3AcJT6000000@0oooo1`000004
0?ooo`8000001P3ooolR000000D0oooo0P0000040?ooo`8000006`3AcJU<000001/0dLfYC03ooolK
0=7=ZD`0oooo5P3AcJT001D0dLfYC000000K0=7=Z@H00000103oool7000000@0oooo0P0000060?oo
ob8000001@3oool2000000@0oooo0P00000K0=7=ZD`000006`3AcJU<0?oooa/0dLfYC03ooolF0=7=
Z@005@3AcJU<000001/0dLfY1P0000040?ooo`L00000103oool2000000H0oooo00<000000?ooo`3o
ool07@3oool2000000D0oooo0P0000040?ooo`8000006`3AcJU<0?oooa/0dLfYC03ooolK0=7=ZD`0
oooo5P3AcJT001D0dLfYC03ooolK0=7=Z@H00000103oool7000000@0oooo0P0000060?ooo`030000
003oool0oooo01d0oooo0P0000050?ooo`800000103oool2000001/0dLfYC03ooolK0=7=ZD`0oooo
6`3AcJU<000001H0dLfY000E0=7=ZD`0oooo6`3AcJT4000000L0oooo100000060?ooo`8000000P3o
ool200000080oooo0`00000K0?ooo`@000000P3oool2000000030?ooo`000000000000H0oooo6`3A
cJU<0?oooa/0dLfYC000000K0=7=ZD`0oooo5P3AcJT001D0dLfYC03ooolK0=7=Z@@000001`3oool4
000000H0oooo0P0000020?ooo`8000000P3oool3000001/0oooo100000020?ooo`80000000<0oooo
0000000000001P3ooolK0=7=ZD`000006`3AcJU<000001/0dLfYC03ooolF0=7=Z@005@3AcJU<0?oo
oa/0dLfY103oool7000000@0oooo100000020?ooo`@000000P3oool2000000030?ooo`0000000000
0080oooo5`0000020?ooo`8000000P3oool200000080oooo0`0000020?ooo`@000006`3AcJU<0000
01/0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfYC000000K0=7=Z@@0oooo1`0000040?ooo`@0
00000P3oool400000080oooo0P0000000`3oool00000000000020?oooaL000000P3oool200000080
oooo0P0000020?ooo`<000000P3oool4000001/0dLfYC03ooolK0=7=ZD`0oooo6`3AcJU<000001H0
dLfY000E0=7=ZD`000006`3AcJT6000000@0oooo2`0000020?ooo`8000001@3oool6000001<0oooo
1P0000060?ooo`030000003oool0oooo00H000006`3AcJU<0?oooa/0dLfYC03ooolK0=7=ZD`00000
5P3AcJT001D0dLfYC03ooolK0=7=Z@H00000103oool;00000080oooo0P0000050?ooo`H000004`3o
ool6000000H0oooo00<000000?ooo`3oool01P00000K0=7=ZD`0oooo6`3AcJU<000001/0dLfYC03o
oolF0=7=Z@005@3AcJU<0?oooa/0dLfY1P3oool4000000D0oooo1P0000020?ooo`8000002`3oool2
000000l0oooo0P00000<0?ooo`030000003oool0oooo00H000006`3AcJU<0?oooa/0dLfYC000000K
0=7=ZD`0oooo5P3AcJT001D0dLfYC03ooolK0=7=Z@H0oooo100000050?ooo`H000000P3oool20000
00/0oooo0P00000?0?ooo`800000303oool00`000000oooo0?ooo`06000001/0dLfYC000000K0=7=
ZD`0oooo6`3AcJU<0?oooaH0dLfY000E0=7=ZD`0oooo6`3AcJT200000080oooo1`0000020?ooo`80
00000P3oool200000080oooo100000020?ooo`<00000103oool2000000@0oooo2`0000040?ooo`80
0000103oool400000080oooo0`0000020?ooo`8000000P3ooolK0=7=ZD`000006`3AcJU<0?oooa/0
dLfYC000000F0=7=Z@005@3AcJU<000001/0dLfY0P0000020?ooo`L000000P3oool200000080oooo
0P0000020?ooo`@000000P3oool3000000@0oooo0P0000040?ooo`/00000103oool2000000@0oooo
100000020?ooo`<000000P3oool200000080oooo6`3AcJU<0?oooa/0dLfYC03ooolK0=7=ZD`00000
5P3AcJT001D0dLfYC000000K0=7=Z@80oooo2`0000040?ooo`8000000P3oool200000080oooo1@00
00060?ooo`8000000P3oool2000000L0oooo0P0000020?ooo`8000001P3oool6000000030?ooo`00
000000000080oooo0P0000020?oooa/0dLfYC03ooolK0=7=ZD`000006`3AcJU<0?oooaH0dLfY000E
0=7=ZD`0oooo6`3AcJT20?ooo`/00000103oool200000080oooo0P0000020?ooo`D000001P3oool2
00000080oooo0P0000070?ooo`8000000P3oool2000000H0oooo1P0000000`3oool0000000000002
0?ooo`8000000P3ooolK0=7=ZD`0oooo6`3AcJU<000001/0dLfYC03ooolF0=7=Z@005@3AcJU<0?oo
oa/0dLfY3`0000020?ooo`H000000P3oool4000000<0oooo100000020?ooo`H00000103oool50000
0080oooo100000040?ooo`@0000000<0oooo000000000000100000020?oooa/0dLfYC000000K0=7=
ZD`0oooo6`3AcJU<0?oooaH0dLfY000E0=7=ZD`0oooo6`3AcJT?00000080oooo1P0000020?ooo`@0
00000`3oool400000080oooo1P0000040?ooo`D000000P3oool4000000@0oooo100000000`3oool0
00000000000400000080oooo6`3AcJU<000001/0dLfYC03ooolK0=7=ZD`000005P3AcJT001D0dLfY
C03ooolK0=7=ZA4000001P3oool2000000@0oooo00<000000?ooo`3oool0100000020?ooo`H00000
103oool500000080oooo100000020?ooo`800000103oool00`000000oooo0?ooo`040?ooo`800000
6`3AcJU<0?oooa/0dLfYC03ooolK0=7=ZD`000005P3AcJT001D0dLfYC000000K0=7=ZA4000001P3o
ool2000000@0oooo00<000000?ooo`3oool0100000020?ooo`H00000103oool500000080oooo1000
00020?ooo`800000103oool00`000000oooo0?ooo`040?ooo`8000006`3AcJU<0?oooa/0dLfYC000
000K0=7=ZD`0oooo5P3AcJT001D0dLfYC000000K0=7=ZA<000000P3oool200000080oooo10000000
0`3oool00000000000040?ooo`8000000P3oool2000000L0oooo0P0000020?ooo`800000103oool2
00000080oooo100000000`3oool00000000000020?ooo`@000006`3AcJU<0?oooa/0dLfYC000000K
0=7=ZD`0oooo5P3AcJT001D0dLfYC03ooolK0=7=ZA<000000P3oool200000080oooo100000000`3o
ool00000000000040?ooo`8000000P3oool2000000L0oooo0P0000020?ooo`800000103oool20000
0080oooo100000000`3oool00000000000020?ooo`@000006`3AcJU<0?oooa/0dLfYC03ooolK0=7=
ZD`0oooo5P3AcJT001D0dLfYC03ooolK0=7=ZAD00000103oool4000000<0oooo100000040?ooo`/0
0000103oool4000000@0oooo100000030?ooo`H000006`3AcJU<000001/0dLfYC03ooolK0=7=ZD`0
00005P3AcJT001D0dLfYC03ooolK0=7=ZAD00000103oool4000000<0oooo100000040?ooo`/00000
103oool4000000@0oooo100000030?ooo`H000006`3AcJU<000001/0dLfYC03ooolK0=7=ZD`00000
5P3AcJT001D0dLfYC000000K0=7=ZAL000001`3oool8000000l0oooo200000070?ooo`P000006`3A
cJU<0?oooa/0dLfYC000000K0=7=ZD`0oooo5P3AcJT001D0dLfYC000000K0=7=ZAL000001`3oool8
000000l0oooo200000070?ooo`P000006`3AcJU<0?oooa/0dLfYC000000K0=7=ZD`0oooo5P3AcJT0
01D0dLfYC03ooolK0=7=ZAL000001`3oool8000000l0oooo200000070?ooo`P000006`3AcJU<0?oo
oa/0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfYC03ooolK0=7=ZAD00000103oool4000000<0
oooo100000040?ooo`/00000103oool4000000@0oooo100000030?ooo`H000006`3AcJU<000001/0
dLfYC03ooolK0=7=ZD`000005P3AcJT001D0dLfYC03ooolK0=7=ZAD00000103oool4000000<0oooo
100000040?ooo`/00000103oool4000000@0oooo100000030?ooo`H000006`3AcJU<000001/0dLfY
C03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfYC03ooolK0=7=ZA<000000P3oool200000080oooo1000
00000`3oool00000000000040?ooo`8000000P3oool2000000L0oooo0P0000020?ooo`800000103o
ool200000080oooo100000000`3oool00000000000020?ooo`@000006`3AcJU<0?oooa/0dLfYC000
000K0=7=ZD`0oooo5P3AcJT001D0dLfYC000000K0=7=ZA<000000P3oool200000080oooo10000000
0`3oool00000000000040?ooo`8000000P3oool2000000L0oooo0P0000020?ooo`800000103oool2
00000080oooo100000000`3oool00000000000020?ooo`@000006`3AcJU<0?oooa/0dLfYC000000K
0=7=ZD`0oooo5P3AcJT001D0dLfYC000000K0=7=ZA4000001P3oool2000000@0oooo00<000000?oo
o`3oool0100000020?ooo`H00000103oool500000080oooo100000020?ooo`800000103oool00`00
0000oooo0?ooo`040?ooo`8000006`3AcJU<0?oooa/0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0
dLfYC03ooolK0=7=ZA4000001P3oool2000000@0oooo00<000000?ooo`3oool0100000020?ooo`H0
0000103oool500000080oooo100000020?ooo`800000103oool00`000000oooo0?ooo`040?ooo`80
00006`3AcJU<0?oooa/0dLfYC03ooolK0=7=ZD`000005P3AcJT001D0dLfYC03ooolK0=7=Z@l00000
0P3oool600000080oooo100000030?ooo`@000000P3oool6000000@0oooo1@0000020?ooo`@00000
103oool4000000030?ooo`000000000000@000000P3ooolK0=7=ZD`000006`3AcJU<0?oooa/0dLfY
C03ooolF0=7=Z@005@3AcJU<0?oooa/0dLfY3`0000020?ooo`H000000P3oool4000000<0oooo1000
00020?ooo`H00000103oool500000080oooo100000040?ooo`@0000000<0oooo0000000000001000
00020?oooa/0dLfYC000000K0=7=ZD`0oooo6`3AcJU<0?oooaH0dLfY000E0=7=ZD`0oooo6`3AcJT2
0?ooo`/00000103oool200000080oooo0P0000020?ooo`D000001P3oool200000080oooo0P000007
0?ooo`8000000P3oool2000000H0oooo1P0000000`3oool00000000000020?ooo`8000000P3ooolK
0=7=ZD`0oooo6`3AcJU<000001/0dLfYC03ooolF0=7=Z@005@3AcJU<000001/0dLfY0P3oool;0000
00@0oooo0P0000020?ooo`8000000P3oool5000000H0oooo0P0000020?ooo`8000001`3oool20000
0080oooo0P0000060?ooo`H0000000<0oooo0000000000000P3oool200000080oooo6`3AcJU<0?oo
oa/0dLfYC03ooolK0=7=ZD`000005P3AcJT001D0dLfYC000000K0=7=Z@8000000P3oool700000080
oooo0P0000020?ooo`8000000P3oool400000080oooo0`0000040?ooo`800000103oool;000000@0
oooo0P0000040?ooo`@000000P3oool300000080oooo0P0000020?oooa/0dLfYC03ooolK0=7=ZD`0
oooo6`3AcJU<000001H0dLfY000E0=7=ZD`0oooo6`3AcJT200000080oooo1`0000020?ooo`800000
0P3oool200000080oooo100000020?ooo`<00000103oool2000000@0oooo2`0000040?ooo`800000
103oool400000080oooo0`0000020?ooo`8000000P3ooolK0=7=ZD`000006`3AcJU<0?oooa/0dLfY
C03ooolF0=7=Z@005@3AcJU<0?oooa/0dLfY1P3oool4000000D0oooo1P0000020?ooo`8000002`3o
ool2000000l0oooo0P00000<0?ooo`030000003oool0oooo00H000006`3AcJU<000001/0dLfYC03o
oolK0=7=ZD`0oooo5P3AcJT001D0dLfYC03ooolK0=7=Z@H0oooo100000050?ooo`H000000P3oool2
000000/0oooo0P00000?0?ooo`800000303oool00`000000oooo0?ooo`06000001/0dLfYC03ooolK
0=7=ZD`000006`3AcJU<0?oooaH0dLfY000E0=7=ZD`0oooo6`3AcJT6000000@0oooo2`0000020?oo
o`8000001@3oool6000001<0oooo1P0000060?ooo`030000003oool0oooo00H000006`3AcJU<0?oo
oa/0dLfYC03ooolK0=7=ZD`000005P3AcJT001D0dLfYC000000K0=7=Z@H00000103oool;00000080
oooo0P0000050?ooo`H000004`3oool6000000H0oooo00<000000?ooo`3oool01P00000K0=7=ZD`0
oooo6`3AcJU<0?oooa/0dLfYC000000F0=7=Z@005@3AcJU<000001/0dLfY103oool7000000@0oooo
100000020?ooo`@000000P3oool2000000030?ooo`00000000000080oooo5`0000020?ooo`800000
0P3oool200000080oooo0`0000020?ooo`@000006`3AcJU<0?oooa/0dLfYC03ooolK0=7=ZD`0oooo
5P3AcJT001D0dLfYC03ooolK0=7=Z@@0oooo1`0000040?ooo`@000000P3oool400000080oooo0P00
00000`3oool00000000000020?oooaL000000P3oool200000080oooo0P0000020?ooo`<000000P3o
ool4000001/0dLfYC000000K0=7=ZD`0oooo6`3AcJU<0?oooaH0dLfY000E0=7=ZD`0oooo6`3AcJT4
000000L0oooo100000060?ooo`8000000P3oool200000080oooo0`00000K0?ooo`@000000P3oool2
000000030?ooo`000000000000H0oooo6`3AcJU<000001/0dLfYC000000K0=7=ZD`0oooo5P3AcJT0
01D0dLfYC03ooolK0=7=Z@@000001`3oool4000000H0oooo0P0000020?ooo`8000000P3oool30000
01/0oooo100000020?ooo`80000000<0oooo0000000000001P3ooolK0=7=ZD`0oooo6`3AcJU<0000
01/0dLfYC000000F0=7=Z@005@3AcJU<0?oooa/0dLfY1P0000040?ooo`L00000103oool2000000H0
oooo00<000000?ooo`3oool07@3oool2000000D0oooo0P0000040?ooo`8000006`3AcJU<0?oooa/0
dLfYC03ooolK0=7=ZD`000005P3AcJT001D0dLfYC000000K0=7=Z@H00000103oool7000000@0oooo
0P0000060?ooo`030000003oool0oooo01d0oooo0P0000050?ooo`800000103oool2000001/0dLfY
C03ooolK0=7=ZD`0oooo6`3AcJU<0?oooaH0dLfY000E0=7=ZD`000006`3AcJT6000000@0oooo1`00
00040?ooo`8000001P3ooolR000000D0oooo0P0000040?ooo`8000006`3AcJU<000001/0dLfYC03o
oolK0=7=ZD`0oooo5P3AcJT001D0dLfYC03ooolK0=7=Z@@000001`3oool4000000H0oooo0P000002
0?ooo`8000009P3oool2000000030?ooo`000000000000H0oooo6`3AcJU<000001/0dLfYC000000K
0=7=ZD`0oooo5P3AcJT001D0dLfYC03ooolK0=7=Z@@000001`3oool4000000H0oooo0P0000020?oo
o`8000009P3oool2000000030?ooo`000000000000H0oooo6`3AcJU<0?oooa/0dLfYC000000K0=7=
ZD`000005P3AcJT001D0dLfYC03ooolK0=7=Z@@0oooo1`0000040?ooo`@000000P3oool4000002X0
oooo0`0000020?ooo`@000006`3AcJU<0?oooa/0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfY
C03ooolK0=7=Z@@0oooo1`0000040?ooo`@000000P3oool4000002X0oooo0`0000020?ooo`@00000
6`3AcJU<0?oooa/0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfYC000000K0=7=Z@H00000103o
ool;00000080oooo;@0000020?ooo`H000006`3AcJU<0?oooa/0dLfYC03ooolK0=7=ZD`0oooo5P3A
cJT001D0dLfYC000000K0=7=Z@H00000103oool;00000080oooo;@0000020?ooo`H000006`3AcJU<
000001/0dLfYC000000K0=7=ZD`0oooo5P3AcJT001D0dLfYC03ooolK0=7=Z@H0oooo100000050?oo
o`H00000<@3oool6000001/0dLfYC000000K0=7=ZD`000006`3AcJU<000001H0dLfY000E0=7=ZD`0
oooo6`3AcJT60?ooo`@000001@3oool600000340oooo1P00000K0=7=ZD`0oooo6`3AcJU<0?oooa/0
dLfYC03ooolF0=7=Z@005@3AcJU<0?oooa/0dLfY0P0000020?ooo`L000000P3oool200000080oooo
0P00000e0?ooo`8000000P3ooolK0=7=ZD`0oooo6`3AcJU<0?oooa/0dLfYC03ooolF0=7=Z@005@3A
cJU<0?oooa/0dLfY0P0000020?ooo`L000000P3oool200000080oooo0P00000e0?ooo`8000000P3o
oolK0=7=ZD`0oooo6`3AcJU<0?oooa/0dLfYC03ooolF0=7=Z@005@3AcJU<000001/0dLfY0P3oool;
000000@0oooo>@0000020?oooa/0dLfYC000000K0=7=ZD`000006`3AcJU<000001H0dLfY000E0=7=
ZD`000006`3AcJT20?ooo`/00000103oooli00000080oooo6`3AcJU<000001/0dLfYC000000K0=7=
ZD`000005P3AcJT00?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY5@3A
cJT00?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT003L0dLfY
0T0000030=7=Z@=00000H03AcJT3@0000080dLfY0T00001P0=7=Z@=0000000<0dLfY@00004000000
0T00001O0=7=Z@=000000P3AcJT2@0000600dLfY0d0000020=7=Z@900000>03AcJT003H0dLfY00A0
00000=7=Z@3AcJU00000103AcJT00d000000dLfY0=7=Z@1O0=7=Z@04@000003AcJT0dLfY@0000080
dLfY00=000000=7=Z@3AcJT0GP3AcJT014000000dLfY0=7=ZD00001S0=7=Z@04@000003AcJT0dLfY
@0000080dLfY00=000000=7=Z@3AcJT0GP3AcJT014000000dLfY0=7=ZD0000020=7=Z@03@000003A
cJT0dLfY03D0dLfY000h0=7=Z@03@000003AcJT0dLfY0080dLfY0d00001M0=7=Z@E0000000D0dLfY
@000003AcJT0dLfY@000001M0=7=Z@E000000P3AcJT00d000000dLfY0=7=Z@1M0=7=Z@E00000103A
cJT00d000000dLfY0=7=Z@1K0=7=Z@E0000000D0dLfY@000003AcJT0dLfY@000000g0=7=Z@00>@3A
cJT014000000dLfY0=7=ZD0000020=7=Z@03@000003AcJT0dLfY05/0dLfY00A000000=7=Z@3AcJU0
00000P3AcJT014000000dLfY0=7=ZD00001M0=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=00000
0=7=Z@3AcJT0G03AcJT014000000dLfY0=7=ZD0000030=7=Z@900000GP3AcJT014000000dLfY0=7=
ZD0000030=7=Z@900000>03AcJT003H0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY
0=7=ZD00001N0=7=Z@03@000003AcJU000000080dLfY00A000000=7=Z@3AcJU00000GP3AcJT00d00
0000dLfY@00000020=7=Z@04@000003AcJT0dLfY@00005h0dLfY00=000000=7=ZD0000000`3AcJT0
0d000000dLfY0=7=Z@1N0=7=Z@03@000003AcJU000000080dLfY00A000000=7=Z@3AcJU00000=`3A
cJT003L0dLfY0T0000040=7=Z@=00000G`3AcJT2@00000<0dLfY0T00001P0=7=Z@9000000`3AcJT2
@0000600dLfY0T0000030=7=Z@=00000G`3AcJT2@00000<0dLfY0T00000h0=7=Z@00o`3AcJWo0=7=
ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o
0=7=ZOl0dLfY5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY
5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT00?l0
dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT001D0dLfY0P000003
0?ooo`D000000P3oool300000080oooo1@0000030?ooo`800000<@3ooolK0=7=ZD`0oooo6`3AcJT=
000000D0oooo100000050?ooo`d00000903ooolK0=7=Z@8000002@3oool2000000T0oooo0P000009
0?ooo`800000203oool3000000P0oooo0P0000090?ooo`8000002@3ooolK0=7=ZD`0oooo5P3AcJT0
01D0dLfY0P0000030?ooo`D000000P3oool300000080oooo1@0000030?ooo`800000<@3ooolK0=7=
ZD`0oooo6`3AcJT=000000D0oooo100000050?ooo`d00000903ooolK0=7=Z@8000002@3oool20000
00T0oooo0P0000090?ooo`800000203oool3000000P0oooo0P0000090?ooo`8000002@3ooolK0=7=
ZD`0oooo5P3AcJT001D0dLfY0P0000030?ooo`D000000P3oool300000080oooo1@0000030?ooo`80
0000<@3ooolK0=7=ZD`0oooo6`3AcJT=000000D0oooo100000050?ooo`d00000903ooolK0=7=Z@80
00002@3oool2000000T0oooo0P0000090?ooo`800000203oool3000000P0oooo0P0000090?ooo`80
00002@3ooolK0=7=ZD`0oooo5P3AcJT001D0dLfY0P0000030?ooo`D000000P3oool300000080oooo
1@0000030?ooo`800000<@3ooolK0=7=ZD`0oooo6`3AcJT=000000D0oooo100000050?ooo`d00000
903ooolK0=7=Z@8000002@3oool2000000T0oooo0P0000090?ooo`800000203oool3000000P0oooo
0P0000090?ooo`8000002@3ooolK0=7=ZD`0oooo5P3AcJT001D0dLfY0P0000030?ooo`D000000P3o
ool300000080oooo1@0000030?ooo`800000<@3ooolK0=7=ZD`0oooo6`3AcJT=000000D0oooo1000
00050?ooo`d00000903ooolK0=7=Z@8000000P3oool500000080oooo0P0000020?ooo`D000000P3o
ool200000080oooo100000030?ooo`8000000P3oool400000080oooo0`0000020?ooo`@000000P3o
ool2000000<0oooo100000020?ooo`8000000`3oool400000080oooo6`3AcJU<000001H0dLfY000E
0=7=Z@D000001@3oool7000000D0oooo1@0000020?ooobd000000P3ooolK0=7=ZD`000006`3AcJT2
0?ooo`T000004P3oool9000000@0oooo800000020?oooa/0dLfY0P0000020?ooo`D000000P3oool2
00000080oooo1@0000020?ooo`8000000P3oool4000000<0oooo0P0000020?ooo`@000000P3oool3
00000080oooo100000020?ooo`8000000`3oool400000080oooo0P0000030?ooo`@000000P3ooolK
0=7=ZD`000005P3AcJT001D0dLfY1@0000050?ooo`L000001@3oool500000080oooo;@0000020?oo
oa/0dLfYC000000K0=7=Z@80oooo2@00000B0?ooo`T00000103ooolP00000080oooo6`3AcJT20000
0080oooo1@0000020?ooo`8000000P3oool500000080oooo0P0000020?ooo`@000000`3oool20000
0080oooo100000020?ooo`<000000P3oool400000080oooo0P0000030?ooo`@000000P3oool20000
00<0oooo100000020?oooa/0dLfYC03ooolF0=7=Z@005@3AcJT20?oooaL000000P3oool5000002L0
oooo1@00000K0=7=ZD`0oooo6`3AcJT200000080oooo1@0000020?ooo`L00000103oool700000080
oooo1@0000020?ooo`8000000P3oool3000001/0oooo0P0000020?oooa/0dLfYC000000K0=7=ZD`0
oooo5P3AcJT001D0dLfY0P3ooolG00000080oooo1@00000W0?ooo`D000006`3AcJU<0?oooa/0dLfY
0P0000020?ooo`D000000P3oool7000000@0oooo1`0000020?ooo`D000000P3oool200000080oooo
0`00000K0?ooo`8000000P3ooolK0=7=ZD`000006`3AcJU<0?oooaH0dLfY000E0=7=Z@80oooo5`00
00020?ooo`D000009`3oool5000001/0dLfYC03ooolK0=7=Z@/0oooo0P0000030?ooo`800000103o
ool300000080oooo0P00000;0?ooo`L000005P3oool7000001/0dLfY0P0000020?ooo`D000000P3o
ool200000080oooo1@0000020?ooo`8000000P3oool4000000<0oooo0P0000020?ooo`@000000P3o
ool300000080oooo100000020?ooo`8000000`3oool400000080oooo0P0000030?ooo`@000000P3o
oolK0=7=ZD`0oooo5P3AcJT001D0dLfY2P3oool7000000X0oooo0P0000030?ooo`8000008`3oool2
000000<0oooo0P00000K0=7=ZD`0oooo6`3AcJT;0?ooo`8000000`3oool2000000@0oooo0`000002
0?ooo`8000002`3oool7000001H0oooo1`00000K0=7=Z@8000000P3oool500000080oooo0P000002
0?ooo`D000000P3oool200000080oooo100000030?ooo`8000000P3oool400000080oooo0`000002
0?ooo`@000000P3oool2000000<0oooo100000020?ooo`8000000`3oool400000080oooo6`3AcJU<
0?oooaH0dLfY000E0=7=Z@X0oooo1`00000:0?ooo`8000000`3oool2000002<0oooo0P0000030?oo
o`8000006`3AcJU<0?oooa/0dLfY100000070?ooo`8000000`3oool2000000@0oooo0`0000020?oo
o`8000001`3oool;00000080oooo4P0000020?ooo`L000006`3AcJT2000000T0oooo0P0000090?oo
o`8000002@3oool2000000P0oooo0`0000080?ooo`8000002@3oool2000000T0oooo6`3AcJU<0000
01H0dLfY000E0=7=Z@L0oooo0`0000020?ooo`<000000P3oool3000000L0oooo0P0000080?oooad0
0000203oool2000001/0dLfYC000000K0=7=Z@@000001`3oool2000000<0oooo0P0000040?ooo`<0
00000P3oool2000000L0oooo2`0000020?oooa8000000P3oool7000001/0dLfY0P0000090?ooo`80
00002@3oool2000000T0oooo0P0000080?ooo`<00000203oool2000000T0oooo0P0000090?oooa/0
dLfYC000000F0=7=Z@005@3AcJT70?ooo`<000000P3oool300000080oooo0`0000070?ooo`800000
203ooolM000000P0oooo0P00000K0=7=ZD`000006`3AcJT4000000L0oooo0P0000030?ooo`800000
103oool300000080oooo0P0000070?ooo`/000000P3ooolB00000080oooo1`00000K0=7=Z@800000
2@3oool2000000T0oooo0P0000090?ooo`800000203oool3000000P0oooo0P0000090?ooo`800000
2@3ooolK0=7=ZD`0oooo5P3AcJT001D0dLfY1`3oool300000080oooo0`0000020?ooo`<000001`3o
ool2000000P0oooo7@0000080?ooo`8000006`3AcJU<0?oooa/0dLfY0P3oool2000000<0oooo0P00
00020?ooo`L00000103oool700000080oooo0`0000020?ooo`8000000P3oool500000080oooo1000
000>0?ooo`@000000`3oool4000001/0dLfY0P0000090?ooo`8000002@3oool2000000T0oooo0P00
00080?ooo`<00000203oool2000000T0oooo0P0000090?oooa/0dLfYC03ooolF0=7=Z@005@3AcJT2
0?ooo`<000001`3oool3000000L0oooo0`0000020?ooo`800000203oool2000001T0oooo0P000008
0?ooo`8000006`3AcJU<0?oooa/0dLfY0P3oool2000000<0oooo0P0000020?ooo`L00000103oool7
00000080oooo0`0000020?ooo`8000000P3oool500000080oooo1000000>0?ooo`@000000`3oool4
000001/0dLfY0P0000020?ooo`D000000P3oool200000080oooo1@0000020?ooo`8000000P3oool4
000000<0oooo0P0000020?ooo`@000000P3oool300000080oooo100000020?ooo`8000000`3oool4
00000080oooo0P0000030?ooo`@000000P3ooolK0=7=ZD`0oooo5P3AcJT001D0dLfY0P3oool30000
00L0oooo0`0000070?ooo`<000000P3oool2000000P0oooo0P00000I0?ooo`800000203oool20000
01/0dLfYC03ooolK0=7=Z@80oooo1@0000020?ooo`8000004P3oool2000000<0oooo100000090?oo
o`8000000P3oool3000000T0oooo0P0000020?ooo`8000001`3ooolK0=7=Z@8000000P3oool50000
0080oooo0P0000020?ooo`D000000P3oool200000080oooo100000030?ooo`8000000P3oool40000
0080oooo0`0000020?ooo`@000000P3oool2000000<0oooo100000020?ooo`8000000`3oool40000
0080oooo6`3AcJU<0?oooaH0dLfY000E0=7=Z@8000002P3oool3000000X0oooo100000030?ooo`80
00000`3oool5000001<0oooo1@0000030?ooo`8000000`3oool2000001/0dLfYC03ooolK0=7=Z@80
oooo1@0000020?ooo`8000004P3oool2000000<0oooo100000090?ooo`8000000P3oool3000000T0
oooo0P0000020?ooo`8000001`3ooolK0=7=Z@8000000P3oool500000080oooo0P0000020?ooo`D0
00000P3oool200000080oooo100000030?ooo`8000000P3oool400000080oooo0`0000020?ooo`@0
00000P3oool2000000<0oooo100000020?ooo`8000000`3oool400000080oooo6`3AcJU<000001H0
dLfY000E0=7=Z@8000002P3oool3000000X0oooo100000030?ooo`8000000`3oool5000001<0oooo
1@0000030?ooo`8000000`3oool2000001/0dLfYC03ooolK0=7=Z@@0oooo0`0000040?ooo`800000
1@3oool4000000D0oooo0P0000050?ooo`8000002`3oool2000000L0oooo100000070?ooo`800000
1`3ooolK0=7=ZD`000006`3AcJU<000001H0dLfY000E0=7=Z@8000002P3oool3000000X0oooo1000
00030?ooo`8000000`3oool5000001<0oooo1@0000030?ooo`8000000`3oool2000001/0dLfYC000
000K0=7=Z@@0oooo0`0000040?ooo`8000001@3oool4000000D0oooo0P0000050?ooo`8000002`3o
ool2000000L0oooo100000070?ooo`8000001`3ooolK0=7=ZD`000006`3AcJU<0?oooaH0dLfY000E
0=7=Z@X000000P3oool300000080oooo2P0000020?ooo`<000000P3oool300000080oooo0`000002
0?ooo`l000000P3oool300000080oooo0`0000020?ooo`<000000P3ooolK0=7=ZD`000006`3AcJT7
00000080oooo0P0000070?ooo`@000001`3oool2000000<0oooo2`0000020?ooo`8000001`3oool4
000000L0oooo0P0000030?ooo`@000006`3AcJT200000080oooo1@0000020?ooo`8000000P3oool5
00000080oooo0P0000020?ooo`@000000`3oool200000080oooo100000020?ooo`<000000P3oool4
00000080oooo0P0000030?ooo`@000000P3oool2000000<0oooo100000020?oooa/0dLfYC03ooolF
0=7=Z@005@3AcJT:00000080oooo0`0000020?ooo`X000000P3oool300000080oooo0`0000020?oo
o`<000000P3oool?00000080oooo0`0000020?ooo`<000000P3oool300000080oooo6`3AcJU<0?oo
oa/0dLfY1`0000020?ooo`8000001`3oool4000000L0oooo0P0000030?ooo`/000000P3oool20000
00L0oooo100000070?ooo`8000000`3oool4000001/0dLfY0P0000020?ooo`D000000P3oool20000
0080oooo1@0000020?ooo`8000000P3oool4000000<0oooo0P0000020?ooo`@000000P3oool30000
0080oooo100000020?ooo`8000000`3oool400000080oooo0P0000030?ooo`@000000P3ooolK0=7=
ZD`0oooo5P3AcJT001D0dLfY1`3oool=000001<0oooo200000090?ooo`P00000303ooolK0=7=ZD`0
oooo6`3AcJT700000080oooo0P0000070?ooo`@000001`3oool2000000<0oooo2`0000020?ooo`80
00001`3oool4000000L0oooo0P0000030?ooo`@000006`3AcJT2000000T0oooo0P0000090?ooo`80
00002@3oool2000000P0oooo0`0000080?ooo`8000002@3oool2000000T0oooo6`3AcJU<0?oooaH0
dLfY000E0=7=Z@L0oooo3@00000C0?ooo`P000002@3oool8000000`0oooo6`3AcJU<0?oooa/0dLfY
1`3oool200000080oooo1@0000090?ooo`@000000P3oool3000000P0oooo1`0000020?ooo`<00000
2@3oool200000080oooo1`0000020?oooa/0dLfY0P0000090?ooo`8000002@3oool2000000T0oooo
0P0000080?ooo`<00000203oool2000000T0oooo0P0000090?oooa/0dLfYC03ooolF0=7=Z@005@3A
cJT70?ooo`d000004`3oool8000000T0oooo2000000<0?oooa/0dLfYC03ooolK0=7=Z@L0oooo0P00
00020?ooo`D000002@3oool400000080oooo0`0000080?ooo`L000000P3oool3000000T0oooo0P00
00020?ooo`L000000P3ooolK0=7=Z@8000002@3oool2000000T0oooo0P0000090?ooo`800000203o
ool3000000P0oooo0P0000090?ooo`8000002@3ooolK0=7=ZD`000005P3AcJT001D0dLfY1@3oool2
000000D0oooo0`0000050?ooo`8000001@3oool2000000<0oooo0P00000=0?ooo`8000001@3oool2
000000d0oooo0P0000030?ooo`8000006`3AcJU<0?oooa/0dLfY103oool3000000@0oooo1@000009
0?ooo`@000001@3oool2000000@0oooo0P0000070?ooo`8000003P3oool2000000L0oooo0P00000K
0=7=Z@8000002@3oool2000000T0oooo0P0000090?ooo`800000203oool3000000P0oooo0P000009
0?ooo`8000002@3ooolK0=7=ZD`000005P3AcJT001D0dLfY1@3oool2000000D0oooo0`0000050?oo
o`8000001@3oool2000000<0oooo0P00000=0?ooo`8000001@3oool2000000d0oooo0P0000030?oo
o`8000006`3AcJU<000001/0dLfY103oool3000000@0oooo1@0000090?ooo`@000001@3oool20000
00@0oooo0P0000070?ooo`8000003P3oool2000000L0oooo0P00000K0=7=Z@8000000P3oool50000
0080oooo0P0000020?ooo`D000000P3oool200000080oooo100000030?ooo`8000000P3oool40000
0080oooo0`0000020?ooo`@000000P3oool2000000<0oooo100000020?ooo`8000000`3oool40000
0080oooo6`3AcJU<0?oooaH0dLfY000E0=7=Z@L0oooo3@0000090?ooo`<000001@3oool2000000D0
oooo0`0000090?ooo`<000001@3oool2000000D0oooo0`0000020?oooa/0dLfYC000000K0=7=Z@L0
oooo0P0000090?ooo`@000002@3oool3000000P0oooo0`0000020?ooo`8000000P3oool>00000080
oooo0P0000030?ooo`8000000P3ooolK0=7=Z@8000000P3oool500000080oooo0P0000020?ooo`D0
00000P3oool200000080oooo100000030?ooo`8000000P3oool400000080oooo0`0000020?ooo`@0
00000P3oool2000000<0oooo100000020?ooo`8000000`3oool400000080oooo6`3AcJU<0?oooaH0
dLfY000E0=7=Z@L0oooo3@0000090?ooo`<000001@3oool2000000D0oooo0`0000090?ooo`<00000
1@3oool2000000D0oooo0`0000020?oooa/0dLfYC03ooolK0=7=Z@L0oooo0P0000090?ooo`@00000
2@3oool3000000P0oooo0`0000020?ooo`8000000P3oool>00000080oooo0P0000030?ooo`800000
0P3ooolK0=7=Z@8000000P3oool500000080oooo0P0000020?ooo`D000000P3oool200000080oooo
100000030?ooo`8000000P3oool400000080oooo0`0000020?ooo`@000000P3oool2000000<0oooo
100000020?ooo`8000000`3oool400000080oooo6`3AcJU<0?oooaH0dLfY000E0=7=Z@L0oooo3@00
00090?ooo`<000001@3oool2000000D0oooo0`0000090?ooo`<000001@3oool2000000D0oooo0`00
00020?oooa/0dLfYC03ooolK0=7=Z@L000002`3oool4000000`0oooo200000030?ooo`800000103o
ool3000000T0oooo0P0000040?ooo`<000000P3oool2000001/0dLfYC000000K0=7=ZD`0oooo5P3A
cJT001D0dLfY2P0000020?ooo`<000000P3oool<000000<0oooo0P00000=0?ooo`T000003@3oool2
000000<0oooo0P00000K0=7=ZD`0oooo6`3AcJT7000000/0oooo1000000<0?ooo`P000000`3oool2
000000@0oooo0`0000090?ooo`800000103oool300000080oooo0P00000K0=7=ZD`000006`3AcJU<
000001H0dLfY000E0=7=Z@X000000P3oool300000080oooo300000030?ooo`8000003@3oool90000
00d0oooo0P0000030?ooo`8000006`3AcJU<0?oooa/0dLfY1`00000;0?ooo`@00000303oool80000
00<0oooo0P0000040?ooo`<000002@3oool2000000@0oooo0`0000020?ooo`8000006`3AcJT20000
0080oooo1@0000020?ooo`8000000P3oool500000080oooo0P0000020?ooo`@000000`3oool20000
0080oooo100000020?ooo`<000000P3oool400000080oooo0P0000030?ooo`@000000P3oool20000
00<0oooo100000020?oooa/0dLfYC000000F0=7=Z@005@3AcJT<0?ooo`<00000303oool2000000X0
oooo2P0000050?ooo`X000002P3oool2000001/0dLfYC03ooolK0=7=Z@@0oooo300000090?ooo`/0
0000103oool2000000D0oooo0P0000020?ooo`D00000103oool500000080oooo0P0000050?ooo`80
00006`3AcJT200000080oooo1@0000020?ooo`8000000P3oool500000080oooo0P0000020?ooo`@0
00000`3oool200000080oooo100000020?ooo`<000000P3oool400000080oooo0P0000030?ooo`@0
00000P3oool2000000<0oooo100000020?oooa/0dLfYC03ooolF0=7=Z@005@3AcJT<0?ooo`<00000
303oool2000000X0oooo2P0000050?ooo`X000002P3oool2000001/0dLfYC000000K0=7=Z@@0oooo
300000090?ooo`/00000103oool2000000D0oooo0P0000020?ooo`D00000103oool500000080oooo
0P0000050?ooo`8000006`3AcJT2000000T0oooo0P0000090?ooo`8000002@3oool2000000P0oooo
0`0000080?ooo`8000002@3oool2000000T0oooo6`3AcJU<0?oooaH0dLfY000E0=7=Z@`0oooo0`00
000<0?ooo`8000002P3oool:000000D0oooo2P00000:0?ooo`8000006`3AcJU<000001/0dLfY1000
00090?ooo`<000002@3oool2000000T0oooo1P0000030?ooo`8000000P3oool2000000<0oooo0P00
00040?ooo`<000000P3oool200000080oooo0`0000020?ooo`8000006`3AcJT2000000T0oooo0P00
00090?ooo`8000002@3oool2000000P0oooo0`0000080?ooo`8000002@3oool2000000T0oooo6`3A
cJU<0?oooaH0dLfY000E0=7=Z@8000002P3oool3000000X0oooo100000050?ooo`<000000P3oool3
000000L0oooo1@0000070?ooo`<000000P3oool3000000D0oooo0P00000K0=7=ZD`0oooo6`3AcJT4
000000T0oooo0`0000090?ooo`8000002@3oool6000000<0oooo0P0000020?ooo`8000000`3oool2
000000@0oooo0`0000020?ooo`8000000P3oool300000080oooo0P00000K0=7=Z@8000002@3oool2
000000T0oooo0P0000090?ooo`800000203oool3000000P0oooo0P0000090?ooo`8000002@3ooolK
0=7=ZD`0oooo5P3AcJT001D0dLfY0P00000:0?ooo`<000002P3oool4000000D0oooo0`0000020?oo
o`<000001`3oool5000000L0oooo0`0000020?ooo`<000001@3oool2000001/0dLfYC03ooolK0=7=
Z@80oooo1@0000040?ooo`D000000P3oool4000000<0oooo100000050?ooo`@00000103oool30000
00T0oooo0P0000040?ooo`<000002@3oool200000080oooo6`3AcJT2000000T0oooo0P0000090?oo
o`8000002@3oool2000000P0oooo0`0000080?ooo`8000002@3oool2000000T0oooo6`3AcJU<0000
01H0dLfY000E0=7=Z@8000000`3oool500000080oooo0`0000020?ooo`D000000`3oool2000000X0
oooo1`0000030?ooo`T000000`3oool7000000X0oooo6`3AcJU<0?oooa/0dLfY0P3oool5000000@0
oooo1@0000020?ooo`@000000`3oool4000000D0oooo100000040?ooo`<000002@3oool2000000@0
oooo0`0000090?ooo`8000000P3ooolK0=7=Z@8000000P3oool500000080oooo0P0000020?ooo`D0
00000P3oool200000080oooo100000030?ooo`8000000P3oool400000080oooo0`0000020?ooo`@0
00000P3oool2000000<0oooo100000020?ooo`8000000`3oool400000080oooo6`3AcJU<000001H0
dLfY000E0=7=Z@8000000`3oool500000080oooo0`0000020?ooo`D000000`3oool2000000X0oooo
1`0000030?ooo`T000000`3oool7000000X0oooo6`3AcJU<0?oooa/0dLfY0P3oool5000000@0oooo
1@0000020?ooo`@000000`3oool4000000D0oooo100000040?ooo`<000002@3oool2000000@0oooo
0`0000090?ooo`8000000P3ooolK0=7=Z@8000000P3oool500000080oooo0P0000020?ooo`D00000
0P3oool200000080oooo100000030?ooo`8000000P3oool400000080oooo0`0000020?ooo`@00000
0P3oool2000000<0oooo100000020?ooo`8000000`3oool400000080oooo6`3AcJU<000001H0dLfY
000E0=7=Z@8000000`3oool500000080oooo0`0000020?ooo`D000000`3oool2000000X0oooo1`00
00030?ooo`T000000`3oool7000000X0oooo6`3AcJU<0?oooa/0dLfY0P0000020?ooo`<00000103o
ool2000000<0oooo2@0000020?ooo`8000001@3oool200000080oooo100000030?ooo`@000001@3o
ool2000000@0oooo0`0000040?ooo`D000000P3oool2000001/0dLfY0P0000020?ooo`D000000P3o
ool200000080oooo1@0000020?ooo`8000000P3oool4000000<0oooo0P0000020?ooo`@000000P3o
ool300000080oooo100000020?ooo`8000000`3oool400000080oooo0P0000030?ooo`@000000P3o
oolK0=7=ZD`0oooo5P3AcJT001D0dLfYC000000K0=7=ZD`000006`3AcJT200000080oooo0`000004
0?ooo`8000000`3oool900000080oooo0P0000050?ooo`8000000P3oool4000000<0oooo10000005
0?ooo`800000103oool3000000@0oooo1@0000020?ooo`8000006`3AcJU<000001/0dLfYC03ooolF
0=7=Z@005@3AcJU<000001/0dLfYC000000K0=7=Z@8000000P3oool3000000@0oooo0P0000030?oo
o`T000000P3oool2000000D0oooo0P0000020?ooo`@000000`3oool4000000D0oooo0P0000040?oo
o`<00000103oool500000080oooo0P00000K0=7=ZD`000006`3AcJU<0?oooaH0dLfY000E0=7=Z@80
00000`3oool500000080oooo0`0000020?ooo`D000000`3oool2000000X0oooo1`0000030?ooo`T0
00000`3oool7000000X0oooo6`3AcJU<0?oooa/0dLfY0P0000020?ooo`<00000103oool2000000<0
oooo2@0000020?ooo`8000001@3oool200000080oooo100000030?ooo`@000001@3oool2000000@0
oooo0`0000040?ooo`D000000P3oool2000001/0dLfY0P0000020?ooo`D000000P3oool200000080
oooo1@0000020?ooo`8000000P3oool4000000<0oooo0P0000020?ooo`@000000P3oool300000080
oooo100000020?ooo`8000000`3oool400000080oooo0P0000030?ooo`@000000P3ooolK0=7=ZD`0
oooo5P3AcJT001D0dLfY0P0000030?ooo`D000000P3oool300000080oooo1@0000030?ooo`800000
2P3oool7000000<0oooo2@0000030?ooo`L000002P3ooolK0=7=ZD`0oooo6`3AcJT20?ooo`D00000
103oool500000080oooo100000030?ooo`@000001@3oool4000000@0oooo0`0000090?ooo`800000
103oool3000000T0oooo0P0000020?oooa/0dLfY0P0000020?ooo`D000000P3oool200000080oooo
1@0000020?ooo`8000000P3oool4000000<0oooo0P0000020?ooo`@000000P3oool300000080oooo
100000020?ooo`8000000`3oool400000080oooo0P0000030?ooo`@000000P3ooolK0=7=ZD`00000
5P3AcJT001D0dLfY0P0000030?ooo`D000000P3oool300000080oooo1@0000030?ooo`8000002P3o
ool7000000<0oooo2@0000030?ooo`L000002P3ooolK0=7=ZD`0oooo6`3AcJT20?ooo`D00000103o
ool500000080oooo100000030?ooo`@000001@3oool4000000@0oooo0`0000090?ooo`800000103o
ool3000000T0oooo0P0000020?oooa/0dLfY0P0000090?ooo`8000002@3oool2000000T0oooo0P00
00080?ooo`<00000203oool2000000T0oooo0P0000090?oooa/0dLfYC000000F0=7=Z@005@3AcJT2
000000X0oooo0`00000:0?ooo`@000001@3oool300000080oooo0`0000070?ooo`D000001`3oool3
00000080oooo0`0000050?ooo`8000006`3AcJU<0?oooa/0dLfY100000090?ooo`<000002@3oool2
000000T0oooo1P0000030?ooo`8000000P3oool2000000<0oooo0P0000040?ooo`<000000P3oool2
00000080oooo0`0000020?ooo`8000006`3AcJT2000000T0oooo0P0000090?ooo`8000002@3oool2
000000P0oooo0`0000080?ooo`8000002@3oool2000000T0oooo6`3AcJU<0?oooaH0dLfY000E0=7=
Z@8000002P3oool3000000X0oooo100000050?ooo`<000000P3oool3000000L0oooo1@0000070?oo
o`<000000P3oool3000000D0oooo0P00000K0=7=ZD`0oooo6`3AcJT4000000T0oooo0`0000090?oo
o`8000002@3oool6000000<0oooo0P0000020?ooo`8000000`3oool2000000@0oooo0`0000020?oo
o`8000000P3oool300000080oooo0P00000K0=7=Z@8000002@3oool2000000T0oooo0P0000090?oo
o`800000203oool3000000P0oooo0P0000090?ooo`8000002@3ooolK0=7=ZD`0oooo5P3AcJT001D0
dLfY303oool3000000`0oooo0P00000:0?ooo`X000001@3oool:000000X0oooo0P00000K0=7=ZD`0
00006`3AcJT4000000T0oooo0`0000090?ooo`8000002@3oool6000000<0oooo0P0000020?ooo`80
00000`3oool2000000@0oooo0`0000020?ooo`8000000P3oool300000080oooo0P00000K0=7=Z@80
00002@3oool2000000T0oooo0P0000090?ooo`800000203oool3000000P0oooo0P0000090?ooo`80
00002@3ooolK0=7=ZD`0oooo5P3AcJT001D0dLfY303oool3000000`0oooo0P00000:0?ooo`X00000
1@3oool:000000X0oooo0P00000K0=7=ZD`000006`3AcJT40?ooo``000002@3oool;000000@0oooo
0P0000050?ooo`8000000P3oool5000000@0oooo1@0000020?ooo`8000001@3oool2000001/0dLfY
0P0000020?ooo`D000000P3oool200000080oooo1@0000020?ooo`8000000P3oool4000000<0oooo
0P0000020?ooo`@000000P3oool300000080oooo100000020?ooo`8000000`3oool400000080oooo
0P0000030?ooo`@000000P3ooolK0=7=ZD`0oooo5P3AcJT001D0dLfY303oool3000000`0oooo0P00
000:0?ooo`X000001@3oool:000000X0oooo0P00000K0=7=ZD`0oooo6`3AcJT40?ooo``000002@3o
ool;000000@0oooo0P0000050?ooo`8000000P3oool5000000@0oooo1@0000020?ooo`8000001@3o
ool2000001/0dLfY0P0000020?ooo`D000000P3oool200000080oooo1@0000020?ooo`8000000P3o
ool4000000<0oooo0P0000020?ooo`@000000P3oool300000080oooo100000020?ooo`8000000`3o
ool400000080oooo0P0000030?ooo`@000000P3ooolK0=7=ZD`000005P3AcJT001D0dLfY2P000002
0?ooo`<000000P3oool<000000<0oooo0P00000=0?ooo`T000003@3oool2000000<0oooo0P00000K
0=7=ZD`0oooo6`3AcJT7000000/0oooo1000000<0?ooo`P000000`3oool2000000@0oooo0`000009
0?ooo`800000103oool300000080oooo0P00000K0=7=Z@8000000P3oool500000080oooo0P000002
0?ooo`D000000P3oool200000080oooo100000030?ooo`8000000P3oool400000080oooo0`000002
0?ooo`@000000P3oool2000000<0oooo100000020?ooo`8000000`3oool400000080oooo6`3AcJU<
000001H0dLfY000E0=7=Z@X000000P3oool300000080oooo300000030?ooo`8000003@3oool90000
00d0oooo0P0000030?ooo`8000006`3AcJU<0?oooa/0dLfY1`00000;0?ooo`@00000303oool80000
00<0oooo0P0000040?ooo`<000002@3oool2000000@0oooo0`0000020?ooo`8000006`3AcJU<0000
01/0dLfYC03ooolF0=7=Z@005@3AcJT70?ooo`d000002@3oool3000000D0oooo0P0000050?ooo`<0
00002@3oool3000000D0oooo0P0000050?ooo`<000000P3ooolK0=7=ZD`0oooo6`3AcJT70?ooo`80
00002@3oool4000000T0oooo0`0000080?ooo`<000000P3oool200000080oooo3P0000020?ooo`80
00000`3oool200000080oooo6`3AcJU<000001/0dLfYC03ooolF0=7=Z@005@3AcJT70?ooo`d00000
2@3oool3000000D0oooo0P0000050?ooo`<000002@3oool3000000D0oooo0P0000050?ooo`<00000
0P3ooolK0=7=ZD`0oooo6`3AcJT70?ooo`8000002@3oool4000000T0oooo0`0000080?ooo`<00000
0P3oool200000080oooo3P0000020?ooo`8000000`3oool200000080oooo6`3AcJT200000080oooo
1@0000020?ooo`8000000P3oool500000080oooo0P0000020?ooo`@000000`3oool200000080oooo
100000020?ooo`<000000P3oool400000080oooo0P0000030?ooo`@000000P3oool2000000<0oooo
100000020?oooa/0dLfYC03ooolF0=7=Z@005@3AcJT70?ooo`d000002@3oool3000000D0oooo0P00
00050?ooo`<000002@3oool3000000D0oooo0P0000050?ooo`<000000P3ooolK0=7=ZD`000006`3A
cJT40?ooo`<00000103oool5000000T0oooo100000050?ooo`800000103oool2000000L0oooo0P00
000>0?ooo`8000001`3oool2000001/0dLfY0P0000020?ooo`D000000P3oool200000080oooo1@00
00020?ooo`8000000P3oool4000000<0oooo0P0000020?ooo`@000000P3oool300000080oooo1000
00020?ooo`8000000`3oool400000080oooo0P0000030?ooo`@000000P3ooolK0=7=ZD`0oooo5P3A
cJT001D0dLfY1@3oool2000000D0oooo0`0000050?ooo`8000001@3oool2000000<0oooo0P00000=
0?ooo`8000001@3oool2000000d0oooo0P0000030?ooo`8000006`3AcJU<000001/0dLfY103oool3
000000@0oooo1@0000090?ooo`@000001@3oool2000000@0oooo0P0000070?ooo`8000003P3oool2
000000L0oooo0P00000K0=7=Z@8000002@3oool2000000T0oooo0P0000090?ooo`800000203oool3
000000P0oooo0P0000090?ooo`8000002@3ooolK0=7=ZD`0oooo5P3AcJT001D0dLfY1@3oool20000
00D0oooo0`0000050?ooo`8000001@3oool2000000<0oooo0P00000=0?ooo`8000001@3oool20000
00d0oooo0P0000030?ooo`8000006`3AcJU<0?oooa/0dLfY103oool3000000@0oooo1@0000090?oo
o`@000001@3oool2000000@0oooo0P0000070?ooo`8000003P3oool2000000L0oooo0P00000K0=7=
Z@8000002@3oool2000000T0oooo0P0000090?ooo`800000203oool3000000P0oooo0P0000090?oo
o`8000002@3ooolK0=7=ZD`000005P3AcJT001D0dLfY1`3oool=000001<0oooo200000090?ooo`P0
0000303ooolK0=7=ZD`0oooo6`3AcJT70?ooo`8000000P3oool5000000T0oooo100000020?ooo`<0
0000203oool700000080oooo0`0000090?ooo`8000000P3oool700000080oooo6`3AcJT2000000T0
oooo0P0000090?ooo`8000002@3oool2000000P0oooo0`0000080?ooo`8000002@3oool2000000T0
oooo6`3AcJU<000001H0dLfY000E0=7=Z@L0oooo3@00000C0?ooo`P000002@3oool8000000`0oooo
6`3AcJU<0?oooa/0dLfY1`3oool200000080oooo1@0000090?ooo`@000000P3oool3000000P0oooo
1`0000020?ooo`<000002@3oool200000080oooo1`0000020?oooa/0dLfY0P0000090?ooo`800000
2@3oool2000000T0oooo0P0000080?ooo`<00000203oool2000000T0oooo0P0000090?oooa/0dLfY
C03ooolF0=7=Z@005@3AcJT70?ooo`d000004`3oool8000000T0oooo2000000<0?oooa/0dLfYC03o
oolK0=7=Z@L000000P3oool2000000L0oooo100000070?ooo`8000000`3oool;00000080oooo0P00
00070?ooo`@000001`3oool2000000<0oooo1000000K0=7=Z@8000000P3oool500000080oooo0P00
00020?ooo`D000000P3oool200000080oooo100000030?ooo`8000000P3oool400000080oooo0`00
00020?ooo`@000000P3oool2000000<0oooo100000020?ooo`8000000`3oool400000080oooo6`3A
cJU<0?oooaH0dLfY000E0=7=Z@X000000P3oool300000080oooo2P0000020?ooo`<000000P3oool3
00000080oooo0`0000020?ooo`l000000P3oool300000080oooo0`0000020?ooo`<000000P3ooolK
0=7=ZD`0oooo6`3AcJT700000080oooo0P0000070?ooo`@000001`3oool2000000<0oooo2`000002
0?ooo`8000001`3oool4000000L0oooo0P0000030?ooo`@000006`3AcJT200000080oooo1@000002
0?ooo`8000000P3oool500000080oooo0P0000020?ooo`@000000`3oool200000080oooo10000002
0?ooo`<000000P3oool400000080oooo0P0000030?ooo`@000000P3oool2000000<0oooo10000002
0?oooa/0dLfYC03ooolF0=7=Z@005@3AcJT:00000080oooo0`0000020?ooo`X000000P3oool30000
0080oooo0`0000020?ooo`<000000P3oool?00000080oooo0`0000020?ooo`<000000P3oool30000
0080oooo6`3AcJU<000001/0dLfY103oool3000000@0oooo0P0000050?ooo`@000001@3oool20000
00D0oooo0P00000;0?ooo`8000001`3oool4000000L0oooo0P0000070?oooa/0dLfY0P0000020?oo
o`D000000P3oool200000080oooo1@0000020?ooo`8000000P3oool4000000<0oooo0P0000020?oo
o`@000000P3oool300000080oooo100000020?ooo`8000000`3oool400000080oooo0P0000030?oo
o`@000000P3ooolK0=7=ZD`0oooo5P3AcJT001D0dLfY0P00000:0?ooo`<000002P3oool4000000<0
oooo0P0000030?ooo`D000004`3oool5000000<0oooo0P0000030?ooo`8000006`3AcJU<000001/0
dLfY103oool3000000@0oooo0P0000050?ooo`@000001@3oool2000000D0oooo0P00000;0?ooo`80
00001`3oool4000000L0oooo0P0000070?oooa/0dLfYC000000K0=7=ZD`000005P3AcJT001D0dLfY
0P00000:0?ooo`<000002P3oool4000000<0oooo0P0000030?ooo`D000004`3oool5000000<0oooo
0P0000030?ooo`8000006`3AcJU<0?oooa/0dLfY0P3oool500000080oooo0P00000B0?ooo`800000
0`3oool4000000T0oooo0P0000020?ooo`<000002@3oool200000080oooo0P0000070?oooa/0dLfY
C000000K0=7=ZD`000005P3AcJT001D0dLfY0P00000:0?ooo`<000002P3oool4000000<0oooo0P00
00030?ooo`D000004`3oool5000000<0oooo0P0000030?ooo`8000006`3AcJU<0?oooa/0dLfY0P3o
ool500000080oooo0P00000B0?ooo`8000000`3oool4000000T0oooo0P0000020?ooo`<000002@3o
ool200000080oooo0P0000070?oooa/0dLfY0P0000020?ooo`D000000P3oool200000080oooo1@00
00020?ooo`8000000P3oool4000000<0oooo0P0000020?ooo`@000000P3oool300000080oooo1000
00020?ooo`8000000`3oool400000080oooo0P0000030?ooo`@000000P3ooolK0=7=ZD`0oooo5P3A
cJT001D0dLfY0P3oool3000000L0oooo0`0000070?ooo`<000000P3oool2000000P0oooo0P00000I
0?ooo`800000203oool2000001/0dLfYC03ooolK0=7=Z@80oooo1@0000020?ooo`8000004P3oool2
000000<0oooo100000090?ooo`8000000P3oool3000000T0oooo0P0000020?ooo`8000001`3ooolK
0=7=Z@8000000P3oool500000080oooo0P0000020?ooo`D000000P3oool200000080oooo10000003
0?ooo`8000000P3oool400000080oooo0`0000020?ooo`@000000P3oool2000000<0oooo10000002
0?ooo`8000000`3oool400000080oooo6`3AcJU<0?oooaH0dLfY000E0=7=Z@80oooo0`0000070?oo
o`<000001`3oool300000080oooo0P0000080?ooo`8000006@3oool2000000P0oooo0P00000K0=7=
ZD`0oooo6`3AcJT20?ooo`8000000`3oool200000080oooo1`0000040?ooo`L000000P3oool30000
0080oooo0P0000020?ooo`D000000P3oool4000000h0oooo100000030?ooo`@000006`3AcJT20000
00T0oooo0P0000090?ooo`8000002@3oool2000000P0oooo0`0000080?ooo`8000002@3oool20000
00T0oooo6`3AcJU<0?oooaH0dLfY000E0=7=Z@L0oooo0`0000020?ooo`<000000P3oool3000000L0
oooo0P0000080?oooad00000203oool2000001/0dLfYC03ooolK0=7=Z@80oooo0P0000030?ooo`80
00000P3oool7000000@0oooo1`0000020?ooo`<000000P3oool200000080oooo1@0000020?ooo`@0
00003P3oool4000000<0oooo1000000K0=7=Z@8000002@3oool2000000T0oooo0P0000090?ooo`80
0000203oool3000000P0oooo0P0000090?ooo`8000002@3ooolK0=7=ZD`0oooo5P3AcJT001D0dLfY
1`3oool300000080oooo0`0000020?ooo`<000001`3oool2000000P0oooo7@0000080?ooo`800000
6`3AcJU<000001/0dLfY100000070?ooo`8000000`3oool2000000@0oooo0`0000020?ooo`800000
1`3oool;00000080oooo4P0000020?ooo`L000006`3AcJT2000000T0oooo0P0000090?ooo`800000
2@3oool2000000P0oooo0`0000080?ooo`8000002@3oool2000000T0oooo6`3AcJU<000001H0dLfY
000E0=7=Z@L0oooo0`0000020?ooo`<000000P3oool3000000L0oooo0P0000080?oooad00000203o
ool2000001/0dLfYC000000K0=7=Z@@000001`3oool2000000<0oooo0P0000040?ooo`<000000P3o
ool2000000L0oooo2`0000020?oooa8000000P3oool7000001/0dLfY0P0000090?ooo`8000002@3o
ool2000000T0oooo0P0000080?ooo`<00000203oool2000000T0oooo0P0000090?oooa/0dLfYC000
000F0=7=Z@005@3AcJT:0?ooo`L000002P3oool2000000<0oooo0P00000S0?ooo`8000000`3oool2
000001/0dLfYC03ooolK0=7=Z@/0oooo0P0000030?ooo`800000103oool300000080oooo0P00000;
0?ooo`L000005P3oool7000001/0dLfY0P0000020?ooo`D000000P3oool200000080oooo1@000002
0?ooo`8000000P3oool4000000<0oooo0P0000020?ooo`@000000P3oool300000080oooo10000002
0?ooo`8000000`3oool400000080oooo0P0000030?ooo`@000000P3ooolK0=7=ZD`000005P3AcJT0
01D0dLfY2P3oool7000000X0oooo0P0000030?ooo`8000008`3oool2000000<0oooo0P00000K0=7=
ZD`0oooo6`3AcJT;0?ooo`8000000`3oool2000000@0oooo0`0000020?ooo`8000002`3oool70000
01H0oooo1`00000K0=7=Z@8000000P3oool500000080oooo0P0000020?ooo`D000000P3oool20000
0080oooo100000030?ooo`8000000P3oool400000080oooo0`0000020?ooo`@000000P3oool20000
00<0oooo100000020?ooo`8000000`3oool400000080oooo6`3AcJU<0?oooaH0dLfY000E0=7=Z@80
oooo5`0000020?ooo`D000009`3oool5000001/0dLfYC03ooolK0=7=Z@8000000P3oool500000080
oooo1`0000040?ooo`L000000P3oool500000080oooo0P0000020?ooo`<000006`3oool200000080
oooo6`3AcJT200000080oooo1@0000020?ooo`8000000P3oool500000080oooo0P0000020?ooo`@0
00000`3oool200000080oooo100000020?ooo`<000000P3oool400000080oooo0P0000030?ooo`@0
00000P3oool2000000<0oooo100000020?oooa/0dLfYC03ooolF0=7=Z@005@3AcJT20?oooaL00000
0P3oool5000002L0oooo1@00000K0=7=ZD`0oooo6`3AcJT200000080oooo1@0000020?ooo`L00000
103oool700000080oooo1@0000020?ooo`8000000P3oool3000001/0oooo0P0000020?oooa/0dLfY
C000000K0=7=ZD`0oooo5P3AcJT001D0dLfY0P3ooolG00000080oooo1@00000W0?ooo`D000006`3A
cJU<0?oooa/0dLfY0P0000020?ooo`D000000P3oool7000000@0oooo1`0000020?ooo`D000000P3o
ool200000080oooo0`00000K0?ooo`8000000P3ooolK0=7=ZD`000006`3AcJU<0?oooaH0dLfY000E
0=7=Z@D000001@3oool7000000D0oooo1@0000020?ooobd000000P3ooolK0=7=ZD`000006`3AcJT2
0?ooo`T000004P3oool9000000@0oooo800000020?oooa/0dLfY0P0000020?ooo`D000000P3oool2
00000080oooo1@0000020?ooo`8000000P3oool4000000<0oooo0P0000020?ooo`@000000P3oool3
00000080oooo100000020?ooo`8000000`3oool400000080oooo0P0000030?ooo`@000000P3ooolK
0=7=ZD`000005P3AcJT001D0dLfY1@0000050?ooo`L000001@3oool500000080oooo;@0000020?oo
oa/0dLfYC000000K0=7=Z@80oooo2@00000B0?ooo`T00000103ooolP00000080oooo6`3AcJT20000
0080oooo1@0000020?ooo`8000000P3oool500000080oooo0P0000020?ooo`@000000`3oool20000
0080oooo100000020?ooo`<000000P3oool400000080oooo0P0000030?ooo`@000000P3oool20000
00<0oooo100000020?oooa/0dLfYC000000F0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY
5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT00?l0
dLfYo`3AcJTE0=7=Z@00=`3AcJT2@00000<0dLfY1D00001M0=7=Z@900000103AcJT2@00005l0dLfY
0T0000050=7=Z@=00000G@3AcJT2@00000@0dLfY0T00001O0=7=Z@9000000`3AcJT3@00003P0dLfY
000f0=7=Z@04@000003AcJT0dLfY@00000@0dLfY00=000000=7=Z@3AcJT0G03AcJT014000000dLfY
0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00005d0dLfY00A000000=7=Z@3AcJU000001@3AcJT0
0d000000dLfY0=7=Z@1K0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000
G@3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@00003L0dLfY000h0=7=Z@03
@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0GP3AcJT00d000000dLfY0=7=Z@030=7=Z@03
@000003AcJT0dLfY05h0dLfY00A000000=7=Z@3AcJT0dLfY1D00001N0=7=Z@03@000003AcJT0dLfY
00@0dLfY00=000000=7=Z@3AcJT0G@3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=00000
0=7=Z@3AcJT0=@3AcJT003T0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@1O0=7=
Z@03@000003AcJT0dLfY00<0dLfY00=000000=7=Z@3AcJT0GP3AcJT014000000dLfY0=7=ZD000002
0=7=Z@03@000003AcJT0dLfY05h0dLfY00A000000=7=Z@3AcJT0dLfY0T00001Q0=7=Z@03@000003A
cJT0dLfY00=00000>03AcJT003H0dLfY00A000000=7=Z@3AcJU00000103AcJT00d000000dLfY0=7=
Z@1L0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3AcJU00000G@3AcJT014000000
dLfY0=7=ZD0000030=7=Z@03@000003AcJU0000005d0dLfY00A000000=7=Z@3AcJU000000`3AcJT0
0d000000dLfY0=7=Z@1M0=7=Z@04@000003AcJT0dLfY@00000<0dLfY00=000000=7=Z@3AcJT0=`3A
cJT003L0dLfY0T0000040=7=Z@900000G`3AcJT2@00000@0dLfY0T00001O0=7=Z@9000001@3AcJT2
@00005h0dLfY0T0000040=7=Z@=00000GP3AcJT2@00000@0dLfY0d00000g0=7=Z@00o`3AcJWo0=7=
ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o
0=7=ZOl0dLfY5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY
5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT00?l0
dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT001D0dLfYCOoooolJ
0=7=ZDgooooo6P3AcJT3000000cooooo0`00000=ooooo`<000003?ooool3000000gooooo0`00000<
oooooaX0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfYCOoooolJ0=7=ZDgooooo6P3AcJT30000
00cooooo0`00000=ooooo`<000003?ooool3000000gooooo0`00000<oooooaX0dLfYC03ooolK0=7=
ZD`0oooo5P3AcJT001D0dLfYCOoooolJ0=7=ZDgooooo6P3AcJT3000000cooooo0`00000=ooooo`<0
00003?ooool3000000gooooo0`00000<oooooaX0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfY
COoooolJ0=7=ZDgooooo6P3AcJT3000000cooooo0`00000=ooooo`<000003?ooool3000000gooooo
0`00000<oooooaX0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfYCOoooolJ0=7=ZDgooooo6P3A
cJT3000000cooooo0`00000=ooooo`<000003?ooool3000000gooooo0`00000<oooooaX0dLfYC03o
oolK0=7=ZD`0oooo5P3AcJT001D0dLfYCOoooolJ0=7=ZDgooooo6P3AcJT3000000cooooo0`00000=
ooooo`<000003?ooool3000000gooooo0`00000<oooooaX0dLfYC03ooolK0=7=ZD`000005P3AcJT0
01D0dLfYCOoooolJ0=7=ZDd000006P3AcJT3000000?ooooo1P000003ooooo`<000000oooool70000
00?ooooo0`000003ooooo`H000000oooool3000000?ooooo1`000003ooooo`<000000oooool60000
00?ooooo6P3AcJU<000001/0dLfYC000000F0=7=Z@005@3AcJU=000001X0dLfYC@00000J0=7=Z@<0
00000oooool6000000?ooooo0`000003ooooo`L000000oooool3000000?ooooo1P000003ooooo`<0
00000oooool7000000?ooooo0`000003ooooo`H000000ooooolJ0=7=ZD`000006`3AcJU<000001H0
dLfY000E0=7=ZDd000006P3AcJU=000001X0dLfY0`000003ooooo`H000000oooool3000000?ooooo
1`000003ooooo`<000000oooool6000000?ooooo0`000003ooooo`L000000oooool3000000?ooooo
1P000003oooooaX0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfYC@00000J0=7=ZDgooooo6P3A
cJU=000001X0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfYC@00000J0=7=ZDgooooo6P3AcJU=
000001X0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfYCOoooolJ0=7=ZDgooooo6P3AcJU=0000
01X0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfYCOoooolJ0=7=ZDgooooo6P3AcJT3000000?o
oooo1P000003ooooo`<000000oooool7000000?ooooo0`000003ooooo`H000000oooool3000000?o
oooo1`000003ooooo`<000000oooool6000000?ooooo6P3AcJU<0?oooa/0dLfYC03ooolF0=7=Z@00
5@3AcJU=oooooaX0dLfYCOoooolJ0=7=Z@<000000oooool6000000?ooooo0`000003ooooo`L00000
0oooool3000000?ooooo1P000003ooooo`<000000oooool7000000?ooooo0`000003ooooo`H00000
0ooooolJ0=7=ZD`0oooo6`3AcJU<000001H0dLfY000E0=7=ZDgooooo6P3AcJU=oooooaX0dLfY0`00
0003ooooo`H000000oooool3000000?ooooo1`000003ooooo`<000000oooool6000000?ooooo0`00
0003ooooo`L000000oooool3000000?ooooo1P000003oooooaX0dLfYC000000K0=7=ZD`000005P3A
cJT001D0dLfYCOoooolJ0=7=ZDgooooo6P3AcJT3000000cooooo0`00000=ooooo`<000003?ooool3
000000gooooo0`00000<oooooaX0dLfYC000000K0=7=ZD`0oooo5P3AcJT001D0dLfYCOoooolJ0=7=
ZDd000006P3AcJT3000000cooooo0`00000=ooooo`<000003?ooool3000000gooooo0`00000<oooo
oaX0dLfYC000000K0=7=ZD`0oooo5P3AcJT001D0dLfYCOoooolJ0=7=ZDd000006P3AcJT3000000co
oooo0`00000=ooooo`<000003?ooool3000000gooooo0`00000<oooooaX0dLfYC03ooolK0=7=ZD`0
oooo5P3AcJT001D0dLfYC@00000J0=7=ZDd000006P3AcJT3000000cooooo0`00000=ooooo`<00000
3?ooool3000000gooooo0`00000<oooooaX0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfYC@00
000J0=7=ZDgooooo6P3AcJT3000000cooooo0`00000=ooooo`<000003?ooool3000000gooooo0`00
000<oooooaX0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfYC@00000J0=7=ZDgooooo6P3AcJT3
000000cooooo0`00000=ooooo`<000003?ooool3000000gooooo0`00000<oooooaX0dLfYC03ooolK
0=7=ZD`000005P3AcJT001D0dLfYCOoooolJ0=7=ZDgooooo6P3AcJT3000000?ooooo1P000003oooo
o`<000000oooool7000000?ooooo0`000003ooooo`H000000oooool3000000?ooooo1`000003oooo
o`<000000oooool6000000?ooooo6P3AcJU<0?oooa/0dLfYC000000F0=7=Z@005@3AcJU=oooooaX0
dLfYCOoooolJ0=7=Z@<000000oooool6000000?ooooo0`000003ooooo`L000000oooool3000000?o
oooo1P000003ooooo`<000000oooool7000000?ooooo0`000003ooooo`H000000ooooolJ0=7=ZD`0
oooo6`3AcJU<000001H0dLfY000E0=7=ZDgooooo6P3AcJU=oooooaX0dLfY0`000003ooooo`H00000
0oooool3000000?ooooo1`000003ooooo`<000000oooool6000000?ooooo0`000003ooooo`L00000
0oooool3000000?ooooo1P000003oooooaX0dLfYC000000K0=7=ZD`0oooo5P3AcJT001D0dLfYCOoo
oolJ0=7=ZDgooooo6P3AcJU=000001X0dLfYC000000K0=7=ZD`0oooo5P3AcJT001D0dLfYCOoooolJ
0=7=ZDd000006P3AcJU=000001X0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfYCOoooolJ0=7=
ZDd000006P3AcJU=000001X0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfYCOoooolJ0=7=ZDd0
00006P3AcJT3000000?ooooo1P000003ooooo`<000000oooool7000000?ooooo0`000003ooooo`H0
00000oooool3000000?ooooo1`000003ooooo`<000000oooool6000000?ooooo6P3AcJU<0?oooa/0
dLfYC03ooolF0=7=Z@005@3AcJU=oooooaX0dLfYCOoooolJ0=7=Z@<000000oooool6000000?ooooo
0`000003ooooo`L000000oooool3000000?ooooo1P000003ooooo`<000000oooool7000000?ooooo
0`000003ooooo`H000000ooooolJ0=7=ZD`0oooo6`3AcJU<000001H0dLfY000E0=7=ZDd000006P3A
cJU=oooooaX0dLfY0`000003ooooo`H000000oooool3000000?ooooo1`000003ooooo`<000000ooo
ool6000000?ooooo0`000003ooooo`L000000oooool3000000?ooooo1P000003oooooaX0dLfYC03o
oolK0=7=ZD`000005P3AcJT001D0dLfYC@00000J0=7=ZDgooooo6P3AcJT3000000cooooo0`00000=
ooooo`<000003?ooool3000000gooooo0`00000<oooooaX0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT0
01D0dLfYC@00000J0=7=ZDgooooo6P3AcJT3000000cooooo0`00000=ooooo`<000003?ooool30000
00gooooo0`00000<oooooaX0dLfYC000000K0=7=ZD`0oooo5P3AcJT001D0dLfYCOoooolJ0=7=ZDgo
oooo6P3AcJT3000000cooooo0`00000=ooooo`<000003?ooool3000000gooooo0`00000<oooooaX0
dLfYC000000K0=7=ZD`0oooo5P3AcJT001D0dLfYCOoooolJ0=7=ZDgooooo6P3AcJT3000000cooooo
0`00000=ooooo`<000003?ooool3000000gooooo0`00000<oooooaX0dLfYC000000K0=7=ZD`0oooo
5P3AcJT001D0dLfYCOoooolJ0=7=ZDgooooo6P3AcJT3000000cooooo0`00000=ooooo`<000003?oo
ool3000000gooooo0`00000<oooooaX0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfYCOoooolJ
0=7=ZDd000006P3AcJT3000000cooooo0`00000=ooooo`<000003?ooool3000000gooooo0`00000<
oooooaX0dLfYC03ooolK0=7=ZD`000005P3AcJT001D0dLfYCOoooolJ0=7=ZDd000006P3AcJT30000
00?ooooo1P000003ooooo`<000000oooool7000000?ooooo0`000003ooooo`H000000oooool30000
00?ooooo1`000003ooooo`<000000oooool6000000?ooooo6P3AcJU<0?oooa/0dLfYC000000F0=7=
Z@005@3AcJU=oooooaX0dLfYC@00000J0=7=Z@<000000oooool6000000?ooooo0`000003ooooo`L0
00000oooool3000000?ooooo1P000003ooooo`<000000oooool7000000?ooooo0`000003ooooo`H0
00000ooooolJ0=7=ZD`0oooo6`3AcJU<000001H0dLfY000E0=7=ZDgooooo6P3AcJU=oooooaX0dLfY
0`000003ooooo`H000000oooool3000000?ooooo1`000003ooooo`<000000oooool6000000?ooooo
0`000003ooooo`L000000oooool3000000?ooooo1P000003oooooaX0dLfYC03ooolK0=7=ZD`0oooo
5P3AcJT001D0dLfYC@00000J0=7=ZDgooooo6P3AcJU=000001X0dLfYC000000K0=7=ZD`0oooo5P3A
cJT001D0dLfYC@00000J0=7=ZDgooooo6P3AcJU=000001X0dLfYC000000K0=7=ZD`0oooo5P3AcJT0
01D0dLfYC@00000J0=7=ZDgooooo6P3AcJU=000001X0dLfYC000000K0=7=ZD`0oooo5P3AcJT001D0
dLfYC@00000J0=7=ZDgooooo6P3AcJT3000000?ooooo1P000003ooooo`<000000oooool7000000?o
oooo0`000003ooooo`H000000oooool3000000?ooooo1`000003ooooo`<000000oooool6000000?o
oooo6P3AcJU<0?oooa/0dLfYC03ooolF0=7=Z@005@3AcJU=oooooaX0dLfYCOoooolJ0=7=Z@<00000
0oooool6000000?ooooo0`000003ooooo`L000000oooool3000000?ooooo1P000003ooooo`<00000
0oooool7000000?ooooo0`000003ooooo`H000000ooooolJ0=7=ZD`0oooo6`3AcJU<000001H0dLfY
000E0=7=ZDgooooo6P3AcJU=000001X0dLfY0`000003ooooo`H000000oooool3000000?ooooo1`00
0003ooooo`<000000oooool6000000?ooooo0`000003ooooo`L000000oooool3000000?ooooo1P00
0003oooooaX0dLfYC03ooolK0=7=ZD`000005P3AcJT001D0dLfYCOoooolJ0=7=ZDd000006P3AcJT3
000000cooooo0`00000=ooooo`<000003?ooool3000000gooooo0`00000<oooooaX0dLfYC03ooolK
0=7=ZD`000005P3AcJT001D0dLfYCOoooolJ0=7=ZDd000006P3AcJT3000000cooooo0`00000=oooo
o`<000003?ooool3000000gooooo0`00000<oooooaX0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0
dLfYCOoooolJ0=7=ZDgooooo6P3AcJT3000000cooooo0`00000=ooooo`<000003?ooool3000000go
oooo0`00000<oooooaX0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfYCOoooolJ0=7=ZDgooooo
6P3AcJT3000000cooooo0`00000=ooooo`<000003?ooool3000000gooooo0`00000<oooooaX0dLfY
C000000K0=7=ZD`0oooo5P3AcJT001D0dLfYCOoooolJ0=7=ZDgooooo6P3AcJT3000000cooooo0`00
000=ooooo`<000003?ooool3000000gooooo0`00000<oooooaX0dLfYC000000K0=7=ZD`0oooo5P3A
cJT001D0dLfYC@00000J0=7=ZDgooooo6P3AcJT3000000cooooo0`00000=ooooo`<000003?ooool3
000000gooooo0`00000<oooooaX0dLfYC000000K0=7=ZD`0oooo5P3AcJT001D0dLfYC@00000J0=7=
ZDgooooo6P3AcJT3000000?ooooo1P000003ooooo`<000000oooool7000000?ooooo0`000003oooo
o`H000000oooool3000000?ooooo1`000003ooooo`<000000oooool6000000?ooooo6P3AcJU<0?oo
oa/0dLfYC000000F0=7=Z@005@3AcJU=000001X0dLfYCOoooolJ0=7=Z@<000000oooool6000000?o
oooo0`000003ooooo`L000000oooool3000000?ooooo1P000003ooooo`<000000oooool7000000?o
oooo0`000003ooooo`H000000ooooolJ0=7=ZD`0oooo6`3AcJU<000001H0dLfY000E0=7=ZDd00000
6P3AcJU=000001X0dLfY0`000003ooooo`H000000oooool3000000?ooooo1`000003ooooo`<00000
0oooool6000000?ooooo0`000003ooooo`L000000oooool3000000?ooooo1P000003oooooaX0dLfY
C03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfYCOoooolJ0=7=ZDd000006P3AcJU=000001X0dLfYC03o
oolK0=7=ZD`0oooo5P3AcJT001D0dLfYCOoooolJ0=7=ZDd000006P3AcJU=000001X0dLfYC03ooolK
0=7=ZD`0oooo5P3AcJT001D0dLfYCOoooolJ0=7=ZDd000006P3AcJU=000001X0dLfYC000000K0=7=
ZD`0oooo5P3AcJT001D0dLfYCOoooolJ0=7=ZDgooooo6P3AcJT3000000?ooooo1P000003ooooo`<0
00000oooool7000000?ooooo0`000003ooooo`H000000oooool3000000?ooooo1`000003ooooo`<0
00000oooool6000000?ooooo6P3AcJU<000001/0dLfYC03ooolF0=7=Z@005@3AcJU=oooooaX0dLfY
COoooolJ0=7=Z@<000000oooool6000000?ooooo0`000003ooooo`L000000oooool3000000?ooooo
1P000003ooooo`<000000oooool7000000?ooooo0`000003ooooo`H000000ooooolJ0=7=ZD`00000
6`3AcJU<000001H0dLfY000E0=7=ZDgooooo6P3AcJU=oooooaX0dLfY0`000003ooooo`H000000ooo
ool3000000?ooooo1`000003ooooo`<000000oooool6000000?ooooo0`000003ooooo`L000000ooo
ool3000000?ooooo1P000003oooooaX0dLfYC03ooolK0=7=ZD`000005P3AcJT001D0dLfYCOoooolJ
0=7=ZDgooooo6P3AcJT3000000cooooo0`00000=ooooo`<000003?ooool3000000gooooo0`00000<
oooooaX0dLfYC03ooolK0=7=ZD`000005P3AcJT001D0dLfYC@00000J0=7=ZDgooooo6P3AcJT30000
00cooooo0`00000=ooooo`<000003?ooool3000000gooooo0`00000<oooooaX0dLfYC03ooolK0=7=
ZD`0oooo5P3AcJT001D0dLfYC@00000J0=7=ZDgooooo6P3AcJT3000000cooooo0`00000=ooooo`<0
00003?ooool3000000gooooo0`00000<oooooaX0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfY
C@00000J0=7=ZDd000006P3AcJT3000000cooooo0`00000=ooooo`<000003?ooool3000000gooooo
0`00000<oooooaX0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfYC@00000J0=7=ZDd000006P3A
cJT3000000cooooo0`00000=ooooo`<000003?ooool3000000gooooo0`00000<oooooaX0dLfYC03o
oolK0=7=ZD`0oooo5P3AcJT001D0dLfYCOoooolJ0=7=ZDd000006P3AcJT3000000cooooo0`00000=
ooooo`<000003?ooool3000000gooooo0`00000<oooooaX0dLfYC000000K0=7=ZD`0oooo5P3AcJT0
01D0dLfYCOoooolJ0=7=ZDgooooo6P3AcJT3000000?ooooo1P000003ooooo`<000000oooool70000
00?ooooo0`000003ooooo`H000000oooool3000000?ooooo1`000003ooooo`<000000oooool60000
00?ooooo6P3AcJU<000001/0dLfYC000000F0=7=Z@005@3AcJU=oooooaX0dLfYCOoooolJ0=7=Z@<0
00000oooool6000000?ooooo0`000003ooooo`L000000oooool3000000?ooooo1P000003ooooo`<0
00000oooool7000000?ooooo0`000003ooooo`H000000ooooolJ0=7=ZD`000006`3AcJU<000001H0
dLfY000E0=7=ZDgooooo6P3AcJU=oooooaX0dLfY0`000003ooooo`H000000oooool3000000?ooooo
1`000003ooooo`<000000oooool6000000?ooooo0`000003ooooo`L000000oooool3000000?ooooo
1P000003oooooaX0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfYCOoooolJ0=7=ZDgooooo6P3A
cJU=000001X0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfYCOoooolJ0=7=ZDgooooo6P3AcJU=
000001X0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfYCOoooolJ0=7=ZDgooooo6P3AcJU=0000
01X0dLfYC03ooolK0=7=ZD`0oooo5P3AcJT001D0dLfYC@00000J0=7=ZDd000006P3AcJT3000000?o
oooo1P000003ooooo`<000000oooool7000000?ooooo0`000003ooooo`H000000oooool3000000?o
oooo1`000003ooooo`<000000oooool6000000?ooooo6P3AcJU<0?oooa/0dLfYC03ooolF0=7=Z@00
5@3AcJU=000001X0dLfYC@00000J0=7=Z@<000000oooool6000000?ooooo0`000003ooooo`L00000
0oooool3000000?ooooo1P000003ooooo`<000000oooool7000000?ooooo0`000003ooooo`H00000
0ooooolJ0=7=ZD`000006`3AcJU<000001H0dLfY000E0=7=ZDd000006P3AcJU=000001X0dLfY0`00
0003ooooo`H000000oooool3000000?ooooo1`000003ooooo`<000000oooool6000000?ooooo0`00
0003ooooo`L000000oooool3000000?ooooo1P000003oooooaX0dLfYC000000K0=7=ZD`000005P3A
cJT001D0dLfYC@00003X0=7=ZD`000006`3AcJU<000001H0dLfY003o0=7=ZOl0dLfY5@3AcJT00?l0
dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT00?l0dLfYo`3AcJTE
0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT003H0dLfY140000020=7=Z@E00000
G03AcJT4@00000@0dLfY0d00001L0=7=Z@A000000`3AcJT2@00005h0dLfY140000040=7=Z@03@000
003AcJT0dLfY05d0dLfY0T0000040=7=Z@900000>03AcJT003H0dLfY00=000000=7=Z@3AcJT01@3A
cJT00d000000dLfY0=7=Z@1L0=7=Z@03@000003AcJT0dLfY00H0dLfY00=000000=7=Z@3AcJT0F`3A
cJT00d000000dLfY0=7=Z@030=7=Z@04@000003AcJT0dLfY@00005d0dLfY00=000000=7=Z@3AcJT0
1@3AcJT00d000000dLfY0=7=Z@1L0=7=Z@04@000003AcJT0dLfY@0000080dLfY00A000000=7=Z@3A
cJU00000=`3AcJT003L0dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@1M0=7=Z@03
@000003AcJT0dLfY0080dLfY1D00001M0=7=Z@03@000003AcJT0dLfY00D0dLfY00=000000=7=Z@3A
cJT0G03AcJT00d000000dLfY0=7=Z@040=7=Z@03@000003AcJT0dLfY05h0dLfY00E000000=7=Z@3A
cJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY03D0dLfY000h0=7=Z@03@000003AcJT0dLfY00<0
dLfY00=000000=7=Z@3AcJT0GP3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=
Z@3AcJT0G@3AcJT00d000000dLfY0=7=Z@020=7=Z@900000H03AcJT00d000000dLfY0=7=Z@040=7=
Z@03@000003AcJT0dLfY05h0dLfY00A000000=7=Z@3AcJU000000P3AcJT00d000000dLfY0=7=Z@0e
0=7=Z@00=P3AcJT014000000dLfY0=7=ZD0000040=7=Z@03@000003AcJT0dLfY05`0dLfY00A00000
0=7=Z@3AcJU000000`3AcJT00d000000dLfY@000001M0=7=Z@04@000003AcJT0dLfY@00000<0dLfY
00=000000=7=Z@3AcJT0G@3AcJT014000000dLfY0=7=ZD0000020=7=Z@04@000003AcJT0dLfY@000
05d0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000g0=7=Z@00=`3AcJT2
@00000@0dLfY0T00001O0=7=Z@9000001@3AcJT2@00005h0dLfY0T0000040=7=Z@=00000GP3AcJT2
@00000<0dLfY1400001N0=7=Z@900000103AcJT2@00003P0dLfY003o0=7=ZOl0dLfY5@3AcJT00?l0
dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT00?l0dLfYo`3AcJTE
0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@00o`3A
cJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0
dLfY003o0=7=ZOl0dLfY5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@005@3AcJU=oooooaX0dLfYCOoooolJ
0=7=Z@d000001Oooool4000000Gooooo3P00000ToooooaX0dLfYCOoooolJ0=7=Z@l00000?_oooolE
0=7=Z@005@3AcJU=oooooaX0dLfYCOoooolJ0=7=Z@d000001Oooool4000000Gooooo3P00000Toooo
oaX0dLfYCOoooolJ0=7=Z@l00000?_oooolE0=7=Z@005@3AcJU=oooooaX0dLfYCOoooolJ0=7=Z@d0
00001Oooool4000000Gooooo3P00000ToooooaX0dLfYCOoooolJ0=7=Z@l00000?_oooolE0=7=Z@00
5@3AcJU=oooooaX0dLfYCOoooolJ0=7=Z@d000001Oooool4000000Gooooo3P00000ToooooaX0dLfY
COoooolJ0=7=Z@l00000?_oooolE0=7=Z@005@3AcJU=oooooaX0dLfYCOoooolJ0=7=Z@d000001Ooo
ool4000000Gooooo3P00000ToooooaX0dLfYCOoooolJ0=7=Z@l00000?_oooolE0=7=Z@005@3AcJU=
oooooaX0dLfYCOoooolJ0=7=Z@d000001Oooool4000000Gooooo3P00000ToooooaX0dLfYCOoooolJ
0=7=Z@l00000?_oooolE0=7=Z@005@3AcJU=oooooaX0dLfYCOoooolJ0=7=Z@d000001Oooool40000
00Gooooo3P00000ToooooaX0dLfYCOoooolJ0=7=Z@l00000?_oooolE0=7=Z@005@3AcJU=oooooaX0
dLfYCOoooolJ0=7=Z@d000001Oooool4000000Gooooo3P00000ToooooaX0dLfYCOoooolJ0=7=Z@?o
oooo20000008ooooocH000001?oooolE0=7=Z@005@3AcJU=oooooaX0dLfYCOoooolJ0=7=Z@d00000
1Oooool4000000Gooooo3P00000ToooooaX0dLfYC@00000J0=7=Z@?ooooo20000008ooooocH00000
1?oooolE0=7=Z@005@3AcJU=oooooaX0dLfYCOoooolJ0=7=Z@Cooooo1@000004ooooo`h000001Ooo
ool4000000Wooooo70000004oooooaX0dLfYC@00000J0=7=Z@?ooooo20000008ooooocH000001?oo
oolE0=7=Z@005@3AcJU=oooooaX0dLfYC@00000J0=7=Z@Cooooo1@000004ooooo`h000001Oooool4
000000Wooooo70000004oooooaX0dLfYC@00000J0=7=Z@?ooooo20000008ooooocH000001?oooolE
0=7=Z@005@3AcJU=oooooaX0dLfYC@00000J0=7=Z@Cooooo1@000004ooooo`h000001Oooool40000
00Wooooo70000004oooooaX0dLfYC@00000J0=7=Z@<000002?ooool4000000Cooooo1000000^oooo
o`@000001?oooolE0=7=Z@005@3AcJU=000001X0dLfYC@00000J0=7=Z@Cooooo1@000004ooooo`h0
00001Oooool4000000Wooooo70000004oooooaX0dLfYCOoooolJ0=7=Z@<000002?ooool4000000Co
oooo1000000^ooooo`@000001?oooolE0=7=Z@005@3AcJU=000001X0dLfYC@00000J0=7=Z@T00000
1?ooool>000000Gooooo2@000004ooooo`D000004_ooool5000000Cooooo6P3AcJU=oooooaX0dLfY
0`000008ooooo`@000001?ooool4000002kooooo10000004oooooaD0dLfY000E0=7=ZDd000006P3A
cJU=000001X0dLfY2@000004ooooo`h000001Oooool9000000Cooooo1@00000Booooo`D000001?oo
oolJ0=7=ZDgooooo6P3AcJT3000000Sooooo10000004ooooo`@00000;_ooool4000000Cooooo5@3A
cJT001D0dLfYC@00000J0=7=ZDgooooo6P3AcJT9000000Cooooo3P000005ooooo`T000001?ooool5
000001;ooooo1@000004oooooaX0dLfYCOoooolJ0=7=Z@?ooooo20000004ooooo``000009oooool;
000001D0dLfY000E0=7=ZDd000006P3AcJU=oooooaX0dLfY2@000004ooooo`h000001Oooool90000
00Cooooo1@00000Booooo`D000001?oooolJ0=7=ZDgooooo6P3AcJT3ooooo`P000001?ooool<0000
02Oooooo2`00000E0=7=Z@005@3AcJU=000001X0dLfYCOoooolJ0=7=Z@T000001?ooool>000000Go
oooo2@000004ooooo`D000004_ooool5000000Cooooo6P3AcJU=oooooaX0dLfY0oooool8000000Co
oooo3000000Wooooo`/000005@3AcJT001D0dLfYC@00000J0=7=ZDgooooo6P3AcJT4000000Gooooo
10000005ooooo`@000001Oooool5000000Cooooo4P00000:ooooo`d000006P3AcJU=oooooaX0dLfY
0oooool8000000Cooooo3000000Wooooo`/000005@3AcJT001D0dLfYCOoooolJ0=7=ZDgooooo6P3A
cJT4000000Gooooo10000005ooooo`@000001Oooool5000000Cooooo4P00000:ooooo`d000006P3A
cJU=oooooaX0dLfY0oooool8000000Cooooo30000004oooooal000001?ooool;000001D0dLfY000E
0=7=ZDgooooo6P3AcJU=oooooaX0dLfY10000005ooooo`@000001Oooool4000000Gooooo1@000004
oooooa8000002_ooool=000001X0dLfYCOoooolJ0=7=Z@?ooooo20000004ooooo``000001?oooolO
000000Cooooo2`00000E0=7=Z@005@3AcJU=oooooaX0dLfYCOoooolJ0=7=Z@@000001Oooool40000
00Gooooo10000005ooooo`D000001?oooolB000000[ooooo3@00000J0=7=ZDd000006P3AcJT3oooo
o`P000001?ooool<000000Cooooo7`000004ooooo`/000005@3AcJT001D0dLfYCOoooolJ0=7=ZDgo
oooo6P3AcJTBooooo`@000005oooool9000000[ooooo2@000004oooooaX0dLfYC@00000J0=7=Z@?o
oooo20000004ooooo``000001?oooolO000000Cooooo2`00000E0=7=Z@005@3AcJU=oooooaX0dLfY
COoooolJ0=7=ZA;ooooo1000000Gooooo`T000002_ooool9000000Cooooo6P3AcJU=000001X0dLfY
0`000008ooooo`@000001?ooool4000000Cooooo1`00000Hooooo`P000000oooool4000000Cooooo
5@3AcJT001D0dLfYCOoooolJ0=7=ZDgooooo6P3AcJTBooooo`@000005oooool9000000[ooooo2@00
0004oooooaX0dLfYC@00000J0=7=Z@<000002?ooool4000000Cooooo10000004ooooo`L000006?oo
ool8000000?ooooo10000004oooooaD0dLfY000E0=7=ZDgooooo6P3AcJU=000001X0dLfY4_ooool4
000001Oooooo2@00000:ooooo`T000001?oooolJ0=7=ZDgooooo6P3AcJT3000000Sooooo10000004
ooooo`@000001?ooool7000001Sooooo20000003ooooo`@000001?oooolE0=7=Z@005@3AcJU=oooo
oaX0dLfYC@00000J0=7=ZA;ooooo1000000Gooooo`T000002_ooool9000000Cooooo6P3AcJU=oooo
oaX0dLfY0oooool8000000Sooooo10000004ooooo`@000000oooool40000013ooooo10000004oooo
o`@000000oooool4000000Cooooo5@3AcJT001D0dLfYCOoooolJ0=7=ZDd000006P3AcJT4ooooo`D0
00002Oooool4000000[ooooo10000005ooooo`@000007?ooool4000001X0dLfYCOoooolJ0=7=Z@?o
oooo20000008ooooo`@000001?ooool4000000?ooooo1000000@ooooo`@000001?ooool4000000?o
oooo10000004oooooaD0dLfY000E0=7=ZDgooooo6P3AcJU=000001X0dLfY1?ooool5000000Wooooo
1000000:ooooo`@000001Oooool4000001cooooo1000000J0=7=ZDgooooo6P3AcJT3ooooo`P00000
2?ooool4000000Cooooo10000003ooooo`@000004?ooool4000000Cooooo10000003ooooo`@00000
1?oooolE0=7=Z@005@3AcJU=oooooaX0dLfYC@00000J0=7=Z@Cooooo1@000009ooooo`@000002_oo
ool4000000Gooooo1000000Looooo`@000006P3AcJU=oooooaX0dLfY0oooool8000000Sooooo1000
0004ooooo`@000000oooool40000013ooooo10000004ooooo`@000000oooool4000000Cooooo5@3A
cJT001D0dLfYCOoooolJ0=7=ZDgooooo6P3AcJT4ooooo`D000002Oooool4000000[ooooo10000005
ooooo`@000007?ooool4000001X0dLfYCOoooolJ0=7=Z@l000001?ooool<000000_ooooo2000000<
ooooo`/000001?oooolE0=7=Z@005@3AcJU=000001X0dLfYCOoooolJ0=7=Z@@000003_ooool40000
00kooooo1@000004ooooo`D000001?ooool:000000Cooooo1@000004oooooaX0dLfYCOoooolJ0=7=
Z@l000001?ooool<000000_ooooo2000000<ooooo`/000001?oooolE0=7=Z@005@3AcJU=000001X0
dLfYCOoooolJ0=7=Z@@000003_ooool4000000kooooo1@000004ooooo`D000001?ooool:000000Co
oooo1@000004oooooaX0dLfYCOoooolJ0=7=Z@l000001?ooool<000000_ooooo2000000<ooooo`/0
00001?oooolE0=7=Z@005@3AcJU=000001X0dLfYCOoooolJ0=7=Z@@000003_ooool4000000kooooo
1@000004ooooo`D000001?ooool:000000Cooooo1@000004oooooaX0dLfYC@00000J0=7=Z@l00000
1?ooool<000000_ooooo2000000<ooooo`/000001?oooolE0=7=Z@005@3AcJU=000001X0dLfYCOoo
oolJ0=7=Z@@000003_ooool4000000kooooo1@000004ooooo`D000001?ooool:000000Cooooo1@00
0004oooooaX0dLfYC@00000J0=7=ZA<000005oooool8000001Oooooo1000000E0=7=Z@005@3AcJU=
000001X0dLfYCOoooolJ0=7=Z@Cooooo2@000005ooooo`@000001Oooool9000000kooooo4P000009
oooooaX0dLfYC@00000J0=7=ZA<000005oooool8000001Oooooo1000000E0=7=Z@005@3AcJU=0000
01X0dLfYCOoooolJ0=7=Z@Cooooo2@000005ooooo`@000001Oooool9000000kooooo4P000009oooo
oaX0dLfYC@00000J0=7=ZA<000005oooool8000001Oooooo1000000E0=7=Z@005@3AcJU=000001X0
dLfYCOoooolJ0=7=Z@Cooooo2@000005ooooo`@000001Oooool9000000kooooo4P000009oooooaX0
dLfYC@00000J0=7=ZA<000005oooool8000001Oooooo1000000E0=7=Z@005@3AcJU=oooooaX0dLfY
COoooolJ0=7=Z@Cooooo2@000005ooooo`@000001Oooool9000000kooooo4P000009oooooaX0dLfY
COoooolJ0=7=ZAL000002?ooool70000013ooooo20000007ooooo`P000005@3AcJT001D0dLfYCOoo
oolJ0=7=ZDgooooo6P3AcJT4ooooo`T000001Oooool4000000Gooooo2@00000>oooooa8000002Ooo
oolJ0=7=ZDgooooo6P3AcJTG000000Sooooo1`00000@ooooo`P000001oooool8000001D0dLfY000E
0=7=ZDgooooo6P3AcJU=000001X0dLfYC@00000J0=7=ZDgooooo6P3AcJTG000000Sooooo1`00000@
ooooo`P000001oooool8000001D0dLfY000E0=7=ZDgooooo6P3AcJU=000001X0dLfYC@00000J0=7=
ZDgooooo6P3AcJTG000000Sooooo1`00000@ooooo`P000001oooool8000001D0dLfY000E0=7=ZDgo
oooo6P3AcJU=000001X0dLfYC@00000J0=7=ZDgooooo6P3AcJTG000000Sooooo1`00000@ooooo`P0
00001oooool8000001D0dLfY000E0=7=ZDgooooo6P3AcJU=000001X0dLfYC@00000J0=7=ZDgooooo
6P3AcJTG000000Sooooo1`00000@ooooo`P000001oooool8000001D0dLfY000E0=7=ZDgooooo6P3A
cJU=000001X0dLfY1?ooool9000000Gooooo10000005ooooo`T000003_oooolB000000Wooooo6P3A
cJU=oooooaX0dLfY5`000008ooooo`L000004?ooool8000000Oooooo2000000E0=7=Z@005@3AcJU=
oooooaX0dLfYCOoooolJ0=7=Z@Cooooo2@000005ooooo`@000001Oooool9000000kooooo4P000009
oooooaX0dLfYCOoooolJ0=7=ZA<000005oooool8000001Oooooo1000000E0=7=Z@005@3AcJU=oooo
oaX0dLfYCOoooolJ0=7=Z@Cooooo2@000005ooooo`@000001Oooool9000000kooooo4P000009oooo
oaX0dLfYC@00000J0=7=ZA<000005oooool8000001Oooooo1000000E0=7=Z@005@3AcJU=oooooaX0
dLfYCOoooolJ0=7=Z@Cooooo2@000005ooooo`@000001Oooool9000000kooooo4P000009oooooaX0
dLfYC@00000J0=7=ZA<000005oooool8000001Oooooo1000000E0=7=Z@005@3AcJU=oooooaX0dLfY
COoooolJ0=7=Z@Cooooo2@000005ooooo`@000001Oooool9000000kooooo4P000009oooooaX0dLfY
C@00000J0=7=ZA<000005oooool8000001Oooooo1000000E0=7=Z@005@3AcJU=oooooaX0dLfYCOoo
oolJ0=7=Z@@000003_ooool4000000kooooo1@000004ooooo`D000001?ooool:000000Cooooo1@00
0004oooooaX0dLfYC@00000J0=7=Z@l000001?ooool<000000_ooooo2000000<ooooo`/000001?oo
oolE0=7=Z@005@3AcJU=000001X0dLfYCOoooolJ0=7=Z@@000003_ooool4000000kooooo1@000004
ooooo`D000001?ooool:000000Cooooo1@000004oooooaX0dLfYCOoooolJ0=7=Z@l000001?ooool<
000000_ooooo2000000<ooooo`/000001?oooolE0=7=Z@005@3AcJU=000001X0dLfYCOoooolJ0=7=
Z@@000003_ooool4000000kooooo1@000004ooooo`D000001?ooool:000000Cooooo1@000004oooo
oaX0dLfYCOoooolJ0=7=Z@l000001?ooool<000000_ooooo2000000<ooooo`/000001?oooolE0=7=
Z@005@3AcJU=000001X0dLfYCOoooolJ0=7=Z@@000003_ooool4000000kooooo1@000004ooooo`D0
00001?ooool:000000Cooooo1@000004oooooaX0dLfYCOoooolJ0=7=Z@l000001?ooool<000000_o
oooo2000000<ooooo`/000001?oooolE0=7=Z@005@3AcJU=000001X0dLfYCOoooolJ0=7=Z@Cooooo
1@000009ooooo`@000002_ooool4000000Gooooo1000000Looooo`@000006P3AcJU=oooooaX0dLfY
0oooool8000000Sooooo10000004ooooo`@000000oooool40000013ooooo10000004ooooo`@00000
0oooool4000000Cooooo5@3AcJT001D0dLfYC@00000J0=7=ZDgooooo6P3AcJT4ooooo`D000002Ooo
ool4000000[ooooo10000005ooooo`@000007?ooool4000001X0dLfYCOoooolJ0=7=Z@?ooooo2000
0008ooooo`@000001?ooool4000000?ooooo1000000@ooooo`@000001?ooool4000000?ooooo1000
0004oooooaD0dLfY000E0=7=ZDd000006P3AcJU=000001X0dLfY1?ooool5000000Wooooo1000000:
ooooo`@000001Oooool4000001cooooo1000000J0=7=ZDgooooo6P3AcJT3ooooo`P000002?ooool4
000000Cooooo10000003ooooo`@000004?ooool4000000Cooooo10000003ooooo`@000001?oooolE
0=7=Z@005@3AcJU=000001X0dLfYC@00000J0=7=Z@Cooooo1@000009ooooo`@000002_ooool40000
00Gooooo1000000Looooo`@000006P3AcJU=oooooaX0dLfY0oooool8000000Sooooo10000004oooo
o`@000000oooool40000013ooooo10000004ooooo`@000000oooool4000000Cooooo5@3AcJT001D0
dLfYCOoooolJ0=7=ZDd000006P3AcJT4ooooo`D000002Oooool4000000[ooooo10000005ooooo`@0
00007?ooool4000001X0dLfYCOoooolJ0=7=Z@<000002?ooool4000000Cooooo10000004ooooo`L0
00006?ooool8000000?ooooo10000004oooooaD0dLfY000E0=7=ZDgooooo6P3AcJU=000001X0dLfY
4_ooool4000001Oooooo2@00000:ooooo`T000001?oooolJ0=7=ZDgooooo6P3AcJT3000000Sooooo
10000004ooooo`@000001?ooool7000001Sooooo20000003ooooo`@000001?oooolE0=7=Z@005@3A
cJU=oooooaX0dLfYC@00000J0=7=ZA;ooooo1000000Gooooo`T000002_ooool9000000Cooooo6P3A
cJU=000001X0dLfY0`000008ooooo`@000001?ooool4000000Cooooo1`00000Hooooo`P000000ooo
ool4000000Cooooo5@3AcJT001D0dLfYCOoooolJ0=7=ZDgooooo6P3AcJTBooooo`@000005oooool9
000000[ooooo2@000004oooooaX0dLfYC@00000J0=7=Z@?ooooo20000004ooooo``000001?oooolO
000000Cooooo2`00000E0=7=Z@005@3AcJU=oooooaX0dLfYCOoooolJ0=7=ZA;ooooo1000000Goooo
o`T000002_ooool9000000Cooooo6P3AcJU=000001X0dLfY0oooool8000000Cooooo30000004oooo
oal000001?ooool;000001D0dLfY000E0=7=ZDgooooo6P3AcJU=oooooaX0dLfY10000005ooooo`@0
00001Oooool4000000Gooooo1@000004oooooa8000002_ooool=000001X0dLfYC@00000J0=7=Z@?o
oooo20000004ooooo``000001?oooolO000000Cooooo2`00000E0=7=Z@005@3AcJU=oooooaX0dLfY
COoooolJ0=7=Z@@000001Oooool4000000Gooooo10000005ooooo`D000001?oooolB000000[ooooo
3@00000J0=7=ZDgooooo6P3AcJT3ooooo`P000001?ooool<000000Cooooo7`000004ooooo`/00000
5@3AcJT001D0dLfYCOoooolJ0=7=ZDgooooo6P3AcJT4000000Gooooo10000005ooooo`@000001Ooo
ool5000000Cooooo4P00000:ooooo`d000006P3AcJU=oooooaX0dLfY0oooool8000000Cooooo3000
000Wooooo`/000005@3AcJT001D0dLfYCOoooolJ0=7=ZDgooooo6P3AcJT4000000Gooooo10000005
ooooo`@000001Oooool5000000Cooooo4P00000:ooooo`d000006P3AcJU=oooooaX0dLfY0oooool8
000000Cooooo3000000Wooooo`/000005@3AcJT001D0dLfYCOoooolJ0=7=ZDgooooo6P3AcJT40000
00Gooooo10000005ooooo`@000001Oooool5000000Cooooo4P00000:ooooo`d000006P3AcJU=oooo
oaX0dLfY0oooool8000000Cooooo3000000Wooooo`/000005@3AcJT001D0dLfYCOoooolJ0=7=ZDgo
oooo6P3AcJT9000000Cooooo3P000005ooooo`T000001?ooool5000001;ooooo1@000004oooooaX0
dLfYCOoooolJ0=7=Z@?ooooo20000004ooooo``000009oooool;000001D0dLfY000E0=7=ZDgooooo
6P3AcJU=oooooaX0dLfY2@000004ooooo`h000001Oooool9000000Cooooo1@00000Booooo`D00000
1?oooolJ0=7=ZDgooooo6P3AcJT3000000Sooooo10000004ooooo`@00000;_ooool4000000Cooooo
5@3AcJT001D0dLfYC@00000J0=7=ZDgooooo6P3AcJT9000000Cooooo3P000005ooooo`T000001?oo
ool5000001;ooooo1@000004oooooaX0dLfYCOoooolJ0=7=Z@<000002?ooool4000000Cooooo1000
000^ooooo`@000001?oooolE0=7=Z@005@3AcJU=000001X0dLfYC@00000J0=7=Z@T000001?ooool>
000000Gooooo2@000004ooooo`D000004_ooool5000000Cooooo6P3AcJU=oooooaX0dLfY0`000008
ooooo`@000001?ooool4000002kooooo10000004oooooaD0dLfY000E0=7=ZDd000006P3AcJU=0000
01X0dLfY1?ooool5000000Cooooo3P000005ooooo`@000002OoooolL000000Cooooo6P3AcJU=0000
01X0dLfY0`000008ooooo`@000001?ooool4000002kooooo10000004oooooaD0dLfY000E0=7=ZDd0
00006P3AcJU=000001X0dLfY1?ooool5000000Cooooo3P000005ooooo`@000002OoooolL000000Co
oooo6P3AcJU=000001X0dLfY0oooool8000000Sooooo=P000004oooooaD0dLfY000E0=7=ZDd00000
6P3AcJU=000001X0dLfY1?ooool5000000Cooooo3P000005ooooo`@000002OoooolL000000Cooooo
6P3AcJU=000001X0dLfY0oooool8000000Sooooo=P000004oooooaD0dLfY000E0=7=ZDd000006P3A
cJU=000001X0dLfY1?ooool5000000Cooooo3P000005ooooo`@000002OoooolL000000Cooooo6P3A
cJU=000001X0dLfY0oooool8000000Sooooo=P000004oooooaD0dLfY003o0=7=ZD/0dLfYC@00000J
0=7=Z@?ooooo20000008ooooocH000001?oooolE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0
dLfY5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT0
0?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY000f0=7=Z@E0000000<0dLfY@00004000000
0T00001M0=7=Z@E000000P3AcJT2@00005h0dLfY1D0000030=7=Z@03@000003AcJT0dLfY05`0dLfY
1D0000020=7=Z@900000GP3AcJT4@00000<0dLfY0T00000h0=7=Z@00>03AcJT01D000000dLfY0=7=
Z@3AcJU000000680dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0dLfY05d0
dLfY00=000000=7=Z@3AcJT00`3AcJT00d000000dLfY0=7=Z@1N0=7=Z@05@000003AcJT0dLfY0=7=
ZD0000000P3AcJT00d000000dLfY0=7=Z@1K0=7=Z@03@000003AcJT0dLfY00<0dLfY00A000000=7=
Z@3AcJU00000=`3AcJT003P0dLfY00=000000=7=Z@3AcJT00P3AcJT00d000000dLfY0=7=Z@1O0=7=
Z@03@000003AcJT0dLfY00@0dLfY00=000000=7=Z@3AcJT0G@3AcJT00d000000dLfY0=7=Z@030=7=
Z@03@000003AcJT0dLfY05h0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03@000003AcJT0
dLfY05`0dLfY00=000000=7=Z@3AcJT00P3AcJT014000000dLfY0=7=ZD00000g0=7=Z@00>03AcJT0
0d000000dLfY0=7=Z@030=7=Z@03@000003AcJT0dLfY05h0dLfY00=000000=7=Z@3AcJT00P3AcJT2
@0000600dLfY00=000000=7=Z@3AcJT0103AcJT00d000000dLfY0=7=Z@1M0=7=Z@03@000003AcJT0
dLfY0080dLfY0T00001P0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=
Z@0e0=7=Z@00>03AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0G@3A
cJT00d000000dLfY0=7=Z@020=7=Z@03@000003AcJT0dLfY05l0dLfY00E000000=7=Z@3AcJT0dLfY
@00000020=7=Z@03@000003AcJT0dLfY05d0dLfY00E000000=7=Z@3AcJT0dLfY@00000020=7=Z@03
@000003AcJT0dLfY05/0dLfY00A000000=7=Z@3AcJU000000P3AcJT014000000dLfY0=7=ZD00000g
0=7=Z@00=`3AcJT2@00000@0dLfY0T00001O0=7=Z@900000103AcJT3@00005h0dLfY0T0000030=7=
Z@A00000GP3AcJT2@00000@0dLfY0T00001O0=7=Z@900000103AcJT2@00003P0dLfY003o0=7=ZOl0
dLfY5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT0
0?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT00?l0dLfYo`3A
cJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@00
o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@005@3AcJU=oooo
oaX0dLfY3`00000noooooaX0dLfYCOoooolJ0=7=ZDgooooo6P3AcJT?000003kooooo5@3AcJT001D0
dLfYCOoooolJ0=7=Z@l00000?_oooolJ0=7=ZDgooooo6P3AcJU=oooooaX0dLfY3`00000noooooaD0
dLfY000E0=7=ZDgooooo6P3AcJT?000003kooooo6P3AcJU=oooooaX0dLfYCOoooolJ0=7=Z@l00000
?_oooolE0=7=Z@005@3AcJU=oooooaX0dLfY3`00000noooooaX0dLfYCOoooolJ0=7=ZDgooooo6P3A
cJT?000003kooooo5@3AcJT001D0dLfYCOoooolJ0=7=Z@l00000?_oooolJ0=7=ZDgooooo6P3AcJU=
oooooaX0dLfY3`00000noooooaD0dLfY000E0=7=ZDgooooo6P3AcJT?000003kooooo6P3AcJU=oooo
oaX0dLfYCOoooolJ0=7=Z@l00000?_oooolE0=7=Z@005@3AcJU=oooooaX0dLfY3`00000noooooaX0
dLfYCOoooolJ0=7=ZDgooooo6P3AcJT?000003kooooo5@3AcJT001D0dLfYCOoooolJ0=7=Z@l00000
?_oooolJ0=7=ZDgooooo6P3AcJU=oooooaX0dLfY3`00000noooooaD0dLfY000E0=7=ZDgooooo6P3A
cJT?000003kooooo6P3AcJU=oooooaX0dLfYCOoooolJ0=7=Z@l00000?_oooolE0=7=Z@005@3AcJU=
oooooaX0dLfY3`00000noooooaX0dLfYCOoooolJ0=7=ZDgooooo6P3AcJT?000003kooooo5@3AcJT0
01D0dLfYCOoooolJ0=7=Z@l00000?_oooolJ0=7=ZDgooooo6P3AcJU=oooooaX0dLfY3`00000noooo
oaD0dLfY000E0=7=ZDgooooo6P3AcJT?000003kooooo6P3AcJU=oooooaX0dLfYCOoooolJ0=7=Z@l0
0000?_oooolE0=7=Z@005@3AcJU=oooooaX0dLfY3`00000noooooaX0dLfYCOoooolJ0=7=ZDgooooo
6P3AcJT?000003kooooo5@3AcJT001D0dLfYCOoooolJ0=7=Z@l00000?_oooolJ0=7=ZDgooooo6P3A
cJU=oooooaX0dLfY3`00000noooooaD0dLfY000E0=7=ZDgooooo6P3AcJT?000003kooooo6P3AcJU=
oooooaX0dLfYCOoooolJ0=7=Z@l00000?_oooolE0=7=Z@005@3AcJU=oooooaX0dLfY3`00000noooo
oaX0dLfYCOoooolJ0=7=ZDgooooo6P3AcJTGooooobh000002?oooolE0=7=Z@005@3AcJU=oooooaX0
dLfY3`00000noooooaX0dLfYCOoooolJ0=7=ZDgooooo6P3AcJTGooooobh000002?oooolE0=7=Z@00
5@3AcJU=oooooaX0dLfY3`00000noooooaX0dLfYCOoooolJ0=7=ZDd000006P3AcJTGooooobh00000
2?oooolE0=7=Z@005@3AcJU=oooooaX0dLfY3`00000noooooaX0dLfYCOoooolJ0=7=ZDd000006P3A
cJTGooooobh000002?oooolE0=7=Z@005@3AcJU=oooooaX0dLfY3`00000noooooaX0dLfYCOoooolJ
0=7=ZDd000006P3AcJTGooooobh000002?oooolE0=7=Z@005@3AcJU=oooooaX0dLfY3`00000noooo
oaX0dLfYCOoooolJ0=7=ZDd000006P3AcJTGooooobh000002?oooolE0=7=Z@005@3AcJU=oooooaX0
dLfY3`00000noooooaX0dLfYCOoooolJ0=7=ZDd000006P3AcJTGooooobh000002?oooolE0=7=Z@00
5@3AcJU=oooooaX0dLfY3`00000noooooaX0dLfYCOoooolJ0=7=ZDd000006P3AcJTGooooobh00000
2?oooolE0=7=Z@005@3AcJU=oooooaX0dLfY3`00000noooooaX0dLfYCOoooolJ0=7=ZDd000006P3A
cJTGooooo`P000007oooool7000000Sooooo5@3AcJT001D0dLfYCOoooolJ0=7=Z@l00000?_oooolJ
0=7=ZDgooooo6P3AcJU=000001X0dLfY5oooool8000001oooooo1`000008oooooaD0dLfY000E0=7=
ZDgooooo6P3AcJT?000003kooooo6P3AcJU=000001X0dLfYCOoooolJ0=7=ZAOooooo2000000Ooooo
o`L000002?oooolE0=7=Z@005@3AcJU=oooooaX0dLfY3`00000noooooaX0dLfYC@00000J0=7=ZDgo
oooo6P3AcJTGooooo`P000007oooool7000000Sooooo5@3AcJT001D0dLfYCOoooolJ0=7=Z@l00000
?_oooolJ0=7=ZDd000006P3AcJU=oooooaX0dLfY5oooool8000001oooooo1`000008oooooaD0dLfY
000E0=7=ZDgooooo6P3AcJT?000003kooooo6P3AcJU=000001X0dLfYCOoooolJ0=7=ZAOooooo2000
000Oooooo`L000002?oooolE0=7=Z@005@3AcJU=oooooaX0dLfY3`00000noooooaX0dLfYC@00000J
0=7=ZDgooooo6P3AcJTGooooo`P000007oooool7000000Sooooo5@3AcJT001D0dLfYCOoooolJ0=7=
Z@l000004?oooolO000000oooooo6P3AcJU=000001X0dLfYCOoooolJ0=7=Z@l000002?ooool?0000
013ooooo3`000008oooooaD0dLfY000E0=7=ZDgooooo6P3AcJT?0000013ooooo7`00000?oooooaX0
dLfYC@00000J0=7=ZDgooooo6P3AcJT?000000Sooooo3`00000@ooooo`l000002?oooolE0=7=Z@00
5@3AcJU=oooooaX0dLfY3`00000@oooooal000003ooooolJ0=7=ZDd000006P3AcJU=oooooaX0dLfY
3`000008ooooo`l000004?ooool?000000Sooooo5@3AcJT001D0dLfYCOoooolJ0=7=Z@l000004?oo
oolO000000oooooo6P3AcJU=000001X0dLfYCOoooolJ0=7=Z@l000002?ooool?0000013ooooo3`00
0008oooooaD0dLfY000E0=7=ZDgooooo6P3AcJT?0000013ooooo7`00000?oooooaX0dLfYC@00000J
0=7=ZDgooooo6P3AcJT?000000Sooooo3`00000@ooooo`l000002?oooolE0=7=Z@005@3AcJU=oooo
oaX0dLfY3`00000@oooooal000003ooooolJ0=7=ZDd000006P3AcJU=oooooaX0dLfY3`000008oooo
o`l000004?ooool?000000Sooooo5@3AcJT001D0dLfYCOoooolJ0=7=Z@l000004?oooolO000000oo
oooo6P3AcJU=000001X0dLfYCOoooolJ0=7=Z@l000002?ooool?0000013ooooo3`000008oooooaD0
dLfY000E0=7=ZDgooooo6P3AcJT?0000013ooooo7`00000?oooooaX0dLfYC@00000J0=7=ZDgooooo
6P3AcJT?000000Sooooo3`00000@ooooo`l000002?oooolE0=7=Z@005@3AcJU=oooooaX0dLfY3`00
000@oooooal000003ooooolJ0=7=ZDgooooo6P3AcJU=oooooaX0dLfY5`000008ooooo`L000004?oo
ool8000000Oooooo2000000E0=7=Z@005@3AcJU=oooooaX0dLfY3`00000@oooooal000003ooooolJ
0=7=ZDgooooo6P3AcJU=oooooaX0dLfY5`000008ooooo`L000004?ooool8000000Oooooo2000000E
0=7=Z@005@3AcJU=oooooaX0dLfY3`00000@oooooal000003ooooolJ0=7=ZDgooooo6P3AcJU=oooo
oaX0dLfY5`000008ooooo`L000004?ooool8000000Oooooo2000000E0=7=Z@005@3AcJU=oooooaX0
dLfY3`00000@oooooal000003ooooolJ0=7=ZDgooooo6P3AcJU=oooooaX0dLfY5`000008ooooo`L0
00004?ooool8000000Oooooo2000000E0=7=Z@005@3AcJU=oooooaX0dLfY3`00000@oooooal00000
3ooooolJ0=7=ZDgooooo6P3AcJU=000001X0dLfY5`000008ooooo`L000004?ooool8000000Oooooo
2000000E0=7=Z@005@3AcJU=oooooaX0dLfY3`00000@oooooal000003ooooolJ0=7=ZDgooooo6P3A
cJU=000001X0dLfY5`000008ooooo`L000004?ooool8000000Oooooo2000000E0=7=Z@005@3AcJU=
oooooaX0dLfY3`00000@oooooal000003ooooolJ0=7=ZDgooooo6P3AcJU=000001X0dLfY5`000008
ooooo`L000004?ooool8000000Oooooo2000000E0=7=Z@005@3AcJU=oooooaX0dLfYC@00000J0=7=
ZDgooooo6P3AcJU=000001X0dLfY5`000008ooooo`L000004?ooool8000000Oooooo2000000E0=7=
Z@005@3AcJU=oooooaX0dLfYC@00000J0=7=ZDgooooo6P3AcJU=000001X0dLfY5`000008ooooo`L0
00004?ooool8000000Oooooo2000000E0=7=Z@005@3AcJU=oooooaX0dLfYC@00000J0=7=ZDgooooo
6P3AcJU=000001X0dLfY5`000008ooooo`L000004?ooool8000000Oooooo2000000E0=7=Z@005@3A
cJU=oooooaX0dLfYC@00000J0=7=ZDgooooo6P3AcJU=000001X0dLfY5`000008ooooo`L000004?oo
ool8000000Oooooo2000000E0=7=Z@005@3AcJU=oooooaX0dLfYC@00000J0=7=ZDgooooo6P3AcJU=
000001X0dLfY5`000008ooooo`L000004?ooool8000000Oooooo2000000E0=7=Z@005@3AcJU=0000
01X0dLfYC@00000J0=7=ZDgooooo6P3AcJU=oooooaX0dLfY5`000008ooooo`L000004?ooool80000
00Oooooo2000000E0=7=Z@005@3AcJU=000001X0dLfYC@00000J0=7=ZDgooooo6P3AcJU=oooooaX0
dLfY5`000008ooooo`L000004?ooool8000000Oooooo2000000E0=7=Z@005@3AcJU=000001X0dLfY
C@00000J0=7=ZDgooooo6P3AcJU=oooooaX0dLfY5`000008ooooo`L000004?ooool8000000Oooooo
2000000E0=7=Z@005@3AcJU=000001X0dLfYC@00000J0=7=ZDgooooo6P3AcJU=oooooaX0dLfY3`00
0008ooooo`l000004?ooool?000000Sooooo5@3AcJT001D0dLfYC@00000J0=7=ZDd000006P3AcJU=
oooooaX0dLfYCOoooolJ0=7=Z@l000002?ooool?0000013ooooo3`000008oooooaD0dLfY000E0=7=
ZDd000006P3AcJU=000001X0dLfYCOoooolJ0=7=ZDgooooo6P3AcJT?000000Sooooo3`00000@oooo
o`l000002?oooolE0=7=Z@005@3AcJU=000001X0dLfYC@00000J0=7=ZDgooooo6P3AcJU=oooooaX0
dLfY3`000008ooooo`l000004?ooool?000000Sooooo5@3AcJT001D0dLfYC@00000J0=7=ZDd00000
6P3AcJU=oooooaX0dLfYCOoooolJ0=7=Z@l000002?ooool?0000013ooooo3`000008oooooaD0dLfY
000E0=7=ZDd000006P3AcJU=000001X0dLfYCOoooolJ0=7=ZDgooooo6P3AcJT?000000Sooooo3`00
000@ooooo`l000002?oooolE0=7=Z@005@3AcJU=000001X0dLfYC@00000J0=7=ZDgooooo6P3AcJU=
oooooaX0dLfY3`000008ooooo`l000004?ooool?000000Sooooo5@3AcJT001D0dLfYC@00000J0=7=
Z@l000004?oooolO000000oooooo6P3AcJU=oooooaX0dLfYCOoooolJ0=7=ZAOooooo2000000Ooooo
o`L000002?oooolE0=7=Z@005@3AcJU=000001X0dLfY3`00000@oooooal000003ooooolJ0=7=ZDgo
oooo6P3AcJU=oooooaX0dLfY5oooool8000001oooooo1`000008oooooaD0dLfY000E0=7=ZDd00000
6P3AcJT?0000013ooooo7`00000?oooooaX0dLfYCOoooolJ0=7=ZDgooooo6P3AcJTGooooo`P00000
7oooool7000000Sooooo5@3AcJT001D0dLfYC@00000J0=7=Z@l000004?oooolO000000oooooo6P3A
cJU=000001X0dLfYCOoooolJ0=7=ZAOooooo2000000Oooooo`L000002?oooolE0=7=Z@005@3AcJU=
000001X0dLfY3`00000@oooooal000003ooooolJ0=7=ZDd000006P3AcJU=oooooaX0dLfY5oooool8
000001oooooo1`000008oooooaD0dLfY000E0=7=ZDd000006P3AcJT?0000013ooooo7`00000?oooo
oaX0dLfYC@00000J0=7=ZDgooooo6P3AcJTGooooo`P000007oooool7000000Sooooo5@3AcJT001D0
dLfYC@00000J0=7=Z@l000004?oooolO000000oooooo6P3AcJU=000001X0dLfYCOoooolJ0=7=ZAOo
oooo2000000Oooooo`L000002?oooolE0=7=Z@005@3AcJU=000001X0dLfY3`00000@oooooal00000
3ooooolJ0=7=ZDd000006P3AcJU=000001X0dLfY5oooool8000001oooooo1`000008oooooaD0dLfY
000E0=7=ZDd000006P3AcJT?0000013ooooo7`00000?oooooaX0dLfYC@00000J0=7=ZDd000006P3A
cJTGooooobh000002?oooolE0=7=Z@005@3AcJU=000001X0dLfY3`00000@oooooal000003ooooolJ
0=7=ZDd000006P3AcJU=000001X0dLfY5oooool^000000Sooooo5@3AcJT001D0dLfYC@00000J0=7=
Z@l000004?oooolO000000oooooo6P3AcJU=000001X0dLfYC@00000J0=7=ZAOooooo;P000008oooo
oaD0dLfY000E0=7=ZDd000006P3AcJT?0000013ooooo7`00000?oooooaX0dLfYC@00000J0=7=ZDd0
00006P3AcJTGooooobh000002?oooolE0=7=Z@005@3AcJU=000001X0dLfY3`00000@oooooal00000
3ooooolJ0=7=ZDd000006P3AcJU=000001X0dLfY5oooool^000000Sooooo5@3AcJT001D0dLfYC@00
000J0=7=Z@l000004?oooolO000000oooooo6P3AcJU=000001X0dLfYC@00000J0=7=ZAOooooo;P00
0008oooooaD0dLfY000E0=7=ZDd000006P3AcJT?0000013ooooo7`00000?oooooaX0dLfYC@00000J
0=7=ZDd000006P3AcJTGooooobh000002?oooolE0=7=Z@005@3AcJU=000001X0dLfY3`00000@oooo
oal000003ooooon10=7=ZDd00000O03AcJT00?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY
003o0=7=ZOl0dLfY5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0
dLfY5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@00>P3AcJT2@00006D0dLfY0T00001T0=7=Z@=00000I03A
cJT3@0000640dLfY1D0000020=7=Z@900000>03AcJT003T0dLfY00A000000=7=Z@3AcJU00000H`3A
cJT014000000dLfY0=7=ZD00001S0=7=Z@04@000003AcJT0dLfY@00006D0dLfY00=000000=7=Z@3A
cJT0H@3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0=@3AcJT003/0
dLfY00=000000=7=Z@3AcJT0I@3AcJT00d000000dLfY0=7=Z@1Q0=7=Z@04@000003AcJT0dLfY@000
06@0dLfY0d00001R0=7=Z@05@000003AcJT0dLfY0=7=ZD0000000P3AcJT00d000000dLfY0=7=Z@0e
0=7=Z@00?03AcJT00d000000dLfY0=7=Z@1R0=7=Z@900000I03AcJT3@00006@0dLfY00A000000=7=
Z@3AcJU00000HP3AcJT01D000000dLfY0=7=Z@3AcJU000000080dLfY00=000000=7=Z@3AcJT0=@3A
cJT003T0dLfY00A000000=7=Z@3AcJU00000I03AcJT00d000000dLfY0=7=Z@1T0=7=Z@03@000003A
cJT0dLfY06<0dLfY00A000000=7=Z@3AcJU00000HP3AcJT01D000000dLfY0=7=Z@3AcJU000000080
dLfY00=000000=7=Z@3AcJT0=@3AcJT003X0dLfY0T00001U0=7=Z@=00000I03AcJT3@00006@0dLfY
0d00001Q0=7=Z@900000103AcJT2@00003P0dLfY003o0=7=ZOl0dLfY5@3AcJT00?l0dLfYo`3AcJTE
0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@00o`3A
cJWo0=7=ZAD0dLfY003o0=7=ZOl0dLfY5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0
dLfY003o0=7=ZOl0dLfY5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY003o0=7=
ZOl0dLfY5@3AcJT00?l0dLfYo`3AcJTE0=7=Z@00o`3AcJWo0=7=ZAD0dLfY0000\
\>"],
  ImageRangeCache->{{{0, 530.875}, {530.875, 0}} -> {-0.125026, -0.125026, \
0.00988944, 0.00988944}, {{12.625, 106.25}, {518.188, 424.563}} -> {-10.7284, \
-7.23276, 0.508575, 0.508575}, {{115.625, 209.25}, {518.188, 424.563}} -> \
{-64.7298, -7.41819, 0.521614, 0.521614}, {{218.625, 312.25}, {518.188, \
424.563}} -> {-124.379, -7.7891, 0.547695, 0.547695}, {{321.563, 415.188}, \
{518.188, 424.563}} -> {-193.669, -8.34549, 0.586818, 0.586818}, {{424.563, \
518.188}, {518.188, 424.563}} -> {-271.051, -8.90182, 0.625937, 0.625937}, \
{{12.625, 106.25}, {415.188, 321.563}} -> {-8.5277, -47.387, 0.404251, \
0.404251}, {{115.625, 209.25}, {415.188, 321.563}} -> {-53.4022, -50.4443, \
0.430333, 0.430333}, {{218.625, 312.25}, {415.188, 321.563}} -> {-100.688, \
-51.973, 0.443374, 0.443374}, {{321.563, 415.188}, {415.188, 321.563}} -> \
{-150.631, -53.5015, 0.456414, 0.456414}, {{424.563, 518.188}, {415.188, \
321.563}} -> {-203.289, -55.0301, 0.469454, 0.469454}, {{12.625, 106.25}, \
{312.25, 218.625}} -> {-5.77684, -60.2902, 0.273848, 0.273848}, {{115.625, \
209.25}, {312.25, 218.625}} -> {-38.8379, -68.903, 0.312969, 0.312969}, \
{{218.625, 312.25}, {312.25, 218.625}} -> {-74.0352, -71.774, 0.32601, \
0.32601}, {{321.563, 415.188}, {312.25, 218.625}} -> {-116.201, -77.5159, \
0.352091, 0.352091}, {{424.563, 518.188}, {312.25, 218.625}} -> {-169.407, \
-86.1287, 0.391211, 0.391211}, {{12.625, 106.25}, {209.25, 115.625}} -> \
{-3.30105, -50.5694, 0.156485, 0.156485}, {{115.625, 209.25}, {209.25, \
115.625}} -> {-24.2737, -63.2117, 0.195606, 0.195606}, {{218.625, 312.25}, \
{209.25, 115.625}} -> {-50.3439, -71.64, 0.221686, 0.221686}, {{321.563, \
415.188}, {209.25, 115.625}} -> {-77.4675, -75.8541, 0.234727, 0.234727}, \
{{424.563, 518.188}, {209.25, 115.625}} -> {-112.938, -84.2824, 0.260808, \
0.260808}, {{12.625, 106.25}, {106.25, 12.625}} -> {-0.825262, -16.6718, \
0.0391211, 0.0391211}, {{115.625, 209.25}, {106.25, 12.625}} -> {-8.09122, \
-27.7863, 0.0652018, 0.0652018}, {{218.625, 312.25}, {106.25, 12.625}} -> \
{-17.7685, -33.3437, 0.0782425, 0.0782425}, {{321.563, 415.188}, {106.25, \
12.625}} -> {-38.7336, -50.0153, 0.117363, 0.117363}, {{424.563, 518.188}, \
{106.25, 12.625}} -> {-56.4691, -55.5728, 0.130404, 0.130404}}],

Cell[BoxData[
    \({2, 4, 7, 8, 11, 13, 14, 16, 19, 22, 23, 26, 28, 29, 32, 37, 38, 41, 
      43, 44, 46, 47, 49}\)], "Output",
  CellLabel->"Out[123]="]
}, Open  ]],

Cell["\<\
Note the case n=2 overlaps with itself and we have to make some assumptions \
as to its not simultaneously toggling the neighbors. The values of n not \
having a solution start as 5, 6, 10, 12, 15, 18, 20, 24, 25, 30,  at first we \
conjecture that they are equal to those numbers having only two different \
prime divisors but 28 contradicts it;  25 shows that they are more. 
If we do not include the cell we are toggling we would have that there exists \
a solution for n even and this solution is quite symmetrical, as the \
following table shows.\
\>", "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0238095 0.190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.200176 0.200176 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0228938 0.0192308 0.0228938 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
42 string
42 42 8 [42 0 0 42 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000
FF0000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
0000FFFF0000
FF0000FFFF00000000000000000000000000000000000000000000000000000000000000
00FFFF0000FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFF0000
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFF0000FF
0000FFFF0000FFFF0000000000000000000000000000000000000000000000000000FFFF
0000FFFF0000
FF0000FFFF0000FFFF000000000000000000000000000000000000000000000000FFFF00
00FFFF0000FF
0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
0000FFFF0000
FF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00
00FFFF0000FF
0000FFFF0000FFFF0000FFFF000000000000000000000000000000000000FFFF0000FFFF
0000FFFF0000
FF0000FFFF0000FFFF0000FFFF00000000000000000000000000000000FFFF0000FFFF00
00FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF
0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF00
00FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF00000000000000000000FFFF0000FFFF0000FFFF
0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000000000000000FFFF0000FFFF0000FFFF00
00FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFF0000FFFF0000FFFF0000FFFF00
00FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFF0000FFFF0000FFFF0000FFFF00
00FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000000000000000FFFF0000FFFF0000FFFF00
00FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF00000000000000000000FFFF0000FFFF0000FFFF
0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF00
00FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF
0000FFFF0000
FF0000FFFF0000FFFF0000FFFF00000000000000000000000000000000FFFF0000FFFF00
00FFFF0000FF
0000FFFF0000FFFF0000FFFF000000000000000000000000000000000000FFFF0000FFFF
0000FFFF0000
FF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00
00FFFF0000FF
0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
0000FFFF0000
FF0000FFFF0000FFFF000000000000000000000000000000000000000000000000FFFF00
00FFFF0000FF
0000FFFF0000FFFF0000000000000000000000000000000000000000000000000000FFFF
0000FFFF0000
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFF0000FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFF0000
FF0000FFFF00000000000000000000000000000000000000000000000000000000000000
00FFFF0000FF
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
0000FFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000
FF0000000000000000000000000000000000000000000000000000000000000000000000
0000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.0238095 0.39418 0.200176 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0218531 0.0192308 0.0218531 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
44 string
44 44 8 [44 0 0 44 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
FF0000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
00000000FFFF0000
FF0000FFFF00000000000000000000000000000000000000000000000000000000000000
000000FFFF0000FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFF0000
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFF0000FF
0000FFFF0000FFFF00000000000000000000000000000000000000000000000000000000
FFFF0000FFFF0000
FF0000FFFF0000FFFF0000000000000000000000000000000000000000000000000000FF
FF0000FFFF0000FF
0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000000000000000000000000000000000000000FFFF0000
FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF000000000000000000000000000000000000FFFF0000FF
FF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000
FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FF
FF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF000000000000000000000000FFFF0000FFFF0000
FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF00000000000000000000FFFF0000FFFF0000FF
FF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFF0000FFFF0000FFFF0000FF
FF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF00000000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FF
FF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF00000000FFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFF0000FFFF0000FFFF0000FF
FF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF00000000000000000000FFFF0000FFFF0000FF
FF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF000000000000000000000000FFFF0000FFFF0000
FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FF
FF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000
FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF000000000000000000000000000000000000FFFF0000FF
FF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000000000000000000000000000000000000000FFFF0000
FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FF0000FFFF0000FF
0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFF0000FFFF0000
FF0000FFFF0000FFFF0000000000000000000000000000000000000000000000000000FF
FF0000FFFF0000FF
0000FFFF0000FFFF00000000000000000000000000000000000000000000000000000000
FFFF0000FFFF0000
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFF0000FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFF0000
FF0000FFFF00000000000000000000000000000000000000000000000000000000000000
000000FFFF0000FF
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
00000000FFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000
FF0000000000000000000000000000000000000000000000000000000000000000000000
00000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.0238095 0.588183 0.200176 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.020903 0.0192308 0.020903 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
46 string
46 46 8 [46 0 0 46 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000FFFF0000
FF0000FFFF00000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFF0000
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFF0000FF
0000FFFF0000FFFF00000000000000000000000000000000000000000000000000000000
0000FFFF0000FFFF0000
FF0000FFFF0000FFFF000000000000000000000000000000000000000000000000000000
00FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF00000000000000000000000000000000000000000000FFFF
0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000000000000000000000000000000000000000FFFF00
00FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00
00FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000000000000000000000000000FFFF0000FFFF
0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF000000000000000000000000FFFF0000FFFF00
00FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFF0000FFFF0000FFFF00
00FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000000000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF00000000FFFF0000FFFF0000FFFF00
00FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF00000000FFFF0000FFFF0000FFFF00
00FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000000000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFF0000FFFF0000FFFF00
00FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF000000000000000000000000FFFF0000FFFF00
00FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000000000000000000000000000FFFF0000FFFF
0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00
00FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000000000000000000000000000000000000000FFFF00
00FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF00000000000000000000000000000000000000000000FFFF
0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFF0000FFFF0000
FF0000FFFF0000FFFF000000000000000000000000000000000000000000000000000000
00FFFF0000FFFF0000FF
0000FFFF0000FFFF00000000000000000000000000000000000000000000000000000000
0000FFFF0000FFFF0000
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFF0000FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFF0000
FF0000FFFF00000000000000000000000000000000000000000000000000000000000000
0000000000FFFF0000FF
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
000000000000FFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.0238095 0.782187 0.200176 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0200321 0.0192308 0.0200321 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
48 string
48 48 8 [48 0 0 48 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
FF0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
0000000000000000FFFF0000
FF0000FFFF00000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF0000FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFF0000
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF0000FF
0000FFFF0000FFFF00000000000000000000000000000000000000000000000000000000
00000000FFFF0000FFFF0000
FF0000FFFF0000FFFF000000000000000000000000000000000000000000000000000000
000000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF000000000000000000000000000000000000000000000000
FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF00000000000000000000000000000000000000000000FF
FF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF00000000000000000000000000000000FFFF0000
FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000000000000000000000000000FFFF0000FF
FF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF0000FF
FF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000000000000000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000000000FFFF0000FFFF0000FF
FF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FF
FF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFF0000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF000000000000FFFF0000FFFF0000FF
FF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000000000000000FFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF0000FF
FF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000
FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000000000000000000000000000FFFF0000FF
FF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF00000000000000000000000000000000FFFF0000
FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF00000000000000000000000000000000000000000000FF
FF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF000000000000000000000000000000000000000000000000
FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF000000000000000000000000000000000000000000000000000000
000000FFFF0000FFFF0000FF
0000FFFF0000FFFF00000000000000000000000000000000000000000000000000000000
00000000FFFF0000FFFF0000
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFF0000FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFF0000
FF0000FFFF00000000000000000000000000000000000000000000000000000000000000
00000000000000FFFF0000FF
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
0000000000000000FFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000
FF0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.0238095 0.97619 0.200176 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0192308 0.0192308 0.0192308 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
50 string
50 50 8 [50 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000
FF0000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FFFF0000
FF0000FFFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFF0000FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFF0000
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFF0000FF
0000FFFF0000FFFF00000000000000000000000000000000000000000000000000000000
000000000000FFFF0000FFFF0000
FF0000FFFF0000FFFF000000000000000000000000000000000000000000000000000000
0000000000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF000000000000000000000000000000000000000000000000
0000FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000000000000000000000000000000000000000000000
00FFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF000000000000000000000000000000000000FFFF
0000FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF00000000000000000000000000000000FFFF00
00FFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00
00FFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF00000000000000000000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000000000000000FFFF0000FFFF00
00FFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFF0000FFFF0000FFFF00
00FFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFF0000FFFF0000FFFF00
00FFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFF0000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000000000000000FFFF0000FFFF00
00FFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF00000000000000000000FFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00
00FFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
0000FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF00000000000000000000000000000000FFFF00
00FFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF000000000000000000000000000000000000FFFF
0000FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000000000000000000000000000000000000000000000
00FFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF000000000000000000000000000000000000000000000000
0000FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF000000000000000000000000000000000000000000000000000000
0000000000FFFF0000FFFF0000FF
0000FFFF0000FFFF00000000000000000000000000000000000000000000000000000000
000000000000FFFF0000FFFF0000
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFF0000FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFF0000
FF0000FFFF00000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFF0000FF
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
00000000000000000000FFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.217813 0.200176 0.39418 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0300481 0.0192308 0.0300481 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.217813 0.39418 0.39418 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0282805 0.0192308 0.0282805 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
34 string
34 34 8 [34 0 0 34 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.217813 0.588183 0.39418 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0267094 0.0192308 0.0267094 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
36 string
36 36 8 [36 0 0 36 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.217813 0.782187 0.39418 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0253036 0.0192308 0.0253036 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
38 string
38 38 8 [38 0 0 38 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000
FF0000000000000000000000000000000000000000000000000000000000000000000000
00FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF
0000FFFF000000000000000000000000000000000000000000000000000000000000FFFF
0000
FF0000FFFF00000000000000000000000000000000000000000000000000000000FFFF00
00FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
0000
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00
00FF
0000FFFF0000FFFF00000000000000000000000000000000000000000000FFFF0000FFFF
0000
FF0000FFFF0000FFFF0000000000000000000000000000000000000000FFFF0000FFFF00
00FF
0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF
0000
FF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF00
00FF
0000FFFF0000FFFF0000FFFF0000000000000000000000000000FFFF0000FFFF0000FFFF
0000
FF0000FFFF0000FFFF0000FFFF000000000000000000000000FFFF0000FFFF0000FFFF00
00FF
0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF
0000
FF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF00
00FF
0000FFFF0000FFFF0000FFFF0000FFFF000000000000FFFF0000FFFF0000FFFF0000FFFF
0000
FF0000FFFF0000FFFF0000FFFF0000FFFF00000000FFFF0000FFFF0000FFFF0000FFFF00
00FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF
0000
FF0000FFFF0000FFFF0000FFFF0000FFFF00000000FFFF0000FFFF0000FFFF0000FFFF00
00FF
0000FFFF0000FFFF0000FFFF0000FFFF000000000000FFFF0000FFFF0000FFFF0000FFFF
0000
FF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF00
00FF
0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFF
0000
FF0000FFFF0000FFFF0000FFFF000000000000000000000000FFFF0000FFFF0000FFFF00
00FF
0000FFFF0000FFFF0000FFFF0000000000000000000000000000FFFF0000FFFF0000FFFF
0000
FF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF00
00FF
0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF
0000
FF0000FFFF0000FFFF0000000000000000000000000000000000000000FFFF0000FFFF00
00FF
0000FFFF0000FFFF00000000000000000000000000000000000000000000FFFF0000FFFF
0000
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00
00FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
0000
FF0000FFFF00000000000000000000000000000000000000000000000000000000FFFF00
00FF
0000FFFF000000000000000000000000000000000000000000000000000000000000FFFF
0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000
FF0000000000000000000000000000000000000000000000000000000000000000000000
00FF
000000000000000000000000000000000000000000000000000000000000000000000000
0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.217813 0.97619 0.39418 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
FFFF0000
FF0000FFFF000000000000000000000000000000000000000000000000000000000000FF
FF0000FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFF0000
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FF0000FF
0000FFFF0000FFFF000000000000000000000000000000000000000000000000FFFF0000
FFFF0000
FF0000FFFF0000FFFF00000000000000000000000000000000000000000000FFFF0000FF
FF0000FF
0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000
FFFF0000
FF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FF
FF0000FF
0000FFFF0000FFFF0000FFFF00000000000000000000000000000000FFFF0000FFFF0000
FFFF0000
FF0000FFFF0000FFFF0000FFFF0000000000000000000000000000FFFF0000FFFF0000FF
FF0000FF
0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000
FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FF
FF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000000000000000FFFF0000FFFF0000FFFF0000
FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF000000000000FFFF0000FFFF0000FFFF0000FF
FF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FF
FF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFF0000FFFF0000FFFF0000FFFF0000
FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF000000000000FFFF0000FFFF0000FFFF0000FF
FF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000000000000000FFFF0000FFFF0000FFFF0000
FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FF
FF0000FF
0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000
FFFF0000
FF0000FFFF0000FFFF0000FFFF0000000000000000000000000000FFFF0000FFFF0000FF
FF0000FF
0000FFFF0000FFFF0000FFFF00000000000000000000000000000000FFFF0000FFFF0000
FFFF0000
FF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FF
FF0000FF
0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000
FFFF0000
FF0000FFFF0000FFFF00000000000000000000000000000000000000000000FFFF0000FF
FF0000FF
0000FFFF0000FFFF000000000000000000000000000000000000000000000000FFFF0000
FFFF0000
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FF0000FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFF0000
FF0000FFFF000000000000000000000000000000000000000000000000000000000000FF
FF0000FF
0000FFFF0000000000000000000000000000000000000000000000000000000000000000
FFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000
FF0000000000000000000000000000000000000000000000000000000000000000000000
000000FF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.411817 0.200176 0.588183 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0437063 0.0192308 0.0437063 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
22 string
22 22 8 [22 0 0 22 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000
FF0000000000000000000000000000000000000000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
0000FFFF0000000000000000000000000000FFFF0000
FF0000FFFF000000000000000000000000FFFF0000FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF0000
FF0000FFFF0000FFFFFFFFFFFFFFFF0000FFFF0000FF
0000FFFF0000FFFF000000000000FFFF0000FFFF0000
FF0000FFFF0000FFFF00000000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF00000000FFFF0000FFFF0000FF
0000FFFF0000FFFF000000000000FFFF0000FFFF0000
FF0000FFFF0000FFFFFFFFFFFFFFFF0000FFFF0000FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF0000
FF0000FFFF000000000000000000000000FFFF0000FF
0000FFFF0000000000000000000000000000FFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000000000000000000000000000000000000000FF
00000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.411817 0.39418 0.588183 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0400641 0.0192308 0.0400641 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
24 string
24 24 8 [24 0 0 24 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000
FF00000000000000000000000000000000000000000000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
0000FFFF00000000000000000000000000000000FFFF0000
FF0000FFFF0000000000000000000000000000FFFF0000FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF0000FF
0000FFFF0000FFFF0000000000000000FFFF0000FFFF0000
FF0000FFFF0000FFFF000000000000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFFFFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFFFFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF000000000000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000000000000000FFFF0000FFFF0000
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF0000FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000
FF0000FFFF0000000000000000000000000000FFFF0000FF
0000FFFF00000000000000000000000000000000FFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00000000000000000000000000000000000000000000FF
000000000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.411817 0.588183 0.588183 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0369822 0.0192308 0.0369822 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
26 string
26 26 8 [26 0 0 26 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000000000000000
FF000000000000000000000000000000000000000000000000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
0000FFFF000000000000000000000000000000000000FFFF0000
FF0000FFFF00000000000000000000000000000000FFFF0000FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FF
0000FFFF0000FFFF00000000000000000000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000000000000000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFFFFFFFFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFFFFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFFFFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFFFFFFFFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000000000000000FFFF0000FFFF0000FF
0000FFFF0000FFFF00000000000000000000FFFF0000FFFF0000
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000
FF0000FFFF00000000000000000000000000000000FFFF0000FF
0000FFFF000000000000000000000000000000000000FFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF000000000000000000000000000000000000000000000000FF
0000000000000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.411817 0.782187 0.588183 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0343407 0.0192308 0.0343407 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
28 string
28 28 8 [28 0 0 28 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000000000000000000000000000000000000000000000000000
FF0000000000000000000000000000000000000000000000000000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
0000FFFF0000000000000000000000000000000000000000FFFF0000
FF0000FFFF000000000000000000000000000000000000FFFF0000FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FF
0000FFFF0000FFFF000000000000000000000000FFFF0000FFFF0000
FF0000FFFF0000FFFF00000000000000000000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFFFFFFFFFFFFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFFFFFFFFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF00000000FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF00000000FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFFFFFFFFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFFFFFFFFFFFFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF00000000000000000000FFFF0000FFFF0000FF
0000FFFF0000FFFF000000000000000000000000FFFF0000FFFF0000
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000
FF0000FFFF000000000000000000000000000000000000FFFF0000FF
0000FFFF0000000000000000000000000000000000000000FFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000000000000000000000000000000000000000000000000000FF
00000000000000000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.411817 0.97619 0.588183 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0320513 0.0192308 0.0320513 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
30 string
30 30 8 [30 0 0 30 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000
FF00000000000000000000000000000000000000000000000000000000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
0000FFFF00000000000000000000000000000000000000000000FFFF0000
FF0000FFFF0000000000000000000000000000000000000000FFFF0000FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FF
0000FFFF0000FFFF0000000000000000000000000000FFFF0000FFFF0000
FF0000FFFF0000FFFF000000000000000000000000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF000000000000FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF00000000FFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF00000000FFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF000000000000FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFF000000000000000000000000FFFF0000FFFF0000FF
0000FFFF0000FFFF0000000000000000000000000000FFFF0000FFFF0000
FF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000FF
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF0000
FF0000FFFF0000000000000000000000000000000000000000FFFF0000FF
0000FFFF00000000000000000000000000000000000000000000FFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00000000000000000000000000000000000000000000000000000000FF
000000000000000000000000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.60582 0.200176 0.782187 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0801282 0.0192308 0.0801282 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
12 string
12 12 8 [12 0 0 12 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000
FF00000000000000000000FF
0000FFFFFFFFFFFFFFFF0000
FF0000FFFFFFFFFFFF0000FF
0000FFFF00000000FFFF0000
FF0000FFFF0000FFFF0000FF
0000FFFF00000000FFFF0000
FF0000FFFFFFFFFFFF0000FF
0000FFFFFFFFFFFFFFFF0000
FF00000000000000000000FF
000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.60582 0.39418 0.782187 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0686813 0.0192308 0.0686813 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
14 string
14 14 8 [14 0 0 14 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000000000000000000000
FF000000000000000000000000FF
0000FFFFFFFFFFFFFFFFFFFF0000
FF0000FFFFFFFFFFFFFFFF0000FF
0000FFFF000000000000FFFF0000
FF0000FFFF00000000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000
FF0000FFFF00000000FFFF0000FF
0000FFFF000000000000FFFF0000
FF0000FFFFFFFFFFFFFFFF0000FF
0000FFFFFFFFFFFFFFFFFFFF0000
FF000000000000000000000000FF
0000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.60582 0.588183 0.782187 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0600962 0.0192308 0.0600962 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
16 string
16 16 8 [16 0 0 16 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000000000000000000000000000
FF0000000000000000000000000000FF
0000FFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000FFFFFFFFFFFFFFFFFFFF0000FF
0000FFFF0000000000000000FFFF0000
FF0000FFFF000000000000FFFF0000FF
0000FFFF0000FFFFFFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFFFFFF0000FFFF0000
FF0000FFFF000000000000FFFF0000FF
0000FFFF0000000000000000FFFF0000
FF0000FFFFFFFFFFFFFFFFFFFF0000FF
0000FFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000000000000000000000000000FF
00000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.60582 0.782187 0.782187 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0534188 0.0192308 0.0534188 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
18 string
18 18 8 [18 0 0 18 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000
FF00000000000000000000000000000000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FF
0000FFFF00000000000000000000FFFF0000
FF0000FFFF0000000000000000FFFF0000FF
0000FFFF0000FFFFFFFFFFFF0000FFFF0000
FF0000FFFF0000FFFFFFFF0000FFFF0000FF
0000FFFF0000FFFF0000FFFF0000FFFF0000
FF0000FFFF0000FFFFFFFF0000FFFF0000FF
0000FFFF0000FFFFFFFFFFFF0000FFFF0000
FF0000FFFF0000000000000000FFFF0000FF
0000FFFF00000000000000000000FFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00000000000000000000000000000000FF
000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.60582 0.97619 0.782187 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0480769 0.0192308 0.0480769 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
20 string
20 20 8 [20 0 0 20 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000
FF000000000000000000000000000000000000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
0000FFFF000000000000000000000000FFFF0000
FF0000FFFF00000000000000000000FFFF0000FF
0000FFFF0000FFFFFFFFFFFFFFFF0000FFFF0000
FF0000FFFF0000FFFFFFFFFFFF0000FFFF0000FF
0000FFFF0000FFFF00000000FFFF0000FFFF0000
FF0000FFFF0000FFFF0000FFFF0000FFFF0000FF
0000FFFF0000FFFF00000000FFFF0000FFFF0000
FF0000FFFF0000FFFFFFFFFFFF0000FFFF0000FF
0000FFFF0000FFFFFFFFFFFFFFFF0000FFFF0000
FF0000FFFF00000000000000000000FFFF0000FF
0000FFFF000000000000000000000000FFFF0000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF000000000000000000000000000000000000FF
0000000000000000000000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.799824 0.200176 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.480769 0.0192308 0.480769 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
2 string
2 2 8 [2 0 0 2 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF
0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.799824 0.39418 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFF
00000000
FF0000FF
00000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.799824 0.588183 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.160256 0.0192308 0.160256 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
6 string
6 6 8 [6 0 0 6 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFF
000000000000
FF00000000FF
0000FFFF0000
FF00000000FF
000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.799824 0.782187 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.120192 0.0192308 0.120192 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFF
0000000000000000
FF000000000000FF
0000FFFFFFFF0000
FF0000FFFF0000FF
0000FFFFFFFF0000
FF000000000000FF
0000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.799824 0.97619 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0961538 0.0192308 0.0961538 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
10 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFF
00000000000000000000
FF0000000000000000FF
0000FFFFFFFFFFFF0000
FF0000FFFFFFFF0000FF
0000FFFF0000FFFF0000
FF0000FFFFFFFF0000FF
0000FFFFFFFFFFFF0000
FF0000000000000000FF
00000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{474.5, 474.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007J0001fR000`400?l00000o`00003oo`3AcJWK
0=7=Z@00o`3AcJWK0=7=Z@00o`3AcJWK0=7=Z@00o`3AcJWK0=7=Z@00o`3AcJWK0=7=Z@00o`3AcJWK
0=7=Z@00o`3AcJWK0=7=Z@00o`3AcJWK0=7=Z@00o`3AcJWK0=7=Z@00o`3AcJWK0=7=Z@00o`3AcJWK
0=7=Z@00o`3AcJWK0=7=Z@00o`3AcJWK0=7=Z@00o`3AcJWK0=7=Z@00303AcJUA0?ooo`/0dLfYD@3o
ool;0=7=ZE00oooo303AcJU@0?ooo``0dLfYD03oool>0=7=Z@00303AcJUA0?ooo`/0dLfYD@3oool;
0=7=ZE00oooo303AcJU@0?ooo``0dLfYD03oool>0=7=Z@00303AcJUA000000/0dLfYD@00000;0=7=
ZE000000303AcJU@000000`0dLfYD000000>0=7=Z@00303AcJUA000000/0dLfYD@00000;0=7=Z@80
ooooC00000020?ooo``0dLfY0P3ooom<00000080oooo303AcJT20?oood`000000P3oool>0=7=Z@00
303AcJT20?ooodd000000P3oool;0=7=Z@80ooooC@0000020?ooo`/0dLfY0P3ooom<00000080oooo
303AcJT20?oood`000000P3oool<0=7=Z@80ooooC00000020?ooo`h0dLfY000<0=7=Z@80ooooC@00
00020?ooo`/0dLfY100000190?ooo`@000002`3AcJT3000004X0oooo0`00000<0=7=Z@<00000BP3o
ool3000000`0dLfY0`00001:0?ooo`<000003P3AcJT000`0dLfY100000190?ooo`@000002`3AcJT4
000004T0oooo1000000;0=7=Z@<00000BP3oool3000000`0dLfY0`00001:0?ooo`<00000303AcJT2
0?ooo`<00000AP3oool300000080oooo3P3AcJT000`0dLfY100000190?ooo`@000002`3AcJT20?oo
o`@00000A@3oool400000080oooo2`3AcJT20?ooo`<00000AP3oool300000080oooo303AcJT20?oo
o`<00000AP3oool300000080oooo303AcJT20?ooo`<00000AP3oool300000080oooo3P3AcJT000`0
dLfY0P3oool4000004D0oooo100000020?ooo`/0dLfY0P3oool4000004D0oooo100000020?ooo`/0
dLfY0P3oool3000004H0oooo0`0000020?ooo``0dLfY0`0000040?oood800000103oool3000000`0
dLfY0`0000030?oood@000000`3oool3000000h0dLfY000<0=7=Z@80oooo100000150?ooo`@00000
0P3oool;0=7=Z@@000000`3ooom3000000<0oooo1000000;0=7=Z@<00000103ooom2000000@0oooo
0`00000<0=7=Z@<00000103ooom2000000@0oooo0`00000<0=7=Z@<000000`3ooom4000000<0oooo
0`00000>0=7=Z@00303AcJT4000000@0oooo@@0000040?ooo`@000002`3AcJT4000000<0oooo@`00
00030?ooo`@000002`3AcJT20?ooo`<00000103oooln000000@0oooo0`0000020?ooo``0dLfY0P3o
ool3000000<0oooo@00000030?ooo`<000000P3oool<0=7=Z@80oooo0`0000030?oood0000000`3o
ool300000080oooo3P3AcJT000`0dLfY0P3oool4000000@0oooo?@0000040?ooo`@000000P3oool;
0=7=Z@80oooo100000030?ooocl000000`3oool400000080oooo2`3AcJT20?ooo`<00000103oooln
000000@0oooo0`0000020?ooo``0dLfY0P3oool3000000<0oooo@00000030?ooo`<000000P3oool<
0=7=Z@<000000`3oool4000003`0oooo100000030?ooo`<000003P3AcJT000`0dLfY0P3oool40000
00@0oooo?@0000040?ooo`@000000P3oool;0=7=Z@80oooo100000030?ooocl000000`3oool40000
0080oooo2`3AcJT3000000@0oooo0`00000l0?ooo`<00000103oool3000000`0dLfY0`0000040?oo
o`<00000?03oool3000000@0oooo0`00000<0=7=Z@<000000`3oool4000003`0oooo100000030?oo
o`<000003P3AcJT000`0dLfY100000040?ooo`@00000>@3oool4000000@0oooo1000000;0=7=Z@@0
00000`3oool4000003/0oooo100000030?ooo`@000002`3AcJT3000000@0oooo0`00000l0?ooo`<0
0000103oool3000000`0dLfY0P3oool3000000<0oooo1000000h0?ooo`@000000`3oool300000080
oooo303AcJT20?ooo`<000000`3oool3000003X0oooo0`0000030?ooo`<000000P3oool>0=7=Z@00
303AcJT4000000@0oooo1000000i0?ooo`@00000103oool4000000/0dLfY100000030?ooo`@00000
>`3oool4000000<0oooo1000000;0=7=Z@80oooo0`0000040?ooo`<00000>03oool3000000@0oooo
0`0000020?ooo``0dLfY0P3oool3000000<0oooo1000000h0?ooo`@000000`3oool300000080oooo
303AcJT3000000<0oooo100000030?ooocH000000`3oool4000000<0oooo0`00000>0=7=Z@00303A
cJT20?ooo`@00000103oool4000003H0oooo0`0000040?ooo`@000000P3oool;0=7=Z@80oooo1000
00030?ooo`@00000=`3oool4000000<0oooo100000020?ooo`/0dLfY0P3oool3000000@0oooo0`00
000h0?ooo`<00000103oool300000080oooo303AcJT3000000@0oooo0`0000030?ooocH000000`3o
ool3000000@0oooo0`00000<0=7=Z@<000000`3oool4000000<0oooo=P0000030?ooo`@000000`3o
ool3000000h0dLfY000<0=7=Z@80oooo100000040?ooo`@00000=P3oool3000000@0oooo10000002
0?ooo`/0dLfY100000030?ooo`@00000103ooolc000000@0oooo100000030?ooo`@000002`3AcJT3
000000@0oooo0`0000040?oooc@00000103oool3000000@0oooo0`00000<0=7=Z@<00000103oool3
000000<0oooo=P0000030?ooo`<00000103oool3000000`0dLfY0P3oool3000000<0oooo0`000003
0?oooc@000000`3oool3000000<0oooo0`0000020?ooo`h0dLfY000<0=7=Z@@00000103oool40000
00<0oooo<`0000030?ooo`@00000103oool4000000/0dLfY100000030?ooo`@00000103ooolc0000
00@0oooo100000030?ooo`@000002`3AcJT20?ooo`<00000103oool3000000@0oooo<00000040?oo
o`<00000103oool300000080oooo303AcJT20?ooo`<000000`3oool4000000<0oooo<P0000030?oo
o`@000000`3oool300000080oooo303AcJT20?ooo`<000000`3oool3000000<0oooo=00000030?oo
o`<000000`3oool300000080oooo3P3AcJT000`0dLfY100000040?ooo`@000000`3ooolc000000<0
oooo100000040?ooo`@000002`3AcJT20?ooo`@000000`3oool4000000@0oooo;`0000040?ooo`@0
00000`3oool400000080oooo2`3AcJT20?ooo`<00000103oool3000000@0oooo<00000040?ooo`<0
0000103oool300000080oooo303AcJT3000000@0oooo0`0000030?ooo`@00000;P3oool4000000<0
oooo0`0000040?ooo`<00000303AcJT3000000<0oooo100000030?ooo`<00000<03oool3000000<0
oooo100000030?ooo`<000003P3AcJT000`0dLfY0P3oool4000000@0oooo100000030?ooobl00000
103oool3000000@0oooo100000020?ooo`/0dLfY0P3oool4000000<0oooo100000040?ooobl00000
103oool4000000<0oooo100000020?ooo`/0dLfY0`0000040?ooo`<00000103oool3000002h0oooo
0`0000040?ooo`<00000103oool3000000`0dLfY0`0000040?ooo`<000000`3oool4000002h0oooo
100000030?ooo`<00000103oool3000000`0dLfY0P3oool3000000<0oooo0`0000030?ooo`@00000
;03oool4000000<0oooo0`0000030?ooo`<000000P3oool>0=7=Z@00303AcJT20?ooo`@00000103o
ool4000000<0oooo;`0000040?ooo`<00000103oool400000080oooo2`3AcJT4000000<0oooo1000
00040?ooo`<00000;@3oool3000000@0oooo100000030?ooo`@000002`3AcJT3000000@0oooo0`00
00040?ooo`<00000;P3oool3000000@0oooo0`0000040?ooo`<00000303AcJT20?ooo`<000000`3o
ool4000000<0oooo0`00000/0?ooo`<000000`3oool4000000<0oooo0`0000020?ooo``0dLfY0P3o
ool3000000<0oooo0`0000030?ooo`@00000;03oool4000000<0oooo0`0000030?ooo`<000000P3o
ool>0=7=Z@00303AcJT4000000@0oooo100000030?ooo`@00000:`3oool4000000<0oooo10000004
0?ooo`@000002`3AcJT4000000<0oooo100000040?ooo`<00000;@3oool3000000@0oooo10000003
0?ooo`@000002`3AcJT20?ooo`<00000103oool3000000@0oooo0`00000Z0?ooo`<00000103oool3
000000@0oooo0`0000020?ooo``0dLfY0P3oool3000000<0oooo100000030?ooo`<00000;03oool3
000000<0oooo100000030?ooo`<000000P3oool<0=7=Z@<000000`3oool4000000<0oooo0`000003
0?ooobX000000`3oool3000000<0oooo100000030?ooo`<000003P3AcJT000`0dLfY100000040?oo
o`@000000`3oool4000002/0oooo100000030?ooo`@00000103oool4000000/0dLfY0P3oool40000
00<0oooo100000040?ooo`<00000:@3oool3000000@0oooo100000030?ooo`@000000P3oool;0=7=
Z@80oooo0`0000040?ooo`<00000103oool3000002X0oooo0`0000040?ooo`<00000103oool30000
0080oooo303AcJT3000000@0oooo0`0000030?ooo`@000000`3ooolX000000<0oooo100000030?oo
o`<00000103oool3000000`0dLfY0P3oool3000000<0oooo0`0000030?ooo`@000000`3ooolV0000
00<0oooo100000030?ooo`<000000`3oool300000080oooo3P3AcJT000`0dLfY0P3oool4000000@0
oooo100000030?ooo`@000009`3oool4000000@0oooo0`0000040?ooo`@000000P3oool;0=7=Z@80
oooo100000030?ooo`@00000103oool3000002T0oooo0`0000040?ooo`@000000`3oool400000080
oooo2`3AcJT3000000@0oooo0`0000040?ooo`<00000103ooolV000000@0oooo0`0000040?ooo`<0
0000103oool3000000`0dLfY0P3oool3000000<0oooo100000030?ooo`<00000103ooolT000000@0
oooo0`0000030?ooo`@000000`3oool300000080oooo303AcJT20?ooo`<000000`3oool3000000<0
oooo100000030?ooobH000000`3oool4000000<0oooo0`0000030?ooo`<000000P3oool>0=7=Z@00
303AcJT20?ooo`@00000103oool4000000<0oooo1000000W0?ooo`@00000103oool3000000@0oooo
100000020?ooo`/0dLfY100000030?ooo`@00000103oool3000000@0oooo9@0000040?ooo`<00000
103oool4000000<0oooo1000000;0=7=Z@80oooo0`0000040?ooo`<00000103oool3000000@0oooo
8P0000040?ooo`<00000103oool3000000@0oooo0`0000020?ooo``0dLfY0P3oool3000000<0oooo
100000030?ooo`<00000103ooolT000000@0oooo0`0000030?ooo`@000000`3oool300000080oooo
303AcJT3000000<0oooo100000030?ooo`<000000`3oool3000002@0oooo0`0000030?ooo`<00000
0`3oool4000000<0oooo0`00000>0=7=Z@00303AcJT4000000@0oooo100000030?ooo`@00000103o
oolS000000@0oooo100000030?ooo`@00000103oool4000000/0dLfY0P3oool4000000<0oooo1000
00040?ooo`<00000103ooolQ000000@0oooo0`0000040?ooo`@000000`3oool400000080oooo2`3A
cJT20?ooo`<00000103oool3000000@0oooo0`0000040?ooob800000103oool3000000@0oooo0`00
00040?ooo`<000000P3oool<0=7=Z@<00000103oool3000000<0oooo100000030?ooo`<000008P3o
ool3000000<0oooo100000030?ooo`<00000103oool3000000`0dLfY0`0000030?ooo`@000000`3o
ool3000000<0oooo0`00000T0?ooo`<000000`3oool3000000<0oooo100000030?ooo`<000003P3A
cJT000`0dLfY100000040?ooo`@000000`3oool4000000@0oooo8`0000040?ooo`@000000`3oool4
000000@0oooo1000000;0=7=Z@80oooo100000030?ooo`@00000103oool3000000@0oooo8@000004
0?ooo`<00000103oool4000000<0oooo100000020?ooo`/0dLfY0`0000040?ooo`<00000103oool3
000000@0oooo0`00000P0?ooo`<00000103oool3000000@0oooo0`0000040?ooo`<00000303AcJT3
000000@0oooo0`0000030?ooo`@000000`3oool300000280oooo0`0000030?ooo`@000000`3oool3
000000@0oooo0`00000<0=7=Z@80oooo0`0000030?ooo`<000000`3oool4000000<0oooo0`00000P
0?ooo`<000000`3oool4000000<0oooo0`0000030?ooo`<000000P3oool>0=7=Z@00303AcJT20?oo
o`@00000103oool4000000<0oooo100000040?oooal00000103oool4000000@0oooo0`0000040?oo
o`@000000P3oool;0=7=Z@@000000`3oool4000000@0oooo0`0000040?ooo`@000007@3oool40000
00@0oooo0`0000040?ooo`@000000`3oool4000000/0dLfY0`0000040?ooo`<00000103oool30000
00@0oooo0`00000P0?ooo`<00000103oool3000000@0oooo0`0000040?ooo`<00000303AcJT20?oo
o`<000000`3oool4000000<0oooo0`0000040?ooo`<000007P3oool3000000@0oooo0`0000030?oo
o`@000000`3oool300000080oooo303AcJT3000000<0oooo100000030?ooo`<000000`3oool30000
00@0oooo700000040?ooo`<000000`3oool3000000<0oooo100000030?ooo`<000003P3AcJT000`0
dLfY0P3oool4000000@0oooo100000030?ooo`@00000103ooolO000000@0oooo100000040?ooo`<0
0000103oool400000080oooo2`3AcJT4000000<0oooo100000040?ooo`<00000103oool4000001d0
oooo100000040?ooo`<00000103oool4000000<0oooo1000000;0=7=Z@80oooo0`0000040?ooo`<0
0000103oool3000000@0oooo0`00000L0?ooo`<00000103oool3000000@0oooo0`0000040?ooo`<0
00000P3oool<0=7=Z@<00000103oool3000000<0oooo100000030?ooo`<00000103ooolJ000000@0
oooo0`0000030?ooo`@000000`3oool3000000@0oooo0`00000<0=7=Z@<000000`3oool4000000<0
oooo0`0000030?ooo`<00000103ooolL000000@0oooo0`0000030?ooo`<000000`3oool4000000<0
oooo0`00000>0=7=Z@00303AcJT4000000@0oooo100000030?ooo`@00000103oool4000001/0oooo
100000040?ooo`@000000`3oool4000000@0oooo1000000;0=7=Z@80oooo100000030?ooo`@00000
103oool3000000@0oooo1000000I0?ooo`@00000103oool3000000@0oooo100000030?ooo`@00000
0P3oool;0=7=Z@80oooo0`0000040?ooo`<00000103oool3000000@0oooo0`00000L0?ooo`<00000
103oool3000000@0oooo0`0000040?ooo`<000000P3oool<0=7=Z@<00000103oool3000000<0oooo
100000030?ooo`<00000103ooolJ000000@0oooo0`0000030?ooo`@000000`3oool3000000@0oooo
0`00000<0=7=Z@80oooo0`0000030?ooo`<000000`3oool4000000<0oooo0`0000030?oooaX00000
0`3oool3000000<0oooo100000030?ooo`<000000`3oool300000080oooo3P3AcJT000`0dLfY0P3o
ool4000000@0oooo100000030?ooo`@00000103oool4000001L0oooo100000040?ooo`@00000103o
ool3000000@0oooo100000020?ooo`/0dLfY0P3oool4000000<0oooo100000040?ooo`<00000103o
ool4000001T0oooo100000040?ooo`<00000103oool4000000<0oooo100000020?ooo`/0dLfY0`00
00040?ooo`<00000103oool3000000@0oooo0`0000040?oooaP00000103oool3000000@0oooo0`00
00040?ooo`<00000103oool3000000`0dLfY0P3oool3000000<0oooo100000030?ooo`<00000103o
ool3000000<0oooo600000030?ooo`<00000103oool3000000<0oooo100000030?ooo`<000000P3o
ool<0=7=Z@<000000`3oool4000000<0oooo0`0000030?ooo`<00000103oool3000001H0oooo0`00
00040?ooo`<000000`3oool3000000<0oooo100000030?ooo`<000003P3AcJT000`0dLfY0P3oool4
000000@0oooo100000030?ooo`@00000103oool4000001L0oooo100000040?ooo`@00000103oool3
000000@0oooo100000020?ooo`/0dLfY100000030?ooo`@00000103oool3000000@0oooo10000003
0?oooaL000000`3oool4000000@0oooo0`0000040?ooo`@000000`3oool4000000/0dLfY0P3oool3
000000@0oooo0`0000040?ooo`<00000103oool3000000@0oooo500000040?ooo`<00000103oool3
000000@0oooo0`0000040?ooo`<000000P3oool<0=7=Z@80oooo0`0000030?ooo`@000000`3oool3
000000@0oooo0`0000030?oooaP000000`3oool3000000@0oooo0`0000030?ooo`@000000`3oool3
00000080oooo303AcJT3000000<0oooo100000030?ooo`<000000`3oool3000000@0oooo0`00000F
0?ooo`<00000103oool3000000<0oooo0`0000030?ooo`@000000`3oool3000000h0dLfY000<0=7=
Z@@00000103oool4000000<0oooo100000040?ooo`@00000103ooolC000000@0oooo100000040?oo
o`@000000`3oool4000000@0oooo1000000;0=7=Z@@000000`3oool4000000@0oooo0`0000040?oo
o`@000000`3ooolG000000<0oooo100000040?ooo`<00000103oool4000000<0oooo1000000;0=7=
Z@80oooo0`0000040?ooo`<00000103oool3000000@0oooo0`0000040?oooa@00000103oool30000
00@0oooo0`0000040?ooo`<00000103oool300000080oooo303AcJT3000000@0oooo0`0000030?oo
o`@000000`3oool3000000@0oooo0`00000D0?ooo`<00000103oool3000000<0oooo100000030?oo
o`<00000103oool3000000`0dLfY0P3oool3000000<0oooo0`0000030?ooo`@000000`3oool30000
00<0oooo0`00000D0?ooo`<000000`3oool3000000<0oooo100000030?ooo`<000000`3oool30000
0080oooo3P3AcJT000`0dLfY100000040?ooo`@000000`3oool4000000@0oooo100000040?oooa<0
0000103oool4000000@0oooo100000030?ooo`@00000103oool4000000/0dLfY0P3oool4000000<0
oooo100000040?ooo`<00000103oool4000000<0oooo4`0000030?ooo`@00000103oool3000000@0
oooo100000030?ooo`@000000P3oool;0=7=Z@<00000103oool3000000@0oooo0`0000040?ooo`<0
0000103oool300000180oooo0`0000040?ooo`<00000103oool3000000@0oooo0`0000040?ooo`<0
0000303AcJT20?ooo`<000000`3oool4000000<0oooo0`0000040?ooo`<000000`3oool400000100
oooo100000030?ooo`<00000103oool3000000<0oooo100000030?ooo`<000000P3oool<0=7=Z@80
oooo0`0000030?ooo`<000000`3oool4000000<0oooo0`0000030?ooo`<00000503oool3000000<0
oooo0`0000030?ooo`@000000`3oool3000000<0oooo0`0000020?ooo`h0dLfY000<0=7=Z@80oooo
100000040?ooo`@000000`3oool4000000@0oooo100000040?ooo`l00000103oool4000000@0oooo
100000040?ooo`<00000103oool400000080oooo2`3AcJT20?ooo`@000000`3oool4000000@0oooo
0`0000040?ooo`@000000`3ooolC000000<0oooo100000040?ooo`<00000103oool4000000<0oooo
100000020?ooo`/0dLfY0`0000040?ooo`<00000103oool3000000@0oooo0`0000040?ooo`<00000
4P3oool3000000@0oooo0`0000040?ooo`<00000103oool3000000@0oooo0`00000<0=7=Z@80oooo
0`0000030?ooo`@000000`3oool3000000@0oooo0`0000030?ooo`@00000403oool4000000<0oooo
0`0000040?ooo`<000000`3oool4000000<0oooo0`0000020?ooo``0dLfY0`0000030?ooo`@00000
0`3oool3000000<0oooo0`0000040?ooo`<000000`3oool@000000<0oooo0`0000040?ooo`<00000
0`3oool3000000<0oooo100000030?ooo`<000003P3AcJT000`0dLfY0P3oool4000000@0oooo1000
00030?ooo`@00000103oool4000000@0oooo3`0000040?ooo`@00000103oool4000000@0oooo0`00
00040?ooo`@000000P3oool;0=7=Z@@000000`3oool4000000@0oooo0`0000040?ooo`@000000`3o
ool4000000l0oooo100000030?ooo`@00000103oool3000000@0oooo100000030?ooo`@000002`3A
cJT20?ooo`<00000103oool3000000@0oooo0`0000040?ooo`<00000103oool3000000h0oooo0`00
00040?ooo`<00000103oool3000000@0oooo0`0000040?ooo`<000000P3oool<0=7=Z@<00000103o
ool3000000<0oooo100000030?ooo`<00000103oool3000000<0oooo3P0000030?ooo`<00000103o
ool3000000<0oooo100000030?ooo`<00000103oool3000000`0dLfY0P3oool3000000<0oooo0`00
00030?ooo`@000000`3oool3000000<0oooo0`0000040?ooo``00000103oool3000000<0oooo0`00
00030?ooo`@000000`3oool3000000<0oooo0`0000020?ooo`h0dLfY000<0=7=Z@@00000103oool4
000000<0oooo100000040?ooo`@00000103oool4000000/0oooo100000040?ooo`@00000103oool4
000000<0oooo100000040?ooo`@000002`3AcJT20?ooo`@000000`3oool4000000@0oooo0`000004
0?ooo`@000000`3oool4000000/0oooo100000030?ooo`@00000103oool3000000@0oooo10000003
0?ooo`@000000P3oool;0=7=Z@80oooo0`0000040?ooo`<00000103oool3000000@0oooo0`000004
0?ooo`<000003P3oool3000000@0oooo0`0000040?ooo`<00000103oool3000000@0oooo0`000002
0?ooo``0dLfY0`0000040?ooo`<000000`3oool4000000<0oooo0`0000040?ooo`<000000`3oool>
000000<0oooo0`0000040?ooo`<000000`3oool4000000<0oooo0`0000040?ooo`<00000303AcJT2
0?ooo`<000000`3oool3000000<0oooo100000030?ooo`<000000`3oool3000000@0oooo30000004
0?ooo`<000000`3oool3000000<0oooo100000030?ooo`<000000`3oool300000080oooo3P3AcJT0
00`0dLfY100000040?ooo`@000000`3oool4000000@0oooo100000040?ooo`@000002`3oool40000
00@0oooo100000040?ooo`@000000`3oool4000000@0oooo1000000;0=7=Z@80oooo100000030?oo
o`@00000103oool3000000@0oooo100000030?ooo`@000002`3oool4000000<0oooo100000040?oo
o`<00000103oool4000000<0oooo100000020?ooo`/0dLfY0`0000040?ooo`<00000103oool30000
00@0oooo0`0000040?ooo`<00000103oool:000000@0oooo0`0000040?ooo`<00000103oool30000
00@0oooo0`0000040?ooo`<00000303AcJT20?ooo`<000000`3oool4000000<0oooo0`0000040?oo
o`<000000`3oool4000000<0oooo2P0000030?ooo`@000000`3oool3000000@0oooo0`0000030?oo
o`@000000`3oool300000080oooo303AcJT3000000<0oooo100000030?ooo`<000000`3oool30000
00@0oooo0`0000030?ooo`<000002P3oool3000000<0oooo0`0000040?ooo`<000000`3oool30000
00<0oooo100000030?ooo`<000003P3AcJT000`0dLfY0P3oool4000000@0oooo100000030?ooo`@0
0000103oool4000000@0oooo100000070?ooo`@00000103oool4000000@0oooo100000040?ooo`<0
0000103oool400000080oooo2`3AcJT4000000<0oooo100000040?ooo`<00000103oool4000000<0
oooo100000040?ooo`L00000103oool4000000<0oooo100000040?ooo`<00000103oool4000000<0
oooo1000000;0=7=Z@80oooo0`0000040?ooo`<00000103oool3000000@0oooo0`0000040?ooo`<0
0000103oool6000000@0oooo0`0000040?ooo`<00000103oool3000000@0oooo0`0000040?ooo`<0
00000P3oool<0=7=Z@<00000103oool3000000<0oooo100000030?ooo`<00000103oool3000000<0
oooo100000060?ooo`@000000`3oool3000000@0oooo0`0000030?ooo`@000000`3oool3000000@0
oooo0`00000<0=7=Z@80oooo0`0000030?ooo`<000000`3oool4000000<0oooo0`0000030?ooo`<0
0000103oool3000000H0oooo0`0000040?ooo`<000000`3oool3000000<0oooo100000030?ooo`<0
00000`3oool300000080oooo3P3AcJT000`0dLfY0P3oool4000000@0oooo100000030?ooo`@00000
103oool4000000@0oooo100000070?ooo`@00000103oool4000000@0oooo100000040?ooo`<00000
103oool400000080oooo2`3AcJT4000000<0oooo100000040?ooo`<00000103oool4000000<0oooo
100000040?ooo`L00000103oool4000000<0oooo100000040?ooo`<00000103oool4000000<0oooo
1000000;0=7=Z@80oooo0`0000040?ooo`<00000103oool3000000@0oooo0`0000040?ooo`<00000
103oool6000000@0oooo0`0000040?ooo`<00000103oool3000000@0oooo0`0000040?ooo`<00000
0P3oool<0=7=Z@<00000103oool3000000<0oooo100000030?ooo`<00000103oool3000000<0oooo
100000060?ooo`@000000`3oool3000000@0oooo0`0000030?ooo`@000000`3oool3000000@0oooo
0`00000<0=7=Z@80oooo0`0000030?ooo`<000000`3oool4000000<0oooo0`0000030?ooo`<00000
103oool3000000H0oooo0`0000040?ooo`<000000`3oool3000000<0oooo100000030?ooo`<00000
0`3oool300000080oooo3P3AcJT000`0dLfY100000040?ooo`@000000`3oool4000000@0oooo1000
00040?ooo`@00000103oool3000000@0oooo100000040?ooo`@00000103oool4000000<0oooo1000
00040?ooo`@000002`3AcJT20?ooo`@000000`3oool4000000@0oooo0`0000040?ooo`@000000`3o
ool4000000@0oooo0`0000040?ooo`@000000`3oool4000000@0oooo0`0000040?ooo`@000000`3o
ool400000080oooo2`3AcJT3000000@0oooo0`0000040?ooo`<00000103oool3000000@0oooo0`00
00040?ooo`<00000103oool3000000@0oooo0`0000040?ooo`<00000103oool3000000@0oooo0`00
00040?ooo`<00000303AcJT20?ooo`<000000`3oool4000000<0oooo0`0000040?ooo`<000000`3o
ool4000000<0oooo0`0000040?ooo`<000000`3oool4000000<0oooo0`0000040?ooo`<000000`3o
ool4000000<0oooo0`0000020?ooo``0dLfY0`0000030?ooo`@000000`3oool3000000<0oooo0`00
00040?ooo`<000000`3oool3000000<0oooo100000030?ooo`<000000`3oool3000000@0oooo0`00
00030?ooo`<000000`3oool4000000<0oooo0`00000>0=7=Z@00303AcJT4000000@0oooo10000003
0?ooo`@00000103oool4000000@0oooo100000040?ooo`<00000103oool4000000@0oooo10000004
0?ooo`@000000`3oool4000000@0oooo1000000;0=7=Z@80oooo100000030?ooo`@00000103oool3
000000@0oooo100000030?ooo`@00000103oool3000000@0oooo100000030?ooo`@00000103oool3
000000@0oooo100000030?ooo`@000000P3oool;0=7=Z@<00000103oool3000000@0oooo0`000004
0?ooo`<00000103oool3000000@0oooo0`0000040?ooo`<00000103oool3000000@0oooo0`000004
0?ooo`<00000103oool3000000@0oooo0`00000<0=7=Z@80oooo0`0000030?ooo`@000000`3oool3
000000@0oooo0`0000030?ooo`@000000`3oool3000000@0oooo0`0000030?ooo`@000000`3oool3
000000@0oooo0`0000030?ooo`@000000`3oool300000080oooo303AcJT3000000<0oooo10000003
0?ooo`<000000`3oool3000000@0oooo0`0000030?ooo`<000000`3oool4000000<0oooo0`000003
0?ooo`<00000103oool3000000<0oooo0`0000030?ooo`@000000`3oool3000000h0dLfY000<0=7=
Z@80oooo100000040?ooo`@000000`3oool4000000@0oooo100000040?ooo`@000001`3oool40000
00@0oooo100000040?ooo`@00000103oool3000000@0oooo100000020?ooo`/0dLfY100000030?oo
o`@00000103oool3000000@0oooo100000030?ooo`@00000103oool7000000@0oooo100000030?oo
o`@00000103oool3000000@0oooo100000030?ooo`@000002`3AcJT20?ooo`<00000103oool30000
00@0oooo0`0000040?ooo`<00000103oool3000000@0oooo1P0000040?ooo`<00000103oool30000
00@0oooo0`0000040?ooo`<00000103oool300000080oooo303AcJT3000000@0oooo0`0000030?oo
o`@000000`3oool3000000@0oooo0`0000030?ooo`@000001P3oool4000000<0oooo0`0000040?oo
o`<000000`3oool4000000<0oooo0`0000040?ooo`<00000303AcJT20?ooo`<000000`3oool30000
00<0oooo100000030?ooo`<000000`3oool3000000@0oooo0`0000060?ooo`<00000103oool30000
00<0oooo0`0000030?ooo`@000000`3oool3000000<0oooo0`0000020?ooo`h0dLfY000<0=7=Z@80
oooo100000040?ooo`@000000`3oool4000000@0oooo100000040?ooo`@000001`3oool4000000@0
oooo100000040?ooo`@00000103oool3000000@0oooo100000020?ooo`/0dLfY100000030?ooo`@0
0000103oool3000000@0oooo100000030?ooo`@00000103oool7000000@0oooo100000030?ooo`@0
0000103oool3000000@0oooo100000030?ooo`@000002`3AcJT3000000@0oooo0`0000040?ooo`<0
0000103oool3000000@0oooo0`0000040?ooo`X00000103oool3000000@0oooo0`0000040?ooo`<0
0000103oool3000000@0oooo0`00000<0=7=Z@80oooo0`0000030?ooo`@000000`3oool3000000@0
oooo0`0000030?ooo`@000000`3oool:000000<0oooo100000030?ooo`<00000103oool3000000<0
oooo100000030?ooo`<000000P3oool<0=7=Z@<000000`3oool4000000<0oooo0`0000030?ooo`<0
0000103oool3000000<0oooo0`00000:0?ooo`<000000`3oool3000000@0oooo0`0000030?ooo`<0
00000`3oool4000000<0oooo0`00000>0=7=Z@00303AcJT4000000@0oooo100000030?ooo`@00000
103oool4000000@0oooo1000000;0?ooo`@00000103oool4000000@0oooo100000030?ooo`@00000
103oool4000000/0dLfY0P3oool4000000<0oooo100000040?ooo`<00000103oool4000000<0oooo
1000000;0?ooo`@000000`3oool4000000@0oooo0`0000040?ooo`@000000`3oool400000080oooo
2`3AcJT3000000@0oooo0`0000040?ooo`<00000103oool3000000@0oooo0`0000040?ooo`X00000
103oool3000000@0oooo0`0000040?ooo`<00000103oool3000000@0oooo0`00000<0=7=Z@80oooo
0`0000030?ooo`@000000`3oool3000000@0oooo0`0000030?ooo`@000000`3oool:000000<0oooo
100000030?ooo`<00000103oool3000000<0oooo100000030?ooo`<000000P3oool<0=7=Z@<00000
0`3oool4000000<0oooo0`0000030?ooo`<00000103oool3000000<0oooo0`00000:0?ooo`<00000
0`3oool3000000@0oooo0`0000030?ooo`<000000`3oool4000000<0oooo0`00000>0=7=Z@00303A
cJT4000000@0oooo100000030?ooo`@00000103oool4000000@0oooo1000000;0?ooo`@00000103o
ool4000000@0oooo100000030?ooo`@00000103oool4000000/0dLfY100000030?ooo`@00000103o
ool3000000@0oooo100000030?ooo`@000003`3oool4000000<0oooo100000040?ooo`<00000103o
ool4000000<0oooo1000000;0=7=Z@80oooo0`0000040?ooo`<00000103oool3000000@0oooo0`00
00040?ooo`<000003P3oool3000000@0oooo0`0000040?ooo`<00000103oool3000000@0oooo0`00
00020?ooo``0dLfY0`0000040?ooo`<000000`3oool4000000<0oooo0`0000040?ooo`<000000`3o
ool>000000<0oooo0`0000040?ooo`<000000`3oool4000000<0oooo0`0000040?ooo`<00000303A
cJT20?ooo`<000000`3oool3000000<0oooo100000030?ooo`<000000`3oool3000000@0oooo3000
00040?ooo`<000000`3oool3000000<0oooo100000030?ooo`<000000`3oool300000080oooo3P3A
cJT000`0dLfY0P3oool4000000@0oooo100000030?ooo`@00000103oool4000000@0oooo3`000004
0?ooo`@00000103oool4000000@0oooo0`0000040?ooo`@000000P3oool;0=7=Z@@000000`3oool4
000000@0oooo0`0000040?ooo`@000000`3oool4000000l0oooo100000030?ooo`@00000103oool3
000000@0oooo100000030?ooo`@000002`3AcJT20?ooo`<00000103oool3000000@0oooo0`000004
0?ooo`<00000103oool3000000h0oooo0`0000040?ooo`<00000103oool3000000@0oooo0`000004
0?ooo`<000000P3oool<0=7=Z@<00000103oool3000000<0oooo100000030?ooo`<00000103oool3
000000<0oooo3P0000030?ooo`<00000103oool3000000<0oooo100000030?ooo`<00000103oool3
000000`0dLfY0`0000030?ooo`@000000`3oool3000000<0oooo0`0000040?ooo`<000000`3oool@
000000<0oooo0`0000040?ooo`<000000`3oool3000000<0oooo100000030?ooo`<000003P3AcJT0
00`0dLfY0P3oool4000000@0oooo100000030?ooo`@00000103oool4000000@0oooo3`0000040?oo
o`@00000103oool4000000@0oooo0`0000040?ooo`@000000P3oool;0=7=Z@80oooo100000030?oo
o`@00000103oool3000000@0oooo100000030?oooa<000000`3oool4000000@0oooo0`0000040?oo
o`@000000`3oool400000080oooo2`3AcJT3000000@0oooo0`0000040?ooo`<00000103oool30000
00@0oooo0`00000B0?ooo`<00000103oool3000000@0oooo0`0000040?ooo`<00000103oool30000
00`0dLfY0P3oool3000000<0oooo100000030?ooo`<00000103oool3000000<0oooo1000000@0?oo
o`@000000`3oool3000000@0oooo0`0000030?ooo`@000000`3oool300000080oooo303AcJT30000
00<0oooo100000030?ooo`<000000`3oool3000000@0oooo0`0000030?oooa0000000`3oool30000
00@0oooo0`0000030?ooo`<000000`3oool4000000<0oooo0`00000>0=7=Z@00303AcJT4000000@0
oooo100000030?ooo`@00000103oool4000000@0oooo4`0000040?ooo`@00000103oool4000000<0
oooo100000040?ooo`@000002`3AcJT20?ooo`@000000`3oool4000000@0oooo0`0000040?ooo`@0
00000`3ooolC000000<0oooo100000040?ooo`<00000103oool4000000<0oooo100000020?ooo`/0
dLfY0`0000040?ooo`<00000103oool3000000@0oooo0`0000040?ooo`<000004P3oool3000000@0
oooo0`0000040?ooo`<00000103oool3000000@0oooo0`00000<0=7=Z@<00000103oool3000000<0
oooo100000030?ooo`<00000103oool3000001@0oooo0`0000040?ooo`<000000`3oool4000000<0
oooo0`0000040?ooo`<00000303AcJT20?ooo`<000000`3oool3000000<0oooo100000030?ooo`<0
00000`3oool3000001@0oooo0`0000030?ooo`<000000`3oool4000000<0oooo0`0000030?ooo`<0
00000P3oool>0=7=Z@00303AcJT4000000@0oooo100000030?ooo`@00000103oool4000000@0oooo
4`0000040?ooo`@00000103oool4000000<0oooo100000040?ooo`@000002`3AcJT4000000<0oooo
100000040?ooo`<00000103oool4000000<0oooo5`0000030?ooo`@00000103oool3000000@0oooo
100000030?ooo`@000002`3AcJT20?ooo`<00000103oool3000000@0oooo0`0000040?ooo`<00000
103ooolD000000@0oooo0`0000040?ooo`<00000103oool3000000@0oooo0`0000020?ooo``0dLfY
0`0000040?ooo`<000000`3oool4000000<0oooo0`0000040?ooo`<00000503oool3000000@0oooo
0`0000030?ooo`@000000`3oool3000000@0oooo0`00000<0=7=Z@80oooo0`0000030?ooo`<00000
0`3oool4000000<0oooo0`0000030?ooo`<00000503oool3000000<0oooo0`0000030?ooo`@00000
0`3oool3000000<0oooo0`0000020?ooo`h0dLfY000<0=7=Z@80oooo100000040?ooo`@000000`3o
ool4000000@0oooo1000000G0?ooo`@00000103oool4000000@0oooo0`0000040?ooo`@000000P3o
ool;0=7=Z@@000000`3oool4000000@0oooo0`0000040?ooo`@000000`3ooolG000000<0oooo1000
00040?ooo`<00000103oool4000000<0oooo1000000;0=7=Z@<00000103oool3000000@0oooo0`00
00040?ooo`<00000103ooolH000000@0oooo0`0000040?ooo`<00000103oool3000000@0oooo0`00
000<0=7=Z@80oooo0`0000030?ooo`@000000`3oool3000000@0oooo0`0000030?oooaP000000`3o
ool3000000@0oooo0`0000030?ooo`@000000`3oool300000080oooo303AcJT3000000<0oooo1000
00030?ooo`<000000`3oool3000000@0oooo0`00000F0?ooo`<00000103oool3000000<0oooo0`00
00030?ooo`@000000`3oool3000000h0dLfY000<0=7=Z@@00000103oool4000000<0oooo10000004
0?ooo`@000006`3oool4000000@0oooo100000030?ooo`@00000103oool4000000/0dLfY0P3oool4
000000<0oooo100000040?ooo`<00000103oool4000001T0oooo100000040?ooo`<00000103oool4
000000<0oooo100000020?ooo`/0dLfY0`0000040?ooo`<00000103oool3000000@0oooo0`000004
0?oooaP00000103oool3000000@0oooo0`0000040?ooo`<00000103oool3000000`0dLfY0P3oool3
000000<0oooo100000030?ooo`<00000103oool3000000<0oooo600000030?ooo`<00000103oool3
000000<0oooo100000030?ooo`<000000P3oool<0=7=Z@80oooo0`0000030?ooo`<000000`3oool4
000000<0oooo0`0000030?oooaX000000`3oool3000000<0oooo100000030?ooo`<000000`3oool3
00000080oooo3P3AcJT000`0dLfY100000040?ooo`@000000`3oool4000000@0oooo1000000K0?oo
o`@00000103oool4000000<0oooo100000040?ooo`@000002`3AcJT20?ooo`@000000`3oool40000
00@0oooo0`0000040?ooo`@000006@3oool4000000@0oooo0`0000040?ooo`@000000`3oool40000
0080oooo2`3AcJT20?ooo`<00000103oool3000000@0oooo0`0000040?ooo`<00000703oool30000
00@0oooo0`0000040?ooo`<00000103oool300000080oooo303AcJT3000000@0oooo0`0000030?oo
o`@000000`3oool3000000@0oooo6P0000040?ooo`<000000`3oool4000000<0oooo0`0000040?oo
o`<00000303AcJT20?ooo`<000000`3oool3000000<0oooo100000030?ooo`<000000`3ooolJ0000
00<0oooo0`0000030?ooo`@000000`3oool3000000<0oooo0`0000020?ooo`h0dLfY000<0=7=Z@80
oooo100000040?ooo`@000000`3oool4000000@0oooo7`0000040?ooo`@00000103oool3000000@0
oooo100000020?ooo`/0dLfY100000030?ooo`@00000103oool3000000@0oooo1000000M0?ooo`@0
0000103oool3000000@0oooo100000030?ooo`@000002`3AcJT20?ooo`<00000103oool3000000@0
oooo0`0000040?ooo`<00000703oool3000000@0oooo0`0000040?ooo`<00000103oool300000080
oooo303AcJT20?ooo`<000000`3oool4000000<0oooo0`0000040?ooo`<000007P3oool3000000@0
oooo0`0000030?ooo`@000000`3oool300000080oooo303AcJT3000000<0oooo100000030?ooo`<0
00000`3oool3000000@0oooo700000040?ooo`<000000`3oool3000000<0oooo100000030?ooo`<0
00003P3AcJT000`0dLfY0P3oool4000000@0oooo100000030?ooo`@00000103ooolO000000@0oooo
100000040?ooo`<00000103oool400000080oooo2`3AcJT4000000<0oooo100000040?ooo`<00000
103oool4000001d0oooo100000040?ooo`<00000103oool4000000<0oooo1000000;0=7=Z@<00000
103oool3000000@0oooo0`0000040?ooo`<00000803oool3000000@0oooo0`0000040?ooo`<00000
103oool3000000`0dLfY0P3oool3000000<0oooo100000030?ooo`<00000103oool3000001h0oooo
0`0000040?ooo`<000000`3oool4000000<0oooo0`0000020?ooo``0dLfY0P3oool3000000<0oooo
0`0000030?ooo`@000000`3oool300000200oooo0`0000030?ooo`@000000`3oool3000000<0oooo
0`0000020?ooo`h0dLfY000<0=7=Z@@00000103oool4000000<0oooo100000040?ooob<00000103o
ool4000000<0oooo100000040?ooo`@000002`3AcJT20?ooo`@000000`3oool4000000@0oooo0`00
00040?ooob400000103oool3000000@0oooo100000030?ooo`@000000P3oool;0=7=Z@<00000103o
ool3000000@0oooo0`0000040?ooo`<00000803oool3000000@0oooo0`0000040?ooo`<00000103o
ool3000000`0dLfY0`0000040?ooo`<000000`3oool4000000<0oooo0`00000R0?ooo`<000000`3o
ool4000000<0oooo0`0000040?ooo`<00000303AcJT20?ooo`<000000`3oool3000000<0oooo1000
00030?ooo`<00000803oool3000000<0oooo100000030?ooo`<000000`3oool300000080oooo3P3A
cJT000`0dLfY100000040?ooo`@000000`3oool4000000@0oooo8`0000040?ooo`@000000`3oool4
000000@0oooo1000000;0=7=Z@@000000`3oool4000000@0oooo0`0000040?ooobD00000103oool3
000000@0oooo100000030?ooo`@000002`3AcJT20?ooo`<00000103oool3000000@0oooo0`000004
0?ooob800000103oool3000000@0oooo0`0000040?ooo`<000000P3oool<0=7=Z@<00000103oool3
000000<0oooo100000030?ooo`<000008P3oool3000000<0oooo100000030?ooo`<00000103oool3
000000`0dLfY0`0000030?ooo`@000000`3oool3000000<0oooo0`00000T0?ooo`<000000`3oool3
000000<0oooo100000030?ooo`<000003P3AcJT000`0dLfY0P3oool4000000@0oooo100000030?oo
o`@000009`3oool4000000@0oooo0`0000040?ooo`@000000P3oool;0=7=Z@@000000`3oool40000
00@0oooo0`0000040?ooobD00000103oool3000000@0oooo100000030?ooo`@000002`3AcJT30000
00@0oooo0`0000040?ooo`<00000103ooolV000000@0oooo0`0000040?ooo`<00000103oool30000
00`0dLfY0P3oool3000000<0oooo100000030?ooo`<00000103ooolT000000@0oooo0`0000030?oo
o`@000000`3oool300000080oooo303AcJT3000000<0oooo100000030?ooo`<000000`3oool30000
02@0oooo0`0000030?ooo`<000000`3oool4000000<0oooo0`00000>0=7=Z@00303AcJT20?ooo`@0
0000103oool4000000<0oooo1000000W0?ooo`@00000103oool3000000@0oooo100000020?ooo`/0
dLfY0P3oool4000000<0oooo100000040?ooo`<00000:@3oool3000000@0oooo100000030?ooo`@0
00000P3oool;0=7=Z@<00000103oool3000000@0oooo0`0000040?ooobH00000103oool3000000@0
oooo0`0000040?ooo`<00000303AcJT3000000@0oooo0`0000030?ooo`@000000`3ooolX000000<0
oooo100000030?ooo`<00000103oool3000000`0dLfY0P3oool3000000<0oooo0`0000030?ooo`@0
00000`3ooolV000000<0oooo100000030?ooo`<000000`3oool300000080oooo3P3AcJT000`0dLfY
100000040?ooo`@000000`3oool4000002/0oooo100000030?ooo`@00000103oool4000000/0dLfY
0P3oool4000000<0oooo100000040?ooo`<00000:@3oool3000000@0oooo100000030?ooo`@00000
0P3oool;0=7=Z@80oooo0`0000040?ooo`<00000103oool3000002X0oooo0`0000040?ooo`<00000
103oool300000080oooo303AcJT3000000@0oooo0`0000030?ooo`@000000`3ooolX000000<0oooo
100000030?ooo`<00000103oool3000000`0dLfY0`0000030?ooo`@000000`3oool3000000<0oooo
:P0000030?ooo`<000000`3oool4000000<0oooo0`00000>0=7=Z@00303AcJT4000000@0oooo1000
00030?ooo`@00000:`3oool4000000<0oooo100000040?ooo`@000002`3AcJT4000000<0oooo1000
00040?ooo`<00000;@3oool3000000@0oooo100000030?ooo`@000002`3AcJT20?ooo`<00000103o
ool3000000@0oooo0`00000Z0?ooo`<00000103oool3000000@0oooo0`0000020?ooo``0dLfY0P3o
ool3000000<0oooo100000030?ooo`<00000;03oool3000000<0oooo100000030?ooo`<000000P3o
ool<0=7=Z@<000000`3oool4000000<0oooo0`0000030?ooobX000000`3oool3000000<0oooo1000
00030?ooo`<000003P3AcJT000`0dLfY0P3oool4000000@0oooo100000030?ooobl00000103oool3
000000@0oooo100000020?ooo`/0dLfY100000030?ooo`@00000103oool3000002d0oooo0`000004
0?ooo`@000000`3oool4000000/0dLfY0`0000040?ooo`<00000103oool3000002h0oooo0`000004
0?ooo`<00000103oool3000000`0dLfY0P3oool3000000<0oooo100000030?ooo`<00000;03oool3
000000<0oooo100000030?ooo`<000000P3oool<0=7=Z@80oooo0`0000030?ooo`<000000`3oool4
000002`0oooo100000030?ooo`<000000`3oool300000080oooo3P3AcJT000`0dLfY0P3oool40000
00@0oooo100000030?ooobl00000103oool3000000@0oooo100000020?ooo`/0dLfY0P3oool40000
00<0oooo100000040?ooobl00000103oool4000000<0oooo100000020?ooo`/0dLfY0`0000040?oo
o`<00000103oool3000002h0oooo0`0000040?ooo`<00000103oool3000000`0dLfY0`0000040?oo
o`<000000`3oool4000002h0oooo100000030?ooo`<00000103oool3000000`0dLfY0`0000030?oo
o`@000000`3oool300000300oooo0`0000030?ooo`@000000`3oool3000000h0dLfY000<0=7=Z@@0
0000103oool4000000<0oooo<`0000030?ooo`@00000103oool4000000/0dLfY0P3oool4000000<0
oooo100000040?ooobl00000103oool4000000<0oooo100000020?ooo`/0dLfY0P3oool3000000@0
oooo0`0000040?oooc000000103oool3000000@0oooo0`0000020?ooo``0dLfY0P3oool3000000<0
oooo100000030?oooc8000000`3oool4000000<0oooo0`0000020?ooo``0dLfY0`0000030?ooo`@0
00000`3oool300000300oooo0`0000030?ooo`@000000`3oool3000000h0dLfY000<0=7=Z@@00000
103oool4000000<0oooo<`0000030?ooo`@00000103oool4000000/0dLfY100000030?ooo`@00000
103ooolc000000@0oooo100000030?ooo`@000002`3AcJT3000000@0oooo0`0000040?oooc@00000
103oool3000000@0oooo0`00000<0=7=Z@80oooo0`0000030?ooo`@000000`3ooolb000000<0oooo
100000030?ooo`<000000P3oool<0=7=Z@80oooo0`0000030?ooo`<000000`3ooold000000<0oooo
0`0000030?ooo`<000000P3oool>0=7=Z@00303AcJT20?ooo`@00000103oool4000003H0oooo0`00
00040?ooo`@000000P3oool;0=7=Z@80oooo100000030?ooo`@00000=`3oool4000000<0oooo1000
00020?ooo`/0dLfY0`0000040?ooo`<00000103ooold000000@0oooo0`0000040?ooo`<00000303A
cJT3000000@0oooo0`0000030?ooocH000000`3oool3000000@0oooo0`00000<0=7=Z@80oooo0`00
00030?ooo`<000000`3ooold000000<0oooo0`0000030?ooo`<000000P3oool>0=7=Z@00303AcJT2
0?ooo`@00000103oool4000003H0oooo0`0000040?ooo`@000000P3oool;0=7=Z@80oooo10000003
0?ooo`@00000=`3oool4000000<0oooo100000020?ooo`/0dLfY0P3oool3000000@0oooo0`00000h
0?ooo`<00000103oool300000080oooo303AcJT3000000@0oooo0`0000030?ooocH000000`3oool3
000000@0oooo0`00000<0=7=Z@<000000`3oool4000000<0oooo=P0000030?ooo`@000000`3oool3
000000h0dLfY000<0=7=Z@@00000103oool4000003T0oooo100000040?ooo`@000002`3AcJT40000
00<0oooo1000000k0?ooo`@000000`3oool4000000/0dLfY0P3oool3000000@0oooo0`00000h0?oo
o`<00000103oool300000080oooo303AcJT20?ooo`<000000`3oool4000003P0oooo100000030?oo
o`<000000P3oool<0=7=Z@80oooo0`0000030?ooo`<00000>P3oool3000000<0oooo0`0000020?oo
o`h0dLfY000<0=7=Z@@00000103oool4000003T0oooo100000040?ooo`@000002`3AcJT4000000<0
oooo1000000k0?ooo`@000000`3oool4000000/0dLfY0`0000040?ooo`<00000?03oool3000000@0
oooo0`00000<0=7=Z@<00000103oool3000003`0oooo0`0000040?ooo`<00000303AcJT20?ooo`<0
00000`3oool3000003X0oooo0`0000030?ooo`<000000P3oool>0=7=Z@00303AcJT20?ooo`@00000
103ooolm000000@0oooo100000020?ooo`/0dLfY0P3oool4000000<0oooo?`0000030?ooo`@00000
0P3oool;0=7=Z@<00000103oool3000003`0oooo0`0000040?ooo`<00000303AcJT3000000@0oooo
0`00000l0?ooo`<00000103oool3000000`0dLfY0`0000030?ooo`@00000?03oool4000000<0oooo
0`00000>0=7=Z@00303AcJT4000000@0oooo@@0000040?ooo`@000002`3AcJT20?ooo`@000000`3o
oolo000000<0oooo100000020?ooo`/0dLfY0P3oool3000000@0oooo?P0000040?ooo`<000000P3o
ool<0=7=Z@80oooo0`0000030?oood0000000`3oool300000080oooo303AcJT20?ooo`<000000`3o
oom0000000<0oooo0`0000020?ooo`h0dLfY000<0=7=Z@@00000103ooom1000000@0oooo1000000;
0=7=Z@@000000`3ooom3000000<0oooo1000000;0=7=Z@<00000103ooom2000000@0oooo0`00000<
0=7=Z@80oooo0`0000030?oood0000000`3oool300000080oooo303AcJT20?ooo`<000000`3ooom0
000000<0oooo0`0000020?ooo`h0dLfY000<0=7=Z@80oooo100000150?ooo`@000000P3oool;0=7=
Z@@000000`3ooom3000000<0oooo1000000;0=7=Z@<00000103ooom2000000@0oooo0`00000<0=7=
Z@<00000103ooom2000000@0oooo0`00000<0=7=Z@<000000`3ooom4000000<0oooo0`00000>0=7=
Z@00303AcJT20?ooo`@00000A@3oool400000080oooo2`3AcJT20?ooo`@00000A@3oool400000080
oooo2`3AcJT20?ooo`<00000AP3oool300000080oooo303AcJT20?ooo`<00000AP3oool300000080
oooo303AcJT3000000<0ooooA00000030?ooo`<000003P3AcJT000`0dLfY100000190?ooo`@00000
2`3AcJT20?ooo`@00000A@3oool400000080oooo2`3AcJT20?ooo`<00000AP3oool300000080oooo
303AcJT20?ooo`<00000AP3oool300000080oooo303AcJT20?ooo`<00000AP3oool300000080oooo
3P3AcJT000`0dLfY100000190?ooo`@000002`3AcJT4000004T0oooo1000000;0=7=Z@<00000BP3o
ool3000000`0dLfY0`00001:0?ooo`<00000303AcJT3000004X0oooo0`00000>0=7=Z@00303AcJT2
0?ooodd000000P3oool;0=7=Z@80ooooC@0000020?ooo`/0dLfY0`00001:0?ooo`<00000303AcJT3
000004X0oooo0`00000<0=7=Z@<00000BP3oool3000000h0dLfY000<0=7=Z@80ooooC@0000020?oo
o`/0dLfY0P3ooom=00000080oooo2`3AcJT20?oood`000000P3oool<0=7=Z@80ooooC00000020?oo
o``0dLfY0P3ooom<00000080oooo3P3AcJT000`0dLfYD@00000;0=7=ZE4000002`3AcJU@000000`0
dLfYD000000<0=7=ZE0000003P3AcJT000`0dLfYD@00000;0=7=ZE4000002`3AcJU@000000`0dLfY
D000000<0=7=ZE0000003P3AcJT00?l0dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0
dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0
dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0dLfYf`3AcJT000`0dLfYD@3oool;0=7=
ZE40oooo2`3AcJU@0?ooo``0dLfYD03oool<0=7=ZE00oooo3P3AcJT000`0dLfYD@3oool;0=7=ZE40
oooo2`3AcJU@0?ooo``0dLfYD03oool<0=7=ZE00oooo3P3AcJT000`0dLfYD@3oool;0=7=ZE400000
2`3AcJU@000000`0dLfYD000000<0=7=ZE0000003P3AcJT000`0dLfYD@00000;0=7=ZE4000002`3A
cJU@000000`0dLfYD000000<0=7=ZE0000003P3AcJT000`0dLfYD@00000;0=7=ZE4000002`3AcJT2
0?oood`000000P3oool<0=7=Z@80ooooC00000020?ooo``0dLfY0P3ooom<00000080oooo3P3AcJT0
00`0dLfY0`3ooom;000000<0oooo2`3AcJT20?ooodd000000P3oool;0=7=Z@80ooooC00000020?oo
o``0dLfY0P3ooom<00000080oooo303AcJT20?oood`000000P3oool>0=7=Z@00303AcJT30?oood/0
00000`3oool;0=7=Z@80ooooC@0000020?ooo`/0dLfY0P3ooom<00000080oooo303AcJT4000004P0
oooo1000000<0=7=Z@@00000B03oool4000000h0dLfY000<0=7=Z@<0ooooB`0000030?ooo`/0dLfY
1@0000170?ooo`D000002`3AcJT4000004P0oooo1000000<0=7=Z@@00000B03oool4000000`0dLfY
100000180?ooo`@000003P3AcJT000`0dLfY1@0000170?ooo`D000002`3AcJT5000004L0oooo1@00
000;0=7=Z@@00000B03oool4000000`0dLfY0P3oool4000004@0oooo100000020?ooo``0dLfY0P3o
ool4000004@0oooo100000020?ooo`h0dLfY000<0=7=Z@D00000A`3oool5000000/0dLfY0P3oool5
000004<0oooo1@0000020?ooo`/0dLfY0P3oool500000480oooo1@0000020?ooo``0dLfY0P3oool4
000004@0oooo100000020?ooo``0dLfY0P3oool4000004@0oooo100000020?ooo`h0dLfY000<0=7=
Z@<0oooo1@0000110?ooo`D000000`3oool;0=7=Z@80oooo1@0000130?ooo`D000000P3oool;0=7=
Z@80oooo1@0000120?ooo`D000000P3oool<0=7=Z@80oooo100000140?ooo`@000000P3oool<0=7=
Z@@00000103ooom0000000@0oooo1000000>0=7=Z@00303AcJT30?ooo`D00000@@3oool5000000<0
oooo2`3AcJT20?ooo`D00000@`3oool500000080oooo2`3AcJT4000000D0oooo?P0000050?ooo`@0
0000303AcJT4000000@0oooo@00000040?ooo`@00000303AcJT4000000@0oooo@00000040?ooo`@0
00003P3AcJT000`0dLfY0`3oool500000440oooo1@0000030?ooo`/0dLfY1@0000050?ooocd00000
1@3oool5000000/0dLfY100000050?oooch000001@3oool4000000`0dLfY100000040?oood000000
103oool4000000`0dLfY0P3oool4000000@0oooo?00000040?ooo`@000000P3oool>0=7=Z@00303A
cJT5000000D0oooo?@0000050?ooo`D000002`3AcJT5000000D0oooo?@0000050?ooo`D000002`3A
cJT20?ooo`D00000103ooolj000000@0oooo1@0000020?ooo``0dLfY0P3oool4000000D0oooo>P00
00050?ooo`@000000P3oool<0=7=Z@80oooo100000040?oooc`00000103oool400000080oooo3P3A
cJT000`0dLfY1@0000050?ooocd000001@3oool5000000/0dLfY0P3oool5000000D0oooo>@000005
0?ooo`D000000P3oool;0=7=Z@80oooo1@0000040?ooocX00000103oool500000080oooo303AcJT2
0?ooo`@000001@3ooolj000000D0oooo100000020?ooo``0dLfY100000040?ooo`@00000>03oool4
000000@0oooo1000000>0=7=Z@00303AcJT30?ooo`D000001@3ooolg000000D0oooo1@0000030?oo
o`/0dLfY0P3oool5000000D0oooo>@0000050?ooo`D000000P3oool;0=7=Z@80oooo1@0000040?oo
ocX00000103oool500000080oooo303AcJT4000000@0oooo1@00000f0?ooo`D00000103oool40000
00`0dLfY100000040?ooo`@00000>03oool4000000@0oooo1000000>0=7=Z@00303AcJT30?ooo`D0
00001@3ooolg000000D0oooo1@0000030?ooo`/0dLfY1@0000050?ooo`@00000=@3oool4000000D0
oooo1@00000;0=7=Z@@000001@3oool4000003H0oooo100000050?ooo`@00000303AcJT4000000@0
oooo1@00000f0?ooo`D00000103oool4000000`0dLfY0P3oool4000000@0oooo1000000d0?ooo`@0
0000103oool400000080oooo3P3AcJT000`0dLfY0`3oool5000000D0oooo=`0000050?ooo`D00000
0`3oool;0=7=Z@D000001@3oool4000003D0oooo100000050?ooo`D000002`3AcJT4000000D0oooo
1000000f0?ooo`@000001@3oool4000000`0dLfY0P3oool4000000D0oooo1000000b0?ooo`@00000
1@3oool400000080oooo303AcJT20?ooo`@00000103oool4000003@0oooo100000040?ooo`@00000
0P3oool>0=7=Z@00303AcJT5000000D0oooo1@00000c0?ooo`D000001@3oool5000000/0dLfY1@00
00050?ooo`@00000=@3oool4000000D0oooo1@00000;0=7=Z@80oooo1@0000040?ooo`D00000<03o
ool5000000@0oooo1@0000020?ooo``0dLfY0P3oool4000000D0oooo1000000b0?ooo`@000001@3o
ool400000080oooo303AcJT4000000@0oooo100000040?oooc000000103oool4000000@0oooo1000
000>0=7=Z@00303AcJT5000000D0oooo1@00000c0?ooo`D000001@3oool5000000/0dLfY0P3oool5
000000D0oooo1@00000_0?ooo`D000001@3oool500000080oooo2`3AcJT20?ooo`D00000103oool5
00000300oooo1@0000040?ooo`D000000P3oool<0=7=Z@@00000103oool5000000@0oooo;P000004
0?ooo`D00000103oool4000000`0dLfY100000040?ooo`@00000103oool`000000@0oooo10000004
0?ooo`@000003P3AcJT000`0dLfY0`3oool5000000D0oooo1@00000]0?ooo`D000001@3oool50000
00<0oooo2`3AcJT20?ooo`D000001@3oool5000002l0oooo1@0000050?ooo`D000000P3oool;0=7=
Z@@000001@3oool4000000D0oooo;00000050?ooo`@000001@3oool4000000`0dLfY100000040?oo
o`D00000103oool^000000@0oooo1@0000040?ooo`@00000303AcJT20?ooo`@00000103oool40000
00@0oooo;00000040?ooo`@00000103oool400000080oooo3P3AcJT000`0dLfY0`3oool5000000D0
oooo1@00000]0?ooo`D000001@3oool5000000<0oooo2`3AcJT5000000D0oooo100000050?ooob/0
00001@3oool4000000D0oooo1@00000;0=7=Z@@000001@3oool4000000D0oooo;00000050?ooo`@0
00001@3oool4000000`0dLfY0P3oool4000000D0oooo100000040?ooobX00000103oool4000000D0
oooo100000020?ooo``0dLfY0P3oool4000000@0oooo100000040?ooob`00000103oool4000000@0
oooo100000020?ooo`h0dLfY000<0=7=Z@<0oooo1@0000050?ooo`D00000;@3oool5000000D0oooo
1@0000030?ooo`/0dLfY1@0000050?ooo`@000001@3oool[000000D0oooo100000050?ooo`D00000
2`3AcJT20?ooo`D00000103oool5000000@0oooo:00000040?ooo`D00000103oool500000080oooo
303AcJT20?ooo`@000001@3oool4000000@0oooo:P0000040?ooo`@000001@3oool400000080oooo
303AcJT4000000@0oooo100000040?ooo`@00000:03oool4000000@0oooo100000040?ooo`@00000
3P3AcJT000`0dLfY1@0000050?ooo`D000001@3ooolY000000D0oooo1@0000050?ooo`D000002`3A
cJT5000000D0oooo100000050?ooob/000001@3oool4000000D0oooo1@00000;0=7=Z@80oooo1@00
00040?ooo`D00000103ooolX000000@0oooo1@0000040?ooo`D000000P3oool<0=7=Z@@00000103o
ool5000000@0oooo1000000V0?ooo`@00000103oool5000000@0oooo1000000<0=7=Z@@00000103o
ool4000000@0oooo1000000X0?ooo`@00000103oool4000000@0oooo1000000>0=7=Z@00303AcJT5
000000D0oooo1@0000050?ooobT000001@3oool5000000D0oooo1@00000;0=7=Z@80oooo1@000005
0?ooo`D00000103ooolW000000@0oooo1@0000050?ooo`D000000P3oool;0=7=Z@@000001@3oool4
000000D0oooo1000000T0?ooo`@000001@3oool4000000D0oooo1000000<0=7=Z@@00000103oool5
000000@0oooo1000000V0?ooo`@00000103oool5000000@0oooo1000000<0=7=Z@80oooo10000004
0?ooo`@00000103oool4000002@0oooo100000040?ooo`@00000103oool400000080oooo3P3AcJT0
00`0dLfY0`3oool5000000D0oooo1@0000050?ooob<000001@3oool5000000D0oooo1@0000030?oo
o`/0dLfY0P3oool5000000D0oooo1@0000040?ooobL00000103oool5000000D0oooo1@0000020?oo
o`/0dLfY100000050?ooo`@000001@3oool4000002@0oooo100000050?ooo`@000001@3oool40000
00`0dLfY0P3oool4000000D0oooo100000040?ooo`@000008P3oool4000000@0oooo100000050?oo
o`@000000P3oool<0=7=Z@80oooo100000040?ooo`@00000103oool4000002@0oooo100000040?oo
o`@00000103oool400000080oooo3P3AcJT000`0dLfY0`3oool5000000D0oooo1@0000050?ooob<0
00001@3oool5000000D0oooo1@0000030?ooo`/0dLfY1@0000050?ooo`@000001@3oool500000240
oooo1@0000050?ooo`@000001@3oool5000000/0dLfY100000050?ooo`@000001@3oool4000002@0
oooo100000050?ooo`@000001@3oool4000000`0dLfY0P3oool4000000D0oooo100000040?ooo`@0
00008P3oool4000000@0oooo100000050?ooo`@000000P3oool<0=7=Z@@00000103oool4000000@0
oooo100000040?ooob000000103oool4000000@0oooo100000040?ooo`@000003P3AcJT000`0dLfY
0`3oool5000000D0oooo1@0000050?ooob<000001@3oool5000000D0oooo1@0000030?ooo`/0dLfY
1@0000050?ooo`@000001@3oool500000240oooo1@0000050?ooo`@000001@3oool5000000/0dLfY
0P3oool5000000@0oooo1@0000040?ooo`@00000803oool4000000@0oooo1@0000040?ooo`D00000
0P3oool<0=7=Z@@00000103oool5000000@0oooo100000040?oooah00000103oool4000000@0oooo
1@0000040?ooo`@00000303AcJT4000000@0oooo100000040?ooo`@00000103ooolP000000@0oooo
100000040?ooo`@00000103oool4000000h0dLfY000<0=7=Z@D000001@3oool5000000D0oooo1@00
000O0?ooo`D000001@3oool5000000D0oooo1@00000;0=7=Z@80oooo1@0000050?ooo`D00000103o
ool5000001d0oooo1@0000040?ooo`D000001@3oool500000080oooo2`3AcJT20?ooo`D00000103o
ool5000000@0oooo1000000P0?ooo`@00000103oool5000000@0oooo1@0000020?ooo``0dLfY1000
00040?ooo`D00000103oool4000000@0oooo7P0000040?ooo`@00000103oool5000000@0oooo1000
000<0=7=Z@80oooo100000040?ooo`@00000103oool4000000@0oooo700000040?ooo`@00000103o
ool4000000@0oooo100000020?ooo`h0dLfY000<0=7=Z@D000001@3oool5000000D0oooo1@00000O
0?ooo`D000001@3oool5000000D0oooo1@00000;0=7=Z@80oooo1@0000050?ooo`D00000103oool5
000001d0oooo1@0000040?ooo`D000001@3oool500000080oooo2`3AcJT4000000D0oooo10000005
0?ooo`@000001@3ooolJ000000D0oooo100000050?ooo`@000001@3oool4000000`0dLfY0P3oool4
000000D0oooo100000040?ooo`@00000103ooolJ000000@0oooo100000040?ooo`@000001@3oool4
00000080oooo303AcJT20?ooo`@00000103oool4000000@0oooo100000040?oooa`00000103oool4
000000@0oooo100000040?ooo`@000000P3oool>0=7=Z@00303AcJT30?ooo`D000001@3oool50000
00D0oooo1@00000I0?ooo`D000001@3oool5000000D0oooo1@0000030?ooo`/0dLfY0P3oool50000
00D0oooo1@0000040?ooo`D000007@3oool5000000@0oooo1@0000050?ooo`D000000P3oool;0=7=
Z@@000001@3oool4000000D0oooo100000050?oooaX000001@3oool4000000D0oooo100000050?oo
o`@00000303AcJT20?ooo`@000001@3oool4000000@0oooo100000040?oooaX00000103oool40000
00@0oooo100000050?ooo`@000000P3oool<0=7=Z@@00000103oool4000000@0oooo100000040?oo
o`@00000603oool4000000@0oooo100000040?ooo`@00000103oool4000000h0dLfY000<0=7=Z@<0
oooo1@0000050?ooo`D000001@3oool5000001T0oooo1@0000050?ooo`D000001@3oool5000000<0
oooo2`3AcJT5000000D0oooo100000050?ooo`D000001@3ooolG000000D0oooo1@0000050?ooo`@0
00001@3oool5000000/0dLfY0P3oool5000000@0oooo1@0000040?ooo`@000001@3ooolF000000D0
oooo100000040?ooo`D00000103oool500000080oooo303AcJT20?ooo`@000001@3oool4000000@0
oooo100000040?oooaX00000103oool4000000@0oooo100000050?ooo`@000000P3oool<0=7=Z@@0
0000103oool4000000@0oooo100000040?ooo`@00000603oool4000000@0oooo100000040?ooo`@0
0000103oool4000000h0dLfY000<0=7=Z@<0oooo1@0000050?ooo`D000001@3oool5000001T0oooo
1@0000050?ooo`D000001@3oool5000000<0oooo2`3AcJT5000000D0oooo100000050?ooo`D00000
1@3ooolG000000D0oooo1@0000050?ooo`@000001@3oool5000000/0dLfY0P3oool5000000@0oooo
1@0000040?ooo`@000001@3ooolF000000D0oooo100000040?ooo`D00000103oool500000080oooo
303AcJT4000000@0oooo1@0000040?ooo`@00000103oool4000001H0oooo100000040?ooo`@00000
103oool5000000@0oooo1000000<0=7=Z@80oooo100000040?ooo`@00000103oool4000000@0oooo
1000000D0?ooo`@00000103oool4000000@0oooo100000040?ooo`@000000P3oool>0=7=Z@00303A
cJT5000000D0oooo1@0000050?ooo`D000001@3ooolE000000D0oooo1@0000050?ooo`D000001@3o
ool5000000/0dLfY0P3oool5000000D0oooo1@0000040?ooo`D000001@3ooolC000000D0oooo1@00
00040?ooo`D000001@3oool500000080oooo2`3AcJT4000000D0oooo100000050?ooo`@000001@3o
ool400000180oooo100000050?ooo`@000001@3oool4000000D0oooo1000000<0=7=Z@@00000103o
ool5000000@0oooo100000040?ooo`@000005P3oool4000000@0oooo100000040?ooo`D00000103o
ool4000000`0dLfY0P3oool4000000@0oooo100000040?ooo`@00000103oool4000001@0oooo1000
00040?ooo`@00000103oool4000000@0oooo100000020?ooo`h0dLfY000<0=7=Z@D000001@3oool5
000000D0oooo1@0000050?oooaD000001@3oool5000000D0oooo1@0000050?ooo`D000002`3AcJT2
0?ooo`D000001@3oool5000000@0oooo1@0000050?oooa<000001@3oool5000000@0oooo1@000005
0?ooo`D000000P3oool;0=7=Z@@000001@3oool4000000D0oooo100000050?ooo`@000004P3oool4
000000D0oooo100000050?ooo`@000001@3oool4000000`0dLfY0P3oool4000000D0oooo10000004
0?ooo`@00000103oool500000100oooo1@0000040?ooo`@00000103oool4000000D0oooo10000002
0?ooo``0dLfY100000040?ooo`@00000103oool4000000@0oooo100000040?oooa000000103oool4
000000@0oooo100000040?ooo`@00000103oool4000000h0dLfY000<0=7=Z@<0oooo1@0000050?oo
o`D000001@3oool5000000D0oooo3`0000050?ooo`D000001@3oool5000000D0oooo1@0000030?oo
o`/0dLfY1@0000050?ooo`@000001@3oool5000000D0oooo1000000?0?ooo`@000001@3oool50000
00D0oooo100000050?ooo`D000002`3AcJT4000000D0oooo100000050?ooo`@000001@3oool40000
0180oooo100000050?ooo`@000001@3oool4000000D0oooo1000000<0=7=Z@80oooo100000050?oo
o`@00000103oool4000000@0oooo1@00000@0?ooo`D00000103oool4000000@0oooo100000050?oo
o`@000000P3oool<0=7=Z@@00000103oool4000000@0oooo100000040?ooo`@00000103oool@0000
00@0oooo100000040?ooo`@00000103oool4000000@0oooo1000000>0=7=Z@00303AcJT30?ooo`D0
00001@3oool5000000D0oooo1@0000050?ooo`l000001@3oool5000000D0oooo1@0000050?ooo`D0
00000`3oool;0=7=Z@D000001@3oool4000000D0oooo1@0000050?ooo`@000003`3oool4000000D0
oooo1@0000050?ooo`@000001@3oool5000000/0dLfY0P3oool5000000@0oooo1@0000040?ooo`@0
00001@3oool4000000h0oooo100000050?ooo`@00000103oool5000000@0oooo1@0000020?ooo``0
dLfY100000040?ooo`D00000103oool4000000@0oooo100000050?ooo``000001@3oool4000000@0
oooo100000040?ooo`D00000103oool4000000`0dLfY0P3oool4000000@0oooo100000040?ooo`@0
0000103oool4000000@0oooo300000040?ooo`@00000103oool4000000@0oooo100000040?ooo`@0
00000P3oool>0=7=Z@00303AcJT30?ooo`D000001@3oool5000000D0oooo1@0000050?ooo`l00000
1@3oool5000000D0oooo1@0000050?ooo`D000000`3oool;0=7=Z@D000001@3oool4000000D0oooo
1@0000050?ooo`@000003`3oool4000000D0oooo1@0000050?ooo`@000001@3oool5000000/0dLfY
0P3oool5000000@0oooo1@0000040?ooo`@000001@3oool4000000h0oooo100000050?ooo`@00000
103oool5000000@0oooo1@0000020?ooo``0dLfY100000040?ooo`D00000103oool4000000@0oooo
100000050?ooo``000001@3oool4000000@0oooo100000040?ooo`D00000103oool4000000`0dLfY
0P3oool4000000@0oooo100000040?ooo`@00000103oool4000000@0oooo300000040?ooo`@00000
103oool4000000@0oooo100000040?ooo`@000000P3oool>0=7=Z@00303AcJT5000000D0oooo1@00
00050?ooo`D000001@3oool5000000/0oooo1@0000050?ooo`D000001@3oool5000000D0oooo1@00
000;0=7=Z@80oooo1@0000050?ooo`D00000103oool5000000D0oooo1@0000090?ooo`D000001@3o
ool5000000@0oooo1@0000050?ooo`D000000P3oool;0=7=Z@@000001@3oool4000000D0oooo1000
00050?ooo`@000001@3oool8000000D0oooo100000050?ooo`@000001@3oool4000000D0oooo1000
000<0=7=Z@80oooo100000050?ooo`@00000103oool4000000@0oooo1@0000040?ooo`P00000103o
ool5000000@0oooo100000040?ooo`@000001@3oool400000080oooo303AcJT4000000@0oooo1000
00040?ooo`@00000103oool4000000@0oooo100000080?ooo`@00000103oool4000000@0oooo1000
00040?ooo`@00000103oool4000000h0dLfY000<0=7=Z@D000001@3oool5000000D0oooo1@000005
0?ooo`D000002`3oool5000000D0oooo1@0000050?ooo`D000001@3oool5000000/0dLfY0P3oool5
000000D0oooo1@0000040?ooo`D000001@3oool5000000T0oooo1@0000050?ooo`D00000103oool5
000000D0oooo1@0000020?ooo`/0dLfY100000050?ooo`@000001@3oool4000000D0oooo10000005
0?ooo`P000001@3oool4000000D0oooo100000050?ooo`@000001@3oool4000000`0dLfY0P3oool4
000000D0oooo100000040?ooo`@00000103oool5000000@0oooo200000040?ooo`D00000103oool4
000000@0oooo100000050?ooo`@000000P3oool<0=7=Z@@00000103oool4000000@0oooo10000004
0?ooo`@00000103oool4000000P0oooo100000040?ooo`@00000103oool4000000@0oooo10000004
0?ooo`@000003P3AcJT000`0dLfY0`3oool5000000D0oooo1@0000050?ooo`D000001@3oool50000
00D0oooo1@0000050?ooo`D000001@3oool5000000D0oooo1@0000030?ooo`/0dLfY1@0000050?oo
o`@000001@3oool5000000D0oooo100000050?ooo`D000001@3oool4000000D0oooo1@0000050?oo
o`@000001@3oool5000000/0dLfY0P3oool5000000@0oooo1@0000040?ooo`@000001@3oool40000
00D0oooo100000050?ooo`@000001@3oool4000000@0oooo1@0000040?ooo`D000000P3oool<0=7=
Z@@00000103oool5000000@0oooo100000040?ooo`@000001@3oool4000000@0oooo100000050?oo
o`@00000103oool4000000@0oooo1@0000040?ooo`@00000303AcJT20?ooo`@00000103oool40000
00@0oooo100000040?ooo`@00000103oool4000000@0oooo100000040?ooo`@00000103oool40000
00@0oooo100000040?ooo`@000000P3oool>0=7=Z@00303AcJT30?ooo`D000001@3oool5000000D0
oooo1@0000050?ooo`D000001@3oool5000000D0oooo1@0000050?ooo`D000001@3oool5000000<0
oooo2`3AcJT5000000D0oooo100000050?ooo`D000001@3oool4000000D0oooo1@0000050?ooo`@0
00001@3oool5000000D0oooo100000050?ooo`D000002`3AcJT20?ooo`D00000103oool5000000@0
oooo100000050?ooo`@000001@3oool4000000D0oooo100000050?ooo`@00000103oool5000000@0
oooo1@0000020?ooo``0dLfY100000040?ooo`D00000103oool4000000@0oooo100000050?ooo`@0
0000103oool4000000D0oooo100000040?ooo`@00000103oool5000000@0oooo1000000<0=7=Z@80
oooo100000040?ooo`@00000103oool4000000@0oooo100000040?ooo`@00000103oool4000000@0
oooo100000040?ooo`@00000103oool4000000@0oooo100000020?ooo`h0dLfY000<0=7=Z@<0oooo
1@0000050?ooo`D000001@3oool5000000D0oooo1@0000050?ooo`D000001@3oool5000000D0oooo
1@0000050?ooo`D000000`3oool;0=7=Z@80oooo1@0000050?ooo`D00000103oool5000000D0oooo
1@0000090?ooo`D000001@3oool5000000@0oooo1@0000050?ooo`D000000P3oool;0=7=Z@@00000
1@3oool4000000D0oooo100000050?ooo`@000001@3oool8000000D0oooo100000050?ooo`@00000
1@3oool4000000D0oooo1000000<0=7=Z@80oooo100000050?ooo`@00000103oool4000000@0oooo
1@0000040?ooo`P00000103oool5000000@0oooo100000040?ooo`@000001@3oool400000080oooo
303AcJT4000000@0oooo100000040?ooo`@00000103oool4000000@0oooo100000080?ooo`@00000
103oool4000000@0oooo100000040?ooo`@00000103oool4000000h0dLfY000<0=7=Z@D000001@3o
ool5000000D0oooo1@0000050?ooo`D000002`3oool5000000D0oooo1@0000050?ooo`D000001@3o
ool5000000/0dLfY0P3oool5000000D0oooo1@0000040?ooo`D000001@3oool5000000T0oooo1@00
00050?ooo`D00000103oool5000000D0oooo1@0000020?ooo`/0dLfY100000050?ooo`@000001@3o
ool4000000D0oooo100000050?ooo`P000001@3oool4000000D0oooo100000050?ooo`@000001@3o
ool4000000`0dLfY0P3oool4000000D0oooo100000040?ooo`@00000103oool5000000@0oooo2000
00040?ooo`D00000103oool4000000@0oooo100000050?ooo`@000000P3oool<0=7=Z@@00000103o
ool4000000@0oooo100000040?ooo`@00000103oool4000000P0oooo100000040?ooo`@00000103o
ool4000000@0oooo100000040?ooo`@000003P3AcJT000`0dLfY1@0000050?ooo`D000001@3oool5
000000D0oooo1@00000;0?ooo`D000001@3oool5000000D0oooo1@0000050?ooo`D000002`3AcJT2
0?ooo`D000001@3oool5000000@0oooo1@0000050?ooo`D000002@3oool5000000D0oooo1@000004
0?ooo`D000001@3oool500000080oooo2`3AcJT20?ooo`D00000103oool5000000@0oooo10000005
0?ooo`@000003P3oool4000000D0oooo100000040?ooo`D00000103oool500000080oooo303AcJT4
000000@0oooo1@0000040?ooo`@00000103oool4000000D0oooo300000050?ooo`@00000103oool4
000000@0oooo1@0000040?ooo`@00000303AcJT20?ooo`@00000103oool4000000@0oooo10000004
0?ooo`@00000103oool<000000@0oooo100000040?ooo`@00000103oool4000000@0oooo10000002
0?ooo`h0dLfY000<0=7=Z@<0oooo1@0000050?ooo`D000001@3oool5000000D0oooo3`0000050?oo
o`D000001@3oool5000000D0oooo1@0000030?ooo`/0dLfY1@0000050?ooo`@000001@3oool50000
00D0oooo1000000?0?ooo`@000001@3oool5000000D0oooo100000050?ooo`D000002`3AcJT20?oo
o`D00000103oool5000000@0oooo100000050?ooo`@000003P3oool4000000D0oooo100000040?oo
o`D00000103oool500000080oooo303AcJT4000000@0oooo1@0000040?ooo`@00000103oool40000
00D0oooo300000050?ooo`@00000103oool4000000@0oooo1@0000040?ooo`@00000303AcJT20?oo
o`@00000103oool4000000@0oooo100000040?ooo`@00000103oool<000000@0oooo100000040?oo
o`@00000103oool4000000@0oooo100000020?ooo`h0dLfY000<0=7=Z@<0oooo1@0000050?ooo`D0
00001@3oool5000000D0oooo3`0000050?ooo`D000001@3oool5000000D0oooo1@0000030?ooo`/0
dLfY1@0000050?ooo`@000001@3oool5000000D0oooo1000000?0?ooo`@000001@3oool5000000D0
oooo100000050?ooo`D000002`3AcJT20?ooo`D00000103oool5000000@0oooo100000050?ooo`@0
00003P3oool4000000D0oooo100000040?ooo`D00000103oool500000080oooo303AcJT20?ooo`@0
00001@3oool4000000@0oooo100000040?ooo`D00000403oool5000000@0oooo100000040?ooo`@0
00001@3oool400000080oooo303AcJT4000000@0oooo100000040?ooo`@00000103oool4000000@0
oooo400000040?ooo`@00000103oool4000000@0oooo100000040?ooo`@000003P3AcJT000`0dLfY
0`3oool5000000D0oooo1@0000050?ooo`D000001@3oool?000000D0oooo1@0000050?ooo`D00000
1@3oool5000000<0oooo2`3AcJT20?ooo`D000001@3oool5000000@0oooo1@0000050?oooa<00000
1@3oool5000000@0oooo1@0000050?ooo`D000000P3oool;0=7=Z@@000001@3oool4000000D0oooo
100000050?ooo`@000004P3oool4000000D0oooo100000050?ooo`@000001@3oool4000000`0dLfY
0P3oool4000000D0oooo100000040?ooo`@00000103oool500000100oooo1@0000040?ooo`@00000
103oool4000000D0oooo100000020?ooo``0dLfY100000040?ooo`@00000103oool4000000@0oooo
100000040?oooa000000103oool4000000@0oooo100000040?ooo`@00000103oool4000000h0dLfY
000<0=7=Z@D000001@3oool5000000D0oooo1@0000050?oooaD000001@3oool5000000D0oooo1@00
00050?ooo`D000002`3AcJT20?ooo`D000001@3oool5000000@0oooo1@0000050?oooa<000001@3o
ool5000000@0oooo1@0000050?ooo`D000000P3oool;0=7=Z@@000001@3oool4000000D0oooo1000
00050?ooo`@000004P3oool4000000D0oooo100000050?ooo`@000001@3oool4000000`0dLfY1000
00040?ooo`D00000103oool4000000@0oooo1000000F0?ooo`@00000103oool4000000@0oooo1@00
00040?ooo`@00000303AcJT20?ooo`@00000103oool4000000@0oooo100000040?ooo`@00000503o
ool4000000@0oooo100000040?ooo`@00000103oool400000080oooo3P3AcJT000`0dLfY1@000005
0?ooo`D000001@3oool5000000D0oooo5@0000050?ooo`D000001@3oool5000000D0oooo1@00000;
0=7=Z@D000001@3oool4000000D0oooo1@0000050?oooaL000001@3oool5000000D0oooo10000005
0?ooo`D000002`3AcJT20?ooo`D00000103oool5000000@0oooo100000050?oooaH000001@3oool4
000000@0oooo1@0000040?ooo`D000000P3oool<0=7=Z@@00000103oool5000000@0oooo10000004
0?ooo`@000005P3oool4000000@0oooo100000040?ooo`D00000103oool4000000`0dLfY0P3oool4
000000@0oooo100000040?ooo`@00000103oool4000001@0oooo100000040?ooo`@00000103oool4
000000@0oooo100000020?ooo`h0dLfY000<0=7=Z@<0oooo1@0000050?ooo`D000001@3oool50000
01T0oooo1@0000050?ooo`D000001@3oool5000000<0oooo2`3AcJT5000000D0oooo100000050?oo
o`D000001@3ooolG000000D0oooo1@0000050?ooo`@000001@3oool5000000/0dLfY0P3oool50000
00@0oooo1@0000040?ooo`@000001@3ooolF000000D0oooo100000040?ooo`D00000103oool50000
0080oooo303AcJT4000000@0oooo1@0000040?ooo`@00000103oool4000001H0oooo100000040?oo
o`@00000103oool5000000@0oooo1000000<0=7=Z@@00000103oool4000000@0oooo100000040?oo
o`@00000603oool4000000@0oooo100000040?ooo`@00000103oool4000000h0dLfY000<0=7=Z@<0
oooo1@0000050?ooo`D000001@3oool5000001T0oooo1@0000050?ooo`D000001@3oool5000000<0
oooo2`3AcJT5000000D0oooo100000050?ooo`D000001@3ooolG000000D0oooo1@0000050?ooo`@0
00001@3oool5000000/0dLfY100000050?ooo`@000001@3oool4000000D0oooo6P0000050?ooo`@0
00001@3oool4000000D0oooo1000000<0=7=Z@80oooo100000050?ooo`@00000103oool4000000@0
oooo6P0000040?ooo`@00000103oool4000000D0oooo100000020?ooo``0dLfY100000040?ooo`@0
0000103oool4000000@0oooo1000000H0?ooo`@00000103oool4000000@0oooo100000040?ooo`@0
00003P3AcJT000`0dLfY0`3oool5000000D0oooo1@0000050?ooo`D000006@3oool5000000D0oooo
1@0000050?ooo`D000000`3oool;0=7=Z@80oooo1@0000050?ooo`D00000103oool5000001d0oooo
1@0000040?ooo`D000001@3oool500000080oooo2`3AcJT4000000D0oooo100000050?ooo`@00000
1@3ooolJ000000D0oooo100000050?ooo`@000001@3oool4000000`0dLfY0P3oool4000000D0oooo
100000040?ooo`@00000103ooolJ000000@0oooo100000040?ooo`@000001@3oool400000080oooo
303AcJT20?ooo`@00000103oool4000000@0oooo100000040?oooa`00000103oool4000000@0oooo
100000040?ooo`@000000P3oool>0=7=Z@00303AcJT5000000D0oooo1@0000050?ooo`D000007`3o
ool5000000D0oooo1@0000050?ooo`D000002`3AcJT20?ooo`D000001@3oool5000000@0oooo1@00
000M0?ooo`D00000103oool5000000D0oooo1@0000020?ooo`/0dLfY0P3oool5000000@0oooo1@00
00040?ooo`@00000803oool4000000@0oooo1@0000040?ooo`D000000P3oool<0=7=Z@@00000103o
ool5000000@0oooo100000040?oooah00000103oool4000000@0oooo1@0000040?ooo`@00000303A
cJT20?ooo`@00000103oool4000000@0oooo100000040?oooa`00000103oool4000000@0oooo1000
00040?ooo`@000000P3oool>0=7=Z@00303AcJT5000000D0oooo1@0000050?ooo`D000007`3oool5
000000D0oooo1@0000050?ooo`D000002`3AcJT5000000D0oooo100000050?ooo`D000008@3oool5
000000D0oooo100000050?ooo`D000002`3AcJT20?ooo`D00000103oool5000000@0oooo1000000P
0?ooo`@00000103oool5000000@0oooo1@0000020?ooo``0dLfY100000040?ooo`D00000103oool4
000000@0oooo7P0000040?ooo`@00000103oool5000000@0oooo1000000<0=7=Z@@00000103oool4
000000@0oooo100000040?ooob000000103oool4000000@0oooo100000040?ooo`@000003P3AcJT0
00`0dLfY0`3oool5000000D0oooo1@0000050?ooob<000001@3oool5000000D0oooo1@0000030?oo
o`/0dLfY1@0000050?ooo`@000001@3oool500000240oooo1@0000050?ooo`@000001@3oool50000
00/0dLfY0P3oool5000000@0oooo1@0000040?ooo`@00000803oool4000000@0oooo1@0000040?oo
o`D000000P3oool<0=7=Z@80oooo100000050?ooo`@00000103oool400000280oooo100000040?oo
o`@000001@3oool400000080oooo303AcJT4000000@0oooo100000040?ooo`@00000103ooolP0000
00@0oooo100000040?ooo`@00000103oool4000000h0dLfY000<0=7=Z@<0oooo1@0000050?ooo`D0
00001@3ooolS000000D0oooo1@0000050?ooo`D000000`3oool;0=7=Z@80oooo1@0000050?ooo`D0
0000103ooolW000000@0oooo1@0000050?ooo`D000000P3oool;0=7=Z@@000001@3oool4000000D0
oooo1000000T0?ooo`@000001@3oool4000000D0oooo1000000<0=7=Z@80oooo100000050?ooo`@0
0000103oool400000280oooo100000040?ooo`@000001@3oool400000080oooo303AcJT20?ooo`@0
0000103oool4000000@0oooo1000000T0?ooo`@00000103oool4000000@0oooo100000020?ooo`h0
dLfY000<0=7=Z@<0oooo1@0000050?ooo`D000001@3ooolS000000D0oooo1@0000050?ooo`D00000
0`3oool;0=7=Z@80oooo1@0000050?ooo`D00000103ooolW000000@0oooo1@0000050?ooo`D00000
0P3oool;0=7=Z@@000001@3oool4000000D0oooo1000000T0?ooo`@000001@3oool4000000D0oooo
1000000<0=7=Z@@00000103oool5000000@0oooo1000000V0?ooo`@00000103oool5000000@0oooo
1000000<0=7=Z@80oooo100000040?ooo`@00000103oool4000002@0oooo100000040?ooo`@00000
103oool400000080oooo3P3AcJT000`0dLfY1@0000050?ooo`D000001@3ooolY000000D0oooo1@00
00050?ooo`D000002`3AcJT20?ooo`D000001@3oool5000000@0oooo9`0000040?ooo`D000001@3o
ool500000080oooo2`3AcJT20?ooo`D00000103oool5000000@0oooo:00000040?ooo`D00000103o
ool500000080oooo303AcJT4000000@0oooo1@0000040?ooo`@000009P3oool4000000@0oooo1@00
00040?ooo`@00000303AcJT4000000@0oooo100000040?ooo`@00000:03oool4000000@0oooo1000
00040?ooo`@000003P3AcJT000`0dLfY1@0000050?ooo`D000001@3ooolY000000D0oooo1@000005
0?ooo`D000002`3AcJT5000000D0oooo100000050?ooob/000001@3oool4000000D0oooo1@00000;
0=7=Z@80oooo1@0000040?ooo`D00000103ooolX000000@0oooo1@0000040?ooo`D000000P3oool<
0=7=Z@80oooo100000050?ooo`@00000103ooolZ000000@0oooo100000050?ooo`@000000P3oool<
0=7=Z@@00000103oool4000000@0oooo1000000X0?ooo`@00000103oool4000000@0oooo1000000>
0=7=Z@00303AcJT30?ooo`D000001@3oool5000002d0oooo1@0000050?ooo`D000000`3oool;0=7=
Z@D000001@3oool4000000D0oooo:`0000050?ooo`@000001@3oool5000000/0dLfY100000050?oo
o`@000001@3oool/000000D0oooo100000050?ooo`@00000303AcJT20?ooo`@000001@3oool40000
00@0oooo:P0000040?ooo`@000001@3oool400000080oooo303AcJT20?ooo`@00000103oool40000
00@0oooo;00000040?ooo`@00000103oool400000080oooo3P3AcJT000`0dLfY0`3oool5000000D0
oooo1@00000]0?ooo`D000001@3oool5000000<0oooo2`3AcJT20?ooo`D000001@3oool5000002l0
oooo1@0000050?ooo`D000000P3oool;0=7=Z@@000001@3oool4000000D0oooo;00000050?ooo`@0
00001@3oool4000000`0dLfY100000040?ooo`D00000103oool^000000@0oooo1@0000040?ooo`@0
0000303AcJT20?ooo`@00000103oool4000000@0oooo;00000040?ooo`@00000103oool400000080
oooo3P3AcJT000`0dLfY0`3oool5000000D0oooo1@00000]0?ooo`D000001@3oool5000000<0oooo
2`3AcJT20?ooo`D000001@3oool5000002l0oooo1@0000050?ooo`D000000P3oool;0=7=Z@80oooo
1@0000040?ooo`D00000<03oool5000000@0oooo1@0000020?ooo``0dLfY100000040?ooo`D00000
103oool^000000@0oooo1@0000040?ooo`@00000303AcJT4000000@0oooo100000040?oooc000000
103oool4000000@0oooo1000000>0=7=Z@00303AcJT5000000D0oooo1@00000c0?ooo`D000001@3o
ool5000000/0dLfY0P3oool5000000D0oooo1@00000_0?ooo`D000001@3oool500000080oooo2`3A
cJT20?ooo`D00000103oool500000300oooo1@0000040?ooo`D000000P3oool<0=7=Z@80oooo1000
00050?ooo`@00000<P3oool4000000D0oooo100000020?ooo``0dLfY100000040?ooo`@00000103o
ool`000000@0oooo100000040?ooo`@000003P3AcJT000`0dLfY1@0000050?ooo`D00000<`3oool5
000000D0oooo1@00000;0=7=Z@D000001@3oool4000003D0oooo100000050?ooo`D000002`3AcJT4
000000D0oooo1000000f0?ooo`@000001@3oool4000000`0dLfY0P3oool4000000D0oooo1000000b
0?ooo`@000001@3oool400000080oooo303AcJT20?ooo`@00000103oool4000003@0oooo10000004
0?ooo`@000000P3oool>0=7=Z@00303AcJT30?ooo`D000001@3ooolg000000D0oooo1@0000030?oo
o`/0dLfY1@0000050?ooo`@00000=@3oool4000000D0oooo1@00000;0=7=Z@@000001@3oool40000
03H0oooo100000050?ooo`@00000303AcJT4000000@0oooo1@00000f0?ooo`D00000103oool40000
00`0dLfY0P3oool4000000@0oooo1000000d0?ooo`@00000103oool400000080oooo3P3AcJT000`0
dLfY0`3oool5000000D0oooo=`0000050?ooo`D000000`3oool;0=7=Z@80oooo1@0000050?ooocT0
00001@3oool500000080oooo2`3AcJT4000000D0oooo1000000f0?ooo`@000001@3oool4000000`0
dLfY100000040?ooo`D00000=P3oool5000000@0oooo1000000<0=7=Z@@00000103oool4000003P0
oooo100000040?ooo`@000003P3AcJT000`0dLfY0`3oool5000000D0oooo=`0000050?ooo`D00000
0`3oool;0=7=Z@80oooo1@0000050?ooocT000001@3oool500000080oooo2`3AcJT20?ooo`D00000
103ooolj000000@0oooo1@0000020?ooo``0dLfY0P3oool4000000D0oooo>P0000050?ooo`@00000
0P3oool<0=7=Z@@00000103oool4000003P0oooo100000040?ooo`@000003P3AcJT000`0dLfY1@00
00050?ooocd000001@3oool5000000/0dLfY1@0000050?ooocd000001@3oool5000000/0dLfY0P3o
ool5000000@0oooo>P0000040?ooo`D000000P3oool<0=7=Z@80oooo100000050?ooocX000001@3o
ool400000080oooo303AcJT20?ooo`@00000103oooll000000@0oooo100000020?ooo`h0dLfY000<
0=7=Z@D000001@3ooolm000000D0oooo1@00000;0=7=Z@D000001@3ooolm000000D0oooo1@00000;
0=7=Z@@000001@3oooln000000D0oooo1000000<0=7=Z@@00000103ooom0000000@0oooo1000000<
0=7=Z@80oooo100000040?oooc`00000103oool400000080oooo3P3AcJT000`0dLfY0`3oool50000
0440oooo1@0000030?ooo`/0dLfY1@0000050?ooocd000001@3oool5000000/0dLfY100000050?oo
och000001@3oool4000000`0dLfY100000040?oood000000103oool4000000`0dLfY100000040?oo
od000000103oool4000000h0dLfY000<0=7=Z@<0oooo1@0000110?ooo`D000000`3oool;0=7=Z@80
oooo1@0000130?ooo`D000000P3oool;0=7=Z@80oooo1@0000120?ooo`D000000P3oool<0=7=Z@@0
0000103ooom0000000@0oooo1000000<0=7=Z@@00000103ooom0000000@0oooo1000000>0=7=Z@00
303AcJT30?ooo`D00000@@3oool5000000<0oooo2`3AcJT20?ooo`D00000@`3oool500000080oooo
2`3AcJT20?ooo`D00000@P3oool500000080oooo303AcJT20?ooo`@00000A03oool400000080oooo
303AcJT20?ooo`@00000A03oool400000080oooo3P3AcJT000`0dLfY1@0000170?ooo`D000002`3A
cJT5000004L0oooo1@00000;0=7=Z@@00000B03oool4000000`0dLfY0P3oool4000004@0oooo1000
00020?ooo``0dLfY0P3oool4000004@0oooo100000020?ooo`h0dLfY000<0=7=Z@D00000A`3oool5
000000/0dLfY1@0000170?ooo`D000002`3AcJT4000004P0oooo1000000<0=7=Z@@00000B03oool4
000000`0dLfY100000180?ooo`@000003P3AcJT000`0dLfY0`3ooom;000000<0oooo2`3AcJT20?oo
odd000000P3oool;0=7=Z@@00000B03oool4000000`0dLfY100000180?ooo`@00000303AcJT40000
04P0oooo1000000>0=7=Z@00303AcJT30?oood/000000`3oool;0=7=Z@80ooooC@0000020?ooo`/0
dLfY0P3ooom<00000080oooo303AcJT20?oood`000000P3oool<0=7=Z@80ooooC00000020?ooo`h0
dLfY000<0=7=Z@<0ooooB`0000030?ooo`/0dLfY0P3ooom=00000080oooo2`3AcJT20?oood`00000
0P3oool<0=7=Z@80ooooC00000020?ooo``0dLfY0P3ooom<00000080oooo3P3AcJT000`0dLfYD@00
000;0=7=ZE4000002`3AcJU@000000`0dLfYD000000<0=7=ZE0000003P3AcJT000`0dLfYD@00000;
0=7=ZE4000002`3AcJU@000000`0dLfYD000000<0=7=ZE0000003P3AcJT00?l0dLfYf`3AcJT00?l0
dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0
dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0
dLfYf`3AcJT000`0dLfYD_ooool:0=7=ZE;ooooo2P3AcJUAooooo`/0dLfYD03oool<0=7=ZE00oooo
3P3AcJT000`0dLfYD_ooool:0=7=ZE;ooooo2P3AcJUAooooo`/0dLfYD03oool<0=7=ZE00oooo3P3A
cJT000`0dLfYD_ooool:0=7=ZE;ooooo2P3AcJUAooooo`/0dLfYD03oool<0=7=ZE00oooo3P3AcJT0
00`0dLfYDP00000:0=7=ZE8000002P3AcJUA000000/0dLfYD000000<0=7=ZE0000003P3AcJT000`0
dLfYDP00000:0=7=ZE8000002P3AcJUA000000/0dLfYD000000<0=7=ZE0000003P3AcJT000`0dLfY
DP00000:0=7=ZE8000002P3AcJUA000000/0dLfYD000000<0=7=Z@<0ooooBP0000030?ooo`h0dLfY
000<0=7=ZE8000002P3AcJT4ooooodX000001?ooool:0=7=Z@?oooooB`000003ooooo`/0dLfY0`3o
oom:000000<0oooo303AcJT30?ooodX000000`3oool>0=7=Z@00303AcJT4ooooodX000001?ooool:
0=7=Z@CoooooBP000004ooooo`X0dLfY0ooooom;000000?ooooo2`3AcJT30?ooodX000000`3oool<
0=7=Z@<0ooooBP0000030?ooo`h0dLfY000<0=7=Z@CoooooBP000004ooooo`X0dLfY1?oooom:0000
00Cooooo2P3AcJT3oooood/000000oooool;0=7=Z@<0ooooBP0000030?ooo``0dLfY1@0000160?oo
o`D000003P3AcJT000`0dLfY1?oooom:000000Cooooo2P3AcJT4ooooodX000001?ooool:0=7=Z@H0
0000AOooool6000000/0dLfY1P0000140?ooo`H00000303AcJT5000004H0oooo1@00000>0=7=Z@00
303AcJT8000004;ooooo2000000:0=7=Z@L00000A?ooool7000000X0dLfY1P000015ooooo`H00000
2`3AcJT6000004@0oooo1P00000<0=7=Z@D00000AP3oool5000000h0dLfY000<0=7=Z@P00000@_oo
ool8000000X0dLfY1`000014ooooo`L000002P3AcJT6000004Gooooo1P00000;0=7=Z@<0oooo1P00
000n0?ooo`H000000`3oool<0=7=Z@<0oooo1@0000100?ooo`D000000`3oool>0=7=Z@00303AcJT8
000004;ooooo2000000:0=7=Z@L00000A?ooool7000000X0dLfY0oooool6000003oooooo1P000003
ooooo`/0dLfY0`3oool6000003h0oooo1P0000030?ooo``0dLfY0`3oool500000400oooo1@000003
0?ooo`h0dLfY000<0=7=Z@P00000@_ooool8000000X0dLfY1?ooool6000003gooooo1`000004oooo
o`X0dLfY0oooool6000003oooooo1P000003ooooo`/0dLfY0`3oool6000003h0oooo1P0000030?oo
o``0dLfY1@0000060?ooocX000001P3oool5000000h0dLfY000<0=7=Z@Cooooo1`00000looooo`L0
00001?ooool:0=7=Z@Cooooo1P00000mooooo`L000001?ooool:0=7=Z@?ooooo1P00000oooooo`H0
00000oooool;0=7=Z@H000001@3ooolj000000D0oooo1P00000<0=7=Z@D000001P3ooolj000000H0
oooo1@00000>0=7=Z@00303AcJT4ooooo`L00000??ooool7000000Cooooo2P3AcJT4ooooo`H00000
?Oooool7000000Cooooo2P3AcJT6000000Oooooo>0000006ooooo`H000002`3AcJT6000000D0oooo
>P0000050?ooo`H00000303AcJT5000000H0oooo>P0000060?ooo`D000003P3AcJT000`0dLfY1?oo
ool7000003cooooo1`000004ooooo`X0dLfY1`000007ooooocH000001oooool7000000X0dLfY1P00
0007ooooocP000001_ooool6000000/0dLfY1P0000050?ooocX000001@3oool6000000`0dLfY0`3o
ool5000000D0oooo=P0000050?ooo`D000000`3oool>0=7=Z@00303AcJT4ooooo`L00000??ooool7
000000Cooooo2P3AcJT7000000Oooooo=P000007ooooo`L000002P3AcJT6000000Oooooo>0000006
ooooo`H000002`3AcJT30?ooo`H000001@3ooold000000D0oooo1P0000030?ooo``0dLfY0`3oool5
000000D0oooo=P0000050?ooo`D000000`3oool>0=7=Z@00303AcJT8000000Oooooo=0000007oooo
o`P000002P3AcJT7000000Oooooo=P000007ooooo`L000002P3AcJT3ooooo`H000001ooooolb0000
00Kooooo1P000003ooooo`/0dLfY0`3oool6000000D0oooo=00000050?ooo`H000000`3oool<0=7=
Z@<0oooo1@0000050?ooocH000001@3oool5000000<0oooo3P3AcJT000`0dLfY20000007oooooc@0
00001oooool8000000X0dLfY1?ooool6000000Oooooo<0000006ooooo`L000001?ooool:0=7=Z@?o
oooo1P000007oooooc8000001_ooool6000000?ooooo2`3AcJT30?ooo`H000001@3ooold000000D0
oooo1P0000030?ooo``0dLfY1@0000060?ooo`D00000<03oool5000000H0oooo1@00000>0=7=Z@00
303AcJT8000000Oooooo=0000007ooooo`P000002P3AcJT4ooooo`H000001oooool`000000Kooooo
1`000004ooooo`X0dLfY0oooool6000000Oooooo<P000006ooooo`H000000oooool;0=7=Z@H00000
1@3oool6000002h0oooo1P0000050?ooo`H00000303AcJT5000000H0oooo1@00000`0?ooo`D00000
1P3oool5000000h0dLfY000<0=7=Z@Cooooo1`000008ooooob`000002?ooool7000000Cooooo2P3A
cJT4ooooo`H000001oooool`000000Kooooo1`000004ooooo`X0dLfY1P000007ooooo`H00000;?oo
ool6000000Kooooo1P00000;0=7=Z@H000001@3oool6000002h0oooo1P0000050?ooo`H00000303A
cJT30?ooo`D000001@3oool6000002X0oooo1P0000050?ooo`D000000`3oool>0=7=Z@00303AcJT4
ooooo`L000002?ooool/000000Sooooo1`000004ooooo`X0dLfY1?ooool6000000Oooooo<0000006
ooooo`L000001?ooool:0=7=Z@H000001oooool6000002cooooo1P000006ooooo`H000002`3AcJT6
000000D0oooo1P00000^0?ooo`H000001@3oool6000000`0dLfY0`3oool5000000D0oooo1P00000Z
0?ooo`H000001@3oool5000000<0oooo3P3AcJT000`0dLfY1?ooool7000000Sooooo;0000008oooo
o`L000001?ooool:0=7=Z@L000001oooool7000002Sooooo1`000007ooooo`L000002P3AcJT60000
00Oooooo1P00000/ooooo`H000001_ooool6000000/0dLfY0`3oool6000000D0oooo1P00000X0?oo
o`H000001@3oool6000000<0oooo303AcJT30?ooo`D000001@3oool6000002X0oooo1P0000050?oo
o`D000000`3oool>0=7=Z@00303AcJT4ooooo`L000002?ooool/000000Sooooo1`000004ooooo`X0
dLfY1`000007ooooo`L00000:?ooool7000000Oooooo1`00000:0=7=Z@?ooooo1P000007ooooo`H0
00009Oooool7000000Kooooo1P000003ooooo`/0dLfY0`3oool6000000D0oooo1P00000X0?ooo`H0
00001@3oool6000000<0oooo303AcJT5000000H0oooo1@0000050?ooobH000001@3oool5000000H0
oooo1@00000>0=7=Z@00303AcJT8000000Oooooo1`00000Uooooo`P000001oooool8000000X0dLfY
1`000007ooooo`L00000:?ooool7000000Oooooo1`00000:0=7=Z@?ooooo1P000007ooooo`H00000
9Oooool7000000Kooooo1P000003ooooo`/0dLfY0`3oool6000000D0oooo1P00000X0?ooo`H00000
1@3oool6000000<0oooo303AcJT5000000H0oooo1@0000050?ooobH000001@3oool5000000H0oooo
1@00000>0=7=Z@00303AcJT8000000Oooooo1`00000Uooooo`P000001oooool8000000X0dLfY1?oo
ool6000000Oooooo1`00000Rooooo`L000001_ooool7000000Cooooo2P3AcJT3ooooo`H000001ooo
ool6000002Gooooo1`000006ooooo`H000000oooool;0=7=Z@H000001@3oool6000000H0oooo8P00
00060?ooo`H000001@3oool6000000`0dLfY1@0000060?ooo`D000001@3ooolV000000D0oooo1@00
00060?ooo`D000003P3AcJT000`0dLfY20000007ooooo`L000009Oooool8000000Oooooo2000000:
0=7=Z@Cooooo1P000007ooooo`L000008_ooool7000000Kooooo1`000004ooooo`X0dLfY1P000007
ooooo`H000001_oooolO000000Oooooo1P000006ooooo`H000002`3AcJT6000000D0oooo1P000006
0?ooob8000001P3oool6000000D0oooo1P00000<0=7=Z@<0oooo1@0000050?ooo`H000001@3ooolP
000000D0oooo1P0000050?ooo`D000000`3oool>0=7=Z@00303AcJT8000000Oooooo1`00000Uoooo
o`P000001oooool8000000X0dLfY1?ooool6000000Oooooo1`00000Rooooo`L000001_ooool70000
00Cooooo2P3AcJT6000000Oooooo1P000006oooooal000001oooool6000000Kooooo1P00000;0=7=
Z@H000001@3oool6000000H0oooo8P0000060?ooo`H000001@3oool6000000`0dLfY0`3oool50000
00D0oooo1P0000050?ooob0000001@3oool6000000D0oooo1@0000030?ooo`h0dLfY000<0=7=Z@Co
oooo1`000008ooooo`L000007_ooool7000000Sooooo1`000004ooooo`X0dLfY1`000007ooooo`L0
00001_oooolK000000Oooooo1`000007ooooo`L000002P3AcJT6000000Oooooo1P000006oooooal0
00001oooool6000000Kooooo1P00000;0=7=Z@<0oooo1P0000050?ooo`H000001P3ooolL000000H0
oooo1P0000050?ooo`H000000`3oool<0=7=Z@D000001P3oool5000000D0oooo1P00000J0?ooo`H0
00001@3oool5000000H0oooo1@00000>0=7=Z@00303AcJT4ooooo`L000002?ooool7000001kooooo
1`000008ooooo`L000001?ooool:0=7=Z@L000001oooool7000000Kooooo6`000007ooooo`L00000
1oooool7000000X0dLfY0oooool6000000Oooooo1P000006oooooaT000001_ooool7000000Kooooo
1P000003ooooo`/0dLfY0`3oool6000000D0oooo1P0000060?oooa`000001P3oool6000000D0oooo
1P0000030?ooo``0dLfY1@0000060?ooo`D000001@3oool6000001X0oooo1P0000050?ooo`D00000
1P3oool5000000h0dLfY000<0=7=Z@Cooooo1`000008ooooo`L000007_ooool7000000Sooooo1`00
0004ooooo`X0dLfY1`000007ooooo`L000001_oooolK000000Oooooo1`000007ooooo`L000002P3A
cJT3ooooo`H000001oooool6000000Kooooo6@000006ooooo`L000001_ooool6000000?ooooo2`3A
cJT6000000D0oooo1P0000060?ooo`H000005P3oool6000000H0oooo1P0000050?ooo`H00000303A
cJT5000000H0oooo1@0000050?ooo`H000006P3oool6000000D0oooo1@0000060?ooo`D000003P3A
cJT000`0dLfY20000007ooooo`L000002?oooolF000000Oooooo20000007ooooo`P000002P3AcJT7
000000Oooooo1`000006oooooa/000001oooool7000000Oooooo1`00000:0=7=Z@?ooooo1P000007
ooooo`H000001_oooolI000000Kooooo1`000006ooooo`H000000oooool;0=7=Z@H000001@3oool6
000000H0oooo1P00000F0?ooo`H000001P3oool6000000D0oooo1P00000<0=7=Z@<0oooo1@000005
0?ooo`H000001@3oool5000001H0oooo1@0000050?ooo`H000001@3oool5000000<0oooo3P3AcJT0
00`0dLfY20000007ooooo`L000002?oooolF000000Oooooo20000007ooooo`P000002P3AcJT4oooo
o`H000001oooool7000000Oooooo50000007ooooo`L000001_ooool7000000Cooooo2P3AcJT60000
00Oooooo1P000006ooooo`H000004oooool6000000Oooooo1P000006ooooo`H000002`3AcJT60000
00D0oooo1P0000060?ooo`H000005P3oool6000000H0oooo1P0000050?ooo`H00000303AcJT30?oo
o`D000001@3oool6000000D0oooo1@00000F0?ooo`D000001@3oool6000000D0oooo1@0000030?oo
o`h0dLfY000<0=7=Z@P000001oooool7000000Sooooo5P000007ooooo`P000001oooool8000000X0
dLfY1?ooool6000000Oooooo1`000007oooooa@000001oooool7000000Kooooo1`000004ooooo`X0
dLfY1P000007ooooo`H000001_ooool6000001?ooooo1P000007ooooo`H000001_ooool6000000/0
dLfY0`3oool6000000D0oooo1P0000060?ooo`D000004P3oool5000000H0oooo1P0000050?ooo`H0
00000`3oool<0=7=Z@<0oooo1@0000050?ooo`H000001@3oool5000001H0oooo1@0000050?ooo`H0
00001@3oool5000000<0oooo3P3AcJT000`0dLfY20000007ooooo`L000002?oooolF000000Oooooo
20000007ooooo`P000002P3AcJT4ooooo`H000001oooool7000000Oooooo50000007ooooo`L00000
1_ooool7000000Cooooo2P3AcJT6000000Oooooo1P000006ooooo`H000004oooool6000000Oooooo
1P000006ooooo`H000002`3AcJT30?ooo`H000001@3oool6000000H0oooo1@00000B0?ooo`D00000
1P3oool6000000D0oooo1P0000030?ooo``0dLfY1@0000060?ooo`D000001@3oool6000000D0oooo
400000050?ooo`H000001@3oool5000000H0oooo1@00000>0=7=Z@00303AcJT4ooooo`L000002?oo
ool7000000Sooooo3P000008ooooo`L000002?ooool7000000Cooooo2P3AcJT7000000Oooooo1`00
0006ooooo`L000003_ooool6000000Oooooo1`000007ooooo`L000002P3AcJT3ooooo`H000001ooo
ool6000000Kooooo1P00000=ooooo`H000001_ooool7000000Kooooo1P000003ooooo`/0dLfY0`3o
ool6000000D0oooo1P0000060?ooo`D000004P3oool5000000H0oooo1P0000050?ooo`H000000`3o
ool<0=7=Z@D000001P3oool5000000D0oooo1P0000050?oooa0000001@3oool6000000D0oooo1@00
00060?ooo`D000003P3AcJT000`0dLfY1?ooool7000000Sooooo1`000008ooooo`h000002?ooool7
000000Sooooo1`000004ooooo`X0dLfY1`000007ooooo`L000001_ooool7000000kooooo1P000007
ooooo`L000001oooool7000000X0dLfY0oooool6000000Oooooo1P000006ooooo`H000003Oooool6
000000Kooooo1`000006ooooo`H000000oooool;0=7=Z@H000001@3oool6000000H0oooo1P000005
0?ooo``000001@3oool6000000H0oooo1P0000050?ooo`H00000303AcJT30?ooo`D000001@3oool6
000000D0oooo1@0000060?ooo`X000001P3oool5000000D0oooo1P0000050?ooo`D000000`3oool>
0=7=Z@00303AcJT4ooooo`L000002?ooool7000000Sooooo3P000008ooooo`L000002?ooool70000
00Cooooo2P3AcJT7000000Oooooo1`000006ooooo`L000003_ooool6000000Oooooo1`000007oooo
o`L000002P3AcJT3ooooo`H000001oooool6000000Kooooo1P00000=ooooo`H000001_ooool70000
00Kooooo1P000003ooooo`/0dLfY1P0000050?ooo`H000001P3oool6000000D0oooo300000050?oo
o`H000001P3oool6000000D0oooo1P00000<0=7=Z@<0oooo1@0000050?ooo`H000001@3oool50000
00H0oooo2P0000060?ooo`D000001@3oool6000000D0oooo1@0000030?ooo`h0dLfY000<0=7=Z@P0
00001oooool7000000Sooooo1`000008ooooo`L000001oooool8000000Oooooo2000000:0=7=Z@Co
oooo1P000007ooooo`L000001oooool6000000Oooooo1`000007ooooo`L000001_ooool7000000Co
oooo2P3AcJT6000000Oooooo1P000006ooooo`H000001oooool6000000Kooooo1P000007ooooo`H0
00001_ooool6000000/0dLfY1P0000050?ooo`H000001P3oool6000000D0oooo300000050?ooo`H0
00001P3oool6000000D0oooo1P00000<0=7=Z@<0oooo1@0000050?ooo`H000001@3oool5000000H0
oooo2P0000060?ooo`D000001@3oool6000000D0oooo1@0000030?ooo`h0dLfY000<0=7=Z@P00000
1oooool7000000Sooooo1`000008ooooo`L000001oooool8000000Oooooo2000000:0=7=Z@Cooooo
1P000007ooooo`L000001oooool6000000Oooooo1`000007ooooo`L000001_ooool7000000Cooooo
2P3AcJT6000000Oooooo1P000006ooooo`H000001oooool6000000Kooooo1P000007ooooo`H00000
1_ooool6000000/0dLfY0`3oool6000000D0oooo1P0000060?ooo`D000001P3oool6000000H0oooo
1@0000060?ooo`H000001@3oool6000000<0oooo303AcJT5000000H0oooo1@0000050?ooo`H00000
1@3oool5000000H0oooo1@0000050?ooo`H000001@3oool5000000H0oooo1@00000>0=7=Z@00303A
cJT8000000Oooooo1`000008ooooo`L000002?ooool7000000Oooooo20000007ooooo`P000002P3A
cJT4ooooo`H000001oooool7000000Oooooo1P000007ooooo`L000001oooool7000000Kooooo1`00
0004ooooo`X0dLfY1P000007ooooo`H000001_ooool6000000Oooooo1P000006ooooo`H000001ooo
ool6000000Kooooo1P00000;0=7=Z@<0oooo1P0000050?ooo`H000001P3oool5000000H0oooo1P00
00060?ooo`D000001P3oool6000000D0oooo1P0000030?ooo``0dLfY1@0000060?ooo`D000001@3o
ool6000000D0oooo1@0000060?ooo`D000001@3oool6000000D0oooo1@0000060?ooo`D000003P3A
cJT000`0dLfY20000007ooooo`L000002?ooool7000000Sooooo1`000007ooooo`P000001oooool8
000000X0dLfY1?ooool6000000Oooooo1`000007ooooo`H000001oooool7000000Oooooo1`000006
ooooo`L000001?ooool:0=7=Z@?ooooo1P000007ooooo`H000001_ooool6000000gooooo1P000006
ooooo`L000001_ooool6000000?ooooo2`3AcJT30?ooo`H000001@3oool6000000H0oooo1@000006
0?ooo`H000001P3oool5000000H0oooo1P0000050?ooo`H000000`3oool<0=7=Z@D000001P3oool5
000000D0oooo1P0000050?ooo`D000001P3oool5000000D0oooo1P0000050?ooo`D000001P3oool5
000000h0dLfY000<0=7=Z@Cooooo1`000008ooooo`L000002?ooool>000000Sooooo1`000008oooo
o`L000001?ooool:0=7=Z@L000001oooool7000000Kooooo1`00000>ooooo`H000001oooool70000
00Oooooo1`00000:0=7=Z@?ooooo1P000007ooooo`H000001_ooool6000000gooooo1P000006oooo
o`L000001_ooool6000000?ooooo2`3AcJT6000000D0oooo1P0000060?ooo`H000001@3oool<0000
00D0oooo1P0000060?ooo`H000001@3oool6000000`0dLfY0`3oool5000000D0oooo1P0000050?oo
o`D000001P3oool:000000H0oooo1@0000050?ooo`H000001@3oool5000000<0oooo3P3AcJT000`0
dLfY1?ooool7000000Sooooo1`000008ooooo`h000002?ooool7000000Sooooo1`000004ooooo`X0
dLfY1`000007ooooo`L000001_ooool7000000kooooo1P000007ooooo`L000001oooool7000000X0
dLfY0oooool6000000Oooooo1P000006ooooo`H000003Oooool6000000Kooooo1`000006ooooo`H0
00000oooool;0=7=Z@H000001@3oool6000000H0oooo1P0000050?ooo``000001@3oool6000000H0
oooo1P0000050?ooo`H00000303AcJT30?ooo`D000001@3oool6000000D0oooo1@0000060?ooo`X0
00001P3oool5000000D0oooo1P0000050?ooo`D000000`3oool>0=7=Z@00303AcJT4ooooo`L00000
2?ooool7000000Sooooo3P000008ooooo`L000002?ooool7000000Cooooo2P3AcJT7000000Oooooo
1`000006ooooo`L000003_ooool6000000Oooooo1`000007ooooo`L000002P3AcJT6000000Oooooo
1P000006ooooo`H000004oooool6000000Oooooo1P000006ooooo`H000002`3AcJT6000000D0oooo
1P0000060?ooo`H000001@3oool<000000D0oooo1P0000060?ooo`H000001@3oool6000000`0dLfY
1@0000060?ooo`D000001@3oool6000000D0oooo400000050?ooo`H000001@3oool5000000H0oooo
1@00000>0=7=Z@00303AcJT4ooooo`L000002?ooool7000000Sooooo3P000008ooooo`L000002?oo
ool7000000Cooooo2P3AcJT4ooooo`H000001oooool7000000Oooooo50000007ooooo`L000001_oo
ool7000000Cooooo2P3AcJT6000000Oooooo1P000006ooooo`H000004oooool6000000Oooooo1P00
0006ooooo`H000002`3AcJT30?ooo`H000001@3oool6000000H0oooo1@00000B0?ooo`D000001P3o
ool6000000D0oooo1P0000030?ooo``0dLfY1@0000060?ooo`D000001@3oool6000000D0oooo4000
00050?ooo`H000001@3oool5000000H0oooo1@00000>0=7=Z@00303AcJT8000000Oooooo1`000008
oooooaH000001oooool8000000Oooooo2000000:0=7=Z@Cooooo1P000007ooooo`L000001ooooolD
000000Oooooo1`000006ooooo`L000001?ooool:0=7=Z@H000001oooool6000000Kooooo1P00000C
ooooo`H000001oooool6000000Kooooo1P00000;0=7=Z@<0oooo1P0000050?ooo`H000001P3oool5
00000180oooo1@0000060?ooo`H000001@3oool6000000<0oooo303AcJT5000000H0oooo1@000005
0?ooo`H000001@3oool@000000D0oooo1P0000050?ooo`D000001P3oool5000000h0dLfY000<0=7=
Z@P000001oooool7000000Sooooo5P000007ooooo`P000001oooool8000000X0dLfY1?ooool60000
00Oooooo1`000007oooooa@000001oooool7000000Kooooo1`000004ooooo`X0dLfY0oooool60000
00Oooooo1P000006oooooaT000001_ooool7000000Kooooo1P000003ooooo`/0dLfY0`3oool60000
00D0oooo1P0000060?ooo`D000004P3oool5000000H0oooo1P0000050?ooo`H000000`3oool<0=7=
Z@<0oooo1@0000050?ooo`H000001@3oool5000001H0oooo1@0000050?ooo`H000001@3oool50000
00<0oooo3P3AcJT000`0dLfY20000007ooooo`L000002?oooolF000000Oooooo20000007ooooo`P0
00002P3AcJT7000000Oooooo1`000006oooooa/000001oooool7000000Oooooo1`00000:0=7=Z@?o
oooo1P000007ooooo`H000001_oooolI000000Kooooo1`000006ooooo`H000000oooool;0=7=Z@H0
00001@3oool6000000H0oooo1P00000F0?ooo`H000001P3oool6000000D0oooo1P00000<0=7=Z@<0
oooo1@0000050?ooo`H000001@3oool5000001H0oooo1@0000050?ooo`H000001@3oool5000000<0
oooo3P3AcJT000`0dLfY1?ooool7000000Sooooo1`00000Nooooo`L000002?ooool7000000Cooooo
2P3AcJT7000000Oooooo1`000006oooooa/000001oooool7000000Oooooo1`00000:0=7=Z@?ooooo
1P000007ooooo`H000001_oooolI000000Kooooo1`000006ooooo`H000000oooool;0=7=Z@H00000
1@3oool6000000H0oooo1P00000F0?ooo`H000001P3oool6000000D0oooo1P00000<0=7=Z@<0oooo
1@0000050?ooo`H000001@3oool5000001H0oooo1@0000050?ooo`H000001@3oool5000000<0oooo
3P3AcJT000`0dLfY1?ooool7000000Sooooo1`00000Nooooo`L000002?ooool7000000Cooooo2P3A
cJT7000000Oooooo1`000006oooooa/000001oooool7000000Oooooo1`00000:0=7=Z@?ooooo1P00
0007ooooo`H000001_oooolI000000Kooooo1`000006ooooo`H000000oooool;0=7=Z@<0oooo1P00
00050?ooo`H000001P3ooolL000000H0oooo1P0000050?ooo`H000000`3oool<0=7=Z@D000001P3o
ool5000000D0oooo1P00000J0?ooo`H000001@3oool5000000H0oooo1@00000>0=7=Z@00303AcJT4
ooooo`L000002?ooool7000001kooooo1`000008ooooo`L000001?ooool:0=7=Z@L000001oooool7
000000Kooooo6`000007ooooo`L000001oooool7000000X0dLfY1P000007ooooo`H000001_oooolO
000000Oooooo1P000006ooooo`H000002`3AcJT30?ooo`H000001@3oool6000000H0oooo70000006
0?ooo`H000001@3oool6000000<0oooo303AcJT5000000H0oooo1@0000050?ooo`H000006P3oool6
000000D0oooo1@0000060?ooo`D000003P3AcJT000`0dLfY1?ooool7000000Sooooo1`00000Noooo
o`L000002?ooool7000000Cooooo2P3AcJT4ooooo`H000001oooool7000002;ooooo1`000006oooo
o`L000001?ooool:0=7=Z@H000001oooool6000000Kooooo7`000007ooooo`H000001_ooool60000
00/0dLfY0`3oool6000000D0oooo1P0000060?oooa`000001P3oool6000000D0oooo1P0000030?oo
o``0dLfY0`3oool5000000D0oooo1P0000050?ooob0000001@3oool6000000D0oooo1@0000030?oo
o`h0dLfY000<0=7=Z@P000001oooool7000002Gooooo20000007ooooo`P000002P3AcJT4ooooo`H0
00001oooool7000002;ooooo1`000006ooooo`L000001?ooool:0=7=Z@H000001oooool6000000Ko
oooo7`000007ooooo`H000001_ooool6000000/0dLfY1P0000050?ooo`H000001P3ooolR000000H0
oooo1P0000050?ooo`H00000303AcJT30?ooo`D000001@3oool6000000D0oooo800000050?ooo`H0
00001@3oool5000000<0oooo3P3AcJT000`0dLfY20000007ooooo`L000009Oooool8000000Oooooo
2000000:0=7=Z@Cooooo1P000007ooooo`L000008_ooool7000000Kooooo1`000004ooooo`X0dLfY
0oooool6000000Oooooo1P00000Uooooo`L000001_ooool6000000?ooooo2`3AcJT6000000D0oooo
1P0000060?ooob8000001P3oool6000000D0oooo1P00000<0=7=Z@<0oooo1@0000050?ooo`H00000
1@3ooolP000000D0oooo1P0000050?ooo`D000000`3oool>0=7=Z@00303AcJT8000000Oooooo1`00
000Uooooo`P000001oooool8000000X0dLfY1`000007ooooo`L00000:?ooool7000000Oooooo1`00
000:0=7=Z@?ooooo1P000007ooooo`H000009Oooool7000000Kooooo1P000003ooooo`/0dLfY1P00
00050?ooo`H000001P3ooolR000000H0oooo1P0000050?ooo`H00000303AcJT5000000H0oooo1@00
00050?ooobH000001@3oool5000000H0oooo1@00000>0=7=Z@00303AcJT4ooooo`L000002?ooool/
000000Sooooo1`000004ooooo`X0dLfY1`000007ooooo`L00000:?ooool7000000Oooooo1`00000:
0=7=Z@?ooooo1P000007ooooo`H000009Oooool7000000Kooooo1P000003ooooo`/0dLfY0`3oool6
000000D0oooo1P00000X0?ooo`H000001@3oool6000000<0oooo303AcJT5000000H0oooo1@000005
0?ooobH000001@3oool5000000H0oooo1@00000>0=7=Z@00303AcJT4ooooo`L000002?ooool/0000
00Sooooo1`000004ooooo`X0dLfY1`000007ooooo`L00000:?ooool7000000Oooooo1`00000:0=7=
Z@H000001oooool6000002cooooo1P000006ooooo`H000002`3AcJT30?ooo`H000001@3oool60000
02P0oooo1P0000050?ooo`H000000`3oool<0=7=Z@D000001P3oool5000000D0oooo9P0000050?oo
o`D000001P3oool5000000h0dLfY000<0=7=Z@Cooooo1`000008ooooob`000002?ooool7000000Co
oooo2P3AcJT4ooooo`H000001oooool`000000Kooooo1`000004ooooo`X0dLfY1P000007ooooo`H0
0000;?ooool6000000Kooooo1P00000;0=7=Z@<0oooo1P0000050?ooo`H00000:03oool6000000D0
oooo1P0000030?ooo``0dLfY0`3oool5000000D0oooo1P00000Z0?ooo`H000001@3oool5000000<0
oooo3P3AcJT000`0dLfY1?ooool7000000Sooooo;0000008ooooo`L000001?ooool:0=7=Z@Cooooo
1P000007oooooc0000001_ooool7000000Cooooo2P3AcJT6000000Oooooo1P00000/ooooo`H00000
1_ooool6000000/0dLfY1P0000050?ooo`H00000;P3oool6000000D0oooo1P00000<0=7=Z@<0oooo
1@0000050?ooo`H00000:P3oool6000000D0oooo1@0000030?ooo`h0dLfY000<0=7=Z@P000001ooo
oold000000Oooooo2000000:0=7=Z@Cooooo1P000007oooooc0000001_ooool7000000Cooooo2P3A
cJT3ooooo`H000001ooooolb000000Kooooo1P000003ooooo`/0dLfY1P0000050?ooo`H00000;P3o
ool6000000D0oooo1P00000<0=7=Z@D000001P3oool500000300oooo1@0000060?ooo`D000003P3A
cJT000`0dLfY20000007oooooc@000001oooool8000000X0dLfY1`000007ooooocH000001oooool7
000000X0dLfY0oooool6000000Oooooo<P000006ooooo`H000000oooool;0=7=Z@H000001@3oool6
000002h0oooo1P0000050?ooo`H00000303AcJT5000000H0oooo1@00000`0?ooo`D000001P3oool5
000000h0dLfY000<0=7=Z@P000001ooooold000000Oooooo2000000:0=7=Z@L000001ooooolf0000
00Oooooo1`00000:0=7=Z@?ooooo1P000007oooooc8000001_ooool6000000?ooooo2`3AcJT30?oo
o`H000001@3ooold000000D0oooo1P0000030?ooo``0dLfY1@0000060?ooo`D00000<03oool50000
00H0oooo1@00000>0=7=Z@00303AcJT8000000Oooooo=0000007ooooo`P000002P3AcJT7000000Oo
oooo=P000007ooooo`L000002P3AcJT6000000Oooooo>0000006ooooo`H000002`3AcJT30?ooo`H0
00001@3ooold000000D0oooo1P0000030?ooo``0dLfY0`3oool5000000D0oooo=P0000050?ooo`D0
00000`3oool>0=7=Z@00303AcJT4ooooo`L00000??ooool7000000Cooooo2P3AcJT7000000Oooooo
=P000007ooooo`L000002P3AcJT6000000Oooooo>0000006ooooo`H000002`3AcJT30?ooo`H00000
1@3ooold000000D0oooo1P0000030?ooo``0dLfY0`3oool5000000D0oooo=P0000050?ooo`D00000
0`3oool>0=7=Z@00303AcJT4ooooo`L00000??ooool7000000Cooooo2P3AcJT4ooooo`H00000?Ooo
ool7000000Cooooo2P3AcJT6000000Oooooo>0000006ooooo`H000002`3AcJT6000000D0oooo>P00
00050?ooo`H00000303AcJT30?ooo`D000001@3ooolf000000D0oooo1@0000030?ooo`h0dLfY000<
0=7=Z@Cooooo1`00000looooo`L000001?ooool:0=7=Z@Cooooo1P00000mooooo`L000001?ooool:
0=7=Z@?ooooo1P00000oooooo`H000000oooool;0=7=Z@H000001@3ooolj000000D0oooo1P00000<
0=7=Z@D000001P3ooolj000000H0oooo1@00000>0=7=Z@00303AcJT8000004;ooooo2000000:0=7=
Z@Cooooo1P00000mooooo`L000001?ooool:0=7=Z@?ooooo1P00000oooooo`H000000oooool;0=7=
Z@H000001@3ooolj000000D0oooo1P00000<0=7=Z@D000001P3ooolj000000H0oooo1@00000>0=7=
Z@00303AcJT8000004;ooooo2000000:0=7=Z@L00000A?ooool7000000X0dLfY0oooool6000003oo
oooo1P000003ooooo`/0dLfY0`3oool6000003h0oooo1P0000030?ooo``0dLfY0`3oool500000400
oooo1@0000030?ooo`h0dLfY000<0=7=Z@P00000@_ooool8000000X0dLfY1`000014ooooo`L00000
2P3AcJT6000004Gooooo1P00000;0=7=Z@<0oooo1P00000n0?ooo`H000000`3oool<0=7=Z@<0oooo
1@0000100?ooo`D000000`3oool>0=7=Z@00303AcJT8000004;ooooo2000000:0=7=Z@L00000A?oo
ool7000000X0dLfY1P000015ooooo`H000002`3AcJT6000004@0oooo1P00000<0=7=Z@<0oooo1@00
00100?ooo`D000000`3oool>0=7=Z@00303AcJT4ooooodX000001?ooool:0=7=Z@CoooooBP000004
ooooo`X0dLfY1P000015ooooo`H000002`3AcJT6000004@0oooo1P00000<0=7=Z@D00000AP3oool5
000000h0dLfY000<0=7=Z@CoooooBP000004ooooo`X0dLfY1?oooom:000000Cooooo2P3AcJT3oooo
od/000000oooool;0=7=Z@H00000A03oool6000000`0dLfY1@0000160?ooo`D000003P3AcJT000`0
dLfY1?oooom:000000Cooooo2P3AcJT4ooooodX000001?ooool:0=7=Z@?oooooB`000003ooooo`/0
dLfY0`3ooom:000000<0oooo303AcJT5000004H0oooo1@00000>0=7=Z@00303AcJUB000000X0dLfY
1?oooom:000000Cooooo2P3AcJT3oooood/000000oooool;0=7=Z@<0ooooBP0000030?ooo``0dLfY
0`3ooom:000000<0oooo3P3AcJT000`0dLfYDP00000:0=7=ZE8000002P3AcJUA000000/0dLfY0`3o
oom:000000<0oooo303AcJT30?ooodX000000`3oool>0=7=Z@00303AcJUB000000X0dLfYDP00000:
0=7=ZE4000002`3AcJU@000000`0dLfYD000000>0=7=Z@00303AcJUB000000X0dLfYDP00000:0=7=
ZE4000002`3AcJU@000000`0dLfYD000000>0=7=Z@00o`3AcJTQ0=7=ZE000000303AcJU@000000h0
dLfY003o0=7=ZM/0dLfY003o0=7=ZM/0dLfY003o0=7=ZM/0dLfY003o0=7=ZM/0dLfY003o0=7=ZM/0
dLfY003o0=7=ZM/0dLfY003o0=7=ZM/0dLfY003o0=7=ZM/0dLfY003o0=7=ZM/0dLfY003o0=7=ZM/0
dLfY003o0=7=ZM/0dLfY000<0=7=ZE;ooooo2P3AcJUBooooo`X0dLfYDOooool;0=7=ZE7ooooo2`3A
cJUAooooo`d0dLfY000<0=7=ZE;ooooo2P3AcJUBooooo`X0dLfYDOooool;0=7=ZE7ooooo2`3AcJUA
ooooo`d0dLfY000<0=7=ZE;ooooo2P3AcJUBooooo`X0dLfYDOooool;0=7=ZE7ooooo2`3AcJUAoooo
o`d0dLfY000<0=7=ZE;ooooo2P3AcJUBooooo`X0dLfYDOooool;0=7=ZE7ooooo2`3AcJUAooooo`d0
dLfY000<0=7=ZE;ooooo2P3AcJUBooooo`X0dLfYDOooool;0=7=ZE7ooooo2`3AcJUA000000d0dLfY
000<0=7=ZE;ooooo2P3AcJUBooooo`X0dLfYD@00000;0=7=ZE4000002`3AcJUA000000d0dLfY000<
0=7=ZE;ooooo2P3AcJUB000000X0dLfYD@00000;0=7=ZE4000002`3AcJUA000000d0dLfY000<0=7=
ZE8000002P3AcJUB000000X0dLfYD@00000;0=7=ZE4000002`3AcJUA000000d0dLfY000<0=7=ZE80
00002P3AcJUB000000X0dLfYD@00000;0=7=ZE4000002`3AcJT4ooooodT000001?ooool=0=7=Z@00
303AcJUB000000X0dLfYDP00000:0=7=ZE4000002`3AcJT4ooooodT000001?ooool;0=7=Z@Cooooo
B@000004ooooo`d0dLfY000<0=7=ZE8000002P3AcJUB000000X0dLfY1Ooooom7000000Gooooo2`3A
cJT4ooooodT000001?ooool;0=7=Z@CoooooB@000004ooooo`d0dLfY000<0=7=ZE8000002P3AcJUB
000000X0dLfY1Ooooom7000000Gooooo2`3AcJT4ooooodT000001?ooool;0=7=Z@CoooooB@000004
ooooo`d0dLfY000<0=7=ZE8000002P3AcJT6ooooodH000001_ooool:0=7=Z@GoooooA`000005oooo
o`/0dLfY1?oooom9000000Cooooo2`3AcJT80000047ooooo2000000=0=7=Z@00303AcJUB000000X0
dLfY1_oooom6000000Kooooo2P3AcJT5ooooodL000001Oooool;0=7=Z@CoooooB@000004ooooo`/0
dLfY20000011ooooo`P000003@3AcJT000`0dLfY1ooooom4000000Oooooo2P3AcJT6ooooodH00000
1_ooool:0=7=Z@GoooooA`000005ooooo`/0dLfY2@00000oooooo`T000002`3AcJT80000047ooooo
2000000=0=7=Z@00303AcJT7oooood@000001oooool:0=7=Z@KoooooAP000006ooooo`X0dLfY2P00
000mooooo`X000002`3AcJT9000003oooooo2@00000;0=7=Z@P00000@Oooool8000000d0dLfY000<
0=7=Z@OoooooA0000007ooooo`X0dLfY1_oooom6000000Kooooo2P3AcJT:000003gooooo2P00000;
0=7=Z@T00000?oooool9000000/0dLfY1?ooool8000003Wooooo20000004ooooo`d0dLfY000<0=7=
Z@OoooooA0000007ooooo`X0dLfY3000000jooooo``000002P3AcJT:000003gooooo2P00000;0=7=
Z@T00000?oooool9000000/0dLfY1?ooool8000003Wooooo20000004ooooo`d0dLfY000<0=7=Z@Oo
ooooA0000007ooooo`X0dLfY3000000jooooo``000002P3AcJT:000003gooooo2P00000;0=7=Z@Co
oooo2@00000gooooo`T000001?ooool;0=7=Z@Cooooo2000000iooooo`P000001?ooool=0=7=Z@00
303AcJT7oooood@000001oooool:0=7=Z@`00000>_ooool<000000X0dLfY2P00000mooooo`X00000
2`3AcJT4ooooo`T00000=oooool9000000Cooooo2`3AcJT4ooooo`P00000>Oooool8000000Cooooo
3@3AcJT000`0dLfY3P00000fooooo`h000002P3AcJT<000003[ooooo3000000:0=7=Z@Gooooo2P00
000cooooo`X000001Oooool;0=7=Z@Cooooo2@00000gooooo`T000001?ooool;0=7=Z@P000002?oo
oola000000Sooooo2000000=0=7=Z@00303AcJT>000003Kooooo3P00000:0=7=Z@`00000>_ooool<
000000X0dLfY1Oooool:000003?ooooo2P000005ooooo`/0dLfY1?ooool9000003Oooooo2@000004
ooooo`/0dLfY20000008oooooc4000002?ooool8000000d0dLfY000<0=7=Z@h00000=_ooool>0000
00X0dLfY3000000jooooo``000002P3AcJT5ooooo`X00000<oooool:000000Gooooo2`3AcJT4oooo
o`T00000=oooool9000000Cooooo2`3AcJT8000000Sooooo<@000008ooooo`P000003@3AcJT000`0
dLfY3P00000fooooo`h000002P3AcJT6ooooo``00000;_ooool<000000Kooooo2P3AcJT5ooooo`X0
0000<oooool:000000Gooooo2`3AcJT9000000Wooooo;@000009ooooo`T000002`3AcJT8000000So
oooo<@000008ooooo`P000003@3AcJT000`0dLfY3P00000fooooo`h000002P3AcJT6ooooo``00000
;_ooool<000000Kooooo2P3AcJT5ooooo`X00000<oooool:000000Gooooo2`3AcJT9000000Wooooo
;@000009ooooo`T000002`3AcJT4ooooo`P000002?oooolY000000Sooooo20000004ooooo`d0dLfY
000<0=7=Z@h00000=_ooool>000000X0dLfY1_ooool<000002kooooo30000006ooooo`X0dLfY2P00
000:ooooobT000002_ooool:000000/0dLfY2@000009ooooobd000002Oooool9000000/0dLfY1?oo
ool8000000Sooooo:@000008ooooo`P000001?ooool=0=7=Z@00303AcJT>000003Kooooo3P00000:
0=7=Z@Kooooo3000000^ooooo``000001_ooool:0=7=Z@X000002_oooolY000000[ooooo2P00000;
0=7=Z@T000002Oooool]000000Wooooo2@00000;0=7=Z@Cooooo20000008ooooobT000002?ooool8
000000Cooooo3@3AcJT000`0dLfY1oooool>000002Sooooo3P000007ooooo`X0dLfY1_ooool<0000
02kooooo30000006ooooo`X0dLfY2P00000:ooooobT000002_ooool:000000/0dLfY1?ooool90000
00Wooooo9@000009ooooo`T000001?ooool;0=7=Z@Cooooo20000008ooooobT000002?ooool80000
00Cooooo3@3AcJT000`0dLfY1oooool>000002Sooooo3P000007ooooo`X0dLfY1_ooool<000002ko
oooo30000006ooooo`X0dLfY2P00000:ooooobT000002_ooool:000000/0dLfY1?ooool9000000Wo
oooo9@000009ooooo`T000001?ooool;0=7=Z@P000002?ooool80000027ooooo20000008ooooo`P0
00003@3AcJT000`0dLfY1oooool>000002Sooooo3P000007ooooo`X0dLfY3000000;ooooob<00000
3?ooool<000000X0dLfY2P00000:ooooobT000002_ooool:000000/0dLfY1?ooool9000000Wooooo
9@000009ooooo`T000001?ooool;0=7=Z@P000002?ooool80000027ooooo20000008ooooo`P00000
3@3AcJT000`0dLfY1oooool>000002Sooooo3P000007ooooo`X0dLfY3000000;ooooob<000003?oo
ool<000000X0dLfY1Oooool:000000[ooooo7`00000:ooooo`X000001Oooool;0=7=Z@Cooooo2@00
0009ooooobD000002Oooool9000000Cooooo2`3AcJT8000000Sooooo2000000Qooooo`P000002?oo
ool8000000d0dLfY000<0=7=Z@Oooooo3P00000Xooooo`h000001oooool:0=7=Z@`000002ooooolS
000000cooooo3000000:0=7=Z@Gooooo2P00000:oooooal000002_ooool:000000Gooooo2`3AcJT9
000000Wooooo2@00000Kooooo`T000002Oooool9000000/0dLfY20000008ooooo`P000008Oooool8
000000Sooooo2000000=0=7=Z@00303AcJT7ooooo`h00000:?ooool>000000Oooooo2P3AcJT<0000
00_ooooo8`00000<ooooo``000002P3AcJT5ooooo`X000002_oooolO000000[ooooo2P000005oooo
o`/0dLfY2@000009ooooo`T000006oooool9000000Wooooo2@00000;0=7=Z@Cooooo20000008oooo
o`P000006Oooool8000000Sooooo20000004ooooo`d0dLfY000<0=7=Z@Oooooo3P00000Xooooo`h0
00001oooool:0=7=Z@`000002ooooolS000000cooooo3000000:0=7=Z@Gooooo2P00000:oooooal0
00002_ooool:000000Gooooo2`3AcJT9000000Wooooo2@00000Kooooo`T000002Oooool9000000/0
dLfY1?ooool8000000Sooooo2000000Iooooo`P000002?ooool8000000Cooooo3@3AcJT000`0dLfY
3P00000=oooooa`000003Oooool>000000X0dLfY1_ooool<000000_ooooo5`00000<ooooo``00000
1_ooool:0=7=Z@Gooooo2P00000:oooooal000002_ooool:000000Gooooo2`3AcJT9000000Wooooo
2@00000Kooooo`T000002Oooool9000000/0dLfY1?ooool8000000Sooooo2000000Iooooo`P00000
2?ooool8000000Cooooo3@3AcJT000`0dLfY3P00000=oooooa`000003Oooool>000000X0dLfY1_oo
ool<000000_ooooo5`00000<ooooo``000001_ooool:0=7=Z@X000002_ooool;000001Cooooo2P00
000:ooooo`X000002`3AcJT9000000Wooooo2@00000Kooooo`T000002Oooool9000000/0dLfY1?oo
ool8000000Sooooo2000000Iooooo`P000002?ooool8000000Cooooo3@3AcJT000`0dLfY3P00000=
oooooa`000003Oooool>000000X0dLfY1_ooool<000000_ooooo5`00000<ooooo``000001_ooool:
0=7=Z@X000002_ooool;000001Cooooo2P00000:ooooo`X000002`3AcJT4ooooo`T000002Oooool9
000001?ooooo2@000009ooooo`T000001?ooool;0=7=Z@P000002?ooool8000000Sooooo4@000008
ooooo`P000002?ooool8000000d0dLfY000<0=7=Z@h000003OoooolL000000gooooo3P00000:0=7=
Z@Kooooo3000000;oooooaL000003?ooool<000000Kooooo2P3AcJT:000000[ooooo2`00000Doooo
o`X000002_ooool:000000/0dLfY1?ooool9000000Wooooo2@00000Cooooo`T000002Oooool90000
00Cooooo2`3AcJT8000000Sooooo20000008oooooa4000002?ooool8000000Sooooo2000000=0=7=
Z@00303AcJT>000000gooooo7000000=ooooo`h000002P3AcJT6ooooo``000002ooooolG000000co
oooo30000006ooooo`X0dLfY2P00000:ooooo`/000005?ooool:000000[ooooo2P00000;0=7=Z@Co
oooo2@000009ooooo`T000004oooool9000000Wooooo2@000004ooooo`/0dLfY20000008ooooo`P0
00002?oooolA000000Sooooo20000008ooooo`P000003@3AcJT000`0dLfY3P00000=oooooa`00000
3Oooool>000000X0dLfY1_ooool<000000_ooooo5`00000<ooooo``000001_ooool:0=7=Z@X00000
2_ooool;000001Cooooo2P00000:ooooo`X000002`3AcJT4ooooo`T000002Oooool9000001?ooooo
2@000009ooooo`T000001?ooool;0=7=Z@P000002?ooool8000000Sooooo4@000008ooooo`P00000
2?ooool8000000d0dLfY000<0=7=Z@Oooooo3P00000=ooooo`h000003Oooool>000000Oooooo2P3A
cJT<000000_ooooo3000000<ooooo`/000003?ooool<000000X0dLfY1Oooool:000000[ooooo2`00
000:ooooo`X000002_ooool:000000Gooooo2`3AcJT9000000Wooooo2@000009ooooo`T000002Ooo
ool9000000Wooooo2@00000;0=7=Z@Cooooo20000008ooooo`P000002?ooool8000000Wooooo2000
0008ooooo`P000001?ooool=0=7=Z@00303AcJT7ooooo`h000003Oooool>000000gooooo3P000007
ooooo`X0dLfY3000000;ooooo``000003?ooool;000000cooooo3000000:0=7=Z@Gooooo2P00000:
ooooo`/000002_ooool:000000[ooooo2P000005ooooo`/0dLfY2@000009ooooo`T000002Oooool9
000000Wooooo2@000009ooooo`T000002`3AcJT4ooooo`P000002?ooool8000000Sooooo20000009
ooooo`P000002?ooool8000000Cooooo3@3AcJT000`0dLfY1oooool>000000gooooo3P00000=oooo
o`h000001oooool:0=7=Z@`000002oooool<000000cooooo2`00000<ooooo``000002P3AcJT5oooo
o`X000002_ooool;000000[ooooo2P00000:ooooo`X000001Oooool;0=7=Z@T000002Oooool90000
00Wooooo2@000009ooooo`T000002Oooool9000000/0dLfY1?ooool8000000Sooooo20000008oooo
o`P000002Oooool8000000Sooooo20000004ooooo`d0dLfY000<0=7=Z@Oooooo3P00000=ooooo`h0
00003Oooool>000000Oooooo2P3AcJT<000000_ooooo3000000<ooooo`/000003?ooool<000000X0
dLfY1Oooool:000000[ooooo2`00000:ooooo`X000002_ooool:000000Gooooo2`3AcJT9000000Wo
oooo2@000009ooooo`T000002Oooool9000000Wooooo2@00000;0=7=Z@Cooooo20000008ooooo`P0
00002?ooool8000000Wooooo20000008ooooo`P000001?ooool=0=7=Z@00303AcJT7ooooo`h00000
3Oooool>000000gooooo3P000007ooooo`X0dLfY3000000;ooooo``000003?ooool;000000cooooo
3000000:0=7=Z@Gooooo2P00000:ooooo`/000002_ooool:000000[ooooo2P000005ooooo`/0dLfY
2@000009ooooo`T000002Oooool9000000Wooooo2@000009ooooo`T000002`3AcJT8000000Sooooo
20000008oooooa4000002?ooool8000000Sooooo2000000=0=7=Z@00303AcJT7ooooo`h000003Ooo
ool>000000gooooo3P000007ooooo`X0dLfY3000000;ooooo``000003?ooool;000000cooooo3000
000:0=7=Z@X000002_ooool;000001Cooooo2P00000:ooooo`X000002`3AcJT4ooooo`T000002Ooo
ool9000001?ooooo2@000009ooooo`T000001?ooool;0=7=Z@P000002?ooool8000000Sooooo4@00
0008ooooo`P000002?ooool8000000d0dLfY000<0=7=Z@Oooooo3P00000=ooooo`h000003Oooool>
000000Oooooo2P3AcJT6ooooo``000002ooooolG000000cooooo30000006ooooo`X0dLfY2P00000:
ooooo`/000005?ooool:000000[ooooo2P00000;0=7=Z@Cooooo2@000009ooooo`T000004oooool9
000000Wooooo2@000004ooooo`/0dLfY20000008ooooo`P000002?oooolA000000Sooooo20000008
ooooo`P000003@3AcJT000`0dLfY3P00000=oooooa`000003Oooool>000000X0dLfY1_ooool<0000
00_ooooo5`00000<ooooo``000001_ooool:0=7=Z@X000002_ooool;000001Cooooo2P00000:oooo
o`X000002`3AcJT4ooooo`T000002Oooool9000001?ooooo2@000009ooooo`T000001?ooool;0=7=
Z@P000002?ooool8000000Sooooo4@000008ooooo`P000002?ooool8000000d0dLfY000<0=7=Z@h0
00003OoooolL000000gooooo3P00000:0=7=Z@Kooooo3000000;oooooaL000003?ooool<000000Ko
oooo2P3AcJT:000000[ooooo2`00000Dooooo`X000002_ooool:000000/0dLfY1?ooool9000000Wo
oooo2@00000Cooooo`T000002Oooool9000000Cooooo2`3AcJT4ooooo`P000002?ooool8000001Wo
oooo20000008ooooo`P000001?ooool=0=7=Z@00303AcJT>000000gooooo7000000=ooooo`h00000
2P3AcJT6ooooo``000002ooooolG000000cooooo30000006ooooo`X0dLfY2P00000:ooooo`/00000
5?ooool:000000[ooooo2P00000;0=7=Z@T000002Oooool9000001_ooooo2@000009ooooo`T00000
2`3AcJT4ooooo`P000002?ooool8000001Wooooo20000008ooooo`P000001?ooool=0=7=Z@00303A
cJT>000000gooooo7000000=ooooo`h000002P3AcJT6ooooo``000002ooooolG000000cooooo3000
0006ooooo`X0dLfY1Oooool:000000[ooooo7`00000:ooooo`X000001Oooool;0=7=Z@T000002Ooo
ool9000001_ooooo2@000009ooooo`T000002`3AcJT4ooooo`P000002?ooool8000001Wooooo2000
0008ooooo`P000001?ooool=0=7=Z@00303AcJT>000000gooooo7000000=ooooo`h000002P3AcJT<
000000_ooooo8`00000<ooooo``000002P3AcJT5ooooo`X000002_oooolO000000[ooooo2P000005
ooooo`/0dLfY2@000009ooooo`T000006oooool9000000Wooooo2@00000;0=7=Z@Cooooo20000008
ooooo`P000006Oooool8000000Sooooo20000004ooooo`d0dLfY000<0=7=Z@h000003OoooolL0000
00gooooo3P00000:0=7=Z@`000002ooooolS000000cooooo3000000:0=7=Z@Gooooo2P00000:oooo
oal000002_ooool:000000Gooooo2`3AcJT9000000Wooooo2@00000Kooooo`T000002Oooool90000
00/0dLfY20000008ooooo`P000008Oooool8000000Sooooo2000000=0=7=Z@00303AcJT7ooooo`h0
0000:?ooool>000000Oooooo2P3AcJT<000000_ooooo8`00000<ooooo``000002P3AcJT5ooooo`X0
00002_oooolO000000[ooooo2P000005ooooo`/0dLfY1?ooool9000000Wooooo9@000009ooooo`T0
00001?ooool;0=7=Z@P000002?ooool80000027ooooo20000008ooooo`P000003@3AcJT000`0dLfY
1oooool>000002Sooooo3P000007ooooo`X0dLfY3000000;ooooob<000003?ooool<000000X0dLfY
1Oooool:000000[ooooo7`00000:ooooo`X000001Oooool;0=7=Z@Cooooo2@000009ooooobD00000
2Oooool9000000Cooooo2`3AcJT8000000Sooooo2000000Qooooo`P000002?ooool8000000d0dLfY
000<0=7=Z@Oooooo3P00000Xooooo`h000001oooool:0=7=Z@`000002ooooolS000000cooooo3000
000:0=7=Z@X000002_oooolY000000[ooooo2P00000;0=7=Z@Cooooo2@000009ooooobD000002Ooo
ool9000000Cooooo2`3AcJT8000000Sooooo2000000Qooooo`P000002?ooool8000000d0dLfY000<
0=7=Z@Oooooo3P00000Xooooo`h000001oooool:0=7=Z@`000002ooooolS000000cooooo3000000:
0=7=Z@X000002_oooolY000000[ooooo2P00000;0=7=Z@Cooooo2@000009ooooobD000002Oooool9
000000Cooooo2`3AcJT4ooooo`P000002?oooolY000000Sooooo20000004ooooo`d0dLfY000<0=7=
Z@Oooooo3P00000Xooooo`h000001oooool:0=7=Z@Kooooo3000000^ooooo``000001_ooool:0=7=
Z@X000002_oooolY000000[ooooo2P00000;0=7=Z@Cooooo2@000009ooooobD000002Oooool90000
00Cooooo2`3AcJT4ooooo`P000002?oooolY000000Sooooo20000004ooooo`d0dLfY000<0=7=Z@Oo
oooo3P00000Xooooo`h000001oooool:0=7=Z@Kooooo3000000^ooooo``000001_ooool:0=7=Z@X0
00002_oooolY000000[ooooo2P00000;0=7=Z@T000002Oooool]000000Wooooo2@00000;0=7=Z@Co
oooo20000008ooooobT000002?ooool8000000Cooooo3@3AcJT000`0dLfY1oooool>000002Sooooo
3P000007ooooo`X0dLfY1_ooool<000002kooooo30000006ooooo`X0dLfY2P00000:ooooobT00000
2_ooool:000000/0dLfY2@000009ooooobd000002Oooool9000000/0dLfY1?ooool8000000Sooooo
:@000008ooooo`P000001?ooool=0=7=Z@00303AcJT>000003Kooooo3P00000:0=7=Z@Kooooo3000
000^ooooo``000001_ooool:0=7=Z@Gooooo2P00000cooooo`X000001Oooool;0=7=Z@T000002Ooo
ool]000000Wooooo2@00000;0=7=Z@P000002?oooola000000Sooooo2000000=0=7=Z@00303AcJT>
000003Kooooo3P00000:0=7=Z@Kooooo3000000^ooooo``000001_ooool:0=7=Z@Gooooo2P00000c
ooooo`X000001Oooool;0=7=Z@T000002Oooool]000000Wooooo2@00000;0=7=Z@P000002?oooola
000000Sooooo2000000=0=7=Z@00303AcJT>000003Kooooo3P00000:0=7=Z@Kooooo3000000^oooo
o``000001_ooool:0=7=Z@Gooooo2P00000cooooo`X000001Oooool;0=7=Z@Cooooo2@00000goooo
o`T000001?ooool;0=7=Z@P000002?oooola000000Sooooo2000000=0=7=Z@00303AcJT>000003Ko
oooo3P00000:0=7=Z@`00000>_ooool<000000X0dLfY1Oooool:000003?ooooo2P000005ooooo`/0
dLfY1?ooool9000003Oooooo2@000004ooooo`/0dLfY20000008oooooc4000002?ooool8000000d0
dLfY000<0=7=Z@h00000=_ooool>000000X0dLfY3000000jooooo``000002P3AcJT5ooooo`X00000
<oooool:000000Gooooo2`3AcJT4ooooo`T00000=oooool9000000Cooooo2`3AcJT4ooooo`P00000
>Oooool8000000Cooooo3@3AcJT000`0dLfY3P00000fooooo`h000002P3AcJT<000003[ooooo3000
000:0=7=Z@X00000?Oooool:000000/0dLfY1?ooool9000003Oooooo2@000004ooooo`/0dLfY1?oo
ool8000003Wooooo20000004ooooo`d0dLfY000<0=7=Z@h00000=_ooool>000000X0dLfY3000000j
ooooo``000002P3AcJT:000003gooooo2P00000;0=7=Z@Cooooo2@00000gooooo`T000001?ooool;
0=7=Z@Cooooo2000000iooooo`P000001?ooool=0=7=Z@00303AcJT7oooood@000001oooool:0=7=
Z@`00000>_ooool<000000X0dLfY2P00000mooooo`X000002`3AcJT9000003oooooo2@00000;0=7=
Z@Cooooo2000000iooooo`P000001?ooool=0=7=Z@00303AcJT7oooood@000001oooool:0=7=Z@Ko
ooooAP000006ooooo`X0dLfY2P00000mooooo`X000002`3AcJT9000003oooooo2@00000;0=7=Z@P0
0000@Oooool8000000d0dLfY000<0=7=Z@OoooooA0000007ooooo`X0dLfY1_oooom6000000Kooooo
2P3AcJT:000003gooooo2P00000;0=7=Z@T00000?oooool9000000/0dLfY20000011ooooo`P00000
3@3AcJT000`0dLfY1ooooom4000000Oooooo2P3AcJT6ooooodH000001_ooool:0=7=Z@GoooooA`00
0005ooooo`/0dLfY2@00000oooooo`T000002`3AcJT80000047ooooo2000000=0=7=Z@00303AcJT7
oooood@000001oooool:0=7=Z@KoooooAP000006ooooo`X0dLfY1Ooooom7000000Gooooo2`3AcJT4
ooooodT000001?ooool;0=7=Z@P00000@Oooool8000000d0dLfY000<0=7=Z@OoooooA0000007oooo
o`X0dLfY1_oooom6000000Kooooo2P3AcJT5ooooodL000001Oooool;0=7=Z@CoooooB@000004oooo
o`/0dLfY1?oooom9000000Cooooo3@3AcJT000`0dLfYDP00000:0=7=Z@KoooooAP000006ooooo`X0
dLfY1Ooooom7000000Gooooo2`3AcJT4ooooodT000001?ooool;0=7=Z@CoooooB@000004ooooo`d0
dLfY000<0=7=ZE8000002P3AcJUB000000X0dLfY1Ooooom7000000Gooooo2`3AcJT4ooooodT00000
1?ooool;0=7=Z@CoooooB@000004ooooo`d0dLfY000<0=7=ZE8000002P3AcJUB000000X0dLfYD@00
000;0=7=ZE4000002`3AcJT4ooooodT000001?ooool=0=7=Z@00303AcJUB000000X0dLfYDP00000:
0=7=ZE4000002`3AcJUA000000/0dLfYD@00000=0=7=Z@00303AcJUB000000X0dLfYDP00000:0=7=
ZE4000002`3AcJUA000000/0dLfYD@00000=0=7=Z@00303AcJUB000000X0dLfYDP00000:0=7=ZE40
00002`3AcJUA000000/0dLfYD@00000=0=7=Z@00303AcJUB000000X0dLfYDP00000:0=7=ZE400000
2`3AcJUA000000/0dLfYD@00000=0=7=Z@00o`3AcJWK0=7=Z@00o`3AcJWK0=7=Z@00o`3AcJWK0=7=
Z@00o`3AcJWK0=7=Z@00o`3AcJWK0=7=Z@00o`3AcJWK0=7=Z@00o`3AcJWK0=7=Z@00o`3AcJWK0=7=
Z@00o`3AcJWK0=7=Z@00o`3AcJWK0=7=Z@00o`3AcJWK0=7=Z@00o`3AcJWK0=7=Z@00303AcJUBoooo
o`X0dLfYD_ooool:0=7=ZE7ooooo2`3AcJUAooooo`/0dLfYDOooool=0=7=Z@00303AcJUBooooo`X0
dLfYD_ooool:0=7=ZE7ooooo2`3AcJUAooooo`/0dLfYDOooool=0=7=Z@00303AcJUBooooo`X0dLfY
D_ooool:0=7=ZE7ooooo2`3AcJUAooooo`/0dLfYDOooool=0=7=Z@00303AcJUBooooo`X0dLfYD_oo
ool:0=7=ZE7ooooo2`3AcJUAooooo`/0dLfYDOooool=0=7=Z@00303AcJUBooooo`X0dLfYD_ooool:
0=7=ZE7ooooo2`3AcJUAooooo`/0dLfYDOooool=0=7=Z@00303AcJUBooooo`X0dLfYD_ooool:0=7=
ZE7ooooo2`3AcJUAooooo`/0dLfYDOooool=0=7=Z@00303AcJUBooooo`X0dLfYD_ooool:0=7=ZE7o
oooo2`3AcJUAooooo`/0dLfYDOooool=0=7=Z@00303AcJUBooooo`X0dLfYD_ooool:0=7=ZE7ooooo
2`3AcJUAooooo`/0dLfYDOooool=0=7=Z@00303AcJUBooooo`X0dLfYD_ooool:0=7=ZE7ooooo2`3A
cJUAooooo`/0dLfYD@00000=0=7=Z@00303AcJUBooooo`X0dLfYD_ooool:0=7=ZE7ooooo2`3AcJUA
ooooo`/0dLfYD@00000=0=7=Z@00303AcJUBooooo`X0dLfYD_ooool:0=7=ZE7ooooo2`3AcJUA0000
00/0dLfYD@00000=0=7=Z@00303AcJUBooooo`X0dLfYD_ooool:0=7=ZE7ooooo2`3AcJUA000000/0
dLfYD@00000=0=7=Z@00303AcJUBooooo`X0dLfYD_ooool:0=7=ZE7ooooo2`3AcJUA000000/0dLfY
D@00000=0=7=Z@00303AcJUBooooo`X0dLfYD_ooool:0=7=ZE7ooooo2`3AcJUA000000/0dLfYD@00
000=0=7=Z@00303AcJUBooooo`X0dLfYD_ooool:0=7=ZE4000002`3AcJUA000000/0dLfYD@00000=
0=7=Z@00303AcJUBooooo`X0dLfYD_ooool:0=7=ZE4000002`3AcJUA000000/0dLfYD@00000=0=7=
Z@00303AcJUBooooo`X0dLfYD_ooool:0=7=ZE4000002`3AcJUA000000/0dLfY2?oooom1000000So
oooo3@3AcJT000`0dLfYD_ooool:0=7=ZE;ooooo2P3AcJUA000000/0dLfYD@00000;0=7=Z@Sooooo
@@000008ooooo`d0dLfY000<0=7=ZE;ooooo2P3AcJUBooooo`X0dLfYD@00000;0=7=ZE4000002`3A
cJT8oooood4000002?ooool=0=7=Z@00303AcJUBooooo`X0dLfYD_ooool:0=7=ZE4000002`3AcJUA
000000/0dLfY2?oooom1000000Sooooo3@3AcJT000`0dLfYD_ooool:0=7=ZE8000002P3AcJUA0000
00/0dLfY2_oooolm000000[ooooo2`3AcJT8oooood4000002?ooool=0=7=Z@00303AcJUBooooo`X0
dLfYDP00000:0=7=ZE4000002`3AcJT:ooooocd000002_ooool;0=7=Z@Sooooo@@000008ooooo`d0
dLfY000<0=7=ZE;ooooo2P3AcJUB000000X0dLfYD@00000;0=7=Z@[ooooo?@00000:ooooo`/0dLfY
2?oooom1000000Sooooo3@3AcJT000`0dLfYD_ooool:0=7=ZE8000002P3AcJUA000000/0dLfY2_oo
oolm000000[ooooo2`3AcJT8oooood4000002?ooool=0=7=Z@00303AcJUBooooo`X0dLfYDP00000:
0=7=ZE4000002`3AcJT:ooooocd000002_ooool;0=7=ZA000000<Oooool@000000d0dLfY000<0=7=
ZE;ooooo2P3AcJUB000000X0dLfYD@00000;0=7=Z@[ooooo?@00000:ooooo`/0dLfY4000000aoooo
oa0000003@3AcJT000`0dLfYD_ooool:0=7=ZE8000002P3AcJUA000000/0dLfY2_oooolm000000[o
oooo2`3AcJT@0000037ooooo4000000=0=7=Z@00303AcJUBooooo`X0dLfYDP00000:0=7=Z@kooooo
=P00000=ooooo`/0dLfY2_oooolm000000[ooooo2`3AcJT@0000037ooooo4000000=0=7=Z@00303A
cJUBooooo`X0dLfYDP00000:0=7=Z@kooooo=P00000=ooooo`/0dLfY2_oooolm000000[ooooo2`3A
cJT@0000037ooooo4000000=0=7=Z@00303AcJUBooooo`X0dLfYDP00000:0=7=Z@kooooo=P00000=
ooooo`/0dLfY2_oooolm000000[ooooo2`3AcJT@0000037ooooo4000000=0=7=Z@00303AcJUBoooo
o`X0dLfYDP00000:0=7=Z@kooooo=P00000=ooooo`/0dLfY5000000Yoooooa@000002`3AcJT@0000
037ooooo4000000=0=7=Z@00303AcJUBooooo`X0dLfYDP00000:0=7=Z@kooooo=P00000=ooooo`/0
dLfY5000000Yoooooa@000002`3AcJT@0000037ooooo4000000=0=7=Z@00303AcJUBooooo`X0dLfY
DP00000:0=7=Z@kooooo=P00000=ooooo`/0dLfY5000000Yoooooa@000002`3AcJT8oooooa000000
8Oooool@000000Sooooo3@3AcJT000`0dLfYD_ooool:0=7=ZE8000002P3AcJT>ooooocH000003Ooo
ool;0=7=ZA@00000:OoooolD000000/0dLfY2?ooool@0000027ooooo40000008ooooo`d0dLfY000<
0=7=ZE;ooooo2P3AcJUB000000X0dLfY3_oooolf000000gooooo2`3AcJTD000002Wooooo5000000;
0=7=Z@Sooooo4000000Qoooooa0000002?ooool=0=7=Z@00303AcJUBooooo`X0dLfYDP00000:0=7=
Z@kooooo=P00000=ooooo`/0dLfY5000000Yoooooa@000002`3AcJT8oooooa0000008Oooool@0000
00Sooooo3@3AcJT000`0dLfYD_ooool:0=7=ZE8000002P3AcJT>ooooocH000003Oooool;0=7=ZA@0
0000:OoooolD000000/0dLfY2?ooool@0000027ooooo40000008ooooo`d0dLfY000<0=7=ZE;ooooo
2P3AcJUB000000X0dLfY3_oooolf000000gooooo2`3AcJTD000002Wooooo5000000;0=7=Z@Sooooo
4000000Qoooooa0000002?ooool=0=7=Z@00303AcJUBooooo`X0dLfYDP00000:0=7=Z@kooooo=P00
000=ooooo`/0dLfY5000000Yoooooa@000002`3AcJT8oooooa0000008Oooool@000000Sooooo3@3A
cJT000`0dLfYD_ooool:0=7=ZE8000002P3AcJT>ooooocH000003Oooool;0=7=ZA@00000:OoooolD
000000/0dLfY2?ooool@0000027ooooo40000008ooooo`d0dLfY000<0=7=ZE8000002P3AcJTEoooo
obP000005Oooool:0=7=ZA/000006ooooolK000000/0dLfY2_oooolD000001Gooooo5000000:oooo
o`/0dLfY4000000@oooooa4000004?ooool@000000d0dLfY000<0=7=ZE8000002P3AcJTEooooobP0
00005Oooool:0=7=ZA/000006ooooolK000000/0dLfY2_oooolD000001Gooooo5000000:ooooo`/0
dLfY4000000@oooooa4000004?ooool@000000d0dLfY000<0=7=ZE8000002P3AcJTEooooobP00000
5Oooool:0=7=ZA/000006ooooolK000000/0dLfY2_oooolD000001Gooooo5000000:ooooo`/0dLfY
4000000@oooooa4000004?ooool@000000d0dLfY000<0=7=ZE8000002P3AcJTEooooobP000005Ooo
ool:0=7=ZA/000006ooooolK000000/0dLfY2_oooolD000001Gooooo5000000:ooooo`/0dLfY4000
000@oooooa4000004?ooool@000000d0dLfY000<0=7=ZE8000002P3AcJTEooooobP000005Oooool:
0=7=ZA/000006ooooolK000000/0dLfY2_oooolD000001Gooooo5000000:ooooo`/0dLfY4000000@
oooooa4000004?ooool@000000d0dLfY000<0=7=ZE8000002P3AcJTEooooobP000005Oooool:0=7=
ZA/000006ooooolK000000/0dLfY2_oooolD000001Gooooo5000000:ooooo`/0dLfY4000000@oooo
oa4000004?ooool@000000d0dLfY000<0=7=ZE8000002P3AcJTEooooobP000005Oooool:0=7=ZA/0
00006ooooolK000000/0dLfY2_oooolD000001Gooooo5000000:ooooo`/0dLfY4000000@oooooa40
00004?ooool@000000d0dLfY000<0=7=ZE8000002P3AcJTEooooobP000005Oooool:0=7=ZA/00000
6ooooolK000000/0dLfY2_oooolD000001Gooooo5000000:ooooo`/0dLfY4000000@oooooa400000
4?ooool@000000d0dLfY000<0=7=ZE8000002P3AcJTEooooobP000005Oooool:0=7=ZA/000006ooo
oolK000000/0dLfY2_oooolD000001Gooooo5000000:ooooo`/0dLfY2?ooool@0000027ooooo4000
0008ooooo`d0dLfY000<0=7=ZE8000002P3AcJTEooooobP000005Oooool:0=7=ZA/000006ooooolK
000000/0dLfY2_oooolD000001Gooooo5000000:ooooo`/0dLfY2?ooool@0000027ooooo40000008
ooooo`d0dLfY000<0=7=ZE8000002P3AcJTEooooobP000005Oooool:0=7=ZA/000006ooooolK0000
00/0dLfY5000000Yoooooa@000002`3AcJT8oooooa0000008Oooool@000000Sooooo3@3AcJT000`0
dLfYDP00000:0=7=ZAGooooo:000000Eooooo`X0dLfY6`00000Koooooa/000002`3AcJTD000002Wo
oooo5000000;0=7=Z@Sooooo4000000Qoooooa0000002?ooool=0=7=Z@00303AcJUB000000X0dLfY
5OoooolX000001Gooooo2P3AcJTK000001_ooooo6`00000;0=7=ZA@00000:OoooolD000000/0dLfY
2?ooool@0000027ooooo40000008ooooo`d0dLfY000<0=7=ZE8000002P3AcJTEooooobP000005Ooo
ool:0=7=Z@kooooo=P00000=ooooo`/0dLfY5000000Yoooooa@000002`3AcJT8oooooa0000008Ooo
ool@000000Sooooo3@3AcJT000`0dLfYDP00000:0=7=ZAGooooo:000000Eooooo`X0dLfY3_oooolf
000000gooooo2`3AcJTD000002Wooooo5000000;0=7=Z@Sooooo4000000Qoooooa0000002?ooool=
0=7=Z@00303AcJUB000000X0dLfY5OoooolX000001Gooooo2P3AcJT>ooooocH000003Oooool;0=7=
ZA@00000:OoooolD000000/0dLfY2?ooool@0000027ooooo40000008ooooo`d0dLfY000<0=7=ZE80
00002P3AcJTEooooobP000005Oooool:0=7=Z@kooooo=P00000=ooooo`/0dLfY5000000Yoooooa@0
00002`3AcJT@0000037ooooo4000000=0=7=Z@00303AcJUB000000X0dLfY5OoooolX000001Gooooo
2P3AcJT>ooooocH000003Oooool;0=7=ZA@00000:OoooolD000000/0dLfY4000000aoooooa000000
3@3AcJT000`0dLfYDP00000:0=7=ZAGooooo:000000Eooooo`X0dLfY3_oooolf000000gooooo2`3A
cJTD000002Wooooo5000000;0=7=ZA000000<Oooool@000000d0dLfY000<0=7=ZE8000002P3AcJTE
ooooobP000005Oooool:0=7=Z@kooooo=P00000=ooooo`/0dLfY5000000Yoooooa@000002`3AcJT@
0000037ooooo4000000=0=7=Z@00303AcJUB000000X0dLfYDP00000:0=7=Z@kooooo=P00000=oooo
o`/0dLfY2_oooolm000000[ooooo2`3AcJT@0000037ooooo4000000=0=7=Z@00303AcJUB000000X0
dLfYDP00000:0=7=Z@kooooo=P00000=ooooo`/0dLfY2_oooolm000000[ooooo2`3AcJT@0000037o
oooo4000000=0=7=Z@00303AcJUB000000X0dLfYDP00000:0=7=Z@kooooo=P00000=ooooo`/0dLfY
2_oooolm000000[ooooo2`3AcJT@0000037ooooo4000000=0=7=Z@00303AcJUB000000X0dLfYDP00
000:0=7=Z@kooooo=P00000=ooooo`/0dLfY2_oooolm000000[ooooo2`3AcJT@0000037ooooo4000
000=0=7=Z@00303AcJUB000000X0dLfYDP00000:0=7=Z@kooooo=P00000=ooooo`/0dLfY2_oooolm
000000[ooooo2`3AcJT8oooood4000002?ooool=0=7=Z@00303AcJUB000000X0dLfYDP00000:0=7=
Z@kooooo=P00000=ooooo`/0dLfY2_oooolm000000[ooooo2`3AcJT8oooood4000002?ooool=0=7=
Z@00303AcJUB000000X0dLfYDP00000:0=7=ZE4000002`3AcJT:ooooocd000002_ooool;0=7=Z@So
oooo@@000008ooooo`d0dLfY000<0=7=ZE8000002P3AcJUB000000X0dLfYD@00000;0=7=Z@[ooooo
?@00000:ooooo`/0dLfY2?oooom1000000Sooooo3@3AcJT000`0dLfYDP00000:0=7=ZE8000002P3A
cJUA000000/0dLfY2_oooolm000000[ooooo2`3AcJT8oooood4000002?ooool=0=7=Z@00303AcJUB
000000X0dLfYDP00000:0=7=ZE4000002`3AcJT:ooooocd000002_ooool;0=7=Z@Sooooo@@000008
ooooo`d0dLfY000<0=7=ZE8000002P3AcJUB000000X0dLfYD@00000;0=7=ZE4000002`3AcJT8oooo
od4000002?ooool=0=7=Z@00303AcJUB000000X0dLfYDP00000:0=7=ZE4000002`3AcJUA000000/0
dLfY2?oooom1000000Sooooo3@3AcJT000`0dLfYDP00000:0=7=ZE8000002P3AcJUA000000/0dLfY
D@00000;0=7=ZE4000003@3AcJT000`0dLfYDP00000:0=7=ZE8000002P3AcJUA000000/0dLfYD@00
000;0=7=ZE4000003@3AcJT000`0dLfYDP00000:0=7=ZE8000002P3AcJUA000000/0dLfYD@00000;
0=7=ZE4000003@3AcJT000`0dLfYDP00000:0=7=ZE8000002P3AcJUA000000/0dLfYD@00000;0=7=
ZE4000003@3AcJT000`0dLfYDP00000:0=7=ZE8000002P3AcJUA000000/0dLfYD@00000;0=7=ZE40
00003@3AcJT000`0dLfYDP00000:0=7=ZE8000002P3AcJUA000000/0dLfYD@00000;0=7=ZE400000
3@3AcJT000`0dLfYDP00000:0=7=ZE8000002P3AcJUA000000/0dLfYD@00000;0=7=ZE4000003@3A
cJT000`0dLfYDP00000:0=7=ZE8000002P3AcJUA000000/0dLfYD@00000;0=7=ZE4000003@3AcJT0
0?l0dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0dLfYf`3AcJT0
0?l0dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0dLfYf`3AcJT0
0?l0dLfYf`3AcJT00?l0dLfYf`3AcJT00?l0dLfYf`3AcJT00001\
\>"],
  ImageRangeCache->{{{0, 473.5}, {473.5, 0}} -> {-0.125026, -0.125026, \
0.0110878, 0.0110878}, {{11.25, 94.75}, {462.188, 378.688}} -> {-6.7253, \
-6.758, 0.523118, 0.523118}, {{103.125, 186.625}, {462.188, 378.688}} -> \
{-57.3959, -7.07983, 0.548031, 0.548031}, {{194.938, 278.5}, {462.188, \
378.688}} -> {-112.626, -7.40163, 0.57294, 0.57294}, {{286.813, 370.313}, \
{462.188, 378.688}} -> {-172.431, -7.72341, 0.597849, 0.597849}, {{378.688, \
462.188}, {462.188, 378.688}} -> {-236.832, -8.04523, 0.62276, 0.62276}, \
{{11.25, 94.75}, {370.313, 286.813}} -> {-5.12404, -41.7673, 0.398567, \
0.398567}, {{103.125, 186.625}, {370.313, 286.813}} -> {-44.3513, -44.3778, \
0.423478, 0.423478}, {{194.938, 278.5}, {370.313, 286.813}} -> {-88.1418, \
-46.9882, 0.448388, 0.448388}, {{286.813, 370.313}, {370.313, 286.813}} -> \
{-136.508, -49.5987, 0.473299, 0.473299}, {{378.688, 462.188}, {370.313, \
286.813}} -> {-189.465, -52.209, 0.498208, 0.498208}, {{11.25, 94.75}, \
{278.5, 194.938}} -> {-3.52278, -53.8815, 0.274015, 0.274015}, {{103.125, \
186.625}, {278.5, 194.938}} -> {-31.3068, -58.7799, 0.298925, 0.298925}, \
{{194.938, 278.5}, {278.5, 194.938}} -> {-63.6007, -63.6209, 0.323594, \
0.323594}, {{286.813, 370.313}, {278.5, 194.938}} -> {-100.585, -68.5764, \
0.348746, 0.348746}, {{378.688, 462.188}, {278.5, 194.938}} -> {-142.099, \
-73.4748, 0.373656, 0.373656}, {{11.25, 94.75}, {186.625, 103.125}} -> \
{-1.92152, -43.1171, 0.149463, 0.149463}, {{103.125, 186.625}, {186.625, \
103.125}} -> {-18.2623, -50.3033, 0.174373, 0.174373}, {{194.938, 278.5}, \
{186.625, 103.125}} -> {-39.1741, -57.4895, 0.199283, 0.199283}, {{286.813, \
370.313}, {186.625, 103.125}} -> {-64.6617, -64.6757, 0.224194, 0.224194}, \
{{378.688, 462.188}, {186.625, 103.125}} -> {-94.7328, -71.8619, 0.249104, \
0.249104}, {{11.25, 94.75}, {94.75, 11.25}} -> {-0.320253, -9.47484, \
0.0249104, 0.0249104}, {{103.125, 186.625}, {94.75, 11.25}} -> {-5.21779, \
-18.9496, 0.0498208, 0.0498208}, {{194.938, 278.5}, {94.75, 11.25}} -> \
{-14.6903, -28.4246, 0.0747315, 0.0747315}, {{286.813, 370.313}, {94.75, \
11.25}} -> {-28.7386, -37.8994, 0.099642, 0.099642}, {{378.688, 462.188}, \
{94.75, 11.25}} -> {-47.3664, -47.3742, 0.124552, 0.124552}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["KNIGHTS DOMAINS", "Subsection"],

Cell["\<\
If instead of changing the neighbor squares when we touch a square we change \
those that are at a knight-move of distance, we obtain the following table:\
\>", "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.01852 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.04806 0.190476 [
[ 0 0 0 0 ]
[ 1 2.01852 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 2.01852 L
0 2.01852 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.04806 0.200176 0.224427 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0204583 0.0192308 0.0204583 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
47 string
47 47 8 [47 0 0 47 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000FF00FF00FF0000FF00FF0000FFFF00FFFF00FF000000FF00FFFF00FFFF0000FF00
FF0000FF00FF00FF000000
000000FF000000FF0000000000FFFFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFFFF0000
000000FF000000FF000000
00000000FF000000FF0000FFFFFF000000FFFF00FF0000000000FF00FFFF000000FFFFFF
0000FF000000FF00000000
FFFF00000000000000FF0000FFFF00FFFF00FFFFFF00FF00FF00FFFFFF00FFFF00FFFF00
00FF00000000000000FFFF
0000FF0000FF00FFFFFFFF00FF00FF000000000000FFFF00FFFF000000000000FF00FF00
FFFFFFFF00FF0000FF0000
FF000000FF0000000000FF00FF000000FF00FF000000000000000000FF00FF000000FF00
FF0000000000FF000000FF
00000000000000FFFFFFFFFF00FF00FFFF00000000FFFF00FFFF00000000FFFF00FF00FF
FFFFFFFF00000000000000
FFFF0000FF00FF0000FFFF00FFFF00FF0000FFFFFF00FF00FF00FFFFFF0000FF00FFFF00
FFFF0000FF00FF0000FFFF
0000FF00FF00FF000000FF00000000FFFF00FF00FF0000000000FF00FF00FFFF00000000
FF000000FF00FF00FF0000
000000FFFF00FFFF0000000000FFFFFF00000000FFFFFF00FFFFFF00000000FFFFFF0000
000000FFFF00FFFF000000
FF000000FFFFFFFFFF000000000000FF00FF0000FFFFFF00FFFFFF0000FF00FF00000000
0000FFFFFFFFFF000000FF
0000FF000000FF0000000000000000000000FF00FF0000000000FF00FF00000000000000
00000000FF000000FF0000
FF00FFFFFFFF00FF0000000000FFFF0000FF00FFFF00FF00FF00FFFF00FF0000FFFF0000
000000FF00FFFFFFFF00FF
00FFFFFF0000FFFF00FF0000FF00FF00FF00FFFFFFFF000000FFFFFFFF00FF00FF00FF00
00FF00FFFF0000FFFFFF00
00FF0000FF00000000FF0000FFFF00FF00000000FF0000000000FF00000000FF00FFFF00
00FF00000000FF0000FF00
FFFF00FF0000FFFFFFFFFF000000FF000000FFFFFFFF000000FFFFFFFF000000FF000000
FFFFFFFFFF0000FF00FFFF
FFFF00FF00FFFF00FF00000000FF000000FF0000FF00FF00FF00FF0000FF000000FF0000
0000FF00FFFF00FF00FFFF
0000FF00000000000000FF00FF000000FF00000000000000000000000000FF000000FF00
FF00000000000000FF0000
FFFFFFFF00FF00FFFF0000FF00FF00FF000000000000000000000000000000FF00FF00FF
0000FFFF00FF00FFFFFFFF
FF0000FF000000FF00000000FFFF00FF00000000FFFF000000FFFF00000000FF00FFFF00
000000FF000000FF0000FF
00FFFFFF000000FFFFFFFFFFFFFFFFFFFF0000FF00FF000000FF00FF0000FFFFFFFFFFFF
FFFFFFFF000000FFFFFF00
FFFF0000FF00FF0000FFFF0000FF00FF000000FFFF00FF00FF00FFFF000000FF00FF0000
FFFF0000FF00FF0000FFFF
00FF00FFFF00FFFF00FFFF00FF000000FF00000000FF000000FF00000000FF000000FF00
FFFF00FFFF00FFFF00FF00
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000
00FF00FFFF00FFFF00FFFF00FF000000FF00000000FF000000FF00000000FF000000FF00
FFFF00FFFF00FFFF00FF00
FFFF0000FF00FF0000FFFF0000FF00FF000000FFFF00FF00FF00FFFF000000FF00FF0000
FFFF0000FF00FF0000FFFF
00FFFFFF000000FFFFFFFFFFFFFFFFFFFF0000FF00FF000000FF00FF0000FFFFFFFFFFFF
FFFFFFFF000000FFFFFF00
FF0000FF000000FF00000000FFFF00FF00000000FFFF000000FFFF00000000FF00FFFF00
000000FF000000FF0000FF
FFFFFFFF00FF00FFFF0000FF00FF00FF000000000000000000000000000000FF00FF00FF
0000FFFF00FF00FFFFFFFF
0000FF00000000000000FF00FF000000FF00000000000000000000000000FF000000FF00
FF00000000000000FF0000
FFFF00FF00FFFF00FF00000000FF000000FF0000FF00FF00FF00FF0000FF000000FF0000
0000FF00FFFF00FF00FFFF
FFFF00FF0000FFFFFFFFFF000000FF000000FFFFFFFF000000FFFFFFFF000000FF000000
FFFFFFFFFF0000FF00FFFF
00FF0000FF00000000FF0000FFFF00FF00000000FF0000000000FF00000000FF00FFFF00
00FF00000000FF0000FF00
00FFFFFF0000FFFF00FF0000FF00FF00FF00FFFFFFFF000000FFFFFFFF00FF00FF00FF00
00FF00FFFF0000FFFFFF00
FF00FFFFFFFF00FF0000000000FFFF0000FF00FFFF00FF00FF00FFFF00FF0000FFFF0000
000000FF00FFFFFFFF00FF
0000FF000000FF0000000000000000000000FF00FF0000000000FF00FF00000000000000
00000000FF000000FF0000
FF000000FFFFFFFFFF000000000000FF00FF0000FFFFFF00FFFFFF0000FF00FF00000000
0000FFFFFFFFFF000000FF
000000FFFF00FFFF0000000000FFFFFF00000000FFFFFF00FFFFFF00000000FFFFFF0000
000000FFFF00FFFF000000
0000FF00FF00FF000000FF00000000FFFF00FF00FF0000000000FF00FF00FFFF00000000
FF000000FF00FF00FF0000
FFFF0000FF00FF0000FFFF00FFFF00FF0000FFFFFF00FF00FF00FFFFFF0000FF00FFFF00
FFFF0000FF00FF0000FFFF
00000000000000FFFFFFFFFF00FF00FFFF00000000FFFF00FFFF00000000FFFF00FF00FF
FFFFFFFF00000000000000
FF000000FF0000000000FF00FF000000FF00FF000000000000000000FF00FF000000FF00
FF0000000000FF000000FF
0000FF0000FF00FFFFFFFF00FF00FF000000000000FFFF00FFFF000000000000FF00FF00
FFFFFFFF00FF0000FF0000
FFFF00000000000000FF0000FFFF00FFFF00FFFFFF00FF00FF00FFFFFF00FFFF00FFFF00
00FF00000000000000FFFF
00000000FF000000FF0000FFFFFF000000FFFF00FF0000000000FF00FFFF000000FFFFFF
0000FF000000FF00000000
000000FF000000FF0000000000FFFFFFFF00FF00FFFFFF00FFFFFF00FF00FFFFFFFF0000
000000FF000000FF000000
000000FF00FF00FF0000FF00FF0000FFFF00FFFF00FF000000FF00FFFF00FFFF0000FF00
FF0000FF00FF00FF000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.04806 0.39418 0.224427 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0200321 0.0192308 0.0200321 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
48 string
48 48 8 [48 0 0 48 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00FFFF00FF0000FFFFFFFF00FF00FF0000000000000000000000000000FF00FF00FF
FFFFFF0000FF00FFFF00FF00
FF00FF0000FF00FFFF00FFFF00FF00FF00FF000000000000000000000000FF00FF00FF00
FFFF00FFFF00FF0000FF00FF
00FF00000000FF0000FFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF
FFFFFF0000FF00000000FF00
FF000000000000FFFF00FFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFF00FFFF
FFFF00FFFF000000000000FF
FF000000000000FF00000000FF0000FF00FF00FF000000FFFF000000FF00FF00FF0000FF
00000000FF000000000000FF
00FF00000000FF000000000000FFFF00FF00FF000000FF0000FF000000FF00FF00FFFF00
0000000000FF00000000FF00
FF00FF0000FF000000FFFFFFFF00FF00FF0000FF00FFFFFFFFFFFF00FF0000FF00FF00FF
FFFFFF000000FF0000FF00FF
00FF00FFFF000000FF00FFFF00FF00FF00FFFF00FF00FFFFFFFF00FF00FFFF00FF00FF00
FFFF00FF000000FFFF00FF00
00FF00FF000000FF0000000000FFFF000000FF00FFFFFFFFFFFFFFFF00FF000000FFFF00
00000000FF000000FF00FF00
FF00FF000000FF0000000000FF0000FF000000FFFFFFFFFFFFFFFFFFFF000000FF0000FF
0000000000FF000000FF00FF
FFFFFFFF0000FFFF00000000FF00FF00FFFFFFFFFFFF00000000FFFFFFFFFFFF00FF00FF
00000000FFFF0000FFFFFFFF
FFFFFFFF0000FFFF0000000000FF00FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF00FF00
00000000FFFF0000FFFFFFFF
FF00FFFFFF00FF0000FFFF000000FF0000000000000000FFFF0000000000000000FF0000
00FFFF0000FF00FFFFFF00FF
00FFFFFF00FF00FFFF0000FF000000FF000000000000FF0000FF000000000000FF000000
FF0000FFFF00FF00FFFFFF00
FF00FF0000FFFF00FF00FF00FF0000000000FF00FF00FF0000FF00FF00FF0000000000FF
00FF00FF00FFFF0000FF00FF
00FF00FFFF0000FF00FF00FF00FF0000000000FF00FF00FFFF00FF00FF0000000000FF00
FF00FF00FF0000FFFF00FF00
FF00FFFF00FFFF000000FFFF00000000000000FFFFFFFF0000FFFFFFFF00000000000000
FFFF000000FFFF00FFFF00FF
00FFFFFFFF0000FF0000FFFF000000000000FF00FFFF00FFFF00FFFF00FF000000000000
FFFF0000FF0000FFFFFFFF00
000000FF00FF00FFFF00FFFF0000FF0000FF0000FF00FF0000FF00FF0000FF0000FF0000
FFFF00FFFF00FF00FF000000
0000FF00FF00FF0000FFFFFF000000FFFF00000000FF00FFFF00FF00000000FFFF000000
FFFFFF0000FF00FF00FF0000
0000FFFF000000FFFFFFFFFF0000FF00FFFFFF00000000FFFF00000000FFFFFF00FF0000
FFFFFFFFFF000000FFFF0000
0000FFFF0000FF00FFFFFFFF000000FFFFFF00FF0000FF0000FF0000FF00FFFFFF000000
FFFFFFFF00FF0000FFFF0000
0000FFFF00FFFFFFFFFF000000FFFF00FF00FF0000FF00000000FF0000FF00FF00FFFF00
0000FFFFFFFFFF00FFFF0000
0000FFFFFF00FFFFFFFF0000FF0000FF00FF00FFFF000000000000FFFF00FF00FF0000FF
0000FFFFFFFF00FFFFFF0000
0000FFFFFF00FFFFFFFF0000FF0000FF00FF00FFFF000000000000FFFF00FF00FF0000FF
0000FFFFFFFF00FFFFFF0000
0000FFFF00FFFFFFFFFF000000FFFF00FF00FF0000FF00000000FF0000FF00FF00FFFF00
0000FFFFFFFFFF00FFFF0000
0000FFFF0000FF00FFFFFFFF000000FFFFFF00FF0000FF0000FF0000FF00FFFFFF000000
FFFFFFFF00FF0000FFFF0000
0000FFFF000000FFFFFFFFFF0000FF00FFFFFF00000000FFFF00000000FFFFFF00FF0000
FFFFFFFFFF000000FFFF0000
0000FF00FF00FF0000FFFFFF000000FFFF00000000FF00FFFF00FF00000000FFFF000000
FFFFFF0000FF00FF00FF0000
000000FF00FF00FFFF00FFFF0000FF0000FF0000FF00FF0000FF00FF0000FF0000FF0000
FFFF00FFFF00FF00FF000000
00FFFFFFFF0000FF0000FFFF000000000000FF00FFFF00FFFF00FFFF00FF000000000000
FFFF0000FF0000FFFFFFFF00
FF00FFFF00FFFF000000FFFF00000000000000FFFFFFFF0000FFFFFFFF00000000000000
FFFF000000FFFF00FFFF00FF
00FF00FFFF0000FF00FF00FF00FF0000000000FF00FF00FFFF00FF00FF0000000000FF00
FF00FF00FF0000FFFF00FF00
FF00FF0000FFFF00FF00FF00FF0000000000FF00FF00FF0000FF00FF00FF0000000000FF
00FF00FF00FFFF0000FF00FF
00FFFFFF00FF00FFFF0000FF000000FF000000000000FF0000FF000000000000FF000000
FF0000FFFF00FF00FFFFFF00
FF00FFFFFF00FF0000FFFF000000FF0000000000000000FFFF0000000000000000FF0000
00FFFF0000FF00FFFFFF00FF
FFFFFFFF0000FFFF0000000000FF00FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF00FF00
00000000FFFF0000FFFFFFFF
FFFFFFFF0000FFFF00000000FF00FF00FFFFFFFFFFFF00000000FFFFFFFFFFFF00FF00FF
00000000FFFF0000FFFFFFFF
FF00FF000000FF0000000000FF0000FF000000FFFFFFFFFFFFFFFFFFFF000000FF0000FF
0000000000FF000000FF00FF
00FF00FF000000FF0000000000FFFF000000FF00FFFFFFFFFFFFFFFF00FF000000FFFF00
00000000FF000000FF00FF00
00FF00FFFF000000FF00FFFF00FF00FF00FFFF00FF00FFFFFFFF00FF00FFFF00FF00FF00
FFFF00FF000000FFFF00FF00
FF00FF0000FF000000FFFFFFFF00FF00FF0000FF00FFFFFFFFFFFF00FF0000FF00FF00FF
FFFFFF000000FF0000FF00FF
00FF00000000FF000000000000FFFF00FF00FF000000FF0000FF000000FF00FF00FFFF00
0000000000FF00000000FF00
FF000000000000FF00000000FF0000FF00FF00FF000000FFFF000000FF00FF00FF0000FF
00000000FF000000000000FF
FF000000000000FFFF00FFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFF00FFFFFFFF00FFFF
FFFF00FFFF000000000000FF
00FF00000000FF0000FFFFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF
FFFFFF0000FF00000000FF00
FF00FF0000FF00FFFF00FFFF00FF00FF00FF000000000000000000000000FF00FF00FF00
FFFF00FFFF00FF0000FF00FF
00FF00FFFF00FF0000FFFFFFFF00FF00FF0000000000000000000000000000FF00FF00FF
FFFFFF0000FF00FFFF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.04806 0.588183 0.224427 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0196232 0.0192308 0.0196232 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
49 string
49 49 8 [49 0 0 49 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00FF000000FFFF000000FFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFF
FF000000FFFF000000FF00FF00
FF00FF0000000000FF0000000000FF00FFFFFF00FF00FF000000FF00FF00FFFFFF00FF00
00000000FF0000000000FF00FF
00FF0000FFFFFF0000FF00000000FF00FF0000FF0000FF000000FF0000FF0000FF00FF00
000000FF0000FFFFFF0000FF00
FF000000FFFFFFFFFFFF00FF00FFFF00FF00FFFFFFFF00FF00FF00FFFFFFFF00FF00FFFF
00FF00FFFFFFFFFFFF000000FF
0000FFFF00FF0000FF00FF0000FFFF0000FF00FFFF00FFFF00FFFF00FFFF00FF0000FFFF
0000FF00FF0000FF00FFFF0000
0000FFFFFF00FFFF000000FFFF00FF00FF00FF00FFFFFF000000FFFFFF00FF00FF00FF00
FFFF000000FFFF00FFFFFF0000
0000FFFF00FF00FFFFFFFFFFFFFFFFFF00FFFF0000FFFF000000FFFF0000FFFF00FFFFFF
FFFFFFFFFFFF00FF00FFFF0000
FF0000FF00FFFF00FF0000FF0000FFFFFFFFFF0000000000000000000000FFFFFFFFFF00
00FF0000FF00FFFF00FF0000FF
FFFF00FFFF00FFFF000000FF00FFFF0000FF00FFFFFF0000000000FFFFFF00FF0000FFFF
00FF000000FFFF00FFFF00FFFF
0000FFFF0000FF00000000FFFFFF00FFFFFF00FF0000FF000000FF0000FF00FFFFFF00FF
FFFF00000000FF0000FFFF0000
00000000FF00FF000000000000FFFFFFFFFF00000000FFFF00FFFF00000000FFFFFFFFFF
000000000000FF00FF00000000
000000FF00FFFFFFFFFF0000FF00FF0000FFFF0000FF00FF00FF00FF0000FFFF0000FF00
FF0000FFFFFFFFFF00FF000000
FF00000000FFFF0000FF00FF000000FFFFFF00000000FF000000FF00000000FFFFFF0000
00FF00FF0000FFFF00000000FF
FF0000FFFF00FF00FFFFFF00000000FF000000FF0000FF000000FF0000FF000000FF0000
0000FFFFFF00FF00FFFF0000FF
FFFFFFFFFFFFFFFFFF00FFFF000000FF000000FF00FFFFFF00FFFFFF00FF000000FF0000
00FFFF00FFFFFFFFFFFFFFFFFF
FF0000000000FFFF00FFFF00FFFFFF0000FF00FF000000FF00FF000000FF00FF0000FFFF
FF00FFFF00FFFF0000000000FF
00FFFFFF00FF00FF00FFFF00FF00000000FF000000FFFF000000FFFF000000FF00000000
FF00FFFF00FF00FF00FFFFFF00
FFFF0000FF00FFFFFFFFFFFFFF0000FFFF0000FF0000FF000000FF0000FF0000FFFF0000
FFFFFFFFFFFFFF00FF0000FFFF
FFFF00FF00FFFFFF000000FF0000000000000000FFFF0000000000FFFF00000000000000
00FF000000FFFFFF00FF00FFFF
FF00FFFFFF000000FFFF000000FFFFFF00FF0000000000FF00FF0000000000FF00FFFFFF
000000FFFF000000FFFFFF00FF
FFFF00FFFFFF0000FF000000000000000000FF0000FF0000000000FF0000FF0000000000
00000000FF0000FFFFFF00FFFF
FF0000FF00FFFF00FF0000FF0000FF00FF00FF00FF0000FF00FF0000FF00FF00FF00FF00
00FF0000FF00FFFF00FF0000FF
FFFFFF00FFFFFF0000FFFF00FFFFFF00FFFF00000000000000000000000000FFFF00FFFF
FF00FFFF0000FFFFFF00FFFFFF
FF0000FFFF0000000000FFFF0000FFFF000000FF00FF0000000000FF00FF000000FFFF00
00FFFF0000000000FFFF0000FF
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000
FF0000FFFF0000000000FFFF0000FFFF000000FF00FF0000000000FF00FF000000FFFF00
00FFFF0000000000FFFF0000FF
FFFFFF00FFFFFF0000FFFF00FFFFFF00FFFF00000000000000000000000000FFFF00FFFF
FF00FFFF0000FFFFFF00FFFFFF
FF0000FF00FFFF00FF0000FF0000FF00FF00FF00FF0000FF00FF0000FF00FF00FF00FF00
00FF0000FF00FFFF00FF0000FF
FFFF00FFFFFF0000FF000000000000000000FF0000FF0000000000FF0000FF0000000000
00000000FF0000FFFFFF00FFFF
FF00FFFFFF000000FFFF000000FFFFFF00FF0000000000FF00FF0000000000FF00FFFFFF
000000FFFF000000FFFFFF00FF
FFFF00FF00FFFFFF000000FF0000000000000000FFFF0000000000FFFF00000000000000
00FF000000FFFFFF00FF00FFFF
FFFF0000FF00FFFFFFFFFFFFFF0000FFFF0000FF0000FF000000FF0000FF0000FFFF0000
FFFFFFFFFFFFFF00FF0000FFFF
00FFFFFF00FF00FF00FFFF00FF00000000FF000000FFFF000000FFFF000000FF00000000
FF00FFFF00FF00FF00FFFFFF00
FF0000000000FFFF00FFFF00FFFFFF0000FF00FF000000FF00FF000000FF00FF0000FFFF
FF00FFFF00FFFF0000000000FF
FFFFFFFFFFFFFFFFFF00FFFF000000FF000000FF00FFFFFF00FFFFFF00FF000000FF0000
00FFFF00FFFFFFFFFFFFFFFFFF
FF0000FFFF00FF00FFFFFF00000000FF000000FF0000FF000000FF0000FF000000FF0000
0000FFFFFF00FF00FFFF0000FF
FF00000000FFFF0000FF00FF000000FFFFFF00000000FF000000FF00000000FFFFFF0000
00FF00FF0000FFFF00000000FF
000000FF00FFFFFFFFFF0000FF00FF0000FFFF0000FF00FF00FF00FF0000FFFF0000FF00
FF0000FFFFFFFFFF00FF000000
00000000FF00FF000000000000FFFFFFFFFF00000000FFFF00FFFF00000000FFFFFFFFFF
000000000000FF00FF00000000
0000FFFF0000FF00000000FFFFFF00FFFFFF00FF0000FF000000FF0000FF00FFFFFF00FF
FFFF00000000FF0000FFFF0000
FFFF00FFFF00FFFF000000FF00FFFF0000FF00FFFFFF0000000000FFFFFF00FF0000FFFF
00FF000000FFFF00FFFF00FFFF
FF0000FF00FFFF00FF0000FF0000FFFFFFFFFF0000000000000000000000FFFFFFFFFF00
00FF0000FF00FFFF00FF0000FF
0000FFFF00FF00FFFFFFFFFFFFFFFFFF00FFFF0000FFFF000000FFFF0000FFFF00FFFFFF
FFFFFFFFFFFF00FF00FFFF0000
0000FFFFFF00FFFF000000FFFF00FF00FF00FF00FFFFFF000000FFFFFF00FF00FF00FF00
FFFF000000FFFF00FFFFFF0000
0000FFFF00FF0000FF00FF0000FFFF0000FF00FFFF00FFFF00FFFF00FFFF00FF0000FFFF
0000FF00FF0000FF00FFFF0000
FF000000FFFFFFFFFFFF00FF00FFFF00FF00FFFFFFFF00FF00FF00FFFFFFFF00FF00FFFF
00FF00FFFFFFFFFFFF000000FF
00FF0000FFFFFF0000FF00000000FF00FF0000FF0000FF000000FF0000FF0000FF00FF00
000000FF0000FFFFFF0000FF00
FF00FF0000000000FF0000000000FF00FFFFFF00FF00FF000000FF00FF00FFFFFF00FF00
00000000FF0000000000FF00FF
00FF00FF000000FFFF000000FFFFFFFF00FFFFFFFFFFFFFF00FFFFFFFFFFFFFF00FFFFFF
FF000000FFFF000000FF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.04806 0.782187 0.224427 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0192308 0.0192308 0.0192308 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
50 string
50 50 8 [50 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00FFFF00FFFFFF00FF000000FFFFFF00000000FF0000FFFF0000FF00000000FFFFFF
000000FF00FFFFFF00FFFF00FF00
FF00FF0000FFFFFF00FF00FF0000FFFF00FF0000FF000000FFFF000000FF0000FF00FFFF
0000FF00FF00FFFFFF0000FF00FF
00FF000000FFFF00000000FFFF00FFFFFFFF0000FF000000FFFF000000FF0000FFFFFFFF
00FFFF00000000FFFF000000FF00
FF000000FF0000FF0000FF0000FFFFFFFFFF000000FF0000FFFF0000FF000000FFFFFFFF
FF0000FF0000FF0000FF000000FF
FF0000FF0000FFFFFF000000000000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
0000000000FFFFFF0000FF0000FF
00FFFF000000FFFF00FF00000000FF00FF00FF00FFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00000000FF00FFFF000000FFFF00
FFFFFF00FFFF0000FFFFFF000000FFFF0000FF0000FFFFFFFFFFFFFFFF0000FF0000FFFF
000000FFFFFF0000FFFF00FFFFFF
FFFF00FFFFFF0000FFFF00FF0000FFFF000000FFFF00FFFFFFFFFFFF00FFFF000000FFFF
0000FF00FFFF0000FFFFFF00FFFF
FF000000FF00FFFF00000000000000FFFF00FF00FFFFFF00FFFF00FFFFFF00FF00FFFF00
000000000000FFFF00FF000000FF
00FF000000FFFFFF000000000000FF0000FF00FFFFFF00FFFFFFFF00FFFFFF00FF0000FF
000000000000FFFFFF000000FF00
FF0000FF0000FF00000000000000FFFF00FF0000FFFFFF00000000FFFFFF0000FF00FFFF
00000000000000FF0000FF0000FF
00FFFF00000000FF000000000000FFFFFF000000FFFF00FF0000FF00FFFF000000FFFFFF
000000000000FF00000000FFFF00
0000FF0000000000000000000000FFFF0000FFFF00FF0000FFFF0000FF00FFFF0000FFFF
0000000000000000000000FF0000
000000FF00000000000000000000FFFF0000FFFFFF000000FFFF000000FFFFFF0000FFFF
00000000000000000000FF000000
FFFFFFFF00FFFFFF00FFFFFFFFFF000000FFFF000000FF00000000FF000000FFFF000000
FFFFFFFFFF00FFFFFF00FFFFFFFF
FFFFFFFFFF00FFFFFF00FFFFFFFF0000FF0000FF000000FF0000FF000000FF0000FF0000
FFFFFFFF00FFFFFF00FFFFFFFFFF
FF00FFFF00FF0000FF0000FF000000FF0000FF0000FFFFFFFFFFFFFFFF0000FF0000FF00
0000FF0000FF0000FF00FFFF00FF
00FFFFFFFF00000000FFFF000000FF00000000FFFF00FFFFFFFFFFFF00FFFF00000000FF
000000FFFF00000000FFFFFFFF00
0000000000FFFF00FF000000FFFFFF00FF000000FFFFFF00000000FFFFFF000000FF00FF
FFFF000000FF00FFFF0000000000
00000000FF0000FF00FF0000FFFF00FF00FF0000FFFF00FF0000FF00FFFF0000FF00FF00
FFFF0000FF00FF0000FF00000000
00FFFF00FFFF00FFFFFFFFFF00FF000000FFFFFF0000FF00FFFF00FF0000FFFFFF000000
FF00FFFFFFFFFF00FFFF00FFFF00
FF0000FFFFFFFF00FFFFFFFFFF000000FF00FFFF000000FFFFFFFF000000FFFF00FF0000
00FFFFFFFFFF00FFFFFFFF0000FF
00000000FFFFFFFFFF00FF000000FF00FFFFFF00FF000000FFFF000000FF00FFFFFF00FF
000000FF00FFFFFFFFFF00000000
00000000FFFFFFFF00FF00FF000000FFFFFF00FF00FF0000FFFF0000FF00FF00FFFFFF00
0000FF00FF00FFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFFFFFF0000FFFFFFFF0000FFFF0000
FFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFF0000FFFF0000FFFFFFFF0000FFFFFFFF0000FFFF0000
FFFF0000FFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFF00FF00FF000000FFFFFF00FF00FF0000FFFF0000FF00FF00FFFFFF00
0000FF00FF00FFFFFFFF00000000
00000000FFFFFFFFFF00FF000000FF00FFFFFF00FF000000FFFF000000FF00FFFFFF00FF
000000FF00FFFFFFFFFF00000000
FF0000FFFFFFFF00FFFFFFFFFF000000FF00FFFF000000FFFFFFFF000000FFFF00FF0000
00FFFFFFFFFF00FFFFFFFF0000FF
00FFFF00FFFF00FFFFFFFFFF00FF000000FFFFFF0000FF00FFFF00FF0000FFFFFF000000
FF00FFFFFFFFFF00FFFF00FFFF00
00000000FF0000FF00FF0000FFFF00FF00FF0000FFFF00FF0000FF00FFFF0000FF00FF00
FFFF0000FF00FF0000FF00000000
0000000000FFFF00FF000000FFFFFF00FF000000FFFFFF00000000FFFFFF000000FF00FF
FFFF000000FF00FFFF0000000000
00FFFFFFFF00000000FFFF000000FF00000000FFFF00FFFFFFFFFFFF00FFFF00000000FF
000000FFFF00000000FFFFFFFF00
FF00FFFF00FF0000FF0000FF000000FF0000FF0000FFFFFFFFFFFFFFFF0000FF0000FF00
0000FF0000FF0000FF00FFFF00FF
FFFFFFFFFF00FFFFFF00FFFFFFFF0000FF0000FF000000FF0000FF000000FF0000FF0000
FFFFFFFF00FFFFFF00FFFFFFFFFF
FFFFFFFF00FFFFFF00FFFFFFFFFF000000FFFF000000FF00000000FF000000FFFF000000
FFFFFFFFFF00FFFFFF00FFFFFFFF
000000FF00000000000000000000FFFF0000FFFFFF000000FFFF000000FFFFFF0000FFFF
00000000000000000000FF000000
0000FF0000000000000000000000FFFF0000FFFF00FF0000FFFF0000FF00FFFF0000FFFF
0000000000000000000000FF0000
00FFFF00000000FF000000000000FFFFFF000000FFFF00FF0000FF00FFFF000000FFFFFF
000000000000FF00000000FFFF00
FF0000FF0000FF00000000000000FFFF00FF0000FFFFFF00000000FFFFFF0000FF00FFFF
00000000000000FF0000FF0000FF
00FF000000FFFFFF000000000000FF0000FF00FFFFFF00FFFFFFFF00FFFFFF00FF0000FF
000000000000FFFFFF000000FF00
FF000000FF00FFFF00000000000000FFFF00FF00FFFFFF00FFFF00FFFFFF00FF00FFFF00
000000000000FFFF00FF000000FF
FFFF00FFFFFF0000FFFF00FF0000FFFF000000FFFF00FFFFFFFFFFFF00FFFF000000FFFF
0000FF00FFFF0000FFFFFF00FFFF
FFFFFF00FFFF0000FFFFFF000000FFFF0000FF0000FFFFFFFFFFFFFFFF0000FF0000FFFF
000000FFFFFF0000FFFF00FFFFFF
00FFFF000000FFFF00FF00000000FF00FF00FF00FFFFFFFFFFFFFFFFFFFF00FF00FF00FF
00000000FF00FFFF000000FFFF00
FF0000FF0000FFFFFF000000000000FF00FF00FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00
0000000000FFFFFF0000FF0000FF
FF000000FF0000FF0000FF0000FFFFFFFFFF000000FF0000FFFF0000FF000000FFFFFFFF
FF0000FF0000FF0000FF000000FF
00FF000000FFFF00000000FFFF00FFFFFFFF0000FF000000FFFF000000FF0000FFFFFFFF
00FFFF00000000FFFF000000FF00
FF00FF0000FFFFFF00FF00FF0000FFFF00FF0000FF000000FFFF000000FF0000FF00FFFF
0000FF00FF00FFFFFF0000FF00FF
00FF00FFFF00FFFFFF00FF000000FFFFFF00000000FF0000FFFF0000FF00000000FFFFFF
000000FF00FFFFFF00FFFF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.04806 0.97619 0.224427 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0188537 0.0192308 0.0188537 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
51 string
51 51 8 [51 0 0 51 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFFFFFF00FFFF00FF00FF00FFFF000000FF0000FFFF000000000000FF000000FFFF
000000FFFFFF000000FFFFFFFFFFFF
FFFFFF00000000FF00FFFFFF00FFFFFF00FF00FF00FF000000FF0000FF00FFFF00FF00FF
000000FFFFFFFFFF00FFFF0000FF00
00FFFFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FFFFFF0000FF00FFFF0000FF0000FF0000
000000FF00FFFF00FF00FFFF00FF00
0000FFFF0000000000FFFF00000000FFFFFFFF0000FF00FFFFFF00000000FFFFFF00FF00
FFFF0000FF0000FF0000FFFF0000FF
FF0000FF000000FF00FFFF00000000FF00000000FFFFFFFF00FFFF000000FFFFFF0000FF
FFFFFFFFFF00000000FF0000FFFFFF
FF00FF00FF00FFFF000000FF000000FF00FFFF0000FFFFFFFF000000000000FFFF00FFFF
FF00FFFF0000000000000000FFFF00
00000000FFFFFF00FF000000FF00000000FF0000FF00FF0000FFFFFFFFFF000000FFFF00
FF0000FF00FFFFFFFF00000000FF00
FFFFFFFFFF00FFFF000000FFFF000000FF00FF0000FF0000FFFF00FFFF0000FFFFFFFFFF
00FF0000000000FF00FF000000FF00
FF00FFFF00FF00FF0000FF0000FFFF0000FF000000FFFF00FFFFFF0000FFFFFF000000FF
FFFF0000000000FF00FFFFFFFF0000
000000FFFF00FF00FFFF000000000000FF0000FF00000000FF000000FF00FF000000FF00
0000FFFF00FFFF0000000000FF0000
FF00FF00000000000000FFFFFFFF00FF00FF000000FF0000FF0000FFFF00FFFFFFFF00FF
FFFFFF00FF000000FF000000FF00FF
FFFF00FF00FF00FF00FFFFFF00FFFF000000FF00FF00FFFFFFFFFF0000FF00FFFFFFFFFF
FF00FFFF00000000FFFFFFFF00FFFF
FFFFFFFF0000FF0000FFFFFF00FFFFFF000000FF00000000FF000000000000FF0000FFFF
0000FFFF00FF00FF00000000000000
00FF0000FF00FF00FF00FFFFFF00000000FF00FF00FFFF0000FFFFFF00000000FFFFFF00
FF00FF00FF0000FF000000FF000000
FFFFFF0000FF000000FFFFFF00000000FF000000FF00FFFFFF00000000FF00000000FFFF
FFFFFF0000000000FFFFFF00000000
FFFF00FFFFFF0000FF0000FFFFFFFFFFFF00FF0000FFFF00FFFFFFFF0000FF00FFFFFFFF
00FFFF00000000FF00FFFF0000FFFF
FF00FF00FF00000000FF0000FF00FFFF00FF00FFFF00000000FFFF00FFFF0000000000FF
FFFF00FF00FF0000FFFFFF00FF0000
0000FF00FFFF0000FF000000FF00FFFFFF00FF0000FF00000000FFFF00FF00FFFF000000
FF00FFFF000000FF0000FFFFFF0000
FFFF000000FFFF00FFFF00FF00FFFF000000000000000000FF00FF00FFFFFF00FF000000
FF000000FF00FF00FF00FFFF00FFFF
0000FF0000FF0000000000FF00000000FF00FF00FFFF0000FFFFFFFF00FF0000FFFF0000
00FFFF00FFFF00FFFF00FFFFFF00FF
00FFFF00FF00FFFFFFFFFF00FFFF0000FFFF0000FFFF00FFFFFF0000FF000000FFFF00FF
FF00FF00FFFF00FF00FF0000FFFFFF
FFFF0000FF00000000FFFF00FF0000FFFF00FFFF00FF00FF00FFFFFFFFFF00FFFF000000
00FF00FF00FF00FFFFFF00FF000000
FF00FF00FFFF0000FFFF00FFFFFFFFFF0000FFFFFF00000000FF00FF00FFFFFF0000FF00
00000000FF00FFFFFF00000000FF00
00FF0000FFFF0000FF000000000000FFFF00FF0000000000FFFF0000FF0000FF00FFFF00
00FFFFFFFF00FFFFFF0000FF00FF00
FF0000FFFF0000000000FFFFFF00FFFFFF00FF000000FFFFFF00FF0000FFFFFFFFFF00FF
000000FFFFFF00FFFFFFFF0000FFFF
FF0000FF00FFFF00FFFF00FF0000FF000000FF0000FF00FFFF00FFFF00FF0000FF000000
FF0000FF00FFFF00FFFF00FF0000FF
FFFF00FF00000000000000FFFFFFFFFFFF00FFFF000000FFFF00FF00FFFFFF00FFFF00FF
00FF00FF00FF00FFFFFF00000000FF
FF00FF0000FF0000FF00FF00FFFFFFFFFF0000FFFF00FF00FFFF00000000FF00FFFFFF00
FF0000FF0000FFFFFF00FFFFFF00FF
0000FFFFFF00FF0000000000FFFF00FF000000FFFFFF00FFFFFFFF000000FFFFFF00FF00
FF0000FFFFFF00FF00FF00FF00FFFF
0000FF000000000000FF000000FFFFFFFF000000FFFFFFFF00FFFFFF00FFFF0000000000
FF00FFFFFFFF00FFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFF00FFFFFFFF0000FFFF0000FF000000FFFF00FFFFFF0000FFFF00FF
FF00FFFFFF0000FF000000FFFFFFFF
FF00FFFF0000FF00FFFF00000000FF00FF000000FF0000FF00FF00000000000000FF0000
FFFFFFFFFF00FFFF00FFFF00FF0000
FF0000FFFF00FF00FF00FF000000FF00000000FF00FFFFFFFF00FFFF0000FFFFFF000000
FFFF00FF00FFFF00FFFF00000000FF
0000FF00FFFF0000FF000000FF00FFFFFF00FF0000FF00000000FFFF00FF00FFFF000000
FF00FFFF000000FF0000FFFFFF0000
FF00FF00FF00000000FF0000FF00FFFF00FF00FFFF00000000FFFF00FFFF0000000000FF
FFFF00FF00FF0000FFFFFF00FF0000
FFFF00FFFFFF0000FF0000FFFFFFFFFFFF00FF0000FFFF00FFFFFFFF0000FF00FFFFFFFF
00FFFF00000000FF00FFFF0000FFFF
FF00FFFFFF0000000000000000FF0000FF0000FFFFFF0000FF0000FFFF0000FF0000FFFF
FF00FFFFFFFF0000FF0000FF00FF00
FFFF00FFFFFF000000FFFF00FF00FF0000FFFFFF0000FFFFFFFF000000FF000000FFFF00
0000FFFFFFFFFFFFFFFF00000000FF
FFFFFF0000FFFF000000FF0000FFFFFF000000FF00FF00FFFF0000FF00FF00FF0000FFFF
0000FF00000000FF00FF00FF000000
0000FFFFFFFF00FF00FF00FFFF000000000000FF000000FFFFFFFF00FFFFFF0000FFFFFF
00FF00FFFF000000FFFF00FFFF0000
0000FFFF00FFFF00FFFFFF00FFFFFFFF00FFFF00000000FF0000FF00FFFFFFFF00FF00FF
00FFFFFFFFFFFF0000FF00FFFF0000
FFFFFFFF0000FF00FFFFFF00FFFFFF00FF00FF00FF00FF00FF000000000000FFFF00FF00
FFFF00FFFFFFFF000000FF0000FFFF
FFFFFFFFFFFF00FF000000000000FF0000FF00FF00FF0000FFFFFF00FFFFFF00000000FF
FF000000FF0000FF00FF00FFFFFF00
FFFFFFFFFF00FFFF000000FFFF000000FF00FF0000FF0000FFFF00FFFF0000FFFFFFFFFF
00FF0000000000FF00FF000000FF00
00FF000000FFFF00FF00FF00FFFF000000FF00FFFF00000000FFFFFF00FF00FF00FFFF00
FFFF00FFFFFFFFFFFF00FF00000000
00FF00000000FFFF0000FFFFFFFFFFFF00FF00FFFFFF00FFFF000000FF00FF000000FFFF
00FF00FFFF0000000000FF000000FF
0000000000FFFFFFFF00FFFF0000FFFF0000FF00FF00FF00FFFF00FF00FFFFFF000000FF
00FFFF00FFFFFF00FF0000FFFFFF00
FFFF00FFFF00000000FF0000FFFFFFFFFFFF00FFFFFFFFFFFFFF0000FF0000000000FF00
0000FF00000000FF000000FFFFFF00
00FFFF00FF00FFFFFF00FFFFFFFFFF0000FF00FFFF0000FFFF00FF0000FFFF0000FF0000
000000000000FF00FFFFFF0000FF00
00FFFFFF00FFFFFFFF00FF0000FF00FF00FFFFFF000000FFFFFFFFFFFFFFFFFFFFFF00FF
FF000000FF0000FFFF00FFFF00FFFF
00FFFF00000000FFFFFF00FFFFFFFFFF0000000000FF0000000000FFFFFFFFFF0000FFFF
00FF00000000000000000000FF00FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.242063 0.200176 0.41843 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0228938 0.0192308 0.0228938 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
42 string
42 42 8 [42 0 0 42 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00FFFFFFFFFFFFFFFF00FF00FF00FF00FF00FFFFFF0000000000FF0000FFFFFF0000FF
FFFFFFFFFFFF
FF000000FFFFFF0000000000FFFFFF000000FF0000FF000000FFFFFFFF00FF0000000000
FFFFFFFF0000
FFFF00000000FF00FF0000FF0000FFFFFFFF00FF00FFFFFFFF0000FF00FFFFFF00FF0000
0000000000FF
FFFF00000000FF00FF0000000000FF0000FF000000FF00FF0000000000FF00FF00FFFFFF
FFFF000000FF
FFFF00FF00FF0000FFFF00FF00FF00FFFFFF00FFFF00000000000000FFFFFF0000FF0000
00000000FFFF
FFFF00FF00FFFFFF00FF00FFFFFFFFFFFF00FFFFFFFFFF00FF00000000FFFF00FF00FFFF
FFFF0000FFFF
FF0000FF00FF000000FF0000FFFFFF000000000000FFFFFFFFFFFFFFFFFF00FF00000000
FF00FFFFFFFF
000000FF00FF00FFFFFF00FFFFFFFF0000FF00FFFF0000FF00FF0000FFFF0000FF00FF00
FF00000000FF
0000FFFFFF000000FF00FFFFFF00FF00FFFFFF0000FFFFFF00FF0000FFFF00FF00FFFF00
00FFFFFF00FF
FF00000000FF00FF00FF0000000000000000FF00FF00FF0000FFFF00FFFF0000FF00FFFF
FFFF000000FF
FF00FFFF0000FF00FF000000FFFF0000FFFFFF0000FF0000FF00FF00FF00FF0000FF0000
000000000000
FFFFFF00FFFF00000000FF00FF0000FF00FF0000FFFFFF00000000FFFFFF000000FFFF00
FFFF00FF00FF
0000FFFFFFFFFFFFFFFF00FFFF00FFFF00000000FF00FF000000FF00FFFFFFFF00FFFFFF
FF000000FF00
00FF0000FF00FFFFFFFFFFFFFFFFFF000000FF00FFFF00000000FF00FF0000FF0000FFFF
FFFF0000FFFF
FFFFFF000000FF00000000FF0000FF00FFFF000000000000FF0000FFFFFF000000FFFFFF
FF00FFFFFF00
00FF00000000FF0000FFFF00FFFF00FFFFFF00FF0000FFFF00FFFF0000FFFF0000000000
FFFF00FF00FF
00FF00000000FFFFFFFF0000000000FF00FFFFFF00FF0000FF00FFFF000000FF00FF0000
FFFF00FF0000
0000FF0000FFFF000000FF000000FF00FFFFFF00FF00FF00FFFFFFFF0000FFFF00FFFF00
00FFFFFF00FF
0000FFFF0000FFFFFF000000000000FF000000FFFF000000FFFF0000FF0000FFFFFF0000
FF000000FF00
0000FF0000FFFF00FFFF00FFFF0000FF00FF00FF0000FFFF00FFFF00000000000000FF00
FFFF00FF00FF
FFFFFFFF00FFFF00FF00FFFF00FF0000FF000000000000FFFF000000FFFFFF00FF00FF00
FFFF000000FF
FF000000FFFF00FF00FF00FFFFFF000000FFFF000000000000FF0000FF00FFFF00FF00FF
FF00FFFFFFFF
FF00FF00FFFF00FF00000000000000FFFF00FFFF0000FF00FF00FF0000FFFF00FFFF00FF
FF0000FF0000
00FF000000FF0000FFFFFF0000FF0000FFFF000000FFFF000000FF000000000000FFFFFF
0000FFFF0000
FF00FFFFFF0000FFFF00FFFF0000FFFFFFFF00FF00FF00FFFFFF00FF000000FF000000FF
FF0000FF0000
0000FF00FFFF0000FF00FF000000FFFF00FF0000FF00FFFFFF00FF0000000000FFFFFFFF
00000000FF00
FF00FF00FFFF0000000000FFFF0000FFFF00FFFF0000FF00FFFFFF00FFFF00FFFF0000FF
00000000FF00
00FFFFFF00FFFFFFFF000000FFFFFF0000FF000000000000FFFF00FF0000FF00000000FF
000000FFFFFF
FFFF0000FFFFFFFF0000FF0000FF00FF00000000FFFF00FF000000FFFFFFFFFFFFFFFFFF
00FF0000FF00
00FF000000FFFFFFFF00FFFFFFFF00FF000000FF00FF00000000FFFF00FFFF00FFFFFFFF
FFFFFFFF0000
FF00FF00FFFF00FFFF000000FFFFFF00000000FFFFFF0000FF00FF0000FF00FF00000000
FFFF00FFFFFF
0000000000000000FF0000FF00FF00FF00FF0000FF0000FFFFFF0000FFFF000000FF00FF
0000FFFF00FF
FF000000FFFFFFFF00FF0000FFFF00FFFF0000FF00FF00FF0000000000000000FF00FF00
FF00000000FF
FF00FFFFFF0000FFFF00FF00FFFF0000FF00FFFFFF0000FFFFFF00FF00FFFFFF00FF0000
00FFFFFF0000
FF00000000FF00FF00FF0000FFFF0000FF00FF0000FFFF00FF0000FFFFFFFF00FFFFFF00
FF00FF000000
FFFFFFFF00FF00000000FF00FFFFFFFFFFFFFFFFFF000000000000FFFFFF0000FF000000
FF00FF0000FF
FFFF0000FFFFFFFF00FF00FFFF00000000FF00FFFFFFFFFF00FFFFFFFFFFFF00FF00FFFF
FF00FF00FFFF
FFFF000000000000FF0000FFFFFF00000000000000FFFF00FFFFFF00FF00FF00FFFF0000
FF00FF00FFFF
FF000000FFFFFFFFFF00FF00FF0000000000FF00FF000000FF0000FF0000000000FF00FF
00000000FFFF
FF00000000000000FF00FFFFFF00FF0000FFFFFFFF00FF00FFFFFFFF0000FF0000FF00FF
00000000FFFF
0000FFFFFFFF0000000000FF00FFFFFFFF000000FF0000FF000000FFFFFF0000000000FF
FFFF000000FF
FFFFFFFFFFFFFF0000FFFFFF0000FF0000000000FFFFFF00FF00FF00FF00FF00FFFFFFFF
FFFFFFFF00FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.242063 0.39418 0.41843 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0223614 0.0192308 0.0223614 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
43 string
43 43 8 [43 0 0 43 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFF000000FFFFFF00FF0000FF0000FFFF00FFFF00FF00FF000000FF000000FFFFFF00
FF00FFFFFFFFFF
00FF0000000000FF00FFFF00FFFF00FFFF0000FF0000FF00000000FFFF00000000FF00FF
FFFFFFFFFFFF00
FFFFFF000000FFFFFFFF00FF00000000FFFF0000FF0000FF00FFFF00FFFF0000FFFFFFFF
FFFFFF000000FF
FFFF00FF00FF00FF000000FF00FF00FF0000FF0000FF00FFFFFF0000FF00FF0000000000
00FFFFFF000000
000000FF00FF00FFFF00FFFF00FFFF0000FFFF00FF00FFFF000000000000FF00FFFFFF00
FFFFFFFF00FF00
00FF00FFFFFFFF000000FFFF000000FFFF0000FF00000000FFFF00FFFFFF00FFFFFF00FF
FFFF000000FF00
FFFFFF00FFFF00FFFF00FFFFFFFF00FF00FFFF00FF0000000000FFFF00FFFF0000FFFF00
0000FFFF0000FF
0000FF00FF00FF00FFFFFF0000FFFF0000FF00FF00FFFFFF000000FFFFFFFF0000FFFFFF
FFFFFF000000FF
FF00FF00FF00FFFFFFFF0000000000000000FFFFFFFF00FFFFFF00FF0000FF00FFFFFF00
FFFFFF00000000
FFFFFF0000000000FFFF0000FF0000FFFF00FFFF0000FF00FF00FFFFFFFFFFFFFFFFFF00
00FFFF000000FF
00000000FFFF00FF00FFFFFF00FF00FF00FF0000FF0000FF00FFFFFFFF00FFFF00FF00FF
FF0000FFFF0000
00000000FF00FFFF00FF00FF0000FFFFFF00FFFF0000000000FF00FF00FF00FF00000000
FF0000FF000000
00FF00FFFF00FFFF00000000FFFFFF0000FF00000000FFFF00FF00000000FFFFFF0000FF
FFFF00FFFF0000
FFFF0000FF0000FF0000FF000000FFFFFF0000FF00FFFF00FF00FF0000FF00FF00FF00FF
FFFF0000FF0000
FF0000FFFF0000FF00FF00FF00FF000000FFFF00FF0000FFFFFF0000FF000000FFFF00FF
00FF00FFFFFFFF
00FFFF00FF00FFFF0000FF00000000FFFFFFFFFFFF0000FF000000FF000000FF00FF0000
FFFFFFFF000000
00FF0000000000FF00FFFFFFFFFF000000FFFF00FFFFFF0000FFFFFF00FF0000FF0000FF
000000FF0000FF
00FFFFFFFF00FFFF00FFFFFF0000FF00000000000000000000000000FF0000FFFFFF00FF
FF00FFFFFFFF00
FF0000FFFF00FFFFFFFFFF00FF000000FFFFFFFF00FF0000FF00FFFFFFFF00FFFFFFFF00
FF0000FF00FF00
FFFF00FF00FFFFFFFFFF00FFFFFF00000000FF00FF00FFFF00FF0000FF0000000000FF00
00FFFFFF0000FF
FFFFFF00FF00FF00FF00FFFF0000FF00000000FFFF00FF00FFFFFF0000FF00FFFFFFFFFF
FF0000FFFFFFFF
00FFFFFFFFFF00FFFF00FFFF0000FF00FF00FFFFFF00FF0000FF000000FF00FFFFFFFF00
00FF0000FFFF00
00000000FF00FFFF000000FFFFFF00000000FFFFFF00FF0000FF0000FF00000000FF0000
0000000000FF00
FF00FF00FF0000FFFFFFFF000000FFFF0000FFFF00FF0000FFFF000000FFFFFFFFFFFF00
00000000FFFF00
00FFFFFFFF0000FFFFFF0000FF00FFFF00FFFFFF000000FFFFFF00FFFF00FF0000FFFFFF
0000FFFFFFFF00
FFFFFF0000FF0000FFFFFF000000FFFF0000FFFFFFFFFFFF0000FF00FF00FFFFFF00FF00
00FF00FFFF0000
FF00000000FFFFFF00FF0000FFFF00FFFFFFFF000000FF00000000FF00FFFFFFFF000000
FF0000FFFFFFFF
000000FF00FFFF00FF0000FF0000FFFF00FF00000000FFFF00FF00FF00FF0000FF00FF00
FF00FFFFFFFF00
FFFFFF0000FFFFFF00FFFF00FF00FFFF00FFFFFF00FFFF0000FF000000FFFFFF000000FF
0000FF00000000
FF00FFFF00FFFFFF000000FFFFFF0000FF000000FF0000FF0000FF00FF00FF00FF0000FF
FF00FFFF00FFFF
000000000000FF00FF00FF00FFFFFF00FFFFFFFF00000000000000000000FF00FFFFFFFF
FF00FFFF000000
FF00FFFF0000FFFF00FF00FFFFFF00FF0000FF000000FFFFFF00FFFFFF0000FFFFFF00FF
00FFFF000000FF
FFFFFF00FFFF0000FFFF00FFFF00FFFF00FFFF00FF0000FFFFFF00FF00FFFF00FFFFFF00
000000000000FF
000000000000FF00FFFFFF00FF00FF000000FFFF00FFFFFFFFFF00FFFF00000000FFFFFF
FFFF0000FF00FF
FF00FF00FF00FFFFFFFF0000000000000000FFFFFFFF00FFFFFF00FF0000FF00FFFFFF00
FFFFFF00000000
FF00FFFF00FF00FF00FFFFFF00FFFFFF00FFFF00FF0000000000FFFFFFFF000000000000
0000000000FFFF
FFFF0000FF0000FFFF00FF00FFFFFFFF00FFFF00000000FF0000FFFF0000FF00FFFFFF00
000000FF00FFFF
FF00FFFFFFFFFFFFFF0000FFFFFFFFFFFF00FFFF0000000000FFFFFF0000000000FFFF00
00FF00FFFFFFFF
00FFFF00FF00FFFFFF000000FF0000FF00FFFFFF00FF0000FF000000FFFF00FF0000FF00
FF000000FF00FF
000000FF0000FFFF0000FF0000FF0000FF00FF00FF0000FFFF00FF00FF0000FF000000FF
FFFFFFFFFFFF00
000000000000FF0000FFFFFFFFFFFF00FFFFFF00FF0000FFFFFF0000000000FF00FF0000
00FFFFFFFF0000
FFFFFFFFFF0000FF00FFFF000000FFFF00000000000000FFFFFFFFFF00FF0000FF000000
00000000FFFFFF
FF0000FFFFFFFF00000000FF00FFFF0000FFFF0000000000FFFF0000FFFF00FF00000000
FFFFFFFF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.242063 0.588183 0.41843 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0218531 0.0192308 0.0218531 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
44 string
44 44 8 [44 0 0 44 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFF0000FFFFFF000000FFFFFFFF00FF00FFFF00FF00FFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FFFFFF0000FF00FF00FFFFFF0000FF00FF00FF00FF0000000000FF0000FFFF0000FF00FF
00FF00FFFFFF00FF
FFFFFFFFFF00FFFF0000000000FF00FF000000FFFF0000FFFFFF0000FF00FFFF00FF0000
FFFF00FFFF0000FF
FF00FFFF00FF000000000000FFFFFF00FFFF0000FF00FFFF0000000000FFFF00FFFFFF00
0000000000FFFFFF
0000FF000000FFFF00FF00FFFF00FF0000FF0000FFFF00FF000000FFFFFF0000FFFFFF00
0000FFFFFFFF0000
0000FF0000FF0000FF00FFFF000000000000FF00FFFFFFFF00FF0000FF00FFFFFFFFFF00
000000FFFF0000FF
00FFFFFFFF0000FF00FF00FF00FFFF00FFFF00FFFF00FFFFFFFF00FF0000000000FF00FF
FF00FF0000FFFFFF
0000FFFFFF00FF00FF00FF0000FF0000FFFFFF00FF00FFFFFFFF00FF00FFFFFFFF00FF00
00FF00FFFF0000FF
FF000000FF00FF0000FF00FFFF00FF000000FF00FF000000000000FFFFFFFFFF0000FFFF
FF000000FF00FF00
FFFFFFFF00FF00FFFFFF000000FFFFFFFFFF00FFFFFFFFFF00FF000000FF0000FFFF00FF
00FFFFFF00000000
0000FF00FFFFFF00FF00FF00FFFFFFFFFF0000FF0000FF00000000FFFF0000FF000000FF
FFFF0000FFFFFFFF
000000FF00FFFF00000000FFFFFF0000FFFF0000FFFFFF0000FF00FFFF00FF000000FF00
0000FFFFFF00FFFF
FFFF00FF0000000000FF000000FFFFFFFFFF00FFFFFF000000000000FF00000000FF00FF
FF0000FF00FF00FF
0000FF00FF00FFFF00FFFF00FFFFFF0000FF0000FF00000000FF0000FF00FF00FFFFFF00
FF00FF0000FFFFFF
FF0000FF00FF00FF0000FF0000FF00FFFF00FF00FFFFFFFFFF0000FFFFFFFFFF0000FFFF
000000FFFF00FFFF
FF00FF00FFFFFFFFFF00FF00FFFFFFFFFF0000FF00FF00FFFFFF000000FF0000FFFF00FF
00FFFFFF00FFFF00
FF0000FF0000FFFF000000FFFF0000FF0000FFFF0000000000FFFFFF00FF00FF0000FF00
0000FF00FFFFFF00
FFFF0000FF000000FFFFFF0000FF00FFFFFF0000FFFFFFFF00FF00000000FFFFFF00FFFF
0000FFFF00FF0000
0000FFFF00FFFF00000000FFFF00FFFF00FFFFFFFFFF00FF00FF0000FFFFFFFFFF00FF00
0000000000FFFFFF
0000FFFF0000FF00000000FF00FFFFFFFF00FF00FFFFFFFF0000000000FFFFFFFF000000
FFFF00FF0000FF00
FFFFFFFFFF00000000FFFFFF00FF00FF00000000FFFF00FF00000000FFFF000000FF00FF
00FF000000FFFFFF
00FFFFFFFF000000FFFFFFFFFF00000000FF00FF000000FFFFFFFF0000FFFF00FF00FF00
00FFFF0000000000
FFFFFF000000FFFFFFFF00FF000000FF00FFFFFFFF000000FF00FF00FFFFFFFFFFFFFF00
FF00FFFFFF0000FF
0000FFFFFF000000FFFFFF00FF00000000000000FF00FFFF0000000000FFFFFFFFFF0000
00FF000000FF0000
0000FFFF0000FFFF00FFFFFFFFFF00FF00000000FFFFFFFF00FF00FF0000FF00FFFFFF00
00FF00FF0000FF00
00FF00FF00FF0000FFFF0000FFFF00000000FF00FF00FFFFFFFFFF00000000FF000000FF
00FF0000000000FF
000000FF0000FFFFFF00FFFFFF0000FF0000FF00FFFFFFFF0000FFFF00000000000000FF
FFFFFF00FFFFFFFF
00FF0000FF00FFFFFFFF00FF00000000FFFFFF0000000000FFFF0000FFFF0000000000FF
0000FFFF00FF00FF
FF00FF000000FFFF00FFFFFFFF00FF0000FF000000FF00FF00FFFFFFFFFFFF0000FFFF00
00FF000000FFFF00
000000FF00FFFF0000000000FF00FFFF0000FF0000000000FF000000FF00000000FFFFFF
FFFF00FFFF00FF00
00FFFF00FFFF00FFFF00000000FFFFFF00FFFF0000FFFFFF000000000000FFFFFF0000FF
FFFF000000FF00FF
FFFFFF00FFFF00FF00FF00FF00000000FF000000FF00FF00FF00FF0000FFFF00FFFF00FF
0000FF00FF0000FF
00FF000000FF00FFFFFF0000FF0000FF0000000000FFFFFF00FFFF0000000000FF0000FF
FFFFFFFF000000FF
FF0000FF00FF00FFFFFF000000FF00FFFFFF00FF00FF00000000FFFFFFFF000000FFFFFF
000000FF0000FF00
0000FF000000FF00FF0000FFFFFF00FF00FFFFFF00FFFF00000000FF000000FF00FFFFFF
FF0000FFFF00FFFF
00FF0000FFFF00FFFFFF00FF000000000000FF0000FFFFFF000000FFFF00FF000000FF00
00FFFF00FF0000FF
00FFFFFF0000FF0000FF0000FFFFFFFF00FFFFFFFF00FFFF00FF0000FF00FF00FFFF00FF
00FF0000FF00FFFF
0000FFFF000000FFFF0000000000FF0000FFFFFF00FF0000FF0000000000FF00FFFFFF00
FF00FFFF00FF00FF
00FFFFFFFF00FF00FF0000FF00FFFF00FFFF0000FF0000FF0000FFFFFFFF00FFFF00FF00
00FFFF000000FFFF
FFFFFF00FFFF00FFFF00FF0000FF000000FF00FF0000FF00FF0000FFFF00FFFF000000FF
00FF0000FFFFFFFF
00FFFF00FF00FF00FFFFFF0000FFFF00FFFFFFFF00FF0000FFFF000000FFFFFFFF0000FF
00FFFFFFFFFF0000
FFFF00FFFFFFFF0000FF0000FFFF00FFFFFF0000FFFFFFFF00FFFFFFFF00FF0000FFFF00
00FFFFFFFFFF00FF
FF0000FF00FF00FFFF000000FFFF00FF00FF00FFFFFFFF00FFFF00FFFF0000FFFF00FF00
00FF00FF0000FFFF
FFFFFF0000000000FFFFFF00FF00FFFF00FF00FF00FF00FFFF0000FFFF0000FF00000000
000000FFFFFFFF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.242063 0.782187 0.41843 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0213675 0.0192308 0.0213675 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
45 string
45 45 8 [45 0 0 45 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000FFFFFFFF0000FFFF00FFFFFF0000FFFFFF00FF00FF00FFFFFF0000FFFFFF00FFFF
0000FFFFFFFF000000
000000FFFFFF00000000FF00FF00FF0000FFFF00FF000000FF00FFFF0000FF00FF00FF00
000000FFFFFF000000
000000FF00000000FFFF00FF0000FF000000FF00FFFF00FFFF00FF000000FF0000FF00FF
FF00000000FF000000
FFFFFF00FF000000FF0000FFFFFF00FF00FF00FFFF000000FFFF00FF00FF00FFFFFF0000
FF000000FF00FFFFFF
FFFF00FF0000FF00FFFF00FF0000000000FFFF00000000000000FFFF0000000000FF00FF
FF00FF0000FF00FFFF
FFFF00000000FFFFFFFF00FFFFFF00FFFFFFFFFF0000000000FFFFFFFFFF00FFFFFF00FF
FFFFFF00000000FFFF
FF000000FFFF00FF0000FF00FFFF0000FFFFFF00FF000000FF00FFFFFF0000FFFF00FF00
00FF00FFFF000000FF
0000000000FFFF00FFFFFF00FF00000000FFFF00FFFF00FFFF00FFFF00000000FF00FFFF
FF00FFFF0000000000
0000FFFFFFFF00FF00FFFF0000FFFF000000000000FF00FF000000000000FFFF0000FFFF
00FF00FFFFFFFF0000
FF00FF00FFFF00FFFF00FF00FF0000000000FFFF0000000000FFFF0000000000FF00FF00
FFFF00FFFF00FF00FF
FFFF00000000FFFFFFFF0000FFFFFFFFFF0000000000000000000000FFFFFFFFFF0000FF
FFFFFF00000000FFFF
0000FFFFFFFF0000000000000000000000FF000000FF00FF000000FF0000000000000000
000000FFFFFFFF0000
FFFF00FF00FFFFFF00FFFF0000FF0000FF0000000000000000000000FF0000FF0000FFFF
00FFFFFF00FF00FFFF
FF0000FF00FFFF00FF00FF00FF00FFFFFF0000FFFF000000FFFF0000FFFFFF00FF00FF00
FF00FFFF00FF0000FF
FFFFFF0000000000FF00FF0000FF00FFFF0000000000000000000000FFFF00FF0000FF00
FF0000000000FFFFFF
000000FF00FF00000000FF0000FFFF000000FFFF00FF00FF00FFFF000000FFFF0000FF00
000000FF00FF000000
0000000000FFFF000000FF00FFFFFF0000000000FFFF00FFFF0000000000FFFFFF00FF00
0000FFFF0000000000
FFFF00FFFFFFFFFF000000FF0000000000000000FFFF00FFFF0000000000000000FF0000
00FFFFFFFFFF00FFFF
FFFFFF00FFFFFFFF00FF0000000000FF000000FF00FF00FF00FF000000FF0000000000FF
00FFFFFFFF00FFFFFF
FF0000FF00FF000000FF000000FF00FF0000FF0000FF00FF0000FF0000FF00FF000000FF
000000FF00FF0000FF
00FFFFFF0000FFFF0000000000FF0000FFFF000000000000000000FFFF0000FF00000000
00FFFF0000FFFFFF00
FF00FF00000000FFFF0000FF000000FFFFFFFFFF0000000000FFFFFFFFFF000000FF0000
FFFF00000000FF00FF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000
FF00FF00000000FFFF0000FF000000FFFFFFFFFF0000000000FFFFFFFFFF000000FF0000
FFFF00000000FF00FF
00FFFFFF0000FFFF0000000000FF0000FFFF000000000000000000FFFF0000FF00000000
00FFFF0000FFFFFF00
FF0000FF00FF000000FF000000FF00FF0000FF0000FF00FF0000FF0000FF00FF000000FF
000000FF00FF0000FF
FFFFFF00FFFFFFFF00FF0000000000FF000000FF00FF00FF00FF000000FF0000000000FF
00FFFFFFFF00FFFFFF
FFFF00FFFFFFFFFF000000FF0000000000000000FFFF00FFFF0000000000000000FF0000
00FFFFFFFFFF00FFFF
0000000000FFFF000000FF00FFFFFF0000000000FFFF00FFFF0000000000FFFFFF00FF00
0000FFFF0000000000
000000FF00FF00000000FF0000FFFF000000FFFF00FF00FF00FFFF000000FFFF0000FF00
000000FF00FF000000
FFFFFF0000000000FF00FF0000FF00FFFF0000000000000000000000FFFF00FF0000FF00
FF0000000000FFFFFF
FF0000FF00FFFF00FF00FF00FF00FFFFFF0000FFFF000000FFFF0000FFFFFF00FF00FF00
FF00FFFF00FF0000FF
FFFF00FF00FFFFFF00FFFF0000FF0000FF0000000000000000000000FF0000FF0000FFFF
00FFFFFF00FF00FFFF
0000FFFFFFFF0000000000000000000000FF000000FF00FF000000FF0000000000000000
000000FFFFFFFF0000
FFFF00000000FFFFFFFF0000FFFFFFFFFF0000000000000000000000FFFFFFFFFF0000FF
FFFFFF00000000FFFF
FF00FF00FFFF00FFFF00FF00FF0000000000FFFF0000000000FFFF0000000000FF00FF00
FFFF00FFFF00FF00FF
0000FFFFFFFF00FF00FFFF0000FFFF000000000000FF00FF000000000000FFFF0000FFFF
00FF00FFFFFFFF0000
0000000000FFFF00FFFFFF00FF00000000FFFF00FFFF00FFFF00FFFF00000000FF00FFFF
FF00FFFF0000000000
FF000000FFFF00FF0000FF00FFFF0000FFFFFF00FF000000FF00FFFFFF0000FFFF00FF00
00FF00FFFF000000FF
FFFF00000000FFFFFFFF00FFFFFF00FFFFFFFFFF0000000000FFFFFFFFFF00FFFFFF00FF
FFFFFF00000000FFFF
FFFF00FF0000FF00FFFF00FF0000000000FFFF00000000000000FFFF0000000000FF00FF
FF00FF0000FF00FFFF
FFFFFF00FF000000FF0000FFFFFF00FF00FF00FFFF000000FFFF00FF00FF00FFFFFF0000
FF000000FF00FFFFFF
000000FF00000000FFFF00FF0000FF000000FF00FFFF00FFFF00FF000000FF0000FF00FF
FF00000000FF000000
000000FFFFFF00000000FF00FF00FF0000FFFF00FF000000FF00FFFF0000FF00FF00FF00
000000FFFFFF000000
000000FFFFFFFF0000FFFF00FFFFFF0000FFFFFF00FF00FF00FFFFFF0000FFFFFF00FFFF
0000FFFFFFFF000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.242063 0.97619 0.41843 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.020903 0.0192308 0.020903 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
46 string
46 46 8 [46 0 0 46 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFFFFFFFFFF00FFFF0000FF00FF0000FF00000000000000000000FF0000FF00FF0000
FFFF00FFFFFFFFFFFF00
FF00FFFFFFFF00FFFFFF000000FF00FFFF000000000000000000000000FFFF00FF000000
FFFFFF00FFFFFFFF00FF
FFFF00000000FFFFFF00FFFFFF000000FF00FFFFFFFFFFFFFFFFFFFF00FF000000FFFFFF
00FFFFFF00000000FFFF
FFFF00000000FFFF00FFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFF
FF00FFFF00000000FFFF
FFFF00000000FF00FF00FFFFFFFFFF00FFFFFFFF0000FFFF0000FFFFFFFF00FFFFFFFFFF
00FF00FF00000000FFFF
FFFF0000000000FF00FFFFFFFFFF00FFFFFFFFFF0000FFFF0000FFFFFFFFFF00FFFFFFFF
FF00FF0000000000FFFF
FF00FFFFFF00000000FF0000FF0000FFFF00FF00FF00FFFF00FF00FF00FFFF0000FF0000
FF00000000FFFFFF00FF
00FFFFFF00FF0000FF00000000FFFF0000FF00FF00FFFFFFFF00FF00FF0000FFFF000000
00FF0000FF00FFFFFF00
FFFFFF00FF0000FF0000FFFF000000FFFFFF00FF0000FFFF0000FF00FFFFFF000000FFFF
0000FF0000FF00FFFFFF
FFFF00FF00FFFF000000FFFF0000FF00FFFFFF000000FFFF000000FFFFFF00FF0000FFFF
000000FFFF00FF00FFFF
0000FFFFFFFF0000FFFF0000FFFFFFFF000000FF0000FFFF0000FF000000FFFFFFFF0000
FFFF0000FFFFFFFF0000
0000FFFFFFFF0000FFFF0000FFFFFFFF0000FF000000FFFF000000FF0000FFFFFFFF0000
FFFF0000FFFFFFFF0000
FF00FF00FFFFFF000000FFFF0000FF00FF00FFFFFF00000000FFFFFF00FF00FF0000FFFF
000000FFFFFF00FF00FF
00FF00FFFFFF00FF0000FFFF000000FF00FFFFFF00FF0000FF00FFFFFF00FF000000FFFF
0000FF00FFFFFF00FF00
FF000000FF0000FF00FFFFFFFF000000FFFF00FFFF00000000FFFF00FFFF000000FFFFFF
FF00FF0000FF000000FF
00FF000000FFFF00FF00FFFF00FF0000FFFFFF0000FF0000FF0000FFFFFF0000FF00FFFF
00FF00FFFF000000FF00
00FFFF00FFFFFF00FFFF0000FF00FFFF0000FF0000000000000000FF0000FFFF00FF0000
FFFF00FFFFFF00FFFF00
FF0000FFFFFF00FFFFFF000000FFFFFF000000FF000000000000FF000000FFFFFF000000
FFFFFF00FFFFFF0000FF
0000FFFFFFFFFF0000FF00FFFFFF00FFFF000000FF00FFFF00FF000000FFFF00FFFFFF00
FF0000FFFFFFFFFF0000
0000FFFFFFFF00FFFF00FF00FFFFFF0000FF000000FFFFFFFF000000FF0000FFFFFF00FF
00FFFF00FFFFFFFF0000
0000FFFF0000FF0000000000FF00FF000000FF0000000000000000FF000000FF00FF0000
000000FF0000FFFF0000
0000FFFF000000FF0000000000FF00FF000000FF000000000000FF000000FF00FF000000
0000FF000000FFFF0000
0000FFFFFFFFFFFFFFFFFFFF000000000000FFFF000000000000FFFF000000000000FFFF
FFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFF000000000000FFFF000000000000FFFF000000000000FFFF
FFFFFFFFFFFFFFFF0000
0000FFFF000000FF0000000000FF00FF000000FF000000000000FF000000FF00FF000000
0000FF000000FFFF0000
0000FFFF0000FF0000000000FF00FF000000FF0000000000000000FF000000FF00FF0000
000000FF0000FFFF0000
0000FFFFFFFF00FFFF00FF00FFFFFF0000FF000000FFFFFFFF000000FF0000FFFFFF00FF
00FFFF00FFFFFFFF0000
0000FFFFFFFFFF0000FF00FFFFFF00FFFF000000FF00FFFF00FF000000FFFF00FFFFFF00
FF0000FFFFFFFFFF0000
FF0000FFFFFF00FFFFFF000000FFFFFF000000FF000000000000FF000000FFFFFF000000
FFFFFF00FFFFFF0000FF
00FFFF00FFFFFF00FFFF0000FF00FFFF0000FF0000000000000000FF0000FFFF00FF0000
FFFF00FFFFFF00FFFF00
00FF000000FFFF00FF00FFFF00FF0000FFFFFF0000FF0000FF0000FFFFFF0000FF00FFFF
00FF00FFFF000000FF00
FF000000FF0000FF00FFFFFFFF000000FFFF00FFFF00000000FFFF00FFFF000000FFFFFF
FF00FF0000FF000000FF
00FF00FFFFFF00FF0000FFFF000000FF00FFFFFF00FF0000FF00FFFFFF00FF000000FFFF
0000FF00FFFFFF00FF00
FF00FF00FFFFFF000000FFFF0000FF00FF00FFFFFF00000000FFFFFF00FF00FF0000FFFF
000000FFFFFF00FF00FF
0000FFFFFFFF0000FFFF0000FFFFFFFF0000FF000000FFFF000000FF0000FFFFFFFF0000
FFFF0000FFFFFFFF0000
0000FFFFFFFF0000FFFF0000FFFFFFFF000000FF0000FFFF0000FF000000FFFFFFFF0000
FFFF0000FFFFFFFF0000
FFFF00FF00FFFF000000FFFF0000FF00FFFFFF000000FFFF000000FFFFFF00FF0000FFFF
000000FFFF00FF00FFFF
FFFFFF00FF0000FF0000FFFF000000FFFFFF00FF0000FFFF0000FF00FFFFFF000000FFFF
0000FF0000FF00FFFFFF
00FFFFFF00FF0000FF00000000FFFF0000FF00FF00FFFFFFFF00FF00FF0000FFFF000000
00FF0000FF00FFFFFF00
FF00FFFFFF00000000FF0000FF0000FFFF00FF00FF00FFFF00FF00FF00FFFF0000FF0000
FF00000000FFFFFF00FF
FFFF0000000000FF00FFFFFFFFFF00FFFFFFFFFF0000FFFF0000FFFFFFFFFF00FFFFFFFF
FF00FF0000000000FFFF
FFFF00000000FF00FF00FFFFFFFFFF00FFFFFFFF0000FFFF0000FFFFFFFF00FFFFFFFFFF
00FF00FF00000000FFFF
FFFF00000000FFFF00FFFFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFF000000FF00FFFF
FF00FFFF00000000FFFF
FFFF00000000FFFFFF00FFFFFF000000FF00FFFFFFFFFFFFFFFFFFFF00FF000000FFFFFF
00FFFFFF00000000FFFF
FF00FFFFFFFF00FFFFFF000000FF00FFFF000000000000000000000000FFFF00FF000000
FFFFFF00FFFFFFFF00FF
00FFFFFFFFFFFF00FFFF0000FF00FF0000FF00000000000000000000FF0000FF00FF0000
FFFF00FFFFFFFFFFFF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.436067 0.200176 0.612434 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0259875 0.0192308 0.0259875 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
37 string
37 37 8 [37 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000000000FFFF000000FF00FF00FFFF00FF00FF00FFFF00FF00FF000000FFFF00000000
00
000000FFFFFF00FFFFFF0000000000FFFFFF00FFFFFF0000000000FFFFFF00FFFFFF0000
00
000000FFFFFF00000000FF0000FFFFFFFFFF00FFFFFFFFFF0000FF00000000FFFFFF0000
00
00FFFF00000000FFFFFF0000FF00FF00FFFF00FFFF00FF00FF0000FFFFFF00000000FFFF
00
00FFFF0000FFFFFFFFFF00FF000000FF00FF00FF00FF000000FF00FFFFFFFFFF0000FFFF
00
FFFFFF00FF000000FFFFFFFFFF0000FF00FF00FF00FF0000FFFFFFFFFF000000FF00FFFF
FF
FF000000FF0000FFFFFFFFFFFF0000FFFF000000FFFF0000FFFFFFFFFFFF0000FF000000
FF
00FF00FFFF00FF00FFFFFF00FF00FF00FFFF00FFFF00FF00FF00FFFFFF00FF00FFFF00FF
00
00FF00FFFFFFFFFF00FFFF0000FF00FFFFFF00FFFFFF00FF0000FFFF00FFFFFFFFFF00FF
00
00FF00FFFFFFFFFFFF00FFFF00FF000000FF00FF000000FF00FFFF00FFFFFFFFFFFF00FF
00
FF00FF0000FFFFFFFFFF00FF00FFFF0000FF00FF0000FFFF00FF00FFFFFFFFFF0000FF00
FF
00000000FFFFFF0000FFFF000000FFFFFFFF00FFFFFFFF000000FFFF0000FFFFFF000000
00
FF0000FF00FFFFFF000000000000FF00FFFF00FFFF00FF000000000000FFFFFF00FF0000
FF
0000FF0000000000FFFFFF000000FFFFFFFF00FFFFFFFF000000FFFFFF0000000000FF00
00
FF00FFFF000000FF0000FFFFFFFF00FFFFFF00FFFFFF00FFFFFFFF0000FF000000FFFF00
FF
FFFFFF00FFFFFF00FF0000FF00FFFF00FF000000FF00FFFF00FF0000FF00FFFFFF00FFFF
FF
00FFFFFF0000FFFFFF0000FFFFFFFFFF00FF00FF00FFFFFFFFFF0000FFFFFF0000FFFFFF
00
FFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FF000000FF00FFFFFFFFFFFFFFFF00FFFFFFFFFF
FF
000000000000000000000000000000000000000000000000000000000000000000000000
00
FFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FF000000FF00FFFFFFFFFFFFFFFF00FFFFFFFFFF
FF
00FFFFFF0000FFFFFF0000FFFFFFFFFF00FF00FF00FFFFFFFFFF0000FFFFFF0000FFFFFF
00
FFFFFF00FFFFFF00FF0000FF00FFFF00FF000000FF00FFFF00FF0000FF00FFFFFF00FFFF
FF
FF00FFFF000000FF0000FFFFFFFF00FFFFFF00FFFFFF00FFFFFFFF0000FF000000FFFF00
FF
0000FF0000000000FFFFFF000000FFFFFFFF00FFFFFFFF000000FFFFFF0000000000FF00
00
FF0000FF00FFFFFF000000000000FF00FFFF00FFFF00FF000000000000FFFFFF00FF0000
FF
00000000FFFFFF0000FFFF000000FFFFFFFF00FFFFFFFF000000FFFF0000FFFFFF000000
00
FF00FF0000FFFFFFFFFF00FF00FFFF0000FF00FF0000FFFF00FF00FFFFFFFFFF0000FF00
FF
00FF00FFFFFFFFFFFF00FFFF00FF000000FF00FF000000FF00FFFF00FFFFFFFFFFFF00FF
00
00FF00FFFFFFFFFF00FFFF0000FF00FFFFFF00FFFFFF00FF0000FFFF00FFFFFFFFFF00FF
00
00FF00FFFF00FF00FFFFFF00FF00FF00FFFF00FFFF00FF00FF00FFFFFF00FF00FFFF00FF
00
FF000000FF0000FFFFFFFFFFFF0000FFFF000000FFFF0000FFFFFFFFFFFF0000FF000000
FF
FFFFFF00FF000000FFFFFFFFFF0000FF00FF00FF00FF0000FFFFFFFFFF000000FF00FFFF
FF
00FFFF0000FFFFFFFFFF00FF000000FF00FF00FF00FF000000FF00FFFFFFFFFF0000FFFF
00
00FFFF00000000FFFFFF0000FF00FF00FFFF00FFFF00FF00FF0000FFFFFF00000000FFFF
00
000000FFFFFF00000000FF0000FFFFFFFFFF00FFFFFFFFFF0000FF00000000FFFFFF0000
00
000000FFFFFF00FFFFFF0000000000FFFFFF00FFFFFF0000000000FFFFFF00FFFFFF0000
00
0000000000FFFF000000FF00FF00FFFF00FF00FF00FFFF00FF00FF000000FFFF00000000
00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.436067 0.39418 0.612434 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0253036 0.0192308 0.0253036 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
38 string
38 38 8 [38 0 0 38 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFF000000FF00FFFFFFFF0000FFFFFFFF0000FFFFFFFF0000FFFFFFFF00FF000000FF
FF00
FF0000FF000000FFFFFFFFFF0000FFFFFFFF0000FFFFFFFF0000FFFFFFFFFF000000FF00
00FF
FF00000000000000FF0000000000000000000000000000000000000000FF000000000000
00FF
00FF00000000000000FF000000000000000000000000000000000000FF00000000000000
FF00
000000000000FFFFFF00FFFF0000FF0000FF0000FF0000FF0000FFFF00FFFFFF00000000
0000
000000000000FFFF00FFFFFF000000FFFF00000000FFFF000000FFFFFF00FFFF00000000
0000
FF000000FFFF000000FFFF0000FF00FF00FF0000FF00FF00FF0000FFFF000000FFFF0000
00FF
00FF0000FFFF0000FF0000FFFF00FF00FF00000000FF00FF00FFFF0000FF0000FFFF0000
FF00
FFFFFF00FF0000FF0000000000FFFF00FF00FFFF00FF00FFFF0000000000FF0000FF00FF
FFFF
FFFF00FF00FFFF0000000000FF0000FF00FFFFFFFF00FF0000FF0000000000FFFF00FF00
FFFF
FFFF0000FFFFFF0000000000FF000000FFFFFFFFFFFF000000FF0000000000FFFFFF0000
FFFF
FFFF0000FFFF00FF0000000000FF0000FFFFFFFFFFFF0000FF0000000000FF00FFFF0000
FFFF
00000000000000FF00FFFF00000000FFFF00FFFF00FFFF00000000FFFF00FF0000000000
0000
000000000000FF00FF0000FF0000FF0000FFFFFFFF0000FF0000FF0000FF00FF00000000
0000
FFFF0000FF0000FFFF00000000FF0000FFFFFFFFFFFF0000FF00000000FFFF0000FF0000
FFFF
FFFF000000FFFF0000FF0000FF000000FFFFFFFFFFFF000000FF0000FF0000FFFF000000
FFFF
FFFF000000FF00FFFF00FFFFFF00FFFF0000FFFF0000FFFF00FFFFFF00FFFF00FF000000
FFFF
FFFF0000FF00FF0000FFFFFF00FFFFFF0000FFFF0000FFFFFF00FFFFFF0000FF00FF0000
FFFF
0000000000000000FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF000000000000
0000
0000000000000000FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF000000000000
0000
FFFF0000FF00FF0000FFFFFF00FFFFFF0000FFFF0000FFFFFF00FFFFFF0000FF00FF0000
FFFF
FFFF000000FF00FFFF00FFFFFF00FFFF0000FFFF0000FFFF00FFFFFF00FFFF00FF000000
FFFF
FFFF000000FFFF0000FF0000FF000000FFFFFFFFFFFF000000FF0000FF0000FFFF000000
FFFF
FFFF0000FF0000FFFF00000000FF0000FFFFFFFFFFFF0000FF00000000FFFF0000FF0000
FFFF
000000000000FF00FF0000FF0000FF0000FFFFFFFF0000FF0000FF0000FF00FF00000000
0000
00000000000000FF00FFFF00000000FFFF00FFFF00FFFF00000000FFFF00FF0000000000
0000
FFFF0000FFFF00FF0000000000FF0000FFFFFFFFFFFF0000FF0000000000FF00FFFF0000
FFFF
FFFF0000FFFFFF0000000000FF000000FFFFFFFFFFFF000000FF0000000000FFFFFF0000
FFFF
FFFF00FF00FFFF0000000000FF0000FF00FFFFFFFF00FF0000FF0000000000FFFF00FF00
FFFF
FFFFFF00FF0000FF0000000000FFFF00FF00FFFF00FF00FFFF0000000000FF0000FF00FF
FFFF
00FF0000FFFF0000FF0000FFFF00FF00FF00000000FF00FF00FFFF0000FF0000FFFF0000
FF00
FF000000FFFF000000FFFF0000FF00FF00FF0000FF00FF00FF0000FFFF000000FFFF0000
00FF
000000000000FFFF00FFFFFF000000FFFF00000000FFFF000000FFFFFF00FFFF00000000
0000
000000000000FFFFFF00FFFF0000FF0000FF0000FF0000FF0000FFFF00FFFFFF00000000
0000
00FF00000000000000FF000000000000000000000000000000000000FF00000000000000
FF00
FF00000000000000FF0000000000000000000000000000000000000000FF000000000000
00FF
FF0000FF000000FFFFFFFFFF0000FFFFFFFF0000FFFFFFFF0000FFFFFFFFFF000000FF00
00FF
00FFFF000000FF00FFFFFFFF0000FFFFFFFF0000FFFFFFFF0000FFFFFFFF00FF000000FF
FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.436067 0.588183 0.612434 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0246548 0.0192308 0.0246548 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
39 string
39 39 8 [39 0 0 39 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFFFFFFFF0000FF0000FFFF0000FFFFFF00FFFFFF0000FFFF0000FF0000FFFFFFFF
FF0000
0000FF000000FFFFFFFFFF00000000FFFFFFFF00FFFFFFFF00000000FFFFFFFFFF000000
FF0000
FFFF0000FFFFFFFF00FF0000FF00FFFF00FF000000FF00FFFF00FF0000FF00FFFFFFFF00
00FFFF
FF000000FFFFFF0000FF0000FFFF000000FF000000FF000000FFFF0000FF0000FFFFFF00
0000FF
FF00FFFF00FF00FFFFFFFF00FFFFFFFF00FF000000FF00FFFFFFFF00FFFFFFFF00FF00FF
FF00FF
FF00FFFFFF0000000000FF00FF0000FF00FFFF00FFFF00FF0000FF00FF0000000000FFFF
FF00FF
FFFFFFFF0000000000FFFFFF00FF00FFFF00FF00FF00FFFF00FF00FFFFFF0000000000FF
FFFFFF
00FFFF00FF00000000FF00FFFF00FFFFFF0000000000FFFFFF00FFFF00FF00000000FF00
FFFF00
00FF0000FF00000000FF00FF000000FFFF00FF00FF00FFFF000000FF00FF00000000FF00
00FF00
FFFFFFFFFF00FFFFFF00FF00FF00000000FFFF00FFFF00000000FF00FF00FFFFFF00FFFF
FFFFFF
00FF0000FFFFFF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FFFFFF00
00FF00
000000000000FFFFFF000000FFFF0000FF00FF00FF00FF0000FFFF000000FFFFFF000000
000000
FF00FFFFFFFF00FF00FFFFFF000000FF0000FF00FF0000FF000000FFFFFF00FF00FFFFFF
FF00FF
FF0000FFFF00FF00000000FF0000FFFF0000FF00FF0000FFFF0000FF00000000FF00FFFF
0000FF
0000FF00FF0000FF0000FF0000FF0000FFFFFF00FFFFFF0000FF0000FF0000FF0000FF00
FF0000
00FFFF00FFFFFFFFFF00FF00FFFF00000000FF00FF00000000FFFF00FF00FFFFFFFFFF00
FFFF00
FFFF00000000FFFFFF0000FF0000FF0000FFFF00FFFF0000FF0000FF0000FFFFFF000000
00FFFF
FFFFFFFFFFFF000000FFFF000000FF00FF0000000000FF00FF000000FFFF000000FFFFFF
FFFFFF
FFFF000000FFFF00FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00FFFF0000
00FFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000
FFFF000000FFFF00FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00FFFF0000
00FFFF
FFFFFFFFFFFF000000FFFF000000FF00FF0000000000FF00FF000000FFFF000000FFFFFF
FFFFFF
FFFF00000000FFFFFF0000FF0000FF0000FFFF00FFFF0000FF0000FF0000FFFFFF000000
00FFFF
00FFFF00FFFFFFFFFF00FF00FFFF00000000FF00FF00000000FFFF00FF00FFFFFFFFFF00
FFFF00
0000FF00FF0000FF0000FF0000FF0000FFFFFF00FFFFFF0000FF0000FF0000FF0000FF00
FF0000
FF0000FFFF00FF00000000FF0000FFFF0000FF00FF0000FFFF0000FF00000000FF00FFFF
0000FF
FF00FFFFFFFF00FF00FFFFFF000000FF0000FF00FF0000FF000000FFFFFF00FF00FFFFFF
FF00FF
000000000000FFFFFF000000FFFF0000FF00FF00FF00FF0000FFFF000000FFFFFF000000
000000
00FF0000FFFFFF0000FF0000FF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FFFFFF00
00FF00
FFFFFFFFFF00FFFFFF00FF00FF00000000FFFF00FFFF00000000FF00FF00FFFFFF00FFFF
FFFFFF
00FF0000FF00000000FF00FF000000FFFF00FF00FF00FFFF000000FF00FF00000000FF00
00FF00
00FFFF00FF00000000FF00FFFF00FFFFFF0000000000FFFFFF00FFFF00FF00000000FF00
FFFF00
FFFFFFFF0000000000FFFFFF00FF00FFFF00FF00FF00FFFF00FF00FFFFFF0000000000FF
FFFFFF
FF00FFFFFF0000000000FF00FF0000FF00FFFF00FFFF00FF0000FF00FF0000000000FFFF
FF00FF
FF00FFFF00FF00FFFFFFFF00FFFFFFFF00FF000000FF00FFFFFFFF00FFFFFFFF00FF00FF
FF00FF
FF000000FFFFFF0000FF0000FFFF000000FF000000FF000000FFFF0000FF0000FFFFFF00
0000FF
FFFF0000FFFFFFFF00FF0000FF00FFFF00FF000000FF00FFFF00FF0000FF00FFFFFFFF00
00FFFF
0000FF000000FFFFFFFFFF00000000FFFFFFFF00FFFFFFFF00000000FFFFFFFFFF000000
FF0000
0000FFFFFFFFFF0000FF0000FFFF0000FFFFFF00FFFFFF0000FFFF0000FF0000FFFFFFFF
FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.436067 0.782187 0.612434 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00FF0000FF0000000000FFFFFF0000FFFF0000FFFF0000FFFFFF0000000000FF0000
FF00FF00
FF00FF00000000FF00000000FFFF00FFFF0000FFFF0000FFFF00FFFF00000000FF000000
00FF00FF
00FF0000FFFF00000000FFFF000000FFFFFF00000000FFFFFF000000FFFF00000000FFFF
0000FF00
FF000000FFFF00000000FFFF0000FF00FFFF00000000FFFF00FF0000FFFF00000000FFFF
000000FF
0000FFFF0000FFFFFF00FF0000FF00FF0000000000000000FF00FF0000FF00FFFFFF0000
FFFF0000
0000FFFF0000FFFF00FF00FFFF00FF00000000000000000000FF00FFFF00FF00FFFF0000
FFFF0000
FF000000FFFF0000FFFFFF00FF0000FFFFFF00FFFF00FFFFFF0000FF00FFFFFF0000FFFF
000000FF
00FF0000FFFF0000FFFF00FF00FFFF00FFFFFF0000FFFFFF00FFFF00FF00FFFF0000FFFF
0000FF00
00000000FF00FFFF000000FF00FF00FFFF0000FFFF0000FFFF00FF00FF000000FFFF00FF
00000000
0000000000FFFFFF0000FF00FF00FF0000FFFF0000FFFF0000FF00FF00FF0000FFFFFF00
00000000
0000FFFFFF00FF0000FF0000FFFF0000FFFF00000000FFFF0000FFFF0000FF0000FF00FF
FFFF0000
0000FFFF00FF00FFFF000000FFFF0000FFFF00000000FFFF0000FFFF000000FFFF00FF00
FFFF0000
FFFF000000FFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFF00
0000FFFF
FFFF0000FF0000FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF0000FF
0000FFFF
FF0000FF00FF00FF00FF0000FFFF0000FF00FFFFFFFF00FF0000FFFF0000FF00FF00FF00
FF0000FF
00FFFF00FF00FF00FF000000FFFF000000FFFFFFFFFFFF000000FFFF000000FF00FF00FF
00FFFF00
00FFFFFF0000FFFFFF00FFFFFFFFFF000000FF0000FF000000FFFFFFFFFF00FFFFFF0000
FFFFFF00
FF00FFFF0000FFFF00FFFFFFFFFF00FF000000FFFF000000FF00FFFFFFFFFF00FFFF0000
FFFF00FF
FF000000000000FF00FF0000FFFFFFFFFF000000000000FFFFFFFFFF0000FF00FF000000
000000FF
00FF00000000FF00FF000000FFFFFFFF00FF00000000FF00FFFFFFFF000000FF00FF0000
0000FF00
00FF00000000FF00FF000000FFFFFFFF00FF00000000FF00FFFFFFFF000000FF00FF0000
0000FF00
FF000000000000FF00FF0000FFFFFFFFFF000000000000FFFFFFFFFF0000FF00FF000000
000000FF
FF00FFFF0000FFFF00FFFFFFFFFF00FF000000FFFF000000FF00FFFFFFFFFF00FFFF0000
FFFF00FF
00FFFFFF0000FFFFFF00FFFFFFFFFF000000FF0000FF000000FFFFFFFFFF00FFFFFF0000
FFFFFF00
00FFFF00FF00FF00FF000000FFFF000000FFFFFFFFFFFF000000FFFF000000FF00FF00FF
00FFFF00
FF0000FF00FF00FF00FF0000FFFF0000FF00FFFFFFFF00FF0000FFFF0000FF00FF00FF00
FF0000FF
FFFF0000FF0000FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFF0000FF
0000FFFF
FFFF000000FFFF0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF0000FFFF00
0000FFFF
0000FFFF00FF00FFFF000000FFFF0000FFFF00000000FFFF0000FFFF000000FFFF00FF00
FFFF0000
0000FFFFFF00FF0000FF0000FFFF0000FFFF00000000FFFF0000FFFF0000FF0000FF00FF
FFFF0000
0000000000FFFFFF0000FF00FF00FF0000FFFF0000FFFF0000FF00FF00FF0000FFFFFF00
00000000
00000000FF00FFFF000000FF00FF00FFFF0000FFFF0000FFFF00FF00FF000000FFFF00FF
00000000
00FF0000FFFF0000FFFF00FF00FFFF00FFFFFF0000FFFFFF00FFFF00FF00FFFF0000FFFF
0000FF00
FF000000FFFF0000FFFFFF00FF0000FFFFFF00FFFF00FFFFFF0000FF00FFFFFF0000FFFF
000000FF
0000FFFF0000FFFF00FF00FFFF00FF00000000000000000000FF00FFFF00FF00FFFF0000
FFFF0000
0000FFFF0000FFFFFF00FF0000FF00FF0000000000000000FF00FF0000FF00FFFFFF0000
FFFF0000
FF000000FFFF00000000FFFF0000FF00FFFF00000000FFFF00FF0000FFFF00000000FFFF
000000FF
00FF0000FFFF00000000FFFF000000FFFFFF00000000FFFFFF000000FFFF00000000FFFF
0000FF00
FF00FF00000000FF00000000FFFF00FFFF0000FFFF0000FFFF00FFFF00000000FF000000
00FF00FF
00FF00FF0000FF0000000000FFFFFF0000FFFF0000FFFF0000FFFFFF0000000000FF0000
FF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.436067 0.97619 0.612434 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0234522 0.0192308 0.0234522 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
41 string
41 41 8 [41 0 0 41 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFF0000FF00000000FF00FFFFFFFF0000FF000000FF0000FFFFFFFF00FF00000000FF
0000FFFF00
FF00FFFF00FF00FF0000FF00FFFFFF00FFFFFFFF00FFFFFFFF00FFFFFF00FF0000FF00FF
00FFFF00FF
FFFF00FFFF000000FFFF00FFFF0000FFFFFF00FF00FF00FFFFFF0000FFFF00FFFF000000
FFFF00FFFF
00FFFF00FFFFFFFF0000FF00FFFFFFFFFF00FF000000FF00FFFFFFFFFF00FF0000FFFFFF
FF00FFFF00
0000FFFF0000FF00FF00FF000000FF0000000000000000000000FF000000FF00FF00FF00
00FFFF0000
FFFF00FF0000FF00FFFFFFFF00FFFFFFFF00FF000000FF00FFFFFFFF00FFFFFFFF00FF00
00FF00FFFF
000000FFFFFF0000FF0000FF000000FFFFFF00FF00FF00FFFFFF000000FF0000FF0000FF
FFFF000000
00FF00FF000000000000FFFF0000FF00FFFFFFFF00FFFFFFFF00FF0000FFFF0000000000
00FF00FF00
0000FF00FFFFFF00000000FF00FF00FF0000FF000000FF0000FF00FF00FF00000000FFFF
FF00FF0000
0000FF0000FF000000000000FF00000000FF00FF00FF00FF00000000FF000000000000FF
0000FF0000
FFFF00FFFFFF00FF00000000FFFFFF00FF00000000000000FF00FFFFFF00000000FF00FF
FFFF00FFFF
0000FF0000FFFFFFFF000000FFFF00FF000000FF00FF000000FF00FFFF000000FFFFFFFF
0000FF0000
FFFFFFFF0000000000FFFFFF000000FF00FF00FF00FF00FF00FF000000FFFFFF00000000
00FFFFFFFF
FFFF00FF00FF0000FF00FFFF00000000FF00FFFF00FFFF00FF00000000FFFF00FF0000FF
00FF00FFFF
FFFF00FFFFFF00FF0000FF00000000FF0000FFFF00FFFF0000FF00000000FF0000FF00FF
FFFF00FFFF
FF00FFFF00FFFF00FF0000FFFF00FF0000FF00FF00FF00FF0000FF00FFFF0000FF00FFFF
00FFFF00FF
00FFFFFF00FFFFFF0000FF0000FF00000000000000000000000000FF0000FF0000FFFFFF
00FFFFFF00
00FFFF000000FFFF00FF0000FF0000FF0000FFFF00FFFF0000FF0000FF0000FF00FFFF00
0000FFFF00
FFFF00FF00FF00FFFF00000000FFFF0000FF0000000000FF0000FFFF00000000FFFF00FF
00FF00FFFF
00FFFF000000FFFF00FF00FFFFFFFFFF00FF0000000000FF00FFFFFFFFFF00FF00FFFF00
0000FFFF00
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000
00FFFF000000FFFF00FF00FFFFFFFFFF00FF0000000000FF00FFFFFFFFFF00FF00FFFF00
0000FFFF00
FFFF00FF00FF00FFFF00000000FFFF0000FF0000000000FF0000FFFF00000000FFFF00FF
00FF00FFFF
00FFFF000000FFFF00FF0000FF0000FF0000FFFF00FFFF0000FF0000FF0000FF00FFFF00
0000FFFF00
00FFFFFF00FFFFFF0000FF0000FF00000000000000000000000000FF0000FF0000FFFFFF
00FFFFFF00
FF00FFFF00FFFF00FF0000FFFF00FF0000FF00FF00FF00FF0000FF00FFFF0000FF00FFFF
00FFFF00FF
FFFF00FFFFFF00FF0000FF00000000FF0000FFFF00FFFF0000FF00000000FF0000FF00FF
FFFF00FFFF
FFFF00FF00FF0000FF00FFFF00000000FF00FFFF00FFFF00FF00000000FFFF00FF0000FF
00FF00FFFF
FFFFFFFF0000000000FFFFFF000000FF00FF00FF00FF00FF00FF000000FFFFFF00000000
00FFFFFFFF
0000FF0000FFFFFFFF000000FFFF00FF000000FF00FF000000FF00FFFF000000FFFFFFFF
0000FF0000
FFFF00FFFFFF00FF00000000FFFFFF00FF00000000000000FF00FFFFFF00000000FF00FF
FFFF00FFFF
0000FF0000FF000000000000FF00000000FF00FF00FF00FF00000000FF000000000000FF
0000FF0000
0000FF00FFFFFF00000000FF00FF00FF0000FF000000FF0000FF00FF00FF00000000FFFF
FF00FF0000
00FF00FF000000000000FFFF0000FF00FFFFFFFF00FFFFFFFF00FF0000FFFF0000000000
00FF00FF00
000000FFFFFF0000FF0000FF000000FFFFFF00FF00FF00FFFFFF000000FF0000FF0000FF
FFFF000000
FFFF00FF0000FF00FFFFFFFF00FFFFFFFF00FF000000FF00FFFFFFFF00FFFFFFFF00FF00
00FF00FFFF
0000FFFF0000FF00FF00FF000000FF0000000000000000000000FF000000FF00FF00FF00
00FFFF0000
00FFFF00FFFFFFFF0000FF00FFFFFFFFFF00FF000000FF00FFFFFFFFFF00FF0000FFFFFF
FF00FFFF00
FFFF00FFFF000000FFFF00FFFF0000FFFFFF00FF00FF00FFFFFF0000FFFF00FFFF000000
FFFF00FFFF
FF00FFFF00FF00FF0000FF00FFFFFF00FFFFFFFF00FFFFFFFF00FFFFFF00FF0000FF00FF
00FFFF00FF
00FFFF0000FF00000000FF00FFFFFFFF0000FF000000FF0000FFFFFFFF00FF00000000FF
0000FFFF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.630071 0.200176 0.806437 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0300481 0.0192308 0.0300481 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.630071 0.39418 0.806437 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0291375 0.0192308 0.0291375 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
33 string
33 33 8 [33 0 0 33 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.630071 0.588183 0.806437 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0282805 0.0192308 0.0282805 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
34 string
34 34 8 [34 0 0 34 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.630071 0.782187 0.806437 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0274725 0.0192308 0.0274725 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
35 string
35 35 8 [35 0 0 35 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.630071 0.97619 0.806437 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0267094 0.0192308 0.0267094 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
36 string
36 36 8 [36 0 0 36 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.824074 0.200176 1.00044 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0356125 0.0192308 0.0356125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
27 string
27 27 8 [27 0 0 27 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFF00FFFF0000FFFFFFFF00000000FFFFFFFF0000FFFFFFFFFF
FF00FFFF00FFFFFF00FFFF00FF00000000FFFFFFFFFF00FF0000FF
FF000000FFFF00FF0000000000FF0000FF00FF0000FF00FF00FFFF
FFFFFF00FFFFFFFFFF0000000000FF00FF00FFFF00FF000000FF00
FF000000FF0000FFFFFFFFFFFF00000000FF000000FFFFFFFF00FF
00FFFFFFFF00FF00FF00FFFFFF00FFFFFF000000000000FFFFFFFF
00FF00000000FF00FFFF00FFFF00FF0000FFFFFFFFFF00FF00FF00
FFFF00FF0000FF00FF00FFFF0000FFFF0000FF000000FFFFFFFF00
FFFFFFFF0000FFFF0000FFFF00FFFF00FF0000FFFFFFFFFF0000FF
FFFF0000FF00FF000000FF0000000000FF000000FF00FF0000FFFF
FF00FFFF00FF0000FFFFFFFFFFFF00FFFFFFFFFF00FFFF0000FFFF
0000000000FF00FF0000FF00FF00FF00FF00FFFFFFFFFF000000FF
000000FF00FFFFFFFF0000FF00FF00FFFF000000FFFFFF0000FF00
0000FF0000000000FF00FF00FF00FF00FF00FF0000000000FF0000
00FF0000FFFFFF000000FFFF00FF00FF0000FFFFFFFF00FF000000
FF000000FFFFFFFFFF00FF00FF00FF00FF0000FF00FF0000000000
FFFF0000FFFF00FFFFFFFFFF00FFFFFFFFFFFF0000FF00FFFF00FF
FFFF0000FF00FF000000FF0000000000FF000000FF00FF0000FFFF
FF0000FFFFFFFFFF0000FF00FFFF00FFFF0000FFFF0000FFFFFFFF
00FFFFFFFF000000FF0000FFFF0000FFFF00FF00FF0000FF00FFFF
00FF00FF00FFFFFFFFFF0000FF00FFFF00FFFF00FF00000000FF00
FFFFFFFF000000000000FFFFFF00FFFFFF00FF00FF00FFFFFFFF00
FF00FFFFFFFF000000FF00000000FFFFFFFFFFFF0000FF000000FF
00FF000000FF00FFFF00FF00FF0000000000FFFFFFFFFF00FFFFFF
FFFF00FF00FF0000FF00FF0000FF0000000000FF00FFFF000000FF
FF0000FF00FFFFFFFFFF00000000FF00FFFF00FFFFFF00FFFF00FF
FFFFFFFFFF0000FFFFFFFF00000000FFFFFFFF0000FFFF00FFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.824074 0.39418 1.00044 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0343407 0.0192308 0.0343407 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
28 string
28 28 8 [28 0 0 28 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFF00000000000000FF0000FFFFFFFFFF00FFFFFFFFFFFFFFFFFF
00FF00FF000000FFFFFFFFFF00FF0000FF0000FF00FFFFFFFFFFFF00
FFFF0000FF00FFFF0000000000FF00FF000000FF00FFFFFF000000FF
FF0000FFFFFF0000FFFFFF000000FFFF00FF00FF00FFFF00FF000000
0000FFFF0000FF00FF000000000000FFFF00FFFF00FF000000FFFFFF
00FFFFFFFF0000FFFF00FF00FF00FFFF00000000FF0000FFFF0000FF
FF0000FF0000FF000000FFFF000000FF00FFFF0000FF00000000FF00
00FF00000000FF00FFFF0000FF00FFFF00FFFF0000FF000000FF00FF
FF00FF00FFFF00FFFFFFFF00FFFFFF000000FFFF000000FF00000000
FF0000FFFF000000FFFF00FF00FF00000000FFFF00FF00000000FFFF
00FF00FFFF0000FF00FFFF00FFFF000000FFFFFF0000FFFFFF000000
00FFFFFF00FF0000FF00FF00FFFF000000FFFFFF00FFFFFFFFFFFFFF
00FFFFFF0000FFFFFF00FFFF0000000000000000FF0000FF0000FFFF
00FF000000FF00FF000000FF0000000000FFFF0000000000FFFF0000
FF00FFFFFFFF0000FF00000000000000FFFFFFFFFF0000FF0000FFFF
FFFFFFFF00000000FF00FF0000000000FF00000000FF00FF0000FF00
00FF00FFFF00FF0000FF00FFFFFF0000FF00000000000000FF00FFFF
FFFF0000FFFFFF00FFFF00FF0000FFFFFF00FF00FFFF00FF000000FF
00FF00FF000000FFFFFF00FF0000FF000000FFFFFFFF00FF00000000
0000FFFF000000FFFFFFFFFF000000FFFF00FFFF0000FF00FF0000FF
FF00FF00FFFFFF00000000000000FF0000FF00FF00FFFFFF0000FF00
FF00FF00FFFFFF0000FF00FF000000FF0000000000FFFFFFFFFFFF00
0000FFFF0000FF00FF00FFFFFFFF00FFFF00000000FF0000FF00FFFF
00FF00FF00FF00FF00000000FFFFFF00FF00FF00FF00FF00000000FF
FFFF000000FF000000000000FF00FF000000FF0000FFFFFF0000FF00
FFFFFF0000FF00FFFF0000FFFFFF0000FF0000000000000000FF00FF
0000FF000000FFFFFFFF00FF00FF0000FFFF00FF0000FFFF00000000
00FFFFFFFFFFFF0000FF00FF000000FF0000FFFFFF00000000FFFF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.824074 0.588183 1.00044 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0331565 0.0192308 0.0331565 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
29 string
29 29 8 [29 0 0 29 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFF00FFFF00FF00FFFF00FF0000FF00FF00FFFFFFFFFFFFFFFF
0000FFFFFF00000000FFFFFFFF000000FFFFFF0000FF00FFFFFFFFFF00
FF000000FF00000000FF00000000FFFF0000FFFF00000000FF000000FF
FF0000FF0000000000FFFFFF000000FFFFFFFF00FF00FF0000FFFF00FF
00FF00FF00000000FF0000FFFF00000000FFFFFFFF00FF000000000000
00FF000000FF00FFFF0000FF00FFFF0000FF000000FF0000FFFF0000FF
0000FFFFFFFF000000FFFFFF0000000000FFFFFF00FF00000000FFFF00
00FF00FF00FFFFFF0000FF000000FFFF00FFFFFF0000FFFFFFFF000000
FFFF0000FFFFFF000000FFFF00FFFFFF00FF000000FFFFFFFF000000FF
0000000000FF0000FF00000000FF00FFFF000000FFFFFF00FF00FFFF00
FFFF0000FF00FFFFFF00FF0000FFFFFF0000FF0000FFFF000000FFFFFF
FFFFFFFF00FFFF00FF0000FFFFFF0000FF00000000FFFF00FF0000FFFF
FFFF00FF00FFFFFFFFFFFF00000000000000FFFFFF00FF00FF00000000
00FF00FF000000FFFF000000FFFFFFFFFF0000FF00000000FF0000FF00
00FF00FFFFFFFFFFFF0000FFFFFF00FFFFFF0000FFFFFFFFFFFF00FF00
00FFFFFFFFFF00FF00FF00FFFFFFFFFFFFFF0000FF0000FF0000FFFF00
FF00FFFFFFFFFF0000FFFFFF0000000000FFFFFF00FFFF000000FFFF00
FF00000000FF00FFFFFF00FF000000FF000000FF00000000FFFFFF00FF
FFFF0000FF00FFFFFF00FF0000FFFFFF0000FF0000FFFF000000FFFFFF
00FF00FF000000FFFF0000FF00000000FFFF0000FF00FFFFFFFFFF0000
FFFFFFFFFF0000000000FFFFFF00FF00FFFF000000FF0000FFFFFF00FF
00FFFFFF000000FF00FFFFFFFF00FFFFFF00FF0000000000FFFFFF0000
00FF00FF00FF00FFFFFFFF00000000000000FFFFFF000000FF00000000
0000FFFFFFFF000000FF00FF0000FFFF00FF00FFFF0000000000FFFFFF
00FFFF0000FFFF00FF0000FF00FF00FFFFFFFFFFFF0000FF00FFFF0000
FF00FFFFFFFF0000FF00FF00000000FFFF00FFFF0000FFFFFFFF0000FF
FFFF00FF00FFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFFFF00FF00FFFF
000000FFFFFFFF000000FF00000000000000FFFF00FFFF00FFFF00FF00
FFFFFFFFFF00FFFF00FF00FFFF00FF0000FF00FF00FFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.824074 0.782187 1.00044 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0320513 0.0192308 0.0320513 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
30 string
30 30 8 [30 0 0 30 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF0000FFFF00FFFF00FF0000FFFFFFFF0000FF00FFFF00FFFF0000FF00
FF000000FFFFFF0000FF00FFFF00FFFF00FFFF00FF0000FFFFFF000000FF
00000000FF0000FFFFFF00FFFF00000000FFFF00FFFFFF0000FF00000000
0000000000FFFF00FFFFFF0000FF0000FF0000FFFFFF00FFFF0000000000
FFFFFF000000FF00FFFFFFFF00FFFFFFFF00FFFFFFFF00FF000000FFFFFF
FFFF00FF000000FFFFFFFFFFFF00FFFF00FFFFFFFFFFFF000000FF00FFFF
00FF00FFFF00000000000000FF00FFFF00FF00000000000000FFFF00FF00
FF00FF0000FF00000000000000FFFFFFFF00000000000000FF0000FF00FF
FF00FFFFFFFF000000000000FF00FFFF00FF000000000000FFFFFFFF00FF
00FFFFFFFFFF00000000000000FFFFFFFF00000000000000FFFFFFFFFF00
FF0000FFFFFF000000000000FFFFFFFFFFFF000000000000FFFFFF0000FF
00FFFF00FFFF000000000000FFFFFFFFFFFF000000000000FFFF00FFFF00
00FFFF0000FFFF00FF00FFFF0000FFFF0000FFFF00FF00FFFF0000FFFF00
FF0000FFFF0000FF00FFFFFF0000FFFF0000FFFFFF00FF0000FFFF0000FF
FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF
FFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF0000FFFF
FF0000FFFF0000FF00FFFFFF0000FFFF0000FFFFFF00FF0000FFFF0000FF
00FFFF0000FFFF00FF00FFFF0000FFFF0000FFFF00FF00FFFF0000FFFF00
00FFFF00FFFF000000000000FFFFFFFFFFFF000000000000FFFF00FFFF00
FF0000FFFFFF000000000000FFFFFFFFFFFF000000000000FFFFFF0000FF
00FFFFFFFFFF00000000000000FFFFFFFF00000000000000FFFFFFFFFF00
FF00FFFFFFFF000000000000FF00FFFF00FF000000000000FFFFFFFF00FF
FF00FF0000FF00000000000000FFFFFFFF00000000000000FF0000FF00FF
00FF00FFFF00000000000000FF00FFFF00FF00000000000000FFFF00FF00
FFFF00FF000000FFFFFFFFFFFF00FFFF00FFFFFFFFFFFF000000FF00FFFF
FFFFFF000000FF00FFFFFFFF00FFFFFFFF00FFFFFFFF00FF000000FFFFFF
0000000000FFFF00FFFFFF0000FF0000FF0000FFFFFF00FFFF0000000000
00000000FF0000FFFFFF00FFFF00000000FFFF00FFFFFF0000FF00000000
FF000000FFFFFF0000FF00FFFF00FFFF00FFFF00FF0000FFFFFF000000FF
00FF0000FFFF00FFFF00FF0000FFFFFFFF0000FF00FFFF00FFFF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.824074 0.97619 1.00044 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0310174 0.0192308 0.0310174 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
31 string
31 31 8 [31 0 0 31 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00FF0000FF000000FFFF0000FF00FF0000FFFF000000FF0000FF00FF00
FF00FF00000000FF0000FFFFFF00FF00FF00FFFFFF0000FF00000000FF00FF
00FF0000FFFF000000FF00FFFFFF000000FFFFFF00FF000000FFFF0000FF00
FF000000FFFF0000FF00FF0000FF000000FF0000FF00FF0000FFFF000000FF
0000FFFF0000FF00FF00FFFF0000FF00FF0000FFFF00FF00FF0000FFFF0000
0000FFFF000000FF00FFFFFFFF0000000000FFFFFFFF00FF000000FFFF0000
FF000000FF000000000000FF00FF000000FF00FF000000000000FF000000FF
00FF000000FF00000000FF000000000000000000FF00000000FF000000FF00
000000FFFF00000000000000FFFF000000FFFF00000000000000FFFF000000
0000FF0000FF00000000000000FF000000FF00000000000000FF0000FF0000
FFFF00FFFFFF00FF000000FFFFFF000000FFFFFF000000FF00FFFFFF00FFFF
FFFFFF00FFFFFF000000FF000000000000000000FF000000FFFFFF00FFFFFF
00FFFF0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FFFF00
0000FFFF0000FF00FFFFFF00FF0000000000FF00FFFFFF00FF0000FFFF0000
FFFF0000FF000000000000000000000000000000000000000000FF0000FFFF
00000000000000000000000000000000000000000000000000000000000000
FFFF0000FF000000000000000000000000000000000000000000FF0000FFFF
0000FFFF0000FF00FFFFFF00FF0000000000FF00FFFFFF00FF0000FFFF0000
00FFFF0000FF0000FF00FF0000FF000000FF0000FF00FF0000FF0000FFFF00
FFFFFF00FFFFFF000000FF000000000000000000FF000000FFFFFF00FFFFFF
FFFF00FFFFFF00FF000000FFFFFF000000FFFFFF000000FF00FFFFFF00FFFF
0000FF0000FF00000000000000FF000000FF00000000000000FF0000FF0000
000000FFFF00000000000000FFFF000000FFFF00000000000000FFFF000000
00FF000000FF00000000FF000000000000000000FF00000000FF000000FF00
FF000000FF000000000000FF00FF000000FF00FF000000000000FF000000FF
0000FFFF000000FF00FFFFFFFF0000000000FFFFFFFF00FF000000FFFF0000
0000FFFF0000FF00FF00FFFF0000FF00FF0000FFFF00FF00FF0000FFFF0000
FF000000FFFF0000FF00FF0000FF000000FF0000FF00FF0000FFFF000000FF
00FF0000FFFF000000FF00FFFFFF000000FFFFFF00FF000000FFFF0000FF00
FF00FF00000000FF0000FFFFFF00FF00FF00FFFFFF0000FF00000000FF00FF
00FF00FF0000FF000000FFFF0000FF00FF0000FFFF000000FF0000FF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.01808 0.200176 1.19444 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0437063 0.0192308 0.0437063 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
22 string
22 22 8 [22 0 0 22 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00FFFF00FFFF0000FFFF0000FFFF00FFFF00FF00
FF00FF0000FFFFFF0000FFFF0000FFFFFF0000FF00FF
00FF000000FFFF00FF00FFFF00FF00FFFF000000FF00
FF000000FF0000FF00FFFFFFFF00FF0000FF000000FF
FF0000FF0000FFFF0000FFFF0000FFFF0000FF0000FF
00FFFF000000FFFF0000FFFF0000FFFF000000FFFF00
FFFFFF00FFFF000000FF0000FF000000FFFF00FFFFFF
FFFF00FFFFFF0000FF00000000FF0000FFFFFF00FFFF
0000FF00000000FF000000000000FF00000000FF0000
000000FF0000FF0000000000000000FF0000FF000000
FFFFFFFFFFFF00000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF00000000000000000000FFFFFFFFFFFF
000000FF0000FF0000000000000000FF0000FF000000
0000FF00000000FF000000000000FF00000000FF0000
FFFF00FFFFFF0000FF00000000FF0000FFFFFF00FFFF
FFFFFF00FFFF000000FF0000FF000000FFFF00FFFFFF
00FFFF000000FFFF0000FFFF0000FFFF000000FFFF00
FF0000FF0000FFFF0000FFFF0000FFFF0000FF0000FF
FF000000FF0000FF00FFFFFFFF00FF0000FF000000FF
00FF000000FFFF00FF00FFFF00FF00FFFF000000FF00
FF00FF0000FFFFFF0000FFFF0000FFFFFF0000FF00FF
00FF00FFFF00FFFF0000FFFF0000FFFF00FFFF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.01808 0.39418 1.19444 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.041806 0.0192308 0.041806 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
23 string
23 23 8 [23 0 0 23 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFF00FFFFFFFFFFFF00FFFFFFFFFFFF00FFFF0000
000000000000FFFFFFFF000000FFFFFFFF000000000000
FF0000FFFF00FF00FF00FF00FF00FF00FF00FFFF0000FF
FF00FF0000FFFFFF00000000000000FFFFFF0000FF00FF
0000FF000000FF00FFFFFF00FFFFFF00FF000000FF0000
FF0000FF0000FFFFFFFF000000FFFFFFFF0000FF0000FF
FFFFFFFFFFFF00FF0000FF00FF0000FF00FFFFFFFFFFFF
FFFF00FF00FFFF00FFFFFF00FFFFFF00FFFF00FF00FFFF
FFFFFF00FFFF00FF00FFFF00FFFF00FF00FFFF00FFFFFF
FFFF0000FFFF00FFFF00FF00FF00FFFF00FFFF0000FFFF
FF00FF00FF00FFFFFFFF000000FFFFFFFF00FF00FF00FF
0000000000000000000000000000000000000000000000
FF00FF00FF00FFFFFFFF000000FFFFFFFF00FF00FF00FF
FFFF0000FFFF00FFFF00FF00FF00FFFF00FFFF0000FFFF
FFFFFF00FFFF00FF00FFFF00FFFF00FF00FFFF00FFFFFF
FFFF00FF00FFFF00FFFFFF00FFFFFF00FFFF00FF00FFFF
FFFFFFFFFFFF00FF0000FF00FF0000FF00FFFFFFFFFFFF
FF0000FF0000FFFFFFFF000000FFFFFFFF0000FF0000FF
0000FF000000FF00FFFFFF00FFFFFF00FF000000FF0000
FF00FF0000FFFFFF00000000000000FFFFFF0000FF00FF
FF0000FFFF00FF00FF00FF00FF00FF00FF00FFFF0000FF
000000000000FFFFFFFF000000FFFFFFFF000000000000
0000FFFF00FFFFFFFFFFFF00FFFFFFFFFFFF00FFFF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.01808 0.588183 1.19444 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0400641 0.0192308 0.0400641 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
24 string
24 24 8 [24 0 0 24 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00000000FF00000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFF00000000000000FF00000000
00FF0000FFFFFF00000000FFFFFFFF0000FF0000FFFFFFFF
0000FFFF000000FF00FF0000FF00FFFFFF00FFFF0000FF00
0000FFFFFFFFFFFFFFFF00FF00FFFF00FF00FFFFFF0000FF
FF0000FFFFFF00FF00FF00FF00FF00000000FFFF0000FFFF
FF00FF0000FFFF0000FF00FFFF00000000FFFF00FF000000
FFFFFF00FF0000FFFFFFFF0000FFFF00FF0000FFFF0000FF
FF00FF00FFFFFFFF0000FFFF000000000000FF00FF000000
FFFFFF0000FF000000000000FFFF0000FFFF0000FF0000FF
00FF00FF00FFFFFFFFFF0000FFFF0000FF00FF0000FF00FF
00FF00FFFF0000FF0000FFFF0000FFFF000000FF00FF00FF
FFFFFFFFFFFF00FFFF00FF00FF0000000000FFFFFFFF0000
0000FFFFFFFFFFFFFFFFFF00FF0000FFFF00FFFFFFFFFFFF
FFFF0000FFFFFF000000000000FF0000FF00FFFFFFFF0000
0000FFFFFFFFFF000000FF00FFFF0000FF00FFFF0000FFFF
0000FF00FFFF00FF0000FFFFFFFF00FFFF00FFFFFF00FF00
00FFFF00FFFFFF00FF00FFFFFFFFFFFF00FFFFFFFF00FFFF
00FF00FF00FF00FF00FFFFFF0000FF000000FF00FFFF0000
FFFF0000FF00FFFFFF000000FFFF00FFFF0000FFFF00FF00
00FF00000000FF00FF00FF000000000000FF0000FFFFFFFF
0000FFFF000000FFFFFFFFFF00FF00FFFF0000000000FF00
FF00FF000000FF0000FF00FF00FF0000FF0000FF00FFFF00
FF0000FFFF00FF00FFFF00FF00FFFF00FF00FFFFFF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.01808 0.782187 1.19444 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0384615 0.0192308 0.0384615 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
25 string
25 25 8 [25 0 0 25 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000FFFF00FFFFFF00FFFF00000000FFFFFFFF00FFFFFF00
FFFFFFFFFF00000000FFFF00FF00FF000000FF00FFFFFFFF00
00FF00FF00FFFFFFFFFFFFFFFFFFFF00FFFF00FF00FF00FFFF
FF000000FFFFFF00FF00000000000000FF00FFFFFF000000FF
00FF000000FF0000FF000000FF0000FFFF00FFFF000000FFFF
0000FF00FFFFFF000000FFFFFFFFFFFF000000FFFF00FF00FF
FF0000FF000000FF00FFFFFF000000FF00FF00FFFFFFFFFFFF
FF00FF000000FFFFFF0000FF00FF0000FFFFFF000000FF00FF
FF00FFFFFF0000FFFF0000FF00FF0000FFFF0000FFFFFF00FF
0000FF00FF00FF000000FF0000FF00000000FFFF000000FF00
00FFFFFF00FFFF000000FFFFFFFFFFFF000000FF00FFFFFFFF
FF00FFFF00FF00FFFF00FF00FF00FFFFFFFFFFFF00FFFF0000
00000000000000000000000000000000000000000000000000
FF00FFFF00FF00FFFF00FF00FF00FFFFFFFFFFFF00FFFF0000
00FFFFFF00FFFF000000FFFFFFFFFFFF000000FF00FFFFFFFF
0000FF00FF00FF000000FF0000FF00000000FFFF000000FF00
FF00FFFFFF0000FFFF0000FF00FF0000FFFF0000FFFFFF00FF
FF00FF000000FFFFFF0000FF00FF0000FFFFFF000000FF00FF
FF0000FF000000FF00FFFFFF000000FF00FF00FFFFFFFFFFFF
0000FF00FFFFFF000000FFFFFFFFFFFF000000FFFF00FF00FF
00FF000000FF0000FF000000FF0000FFFF00FFFF000000FFFF
FF000000FFFFFF00FF00000000000000FF00FFFFFF000000FF
00FF00FF00FFFFFFFFFFFFFFFFFFFF00FFFF00FF00FF00FFFF
FFFFFFFFFF00000000FFFF00FF00FF000000FF00FFFFFFFF00
000000FFFF00FFFFFF00FFFF00000000FFFFFFFF00FFFFFF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.01808 0.97619 1.19444 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0369822 0.0192308 0.0369822 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
26 string
26 26 8 [26 0 0 26 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00FFFF00FF0000FF00FF00FFFF00FF00FF0000FF00FFFF00FF
00FF00000000FFFFFF0000FFFFFF000000FFFFFFFF0000FFFF00
FFFF000000FF0000000000FFFF00FFFF000000FFFFFFFF0000FF
FF00FF0000FFFFFF00FFFF00FFFFFFFFFF00FFFF0000000000FF
0000FF0000FFFFFF0000FFFFFFFF00FF0000FFFF000000000000
FFFFFF000000FF0000FFFFFFFF00FF00FF00000000FFFFFF00FF
00FFFFFFFF00FF00FF00FF000000FFFF00FF00FFFFFFFF00FF00
00FF00FFFF0000FF00FF00FF0000FF00FF00FF0000FFFF00FF00
FFFF00000000FF00000000FF0000FF00000000FF00000000FFFF
000000FF00FF00FF00FFFF00000000FFFF00FF00FF00FF000000
FF00FFFFFF00FF0000FFFFFFFFFF00FFFF0000FFFFFFFF0000FF
0000FFFF00FFFFFFFF00000000FF00FF00FFFF00FFFF00FFFF00
FFFF00FFFF0000000000FFFF000000FF00000000FFFFFFFFFFFF
FFFFFFFFFFFF00000000FF000000FFFF0000000000FFFF00FFFF
00FFFF00FFFF00FFFF00FF00FF00000000FFFFFFFF00FFFF0000
FF0000FFFFFFFF0000FFFF00FFFFFFFFFF0000FF00FFFFFF00FF
000000FF00FF00FF00FFFF00000000FFFF00FF00FF00FF000000
FFFF00000000FF00000000FF0000FF00000000FF00000000FFFF
00FF00FFFF0000FF00FF00FF0000FF00FF00FF0000FFFF00FF00
00FF00FFFFFFFF00FF00FFFF000000FF00FF00FF00FFFFFFFF00
FF00FFFFFF00000000FF00FF00FFFFFFFF0000FF000000FFFFFF
000000000000FFFF0000FF00FFFFFFFF0000FFFFFF0000FF0000
FF0000000000FFFF00FFFFFFFFFF00FFFF00FFFFFF0000FF00FF
FF0000FFFFFFFF000000FFFF00FFFF0000000000FF000000FFFF
00FFFF0000FFFFFFFF000000FFFFFF0000FFFFFF00000000FF00
FF00FFFF00FF0000FF00FF00FFFF00FF00FF0000FF00FFFF00FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.21208 0.200176 1.38845 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0565611 0.0192308 0.0565611 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
17 string
17 17 8 [17 0 0 17 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFF00FF00000000000000FF00FFFFFF
000000FF00FFFFFF00FFFFFF00FF000000
00FFFF00000000FF00FF00000000FFFF00
00FF00FFFFFFFFFF00FFFFFFFFFF00FF00
00FFFF000000FFFF00FFFF000000FFFF00
0000FFFF00FF0000000000FF00FFFF0000
FF00FFFFFFFF0000000000FFFFFFFF00FF
FFFF000000FFFF000000FFFF000000FFFF
FFFFFF0000FFFF000000FFFF0000FFFFFF
FFFF00FF000000FF00FF000000FF00FFFF
FFFFFFFF000000000000000000FFFFFFFF
0000FFFFFFFFFF000000FFFFFFFFFF0000
00FFFFFFFF00FF000000FF00FFFFFFFF00
FFFF0000FFFF0000000000FFFF0000FFFF
00000000FF0000FF00FF0000FF00000000
FF0000FFFF0000FF00FF0000FFFF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.21208 0.39418 1.38845 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0534188 0.0192308 0.0534188 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
18 string
18 18 8 [18 0 0 18 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF000000FF000000000000FF000000FF00
FF000000FF0000000000000000FF000000FF
000000000000FFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFF000000000000
00FF00000000FF00FFFF00FF00000000FF00
FF000000000000FFFFFFFF000000000000FF
0000FFFFFF0000000000000000FFFFFF0000
0000FFFF00FF000000000000FF00FFFF0000
0000FFFFFFFF000000000000FFFFFFFF0000
0000FFFFFFFF000000000000FFFFFFFF0000
0000FFFF00FF000000000000FF00FFFF0000
0000FFFFFF0000000000000000FFFFFF0000
FF000000000000FFFFFFFF000000000000FF
00FF00000000FF00FFFF00FF00000000FF00
000000000000FFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFF000000000000
FF000000FF0000000000000000FF000000FF
00FF000000FF000000000000FF000000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.21208 0.588183 1.38845 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0506073 0.0192308 0.0506073 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
19 string
19 19 8 [19 0 0 19 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF00FFFFFFFFFF00FFFFFFFFFF00FF0000
00000000FF000000FF00FF000000FF00000000
FF00000000FFFF0000000000FFFF00000000FF
000000000000FF00FF00FF00FF000000000000
FFFF00000000FF00FF00FF00FF00000000FFFF
FF00FF000000FF00FF00FF00FF000000FF00FF
FF00FFFFFFFF00FFFF00FFFF00FFFFFFFF00FF
FF0000000000FF0000000000FF0000000000FF
FFFF00FFFFFFFF0000000000FFFFFFFF00FFFF
00000000000000000000000000000000000000
FFFF00FFFFFFFF0000000000FFFFFFFF00FFFF
FF0000000000FF0000000000FF0000000000FF
FF00FFFFFFFF00FFFF00FFFF00FFFFFFFF00FF
FF00FF000000FF00FF00FF00FF000000FF00FF
FFFF00000000FF00FF00FF00FF00000000FFFF
000000000000FF00FF00FF00FF000000000000
FF00000000FFFF0000000000FFFF00000000FF
00000000FF000000FF00FF000000FF00000000
0000FF00FFFFFFFFFF00FFFFFFFFFF00FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.21208 0.782187 1.38845 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0480769 0.0192308 0.0480769 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
20 string
20 20 8 [20 0 0 20 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF00
FF00FFFFFFFFFFFF00000000FFFFFFFFFFFF00FF
FFFF000000FFFFFFFF0000FFFFFFFF000000FFFF
FFFF0000FF00FFFF00FFFF00FFFF00FF0000FFFF
FFFF00FF000000FF00000000FF000000FF00FFFF
FFFFFF000000FF000000000000FF000000FFFFFF
FFFFFFFF00FF0000000000000000FF00FFFFFFFF
FFFFFFFFFF00000000000000000000FFFFFFFFFF
0000FF0000000000000000000000000000FF0000
000000FF000000000000000000000000FF000000
000000FF000000000000000000000000FF000000
0000FF0000000000000000000000000000FF0000
FFFFFFFFFF00000000000000000000FFFFFFFFFF
FFFFFFFF00FF0000000000000000FF00FFFFFFFF
FFFFFF000000FF000000000000FF000000FFFFFF
FFFF00FF000000FF00000000FF000000FF00FFFF
FFFF0000FF00FFFF00FFFF00FFFF00FF0000FFFF
FFFF000000FFFFFFFF0000FFFFFFFF000000FFFF
FF00FFFFFFFFFFFF00000000FFFFFFFFFFFF00FF
00FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.21208 0.97619 1.38845 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0457875 0.0192308 0.0457875 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
21 string
21 21 8 [21 0 0 21 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000000000FFFFFFFFFF00FFFFFFFFFF0000000000
000000FFFFFF00FF00FF00FF00FF00FFFFFF000000
000000FFFFFF00FFFF000000FFFF00FFFFFF000000
00FFFF00000000FF0000000000FF00000000FFFF00
00FFFF0000FFFF0000FF00FF0000FFFF0000FFFF00
FFFFFF00FF00000000FF00FF00000000FF00FFFFFF
FF000000FF00000000FF00FF00000000FF000000FF
FFFFFFFF00000000FF000000FF00000000FFFFFFFF
FF00FF00000000FF0000000000FF00000000FF00FF
FFFF0000FFFFFF00000000000000FFFFFF0000FFFF
000000000000000000000000000000000000000000
FFFF0000FFFFFF00000000000000FFFFFF0000FFFF
FF00FF00000000FF0000000000FF00000000FF00FF
FFFFFFFF00000000FF000000FF00000000FFFFFFFF
FF000000FF00000000FF00FF00000000FF000000FF
FFFFFF00FF00000000FF00FF00000000FF00FFFFFF
00FFFF0000FFFF0000FF00FF0000FFFF0000FFFF00
00FFFF00000000FF0000000000FF00000000FFFF00
000000FFFFFF00FFFF000000FFFF00FFFFFF000000
000000FFFFFF00FF00FF00FF00FF00FFFFFF000000
0000000000FFFFFFFFFF00FFFFFFFFFF0000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.40608 0.200176 1.58245 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0801282 0.0192308 0.0801282 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
12 string
12 12 8 [12 0 0 12 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFFFFFFFFFFFFFFFF
0000FF00FF00FF00FF000000
FF00FFFF0000FFFF00FFFF00
FF00FF00FF00FFFF0000FFFF
FF0000000000FF0000FFFFFF
FF00FFFFFFFFFF000000FFFF
FFFF000000FFFFFFFFFF00FF
FFFFFF0000FF0000000000FF
FFFF0000FFFF00FF00FF00FF
00FFFF00FFFF0000FFFF00FF
000000FF00FF00FF00FF0000
FFFFFFFFFFFFFFFFFF00FFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.40608 0.39418 1.58245 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0739645 0.0192308 0.0739645 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
13 string
13 13 8 [13 0 0 13 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFF00FF000000FF00FFFFFF
0000000000FF000000FFFFFF00
00FF0000FFFFFFFFFFFF0000FF
FF00FFFF00FF00FF00FFFF00FF
FF00FF00FF00FFFFFF00000000
FF00FF000000FFFF0000000000
0000FF00FFFF0000FFFF00FF00
FFFFFF00FFFF0000FFFF0000FF
FF00FF00FF00FFFFFF00000000
FFFF00FF00FFFF0000FFFFFF00
00000000000000000000000000
00FFFF0000FFFFFF00FFFF00FF
FFFF000000FF000000FFFF00FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.40608 0.588183 1.58245 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0686813 0.0192308 0.0686813 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
14 string
14 14 8 [14 0 0 14 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFF00FFFF0000FFFF00FFFFFF
FF00000000FFFFFF00FF00FF00FF
FFFFFFFF00FF00FF00FFFFFF00FF
0000FFFFFFFF0000FFFFFFFF0000
FFFFFFFF000000FF0000FF0000FF
FF0000FF00FF00FFFF00FFFFFFFF
00FFFF00FFFF000000000000FF00
00FF000000000000FFFF00FFFF00
FFFFFFFF00FFFF00FF00FF0000FF
FF0000FF0000FF000000FFFFFFFF
0000FFFFFFFF0000FFFFFFFF0000
FF00FFFFFF00FF00FF00FFFFFFFF
FF00FF00FF00FFFFFF00000000FF
FFFFFF00FFFF0000FFFF00FFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.40608 0.782187 1.58245 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0641026 0.0192308 0.0641026 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
15 string
15 15 8 [15 0 0 15 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00000000FFFFFFFFFFFF00FFFFFFFF
FFFFFF00FF0000FF000000FFFFFF00
00FFFFFF00FF00FFFF0000FF0000FF
00FF00FFFF0000FF000000FFFF0000
00FF00FF00FF00FFFF000000FF00FF
FF0000FFFFFF0000FFFF00FF000000
00FF0000000000FF00FF0000FF0000
0000FF000000FF00FF000000FF0000
00000000FF0000FF00FFFF00FFFF00
0000FFFFFFFF0000FFFF00FFFF00FF
00FFFFFF00FFFFFF000000000000FF
FFFFFFFFFF0000FF000000FF0000FF
0000FF00FF0000FFFFFFFF0000FFFF
FFFF0000FF00FFFFFF0000FF00FF00
000000FFFF00FFFFFF000000FFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.40608 0.97619 1.58245 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0600962 0.0192308 0.0600962 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
16 string
16 16 8 [16 0 0 16 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
00FFFF000000FFFFFF00FFFFFFFFFF00
FF00FFFFFF00FF00FF0000FF000000FF
00FFFF00FF00FF00000000FFFF000000
00000000FFFF00FFFF00FFFFFFFFFFFF
0000FFFFFF000000FFFF00FF00000000
FF0000FFFF00FFFFFFFF00FF00FFFF00
00FF00000000FF0000FFFFFF00FF0000
0000FFFF00FF00000000FF00FFFF0000
00FF0000FFFFFF0000FF000000FF0000
0000FFFF0000FF0000FF00000000FFFF
FFFF0000FF00FFFF000000FFFFFFFFFF
0000FFFF00FFFFFFFFFFFF000000FFFF
FF0000FF00FFFF000000FF0000FFFFFF
000000FF00000000FFFF000000FF0000
00FFFF000000000000FFFFFFFFFFFF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.60009 0.200176 1.77646 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.137363 0.0192308 0.137363 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
7 string
7 7 8 [7 0 0 7 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00000000FFFF00
FFFFFFFFFFFF00
00FF00FF00FFFF
00000000000000
00FF00FF00FFFF
FFFFFFFFFFFF00
00000000FFFF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.60009 0.39418 1.77646 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.120192 0.0192308 0.120192 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
FF0000FFFF0000FF
00FFFF0000FFFF00
0000FF0000FF0000
000000FFFF000000
FFFFFF0000FFFFFF
FFFF00FFFF00FFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.60009 0.588183 1.77646 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.106838 0.0192308 0.106838 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
9 string
9 9 8 [9 0 0 9 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00FF00FFFFFFFFFF
FFFFFF0000FF00FF00
FF000000000000FFFF
FFFF00FFFFFF000000
FF0000FF00FF0000FF
000000FFFFFF00FFFF
FFFF000000000000FF
00FF00FF0000FFFFFF
FFFFFFFFFF00FF00FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.60009 0.782187 1.77646 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0961538 0.0192308 0.0961538 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
10 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00FF0000FF00FF00
FF00FF00000000FF00FF
00FF0000FFFF0000FF00
FF000000FFFF000000FF
0000FFFF0000FFFF0000
0000FFFF0000FFFF0000
FF000000FFFF000000FF
00FF0000FFFF0000FF00
FF00FF00000000FF00FF
00FF00FF0000FF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.60009 0.97619 1.77646 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0874126 0.0192308 0.0874126 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
11 string
11 11 8 [11 0 0 11 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000000000000000000000
0000FFFF000000FFFF0000
00FF00FF000000FF00FF00
00FFFF00FF00FF00FFFF00
000000FF000000FF000000
0000000000000000000000
000000FF000000FF000000
00FFFF00FF00FF00FFFF00
00FF00FF000000FF00FF00
0000FFFF000000FFFF0000
0000000000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.79409 0.200176 1.97046 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.480769 0.0192308 0.480769 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
2 string
2 2 8 [2 0 0 2 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8080
8080
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.79409 0.39418 1.97046 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.320513 0.0192308 0.320513 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
3 string
3 3 8 [3 0 0 3 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
808080
808080
808080
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.79409 0.588183 1.97046 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFF00
FF0000FF
FF0000FF
00FFFF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.79409 0.782187 1.97046 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.192308 0.0192308 0.192308 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
5 string
5 5 8 [5 0 0 5 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00FF00
FF000000FF
0000000000
FF000000FF
00FF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.79409 0.97619 1.97046 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.160256 0.0192308 0.160256 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
6 string
6 6 8 [6 0 0 6 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFF
FFFF0000FFFF
00FF0000FF00
00FF0000FF00
FFFF0000FFFF
FFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{458, 924.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007:0003W2000`400?l00000o`00003oo`3AcJW;
0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;
0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;
0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;
0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;
0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00303AcJT5
00000080oooo00@000000?ooo`3oool000000P3oool300000080oooo0P0000000`3oool000000000
0002000000<0oooo0P0000030?ooo`030000003oool0oooo00D000000P3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo0?ooo`@0000000<0oooo0000000000000P3oool300000080oooo
00@000000?ooo`3oool000000P3oool5000000`0dLfY0P0000000`3oool00000000000030?ooo`80
000000@0oooo00000000000000001`3oool00`000000oooo0?ooo`02000000030?ooo`0000000000
01D0000000<0oooo0000000000000P3oool00`000000oooo0?ooo`050?ooo`<0000000<0oooo0000
000000000`3oool2000000030?ooo`000000000000/0dLfY0P000000103oool000000000003oool5
000000<0oooo1@0000060?ooo`8000002`3oool2000000/0oooo0P0000060?ooo`D000000`3oool5
000000040?ooo`00000000000?ooo`8000002`3AcJT2000000030?ooo`000000000000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`05000000@0oooo1P0000020?ooo`<000000`3o
ool300000080oooo1P0000040?ooo`D000000P3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo0?ooo`80000000<0oooo000000000000303AcJT3000000H0oooo0P0000030?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool0oooo1@000000103oool00000000000000003
0?ooo`T000000P3oool4000000<0oooo1@0000040?ooo`D000002@3oool>0=7=Z@00303AcJT50000
0080oooo00@000000?ooo`3oool000000P3oool300000080oooo0P0000000`3oool0000000000002
000000<0oooo0P0000030?ooo`030000003oool0oooo00D000000P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo0?ooo`@0000000<0oooo0000000000000P3oool300000080oooo00@0
00000?ooo`3oool000000P3oool5000000`0dLfY0P0000000`3oool00000000000030?ooo`800000
00@0oooo00000000000000001`3oool00`000000oooo0?ooo`02000000030?ooo`000000000001D0
000000<0oooo0000000000000P3oool00`000000oooo0?ooo`050?ooo`<0000000<0oooo00000000
00000`3oool2000000030?ooo`000000000000/0dLfY0P000000103oool000000000003oool50000
00<0oooo1@0000060?ooo`8000002`3oool2000000/0oooo0P0000060?ooo`D000000`3oool50000
00040?ooo`00000000000?ooo`8000002`3AcJT2000000030?ooo`000000000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`05000000@0oooo1P0000020?ooo`<000000`3oool3
00000080oooo1P0000040?ooo`D000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo0?ooo`80000000<0oooo000000000000303AcJT3000000H0oooo0P0000030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool0oooo1@000000103oool000000000000000030?oo
o`T000000P3oool4000000<0oooo1@0000040?ooo`D000002@3oool>0=7=Z@00303AcJT500000080
oooo100000020?ooo`P000001`3oool2000000030?ooo`000000000000D0oooo00<000000?ooo`3o
ool00`3oool200000080oooo00<000000?ooo`3oool01@3oool800000080oooo100000020?ooo`D0
0000303AcJT20?ooo`030000003oool0oooo00<000000P3oool010000000oooo0?ooo`3oool20000
00<0oooo0P0000000`3oool00000000000020?ooo`030000003oool0oooo01<000000P3oool00`00
0000oooo0?ooo`02000000030?ooo`000000000000<0oooo0P0000030?ooo`030000003oool0oooo
00<000000P3oool00`000000oooo0?ooo`0;0=7=Z@80oooo00<000000?ooo`3oool0200000000`3o
ool000000000000600000080oooo00<000000?ooo`3oool00`3oool2000000030?ooo`0000000000
0080oooo100000020?ooo`80000000<0oooo0000000000001@3oool00`000000oooo0?ooo`080000
00030?ooo`000000000000H000000P3oool00`000000oooo0?ooo`0;0=7=Z@80oooo00<000000?oo
o`3oool00`0000040?ooo`80000000@0oooo000000000000oooo100000030?ooo`030000003oool0
oooo00<0000000<0oooo0000000000000`0000030?ooo`D0000000@0oooo00000000000000000P3o
ool010000000oooo0?ooo`3oool4000000040?ooo`00000000000?ooo`800000103oool300000080
oooo00<000000?ooo`3oool0303AcJT50?ooo`H0000000<0oooo000000000000103oool2000000@0
oooo0P000000103oool000000000003oool2000000030?ooo`000000000000<0000000@0oooo0000
0000000000000P3oool010000000oooo0?ooo`3oool2000000040?ooo`00000000000?ooo`D00000
1`3oool2000000<0oooo0`0000020?ooo`030000003AcJT0dLfY00`0dLfY000<0=7=Z@L0000000<0
oooo0000000000000`0000020?ooo`<000001@3oool5000000<0oooo0P0000000`3oool000000000
0007000000030?ooo`000000000000<0oooo1@0000050?ooo`<000000P3oool5000000030?ooo`00
0000000000D00000303AcJT2000000030?ooo`000000000000D0000000@0oooo0000000000000000
2P3oool2000000<0oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`3oool2000000X0
oooo0`0000000`3oool0000000000005000000030?ooo`000000000000/0dLfY0P000000103oool0
00000000000000050?ooo`<000000P3oool600000080oooo00<000000?ooo`3oool00`0000020?oo
o`<000000P3oool400000080oooo0`0000020?ooo`<000000P3oool00`000000oooo0?ooo`060000
0080oooo0`0000050?ooo`<0000000<0oooo0000000000002`3AcJT2000000030?ooo`0000000000
00<000000`3oool6000000<0oooo0P0000060?ooo`<0000000<0oooo0000000000000`0000030?oo
o`D0000000@0oooo00000000000000001P3oool2000000<0oooo1P0000030?ooo`D0000000<0oooo
000000000000303AcJT2000000l0oooo00<000000?ooo`3oool00`3oool3000000030?ooo`000000
000000@0oooo0`0000020?ooo`040000003oool0oooo0?ooo`<000000P3oool3000000030?ooo`00
0000000000H0000000<0oooo0000000000000`3oool010000000oooo0?ooo`0000030?ooo`800000
0P3oool00`000000dLfY0=7=Z@0<0=7=Z@00303AcJT7000000030?ooo`000000000000<000000P3o
ool3000000D0oooo1@0000030?ooo`80000000<0oooo0000000000001`0000000`3oool000000000
00030?ooo`D000001@3oool300000080oooo1@0000000`3oool0000000000005000000`0dLfY0P00
00000`3oool0000000000005000000040?ooo`0000000000000000X0oooo0P0000030?ooo`030000
003oool0oooo00l0oooo00@000000?ooo`3oool0oooo0P00000:0?ooo`<0000000<0oooo00000000
00001@0000000`3oool000000000000;0=7=Z@80000000@0oooo00000000000000001@3oool30000
0080oooo1P0000020?ooo`030000003oool0oooo00<000000P3oool300000080oooo100000020?oo
o`<000000P3oool300000080oooo00<000000?ooo`3oool01P0000020?ooo`<000001@3oool30000
00030?ooo`000000000000/0dLfY0P0000000`3oool0000000000003000000<0oooo1P0000030?oo
o`8000001P3oool3000000030?ooo`000000000000<000000`3oool5000000040?ooo`0000000000
000000H0oooo0P0000030?ooo`H000000`3oool5000000030?ooo`000000000000`0dLfY0P00000?
0?ooo`030000003oool0oooo00<0oooo0`0000000`3oool00000000000040?ooo`<000000P3oool0
10000000oooo0?ooo`3oool300000080oooo0`0000000`3oool0000000000006000000030?ooo`00
0000000000<0oooo00@000000?ooo`3oool000000`3oool200000080oooo00<000000=7=Z@3AcJT0
303AcJT000`0dLfY0`3oool<000000030?ooo`0000000000008000000`3oool2000000<0oooo0P00
00040?ooo`8000000P3oool00`000000oooo0?ooo`02000000D0oooo00@000000?ooo`3oool0oooo
0P0000030?ooo`@0000000<0oooo0000000000002P0000030?ooo``0dLfY0P3oool9000000<0oooo
0P0000060?ooo`8000001P3oool2000000d0oooo0P0000060?ooo`8000001P3oool2000000<0oooo
2@0000020?ooo`/0dLfY0P3oool4000000X0oooo0P0000000`3oool00000000000030?ooo`030000
003oool0oooo008000001P3oool2000000040?ooo`00000000000?ooo`8000001P3oool200000080
oooo00@000000?ooo`3oool0oooo0P0000020?ooo`030000003oool0oooo00P0oooo100000020?oo
o`/0dLfY0P3oool400000080oooo0`000000103oool000000000000000020?ooo`<00000203oool4
00000080oooo0`0000030?ooo`<000000P3oool4000000P0oooo0`0000020?ooo`<0000000@0oooo
00000000000000000P3oool400000080oooo303AcJT3000000<0oooo200000030?ooo`H000001P3o
ool3000000030?ooo`000000000000@0oooo1P0000050?ooo`040000003oool0oooo000000<0oooo
0`0000020?ooo`<0000000@0oooo00000000000000000`3oool4000000030?ooo`3AcJT0dLfY00`0
dLfY000<0=7=Z@<0oooo300000000`3oool0000000000002000000<0oooo0P0000030?ooo`800000
103oool200000080oooo00<000000?ooo`3oool00P0000050?ooo`040000003oool0oooo0?ooo`80
00000`3oool4000000030?ooo`000000000000X000000`3oool<0=7=Z@80oooo2@0000030?ooo`80
00001P3oool2000000H0oooo0P00000=0?ooo`8000001P3oool2000000H0oooo0P0000030?ooo`T0
00000P3oool;0=7=Z@<000000`3oool200000080oooo0`0000000`3oool00000000000020?ooo`<0
00000`3oool300000080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`8000000`3oool20000
00<0oooo00<000000?ooo`3oool00`0000030?ooo`@0000000@0oooo000000000000oooo0`000002
0?ooo`8000000`3oool3000000/0dLfY0P3oool3000000040?ooo`0000000000000000D0oooo2@00
00020?ooo`040000003oool0oooo000001<0oooo00@000000?ooo`3oool000000P3oool9000000D0
oooo0`000000103oool000000000000000020?ooo``0dLfY0P3oool3000000030?ooo`0000000000
00<0000000<0oooo0000000000000`3oool6000000030?ooo`000000000000@000001P3oool20000
00<0oooo100000050?ooo`<000002@3oool6000000040?ooo`0000000000000000D0oooo3P3AcJT0
00`0dLfY0`0000020?ooo`<000000P3oool00`000000oooo0?ooo`050?ooo`80000000<0oooo0000
000000000P3oool9000000@0oooo00<000000?ooo`3oool00P3oool900000080oooo0P0000000`3o
ool00000000000070?ooo`030000003oool0oooo00<000000P3oool3000000`0dLfY0P3oool90000
0080oooo1P0000020?ooo`<000000P3oool010000000oooo0?ooo`0000020?ooo`D000000`3oool5
00000080oooo00@000000?ooo`3oool000000P3oool300000080oooo1P0000020?ooo`T000000P3o
ool;0=7=Z@<000000`3oool200000080oooo0`0000000`3oool00000000000020?ooo`<000000`3o
ool300000080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`8000000`3oool2000000<0oooo
00<000000?ooo`3oool00`0000030?ooo`@0000000@0oooo000000000000oooo0`0000020?ooo`80
00000`3oool3000000/0dLfY0P3oool3000000040?ooo`0000000000000000D0oooo2@0000020?oo
o`040000003oool0oooo000001<0oooo00@000000?ooo`3oool000000P3oool9000000D0oooo0`00
0000103oool000000000000000020?ooo``0dLfY0P3oool3000000030?ooo`000000000000<00000
00<0oooo0000000000000`3oool6000000030?ooo`000000000000@000001P3oool2000000<0oooo
100000050?ooo`<000002@3oool6000000040?ooo`0000000000000000D0oooo3P3AcJT000`0dLfY
0P3oool5000000030?ooo`000000000000H000000P3oool2000000030?ooo`000000000000<00000
0P3oool2000000030?ooo`000000000000d000000P3oool00`000000oooo0?ooo`05000000030?oo
o`00000000000080oooo200000000`3oool000000000000300000080oooo303AcJT2000000030?oo
o`000000000000D0000000<0oooo000000000000200000030?ooo`80000000@0oooo000000000000
oooo1@0000020?ooo`<000000P3oool5000000040?ooo`00000000000?ooo`8000000`3oool:0000
00030?ooo`000000000000D0000000<0oooo0000000000002`3AcJT3000000D0oooo0P0000030?oo
o`D000000`3oool010000000oooo0?ooo`0000020?ooo`80000000<0oooo0000000000001@3oool4
000000D0oooo0P0000000`3oool00000000000020?ooo`040000003oool0oooo000000@0oooo1000
00030?ooo`8000001@3oool3000000/0dLfY0P0000030?ooo`@000000`3oool2000000030?ooo`00
0000000000D0000000@0oooo000000000000oooo0P0000000`3oool000000000000?0?ooo`800000
00@0oooo000000000000oooo0P0000000`3oool0000000000005000000030?ooo`000000000000<0
oooo100000030?ooo`800000303AcJT20?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool0oooo1@0000000`3oool0000000000003000000030?ooo`000000000000<0oooo0`000006
0?ooo`T000000`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo``00000103o
ool00`000000dLfY0=7=Z@0<0=7=Z@00303AcJT20?ooo`D0000000<0oooo0000000000001P000002
0?ooo`80000000<0oooo0000000000000`0000020?ooo`80000000<0oooo0000000000003@000002
0?ooo`030000003oool0oooo00D0000000<0oooo0000000000000P3oool8000000030?ooo`000000
000000<000000P3oool<0=7=Z@80000000<0oooo0000000000001@0000000`3oool0000000000008
000000<0oooo0P000000103oool000000000003oool500000080oooo0`0000020?ooo`D0000000@0
oooo000000000000oooo0P0000030?ooo`X0000000<0oooo0000000000001@0000000`3oool00000
0000000;0=7=Z@<000001@3oool2000000<0oooo1@0000030?ooo`040000003oool0oooo00000080
oooo0P0000000`3oool00000000000050?ooo`@000001@3oool2000000030?ooo`00000000000080
oooo00@000000?ooo`3oool00000103oool4000000<0oooo0P0000050?ooo`<000002`3AcJT50?oo
o`040000003oool0oooo0?ooo`<000001@3oool5000000<0oooo0`000000103oool0000000000000
000=0?ooo`<0000000@0oooo00000000000000000`3oool5000000D0oooo0`0000030?ooo`030000
003oool0oooo00<0oooo303AcJT6000000D0oooo00<000000?ooo`3oool0100000020?ooo`H00000
00@0oooo00000000000000000P3oool00`000000oooo0?ooo`03000000L0oooo1@0000030?ooo`03
0000003oool0oooo00<0000000<0oooo0000000000001P3oool600000080oooo00<000000=7=Z@3A
cJT0303AcJT000`0dLfY2`0000090?ooo`030000003oool0oooo008000000`3oool6000000@0oooo
00<000000?ooo`3oool00P3oool6000000<0oooo0P0000020?ooo`030000003oool0oooo00L0oooo
2`00000<0=7=Z@80oooo00<000000?ooo`3oool00`0000020?ooo`@000001`3oool00`000000oooo
0?ooo`02000000040?ooo`000000000000000080oooo0P0000090?ooo`8000000P3oool300000003
0?ooo`00000000000080oooo00<000000?ooo`3oool01@3oool400000080oooo0`0000020?ooo`03
0000003oool0oooo00/0dLfY0`0000030?ooo`8000000P3oool00`000000oooo0?ooo`0<0?ooo`80
00000`3oool3000000@0oooo100000040?ooo`<000000`3oool2000000h0oooo00<000000?ooo`3o
ool00P0000030?ooo`<000002`3AcJT50?ooo`040000003oool0oooo0?ooo`<000001@3oool50000
00<0oooo0`000000103oool0000000000000000=0?ooo`<0000000@0oooo00000000000000000`3o
ool5000000D0oooo0`0000030?ooo`030000003oool0oooo00<0oooo303AcJT6000000D0oooo00<0
00000?ooo`3oool0100000020?ooo`H0000000@0oooo00000000000000000P3oool00`000000oooo
0?ooo`03000000L0oooo1@0000030?ooo`030000003oool0oooo00<0000000<0oooo000000000000
1P3oool600000080oooo00<000000=7=Z@3AcJT0303AcJT000`0dLfY2`0000090?ooo`030000003o
ool0oooo008000000`3oool6000000@0oooo00<000000?ooo`3oool00P3oool6000000<0oooo0P00
00020?ooo`030000003oool0oooo00L0oooo2`00000<0=7=Z@80000000<0oooo0000000000000`3o
ool5000000030?ooo`000000000000<0oooo0P0000000`3oool00000000000020?ooo`040000003o
ool0oooo0?ooo`8000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00800000
0`3oool00`000000oooo0?ooo`02000000030?ooo`000000000000<0oooo0P0000000`3oool00000
00000003000000<0oooo0P0000000`3oool000000000000;0=7=Z@80oooo0`0000000`3oool00000
000000030?ooo`80000000<0oooo0000000000000P000000103oool000000000000000080?oooa80
0000203oool300000080oooo0`0000000`3oool00000000000030?ooo`80000000@0oooo00000000
000000000P3oool;0=7=Z@<0oooo0P0000040?ooo`<000000`3oool2000000030?ooo`0000000000
008000000`3oool4000000<0oooo0P0000090?ooo`8000000`3oool4000000<0oooo100000000`3o
ool00000000000030?ooo`<00000103oool2000000<0oooo303AcJT80?ooo`040000003oool0oooo
0?ooo`D000000`3oool400000080oooo00<000000?ooo`3oool00`000000103oool0000000000000
00030?ooo`8000000`3oool3000000L0oooo0P0000000`3oool0000000000006000000040?ooo`00
000000000?ooo`D000000P3oool00`000000dLfY0=7=Z@0<0=7=Z@00303AcJT30?ooo`@0000000@0
oooo000000000000oooo100000030?ooo`8000000`3oool2000000030?ooo`000000000000800000
103oool200000080oooo00<000000?ooo`3oool00P0000050?ooo`<0000000<0oooo000000000000
0`3oool2000000<0oooo10000000103oool000000000003oool4000000<0oooo303AcJT200000003
0?ooo`000000000000<0oooo1@0000000`3oool00000000000030?ooo`80000000<0oooo00000000
00000P3oool010000000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool00P0000000`3oool00000000000030?oo
o`80000000<0oooo0000000000000`0000030?ooo`80000000<0oooo0000000000002`3AcJT20?oo
o`<0000000<0oooo0000000000000`3oool2000000030?ooo`00000000000080000000@0oooo0000
000000000000203ooolB000000P0oooo0`0000020?ooo`<0000000<0oooo0000000000000`3oool2
000000040?ooo`000000000000000080oooo2`3AcJT20?ooo`@000000P3oool010000000oooo0?oo
o`3oool;000000<0oooo0P0000000`3oool00000000000040?ooo`8000000`3oool2000000@0oooo
0P0000000`3oool00000000000030?ooo`/000000`3oool00`000000oooo0?ooo`0400000080oooo
303AcJT20?ooo`040000003oool0oooo0?ooo`80000000@0oooo000000000000oooo0`0000020?oo
o`<000000`3oool3000000030?ooo`000000000000<000000`3oool00`000000oooo0?ooo`030?oo
o`<00000103oool5000000@0oooo200000000`3oool00000000000060?ooo`<000003P3AcJT000`0
dLfY0`0000020?ooo`80000000@0oooo000000000000oooo1@0000020?ooo`L000000`3oool20000
00040?ooo`00000000000?ooo`T0000000<0oooo0000000000000P3oool010000000oooo0?ooo`3o
ool700000080oooo1@000000103oool000000000003oool200000080oooo0`00000<0=7=Z@800000
00@0oooo000000000000oooo1@0000020?ooo`P000000`3oool5000000030?ooo`000000000000d0
oooo0P0000000`3oool0000000000003000000<0oooo200000020?ooo`D0000000@0oooo00000000
0000oooo0P00000;0=7=Z@<0oooo0P0000030?ooo`8000000`3oool5000000030?ooo`0000000000
00<0oooo0`0000020?ooo`030000003oool0oooo00<0oooo200000050?ooo`030000003oool0oooo
00<000000`3oool200000080oooo100000030?ooo`8000000`3oool2000000<0oooo2`3AcJT20?oo
o`@000000P3oool010000000oooo0?ooo`3oool;000000<0oooo0P0000000`3oool0000000000004
0?ooo`8000000`3oool2000000@0oooo0P0000000`3oool00000000000030?ooo`/000000`3oool0
0`000000oooo0?ooo`0400000080oooo303AcJT20?ooo`040000003oool0oooo0?ooo`80000000@0
oooo000000000000oooo0`0000020?ooo`<000000`3oool3000000030?ooo`000000000000<00000
0`3oool00`000000oooo0?ooo`030?ooo`<00000103oool5000000@0oooo200000000`3oool00000
000000060?ooo`<000003P3AcJT000`0dLfY0`0000020?ooo`80000000@0oooo000000000000oooo
1@0000020?ooo`L000000`3oool2000000040?ooo`00000000000?ooo`T0000000<0oooo00000000
00000P3oool010000000oooo0?ooo`3oool700000080oooo1@000000103oool000000000003oool2
00000080oooo0`00000<0=7=Z@80000000@0oooo000000000000oooo1@0000020?ooo`P000000`3o
ool5000000030?ooo`000000000000d0oooo0P0000000`3oool0000000000003000000<0oooo2000
00020?ooo`D0000000@0oooo000000000000oooo0P00000;0=7=Z@<000000`3oool4000000030?oo
o`000000000000D00000103oool2000000D0oooo00<000000?ooo`3oool00`0000020?ooo`@00000
0P3oool300000080oooo00<000000?ooo`3oool00`3oool2000000D0oooo1P0000000`3oool00000
00000002000000<0oooo0`00000;0=7=Z@80000000<0oooo0000000000000`0000040?ooo`X00000
00@0oooo00000000000000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03000000030?ooo`000000000000P0
0000103oool5000000030?ooo`000000000000`0dLfY1@0000030?ooo`040000003oool0oooo0000
00<0oooo2@0000020?ooo`<0000000<0oooo000000000000100000020?ooo`@000000P3oool00`00
0000oooo0?ooo`0400000080oooo100000030?ooo`8000000`3oool700000080oooo0`00000>0=7=
Z@00303AcJT5000000<0oooo0P0000030?ooo`P000001@3oool7000000D0oooo00<000000?ooo`3o
ool00`3oool7000000D0oooo200000030?ooo`8000000`3oool5000000`0dLfY0P3oool00`000000
oooo0?ooo`05000000030?ooo`000000000000H000000P3oool300000080oooo1000000A0?ooo`@0
00000P3oool300000080oooo200000000`3oool000000000000300000080oooo00<000000?ooo`3o
ool02`3AcJT3000000<0oooo100000000`3oool0000000000005000000@0oooo0P0000050?ooo`03
0000003oool0oooo00<000000P3oool400000080oooo0`0000020?ooo`030000003oool0oooo00<0
oooo0P0000050?ooo`H0000000<0oooo0000000000000P0000030?ooo`<000002`3AcJT200000003
0?ooo`000000000000<00000103oool:000000040?ooo`000000000000000080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`0000000`3oool0000000000008000000@0oooo1@0000000`3oool000000000000<0=7=
Z@80oooo00<000000?ooo`3oool02P0000060?ooo`80000000@0oooo000000000000oooo1@000000
103oool000000000000000020?ooo`<000000`3oool00`000000oooo0?ooo`040?ooo`8000001P3o
ool00`000000oooo0?ooo`0400000080oooo100000020?ooo`80000000<0oooo0=7=Z@3AcJT0303A
cJT000`0dLfY1@0000030?ooo`8000000`3oool8000000D0oooo1`0000050?ooo`030000003oool0
oooo00<0oooo1`0000050?ooo`P000000`3oool2000000<0oooo1@00000<0=7=Z@H0oooo10000003
0?ooo`H000000P3oool00`000000oooo0?ooo`02000000T0oooo1`0000090?ooo`8000000P3oool0
0`000000oooo0?ooo`06000000<0oooo100000060?ooo`/0dLfY1P0000020?ooo`80000000<0oooo
000000000000200000080?ooo`H000000`3oool2000000<0oooo1P0000080?ooo`X0000000<0oooo
0000000000000P3oool6000000/0dLfY0P3oool3000000040?ooo`000000000000000080oooo2`00
00030?ooo`030000003oool0oooo00<00000103oool7000000@0oooo0`0000020?ooo`040000003o
ool0oooo0?ooo`/000000P3oool3000000040?ooo`000000000000000080oooo303AcJT20?ooo`03
0000003oool0oooo00X000001P3oool2000000040?ooo`00000000000?ooo`D0000000@0oooo0000
0000000000000P3oool3000000<0oooo00<000000?ooo`3oool0103oool2000000H0oooo00<00000
0?ooo`3oool0100000020?ooo`@000000P3oool2000000030?ooo`3AcJT0dLfY00`0dLfY000<0=7=
Z@80oooo1@0000080?ooo`X0000000<0oooo0000000000000P3oool3000000D0oooo00<000000?oo
o`3oool00`3oool4000000040?ooo`00000000000?ooo`X00000203oool500000080oooo303AcJT6
0?ooo`@000000`3oool600000080oooo00<000000?ooo`3oool00P0000090?ooo`L000002@3oool2
00000080oooo00<000000?ooo`3oool01P0000030?ooo`@000001P3oool;0=7=Z@H000000P3oool2
000000030?ooo`000000000000P00000203oool6000000<0oooo0P0000030?ooo`H00000203oool:
000000030?ooo`00000000000080oooo1P00000;0=7=Z@8000000`3oool6000000030?ooo`000000
000000P00000103oool5000000<0oooo00<000000?ooo`3oool00`0000020?ooo`040000003oool0
oooo0?ooo`D00000103oool:000000030?ooo`000000000000@000000`3oool2000000`0dLfY0`3o
ool2000000040?ooo`00000000000?ooo`80000000<0oooo000000000000103oool2000000<0oooo
100000020?ooo`040000003oool0oooo000000P0oooo0`0000000`3oool00000000000090?ooo`04
0000003oool0oooo0?ooo`H000001P3oool2000000<0oooo3P3AcJT000`0dLfY0`0000020?ooo`D0
000000<0oooo0000000000004@000000103oool000000000003oool9000000030?ooo`0000000000
0080oooo4P0000000`3oool000000000000300000080oooo0`00000<0=7=Z@H0oooo100000030?oo
o`P0000000<0oooo0000000000002`3oool7000000/0oooo0P0000000`3oool00000000000060000
00<0oooo100000060?ooo`/0dLfY1@0000000`3oool00000000000080?ooo`<000000P3oool00`00
0000oooo0?ooo`03000000<0oooo0`0000020?ooo`80000000@0oooo000000000000oooo0P000002
0?ooo`<000000`3oool300000080oooo00<000000?ooo`3oool00`0000080?ooo`80000000<0oooo
0000000000000`00000;0=7=Z@8000000`3oool6000000030?ooo`000000000000P00000103oool5
000000<0oooo00<000000?ooo`3oool00`0000020?ooo`040000003oool0oooo0?ooo`D00000103o
ool:000000030?ooo`000000000000@000000`3oool2000000`0dLfY1P3oool300000080oooo0`00
00040?ooo`800000103oool5000000030?ooo`000000000000@000000P3oool9000000040?ooo`00
00000000000000<0oooo0`0000030?ooo`80000000@0oooo000000000000oooo2`00000>0=7=Z@00
303AcJT300000080oooo1@0000000`3oool000000000000A000000040?ooo`00000000000?ooo`T0
000000<0oooo0000000000000P3ooolB000000030?ooo`000000000000<000000P3oool3000000`0
dLfY1P3oool4000000<0oooo200000000`3oool000000000000;0?ooo`L000002`3oool200000003
0?ooo`000000000000H000000`3oool4000000H0oooo2`3AcJT20?ooo`H000000`3oool300000080
oooo0P0000000`3oool0000000000003000000D0oooo1P0000020?ooo`@000000P3oool6000000D0
oooo1@0000020?ooo`030000003oool0oooo00<000000`3oool600000080oooo2`3AcJT300000080
oooo4@0000030?ooo`<000000`3oool00`000000oooo0?ooo`03000000<0oooo0`0000020?ooo`04
0000003oool0oooo0?ooo`<000000`3ooolA00000080oooo0`00000<0=7=Z@H0oooo0`0000020?oo
o`<00000103oool2000000@0oooo1@0000000`3oool000000000000400000080oooo2@000000103o
ool000000000000000030?ooo`<000000`3oool2000000040?ooo`00000000000?ooo`/000003P3A
cJT000`0dLfY0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P00000103oool3
00000080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`030000003oool0oooo008000000`3o
ool2000000040?ooo`0000000000000000@0oooo200000020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0303AcJT20?ooo`030000003oool0oooo00<0oooo0P000000103oool00000
0000000000040?ooo`@000000P3oool=000000<0oooo3@0000020?ooo`@00000103oool300000003
0?ooo`000000000000D0oooo00<000000?ooo`3oool02`3AcJT20?ooo`H000000`3oool300000080
oooo0P0000000`3oool0000000000003000000D0oooo1P0000020?ooo`@000000P3oool6000000D0
oooo1@0000020?ooo`030000003oool0oooo00<000000`3oool600000080oooo2`3AcJT500000003
0?ooo`000000000000h000000`3oool3000000@0oooo1@0000030?ooo`D00000103oool3000000<0
oooo400000000`3oool0000000000003000000`0dLfY0P000000103oool000000000000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool6000000040?ooo`000000
00000?ooo`8000000`3oool3000000@0oooo1P0000050?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00`0000000`3oool0000000000003000000030?ooo`000000000000<00000
3P3AcJT000`0dLfY0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P00000103o
ool300000080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`030000003oool0oooo00800000
0`3oool2000000040?ooo`0000000000000000@0oooo200000020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0303AcJT2000000@0oooo0P0000020?ooo`040000003oool0oooo0?oo
o`@0000000<0oooo0000000000000`0000020?ooo`T000000P3oool300000080oooo2@0000020?oo
o`D0000000<0oooo0000000000000P0000030?ooo`030000003oool0oooo00800000103oool20000
00/0dLfY0P3oool3000000<0oooo0P0000000`3oool00000000000050?ooo`H0000000<0oooo0000
000000000`0000020?ooo`<000000P3oool400000080oooo0`0000020?ooo`D0000000<0oooo0000
000000001@0000040?ooo`80000000<0oooo0000000000000`3oool300000080oooo2`3AcJT50000
00030?ooo`000000000000h000000`3oool3000000@0oooo1@0000030?ooo`D00000103oool30000
00<0oooo400000000`3oool0000000000003000000`0dLfY1@3oool3000000030?ooo`0000000000
00<00000103oool600000080oooo100000020?ooo`030000003oool0oooo00<0oooo1P0000000`3o
ool0000000000004000000P0oooo1`0000050?ooo`H000003P3AcJT000`0dLfY0P0000050?ooo`<0
00000`3oool2000000030?ooo`00000000000080000000<0oooo0000000000000P3oool00`000000
oooo0?ooo`02000000H0oooo1@0000070?ooo`040000003oool0oooo00000080oooo0P0000000`3o
ool0000000000002000000030?ooo`000000000000<0oooo0`0000050?ooo`800000303AcJT20000
00@0oooo0P0000020?ooo`040000003oool0oooo0?ooo`@0000000<0oooo0000000000000`000002
0?ooo`T000000P3oool300000080oooo2@0000020?ooo`D0000000<0oooo0000000000000P000003
0?ooo`030000003oool0oooo00800000103oool2000000/0dLfY3P3oool2000000<0oooo1@000000
0`3oool000000000000300000080oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<00000
0?ooo`3oool01@0000000`3oool0000000000003000000<0oooo0P00000>0?ooo`/0dLfY1P3oool2
000000@0oooo0P0000080?ooo`@000000`3oool5000000030?ooo`000000000000D0000000<0oooo
0000000000000`0000030?ooo`@00000203oool2000000@0oooo0P0000060?ooo``0dLfY1@3oool3
000000030?ooo`000000000000<00000103oool600000080oooo100000020?ooo`030000003oool0
oooo00<0oooo1P0000000`3oool0000000000004000000P0oooo1`0000050?ooo`H000003P3AcJT0
00`0dLfY0P0000000`3oool0000000000002000000030?ooo`000000000000D0000000<0oooo0000
000000000P0000030?ooo`80000000<0oooo0000000000001@0000000`3oool00000000000070000
00030?ooo`000000000000D0000000<0oooo0000000000000`3oool4000000030?ooo`0000000000
00D0000000<0oooo0000000000000P0000000`3oool000000000000<0=7=Z@80oooo00<000000?oo
o`3oool00`0000030?ooo`80000000<0oooo0000000000000P3oool00`000000oooo0?ooo`080000
00030?ooo`00000000000080oooo00<000000?ooo`3oool00`0000020?ooo`030000003oool0oooo
0080000000<0oooo0000000000001P0000020?ooo`030000003oool0oooo0080000000<0oooo0000
000000000`3oool300000080oooo00<000000?ooo`3oool02`3AcJT>0?ooo`8000000`3oool50000
00030?ooo`000000000000<000000P3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`00
0000oooo0?ooo`05000000030?ooo`000000000000<000000`3oool2000000h0oooo2`3AcJT80?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool3000000040?ooo`0000000000
00000080oooo100000020?ooo`<000000P3oool400000080oooo0`000000103oool0000000000000
00070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool<0=7=Z@<0oooo0P00
00040?ooo`<000000P3oool3000000T0oooo00<000000?ooo`3oool00`0000030?ooo`030000003o
ool0oooo00@0oooo0`0000020?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`H0000000<0
oooo0000000000000`3oool3000000<0oooo3P3AcJT000`0dLfY0P0000000`3oool0000000000002
000000030?ooo`000000000000D0000000<0oooo0000000000000P0000030?ooo`80000000<0oooo
0000000000001@0000000`3oool0000000000007000000030?ooo`000000000000D0000000<0oooo
0000000000000`3oool4000000030?ooo`000000000000D0000000<0oooo0000000000000P000000
0`3oool000000000000<0=7=Z@80000000<0oooo0000000000000`3oool300000080oooo00<00000
0?ooo`3oool00P000000103oool000000000003oool800000080oooo0P0000000`3oool000000000
00030?ooo`80000000<0oooo0000000000000P3oool8000000040?ooo`00000000000?ooo`800000
0P3oool00`000000oooo0?ooo`03000000<0oooo0P0000000`3oool000000000000;0=7=Z@80oooo
200000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool300000080oooo
00<000000?ooo`3oool01@000000103oool000000000003oool500000080oooo00<000000?ooo`3o
ool00`0000050?ooo`8000000`3oool010000000oooo0?ooo`3oool800000080oooo2`3AcJT80?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool3000000040?ooo`0000000000
00000080oooo100000020?ooo`<000000P3oool400000080oooo0`000000103oool0000000000000
00070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool<0=7=Z@80oooo00@0
00000?ooo`3oool000000P3oool6000000040?ooo`000000000000000080oooo00@000000?ooo`3o
ool0oooo0P0000000`3oool00000000000030?ooo`H000000`3oool010000000oooo0?ooo`3oool8
000000@0oooo0P000000103oool000000000003oool3000000D0oooo00<000000?ooo`3oool00`00
000>0=7=Z@00303AcJT30?ooo`8000000P3oool3000000P0oooo1@0000020?ooo`D000001P3oool5
000000L0oooo100000020?ooo`D00000203oool300000080oooo0P0000030?ooo``0dLfY0P000000
0`3oool00000000000030?ooo`<000000P3oool00`000000oooo0?ooo`02000000040?ooo`000000
00000?ooo`P000000P3oool2000000030?ooo`000000000000<0oooo0P0000000`3oool000000000
00020?ooo`P0000000@0oooo000000000000oooo0P0000020?ooo`030000003oool0oooo00<00000
0`3oool2000000030?ooo`000000000000/0dLfY0P0000040?ooo`8000000P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00H000000P3oool4000000@0oooo100000040?ooo`@0
00000P3oool600000080oooo0P0000030?ooo`040000003oool0oooo00000080oooo0P0000040?oo
o`8000002`3AcJT20?ooo`040000003oool0oooo0?ooo`80000000@0oooo00000000000000000P3o
ool3000000030?ooo`000000000000<000000P3oool3000000040?ooo`0000000000000000d0oooo
0`000000103oool000000000000000020?ooo`D0000000@0oooo00000000000000000P3oool30000
00030?ooo`000000000000<0oooo00<000000?ooo`3oool0303AcJT20?ooo`040000003oool0oooo
00000080oooo1P000000103oool000000000000000020?ooo`040000003oool0oooo0?ooo`800000
00<0oooo0000000000000`3oool6000000<0oooo00@000000?ooo`3oool0oooo200000040?ooo`80
000000@0oooo000000000000oooo0`0000050?ooo`030000003oool0oooo00<000003P3AcJT000`0
dLfY0`3oool200000080oooo0`0000080?ooo`D000000P3oool5000000H0oooo1@0000070?ooo`@0
00000P3oool5000000P0oooo0`0000020?ooo`8000000`3oool<0=7=Z@80oooo00@000000?ooo`3o
ool0oooo0P0000030?ooo`D000000`3oool;000000L0oooo0`0000070?ooo`/000000`3oool50000
00<0oooo0P0000030?ooo`030000003oool0oooo00/0dLfY0P0000040?ooo`8000000P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00H000000P3oool4000000@0oooo10000004
0?ooo`@000000P3oool600000080oooo0P0000030?ooo`040000003oool0oooo00000080oooo0P00
00040?ooo`8000002`3AcJT20?ooo`040000003oool0oooo0?ooo`80000000@0oooo000000000000
00000P3oool3000000030?ooo`000000000000<000000P3oool3000000040?ooo`00000000000000
00d0oooo0`000000103oool000000000000000020?ooo`D0000000@0oooo00000000000000000P3o
ool3000000030?ooo`000000000000<0oooo00<000000?ooo`3oool0303AcJT300000080oooo00@0
00000?ooo`3oool0oooo0`0000020?ooo`@000000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0000000<0oooo000000000000100000030?ooo`80000000<0oooo000000000000
0`3oool400000080oooo00@000000?ooo`3oool0oooo1@000000103oool000000000000000050?oo
o`<000003P3AcJT000`0dLfY0`3oool200000080oooo00@000000?ooo`3oool0oooo0P0000020?oo
o`H000000P3oool500000080oooo0`0000000`3oool00000000000020?ooo`030000003oool0oooo
0080000000<0oooo0000000000000P0000000`3oool000000000000300000080oooo1P0000020?oo
o`8000000`3oool00`000000oooo0?ooo`02000000<0oooo303AcJT20?ooo`040000003oool0oooo
0?ooo`8000000`3oool5000000<0oooo2`0000070?ooo`<000001`3oool;000000<0oooo1@000003
0?ooo`8000000`3oool00`000000oooo0?ooo`0;0=7=Z@<0oooo0`0000020?ooo`8000002`3oool3
000000<0oooo0`0000020?ooo`<000000P3oool400000080oooo0`0000020?ooo`<000000`3oool3
000000/0oooo0P0000020?ooo`<000000`3oool;0=7=Z@8000001P3oool6000000<0oooo1@000000
0`3oool0000000000004000000<0oooo0P0000090?ooo`8000000`3oool6000000030?ooo`000000
000000<000000`3oool6000000H0oooo0P00000<0=7=Z@<000000P3oool010000000oooo0?ooo`3o
ool300000080oooo100000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`00
00000`3oool0000000000004000000<0oooo0P0000000`3oool00000000000030?ooo`@000000P3o
ool010000000oooo0?ooo`3oool5000000040?ooo`0000000000000000D0oooo0`00000>0=7=Z@00
303AcJT300000080oooo2`0000020?ooo`80000000<0oooo0000000000000`0000020?oooaD00000
0P3oool5000000030?ooo`00000000000080oooo2`0000020?ooo`<00000303AcJT2000000H0oooo
0`0000020?ooo`<000000`3oool:000000030?ooo`000000000000<0oooo0P0000030?ooo`800000
0`3oool2000000030?ooo`000000000000P000000`3oool300000080oooo0`0000060?ooo`800000
2`3AcJT30?ooo`<000000P3oool2000000/0oooo0`0000030?ooo`<000000P3oool300000080oooo
100000020?ooo`<000000P3oool3000000<0oooo0`00000;0?ooo`8000000P3oool3000000<0oooo
2`3AcJT8000000<0oooo00<000000?ooo`3oool0100000050?ooo`80000000<0oooo000000000000
0`0000040?ooo`L00000103oool5000000030?ooo`000000000000D0oooo100000020?ooo`040000
003oool0oooo0?ooo`P00000303AcJT30?ooo`D000000`3oool010000000oooo0?ooo`3oool20000
00030?ooo`000000000000<0oooo3@0000020?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool0100000020?ooo`@000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo0?ooo`8000000`3oool>0=7=Z@00303AcJT300000080oooo2`0000020?ooo`80000000<0
oooo0000000000000`0000020?oooaD000000P3oool5000000030?ooo`00000000000080oooo2`00
00020?ooo`<00000303AcJT5000000030?ooo`00000000000080oooo00@000000?ooo`3oool0oooo
0P0000030?ooo`<000000P3oool300000080oooo0`0000020?ooo`030000003oool0oooo00<00000
0P3oool00`000000oooo0?ooo`0300000080oooo0`0000020?ooo`<000000`3oool2000000<0oooo
00<000000?ooo`3oool00P0000000`3oool0000000000003000000/0dLfY0`3oool2000000030?oo
o`000000000000D0oooo1@0000000`3oool000000000000;000000<0oooo200000030?ooo`d00000
0P3oool4000000D0oooo0P0000000`3oool00000000000030?ooo`/0dLfY200000030?ooo`030000
003oool0oooo00@000001@3oool2000000030?ooo`000000000000<00000103oool7000000@0oooo
1@0000000`3oool00000000000050?ooo`@000000P3oool010000000oooo0?ooo`3oool8000000`0
dLfY0`0000020?ooo`<0000000<0oooo0000000000001P0000000`3oool000000000000400000080
oooo00@000000?ooo`3oool000000`3oool3000000H0oooo0P000000103oool00000000000000003
0?ooo`D000000`3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool00`3o
ool2000000030?ooo`3AcJT0dLfY00`0dLfY000<0=7=Z@L0oooo00@000000?ooo`3oool00000103o
ool300000080oooo00<000000?ooo`3oool00P0000000`3oool000000000000G000000030?ooo`00
000000000080oooo00<000000?ooo`3oool00`0000040?ooo`040000003oool0oooo000000L0oooo
303AcJT5000000030?ooo`00000000000080oooo00@000000?ooo`3oool0oooo0P0000030?ooo`<0
00000P3oool300000080oooo0`0000020?ooo`030000003oool0oooo00<000000P3oool00`000000
oooo0?ooo`0300000080oooo0`0000020?ooo`<000000`3oool2000000<0oooo00<000000?ooo`3o
ool00P0000000`3oool0000000000003000000/0dLfY0P3oool00`000000oooo0?ooo`030?ooo`D0
00000`3oool5000000@0oooo0P0000020?ooo`P0000000@0oooo000000000000oooo200000020?oo
o`800000103oool5000000<0oooo1@0000050?ooo`030000003oool0oooo00/0dLfY1P0000020?oo
o`<0000000@0oooo000000000000oooo0`0000040?ooo`040000003oool0oooo00000080oooo0`00
00030?ooo`030000003oool0oooo00<000000P3oool010000000oooo0?ooo`3oool300000080oooo
00@000000?ooo`3oool00000103oool3000000040?ooo`00000000000?ooo`<000000P3oool60000
00`0dLfY0`0000020?ooo`<0000000<0oooo0000000000001P0000000`3oool00000000000040000
0080oooo00@000000?ooo`3oool000000`3oool3000000H0oooo0P000000103oool0000000000000
00030?ooo`D000000`3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool0
0`3oool2000000030?ooo`3AcJT0dLfY00`0dLfY000<0=7=Z@L0oooo00@000000?ooo`3oool00000
103oool300000080oooo00<000000?ooo`3oool00P0000000`3oool000000000000G000000030?oo
o`00000000000080oooo00<000000?ooo`3oool00`0000040?ooo`040000003oool0oooo000000L0
oooo303AcJT300000080oooo00<000000?ooo`3oool00P000000103oool000000000000000050?oo
o`D000000`3oool7000000030?ooo`000000000000<0oooo0P0000000`3oool00000000000050000
00<0oooo1@0000050?ooo`<0000000<0oooo0000000000000P3oool00`000000oooo0?ooo`030000
00/0dLfY0P3oool00`000000oooo0?ooo`030?ooo`D000000`3oool5000000@0oooo0P0000020?oo
o`P0000000@0oooo000000000000oooo200000020?ooo`800000103oool5000000<0oooo1@000005
0?ooo`030000003oool0oooo00/0dLfY0P0000030?ooo`040000003oool0oooo0?ooo`8000001`3o
ool200000080oooo100000050?ooo`<0000000<0oooo0000000000000`3oool2000000040?ooo`00
00000000000000D0oooo100000020?ooo`8000001`3oool2000000<0oooo00@000000?ooo`3oool0
oooo0P00000<0=7=Z@8000000`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
0?ooo`<000000`3oool3000000<0oooo0P0000040?ooo`<000000P3oool4000000<0oooo0P000003
0?ooo`040000003oool0oooo000000<0oooo0P000000103oool000000000003oool3000000D0oooo
3P3AcJT000`0dLfY0P3oool300000080oooo100000020?ooo`L000000`3oool2000000030?ooo`00
0000000000D000000`3oool5000000<0oooo1`0000000`3oool00000000000030?ooo`L000000P3o
ool400000080oooo0`0000020?ooo``0dLfY0`0000020?ooo`030000003oool0oooo0080000000@0
oooo00000000000000001@3oool5000000<0oooo1`0000000`3oool00000000000030?ooo`800000
00<0oooo0000000000001@0000030?ooo`D000001@3oool3000000030?ooo`00000000000080oooo
00<000000?ooo`3oool00`00000;0=7=Z@<0oooo0P0000050?ooo`<0000000<0oooo000000000000
3@000000103oool000000000000000020?ooo`P000000P3oool3000000030?ooo`000000000000d0
000000@0oooo00000000000000001@3oool2000000<0oooo2`3AcJT2000000<0oooo00@000000?oo
o`3oool0oooo0P0000070?ooo`8000000P3oool4000000D0oooo0`0000000`3oool0000000000003
0?ooo`80000000@0oooo00000000000000001@3oool400000080oooo0P0000070?ooo`8000000`3o
ool010000000oooo0?ooo`3oool2000000`0dLfY0`3oool300000080oooo1P0000030?ooo`030000
003oool0oooo00<000000`3oool010000000oooo0?ooo`3oool2000000040?ooo`00000000000?oo
o`8000001`3oool2000000<0oooo1P000000103oool000000000003oool2000000030?ooo`000000
000000@0oooo0P0000000`3oool0000000000003000000h0dLfY000<0=7=Z@8000001@3oool40000
0140oooo0`0000020?ooo`030000003oool0oooo00D000000P3oool00`000000oooo0?ooo`030000
0140oooo100000050?ooo`800000303AcJT3000000<0oooo1@0000080?ooo`<000000P3oool20000
00@0oooo1`0000030?ooo`L00000103oool200000080oooo0`0000080?ooo`D000000`3oool30000
00/0dLfY0P3oool3000000030?ooo`000000000000<0oooo0P0000000`3oool00000000000020000
00040?ooo`000000000000000080oooo00<000000?ooo`3oool00P000000103oool000000000003o
ool4000000040?ooo`00000000000?ooo`@0000000@0oooo000000000000oooo0P0000020?ooo`03
0000003oool0oooo00<000000P3oool3000000030?ooo`000000000000<0oooo0P000000103oool0
00000000000000020?ooo`/0dLfY0P3oool3000000H0oooo00<000000?ooo`3oool01P3oool50000
00030?ooo`000000000000<0oooo100000070?ooo`@000000`3oool2000000030?ooo`0000000000
00<00000203oool00`000000oooo0?ooo`040?ooo`<000000P3oool<0=7=Z@<0oooo0`0000020?oo
o`H000000`3oool00`000000oooo0?ooo`03000000<0oooo00@000000?ooo`3oool0oooo0P000000
103oool000000000003oool2000000L0oooo0P0000030?ooo`H0000000@0oooo000000000000oooo
0P0000000`3oool00000000000040?ooo`80000000<0oooo0000000000000`00000>0=7=Z@00303A
cJT2000000D0oooo1000000A0?ooo`<000000P3oool00`000000oooo0?ooo`0500000080oooo00<0
00000?ooo`3oool00`00000A0?ooo`@000001@3oool2000000`0dLfY0`0000030?ooo`@0000000<0
oooo0000000000001P3oool5000000D0oooo00<000000?ooo`3oool00`0000020?ooo`<000000P3o
ool300000080oooo00<000000?ooo`3oool00`3oool5000000H0oooo0P0000000`3oool000000000
0002000000<0oooo0`00000;0=7=Z@80oooo0`0000000`3oool00000000000030?ooo`80000000<0
oooo0000000000000P000000103oool000000000000000020?ooo`030000003oool0oooo00800000
00@0oooo000000000000oooo10000000103oool000000000003oool4000000040?ooo`0000000000
0?ooo`8000000P3oool00`000000oooo0?ooo`0300000080oooo0`0000000`3oool0000000000003
0?ooo`80000000@0oooo00000000000000000P3oool;0=7=Z@H00000203oool00`000000oooo0?oo
o`05000000030?ooo`000000000000@0oooo0P0000000`3oool0000000000003000000<0oooo1@00
00000`3oool00000000000040?ooo`80000000<0oooo0000000000000`0000020?ooo`030000003o
ool0oooo00H0oooo1P00000<0=7=Z@80oooo00@000000?ooo`3oool000000`3oool3000000<0oooo
0P0000070?ooo`<000001@3oool6000000040?ooo`00000000000?ooo`800000103oool300000080
oooo1`0000020?ooo`030000003oool0oooo00<0oooo1P0000020?ooo`030000003AcJT0dLfY00`0
dLfY000<0=7=Z@<0oooo10000000103oool000000000003oool4000000<0oooo0`0000020?ooo`80
000000<0oooo0000000000000`0000030?ooo`8000000P3oool00`000000oooo0?ooo`02000000<0
oooo1@0000000`3oool00000000000020?ooo`<000000`3oool4000000040?ooo`00000000000?oo
o`@000000`3oool<0=7=Z@<000000`3oool4000000030?ooo`000000000000H0oooo1@0000050?oo
o`030000003oool0oooo00<000000P3oool300000080oooo0`0000020?ooo`030000003oool0oooo
00<0oooo1@0000060?ooo`80000000<0oooo0000000000000P0000030?ooo`<000002`3AcJT50?oo
o`030000003oool0oooo00<0oooo0`0000040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3ooolD000000@0oooo00<000000?ooo`3oool00`3oool2000000<0oooo0`0000050?oo
o`030000003oool0oooo00<0oooo2`3AcJT6000000P0oooo00<000000?ooo`3oool01@0000000`3o
ool00000000000040?ooo`80000000<0oooo0000000000000`0000030?ooo`D0000000<0oooo0000
00000000103oool2000000030?ooo`000000000000<000000P3oool00`000000oooo0?ooo`060?oo
o`H00000303AcJT2000000040?ooo`0000000000000000<0oooo0`0000020?ooo`T000000`3oool0
0`000000oooo0?ooo`07000000<0oooo0`0000020?ooo`<0000000<0oooo0000000000000`3oool3
000000H0oooo00<000000?ooo`3oool00`3oool3000000030?ooo`00000000000080oooo00<00000
0=7=Z@3AcJT0303AcJT000`0dLfY0`3oool4000000040?ooo`00000000000?ooo`@000000`3oool3
00000080oooo0P0000000`3oool0000000000003000000<0oooo0P0000020?ooo`030000003oool0
oooo008000000`3oool5000000030?ooo`00000000000080oooo0`0000030?ooo`@0000000@0oooo
000000000000oooo100000030?ooo``0dLfY0`0000030?ooo`800000203oool5000000<0oooo0P00
0000103oool000000000003oool4000000030?ooo`000000000000D0000000<0oooo000000000000
0P000000103oool000000000003oool2000000<0oooo1@0000080?ooo`8000000`3oool3000000/0
dLfY1@3oool00`000000oooo0?ooo`030?ooo`<00000103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo500000040?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<0
00001@3oool00`000000oooo0?ooo`030?ooo`/0dLfY1P0000060?ooo`80000000@0oooo00000000
0000oooo1@0000050?ooo`040000003oool0oooo00000080oooo0`0000030?ooo`<000000P3oool0
10000000oooo0?ooo`0000050?ooo`D0000000@0oooo000000000000oooo0P0000060?ooo`H00000
303AcJT2000000040?ooo`0000000000000000<0oooo0`0000020?ooo`T000000`3oool00`000000
oooo0?ooo`07000000<0oooo0`0000020?ooo`<0000000<0oooo0000000000000`3oool3000000H0
oooo00<000000?ooo`3oool00`3oool3000000030?ooo`00000000000080oooo00<000000=7=Z@3A
cJT0303AcJT000`0dLfY0P0000000`3oool00000000000030?ooo`8000000`3oool2000000<0oooo
0P0000000`3oool000000000000300000080oooo1P0000020?ooo`D000000P3oool600000080oooo
1@0000000`3oool00000000000030?ooo`8000000`3oool2000000<0oooo0P0000000`3oool00000
0000000<0=7=Z@<000001@3oool2000000H0oooo0`0000020?ooo`<000000P3oool010000000oooo
0?ooo`0000040?ooo`T00000103oool010000000oooo0?ooo`0000020?ooo`<000000P3oool30000
00H0oooo0P0000050?ooo`<000002`3AcJT20?ooo`<000000`3oool8000000<0oooo0`0000030?oo
o`D000000P3oool00`000000oooo0?ooo`0800000080oooo00<000000?ooo`3oool01@0000030?oo
o`<000000`3oool8000000<0oooo0`0000020?ooo`/0dLfY3`3oool3000000@0oooo0`0000030?oo
o`<000001P3oool3000000H0oooo0`0000030?ooo`<00000103oool3000000l0oooo303AcJT20?oo
o`<000000`3oool7000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040000
00D0oooo00<000000?ooo`3oool00`0000070?ooo`80000000<0oooo0000000000000`0000040?oo
o`8000001P3oool3000000<0oooo3P3AcJT000`0dLfYC@00000<0=7=Z@<000001@3oool2000000H0
oooo0`0000020?ooo`<000000P3oool010000000oooo0?ooo`0000040?ooo`T00000103oool01000
0000oooo0?ooo`0000020?ooo`<000000P3oool3000000H0oooo0P0000050?ooo`<000002`3AcJU>
000000/0dLfY3`3oool3000000@0oooo0`0000030?ooo`<000001P3oool3000000H0oooo0`000003
0?ooo`<00000103oool3000000l0oooo303AcJT20?ooo`<0000000<0oooo0000000000000`3oool0
10000000oooo0?ooo`3oool2000000040?ooo`000000000000000080oooo100000020?ooo`<00000
00<0oooo0000000000000`3oool010000000oooo0?ooo`3oool2000000040?ooo`00000000000000
0080oooo100000020?ooo`<0000000<0oooo0000000000000`3oool010000000oooo0?ooo`3oool2
000000030?ooo`00000000000080000000<0oooo0=7=Z@3AcJT0303AcJT000`0dLfYC@00000<0=7=
Z@<000001@3oool2000000H0oooo0`0000020?ooo`<000000P3oool010000000oooo0?ooo`000004
0?ooo`T00000103oool010000000oooo0?ooo`0000020?ooo`<000000P3oool3000000H0oooo0P00
00050?ooo`<000002`3AcJU>000000/0dLfY3`3oool3000000@0oooo0`0000030?ooo`<000001P3o
ool3000000H0oooo0`0000030?ooo`<00000103oool3000000l0oooo303AcJT20?ooo`<0000000<0
oooo0000000000000`3oool010000000oooo0?ooo`3oool2000000040?ooo`000000000000000080
oooo100000020?ooo`<0000000<0oooo0000000000000`3oool010000000oooo0?ooo`3oool20000
00040?ooo`000000000000000080oooo100000020?ooo`<0000000<0oooo0000000000000`3oool0
10000000oooo0?ooo`3oool2000000030?ooo`00000000000080000000<0oooo0=7=Z@3AcJT0303A
cJT000`0dLfY0P0000000`3oool00000000000030?ooo`8000000`3oool2000000<0oooo0P000000
0`3oool000000000000300000080oooo1P0000020?ooo`D000000P3oool600000080oooo1@000000
0`3oool00000000000030?ooo`8000000`3oool2000000<0oooo0P0000000`3oool000000000000<
0=7=Z@<000001@3oool2000000H0oooo0`0000020?ooo`<000000P3oool010000000oooo0?ooo`00
00040?ooo`T00000103oool010000000oooo0?ooo`0000020?ooo`<000000P3oool3000000H0oooo
0P0000050?ooo`<000002`3AcJT20?ooo`<000000`3oool8000000<0oooo0`0000030?ooo`D00000
0P3oool00`000000oooo0?ooo`0800000080oooo00<000000?ooo`3oool01@0000030?ooo`<00000
0`3oool8000000<0oooo0`0000020?ooo`/0dLfY3`3oool3000000@0oooo0`0000030?ooo`<00000
1P3oool3000000H0oooo0`0000030?ooo`<00000103oool3000000l0oooo303AcJT30?ooo`800000
00<0oooo0000000000002@0000090?ooo`040000003oool0oooo0?ooo`D000000`3oool010000000
oooo0?ooo`0000050?ooo`040000003oool0oooo0?ooo`80000000@0oooo000000000000oooo0P00
0000103oool000000000003oool2000000@0oooo1`0000000`3oool0dLfY0=7=Z@0<0=7=Z@00303A
cJT30?ooo`@0000000@0oooo000000000000oooo100000030?ooo`<000000P3oool2000000030?oo
o`000000000000<000000`3oool200000080oooo00<000000?ooo`3oool00P0000030?ooo`D00000
00<0oooo0000000000000P3oool3000000<0oooo10000000103oool000000000003oool4000000<0
oooo303AcJT3000000<0oooo0P0000080?ooo`D000000`3oool2000000040?ooo`00000000000?oo
o`@0000000<0oooo0000000000001@0000000`3oool0000000000002000000040?ooo`0000000000
0?ooo`8000000`3oool5000000P0oooo0P0000030?ooo`<000002`3AcJT50?ooo`030000003oool0
oooo00<0oooo0`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3ooolD
000000@0oooo00<000000?ooo`3oool00`3oool2000000<0oooo0`0000050?ooo`030000003oool0
oooo00<0oooo2`3AcJT6000000H0oooo0P000000103oool000000000003oool5000000D0oooo00@0
00000?ooo`3oool000000P3oool3000000<0oooo0`0000020?ooo`040000003oool0oooo000000D0
oooo1@000000103oool000000000003oool2000000H0oooo1P00000<0=7=Z@80oooo00<000000?oo
o`3oool00`000000103oool000000000000000020?ooo`040000003oool0oooo000000P0oooo0`00
00030?ooo`040000003oool0oooo000000<0oooo1P0000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`000000103oool000000000000000050?ooo`030000003oool0oooo00<0
oooo0P0000000`3oool0dLfY0=7=Z@0<0=7=Z@00303AcJT30?ooo`@0000000@0oooo000000000000
oooo100000030?ooo`<000000P3oool2000000030?ooo`000000000000<000000`3oool200000080
oooo00<000000?ooo`3oool00P0000030?ooo`D0000000<0oooo0000000000000P3oool3000000<0
oooo10000000103oool000000000003oool4000000<0oooo303AcJT3000000<0oooo100000000`3o
ool00000000000060?ooo`D000001@3oool00`000000oooo0?ooo`0300000080oooo0`0000020?oo
o`<000000P3oool00`000000oooo0?ooo`030?ooo`D000001P3oool2000000030?ooo`0000000000
008000000`3oool3000000/0dLfY1@3oool00`000000oooo0?ooo`030?ooo`<00000103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo500000040?ooo`030000003oool0oooo
00<0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`030?ooo`/0dLfY1P0000080?oo
o`030000003oool0oooo00D0000000<0oooo000000000000103oool2000000030?ooo`0000000000
00<000000`3oool5000000030?ooo`000000000000@0oooo0P0000000`3oool00000000000030000
0080oooo00<000000?ooo`3oool01P3oool6000000`0dLfY0P3oool00`000000oooo0?ooo`030000
00040?ooo`000000000000000080oooo00@000000?ooo`3oool00000203oool3000000<0oooo00@0
00000?ooo`3oool000000`3oool600000080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`03000000040?ooo`0000000000000000D0oooo00<000000?ooo`3oool00`3oool200000003
0?ooo`3AcJT0dLfY00`0dLfY000<0=7=Z@8000001@3oool400000140oooo0`0000020?ooo`030000
003oool0oooo00D000000P3oool00`000000oooo0?ooo`0300000140oooo100000050?ooo`800000
303AcJT3000000<0oooo100000000`3oool00000000000060?ooo`D000001@3oool00`000000oooo
0?ooo`0300000080oooo0`0000020?ooo`<000000P3oool00`000000oooo0?ooo`030?ooo`D00000
1P3oool2000000030?ooo`0000000000008000000`3oool3000000/0dLfY0P3oool3000000030?oo
o`000000000000<0oooo0P0000000`3oool0000000000002000000040?ooo`000000000000000080
oooo00<000000?ooo`3oool00P000000103oool000000000003oool4000000040?ooo`0000000000
0?ooo`@0000000@0oooo000000000000oooo0P0000020?ooo`030000003oool0oooo00<000000P3o
ool3000000030?ooo`000000000000<0oooo0P000000103oool000000000000000020?ooo`/0dLfY
1P0000080?ooo`030000003oool0oooo00D0000000<0oooo000000000000103oool2000000030?oo
o`000000000000<000000`3oool5000000030?ooo`000000000000@0oooo0P0000000`3oool00000
0000000300000080oooo00<000000?ooo`3oool01P3oool6000000`0dLfY0`0000050?ooo`030000
003oool0oooo00L000000`3oool2000000030?ooo`000000000000<00000103oool2000000H0oooo
100000050?ooo`040000003oool0oooo00000080oooo0`0000040?ooo`80000000@0oooo00000000
0000oooo0P0000000`3oool00000000000030?ooo`h0dLfY000<0=7=Z@8000001@3oool400000140
oooo0`0000020?ooo`030000003oool0oooo00D000000P3oool00`000000oooo0?ooo`0300000140
oooo100000050?ooo`800000303AcJT3000000<0oooo1@0000080?ooo`<000000P3oool2000000@0
oooo1`0000030?ooo`L00000103oool200000080oooo0`0000080?ooo`D000000`3oool3000000/0
dLfY0P3oool3000000030?ooo`000000000000<0oooo0P0000000`3oool000000000000200000004
0?ooo`000000000000000080oooo00<000000?ooo`3oool00P000000103oool000000000003oool4
000000040?ooo`00000000000?ooo`@0000000@0oooo000000000000oooo0P0000020?ooo`030000
003oool0oooo00<000000P3oool3000000030?ooo`000000000000<0oooo0P000000103oool00000
0000000000020?ooo`/0dLfY0P3oool3000000H0oooo00<000000?ooo`3oool01P3oool500000003
0?ooo`000000000000<0oooo100000070?ooo`@000000`3oool2000000030?ooo`000000000000<0
0000203oool00`000000oooo0?ooo`040?ooo`<000000P3oool<0=7=Z@<000000P3oool900000003
0?ooo`000000000000<000001P3oool4000000H0oooo0P0000040?ooo`8000000`3oool700000080
oooo00<000000?ooo`3oool0103oool2000000`0oooo3P3AcJT000`0dLfY0P3oool300000080oooo
100000020?ooo`L000000`3oool2000000030?ooo`000000000000D000000`3oool5000000<0oooo
1`0000000`3oool00000000000030?ooo`L000000P3oool400000080oooo0`0000020?ooo``0dLfY
0`0000030?ooo`D00000203oool300000080oooo0P0000040?ooo`L000000`3oool7000000@0oooo
0P0000020?ooo`<00000203oool5000000<0oooo0`00000;0=7=Z@<0oooo0P0000050?ooo`<00000
00<0oooo0000000000003@000000103oool000000000000000020?ooo`P000000P3oool300000003
0?ooo`000000000000d0000000@0oooo00000000000000001@3oool2000000<0oooo2`3AcJT20000
00<0oooo00@000000?ooo`3oool0oooo0P0000070?ooo`8000000P3oool4000000D0oooo0`000000
0`3oool00000000000030?ooo`80000000@0oooo00000000000000001@3oool400000080oooo0P00
00070?ooo`8000000`3oool010000000oooo0?ooo`3oool2000000`0dLfY0`0000020?ooo`T00000
00<0oooo0000000000000`0000060?ooo`@000001P3oool2000000@0oooo0P0000030?ooo`L00000
0P3oool00`000000oooo0?ooo`040?ooo`800000303oool>0=7=Z@00303AcJT70?ooo`040000003o
ool0oooo000000@0oooo0`0000020?ooo`030000003oool0oooo0080000000<0oooo000000000000
5`0000000`3oool00000000000020?ooo`030000003oool0oooo00<00000103oool010000000oooo
0?ooo`0000070?ooo``0dLfY0`0000020?ooo`030000003oool0oooo0080000000@0oooo00000000
000000001@3oool5000000<0oooo1`0000000`3oool00000000000030?ooo`80000000<0oooo0000
000000001@0000030?ooo`D000001@3oool3000000030?ooo`00000000000080oooo00<000000?oo
o`3oool00`00000;0=7=Z@80oooo00<000000?ooo`3oool00`3oool5000000<0oooo1@0000040?oo
o`8000000P3oool8000000040?ooo`00000000000?ooo`P000000P3oool2000000@0oooo1@000003
0?ooo`D000001@3oool00`000000oooo0?ooo`0;0=7=Z@8000000`3oool010000000oooo0?ooo`3o
ool2000000L0oooo0P0000020?ooo`@000001@3oool3000000030?ooo`000000000000<0oooo0P00
0000103oool000000000000000050?ooo`@000000P3oool2000000L0oooo0P0000030?ooo`040000
003oool0oooo0?ooo`800000303AcJT2000000`0oooo00<000000?ooo`3oool0103oool3000000<0
oooo0`0000020?ooo`@000000`3oool2000000@0oooo0`0000030?ooo`8000000`3oool00`000000
oooo0?ooo`030?ooo`<0000000<0oooo0000000000000`0000060?ooo`h0dLfY000<0=7=Z@L0oooo
00@000000?ooo`3oool00000103oool300000080oooo00<000000?ooo`3oool00P0000000`3oool0
00000000000G000000030?ooo`00000000000080oooo00<000000?ooo`3oool00`0000040?ooo`04
0000003oool0oooo000000L0oooo303AcJT5000000030?ooo`00000000000080oooo00@000000?oo
o`3oool0oooo0P0000030?ooo`<000000P3oool300000080oooo0`0000020?ooo`030000003oool0
oooo00<000000P3oool00`000000oooo0?ooo`0300000080oooo0`0000020?ooo`<000000`3oool2
000000<0oooo00<000000?ooo`3oool00P0000000`3oool0000000000003000000/0dLfY0P3oool0
0`000000oooo0?ooo`030?ooo`D000000`3oool5000000@0oooo0P0000020?ooo`P0000000@0oooo
000000000000oooo200000020?ooo`800000103oool5000000<0oooo1@0000050?ooo`030000003o
ool0oooo00/0dLfY1P0000020?ooo`<0000000@0oooo000000000000oooo0`0000040?ooo`040000
003oool0oooo00000080oooo0`0000030?ooo`030000003oool0oooo00<000000P3oool010000000
oooo0?ooo`3oool300000080oooo00@000000?ooo`3oool00000103oool3000000040?ooo`000000
00000?ooo`<000000P3oool6000000`0dLfY0P3oool010000000oooo0?ooo`3oool300000080oooo
00@000000?ooo`3oool0oooo1P0000020?ooo`030000003oool0oooo00@000000P3oool300000004
0?ooo`00000000000?ooo`/0000000@0oooo0000000000000000203oool010000000oooo0?ooo`3o
ool2000000<0oooo00<000000?ooo`3oool00`00000>0=7=Z@00303AcJT300000080oooo2`000002
0?ooo`80000000<0oooo0000000000000`0000020?oooaD000000P3oool5000000030?ooo`000000
00000080oooo2`0000020?ooo`<00000303AcJT5000000030?ooo`00000000000080oooo00@00000
0?ooo`3oool0oooo0P0000030?ooo`<000000P3oool300000080oooo0`0000020?ooo`030000003o
ool0oooo00<000000P3oool00`000000oooo0?ooo`0300000080oooo0`0000020?ooo`<000000`3o
ool2000000<0oooo00<000000?ooo`3oool00P0000000`3oool0000000000003000000/0dLfY0`3o
ool2000000030?ooo`000000000000D0oooo1@0000000`3oool000000000000;000000<0oooo2000
00030?ooo`d000000P3oool4000000D0oooo0P0000000`3oool00000000000030?ooo`/0dLfY2000
00030?ooo`030000003oool0oooo00@000001@3oool2000000030?ooo`000000000000<00000103o
ool7000000@0oooo1@0000000`3oool00000000000050?ooo`@000000P3oool010000000oooo0?oo
o`3oool8000000`0dLfY0P3oool010000000oooo0?ooo`3oool300000080oooo00@000000?ooo`3o
ool0oooo1P0000020?ooo`030000003oool0oooo00@000000P3oool3000000040?ooo`0000000000
0?ooo`/0000000@0oooo0000000000000000203oool010000000oooo0?ooo`3oool2000000<0oooo
00<000000?ooo`3oool00`00000>0=7=Z@00303AcJT300000080oooo2`0000020?ooo`80000000<0
oooo0000000000000`0000020?oooaD000000P3oool5000000030?ooo`00000000000080oooo2`00
00020?ooo`<00000303AcJT2000000H0oooo0`0000020?ooo`<000000`3oool:000000030?ooo`00
0000000000<0oooo0P0000030?ooo`8000000`3oool2000000030?ooo`000000000000P000000`3o
ool300000080oooo0`0000060?ooo`8000002`3AcJT30?ooo`<000000P3oool2000000/0oooo0`00
00030?ooo`<000000P3oool300000080oooo100000020?ooo`<000000P3oool3000000<0oooo0`00
000;0?ooo`8000000P3oool3000000<0oooo2`3AcJT8000000<0oooo00<000000?ooo`3oool01000
00050?ooo`80000000<0oooo0000000000000`0000040?ooo`L00000103oool5000000030?ooo`00
0000000000D0oooo100000020?ooo`040000003oool0oooo0?ooo`P00000303AcJT20?ooo`<00000
0`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@000000P3oool600000003
0?ooo`000000000000H0oooo00@000000?ooo`3oool0oooo0`0000050?ooo`@000000`3oool20000
00030?ooo`000000000000<0oooo00@000000?ooo`3oool0oooo1`0000000`3oool0dLfY0=7=Z@0<
0=7=Z@00303AcJT30?ooo`8000000P3oool010000000oooo0?ooo`3oool200000080oooo1P000002
0?ooo`D000000P3oool3000000030?ooo`00000000000080oooo00<000000?ooo`3oool00P000000
0`3oool0000000000002000000030?ooo`000000000000<000000P3oool600000080oooo0P000003
0?ooo`030000003oool0oooo008000000`3oool<0=7=Z@80oooo00@000000?ooo`3oool0oooo0P00
00030?ooo`D000000`3oool;000000L0oooo0`0000070?ooo`/000000`3oool5000000<0oooo0P00
00030?ooo`030000003oool0oooo00/0dLfY0`3oool300000080oooo0P00000;0?ooo`<000000`3o
ool300000080oooo0`0000020?ooo`@000000P3oool300000080oooo0`0000030?ooo`<000002`3o
ool200000080oooo0`0000030?ooo`/0dLfY0P0000060?ooo`H000000`3oool5000000030?ooo`00
0000000000@000000`3oool2000000T0oooo0P0000030?ooo`H0000000<0oooo0000000000000`00
00030?ooo`H000001P3oool2000000`0dLfY0`0000020?ooo`040000003oool0oooo0?ooo`<00000
0P3oool400000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03000000030?oo
o`000000000000@000000`3oool2000000030?ooo`000000000000<0oooo100000020?ooo`040000
003oool0oooo0?ooo`D0000000@0oooo00000000000000001@3oool3000000h0dLfY000<0=7=Z@<0
oooo0P0000020?ooo`<00000203oool500000080oooo1@0000060?ooo`D000001`3oool400000080
oooo1@0000080?ooo`<000000P3oool2000000<0oooo303AcJT20?ooo`040000003oool0oooo0?oo
o`8000000`3oool5000000<0oooo2`0000070?ooo`<000001`3oool;000000<0oooo1@0000030?oo
o`8000000`3oool00`000000oooo0?ooo`0;0=7=Z@800000103oool200000080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0600000080oooo100000040?ooo`@00000103oool4
00000080oooo1P0000020?ooo`8000000`3oool010000000oooo0?ooo`0000020?ooo`800000103o
ool2000000/0dLfY0P3oool010000000oooo0?ooo`3oool2000000040?ooo`000000000000000080
oooo0`0000000`3oool000000000000300000080oooo0`000000103oool0000000000000000=0?oo
o`<0000000@0oooo00000000000000000P3oool5000000040?ooo`000000000000000080oooo0`00
00000`3oool00000000000030?ooo`030000003oool0oooo00`0dLfY0`0000020?ooo`040000003o
ool0oooo0?ooo`<000000P3oool400000080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`03000000030?ooo`000000000000@000000`3oool2000000030?ooo`000000000000<0oooo
100000020?ooo`040000003oool0oooo0?ooo`D0000000@0oooo00000000000000001@3oool30000
00h0dLfY000<0=7=Z@<0oooo0P0000020?ooo`<00000203oool500000080oooo1@0000060?ooo`D0
00001`3oool400000080oooo1@0000080?ooo`<000000P3oool2000000<0oooo303AcJT200000003
0?ooo`000000000000<0oooo0`0000020?ooo`030000003oool0oooo0080000000@0oooo00000000
0000oooo200000020?ooo`80000000<0oooo0000000000000`3oool2000000030?ooo`0000000000
0080oooo20000000103oool000000000003oool200000080oooo00<000000?ooo`3oool00`000003
0?ooo`80000000<0oooo0000000000002`3AcJT2000000@0oooo0P0000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool01P0000020?ooo`@00000103oool4000000@0oooo1000
00020?ooo`H000000P3oool2000000<0oooo00@000000?ooo`3oool000000P3oool2000000@0oooo
0P00000;0=7=Z@80oooo00@000000?ooo`3oool0oooo0P000000103oool000000000000000020?oo
o`<0000000<0oooo0000000000000`0000020?ooo`<0000000@0oooo00000000000000003@3oool3
000000040?ooo`000000000000000080oooo1@000000103oool000000000000000020?ooo`<00000
00<0oooo0000000000000`3oool00`000000oooo0?ooo`0<0=7=Z@80oooo00@000000?ooo`3oool0
00000P3oool6000000040?ooo`000000000000000080oooo00@000000?ooo`3oool0oooo0P000000
0`3oool00000000000030?ooo`H000000`3oool010000000oooo0?ooo`3oool8000000@0oooo0P00
0000103oool000000000003oool3000000D0oooo00<000000?ooo`3oool00`00000>0=7=Z@00303A
cJT2000000030?ooo`00000000000080000000<0oooo0000000000001@0000000`3oool000000000
0002000000<0oooo0P0000000`3oool0000000000005000000030?ooo`000000000000L0000000<0
oooo0000000000001@0000000`3oool00000000000030?ooo`@0000000<0oooo0000000000001@00
00000`3oool0000000000002000000030?ooo`000000000000`0dLfY0P0000000`3oool000000000
00030?ooo`<000000P3oool00`000000oooo0?ooo`02000000040?ooo`00000000000?ooo`P00000
0P3oool2000000030?ooo`000000000000<0oooo0P0000000`3oool00000000000020?ooo`P00000
00@0oooo000000000000oooo0P0000020?ooo`030000003oool0oooo00<000000`3oool200000003
0?ooo`000000000000/0dLfY0P3oool8000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`<000000P3oool00`000000oooo0?ooo`05000000040?ooo`00000000000?oo
o`D000000P3oool00`000000oooo0?ooo`03000000D0oooo0P0000030?ooo`040000003oool0oooo
0?ooo`P000000P3oool;0=7=Z@P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`05
0?ooo`<0000000@0oooo00000000000000000P3oool400000080oooo0`0000020?ooo`@000000P3o
ool3000000040?ooo`0000000000000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`060?ooo``0dLfY0P3oool010000000oooo0?ooo`0000020?ooo`H0000000@0oooo00000000
000000000P3oool010000000oooo0?ooo`3oool2000000030?ooo`000000000000<0oooo1P000003
0?ooo`040000003oool0oooo0?ooo`P00000103oool2000000040?ooo`00000000000?ooo`<00000
1@3oool00`000000oooo0?ooo`03000000h0dLfY000<0=7=Z@80000000<0oooo0000000000000P00
00000`3oool0000000000005000000030?ooo`0000000000008000000`3oool2000000030?ooo`00
0000000000D0000000<0oooo0000000000001`0000000`3oool0000000000005000000030?ooo`00
0000000000<0oooo100000000`3oool0000000000005000000030?ooo`00000000000080000000<0
oooo000000000000303AcJT20?ooo`030000003oool0oooo00<000000`3oool2000000030?ooo`00
000000000080oooo00<000000?ooo`3oool0200000000`3oool00000000000020?ooo`030000003o
ool0oooo00<000000P3oool00`000000oooo0?ooo`02000000030?ooo`000000000000H000000P3o
ool00`000000oooo0?ooo`02000000030?ooo`000000000000<0oooo0`0000020?ooo`030000003o
ool0oooo00/0dLfY3P3oool2000000<0oooo1@0000000`3oool000000000000300000080oooo00<0
00000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool01@0000000`3oool000000000
0003000000<0oooo0P00000>0?ooo`/0dLfY203oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00D0oooo0`000000103oool000000000000000020?ooo`@000000P3oool300000080oooo
100000020?ooo`<0000000@0oooo00000000000000001`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00H0oooo303AcJT30?ooo`800000103oool300000080oooo0`0000090?ooo`03
0000003oool0oooo00<000000`3oool00`000000oooo0?ooo`040?ooo`<000000P3oool00`000000
oooo0?ooo`040?ooo`8000000`3oool6000000030?ooo`000000000000<0oooo0`0000030?ooo`h0
dLfY000<0=7=Z@8000001@3oool3000000<0oooo0P0000000`3oool0000000000002000000030?oo
o`00000000000080oooo00<000000?ooo`3oool00P0000060?ooo`D000001`3oool010000000oooo
0?ooo`0000020?ooo`80000000<0oooo0000000000000P0000000`3oool00000000000030?ooo`<0
00001@3oool2000000`0dLfY0P0000040?ooo`8000000P3oool010000000oooo0?ooo`3oool40000
00030?ooo`000000000000<000000P3oool900000080oooo0`0000020?ooo`T000000P3oool50000
00030?ooo`0000000000008000000`3oool00`000000oooo0?ooo`02000000@0oooo0P00000;0=7=
Z@h0oooo0P0000030?ooo`D0000000<0oooo0000000000000`0000020?ooo`030000003oool0oooo
00<0oooo0P0000050?ooo`030000003oool0oooo00D0000000<0oooo0000000000000`0000030?oo
o`8000003P3oool;0=7=Z@H0oooo0P0000040?ooo`800000203oool4000000<0oooo1@0000000`3o
ool0000000000005000000030?ooo`000000000000<000000`3oool4000000P0oooo0P0000040?oo
o`8000001P3oool<0=7=Z@80oooo00<000000?ooo`3oool00`3oool<000000040?ooo`0000000000
00000080oooo0`0000040?ooo`<000000P3oool3000000<0oooo0`000000103oool0000000000000
00050?ooo`030000003oool0oooo00@0oooo0`0000020?ooo`<0000000<0oooo0000000000000P3o
ool00`000000dLfY0=7=Z@0<0=7=Z@00303AcJT20?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0200000040?ooo`<000000P3oool010000000oooo0?ooo`3oool200000080oooo00<0
00000?ooo`3oool00P0000030?ooo`80000000@0oooo0000000000000000103oool800000080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0=7=Z@800000103oool200000080oooo
00@000000?ooo`3oool0oooo100000000`3oool000000000000300000080oooo2@0000020?ooo`<0
00000P3oool900000080oooo1@0000000`3oool0000000000002000000<0oooo00<000000?ooo`3o
ool00P0000040?ooo`8000002`3AcJT20?ooo`<000000`3oool2000000030?ooo`000000000000D0
oooo1P0000000`3oool000000000000300000080oooo0`0000020?ooo`@000000P3oool300000080
oooo1@0000000`3oool0000000000005000000@0oooo0P0000000`3oool00000000000030?ooo`<0
00000P3oool;0=7=Z@D0000000<0oooo0000000000003P0000030?ooo`<00000103oool5000000<0
oooo1@0000040?ooo`<000000`3oool@000000030?ooo`000000000000<00000303AcJT20?ooo`03
0000003oool0oooo00<0oooo30000000103oool000000000000000020?ooo`<00000103oool30000
0080oooo0`0000030?ooo`<0000000@0oooo00000000000000001@3oool00`000000oooo0?ooo`04
0?ooo`<000000P3oool3000000030?ooo`00000000000080oooo00<000000=7=Z@3AcJT0303AcJT0
00`0dLfY0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P00000103oool30000
0080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`030000003oool0oooo008000000`3oool2
000000040?ooo`0000000000000000@0oooo200000020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0303AcJT20?ooo`030000003oool0oooo00<0oooo0P000000103oool000000000
000000040?ooo`@000000P3oool=000000<0oooo3@0000020?ooo`@00000103oool3000000030?oo
o`000000000000D0oooo00<000000?ooo`3oool02`3AcJT20?ooo`H000000`3oool300000080oooo
0P0000000`3oool0000000000003000000D0oooo1P0000020?ooo`@000000P3oool6000000D0oooo
1@0000020?ooo`030000003oool0oooo00<000000`3oool600000080oooo2`3AcJT5000000030?oo
o`000000000000h000000`3oool3000000@0oooo1@0000030?ooo`D00000103oool3000000<0oooo
400000000`3oool0000000000003000000`0dLfY0`3oool2000000@0oooo1@0000030?ooo`040000
003oool0oooo00000080oooo0`0000040?ooo`<000001P3oool5000000030?ooo`000000000000<0
00000`3oool4000000`0oooo1`0000000`3oool0dLfY0=7=Z@0<0=7=Z@00303AcJT300000080oooo
1@0000000`3oool000000000000A000000040?ooo`00000000000?ooo`T0000000<0oooo00000000
00000P3ooolB000000030?ooo`000000000000<000000P3oool3000000`0dLfY0P3oool00`000000
oooo0?ooo`030?ooo`80000000@0oooo0000000000000000103oool400000080oooo3@0000030?oo
o`d000000P3oool4000000@0oooo0`0000000`3oool00000000000050?ooo`030000003oool0oooo
00/0dLfY0P3oool6000000<0oooo0`0000020?ooo`80000000<0oooo0000000000000`0000050?oo
o`H000000P3oool400000080oooo1P0000050?ooo`D000000P3oool00`000000oooo0?ooo`030000
00<0oooo1P0000020?ooo`/0dLfY0`0000020?oooa4000000`3oool3000000<0oooo00<000000?oo
o`3oool00`0000030?ooo`<000000P3oool010000000oooo0?ooo`3oool3000000<0oooo4@000002
0?ooo`<00000303AcJT50?ooo`<000000`3oool400000080oooo0`0000040?ooo`D0000000@0oooo
000000000000oooo0P0000030?ooo`<0000000@0oooo000000000000oooo0P000000103oool00000
0000000000030?ooo`<000000P3oool6000000040?ooo`00000000000?ooo`80000000<0oooo0000
000000000`00000>0=7=Z@00303AcJT300000080oooo1@0000000`3oool000000000000A00000004
0?ooo`00000000000?ooo`T0000000<0oooo0000000000000P3ooolB000000030?ooo`0000000000
00<000000P3oool3000000`0dLfY1P3oool4000000<0oooo200000000`3oool000000000000;0?oo
o`L000002`3oool2000000030?ooo`000000000000H000000`3oool4000000H0oooo2`3AcJT50000
00030?ooo`000000000000P0oooo0`0000020?ooo`030000003oool0oooo00<000000`3oool30000
0080oooo0P000000103oool000000000003oool200000080oooo0`0000030?ooo`<000000P3oool0
0`000000oooo0?ooo`03000000P0oooo0P0000000`3oool0000000000003000000/0dLfY0P000003
0?ooo`H0000000<0oooo000000000000200000040?ooo`D000000`3oool00`000000oooo0?ooo`03
00000080oooo00@000000?ooo`3oool0oooo1@0000040?ooo`X0000000<0oooo0000000000001000
00030?ooo`800000303AcJT50?ooo`<000000`3oool400000080oooo0`0000040?ooo`D0000000@0
oooo000000000000oooo0P0000030?ooo`<0000000@0oooo000000000000oooo0P000000103oool0
00000000000000030?ooo`<000000P3oool6000000040?ooo`00000000000?ooo`80000000<0oooo
0000000000000`00000>0=7=Z@00303AcJT20?ooo`D00000203oool:000000030?ooo`0000000000
0080oooo0`0000050?ooo`030000003oool0oooo00<0oooo10000000103oool000000000003oool:
000000P0oooo1@0000020?ooo``0dLfY1P3oool4000000<0oooo1P0000020?ooo`030000003oool0
oooo008000002@3oool7000000T0oooo0P0000020?ooo`030000003oool0oooo00H000000`3oool4
000000H0oooo2`3AcJT600000080oooo0P0000000`3oool0000000000008000000P0oooo1P000003
0?ooo`8000000`3oool6000000P0oooo2P0000000`3oool00000000000020?ooo`H000002`3AcJT2
000000<0oooo1P0000000`3oool0000000000008000000@0oooo1@0000030?ooo`030000003oool0
oooo00<000000P3oool010000000oooo0?ooo`3oool5000000@0oooo2P0000000`3oool000000000
0004000000<0oooo0P00000<0=7=Z@<000001P3oool2000000040?ooo`00000000000?ooo`800000
0`3oool9000000030?ooo`000000000000<000001P3oool00`000000oooo0?ooo`030?ooo`<00000
103oool2000000030?ooo`000000000000<0oooo100000030?ooo`8000000`3oool3000000h0dLfY
000<0=7=Z@D000000`3oool2000000<0oooo200000050?ooo`L000001@3oool00`000000oooo0?oo
o`030?ooo`L000001@3oool8000000<0oooo0P0000030?ooo`D00000303AcJT60?ooo`@000000`3o
ool600000080oooo00<000000?ooo`3oool00P0000090?ooo`L000002@3oool200000080oooo00<0
00000?ooo`3oool01P0000030?ooo`@000001P3oool;0=7=Z@H000000P3oool2000000030?ooo`00
0000000000P00000203oool6000000<0oooo0P0000030?ooo`H00000203oool:000000030?ooo`00
000000000080oooo1P00000;0=7=Z@80oooo0`000000103oool000000000000000020?ooo`/00000
0`3oool00`000000oooo0?ooo`03000000@0oooo1`0000040?ooo`<000000P3oool010000000oooo
0?ooo`3oool;00000080oooo0`000000103oool000000000000000020?ooo``0dLfY0`0000030?oo
o`8000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo0P0000030?oo
o`H0000000@0oooo00000000000000000P3oool00`000000oooo0?ooo`040?ooo`80000000@0oooo
000000000000oooo0P0000090?ooo`<0000000<0oooo0000000000000`3oool3000000h0dLfY000<
0=7=Z@D000000`3oool2000000<0oooo200000050?ooo`L000001@3oool00`000000oooo0?ooo`03
0?ooo`L000001@3oool8000000<0oooo0P0000030?ooo`D00000303AcJT20?ooo`030000003oool0
oooo00D0000000<0oooo0000000000001P0000020?ooo`<000000P3oool400000140oooo10000002
0?ooo`<000000P3oool8000000030?ooo`000000000000<000000P3oool00`000000oooo0?ooo`0;
0=7=Z@<000000`3oool4000000030?ooo`000000000000D00000103oool2000000D0oooo00<00000
0?ooo`3oool00`0000020?ooo`@000000P3oool300000080oooo00<000000?ooo`3oool00`3oool2
000000D0oooo1P0000000`3oool0000000000002000000<0oooo0`00000;0=7=Z@80000000<0oooo
0000000000000`0000040?ooo`X0000000@0oooo00000000000000000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`03000000030?ooo`000000000000P00000103oool5000000030?ooo`000000000000`0dLfY0`00
00030?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo0P00
00030?ooo`H0000000@0oooo00000000000000000P3oool00`000000oooo0?ooo`040?ooo`800000
00@0oooo000000000000oooo0P0000090?ooo`<0000000<0oooo0000000000000`3oool3000000h0
dLfY000<0=7=Z@<000000P3oool2000000040?ooo`00000000000?ooo`D000000P3oool7000000<0
oooo0P000000103oool000000000003oool9000000030?ooo`00000000000080oooo00@000000?oo
o`3oool0oooo1`0000020?ooo`D0000000@0oooo000000000000oooo0P0000020?ooo`<00000303A
cJT2000000040?ooo`00000000000?ooo`D000000P3oool8000000<0oooo1@0000000`3oool00000
0000000=0?ooo`80000000<0oooo0000000000000`0000030?ooo`P000000P3oool5000000040?oo
o`00000000000?ooo`8000002`3AcJT3000000<0oooo100000000`3oool0000000000005000000@0
oooo0P0000050?ooo`030000003oool0oooo00<000000P3oool400000080oooo0`0000020?ooo`03
0000003oool0oooo00<0oooo0P0000050?ooo`H0000000<0oooo0000000000000P0000030?ooo`<0
00002`3AcJT2000000030?ooo`000000000000<00000103oool:000000040?ooo`00000000000000
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`0000000`3oool0000000000008000000@0oooo1@0000000`3o
ool000000000000<0=7=Z@H0oooo0`0000020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool02@0000030?ooo`040000003oool0oooo000000<0oooo0P0000060?ooo`@00000
0P3oool3000000<0oooo3P3AcJT000`0dLfY0`0000020?ooo`80000000@0oooo000000000000oooo
1@0000020?ooo`L000000`3oool2000000040?ooo`00000000000?ooo`T0000000<0oooo00000000
00000P3oool010000000oooo0?ooo`3oool700000080oooo1@000000103oool000000000003oool2
00000080oooo0`00000<0=7=Z@80000000@0oooo000000000000oooo1@0000020?ooo`P000000`3o
ool5000000030?ooo`000000000000d0oooo0P0000000`3oool0000000000003000000<0oooo2000
00020?ooo`D0000000@0oooo000000000000oooo0P00000;0=7=Z@<0oooo0P0000030?ooo`800000
0`3oool5000000030?ooo`000000000000<0oooo0`0000020?ooo`030000003oool0oooo00<0oooo
200000050?ooo`030000003oool0oooo00<000000`3oool200000080oooo100000030?ooo`800000
0`3oool2000000<0oooo2`3AcJT20?ooo`@000000P3oool010000000oooo0?ooo`3oool;000000<0
oooo0P0000000`3oool00000000000040?ooo`8000000`3oool2000000@0oooo0P0000000`3oool0
0000000000030?ooo`/000000`3oool00`000000oooo0?ooo`0400000080oooo303AcJT90?ooo`80
000000<0oooo0000000000001`0000020?ooo`<0000000@0oooo000000000000oooo0P000000103o
ool000000000000000050?ooo`030000003oool0oooo00<0oooo1P0000030?ooo`@000000P3oool3
000000040?ooo`00000000000?ooo`8000001@3oool00`000000dLfY0=7=Z@0<0=7=Z@00303AcJT3
0?ooo`@0000000@0oooo000000000000oooo100000030?ooo`8000000`3oool2000000030?ooo`00
0000000000800000103oool200000080oooo00<000000?ooo`3oool00P0000050?ooo`<0000000<0
oooo0000000000000`3oool2000000<0oooo10000000103oool000000000003oool4000000<0oooo
303AcJT2000000030?ooo`000000000000<0oooo1@0000000`3oool00000000000030?ooo`800000
00<0oooo0000000000000P3oool010000000oooo0?ooo`3oool200000080oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool00P0000000`3oool0
0000000000030?ooo`80000000<0oooo0000000000000`0000030?ooo`80000000<0oooo00000000
00002`3AcJT20?ooo`<0000000<0oooo0000000000000`3oool2000000030?ooo`00000000000080
000000@0oooo0000000000000000203ooolB000000P0oooo0`0000020?ooo`<0000000<0oooo0000
000000000`3oool2000000040?ooo`000000000000000080oooo2`3AcJT20?ooo`@000000P3oool0
10000000oooo0?ooo`3oool;000000<0oooo0P0000000`3oool00000000000040?ooo`8000000`3o
ool2000000@0oooo0P0000000`3oool00000000000030?ooo`/000000`3oool00`000000oooo0?oo
o`0400000080oooo303AcJT90?ooo`80000000<0oooo0000000000001`0000020?ooo`<0000000@0
oooo000000000000oooo0P000000103oool000000000000000050?ooo`030000003oool0oooo00<0
oooo1P0000030?ooo`@000000P3oool3000000040?ooo`00000000000?ooo`8000001@3oool00`00
0000dLfY0=7=Z@0<0=7=Z@00303AcJT;000000T0oooo00<000000?ooo`3oool00P0000030?ooo`H0
0000103oool00`000000oooo0?ooo`020?ooo`H000000`3oool200000080oooo00<000000?ooo`3o
ool01`3oool;000000`0dLfY0P0000000`3oool00000000000030?ooo`D0000000<0oooo00000000
00000`3oool2000000030?ooo`00000000000080oooo00@000000?ooo`3oool0oooo0P0000020?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P0000030?ooo`030000003oool0oooo
0080000000<0oooo0000000000000`3oool2000000030?ooo`000000000000<000000`3oool20000
00030?ooo`000000000000/0dLfY0P3oool3000000030?ooo`000000000000<0oooo0P0000000`3o
ool0000000000002000000040?ooo`0000000000000000P0oooo4P0000080?ooo`<000000P3oool3
000000030?ooo`000000000000<0oooo0P000000103oool000000000000000020?ooo`/0dLfY0`3o
ool2000000@0oooo0`0000030?ooo`80000000<0oooo0000000000000P0000030?ooo`@000000`3o
ool2000000T0oooo0P0000030?ooo`@000000`3oool4000000030?ooo`000000000000<0oooo0`00
00040?ooo`8000000`3oool<0=7=Z@P0oooo00@000000?ooo`3oool0oooo1@0000030?ooo`@00000
0P3oool00`000000oooo0?ooo`03000000040?ooo`0000000000000000<0oooo0P0000030?ooo`<0
00001`3oool2000000030?ooo`000000000000H0000000@0oooo000000000000oooo1@0000020?oo
o`030000003AcJT0dLfY00`0dLfY000<0=7=Z@/000002@3oool00`000000oooo0?ooo`02000000<0
oooo1P0000040?ooo`030000003oool0oooo0080oooo1P0000030?ooo`8000000P3oool00`000000
oooo0?ooo`070?ooo`/00000303AcJT20?ooo`030000003oool0oooo00<000000P3oool4000000L0
oooo00<000000?ooo`3oool00P000000103oool000000000000000020?ooo`8000002@3oool20000
0080oooo0`0000000`3oool00000000000020?ooo`030000003oool0oooo00D0oooo100000020?oo
o`<000000P3oool00`000000oooo0?ooo`0;0=7=Z@<000000`3oool200000080oooo00<000000?oo
o`3oool0303oool2000000<0oooo0`0000040?ooo`@00000103oool3000000<0oooo0P00000>0?oo
o`030000003oool0oooo008000000`3oool3000000/0dLfY1@3oool010000000oooo0?ooo`3oool3
000000D0oooo1@0000030?ooo`<0000000@0oooo00000000000000003@3oool3000000040?ooo`00
00000000000000<0oooo1@0000050?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo``0dLfY
0P0000000`3oool0000000000003000000<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`3oool5000000030?ooo`000000000000<0oooo1P0000040?ooo`80000000@0oooo0000
00000000oooo0P0000030?ooo`040000003oool0oooo0?ooo`8000002@3oool00`000000oooo0?oo
o`06000000h0dLfY000<0=7=Z@80oooo1@0000000`3oool000000000000600000080oooo0P000000
0`3oool000000000000300000080oooo0P0000000`3oool000000000000=00000080oooo00<00000
0?ooo`3oool01@0000000`3oool00000000000020?ooo`P0000000<0oooo0000000000000`000002
0?ooo``0dLfY0P0000000`3oool0000000000005000000030?ooo`000000000000P000000`3oool2
000000040?ooo`00000000000?ooo`D000000P3oool300000080oooo1@000000103oool000000000
003oool2000000<0oooo2P0000000`3oool0000000000005000000030?ooo`000000000000/0dLfY
0`0000050?ooo`8000000`3oool5000000<0oooo00@000000?ooo`3oool000000P3oool200000003
0?ooo`000000000000D0oooo100000050?ooo`80000000<0oooo0000000000000P3oool010000000
oooo0?ooo`0000040?ooo`@000000`3oool2000000D0oooo0`00000;0=7=Z@D0oooo00@000000?oo
o`3oool0oooo0`0000050?ooo`D000000`3oool3000000040?ooo`0000000000000000d0oooo0`00
0000103oool000000000000000030?ooo`D000001@3oool3000000<0oooo00<000000?ooo`3oool0
0`3oool<0=7=Z@80000000<0oooo0000000000000`0000030?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool0oooo1@0000000`3oool00000000000030?ooo`H00000103oool20000
00040?ooo`00000000000?ooo`8000000`3oool010000000oooo0?ooo`3oool2000000T0oooo00<0
00000?ooo`3oool01P00000>0=7=Z@00303AcJT20?ooo`D0000000<0oooo0000000000001P000002
0?ooo`80000000<0oooo0000000000000`0000020?ooo`80000000<0oooo0000000000003@000002
0?ooo`030000003oool0oooo00D0000000<0oooo0000000000000P3oool8000000030?ooo`000000
000000<000000P3oool<0=7=Z@80000000<0oooo0000000000001@0000000`3oool0000000000008
000000<0oooo0P000000103oool000000000003oool500000080oooo0`0000020?ooo`D0000000@0
oooo000000000000oooo0P0000030?ooo`X0000000<0oooo0000000000001@0000000`3oool00000
0000000;0=7=Z@<000001@3oool2000000<0oooo1@0000030?ooo`040000003oool0oooo00000080
oooo0P0000000`3oool00000000000050?ooo`@000001@3oool2000000030?ooo`00000000000080
oooo00@000000?ooo`3oool00000103oool4000000<0oooo0P0000050?ooo`<000002`3AcJT20000
00<0oooo100000030?ooo`80000000<0oooo0000000000001@000000103oool000000000003oool2
000000030?ooo`000000000000l0oooo0P000000103oool000000000003oool2000000030?ooo`00
0000000000D0000000<0oooo0000000000000`3oool4000000<0oooo0P00000<0=7=Z@80000000<0
oooo000000000000100000030?ooo`<000002@3oool2000000030?ooo`000000000000@0oooo0P00
00030?ooo`@000000P3oool00`000000oooo0?ooo`04000000<0oooo0P0000000`3oool000000000
00030?ooo`L000000P3oool5000000030?ooo`3AcJT0dLfY00`0dLfY000<0=7=Z@<000000P3oool3
00000080oooo00<000000?ooo`3oool01@3oool2000000030?ooo`00000000000080oooo2@000004
0?ooo`030000003oool0oooo0080oooo2@0000020?ooo`80000000<0oooo0000000000001`3oool0
0`000000oooo0?ooo`0300000080oooo0`00000<0=7=Z@80oooo2@0000020?ooo`H000000P3oool3
00000080oooo00@000000?ooo`3oool000000P3oool5000000<0oooo1@0000020?ooo`040000003o
ool0oooo00000080oooo0`0000020?ooo`H000000P3oool900000080oooo2`3AcJT3000000<0oooo
0P0000020?ooo`<0000000<0oooo0000000000000P3oool3000000<0oooo0`0000020?ooo`040000
003oool0oooo0?ooo`8000000`3oool2000000<0oooo0P0000030?ooo`030000003oool0oooo00<0
00000`3oool4000000040?ooo`00000000000?ooo`<000000P3oool2000000<0oooo0`00000;0=7=
Z@80oooo0`000000103oool000000000000000050?ooo`T000000P3oool010000000oooo0?ooo`00
000C0?ooo`040000003oool0oooo00000080oooo2@0000050?ooo`<0000000@0oooo000000000000
00000P3oool<0=7=Z@P000001P3oool010000000oooo0?ooo`3oool3000000<0oooo0`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000000
00040?ooo`D0000000<0oooo0000000000000`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<000001@3oool00`000000dLfY0=7=Z@0<0=7=Z@00303AcJT30?ooo``0000000<0oooo
0000000000000P0000030?ooo`8000000`3oool2000000@0oooo0P0000020?ooo`030000003oool0
oooo008000001@3oool010000000oooo0?ooo`3oool2000000<0oooo100000000`3oool000000000
000:000000<0oooo303AcJT20?ooo`T000000P3oool600000080oooo0`0000020?ooo`040000003o
ool0oooo00000080oooo1@0000030?ooo`D000000P3oool010000000oooo0?ooo`0000020?ooo`<0
00000P3oool600000080oooo2@0000020?ooo`/0dLfY0`0000030?ooo`8000000P3oool300000003
0?ooo`00000000000080oooo0`0000030?ooo`<000000P3oool010000000oooo0?ooo`3oool20000
00<0oooo0P0000030?ooo`8000000`3oool00`000000oooo0?ooo`03000000<0oooo10000000103o
ool000000000003oool300000080oooo0P0000030?ooo`<000002`3AcJT20?ooo`<0000000@0oooo
00000000000000001@3oool900000080oooo00@000000?ooo`3oool000004`3oool010000000oooo
0?ooo`0000020?ooo`T000001@3oool3000000040?ooo`000000000000000080oooo303AcJT80000
00H0oooo00@000000?ooo`3oool0oooo0`0000030?ooo`<000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo0?ooo`80000000<0oooo000000000000103oool5000000030?oo
o`000000000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03000000D0oooo
00<000000=7=Z@3AcJT0303AcJT000`0dLfY0`3oool<000000030?ooo`0000000000008000000`3o
ool2000000<0oooo0P0000040?ooo`8000000P3oool00`000000oooo0?ooo`02000000D0oooo00@0
00000?ooo`3oool0oooo0P0000030?ooo`@0000000<0oooo0000000000002P0000030?ooo``0dLfY
0P3oool9000000<0oooo0P0000060?ooo`8000001P3oool2000000d0oooo0P0000060?ooo`800000
1P3oool2000000<0oooo2@0000020?ooo`/0dLfY0P3oool4000000X0oooo0P0000000`3oool00000
000000030?ooo`030000003oool0oooo008000001P3oool2000000040?ooo`00000000000?ooo`80
00001P3oool200000080oooo00@000000?ooo`3oool0oooo0P0000020?ooo`030000003oool0oooo
00P0oooo100000020?ooo`/0dLfY0P3oool400000080oooo0`000000103oool00000000000000002
0?ooo`<00000203oool400000080oooo0`0000030?ooo`<000000P3oool4000000P0oooo0`000002
0?ooo`<0000000@0oooo00000000000000000P3oool400000080oooo303AcJT30?ooo`8000000`3o
ool6000000040?ooo`0000000000000000T0oooo0P00000:0?ooo`<000000P3oool700000080oooo
100000020?ooo`H0000000<0oooo0000000000000`0000050?ooo`030000003AcJT0dLfY00`0dLfY
000<0=7=Z@L0000000<0oooo0000000000000`0000020?ooo`<000001@3oool5000000<0oooo0P00
00000`3oool0000000000007000000030?ooo`000000000000<0oooo1@0000050?ooo`<000000P3o
ool5000000030?ooo`000000000000D00000303AcJT2000000030?ooo`000000000000D0000000@0
oooo00000000000000002P3oool2000000<0oooo00<000000?ooo`3oool03`3oool010000000oooo
0?ooo`3oool2000000X0oooo0`0000000`3oool0000000000005000000030?ooo`000000000000/0
dLfY0P000000103oool000000000000000050?ooo`<000000P3oool600000080oooo00<000000?oo
o`3oool00`0000020?ooo`<000000P3oool400000080oooo0`0000020?ooo`<000000P3oool00`00
0000oooo0?ooo`0600000080oooo0`0000050?ooo`<0000000<0oooo0000000000002`3AcJT20000
00030?ooo`000000000000<000000`3oool6000000<0oooo0P0000060?ooo`<0000000<0oooo0000
000000000`0000030?ooo`D0000000@0oooo00000000000000001P3oool2000000<0oooo1P000003
0?ooo`D0000000<0oooo000000000000303AcJT2000000<0oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo0?ooo`060?ooo`<0000000<0oooo0000000000000`3oool3000000<0oooo00<0
00000?ooo`3oool00`0000030?ooo`<0000000<0oooo0000000000002P0000020?ooo`030000003o
ool0oooo00<0oooo0`0000020?ooo`030000003AcJT0dLfY00`0dLfY000<0=7=Z@L0000000<0oooo
0000000000000`0000020?ooo`<000001@3oool5000000<0oooo0P0000000`3oool0000000000007
000000030?ooo`000000000000<0oooo1@0000050?ooo`<000000P3oool5000000030?ooo`000000
000000D00000303AcJT2000000030?ooo`000000000000D0000000@0oooo00000000000000002P3o
ool2000000<0oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`3oool2000000X0oooo
0`0000000`3oool0000000000005000000030?ooo`000000000000/0dLfY0P000000103oool00000
0000000000050?ooo`<000000P3oool600000080oooo00<000000?ooo`3oool00`0000020?ooo`<0
00000P3oool400000080oooo0`0000020?ooo`<000000P3oool00`000000oooo0?ooo`0600000080
oooo0`0000050?ooo`<0000000<0oooo0000000000002`3AcJT2000000030?ooo`000000000000<0
00000`3oool6000000<0oooo0P0000060?ooo`<0000000<0oooo0000000000000`0000030?ooo`D0
000000@0oooo00000000000000001P3oool2000000<0oooo1P0000030?ooo`D0000000<0oooo0000
00000000303AcJT2000000<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`06
0?ooo`<0000000<0oooo0000000000000`3oool3000000<0oooo00<000000?ooo`3oool00`000003
0?ooo`<0000000<0oooo0000000000002P0000020?ooo`030000003oool0oooo00<0oooo0`000002
0?ooo`030000003AcJT0dLfY00`0dLfY000<0=7=Z@D000000P3oool400000080oooo200000070?oo
o`80000000<0oooo0000000000001@3oool00`000000oooo0?ooo`030?ooo`8000000P3oool00`00
0000oooo0?ooo`050?ooo`P000000P3oool400000080oooo1@00000<0=7=Z@80oooo00<000000?oo
o`3oool00`0000020?ooo`040000003oool0oooo0?ooo`8000000`3oool2000000030?ooo`000000
00000080oooo00<000000?ooo`3oool04`0000020?ooo`030000003oool0oooo0080000000<0oooo
0000000000000`3oool2000000<0oooo00<000000?ooo`3oool00`0000020?ooo`030000003oool0
oooo00/0dLfY0P3oool00`000000oooo0?ooo`08000000030?ooo`000000000000H000000P3oool0
0`000000oooo0?ooo`030?ooo`80000000<0oooo0000000000000P3oool400000080oooo0P000000
0`3oool00000000000050?ooo`030000003oool0oooo00P0000000<0oooo0000000000001P000002
0?ooo`030000003oool0oooo00/0dLfY0P3oool00`000000oooo0?ooo`03000000@0oooo0P000000
103oool000000000003oool4000000<0oooo00<000000?ooo`3oool00`0000000`3oool000000000
0003000000<0oooo1@000000103oool000000000000000020?ooo`040000003oool0oooo0?ooo`@0
000000@0oooo000000000000oooo0P0000040?ooo`<000000P3oool00`000000oooo0?ooo`0<0=7=
Z@800000103oool2000000H0oooo00<000000?ooo`3oool00`000000103oool000000000003oool2
000000@0oooo1@00000@0?ooo`8000000`3oool400000080oooo0`0000030?ooo`040000003oool0
oooo0?ooo`8000000`3oool>0=7=Z@00303AcJT500000080oooo00@000000?ooo`3oool000000P3o
ool300000080oooo0P0000000`3oool0000000000002000000<0oooo0P0000030?ooo`030000003o
ool0oooo00D000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`@00000
00<0oooo0000000000000P3oool300000080oooo00@000000?ooo`3oool000000P3oool5000000`0
dLfY0P0000000`3oool00000000000030?ooo`80000000@0oooo00000000000000001`3oool00`00
0000oooo0?ooo`02000000030?ooo`000000000001D0000000<0oooo0000000000000P3oool00`00
0000oooo0?ooo`050?ooo`<0000000<0oooo0000000000000`3oool2000000030?ooo`0000000000
00/0dLfY0P000000103oool000000000003oool5000000<0oooo1@0000060?ooo`8000002`3oool2
000000/0oooo0P0000060?ooo`D000000`3oool5000000040?ooo`00000000000?ooo`8000002`3A
cJT2000000030?ooo`000000000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`05000000@0oooo1P0000020?ooo`<000000`3oool300000080oooo1P0000040?ooo`D000000P3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`80000000<0oooo000000000000
303AcJT2000000<0oooo1P0000040?ooo`8000001`3oool8000000030?ooo`000000000000H00000
1`3oool3000000<0oooo0P0000000`3oool000000000000=00000080oooo0P0000000`3oool0dLfY
0=7=Z@0<0=7=Z@00303AcJT500000080oooo00@000000?ooo`3oool000000P3oool300000080oooo
0P0000000`3oool0000000000002000000<0oooo0P0000030?ooo`030000003oool0oooo00D00000
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`@0000000<0oooo00000000
00000P3oool300000080oooo00@000000?ooo`3oool000000P3oool5000000`0dLfY0P0000000`3o
ool00000000000030?ooo`80000000@0oooo00000000000000001`3oool00`000000oooo0?ooo`02
000000030?ooo`000000000001D0000000<0oooo0000000000000P3oool00`000000oooo0?ooo`05
0?ooo`<0000000<0oooo0000000000000`3oool2000000030?ooo`000000000000/0dLfY0P000000
103oool000000000003oool5000000<0oooo1@0000060?ooo`8000002`3oool2000000/0oooo0P00
00060?ooo`D000000`3oool5000000040?ooo`00000000000?ooo`8000002`3AcJT2000000030?oo
o`000000000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`05000000@0oooo
1P0000020?ooo`<000000`3oool300000080oooo1P0000040?ooo`D000000P3oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo0?ooo`80000000<0oooo000000000000303AcJT2000000<0
oooo1P0000040?ooo`8000001`3oool8000000030?ooo`000000000000H000001`3oool3000000<0
oooo0P0000000`3oool000000000000=00000080oooo0P0000000`3oool0dLfY0=7=Z@0<0=7=Z@00
o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00
o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00
o`3AcJW;0=7=Z@00303AcJT20?ooo`8000003P3oool200000080oooo0P0000020?ooo`80000000<0
oooo0000000000000P3oool2000000D0oooo2P0000000`3oool0000000000002000000H0oooo0`00
000=0?ooo``0dLfY1@3oool6000000D0oooo0P0000020?ooo`<000000P3oool4000000<0oooo0P00
00040?ooo`030000003oool0oooo008000000P3oool500000080oooo1@0000060?ooo`030000003o
ool0oooo008000002@3oool;0=7=Z@8000000`3oool4000000D0oooo1P0000070?ooo`030000003o
ool0oooo008000000`3oool200000080oooo0P0000070?ooo`D000006@3oool;0=7=Z@D000001`3o
ool3000000@0oooo0P0000050?ooo`<000001@3oool200000080oooo00<000000?ooo`3oool00P00
00050?ooo`<000001@3oool2000000@0oooo0`0000070?ooo`D00000303AcJT2000000X0oooo00<0
00000?ooo`3oool00P3oool300000080oooo00<000000?ooo`3oool00`0000020?oooa4000000P3o
ool300000080oooo00<000000?ooo`3oool00`0000040?ooo`030000003oool0oooo00P0oooo0P00
000>0=7=Z@00303AcJT20?ooo`8000003P3oool200000080oooo0P0000020?ooo`80000000<0oooo
0000000000000P3oool2000000D0oooo2P0000000`3oool0000000000002000000H0oooo0`00000=
0?ooo``0dLfY1@3oool6000000D0oooo0P0000020?ooo`<000000P3oool4000000<0oooo0P000004
0?ooo`030000003oool0oooo008000000P3oool500000080oooo1@0000060?ooo`030000003oool0
oooo008000002@3oool;0=7=Z@8000000`3oool4000000D0oooo1P0000070?ooo`030000003oool0
oooo008000000`3oool200000080oooo0P0000070?ooo`D000006@3oool;0=7=Z@D000001`3oool3
000000@0oooo0P0000050?ooo`<000001@3oool200000080oooo00<000000?ooo`3oool00P000005
0?ooo`<000001@3oool2000000@0oooo0`0000070?ooo`D00000303AcJT2000000X0oooo00<00000
0?ooo`3oool00P3oool300000080oooo00<000000?ooo`3oool00`0000020?oooa4000000P3oool3
00000080oooo00<000000?ooo`3oool00`0000040?ooo`030000003oool0oooo00P0oooo0P00000>
0=7=Z@00303AcJT20?ooo`D000001P3oool9000000H0oooo1@0000020?ooo`@0000000<0oooo0000
00000000100000070?ooo`8000000P3oool9000000L0oooo1000000<0=7=Z@8000000P3oool90000
00030?ooo`000000000000@0oooo0P0000030?ooo`8000000`3oool400000080oooo0`0000020?oo
o`L00000103oool700000080oooo0P00000<0?ooo`8000002`3AcJT50?ooo`@000000P3oool00`00
0000oooo0?ooo`02000000D0oooo100000020?ooo`030000003oool0oooo008000000P3oool00`00
0000oooo0?ooo`0900000080oooo0`0000040?ooo`@0000000<0oooo0000000000000P3oool20000
00030?ooo`000000000000D0oooo0P0000020?ooo`/0dLfY1@0000050?ooo`L000000P3oool20000
00030?ooo`00000000000080oooo0`0000040?ooo`030000003oool0oooo00D000000P3oool20000
00<0oooo0`0000020?ooo`80000000<0oooo0000000000000P3oool7000000D0oooo1@00000<0=7=
Z@80oooo00<000000?ooo`3oool01@3oool2000000D0oooo1@0000000`3oool00000000000030?oo
oaD000000`3oool2000000030?ooo`000000000000<000001@3oool2000000L0oooo00<000000?oo
o`3oool03P3AcJT000`0dLfY0P3oool5000000H0oooo2@0000060?ooo`D000000P3oool400000003
0?ooo`000000000000@000001`3oool200000080oooo2@0000070?ooo`@00000303AcJT200000080
oooo2@0000000`3oool00000000000040?ooo`8000000`3oool2000000<0oooo100000020?ooo`<0
00000P3oool7000000@0oooo1`0000020?ooo`800000303oool2000000/0dLfY1@3oool400000080
oooo00<000000?ooo`3oool00P0000050?ooo`@000000P3oool00`000000oooo0?ooo`0200000080
oooo00<000000?ooo`3oool02@0000020?ooo`<00000103oool4000000030?ooo`00000000000080
oooo0P0000000`3oool00000000000050?ooo`8000000P3oool;0=7=Z@D000000P3oool7000000<0
oooo0P0000020?ooo`<000000P3oool500000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`80000000<0oooo0000000000000`0000020?ooo`<000000P3oool2000000<0
oooo1`0000020?ooo`D00000303AcJT30?ooo`L000001@3oool2000000D0oooo1@0000000`3oool0
00000000000A0?ooo`80000000<0oooo0000000000000`0000050?ooo`8000001@3oool7000000<0
oooo3P3AcJT000`0dLfY103oool700000080oooo0P0000020?ooo`<000000P3oool4000000L0oooo
0P0000020?ooo`8000001`3oool4000000030?ooo`000000000000H0oooo0P0000000`3oool00000
0000000;00000080oooo303AcJT50?ooo`H000001`3oool200000080oooo1`0000030?ooo`@00000
0P3oool300000080oooo0P0000030?ooo`800000103oool3000000d0oooo1@0000020?ooo`/0dLfY
2@3oool2000000<0oooo2@0000020?ooo`80000000<0oooo000000000000100000030?ooo`@00000
1@3oool4000000030?ooo`000000000000@0oooo0P0000000`3oool0000000000002000000<0oooo
0P0000040?ooo`<000000P3oool;0=7=Z@D000000P3oool7000000<0oooo0P0000020?ooo`<00000
0P3oool500000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000
00<0oooo0000000000000`0000020?ooo`<000000P3oool2000000<0oooo1`0000020?ooo`D00000
303AcJT30?ooo`L000001@3oool2000000D0oooo1@0000000`3oool000000000000A0?ooo`800000
00<0oooo0000000000000`0000050?ooo`8000001@3oool7000000<0oooo3P3AcJT000`0dLfY103o
ool700000080oooo0P0000020?ooo`<000000P3oool4000000L0oooo0P0000020?ooo`8000001`3o
ool4000000030?ooo`000000000000H0oooo0P0000000`3oool000000000000;00000080oooo303A
cJT40?ooo`030000003oool0oooo008000000P3oool2000000030?ooo`000000000000@000000P3o
ool00`000000oooo0?ooo`0200000080oooo0`0000020?ooo`@0000000<0oooo0000000000001P3o
ool300000080oooo0P0000020?ooo`X000001P3oool5000000/0dLfY0P3oool2000000<0oooo0P00
00020?ooo`X000001P3oool00`000000oooo0?ooo`020?ooo`<000000P3oool2000000@0oooo2000
00040?ooo`8000001@3oool;000000D0oooo2`3AcJT50?ooo`8000000P3oool5000000030?ooo`00
00000000008000001@3oool2000000030?ooo`00000000000080oooo0P0000030?ooo`D00000103o
ool00`000000oooo0?ooo`02000000030?ooo`000000000000D0oooo100000000`3oool000000000
000300000080oooo0P0000050?ooo``0dLfY0`3oool7000000<0oooo0P0000050?ooo`80000000<0
oooo0000000000000`00000E0?ooo`D0000000<0oooo0000000000001@3oool2000000<0oooo1`00
00030?ooo`h0dLfY000<0=7=Z@@0oooo1`0000020?ooo`8000000P3oool900000080oooo0`000002
0?ooo`H0000000<0oooo0000000000000P3oool900000080oooo0P0000020?ooo`8000002@3oool5
00000080oooo303AcJT40?ooo`030000003oool0oooo008000000P3oool2000000030?ooo`000000
000000@000000P3oool00`000000oooo0?ooo`0200000080oooo0`0000020?ooo`@0000000<0oooo
0000000000001P3oool300000080oooo0P0000020?ooo`X000001P3oool5000000/0dLfY0P3oool2
000000<0oooo0P0000020?ooo`X000001P3oool00`000000oooo0?ooo`020?ooo`<000000P3oool2
000000@0oooo200000040?ooo`8000001@3oool;000000D0oooo2`3AcJT50?ooo`8000000P3oool5
000000030?ooo`0000000000008000001@3oool2000000030?ooo`00000000000080oooo0P000003
0?ooo`D00000103oool00`000000oooo0?ooo`02000000030?ooo`000000000000D0oooo10000000
0`3oool000000000000300000080oooo0P0000050?ooo``0dLfY0`3oool7000000<0oooo0P000005
0?ooo`80000000<0oooo0000000000000`00000E0?ooo`D0000000<0oooo0000000000001@3oool2
000000<0oooo1`0000030?ooo`h0dLfY000<0=7=Z@@0oooo0P0000000`3oool00000000000020?oo
o`@000000`3oool200000080oooo0P0000020?ooo`8000001@3oool2000000@0oooo300000060?oo
o`@0000000<0oooo0000000000002@0000040?ooo``0dLfY1@0000020?ooo`8000000P3oool20000
00<0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000040?ooo`8000000P3oool00`00
0000oooo0?ooo`020?ooo`/000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P00000;0=7=Z@@0000000<0oooo000000000000100000030?oo
o`8000000P3oool2000000<0oooo0P0000020?ooo`<000000P3oool3000000@0oooo0P0000020?oo
o`D000001@3oool4000000D0oooo1@0000070?ooo`@000002`3AcJT30?ooo`8000000P3oool30000
0080oooo0P0000030?ooo`8000000P3oool8000000@0oooo300000030?ooo`P000000P3oool20000
00<0oooo0P0000020?ooo`<000000P3oool2000000<0oooo303AcJT30?ooo`L000000P3oool00`00
0000oooo0?ooo`02000000P0oooo0P0000060?ooo`@000000`3oool4000000H0oooo0P0000080?oo
o`8000000P3oool00`000000oooo0?ooo`07000000<0oooo3P3AcJT000`0dLfY103oool200000003
0?ooo`00000000000080oooo100000030?ooo`8000000P3oool200000080oooo0P0000050?ooo`80
0000103oool<000000H0oooo100000000`3oool0000000000009000000@0oooo303AcJT500000080
oooo0P0000020?ooo`8000000`3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000@0
oooo0P0000020?ooo`030000003oool0oooo0080oooo2`0000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02000000/0dLfY100000000`3oool0
000000000004000000<0oooo0P0000020?ooo`8000000`3oool200000080oooo0`0000020?ooo`<0
0000103oool200000080oooo1@0000050?ooo`@000001@3oool5000000L0oooo1000000;0=7=Z@<0
oooo0P0000020?ooo`<000000P3oool2000000<0oooo0P0000020?ooo`P00000103oool<000000<0
oooo200000020?ooo`8000000`3oool200000080oooo0`0000020?ooo`8000000`3oool<0=7=Z@<0
oooo2@0000000`3oool00000000000080?ooo`800000203oool4000000<0oooo100000080?ooo`80
0000203oool2000000030?ooo`000000000000L000000`3oool>0=7=Z@00303AcJT40?ooo`800000
00<0oooo0000000000001P3oool2000000030?ooo`000000000000/0oooo0P0000090?ooo`800000
0P3oool7000000@0oooo0P0000020?ooo`030000003oool0oooo00H0oooo0`0000040?ooo``0dLfY
0P0000020?ooo`030000003oool0oooo00H0oooo1@0000040?ooo`D000000`3oool400000080oooo
1`0000040?ooo`030000003oool0oooo00@0oooo0P0000050?ooo`8000001@3oool500000080oooo
0P00000;0=7=Z@@0000000<0oooo0000000000000P0000020?ooo`<000000P3oool2000000<0oooo
2`0000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0100000000`3oool00000
000000090?ooo`L00000103oool300000080oooo2`3AcJT30?ooo`L000001`3oool2000000D0oooo
0P0000080?ooo`T00000203oool2000000D0oooo0P0000070?ooo`L000000`3oool<0=7=Z@<0oooo
2@0000000`3oool00000000000080?ooo`800000203oool4000000<0oooo100000080?ooo`800000
203oool2000000030?ooo`000000000000L000000`3oool>0=7=Z@00303AcJT40?ooo`80000000<0
oooo0000000000001P3oool2000000030?ooo`000000000000/0oooo0P0000090?ooo`8000000P3o
ool7000000@0oooo0P0000020?ooo`030000003oool0oooo00H0oooo0`0000040?ooo``0dLfY0P00
00020?ooo`030000003oool0oooo00H0oooo1@0000040?ooo`D000000`3oool400000080oooo1`00
00040?ooo`030000003oool0oooo00@0oooo0P0000050?ooo`8000001@3oool500000080oooo0P00
000;0=7=Z@@0000000<0oooo0000000000000P0000020?ooo`<000000P3oool2000000<0oooo2`00
00020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0100000000`3oool000000000
00090?ooo`L00000103oool300000080oooo2`3AcJT20?ooo`D000000`3oool200000080oooo0`00
00020?ooo`8000000`3oool3000000H0oooo00<000000?ooo`3oool01@0000020?ooo`8000001@3o
ool3000000<0oooo0P0000020?ooo`<000000P3oool2000000<0oooo1@0000020?ooo``0dLfY0P3o
ool00`000000oooo0?ooo`030?ooo`L000000P3oool300000080oooo0`0000030?ooo`8000000P3o
ool00`000000oooo0?ooo`02000000<0oooo0P0000020?ooo`030000003oool0oooo008000000`3o
ool300000080oooo0`0000020?ooo`L000001@3oool00`000000oooo0?ooo`0>0=7=Z@00303AcJT2
0?ooo`@0000000<0oooo0000000000000P3oool6000000030?ooo`0000000000008000001P3oool;
00000100oooo0P0000020?ooo`L000000P3oool2000000L0oooo303AcJT50?ooo`800000103oool2
000000<0oooo0P0000070?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool9
000000<0oooo0P0000040?ooo`<00000103oool5000000@0oooo0`0000020?ooo`/0dLfY0P000007
0?ooo`<000000P3oool200000080oooo0P0000000`3oool00000000000040?ooo`030000003oool0
oooo0080oooo0P0000030?ooo`8000001`3oool200000080oooo2@0000000`3oool0000000000004
0?ooo`030000003oool0oooo00@000001@3oool;0=7=Z@80oooo1@0000030?ooo`8000000P3oool3
00000080oooo0P0000030?ooo`<000001P3oool00`000000oooo0?ooo`0500000080oooo0P000005
0?ooo`<000000`3oool200000080oooo0`0000020?ooo`8000000`3oool500000080oooo303AcJT2
0?ooo`030000003oool0oooo00<0oooo1`0000020?ooo`<000000P3oool3000000<0oooo0P000002
0?ooo`030000003oool0oooo008000000`3oool200000080oooo00<000000?ooo`3oool00P000003
0?ooo`<000000P3oool300000080oooo1`0000050?ooo`030000003oool0oooo00h0dLfY000<0=7=
Z@80oooo100000000`3oool00000000000020?ooo`H0000000<0oooo0000000000000P0000060?oo
o`/00000403oool200000080oooo1`0000020?ooo`8000001`3oool<0=7=Z@D0oooo0P0000040?oo
o`8000000`3oool2000000L0oooo0P0000020?ooo`030000003oool0oooo0080oooo0P0000020?oo
o`T000000`3oool2000000@0oooo0`0000040?ooo`D00000103oool300000080oooo2`3AcJT40000
00D0oooo0P0000000`3oool00000000000020?ooo`8000000P3oool300000080oooo0`0000060?oo
o`030000003oool0oooo008000001`3oool200000080oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`04000000030?ooo`000000000000@0oooo0`0000020?ooo`/0dLfY2@0000030?oo
o`8000001@3oool2000000030?ooo`000000000000D00000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo0P0000030?ooo`L0000000<0oooo0000000000001@3oool20000
00<0oooo2@00000<0=7=Z@8000001@3oool00`000000oooo0?ooo`0300000080oooo1`0000030?oo
o`<000000P3oool2000000030?ooo`000000000000L0oooo0P0000000`3oool00000000000020?oo
o`<000000`3oool700000080oooo0`0000020?ooo`030000003oool0oooo00<0oooo0P00000>0=7=
Z@00303AcJT6000000030?ooo`00000000000080oooo0P0000050?ooo`800000203oool300000080
oooo0P0000040?ooo`<000000P3oool200000080oooo0`0000040?ooo`@000000P3oool00`000000
oooo0?ooo`0200000080oooo1`0000020?ooo``0dLfY100000000`3oool00000000000020?ooo`80
00000P3oool00`000000oooo0?ooo`040?ooo`<00000103oool300000080oooo0P0000020?ooo`80
00001@3oool5000000P0oooo0`00000;0?ooo`D000000P3oool;0=7=Z@@000001@3oool200000003
0?ooo`00000000000080oooo0P0000020?ooo`<000000P3oool3000000H0oooo00<000000?ooo`3o
ool00P0000070?ooo`8000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
000000<0oooo000000000000103oool300000080oooo2`3AcJT9000000<0oooo0P0000050?ooo`80
000000<0oooo0000000000001@0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool2000000<0oooo1`0000000`3oool00000000000050?ooo`8000000`3oool9000000`0
dLfY1@3oool2000000030?ooo`00000000000080000000<0oooo0000000000000P0000030?ooo`D0
00001@3oool2000000030?ooo`0000000000008000000`3oool4000000030?ooo`000000000000D0
oooo1@0000030?ooo`@0000000<0oooo0000000000000P0000000`3oool00000000000050?ooo`h0
dLfY000<0=7=Z@H0000000<0oooo0000000000000P3oool2000000D0oooo0P0000080?ooo`<00000
0P3oool2000000@0oooo0`0000020?ooo`8000000P3oool3000000@0oooo100000020?ooo`030000
003oool0oooo008000000P3oool700000080oooo303AcJT20?ooo`80000000<0oooo000000000000
0P3oool2000000L0oooo3P0000070?ooo`8000001P3oool00`000000oooo0?ooo`0400000080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`L000002`3AcJT20?ooo`D00000
0P3oool2000000030?ooo`0000000000008000000P3oool2000000<0oooo0P0000020?ooo`D00000
0P3oool00`000000oooo0?ooo`0;000000T0oooo0`0000060?ooo`D000000P3oool00`000000oooo
0?ooo`02000000/0dLfY0`0000070?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`<00000
103oool:00000080oooo00<000000?ooo`3oool02P0000040?ooo`<00000103oool00`000000oooo
0?ooo`02000000L0oooo0`00000<0=7=Z@D0oooo0P0000000`3oool0000000000002000000030?oo
o`0000000000008000000`3oool5000000D0oooo0P0000000`3oool0000000000002000000<0oooo
100000000`3oool00000000000050?ooo`D000000`3oool4000000030?ooo`000000000000800000
00<0oooo0000000000001@3oool>0=7=Z@00303AcJT4000000D0oooo1P0000020?ooo`030000003o
ool0oooo00@0oooo0P0000020?ooo`030000003oool0oooo00@0oooo100000050?ooo`8000000P3o
ool3000000@0oooo0P0000020?ooo`8000000`3oool4000000D0oooo0P0000020?ooo``0dLfY0P3o
ool2000000030?ooo`00000000000080oooo0P0000070?ooo`h000001`3oool2000000H0oooo00<0
00000?ooo`3oool0100000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool7000000/0dLfY0P3oool500000080oooo0P0000000`3oool000000000000200000080oooo0P00
00030?ooo`8000000P3oool500000080oooo00<000000?ooo`3oool02`0000090?ooo`<000001P3o
ool500000080oooo00<000000?ooo`3oool00P00000;0=7=Z@80oooo00<000000?ooo`3oool00P00
00030?ooo`8000000`3oool200000080oooo0P0000000`3oool0000000000007000000<0oooo2@00
00030?ooo`T0000000<0oooo0000000000000P3oool2000000<0oooo0P0000030?ooo`8000000P3o
ool00`000000oooo0?ooo`0<0=7=Z@<0oooo0P0000020?ooo`030000003oool0oooo0080oooo1@00
00030?ooo`<000000P3oool2000000D0oooo1@0000030?ooo`D000001@3oool200000080oooo0`00
00030?ooo`D00000103oool00`000000oooo0?ooo`02000000<0oooo3P3AcJT000`0dLfY10000005
0?ooo`H000000P3oool00`000000oooo0?ooo`040?ooo`8000000P3oool00`000000oooo0?ooo`04
0?ooo`@000001@3oool200000080oooo0`0000040?ooo`8000000P3oool2000000<0oooo10000005
0?ooo`8000000P3oool<0=7=Z@D0oooo2@0000040?ooo`@0000000<0oooo0000000000000P000003
0?ooo`800000103oool300000080oooo0P0000020?ooo`800000403oool3000000@0oooo1@000002
0?ooo`/0dLfY1`3oool200000080oooo00<000000?ooo`3oool0103oool5000000T0oooo0P000009
0?ooo`030000003oool0oooo00D000000P3oool4000000<0oooo0P0000020?ooo`8000001@3oool7
000000/0dLfY0P3oool00`000000oooo0?ooo`02000000<0oooo0P0000030?ooo`8000000P3oool2
000000030?ooo`000000000000L000000`3oool9000000<0oooo2@0000000`3oool0000000000002
0?ooo`8000000`3oool2000000<0oooo0P0000020?ooo`030000003oool0oooo00`0dLfY0`3oool2
00000080oooo00<000000?ooo`3oool00P3oool5000000<0oooo0`0000020?ooo`8000001@3oool5
000000<0oooo1@0000050?ooo`8000000P3oool3000000<0oooo1@0000040?ooo`030000003oool0
oooo008000000`3oool>0=7=Z@00303AcJT20?ooo`L000000P3oool200000080oooo0P0000000`3o
ool000000000000=00000080oooo0P0000020?ooo`030000003oool0oooo00@00000103oool00`00
0000oooo0?ooo`020?ooo`@000000P3oool00`000000oooo0?ooo`060?ooo`D000000P3oool<0=7=
Z@D0oooo2@0000040?ooo`@0000000<0oooo0000000000000P0000030?ooo`800000103oool30000
0080oooo0P0000020?ooo`800000403oool3000000@0oooo1@0000020?ooo`/0dLfY1`3oool20000
0080oooo00<000000?ooo`3oool0103oool5000000T0oooo0P0000090?ooo`030000003oool0oooo
00D000000P3oool4000000<0oooo0P0000020?ooo`8000001@3oool7000000/0dLfY0`3oool70000
00L0oooo100000080?oooa<00000203oool4000000L0oooo1`0000030?ooo``0dLfY0`0000070?oo
o`<00000103oool3000000L0oooo1@0000000`3oool0000000000002000000<0oooo100000000`3o
ool0000000000003000000L0oooo0`0000040?ooo`<000001`3oool3000000h0dLfY000<0=7=Z@80
oooo0P0000030?ooo`@000000P3oool200000080oooo1@0000040?ooo`<000001P3oool400000003
0?ooo`0000000000008000000P3oool200000080oooo00<000000?ooo`3oool00P0000020?ooo`@0
000000<0oooo0000000000003@00000<0=7=Z@L00000103oool2000000030?ooo`000000000000H0
oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo00@000000P3oool300000080
oooo0P0000070?ooo`8000000`3oool200000080oooo0P0000030?ooo`@000000`3oool4000000/0
dLfY100000000`3oool00000000000050?ooo`8000000P3oool200000080oooo00<000000?ooo`3o
ool01`3oool4000000030?ooo`0000000000008000000P3oool7000000<0oooo100000020?ooo`D0
00001@3oool4000000L0oooo2`3AcJT30?ooo`L000001`3oool4000000P0oooo4`0000080?ooo`@0
00001`3oool7000000<0oooo303AcJT3000000L0oooo0`0000040?ooo`<000001`3oool300000080
oooo1@0000030?ooo`D000000P3oool3000000L0oooo0`0000040?ooo`<000001`3oool3000000h0
dLfY000<0=7=Z@80oooo0P0000030?ooo`@000000P3oool200000080oooo1@0000040?ooo`<00000
1P3oool4000000030?ooo`0000000000008000000P3oool200000080oooo00<000000?ooo`3oool0
0P0000020?ooo`@0000000<0oooo0000000000003@00000<0=7=Z@L00000103oool2000000030?oo
o`000000000000H0oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo00@00000
0P3oool300000080oooo0P0000070?ooo`8000000`3oool200000080oooo0P0000030?ooo`@00000
0`3oool4000000/0dLfY1@0000020?ooo`8000000`3oool8000000D0oooo0`0000040?ooo`<00000
1P3oool300000080oooo0P0000030?ooo`8000000P3oool500000080oooo1@0000060?ooo`030000
003oool0oooo0080oooo2`3AcJT3000000L0oooo4`0000020?ooo`D000000P3oool00`000000oooo
0?ooo`0500000080oooo4`0000070?ooo`<00000303AcJT3000000L0oooo0`0000040?ooo`<00000
1`3oool300000080oooo1@0000030?ooo`D000000P3oool3000000L0oooo0`0000040?ooo`<00000
1`3oool3000000h0dLfY000<0=7=Z@H0oooo00<000000?ooo`3oool00P3oool700000080oooo0P00
00020?ooo`@0000000<0oooo0000000000000P3oool4000000D0oooo200000050?ooo`H000000`3o
ool2000000@0oooo0P0000000`3oool00000000000020?ooo``0dLfY1`0000020?ooo`8000000`3o
ool200000080oooo0P0000020?ooo`<000001@3oool2000000@0oooo2@0000020?ooo`030000003o
ool0oooo008000000P3oool2000000030?ooo`000000000000D000000P3oool400000080oooo1@00
000;0=7=Z@D000000P3oool2000000<0oooo200000050?ooo`<00000103oool3000000H0oooo0`00
00020?ooo`8000000`3oool200000080oooo1@0000020?ooo`D000001P3oool00`000000oooo0?oo
o`020?ooo`/0dLfY0`0000070?oooa<000000P3oool500000080oooo00<000000?ooo`3oool01@00
00020?oooa<000001`3oool3000000`0dLfY0P3oool00`000000oooo0?ooo`02000000D0oooo1@00
00030?ooo`<000000P3oool2000000030?ooo`000000000000D0oooo1`0000050?ooo`80000000<0
oooo0000000000000P3oool3000000<0oooo1@0000050?ooo`8000000P3oool00`000000oooo0?oo
o`0>0=7=Z@00303AcJT60?ooo`030000003oool0oooo0080oooo1`0000020?ooo`8000000P3oool4
000000030?ooo`00000000000080oooo100000050?ooo`P000001@3oool6000000<0oooo0P000004
0?ooo`80000000<0oooo0000000000000P3oool<0=7=Z@8000000P3oool00`000000oooo0?ooo`02
0?ooo`8000000`3oool8000000D0oooo0`0000020?ooo`L00000103oool200000080oooo1`000005
0?ooo`@000001@3oool2000000<0oooo1000000;0=7=Z@@0oooo00<000000?ooo`3oool02@000002
0?ooo`D000002@3oool2000000D0oooo2`0000000`3oool0000000000006000000030?ooo`000000
000000@0oooo0`0000020?ooo`80000000<0oooo0000000000000P3oool;0=7=Z@<0oooo0P000002
0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`<000000P3oool300000080oooo4`000002
0?ooo`<000000P3oool3000000@0oooo00<000000?ooo`3oool00`3oool200000080oooo0P000003
0?ooo``0dLfY0P3oool00`000000oooo0?ooo`02000000D0oooo1@0000030?ooo`<000000P3oool2
000000030?ooo`000000000000D0oooo1`0000050?ooo`80000000<0oooo0000000000000P3oool3
000000<0oooo1@0000050?ooo`8000000P3oool00`000000oooo0?ooo`0>0=7=Z@00303AcJT40000
00h0oooo0P0000040?ooo`8000000`3oool800000080oooo00<000000?ooo`3oool01P0000020?oo
o`030000003oool0oooo00H0oooo0P0000070?ooo`D000000P3oool2000000`0dLfY0P0000020?oo
o`030000003oool0oooo0080oooo0P0000030?ooo`P000001@3oool300000080oooo1`0000040?oo
o`8000000P3oool7000000D0oooo100000050?ooo`8000000`3oool4000000/0dLfY103oool00`00
0000oooo0?ooo`0900000080oooo1@0000090?ooo`8000001@3oool;000000030?ooo`0000000000
00H0000000<0oooo000000000000103oool300000080oooo0P0000000`3oool00000000000020?oo
o`/0dLfY0P3oool300000080oooo0P0000030?ooo`80000000<0oooo0000000000000P3oool20000
00030?ooo`000000000000D0oooo100000030?ooo`D00000103oool3000000D0oooo0P0000000`3o
ool00000000000020?ooo`80000000<0oooo0000000000000`3oool200000080oooo0`0000020?oo
o``0dLfY0P0000000`3oool00000000000050?ooo`80000000<0oooo0000000000000P0000030?oo
o`D000000P3oool00`000000oooo0?ooo`030?ooo`8000000P3oool300000080oooo0P0000050?oo
o`030000003oool0oooo00D000000`3oool4000000030?ooo`000000000000D0oooo0P0000000`3o
ool000000000000>0=7=Z@00303AcJT4000000h0oooo0P0000040?ooo`8000000`3oool800000080
oooo00<000000?ooo`3oool01P0000020?ooo`030000003oool0oooo00H0oooo0P0000070?ooo`D0
00000P3oool2000000`0dLfY103oool300000080oooo100000000`3oool000000000000200000080
oooo1@0000050?ooo`@000000P3oool2000000<0oooo0P0000020?ooo`80000000<0oooo00000000
00000P0000020?ooo`80000000<0oooo0000000000000P3oool2000000D0oooo100000000`3oool0
000000000002000000/0dLfY100000000`3oool00000000000020?ooo`8000000`3oool2000000@0
oooo00<000000?ooo`3oool0103oool300000080oooo0`0000020?ooo`L000000P3oool400000003
0?ooo`00000000000080oooo0P0000050?ooo`8000000P3oool00`000000oooo0?ooo`04000000D0
oooo2`3AcJT20?ooo`<000000P3oool2000000<0oooo0P0000000`3oool00000000000020?ooo`80
000000<0oooo0000000000001@3oool4000000<0oooo1@0000040?ooo`<000001@3oool200000003
0?ooo`00000000000080oooo0P0000000`3oool00000000000030?ooo`8000000P3oool300000080
oooo303AcJT20?ooo`D0000000<0oooo0000000000000P0000000`3oool00000000000070?ooo`D0
00000`3oool2000000<0oooo1`0000030?ooo`8000000`3oool5000000L0oooo0P0000000`3oool0
000000000002000000030?ooo`000000000000<000000P3oool>0=7=Z@00303AcJT200000080oooo
0`0000020?ooo`8000004@3oool500000080oooo0P0000030?ooo`P000000P3oool00`000000oooo
0?ooo`0400000080oooo0`0000080?ooo`<00000103oool<0=7=Z@@0oooo0`0000020?ooo`@00000
00<0oooo0000000000000P0000020?ooo`D000001@3oool400000080oooo0P0000030?ooo`800000
0P3oool2000000030?ooo`0000000000008000000P3oool2000000030?ooo`00000000000080oooo
0P0000050?ooo`@0000000<0oooo0000000000000P00000;0=7=Z@@0000000<0oooo000000000000
0P3oool2000000<0oooo0P0000040?ooo`030000003oool0oooo00@0oooo0`0000020?ooo`<00000
0P3oool700000080oooo100000000`3oool00000000000020?ooo`8000001@3oool200000080oooo
00<000000?ooo`3oool0100000050?ooo`/0dLfY1@3oool9000000030?ooo`00000000000080oooo
0`0000020?ooo`8000000`3ooolC000000<0oooo0P0000020?ooo`<000000P3oool2000000030?oo
o`000000000000L000001@3oool<0=7=Z@80oooo1@0000000`3oool0000000000002000000030?oo
o`000000000000L0oooo1@0000030?ooo`8000000`3oool7000000<0oooo0P0000030?ooo`D00000
1`3oool2000000030?ooo`00000000000080000000<0oooo0000000000000`0000020?ooo`h0dLfY
000<0=7=Z@8000000P3oool300000080oooo0P00000A0?ooo`D000000P3oool2000000<0oooo2000
00020?ooo`030000003oool0oooo00@000000P3oool3000000P0oooo0`0000040?ooo``0dLfY0P3o
ool3000000@0oooo100000000`3oool00000000000020?ooo`8000000P3oool00`000000oooo0?oo
o`05000000@0oooo0P0000020?ooo`<000001P3oool300000080oooo1@0000040?ooo`80000000<0
oooo0000000000000P3oool2000000L0oooo2`3AcJT20?ooo`<000000P3oool200000080oooo00<0
00000?ooo`3oool0100000020?ooo`<000000P3oool2000000<0oooo0P0000020?ooo`030000003o
ool0oooo00L0oooo100000090?ooo`<00000103oool5000000@0oooo00<000000?ooo`3oool00P3o
ool;0=7=Z@D0oooo2@0000000`3oool00000000000020?ooo`<000000P3oool2000000<0oooo4`00
00030?ooo`8000000P3oool300000080oooo0P0000000`3oool0000000000007000000D0oooo303A
cJT2000000030?ooo`000000000000<00000103oool00`000000oooo0?ooo`02000000<0oooo0P00
00000`3oool0000000000002000000D0oooo0`0000020?ooo`<000000P3oool3000000D0oooo1000
00000`3oool00000000000030?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`D0000000<0
oooo0000000000003P3AcJT000`0dLfY1P3oool500000080oooo1`0000020?ooo`@000000P3oool0
0`000000oooo0?ooo`020?ooo`/000000P3oool4000000D0oooo1P0000070?ooo`8000001@3oool2
000000`0dLfY0P3oool3000000@0oooo100000000`3oool00000000000020?ooo`8000000P3oool0
0`000000oooo0?ooo`05000000@0oooo0P0000020?ooo`<000001P3oool300000080oooo1@000004
0?ooo`80000000<0oooo0000000000000P3oool2000000L0oooo2`3AcJT20?ooo`80000000<0oooo
0000000000002@3oool200000080oooo00<000000?ooo`3oool01`3oool4000000030?ooo`000000
00000080oooo0P0000050?ooo`D000000P3oool4000000<0oooo0P0000020?ooo`8000001@3oool2
000000<0oooo0P00000;0=7=Z@D000000P3oool2000000030?ooo`000000000000D000000P3oool3
000000@0oooo1@0000030?ooo`8000000P3oool00`000000oooo0?ooo`02000000<0oooo1@000004
0?ooo`<000000P3oool7000000030?ooo`00000000000080oooo1@00000<0=7=Z@80000000<0oooo
0000000000000`0000040?ooo`030000003oool0oooo008000000`3oool2000000030?ooo`000000
0000008000001@3oool300000080oooo0`0000020?ooo`<000001@3oool4000000030?ooo`000000
000000<0oooo0P0000020?ooo`030000003oool0oooo0080oooo1@0000000`3oool000000000000>
0=7=Z@00303AcJT60?ooo`D000000P3oool700000080oooo100000020?ooo`030000003oool0oooo
0080oooo2`0000020?ooo`@000001@3oool6000000L0oooo0P0000050?ooo`800000303AcJT20000
00<0oooo0P0000020?ooo`8000000`3oool400000080oooo1`00000;0?ooo`<000000P3oool50000
0080oooo1P0000000`3oool00000000000020?ooo`<00000203oool5000000/0dLfY0P3oool20000
00030?ooo`000000000000T0oooo0P0000020?ooo`030000003oool0oooo00L0oooo100000000`3o
ool00000000000020?ooo`8000001@3oool500000080oooo100000030?ooo`8000000P3oool20000
00D0oooo0P0000030?ooo`8000002`3AcJT9000000<0oooo1@0000020?ooo`8000001@3oool80000
00@0oooo00<000000?ooo`3oool00P3oool8000000D0oooo0P0000020?ooo`D000000`3oool90000
00`0dLfY0P0000030?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`<000000P3oool00`00
0000oooo0?ooo`020?ooo`<000000P3oool=00000080oooo0`0000040?ooo`030000003oool0oooo
00<00000103oool00`000000oooo0?ooo`030?ooo`8000000`3oool2000000h0dLfY000<0=7=Z@80
00000P3oool700000080oooo100000030?ooo`800000103oool2000000D0oooo0P0000020?ooo`<0
0000103oool2000000@0oooo0`0000040?ooo`T00000103oool2000000030?ooo`00000000000080
oooo303AcJT2000000<0oooo0P0000020?ooo`8000000`3oool400000080oooo1`00000;0?ooo`<0
00000P3oool500000080oooo1P0000000`3oool00000000000020?ooo`<00000203oool5000000/0
dLfY0P3oool300000080oooo100000030?ooo`H000000`3oool4000000030?ooo`00000000000080
00000`3oool9000000H0oooo00<000000?ooo`3oool00P0000020?ooo`<000000P3oool500000080
oooo0P0000050?ooo`8000002`3AcJT9000000<0oooo1@0000020?ooo`8000001@3oool8000000@0
oooo00<000000?ooo`3oool00P3oool8000000D0oooo0P0000020?ooo`D000000`3oool9000000`0
dLfY0P3oool3000000D0oooo0P0000050?ooo`D000001@3oool5000000030?ooo`000000000000T0
000000<0oooo0000000000000`0000050?ooo`D000001@3oool2000000D0oooo0`0000020?ooo`h0
dLfY000<0=7=Z@8000000P3oool7000000L0oooo2P0000000`3oool00000000000060?ooo`800000
00<0oooo0000000000000P0000020?ooo`8000000`3oool600000080oooo0P0000000`3oool00000
00000002000000@0oooo0P0000000`3oool0000000000002000000`0dLfY0P0000020?ooo`T00000
00<0oooo0000000000002@3oool5000000@0oooo0P0000050?ooo`@000001@3oool200000080oooo
0`0000020?ooo`@0000000<0oooo000000000000100000020?ooo`<000000P3oool;0=7=Z@80oooo
0`0000020?ooo`@000000`3oool6000000<0oooo100000000`3oool0000000000002000000<0oooo
2@0000060?ooo`030000003oool0oooo008000000P3oool300000080oooo1@0000020?ooo`800000
1@3oool2000000/0dLfY0`3oool2000000T0oooo1@0000020?ooo`d00000103oool00`000000oooo
0?ooo`020?ooo`d000000P3oool5000000T0oooo0P0000030?ooo``0dLfY0P3oool3000000D0oooo
0P0000050?ooo`D000001@3oool5000000030?ooo`000000000000T0000000<0oooo000000000000
0`0000050?ooo`D000001@3oool2000000D0oooo0`0000020?ooo`h0dLfY000<0=7=Z@8000000P3o
ool7000000L0oooo2P0000000`3oool00000000000060?ooo`80000000<0oooo0000000000000P00
00020?ooo`8000000`3oool600000080oooo0P0000000`3oool0000000000002000000@0oooo0P00
00000`3oool0000000000002000000`0dLfY0P0000070?ooo`8000000`3oool2000000H0oooo0`00
00020?oooaL000000P3oool4000000D0oooo0P0000030?ooo`8000001`3oool2000000/0dLfY103o
ool300000080oooo1@0000060?ooo`<000000P3oool2000000D0oooo0`0000080?ooo`030000003o
ool0oooo00L000001P3oool00`000000oooo0?ooo`020?ooo`<00000103oool2000000030?ooo`00
00000000008000002`3AcJT30?ooo`8000002@3oool500000080oooo3@0000040?ooo`030000003o
ool0oooo0080oooo3@0000020?ooo`D000002@3oool2000000<0oooo303AcJT3000000T0oooo0`00
00020?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`D000000P3oool2000000<0oooo0P00
00020?ooo`D000000`3oool2000000D0oooo00<000000?ooo`3oool00`0000090?ooo`<000003P3A
cJT000`0dLfY100000020?ooo`<00000103oool500000080oooo1P0000020?ooo`030000003oool0
oooo00@0oooo0P0000020?ooo`030000003oool0oooo008000001`3oool4000000@0oooo0P000003
0?ooo`@000001@3oool200000080oooo303AcJT2000000L0oooo0P0000030?ooo`8000001P3oool3
00000080oooo5`0000020?ooo`@000001@3oool2000000<0oooo0P0000070?ooo`8000002`3AcJT4
0?ooo`<000000P3oool5000000H0oooo0`0000020?ooo`8000001@3oool3000000P0oooo00<00000
0?ooo`3oool01`0000060?ooo`030000003oool0oooo0080oooo0`0000040?ooo`80000000<0oooo
0000000000000P00000;0=7=Z@D0oooo0P0000070?ooo`030000003oool0oooo00T0000000<0oooo
000000000000100000000`3oool00000000000020?ooo`030000003oool0oooo008000000P3oool5
000000030?ooo`000000000000L000000P3oool00`000000oooo0?ooo`050?ooo`8000001@3oool<
0=7=Z@<000002@3oool300000080oooo00<000000?ooo`3oool00`3oool2000000<0oooo1@000002
0?ooo`8000000`3oool200000080oooo1@0000030?ooo`8000001@3oool00`000000oooo0?ooo`03
000000T0oooo0`00000>0=7=Z@00303AcJT400000080oooo0`0000040?ooo`D000000P3oool60000
0080oooo00<000000?ooo`3oool0103oool200000080oooo00<000000?ooo`3oool00P0000070?oo
o`@00000103oool2000000<0oooo100000050?ooo`8000000P3oool<0=7=Z@80oooo0`0000040?oo
o`8000002@3oool2000000030?ooo`000000000000@000001`3oool2000000030?ooo`0000000000
008000000P3oool2000000L0oooo0P0000070?ooo`030000003oool0oooo00@000000P3oool00`00
0000oooo0?ooo`02000000/0dLfY100000030?ooo`8000000`3oool8000000<0oooo0P0000030?oo
o`8000002@3oool200000080oooo00<000000?ooo`3oool0100000090?ooo`030000003oool0oooo
00/000001@3oool;0=7=Z@D0oooo0P0000070?ooo`030000003oool0oooo00T0000000<0oooo0000
00000000100000000`3oool00000000000020?ooo`030000003oool0oooo008000000P3oool50000
00030?ooo`000000000000L000000P3oool00`000000oooo0?ooo`050?ooo`8000001@3oool<0=7=
Z@<000001`3oool2000000<0oooo0P0000000`3oool00000000000050?ooo`<000000P3oool50000
00L0oooo1@0000020?ooo`<000001@3oool2000000030?ooo`000000000000<0oooo0P0000070?oo
o`<000003P3AcJT000`0dLfY100000030?ooo`@000001P3oool;000000030?ooo`000000000000@0
0000103oool5000000@0oooo0`0000020?ooo`@000001@3oool400000080oooo1@0000020?ooo`80
0000303AcJT20?ooo`<00000103oool2000000T0oooo0P0000000`3oool0000000000004000000L0
oooo0P0000000`3oool000000000000200000080oooo0P0000070?ooo`8000001`3oool00`000000
oooo0?ooo`0400000080oooo00<000000?ooo`3oool00P00000;0=7=Z@@000000`3oool400000003
0?ooo`000000000000H0000000<0oooo0000000000001`3oool200000080oooo00<000000?ooo`3o
ool01P3oool8000000P0oooo1@0000030?ooo`8000000P3oool300000080oooo0P00000;0=7=Z@80
oooo0`0000020?ooo`80000000<0oooo0000000000000`0000020?ooo`D000000P3oool200000003
0?ooo`0000000000008000000P3oool300000080oooo00<000000?ooo`3oool0100000000`3oool0
000000000002000000030?ooo`00000000000080oooo1@0000020?ooo`D0000000<0oooo00000000
00000P3oool300000080oooo303AcJT3000000@0oooo0`0000020?ooo`P000000P3oool00`000000
oooo0?ooo`0500000080oooo3@0000020?ooo`D000000P3oool00`000000oooo0?ooo`0800000080
oooo0`0000040?ooo`<000003P3AcJT000`0dLfY100000030?ooo`@000001P3oool;000000030?oo
o`000000000000@00000103oool5000000@0oooo0`0000020?ooo`@000001@3oool400000080oooo
1@0000020?ooo`800000303AcJT40?ooo`030000003oool0oooo008000002@3oool2000000D0oooo
1`0000020?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool300000080oooo
2@0000020?ooo`<000001P3oool300000080oooo2`3AcJT4000000<0oooo100000000`3oool00000
00000006000000030?ooo`000000000000L0oooo0P0000020?ooo`030000003oool0oooo00H0oooo
200000080?ooo`D000000`3oool200000080oooo0`0000020?ooo`8000002`3AcJT2000000D0oooo
0`0000040?ooo`P000000P3oool3000000@0oooo3`0000040?ooo`<000000P3oool8000000@0oooo
0`0000050?ooo`800000303AcJT3000000@0oooo0`0000020?ooo`P000000P3oool00`000000oooo
0?ooo`0500000080oooo3@0000020?ooo`D000000P3oool00`000000oooo0?ooo`0800000080oooo
0`0000040?ooo`<000003P3AcJT000`0dLfY100000020?ooo`<00000103oool2000000<0oooo0P00
00040?ooo`@0000000<0oooo0000000000000P3oool200000080oooo0`0000040?ooo`800000103o
ool<00000080oooo0P0000040?ooo`80000000<0oooo0000000000000P3oool<0=7=Z@@0oooo00<0
00000?ooo`3oool00P0000090?ooo`8000001@3oool700000080oooo0P0000020?ooo`030000003o
ool0oooo0080oooo0P0000020?ooo`<000000P3oool900000080oooo0`0000060?ooo`<000000P3o
ool;0=7=Z@T0oooo1`0000050?ooo`8000000P3oool2000000030?ooo`000000000000D00000103o
ool200000080oooo1`0000030?ooo`H0000000<0oooo0000000000000P3oool2000000030?ooo`00
0000000000@000001@3oool;0=7=Z@8000001@3oool3000000@0oooo200000020?ooo`<00000103o
ool?000000@0oooo0`0000020?ooo`P00000103oool3000000D0oooo0P00000<0=7=Z@<00000103o
ool5000000030?ooo`000000000000L0000000<0oooo0000000000000P3oool5000000030?ooo`00
0000000000T0000000<0oooo0000000000000`0000020?ooo`80000000<0oooo0000000000001`00
00000`3oool0000000000003000000@0oooo0`00000>0=7=Z@00303AcJT400000080oooo0`000004
0?ooo`8000000`3oool2000000@0oooo100000000`3oool00000000000020?ooo`8000000P3oool3
000000@0oooo0P0000040?ooo``000000P3oool2000000@0oooo0P0000000`3oool0000000000002
0?ooo``0dLfY1@3oool200000080oooo0P0000020?ooo`030000003oool0oooo00800000103oool3
00000080oooo1`0000040?ooo`030000003oool0oooo008000001@3oool400000080oooo0P00000:
0?ooo`@000001`3oool;0=7=Z@T0oooo1`0000050?ooo`8000000P3oool2000000030?ooo`000000
000000D00000103oool200000080oooo1`0000030?ooo`H0000000<0oooo0000000000000P3oool2
000000030?ooo`000000000000@000001@3oool;0=7=Z@80oooo00<000000?ooo`3oool01`000003
0?ooo`@000000P3oool5000000P0oooo2@0000080?ooo`D000000P3oool4000000<0oooo1`000002
0?ooo`030000003oool0oooo00`0dLfY0`0000040?ooo`D0000000<0oooo0000000000001`000000
0`3oool00000000000020?ooo`D0000000<0oooo0000000000002@0000000`3oool0000000000003
00000080oooo0P0000000`3oool0000000000007000000030?ooo`000000000000<00000103oool3
000000h0dLfY000<0=7=Z@L0oooo0P0000040?ooo`8000000P3oool00`000000oooo0?ooo`020?oo
o`8000000P3oool300000080oooo2`0000040?ooo`D000001P3oool200000080oooo00<000000?oo
o`3oool00P0000040?ooo`D000000P3oool<0=7=Z@D0oooo0P0000020?ooo`8000000P3oool00`00
0000oooo0?ooo`02000000@0oooo0`0000020?ooo`L00000103oool00`000000oooo0?ooo`020000
00D0oooo100000020?ooo`8000002P3oool4000000L0oooo2`3AcJT2000000L0oooo1@0000090?oo
o`L000000P3oool2000000030?ooo`000000000000@000001`3oool3000000@0oooo0P0000020?oo
o`030000003oool0oooo00@000000`3oool9000000/0dLfY0P3oool00`000000oooo0?ooo`070000
00<0oooo100000020?ooo`D00000203oool9000000P0oooo1@0000020?ooo`@000000`3oool70000
0080oooo00<000000?ooo`3oool0303AcJT300000140oooo2P0000030?ooo`/000000`3oool:0000
0140oooo0`00000>0=7=Z@00303AcJT70?ooo`800000103oool200000080oooo00<000000?ooo`3o
ool00P3oool200000080oooo0`0000020?ooo`/00000103oool5000000H0oooo0P0000020?ooo`03
0000003oool0oooo00800000103oool500000080oooo303AcJT2000000T0oooo0P0000030?ooo`80
0000103oool300000080oooo0P0000000`3oool00000000000060?ooo`030000003oool0oooo00@0
00000P3oool500000080oooo0P0000070?ooo`<000000P3oool4000000<0oooo0P00000;0=7=Z@80
00001`3oool5000000T0oooo1`0000020?ooo`80000000<0oooo000000000000100000070?ooo`<0
0000103oool200000080oooo00<000000?ooo`3oool0100000030?ooo`T000002`3AcJU=000000`0
dLfY0`00000A0?ooo`X000000`3oool;000000<0oooo2P00000A0?ooo`<000003P3AcJT000`0dLfY
0P3oool5000000@0oooo0P0000020?ooo`80000000<0oooo0000000000001P3oool5000000@0oooo
2`0000020?ooo`<000000P3oool2000000@0oooo0P0000000`3oool00000000000040?ooo`800000
1`3oool<0=7=Z@L000000P3oool2000000<0oooo1P0000050?ooo`L000001P3oool00`000000oooo
0?ooo`0400000080oooo0`0000020?ooo`L000000P3oool<00000080oooo0P00000;0=7=Z@D0oooo
1P0000070?ooo`80000000<0oooo000000000000100000000`3oool00000000000070?ooo`H00000
00<0oooo0000000000000P3oool2000000`0oooo0P0000020?ooo`030000003oool0oooo00@0oooo
0`0000020?ooo`/0dLfY0P3oool00`000000oooo0?ooo`07000000<0oooo100000020?ooo`D00000
203oool9000000P0oooo1@0000020?ooo`@000000`3oool700000080oooo00<000000?ooo`3oool0
303AcJT300000140oooo2P0000030?ooo`/000000`3oool:00000140oooo0`00000>0=7=Z@00303A
cJT20?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool=000000<0oooo0P00
00040?ooo`<000000P3oool200000080oooo0P0000020?ooo`<00000103oool2000000<0oooo0P00
00040?ooo`@0000000<0oooo0000000000000P00000<0=7=Z@L000000P3oool2000000<0oooo1P00
00050?ooo`L000001P3oool00`000000oooo0?ooo`0400000080oooo0`0000020?ooo`L000000P3o
ool<00000080oooo0P00000;0=7=Z@@000001@3oool5000000H0oooo00<000000?ooo`3oool03000
00020?ooo`800000103oool8000000T0oooo1P0000000`3oool0000000000004000000030?ooo`00
00000000008000002`3AcJT20?ooo`030000003oool0oooo00L000000`3oool400000080oooo1@00
00080?ooo`T00000203oool500000080oooo100000030?ooo`L000000P3oool00`000000oooo0?oo
o`0<0=7=Z@<00000103oool5000000030?ooo`000000000000L0000000<0oooo0000000000000P3o
ool5000000030?ooo`000000000000T0000000<0oooo0000000000000`0000020?ooo`80000000<0
oooo0000000000001`0000000`3oool0000000000003000000@0oooo0`00000>0=7=Z@00303AcJT2
0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool=000000<0oooo0P000004
0?ooo`<000000P3oool200000080oooo0P0000020?ooo`<00000103oool2000000<0oooo0P000004
0?ooo`@0000000<0oooo0000000000000P00000<0=7=Z@80oooo0P0000000`3oool0000000000002
0?ooo`@000001`3oool5000000@0oooo0`0000040?ooo`80000000<0oooo0000000000000P000004
0?ooo`D000002`3oool9000000<0oooo0P00000;0=7=Z@@000001@3oool5000000H0oooo00<00000
0?ooo`3oool0300000020?ooo`800000103oool8000000T0oooo1P0000000`3oool0000000000004
000000030?ooo`0000000000008000002`3AcJT2000000D0oooo0`0000040?ooo`P000000P3oool3
000000@0oooo3`0000040?ooo`<000000P3oool8000000@0oooo0`0000050?ooo`800000303AcJT3
000000@0oooo1@0000000`3oool0000000000007000000030?ooo`00000000000080oooo1@000000
0`3oool0000000000009000000030?ooo`000000000000<000000P3oool2000000030?ooo`000000
000000L0000000<0oooo0000000000000`0000040?ooo`<000003P3AcJT000`0dLfY0P0000020?oo
o`D000000P3oool4000000D0oooo100000020?ooo`<00000103oool6000000<0oooo1P0000020?oo
o`/000001@3oool4000000<0oooo1000000<0=7=Z@80oooo0P0000000`3oool00000000000020?oo
o`@000001`3oool5000000@0oooo0`0000040?ooo`80000000<0oooo0000000000000P0000040?oo
o`D000002`3oool9000000<0oooo0P00000;0=7=Z@@000000`3oool4000000<0oooo0P0000090?oo
o`80000000<0oooo0000000000001@0000080?ooo`030000003oool0oooo008000000P3oool30000
0080oooo0P0000050?ooo`@0000000<0oooo0000000000000P3oool300000080oooo0P00000;0=7=
Z@8000001@3oool3000000@0oooo200000020?ooo`<00000103oool?000000@0oooo0`0000020?oo
o`P00000103oool3000000D0oooo0P00000<0=7=Z@<00000103oool300000080oooo200000020?oo
o`030000003oool0oooo00D000000P3oool=00000080oooo1@0000020?ooo`030000003oool0oooo
00P000000P3oool3000000@0oooo0`00000>0=7=Z@00303AcJT200000080oooo1@0000020?ooo`@0
00001@3oool400000080oooo0`0000040?ooo`H000000`3oool600000080oooo2`0000050?ooo`@0
00000`3oool4000000`0dLfY0P0000070?ooo`@000001@3oool4000000030?ooo`000000000000@0
oooo00<000000?ooo`3oool0103oool5000000H0oooo00<000000?ooo`3oool00P3oool200000080
oooo0`0000050?ooo`@000001`3oool2000000/0dLfY100000030?ooo`@000000`3oool2000000T0
oooo0P0000000`3oool0000000000005000000P0oooo00<000000?ooo`3oool00P0000020?ooo`<0
00000P3oool2000000D0oooo100000000`3oool00000000000020?ooo`<000000P3oool2000000/0
dLfY0P3oool300000080oooo0P0000000`3oool000000000000300000080oooo1@0000020?ooo`80
000000<0oooo0000000000000P0000020?ooo`<000000P3oool00`000000oooo0?ooo`0400000003
0?ooo`00000000000080000000<0oooo0000000000000P3oool500000080oooo1@0000000`3oool0
0000000000020?ooo`<000000P3oool<0=7=Z@<00000103oool300000080oooo200000020?ooo`03
0000003oool0oooo00D000000P3oool=00000080oooo1@0000020?ooo`030000003oool0oooo00P0
00000P3oool3000000@0oooo0`00000>0=7=Z@00303AcJT20?ooo`8000001@3oool4000000@0oooo
00<000000?ooo`3oool00P3oool4000000L0oooo0P0000020?ooo`80000000<0oooo000000000000
1P3oool2000000030?ooo`000000000000@000000P3oool5000000@0oooo100000000`3oool00000
00000002000000`0dLfY0P0000070?ooo`@000001@3oool4000000030?ooo`000000000000@0oooo
00<000000?ooo`3oool0103oool5000000H0oooo00<000000?ooo`3oool00P3oool200000080oooo
0`0000050?ooo`@000001`3oool2000000/0dLfY0P0000020?ooo`030000003oool0oooo00800000
0P3oool3000000@0oooo0`0000040?ooo`L000000P3oool00`000000oooo0?ooo`02000000T0oooo
1`0000020?ooo`D000000P3oool2000000030?ooo`000000000000L000000P3oool;0=7=Z@D0oooo
0P0000070?ooo`030000003oool0oooo00T0000000<0oooo000000000000100000000`3oool00000
000000020?ooo`030000003oool0oooo008000000P3oool5000000030?ooo`000000000000L00000
0P3oool00`000000oooo0?ooo`050?ooo`8000001@3oool<0=7=Z@<000001`3oool2000000<0oooo
0P0000000`3oool00000000000050?ooo`<000000P3oool5000000L0oooo1@0000020?ooo`<00000
1@3oool2000000030?ooo`000000000000<0oooo0P0000070?ooo`<000003P3AcJT000`0dLfY0P3o
ool2000000D0oooo100000040?ooo`030000003oool0oooo0080oooo100000070?ooo`8000000P3o
ool2000000030?ooo`000000000000H0oooo0P0000000`3oool000000000000400000080oooo1@00
00040?ooo`@0000000<0oooo0000000000000P00000<0=7=Z@D0oooo100000020?ooo`<000001P3o
ool5000000@0oooo0`00000;0?ooo`@0000000<0oooo0000000000000P3oool2000000D0oooo0P00
00020?ooo`<000000P3oool2000000<0oooo1000000;0=7=Z@8000000P3oool00`000000oooo0?oo
o`0200000080oooo0`0000040?ooo`<00000103oool700000080oooo00<000000?ooo`3oool00P00
00090?ooo`L000000P3oool500000080oooo0P0000000`3oool000000000000700000080oooo2`3A
cJT50?ooo`8000001`3oool00`000000oooo0?ooo`09000000030?ooo`000000000000@0000000<0
oooo0000000000000P3oool00`000000oooo0?ooo`0200000080oooo1@0000000`3oool000000000
000700000080oooo00<000000?ooo`3oool01@3oool2000000D0oooo303AcJT3000000T0oooo0`00
00020?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`D000000P3oool2000000<0oooo0P00
00020?ooo`D000000`3oool2000000D0oooo00<000000?ooo`3oool00`0000090?ooo`<000003P3A
cJT000`0dLfY100000020?ooo`030000003oool0oooo0080oooo100000020?ooo`030000003oool0
oooo00H000000`3oool200000080oooo100000020?ooo`030000003oool0oooo00@0oooo0P000002
0?ooo`T000001`3oool700000080oooo0P00000<0=7=Z@D0oooo100000020?ooo`<000001P3oool5
000000@0oooo0`00000;0?ooo`@0000000<0oooo0000000000000P3oool2000000D0oooo0P000002
0?ooo`<000000P3oool2000000<0oooo1000000;0=7=Z@D000000P3oool4000000D0oooo0P000005
0?ooo`@0000000<0oooo0000000000000P0000020?ooo`030000003oool0oooo00H0oooo0`000004
0?ooo``000001`3oool2000000L0oooo2`3AcJT30?ooo`8000002@3oool500000080oooo3@000004
0?ooo`030000003oool0oooo0080oooo3@0000020?ooo`D000002@3oool2000000<0oooo303AcJT3
000000T0oooo0`0000020?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`D000000P3oool2
000000<0oooo0P0000020?ooo`D000000`3oool2000000D0oooo00<000000?ooo`3oool00`000009
0?ooo`<000003P3AcJT000`0dLfY100000020?ooo`030000003oool0oooo0080oooo100000020?oo
o`030000003oool0oooo00H000000`3oool200000080oooo100000020?ooo`030000003oool0oooo
00@0oooo0P0000020?ooo`T000001`3oool700000080oooo0P00000<0=7=Z@80oooo1`0000050?oo
o`8000000P3oool4000000<0oooo0P0000070?ooo`D000000P3oool700000080oooo0P0000070?oo
o`D000000P3oool4000000L0oooo2`3AcJT200000080oooo0`0000020?ooo`8000001`3oool20000
00030?ooo`000000000000D000001P3oool9000000<0oooo100000030?ooo`T000000P3oool30000
00@0oooo0P0000000`3oool00000000000020?ooo`/0dLfY0`3oool2000000T0oooo1@0000020?oo
o`d00000103oool00`000000oooo0?ooo`020?ooo`d000000P3oool5000000T0oooo0P0000030?oo
o``0dLfY0P3oool3000000D0oooo0P0000050?ooo`D000001@3oool5000000030?ooo`0000000000
00T0000000<0oooo0000000000000`0000050?ooo`D000001@3oool2000000D0oooo0`0000020?oo
o`h0dLfY000<0=7=Z@80oooo0P0000020?ooo`030000003oool0oooo0080oooo2@0000040?ooo`@0
00000`3oool2000000@0oooo0`0000020?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`80
0000103oool300000080oooo1`0000020?ooo`800000303AcJT500000080oooo0P0000040?ooo`03
0000003oool0oooo00@000000P3oool3000000@0oooo00<000000?ooo`3oool01`0000040?ooo`80
00000P3oool00`000000oooo0?ooo`0200000080oooo0`0000020?ooo`8000000P3oool00`000000
oooo0?ooo`02000000L0oooo0P00000;0=7=Z@8000000P3oool300000080oooo0P0000070?ooo`80
000000<0oooo0000000000001@0000060?ooo`T000000`3oool4000000<0oooo2@0000020?ooo`<0
0000103oool2000000030?ooo`00000000000080oooo2`3AcJT9000000<0oooo1@0000020?ooo`80
00001@3oool8000000@0oooo00<000000?ooo`3oool00P3oool8000000D0oooo0P0000020?ooo`D0
00000`3oool9000000`0dLfY0P3oool3000000D0oooo0P0000050?ooo`D000001@3oool500000003
0?ooo`000000000000T0000000<0oooo0000000000000`0000050?ooo`D000001@3oool2000000D0
oooo0`0000020?ooo`h0dLfY000<0=7=Z@80oooo0P0000020?ooo`030000003oool0oooo0080oooo
2@0000040?ooo`@000000`3oool2000000@0oooo0`0000020?ooo`8000001P3oool00`000000oooo
0?ooo`020?ooo`800000103oool300000080oooo1`0000020?ooo`800000303AcJT500000080oooo
0P0000040?ooo`030000003oool0oooo00@000000P3oool3000000@0oooo00<000000?ooo`3oool0
1`0000040?ooo`8000000P3oool00`000000oooo0?ooo`0200000080oooo0`0000020?ooo`800000
0P3oool00`000000oooo0?ooo`02000000L0oooo0P00000;0=7=Z@80oooo0P0000000`3oool00000
00000004000000<0oooo0P0000070?ooo`8000000P3oool300000080oooo1@0000020?ooo`800000
0P3oool00`000000oooo0?ooo`090?ooo`@000000`3oool4000000030?ooo`000000000000@00000
0`3oool2000000/0dLfY2@0000030?ooo`D000000P3oool2000000D0oooo200000040?ooo`030000
003oool0oooo0080oooo200000050?ooo`8000000P3oool5000000<0oooo2@00000<0=7=Z@800000
0`3oool2000000D0oooo00<000000?ooo`3oool00P3oool300000080oooo00<000000?ooo`3oool0
0P3oool300000080oooo3@0000020?ooo`<00000103oool00`000000oooo0?ooo`03000000@0oooo
00<000000?ooo`3oool00`3oool2000000<0oooo0P00000>0=7=Z@00303AcJT2000000D0oooo0P00
00080?ooo`D000001P3oool300000080oooo2`0000040?ooo`80000000<0oooo0000000000000P00
00020?ooo`L000000P3oool6000000D0oooo303AcJT50?ooo`@000001@3oool2000000@0oooo0P00
00000`3oool00000000000040?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`@000000P3o
ool5000000D0oooo1P0000000`3oool000000000000200000080oooo1`00000;0=7=Z@80oooo0P00
00000`3oool0000000000004000000<0oooo0P0000070?ooo`8000000P3oool300000080oooo1@00
00020?ooo`8000000P3oool00`000000oooo0?ooo`090?ooo`@000000`3oool4000000030?ooo`00
0000000000@000000`3oool2000000/0dLfY1@0000020?ooo`80000000<0oooo0000000000001@00
00020?ooo`<00000103oool5000000<0oooo0P0000020?ooo`030000003oool0oooo008000000`3o
ool5000000@0oooo0`0000020?ooo`L0000000<0oooo0000000000000P3oool5000000`0dLfY0P00
00000`3oool0000000000003000000@0oooo00<000000?ooo`3oool00P0000030?ooo`80000000<0
oooo0000000000000P0000050?ooo`<000000P3oool300000080oooo0`0000050?ooo`@0000000<0
oooo0000000000000`3oool200000080oooo00<000000?ooo`3oool00P3oool5000000030?ooo`00
0000000000h0dLfY000<0=7=Z@@0oooo0`0000080?ooo`<000000P3oool400000080oooo0P000000
0`3oool0000000000006000000<0oooo0P0000020?ooo`H00000403oool200000080oooo0`000002
0?ooo`800000303AcJT50?ooo`@000001@3oool2000000@0oooo0P0000000`3oool0000000000004
0?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`@000000P3oool5000000D0oooo1P000000
0`3oool000000000000200000080oooo1`00000;0=7=Z@D000000P3oool2000000<0oooo2@000002
0?ooo`8000000`3oool400000080oooo2@0000000`3oool0000000000004000000030?ooo`000000
000000H00000203oool2000000@0oooo00<000000?ooo`3oool00P00000;0=7=Z@D0oooo2@000000
0`3oool00000000000020?ooo`<000000P3oool2000000<0oooo4`0000030?ooo`8000000P3oool3
00000080oooo0P0000000`3oool0000000000007000000D0oooo303AcJT2000000030?ooo`000000
000000<00000103oool00`000000oooo0?ooo`02000000<0oooo0P0000000`3oool0000000000002
000000D0oooo0`0000020?ooo`<000000P3oool3000000D0oooo100000000`3oool0000000000003
0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`D0000000<0oooo0000000000003P3AcJT0
00`0dLfY103oool3000000P0oooo0`0000020?ooo`@000000P3oool2000000030?ooo`0000000000
00H000000`3oool200000080oooo1P00000@0?ooo`8000000P3oool300000080oooo0P00000<0=7=
Z@80oooo0P0000030?ooo`8000001@3oool6000000D0oooo100000000`3oool00000000000040000
0080oooo0`0000020?ooo`@0000000<0oooo0000000000000P3oool200000080oooo00<000000?oo
o`3oool0100000030?ooo`800000103oool00`000000oooo0?ooo`020?ooo`/0dLfY1@0000020?oo
o`8000000`3oool900000080oooo0P0000030?ooo`@000000P3oool9000000030?ooo`0000000000
00@0000000<0oooo0000000000001P0000080?ooo`800000103oool00`000000oooo0?ooo`020000
00/0dLfY1@3oool9000000030?ooo`00000000000080oooo0`0000020?ooo`8000000`3ooolC0000
00<0oooo0P0000020?ooo`<000000P3oool2000000030?ooo`000000000000L000001@3oool<0=7=
Z@80oooo1@0000000`3oool0000000000002000000030?ooo`000000000000L0oooo1@0000030?oo
o`8000000`3oool7000000<0oooo0P0000030?ooo`D000001`3oool2000000030?ooo`0000000000
0080000000<0oooo0000000000000`0000020?ooo`h0dLfY000<0=7=Z@8000000P3oool5000000P0
oooo00<000000?ooo`3oool01P3oool2000000030?ooo`000000000000@000000P3oool200000003
0?ooo`000000000000H000000`3oool2000000@0oooo0P00000>0?ooo`@00000303AcJT20?ooo`80
00000`3oool2000000D0oooo1P0000050?ooo`@0000000<0oooo000000000000100000020?ooo`<0
00000P3oool4000000030?ooo`00000000000080oooo0P0000020?ooo`030000003oool0oooo00@0
00000`3oool2000000@0oooo00<000000?ooo`3oool00P3oool;0=7=Z@8000000`3oool2000000@0
oooo00<000000?ooo`3oool00P3oool7000000D0oooo0P0000040?ooo`<000001P3oool:000000H0
oooo0`0000050?ooo`H0000000<0oooo0000000000000P3oool;0=7=Z@80oooo0`0000020?ooo`80
00000`3oool2000000030?ooo`00000000000080oooo0P0000000`3oool00000000000050?ooo`@0
00000`3oool5000000@0oooo0`0000050?ooo`80000000<0oooo0000000000000P3oool200000003
0?ooo`000000000000<0oooo0P0000020?ooo`<000000P3oool<0=7=Z@80oooo1@0000000`3oool0
000000000002000000030?ooo`000000000000L0oooo1@0000030?ooo`8000000`3oool7000000<0
oooo0P0000030?ooo`D000001`3oool2000000030?ooo`00000000000080000000<0oooo00000000
00000`0000020?ooo`h0dLfY000<0=7=Z@8000000P3oool5000000P0oooo00<000000?ooo`3oool0
1P3oool2000000030?ooo`000000000000@000000P3oool2000000030?ooo`000000000000H00000
0`3oool2000000@0oooo0P00000>0?ooo`@00000303AcJT;00000080oooo00<000000?ooo`3oool0
0P0000020?ooo`8000001@3oool2000000L0oooo4P0000020?ooo`030000003oool0oooo00L0oooo
0P0000040?ooo`D000002`3AcJT50?ooo`800000103oool00`000000oooo0?ooo`0200000080oooo
0P0000000`3oool000000000000500000080oooo1@0000020?ooo`8000000P3oool2000000030?oo
o`00000000000080oooo0`0000040?ooo`8000000`3oool200000080oooo0`0000020?ooo`800000
0P3oool300000080oooo2`3AcJT20?ooo`<000000P3oool2000000<0oooo0P0000000`3oool00000
000000020?ooo`80000000<0oooo0000000000001@3oool4000000<0oooo1@0000040?ooo`<00000
1@3oool2000000030?ooo`00000000000080oooo0P0000000`3oool00000000000030?ooo`800000
0P3oool300000080oooo303AcJT2000000030?ooo`000000000000D0oooo0P0000000`3oool00000
00000002000000<0oooo1@0000020?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`<00000
0P3oool2000000D0oooo00<000000?ooo`3oool01@0000030?ooo`@0000000<0oooo000000000000
1@3oool2000000030?ooo`000000000000h0dLfY000<0=7=Z@80oooo0P0000020?ooo`030000003o
ool0oooo0080oooo0P0000040?ooo`D000001P3oool7000000D0oooo100000020?ooo`8000000P3o
ool300000080oooo0P0000020?ooo`L00000103oool2000000D0oooo303AcJT;00000080oooo00<0
00000?ooo`3oool00P0000020?ooo`8000001@3oool2000000L0oooo4P0000020?ooo`030000003o
ool0oooo00L0oooo0P0000040?ooo`D000002`3AcJT50?ooo`800000103oool00`000000oooo0?oo
o`0200000080oooo0P0000000`3oool000000000000500000080oooo1@0000020?ooo`8000000P3o
ool2000000030?ooo`00000000000080oooo0`0000040?ooo`8000000`3oool200000080oooo0`00
00020?ooo`8000000P3oool300000080oooo2`3AcJT30?ooo`8000000P3oool2000000D0oooo00<0
00000?ooo`3oool00P3oool300000080oooo0`0000020?oooa<000000P3oool300000080oooo0`00
00040?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`8000000`3oool<0=7=Z@80oooo00<0
00000?ooo`3oool00P0000050?ooo`D000000`3oool300000080oooo0P0000000`3oool000000000
00050?ooo`L000001@3oool2000000030?ooo`00000000000080oooo0`0000030?ooo`D000001@3o
ool200000080oooo00<000000?ooo`3oool03P3AcJT000`0dLfY0P3oool200000080oooo00<00000
0?ooo`3oool00P3oool2000000@0oooo1@0000060?ooo`L000001@3oool400000080oooo0P000002
0?ooo`<000000P3oool200000080oooo1`0000040?ooo`8000001@3oool<0=7=Z@80oooo0P000003
0?ooo`@000000`3oool200000080oooo0P0000050?ooo`8000000P3oool300000080oooo1@000006
0?ooo`8000001@3oool4000000D0oooo0P0000000`3oool00000000000040?ooo`D000000P3oool;
0=7=Z@8000000P3oool500000080oooo00<000000?ooo`3oool0103oool300000080oooo10000000
0`3oool0000000000007000000H0oooo00<000000?ooo`3oool00P3oool900000080oooo0`000009
0?ooo`D000000P3oool;0=7=Z@<000001`3ooolC00000080oooo1@0000020?ooo`030000003oool0
oooo00D000000P3ooolC000000L0oooo0`00000<0=7=Z@80oooo00<000000?ooo`3oool00P000005
0?ooo`D000000`3oool300000080oooo0P0000000`3oool00000000000050?ooo`L000001@3oool2
000000030?ooo`00000000000080oooo0`0000030?ooo`D000001@3oool200000080oooo00<00000
0?ooo`3oool03P3AcJT000`0dLfY3`0000020?ooo`<000000P3oool200000080oooo0P0000000`3o
ool00000000000020?ooo`@000000P3oool3000000H0oooo0`0000040?ooo`H0000000<0oooo0000
000000000P3oool4000000<0oooo0P0000020?ooo``0dLfY1@3oool2000000@0oooo0`0000040?oo
o`8000000`3oool2000000@0oooo00<000000?ooo`3oool00P3oool200000080oooo0`0000060?oo
o`030000003oool0oooo00800000103oool00`000000oooo0?ooo`040?ooo``000000P3oool;0=7=
Z@8000000P3oool500000080oooo00<000000?ooo`3oool0103oool300000080oooo100000000`3o
ool0000000000007000000H0oooo00<000000?ooo`3oool00P3oool900000080oooo0`0000090?oo
o`D000000P3oool;0=7=Z@<000001`3ooolC00000080oooo1@0000020?ooo`030000003oool0oooo
00D000000P3ooolC000000L0oooo0`00000<0=7=Z@<000001`3oool3000000@0oooo0`0000070?oo
o`<000000P3oool5000000<0oooo1@0000020?ooo`<000001`3oool3000000@0oooo0`0000070?oo
o`<000003P3AcJT000`0dLfY3`0000020?ooo`<000000P3oool200000080oooo0P0000000`3oool0
0000000000020?ooo`@000000P3oool3000000H0oooo0`0000040?ooo`H0000000<0oooo00000000
00000P3oool4000000<0oooo0P0000020?ooo``0dLfY1@3oool2000000@0oooo0`0000040?ooo`80
00000`3oool2000000@0oooo00<000000?ooo`3oool00P3oool200000080oooo0`0000060?ooo`03
0000003oool0oooo00800000103oool00`000000oooo0?ooo`040?ooo``000000P3oool;0=7=Z@80
oooo0`0000020?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`D000000P3oool2000000D0
oooo0P0000000`3oool00000000000020?ooo`L000001`3oool6000000D0oooo1@0000020?ooo`<0
00000P3oool2000000/0dLfY0`3oool7000000L0oooo100000080?oooa<00000203oool4000000L0
oooo1`0000030?ooo``0dLfY0`0000070?ooo`<00000103oool3000000L0oooo0`0000020?ooo`D0
00000`3oool500000080oooo0`0000070?ooo`<00000103oool3000000L0oooo0`00000>0=7=Z@00
303AcJT20?ooo`D00000203oool2000000030?ooo`000000000000800000103oool2000000<0oooo
100000020?ooo`80000000<0oooo0000000000000P3oool?00000080oooo00<000000?ooo`3oool0
0P0000020?ooo`L000000P3oool<0=7=Z@/000000P3oool00`000000oooo0?ooo`040?ooo`800000
00<0oooo0000000000000P3oool5000000@0oooo0P0000090?ooo`030000003oool0oooo0080oooo
1`0000090?ooo`@0000000<0oooo0000000000000P3oool;0=7=Z@80oooo0`0000020?ooo`800000
0P3oool00`000000oooo0?ooo`040?ooo`D000000P3oool2000000D0oooo0P0000000`3oool00000
000000020?ooo`L000001`3oool6000000D0oooo1@0000020?ooo`<000000P3oool2000000/0dLfY
0`3oool7000000L0oooo100000080?oooa<00000203oool4000000L0oooo1`0000030?ooo``0dLfY
0`0000070?ooo`<00000103oool3000000L0oooo1@0000000`3oool0000000000002000000<0oooo
100000000`3oool0000000000003000000L0oooo0`0000040?ooo`<000001`3oool3000000h0dLfY
000<0=7=Z@80oooo1@0000080?ooo`80000000<0oooo0000000000000P0000040?ooo`8000000`3o
ool400000080oooo0P0000000`3oool00000000000020?ooo`l000000P3oool00`000000oooo0?oo
o`0200000080oooo1`0000020?ooo``0dLfY2`0000020?ooo`030000003oool0oooo00@0oooo0P00
00000`3oool00000000000020?ooo`D00000103oool2000000T0oooo00<000000?ooo`3oool00P3o
ool7000000T0oooo100000000`3oool00000000000020?ooo`/0dLfY100000000`3oool000000000
0004000000030?ooo`00000000000080oooo100000050?ooo`80000000<0oooo0000000000001@3o
ool2000000@0oooo1`0000020?ooo`D000000P3oool2000000L0oooo0`0000040?ooo`030000003o
ool0oooo0080oooo2`3AcJT20?ooo`030000003oool0oooo008000000`3oool2000000<0oooo0P00
00020?ooo`80000000<0oooo0000000000001`0000030?ooo`T000000`3oool9000000030?ooo`00
000000000080oooo0P0000030?ooo`8000000`3oool200000080oooo00<000000?ooo`3oool0303A
cJT30?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`D000000`3oool300000080oooo0P00
00050?ooo`D000000`3oool5000000D0oooo0P0000020?ooo`<000000`3oool5000000@0oooo00<0
00000?ooo`3oool00P0000030?ooo`h0dLfY000<0=7=Z@80oooo0P0000050?ooo`@00000103oool0
0`000000oooo0?ooo`02000000@0oooo0`0000020?ooo`8000001P3oool3000000H0oooo0P000000
0`3oool00000000000060?ooo`80000000<0oooo000000000000100000050?ooo`@00000303AcJT2
0?ooo`80000000<0oooo0000000000000P3oool2000000L0oooo3P0000070?ooo`8000001P3oool0
0`000000oooo0?ooo`0400000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`L000002`3AcJT200000080oooo0`0000040?ooo`030000003oool0oooo00@0oooo0P000000
0`3oool000000000000900000080oooo0`0000060?ooo`D000000`3oool200000080oooo1@000002
0?ooo`@000000`3oool200000080oooo0`0000020?ooo`/0dLfY0P3oool00`000000oooo0?ooo`02
000000<0oooo0P0000030?ooo`8000000P3oool2000000030?ooo`000000000000L000000`3oool9
000000<0oooo2@0000000`3oool00000000000020?ooo`8000000`3oool2000000<0oooo0P000002
0?ooo`030000003oool0oooo00`0dLfY0`3oool200000080oooo00<000000?ooo`3oool00P3oool5
000000<0oooo0`0000020?ooo`8000001@3oool5000000<0oooo1@0000050?ooo`8000000P3oool3
000000<0oooo1@0000040?ooo`030000003oool0oooo008000000`3oool>0=7=Z@00303AcJT20?oo
o`L000000P3oool200000080oooo0P0000000`3oool0000000000002000000@0oooo0`0000020?oo
o`8000000P3oool4000000<0oooo0P0000020?ooo`@000001`3oool2000000D0oooo0P0000020?oo
o`8000000P3oool5000000`0dLfY0P3oool2000000030?ooo`00000000000080oooo0P0000070?oo
o`h000001`3oool2000000H0oooo00<000000?ooo`3oool0100000020?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool7000000/0dLfY0P0000020?ooo`<00000103oool00`00
0000oooo0?ooo`040?ooo`80000000<0oooo0000000000002@0000020?ooo`<000001P3oool50000
00<0oooo0P0000020?ooo`D000000P3oool4000000<0oooo0P0000020?ooo`<000000P3oool;0=7=
Z@<000001`3oool200000080oooo00<000000?ooo`3oool00P3oool3000000@0oooo2P0000020?oo
o`030000003oool0oooo00X00000103oool3000000@0oooo00<000000?ooo`3oool00P0000070?oo
o`<00000303AcJT50?ooo`80000000<0oooo0000000000000P0000000`3oool00000000000020000
00<0oooo1@0000050?ooo`80000000<0oooo0000000000000P0000030?ooo`@0000000<0oooo0000
000000001@3oool5000000<0oooo100000000`3oool0000000000002000000030?ooo`0000000000
00D0oooo3P3AcJT000`0dLfY0P3oool700000080oooo0P0000020?ooo`80000000<0oooo00000000
00000P0000040?ooo`<000000P3oool200000080oooo100000030?ooo`8000000P3oool4000000L0
oooo0P0000050?ooo`8000000P3oool200000080oooo1@00000<0=7=Z@80oooo0P0000030?ooo`80
00000P3oool2000000030?ooo`000000000000H0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`8000000P3oool9000000L0oooo4`0000040?ooo`/0dLfY0P0000050?ooo`@0
000000<0oooo0000000000000P0000020?ooo`<000001`3oool2000000L0oooo0P0000040?ooo`03
0000003oool0oooo00@0000000<0oooo0000000000000P3oool2000000<0oooo0P0000020?ooo`80
000000<0oooo0000000000000P0000020?ooo`030000003oool0oooo0080oooo2`3AcJT9000000<0
oooo0P0000050?ooo`80000000<0oooo0000000000001@0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool2000000<0oooo1`0000000`3oool00000000000050?ooo`80
00000`3oool9000000`0dLfY1@3oool2000000030?ooo`00000000000080000000<0oooo00000000
00000P0000030?ooo`D000001@3oool2000000030?ooo`0000000000008000000`3oool400000003
0?ooo`000000000000D0oooo1@0000030?ooo`@0000000<0oooo0000000000000P0000000`3oool0
0000000000050?ooo`h0dLfY000<0=7=Z@L0oooo0P0000020?ooo`L000000P3oool200000140oooo
2`0000050?ooo`@000000P3oool500000080oooo0P0000020?ooo`<000000P3oool<0=7=Z@@0oooo
0`0000020?ooo`@000000`3oool200000080oooo0P0000070?ooo`030000003oool0oooo0080oooo
1`0000020?ooo`@000000`3oool400000080oooo00<000000?ooo`3oool0103oool700000080oooo
00<000000?ooo`3oool00P3oool;0=7=Z@8000001@3oool4000000030?ooo`000000000000800000
0P3oool3000000L0oooo0P0000070?ooo`800000103oool00`000000oooo0?ooo`04000000030?oo
o`00000000000080oooo0P0000030?ooo`8000000P3oool2000000030?ooo`000000000000800000
0P3oool00`000000oooo0?ooo`020?ooo`/0dLfY2@0000030?ooo`8000001@3oool2000000030?oo
o`000000000000D00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0P0000030?ooo`L0000000<0oooo0000000000001@3oool2000000<0oooo2@00000<0=7=Z@800000
1@3oool00`000000oooo0?ooo`0300000080oooo1`0000030?ooo`<000000P3oool2000000030?oo
o`000000000000L0oooo0P0000000`3oool00000000000020?ooo`<000000`3oool700000080oooo
0`0000020?ooo`030000003oool0oooo00<0oooo0P00000>0=7=Z@00303AcJT70?ooo`8000000P3o
ool700000080oooo0P00000A0?ooo`/000001@3oool400000080oooo1@0000020?ooo`8000000P3o
ool300000080oooo303AcJT40?ooo`<000000P3oool4000000<0oooo0P0000020?ooo`8000001`3o
ool00`000000oooo0?ooo`020?ooo`L000000P3oool4000000<0oooo100000020?ooo`030000003o
ool0oooo00@0oooo1`0000020?ooo`030000003oool0oooo0080oooo2`3AcJT4000000<0oooo1@00
00040?ooo`T000000P3oool3000000D0oooo0P0000020?ooo`@0000000<0oooo0000000000001`00
00020?ooo`8000001@3oool200000080oooo00<000000?ooo`3oool00P3oool2000000030?ooo`00
000000000080oooo2`3AcJT20?ooo`D000000`3oool200000080oooo0`0000020?ooo`8000000`3o
ool3000000H0oooo00<000000?ooo`3oool01@0000020?ooo`8000001@3oool3000000<0oooo0P00
00020?ooo`<000000P3oool2000000<0oooo1@0000020?ooo``0dLfY0P3oool00`000000oooo0?oo
o`030?ooo`L000000P3oool300000080oooo0`0000030?ooo`8000000P3oool00`000000oooo0?oo
o`02000000<0oooo0P0000020?ooo`030000003oool0oooo008000000`3oool300000080oooo0`00
00020?ooo`L000001@3oool00`000000oooo0?ooo`0>0=7=Z@00303AcJT40?ooo`<00000203oool2
000000030?ooo`000000000000@0oooo1`0000020?ooo`8000002@3oool2000000/0oooo0P000002
0?ooo`030000003oool0oooo00@0oooo0P0000020?ooo`030000003oool0oooo0080oooo303AcJT2
0?ooo`800000303oool4000000X0oooo0P0000040?ooo`T000001@3oool9000000@0oooo0`000002
0?ooo`8000001`3oool;0=7=Z@@000000`3oool5000000@0oooo2@0000020?ooo`<000001@3oool2
00000080oooo100000000`3oool000000000000700000080oooo0P0000050?ooo`8000000P3oool0
0`000000oooo0?ooo`020?ooo`80000000<0oooo0000000000000P3oool;0=7=Z@80oooo1@000003
0?ooo`8000000P3oool300000080oooo0P0000030?ooo`<000001P3oool00`000000oooo0?ooo`05
00000080oooo0P0000050?ooo`<000000`3oool200000080oooo0`0000020?ooo`8000000`3oool5
00000080oooo303AcJT20?ooo`030000003oool0oooo00<0oooo1`0000020?ooo`<000000P3oool3
000000<0oooo0P0000020?ooo`030000003oool0oooo008000000`3oool200000080oooo00<00000
0?ooo`3oool00P0000030?ooo`<000000P3oool300000080oooo1`0000050?ooo`030000003oool0
oooo00h0dLfY000<0=7=Z@@0oooo0`0000080?ooo`80000000<0oooo000000000000103oool70000
0080oooo0P0000090?ooo`8000002`3oool200000080oooo00<000000?ooo`3oool0103oool20000
0080oooo00<000000?ooo`3oool00P3oool<0=7=Z@80oooo0P00000<0?ooo`@000002P3oool20000
00@0oooo2@0000050?ooo`T00000103oool300000080oooo0P0000070?ooo`/0dLfY0P0000070?oo
o`80000000<0oooo0000000000000P3oool4000000030?ooo`000000000000@0oooo00<000000?oo
o`3oool00P3oool300000080oooo100000020?ooo`<000001`3oool2000000@0oooo00<000000?oo
o`3oool0100000030?ooo`D00000103oool;0=7=Z@<0oooo1`0000070?ooo`8000001@3oool20000
00P0oooo2@0000080?ooo`8000001@3oool2000000L0oooo1`0000030?ooo``0dLfY0`3oool90000
00030?ooo`000000000000P0oooo0P0000080?ooo`@000000`3oool4000000P0oooo0P0000080?oo
o`80000000<0oooo0000000000001`0000030?ooo`h0dLfY000<0=7=Z@@0oooo2`0000020?ooo`<0
00001P3oool=000000<0oooo0P0000060?ooo`030000003oool0oooo008000000P3oool2000000<0
oooo100000020?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo``0dLfY0P0000030?ooo`80
00000P3oool2000000D0oooo1P0000000`3oool000000000000200000080oooo00<000000?ooo`3o
ool0103oool2000000030?ooo`0000000000008000000P3oool5000000@0oooo0P0000000`3oool0
00000000000200000080oooo00<000000?ooo`3oool01P0000000`3oool00000000000020?ooo`/0
dLfY1@3oool2000000@0oooo00<000000?ooo`3oool00P3oool200000080oooo0`0000020?ooo`D0
00000P3oool2000000030?ooo`0000000000008000000P3oool2000000030?ooo`00000000000080
00000`3oool2000000@0oooo1@0000020?ooo`80000000<0oooo0000000000000P0000070?ooo`/0
dLfY0`3oool200000080oooo0`0000020?ooo`8000000`3oool200000080oooo200000040?ooo``0
00000`3oool800000080oooo0P0000030?ooo`8000000P3oool300000080oooo0P0000030?ooo``0
dLfY0`3oool9000000030?ooo`000000000000P0oooo0P0000080?ooo`@000000`3oool4000000P0
oooo0P0000080?ooo`80000000<0oooo0000000000001`0000030?ooo`h0dLfY000<0=7=Z@@0oooo
2`0000020?ooo`<000001P3oool=000000<0oooo0P0000060?ooo`030000003oool0oooo00800000
0P3oool2000000<0oooo100000020?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo``0dLfY
0P0000030?ooo`8000000P3oool2000000D0oooo1P0000000`3oool000000000000200000080oooo
00<000000?ooo`3oool0103oool2000000030?ooo`0000000000008000000P3oool5000000@0oooo
0P0000000`3oool000000000000200000080oooo00<000000?ooo`3oool01P0000000`3oool00000
000000020?ooo`/0dLfY1@3oool2000000@0oooo00<000000?ooo`3oool00P3oool200000080oooo
0`0000020?ooo`D000000P3oool2000000030?ooo`0000000000008000000P3oool2000000030?oo
o`0000000000008000000`3oool2000000@0oooo1@0000020?ooo`80000000<0oooo000000000000
0P0000070?ooo`/0dLfY0`3oool200000080oooo0`0000020?ooo`8000000`3oool200000080oooo
200000040?ooo``000000`3oool800000080oooo0P0000030?ooo`8000000P3oool300000080oooo
0P0000030?ooo``0dLfY0`3oool700000080oooo00<000000?ooo`3oool00P0000080?ooo`800000
1P3oool4000000<0oooo100000060?ooo`800000203oool200000080oooo00<000000?ooo`3oool0
1`0000030?ooo`h0dLfY000<0=7=Z@80oooo1@00000:0?ooo`030000003oool0oooo008000000P3o
ool900000080oooo0P0000020?ooo`D000000P3oool4000000030?ooo`000000000000P0000000<0
oooo0000000000000P3oool7000000@0oooo303AcJT500000080oooo100000030?ooo`@000000P3o
ool300000080oooo100000000`3oool00000000000020?ooo`8000000P3oool3000000@0oooo0P00
00000`3oool00000000000020?ooo`@0000000<0oooo0000000000001000000<0?ooo`8000002`3A
cJT2000000<0oooo0P0000020?ooo`80000000<0oooo0000000000001P3oool3000000@0oooo00<0
00000?ooo`3oool01@3oool200000080oooo100000030?ooo`D00000203oool300000080oooo0P00
00080?ooo`@000002`3AcJT50?ooo`8000000P3oool5000000030?ooo`0000000000008000001@3o
ool2000000030?ooo`00000000000080oooo0P0000030?ooo`D00000103oool00`000000oooo0?oo
o`02000000030?ooo`000000000000D0oooo100000000`3oool000000000000300000080oooo0P00
00050?ooo``0dLfY0`3oool7000000<0oooo0P0000050?ooo`80000000<0oooo0000000000000`00
000E0?ooo`D0000000<0oooo0000000000001@3oool2000000<0oooo1`0000030?ooo`h0dLfY000<
0=7=Z@80oooo1@00000:0?ooo`030000003oool0oooo008000000P3oool900000080oooo0P000002
0?ooo`D000000P3oool4000000030?ooo`000000000000P0000000<0oooo0000000000000P3oool7
000000@0oooo303AcJT500000080oooo100000030?ooo`@000000P3oool300000080oooo10000000
0`3oool00000000000020?ooo`8000000P3oool3000000@0oooo0P0000000`3oool0000000000002
0?ooo`@0000000<0oooo0000000000001000000<0?ooo`8000002`3AcJT2000000<0oooo0P000002
0?ooo`80000000<0oooo0000000000001P3oool3000000@0oooo00<000000?ooo`3oool01@3oool2
00000080oooo100000030?ooo`D00000203oool300000080oooo0P0000080?ooo`@000002`3AcJT5
0?ooo`8000000P3oool5000000030?ooo`0000000000008000001@3oool2000000030?ooo`000000
00000080oooo0P0000030?ooo`D00000103oool00`000000oooo0?ooo`02000000030?ooo`000000
000000D0oooo100000000`3oool000000000000300000080oooo0P0000050?ooo``0dLfY0`3oool7
000000<0oooo0P0000050?ooo`80000000<0oooo0000000000000`00000E0?ooo`D0000000<0oooo
0000000000001@3oool2000000<0oooo1`0000030?ooo`h0dLfY000<0=7=Z@80oooo3@0000020?oo
o`030000003oool0oooo00@0oooo0P0000020?ooo`<00000203oool00`000000oooo0?ooo`020000
00L0oooo100000020?ooo`@0000000<0oooo0000000000000P3oool7000000@0oooo303AcJT;0000
0080oooo0`00000;0?ooo`8000001@3oool200000080oooo0`0000060?ooo`T0000000<0oooo0000
000000000P3oool5000000L0oooo1000000;0=7=Z@@0oooo00<000000?ooo`3oool01@3oool40000
0080oooo0`0000040?ooo`8000001@3oool3000000P0oooo00<000000?ooo`3oool01@3oool20000
0080oooo100000030?ooo`@00000203oool200000080oooo2`3AcJT500000080oooo1`0000030?oo
o`8000000P3oool300000080oooo1@0000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool2000000030?ooo`000000000000<000000P3oool300000080oooo0P0000030?oo
o`L000000P3oool5000000`0dLfY0`3oool7000000D0oooo0P0000050?ooo`D0000000<0oooo0000
000000004@3oool2000000030?ooo`000000000000<000001@3oool2000000D0oooo1`0000030?oo
o`h0dLfY000<0=7=Z@@000001`3oool900000080oooo0P0000070?ooo`H000000P3oool300000080
oooo1P0000050?ooo`T000001P3oool500000080oooo303AcJT90?ooo`@0000000<0oooo00000000
0000103oool5000000@0oooo300000090?ooo`8000000P3oool300000080oooo3@0000050?ooo`/0
dLfY103oool00`000000oooo0?ooo`050?ooo`@000000P3oool3000000@0oooo0P0000050?ooo`<0
0000203oool00`000000oooo0?ooo`050?ooo`8000000P3oool4000000<0oooo100000080?ooo`80
00000P3oool;0=7=Z@D000000P3oool7000000<0oooo0P0000020?ooo`<000000P3oool500000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`80000000<0oooo00000000
00000`0000020?ooo`<000000P3oool2000000<0oooo1`0000020?ooo`D00000303AcJT30?ooo`L0
00001@3oool2000000D0oooo1@0000000`3oool000000000000A0?ooo`80000000<0oooo00000000
00000`0000050?ooo`8000001@3oool7000000<0oooo3P3AcJT000`0dLfY100000070?ooo`T00000
0P3oool2000000L0oooo1P0000020?ooo`<000000P3oool6000000D0oooo2@0000060?ooo`D00000
0P3oool<0=7=Z@T0oooo100000000`3oool00000000000040?ooo`D00000103oool<000000T0oooo
0P0000020?ooo`<000000P3oool=000000D0oooo2`3AcJT20?ooo`<000000P3oool200000080oooo
00<000000?ooo`3oool00P3oool5000000@0oooo0P0000000`3oool00000000000020?ooo`800000
1`3oool2000000<0oooo0P0000030?ooo`@00000103oool00`000000oooo0?ooo`04000000030?oo
o`00000000000080oooo0`0000040?ooo`/0dLfY1@0000050?ooo`L000000P3oool2000000030?oo
o`00000000000080oooo0`0000040?ooo`030000003oool0oooo00D000000P3oool2000000<0oooo
0`0000020?ooo`80000000<0oooo0000000000000P3oool7000000D0oooo1@00000<0=7=Z@80oooo
00<000000?ooo`3oool01@3oool2000000D0oooo1@0000000`3oool00000000000030?oooaD00000
0`3oool2000000030?ooo`000000000000<000001@3oool2000000L0oooo00<000000?ooo`3oool0
3P3AcJT000`0dLfY3@3oool4000000D0oooo100000020?ooo`T000001@3oool200000080oooo0P00
00020?ooo`030000003oool0oooo008000000P3oool2000000h0oooo0P0000020?ooo``0dLfY0P3o
ool3000000P0oooo1`0000020?ooo`030000003oool0oooo0080oooo0`0000040?ooo`T00000103o
ool3000000@0oooo0P0000000`3oool0000000000005000000P0oooo0`0000020?ooo`/0dLfY1@3o
ool9000000H0oooo00<000000?ooo`3oool00P0000030?ooo`8000000P3oool2000000030?ooo`00
000000000080oooo0P0000030?ooo`@000000`3oool400000080oooo300000070?ooo`8000002`3A
cJT5000000L0oooo0`0000040?ooo`8000001@3oool3000000D0oooo0P0000020?ooo`030000003o
ool0oooo008000001@3oool3000000D0oooo0P0000040?ooo`<000001`3oool5000000`0dLfY0P00
000:0?ooo`030000003oool0oooo0080oooo0`0000020?ooo`030000003oool0oooo00<000000P3o
oolA00000080oooo0`0000020?ooo`030000003oool0oooo00<00000103oool00`000000oooo0?oo
o`080?ooo`8000003P3AcJT000`0dLfY3@3oool4000000D0oooo100000020?ooo`T000001@3oool2
00000080oooo0P0000020?ooo`030000003oool0oooo008000000P3oool2000000h0oooo0P000002
0?ooo``0dLfY0P3oool3000000P0oooo1`0000020?ooo`030000003oool0oooo0080oooo0`000004
0?ooo`T00000103oool3000000@0oooo0P0000000`3oool0000000000005000000P0oooo0`000002
0?ooo`/0dLfY1@3oool9000000H0oooo00<000000?ooo`3oool00P0000030?ooo`8000000P3oool2
000000030?ooo`00000000000080oooo0P0000030?ooo`@000000`3oool400000080oooo30000007
0?ooo`8000002`3AcJT5000000L0oooo0`0000040?ooo`8000001@3oool3000000D0oooo0P000002
0?ooo`030000003oool0oooo008000001@3oool3000000D0oooo0P0000040?ooo`<000001`3oool5
000000`0dLfY0P00000:0?ooo`030000003oool0oooo0080oooo0`0000020?ooo`030000003oool0
oooo00<000000P3ooolA00000080oooo0`0000020?ooo`030000003oool0oooo00<00000103oool0
0`000000oooo0?ooo`080?ooo`8000003P3AcJT00?l0dLfYb`3AcJT00?l0dLfYb`3AcJT00?l0dLfY
b`3AcJT00?l0dLfYb`3AcJT00?l0dLfYb`3AcJT00?l0dLfYb`3AcJT00?l0dLfYb`3AcJT00?l0dLfY
b`3AcJT00?l0dLfYb`3AcJT00?l0dLfYb`3AcJT00?l0dLfYb`3AcJT000`0dLfY2P0000050?ooo`H0
00000P3oool200000080oooo0P0000040?ooo`8000000P3oool300000080oooo0P0000040?ooo`80
00000P3oool200000080oooo1P0000050?ooo`X00000303AcJT2000000@0oooo1P0000020?ooo`80
0000203oool4000000P0oooo1@0000080?ooo`@00000203oool200000080oooo1P0000040?ooo`80
00002`3AcJT4000000X0oooo100000020?ooo`@00000103oool4000000H0oooo0P0000060?ooo`@0
0000103oool400000080oooo1000000:0?ooo`@000002`3AcJT200000080oooo0P0000020?ooo`@0
000000<0oooo000000000000200000060?ooo`@00000103oool3000000@0oooo100000060?ooo`X0
000000<0oooo0000000000000P0000020?ooo`8000000P3oool2000000`0dLfY0P0000040?ooo`<0
00000P3oool800000080oooo0P0000070?ooo`@000000P3oool500000080oooo100000070?ooo`80
00000P3oool800000080oooo0`0000040?ooo`8000003P3AcJT000`0dLfY2P0000050?ooo`H00000
0P3oool200000080oooo0P0000040?ooo`8000000P3oool300000080oooo0P0000040?ooo`800000
0P3oool200000080oooo1P0000050?ooo`X00000303AcJT2000000@0oooo1P0000020?ooo`800000
203oool4000000P0oooo1@0000080?ooo`@00000203oool200000080oooo1P0000040?ooo`800000
2`3AcJT4000000X0oooo100000020?ooo`@00000103oool4000000H0oooo0P0000060?ooo`@00000
103oool400000080oooo1000000:0?ooo`@000002`3AcJT200000080oooo0P0000020?ooo`@00000
00<0oooo000000000000200000060?ooo`@00000103oool3000000@0oooo100000060?ooo`X00000
00<0oooo0000000000000P0000020?ooo`8000000P3oool2000000`0dLfY0P0000040?ooo`<00000
0P3oool800000080oooo0P0000070?ooo`@000000P3oool500000080oooo100000070?ooo`800000
0P3oool800000080oooo0`0000040?ooo`8000003P3AcJT000`0dLfY1P0000070?ooo`8000001P3o
ool:000000H0oooo0`0000060?ooo`X000001P3oool3000000H0oooo1P00000<0=7=Z@80oooo1000
00020?ooo`H000002P3oool4000000P0oooo1@0000080?ooo`@000002P3oool600000080oooo1000
00020?ooo`/0dLfY100000020?ooo`H000002P3oool8000000P0oooo0P0000080?ooo`P000002P3o
ool600000080oooo1000000;0=7=Z@80oooo0P0000020?ooo`L000000P3oool8000000@0oooo0P00
00040?ooo`@000000`3oool4000000@0oooo0P0000040?ooo`P000000P3oool700000080oooo0P00
00020?ooo``0dLfY0P3oool2000000@0oooo00<000000?ooo`3oool00P0000020?ooo`@000000P3o
ool2000000D0oooo0P0000080?ooo`030000003oool0oooo00H0oooo0P0000050?ooo`8000000P3o
ool400000080oooo0P0000020?ooo`8000000`3oool200000080oooo3P3AcJT000`0dLfY1P000007
0?ooo`8000001P3oool:000000H0oooo0`0000060?ooo`X000001P3oool3000000H0oooo1P00000<
0=7=Z@80oooo100000020?ooo`H000002P3oool4000000P0oooo1@0000080?ooo`@000002P3oool6
00000080oooo100000020?ooo`/0dLfY100000020?ooo`H000002P3oool8000000P0oooo0P000008
0?ooo`P000002P3oool600000080oooo1000000;0=7=Z@80oooo0P0000020?ooo`L000000P3oool8
000000@0oooo0P0000040?ooo`@000000`3oool4000000@0oooo0P0000040?ooo`P000000P3oool7
00000080oooo0P0000020?ooo``0dLfY0P3oool2000000@0oooo00<000000?ooo`3oool00P000002
0?ooo`@000000P3oool2000000D0oooo0P0000080?ooo`030000003oool0oooo00H0oooo0P000005
0?ooo`8000000P3oool400000080oooo0P0000020?ooo`8000000`3oool200000080oooo3P3AcJT0
00`0dLfY1P0000070?ooo`P000000P3oool4000000X0oooo0`00000:0?ooo`@000000P3oool90000
00H0oooo1P00000<0=7=Z@80oooo3P0000020?ooobT000000P3oool>00000080oooo2`3AcJT40?oo
o`@00000203oool200000080oooo100000020?ooo`800000103oool200000080oooo1P0000020?oo
o`800000103oool200000080oooo100000020?ooo`800000203oool4000000@0oooo2`3AcJT20000
0080oooo100000040?ooo`L00000103oool6000000H0oooo1`0000060?ooo`H00000103oool70000
00@0oooo100000020?ooo`800000303AcJT40?ooo`8000000`3oool6000000@0oooo0P0000030?oo
o`@000001P3oool200000080oooo00<000000?ooo`3oool00P0000060?ooo`@000000`3oool20000
00@0oooo1P0000030?ooo`800000103oool>0=7=Z@00303AcJT6000000L0oooo200000020?ooo`@0
00002P3oool3000000X0oooo100000020?ooo`T000001P3oool6000000`0dLfY0P3oool>00000080
oooo:@0000020?ooo`h000000P3oool;0=7=Z@@0oooo100000080?ooo`8000000P3oool400000080
oooo0P0000040?ooo`8000000P3oool600000080oooo0P0000040?ooo`8000000P3oool400000080
oooo0P0000080?ooo`@00000103oool;0=7=Z@8000000P3oool4000000@0oooo1`0000040?ooo`H0
00001P3oool7000000H0oooo1P0000040?ooo`L00000103oool400000080oooo0P00000<0=7=Z@@0
oooo0P0000030?ooo`H00000103oool2000000<0oooo100000060?ooo`8000000P3oool00`000000
oooo0?ooo`02000000H0oooo100000030?ooo`800000103oool6000000<0oooo0P0000040?ooo`h0
dLfY000<0=7=Z@800000103oool9000000H0oooo100000020?ooo`8000000P3oool2000000@0oooo
0`0000040?ooo`8000000P3oool200000080oooo100000060?ooo`T00000103oool2000000`0dLfY
0P0000020?ooo`h000000P3ooolU00000080oooo3P0000020?ooo`8000002`3AcJT20?ooo`H00000
1P3oool400000080oooo100000040?ooo`H000000P3oool600000080oooo1P0000040?ooo`@00000
0P3oool4000000H0oooo1P0000020?ooo`/0dLfY0P3oool6000000@0oooo1`0000040?ooo`@00000
0P3oool2000000@0oooo1`0000040?ooo`8000000P3oool4000000@0oooo1`0000040?ooo`H00000
0P3oool<0=7=Z@800000103oool2000000L0oooo100000020?ooo`8000002@3oool200000080oooo
1@0000020?ooo`8000002@3oool200000080oooo100000080?ooo`030000003oool0oooo0080oooo
0P00000>0=7=Z@00303AcJT2000000@0oooo2@0000060?ooo`@000000P3oool200000080oooo0P00
00040?ooo`<00000103oool200000080oooo0P0000020?ooo`@000001P3oool9000000@0oooo0P00
000<0=7=Z@8000000P3oool>00000080oooo9@0000020?ooo`h000000P3oool2000000/0dLfY0P3o
ool6000000H0oooo100000020?ooo`@00000103oool600000080oooo1P0000020?ooo`H00000103o
ool400000080oooo100000060?ooo`H000000P3oool;0=7=Z@80oooo1P0000040?ooo`L00000103o
ool400000080oooo0P0000040?ooo`L00000103oool200000080oooo100000040?ooo`L00000103o
ool600000080oooo303AcJT2000000@0oooo0P0000070?ooo`@000000P3oool2000000T0oooo0P00
00020?ooo`D000000P3oool2000000T0oooo0P0000020?ooo`@00000203oool00`000000oooo0?oo
o`020?ooo`8000003P3AcJT000`0dLfY0P0000040?ooo`@000002`3oool200000080oooo1P000002
0?ooo`8000000P3oool300000080oooo0P0000020?ooo`H000000P3oool2000000/0oooo10000004
0?ooo`800000303AcJT<000000H0oooo0P0000040?ooo`@000000P3oool400000080oooo1@000002
0?ooo`@000000P3oool4000000@0oooo0P0000060?ooo``000002`3AcJT20?ooo`800000103oool2
00000080oooo0P0000080?ooo`800000203oool200000080oooo1P0000020?ooo`800000203oool2
000000P0oooo0P0000020?ooo`800000103oool200000080oooo2`3AcJT4000000@0oooo10000005
0?ooo`8000000P3oool400000080oooo0P0000020?ooo`l000000P3oool200000080oooo10000002
0?ooo`8000001@3oool4000000@0oooo1000000<0=7=Z@@00000103oool300000080oooo0P000002
0?ooo`8000000P3oool500000080oooo5@0000020?ooo`D000000P3oool200000080oooo0P000002
0?ooo`@000000`3oool4000000h0dLfY000<0=7=Z@800000103oool4000000/0oooo0P0000020?oo
o`H000000P3oool200000080oooo0`0000020?ooo`8000000P3oool600000080oooo0P00000;0?oo
o`@00000103oool2000000`0dLfY300000060?ooo`800000103oool400000080oooo100000020?oo
o`D000000P3oool400000080oooo100000040?ooo`8000001P3oool<000000/0dLfY0P3oool20000
00@0oooo0P0000020?ooo`800000203oool2000000P0oooo0P0000020?ooo`H000000P3oool20000
00P0oooo0P0000080?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`/0dLfY100000040?oo
o`@000001@3oool200000080oooo100000020?ooo`8000000P3oool?00000080oooo0P0000020?oo
o`@000000P3oool2000000D0oooo100000040?ooo`@00000303AcJT4000000@0oooo0`0000020?oo
o`8000000P3oool200000080oooo1@0000020?oooaD000000P3oool500000080oooo0P0000020?oo
o`8000000P3oool4000000<0oooo1000000>0=7=Z@00303AcJT2000000@0oooo1000000;0?ooo`80
00000P3oool600000080oooo0P0000020?ooo`<000000P3oool200000080oooo1P0000020?ooo`80
00002`3oool4000000@0oooo0P00000<0=7=Z@`00000103oool2000000H0oooo1P0000040?ooo`T0
0000103oool6000000H0oooo0P0000040?ooo``000002`3AcJT20?ooo`8000001P3oool:00000080
oooo0P0000020?ooo`@000000P3oool2000000@0oooo0P0000040?ooo`8000000P3oool400000080
oooo0P0000020?ooo`X000001P3oool200000080oooo2`3AcJT4000000@0oooo100000030?ooo`80
00000P3oool2000000@0oooo0P0000020?oooa<000000P3oool2000000@0oooo0P0000020?ooo`80
00000`3oool4000000@0oooo1000000<0=7=Z@@0oooo0P0000020?ooo`<000000P3oool2000000P0
oooo00<000000?ooo`3oool01P3oool200000080oooo1@0000020?ooo`800000203oool00`000000
oooo0?ooo`060?ooo`8000000P3oool4000000030?ooo`000000000000@0oooo3P3AcJT000`0dLfY
1P3oool200000080oooo1`00000:0?ooo`@000000P3oool200000080oooo0`0000020?ooo`800000
0P3oool4000000X0oooo1`0000020?ooo`8000001P3oool<0=7=Z@`00000103oool2000000H0oooo
1P0000040?ooo`T00000103oool6000000H0oooo0P0000040?ooo``000002`3AcJT20?ooo`800000
1P3oool:00000080oooo0P0000020?ooo`@000000P3oool2000000@0oooo0P0000040?ooo`800000
0P3oool400000080oooo0P0000020?ooo`X000001P3oool200000080oooo2`3AcJT4000000@0oooo
100000030?ooo`8000000P3oool2000000@0oooo0P0000020?oooa<000000P3oool2000000@0oooo
0P0000020?ooo`8000000`3oool4000000@0oooo1000000<0=7=Z@H000001@3oool400000080oooo
100000020?ooo`D000001P3oool200000080oooo00<000000?ooo`3oool00P0000060?ooo`D00000
0P3oool400000080oooo100000050?ooo`H000003P3AcJT000`0dLfY1P3oool200000080oooo1`00
000:0?ooo`@000000P3oool200000080oooo0`0000020?ooo`8000000P3oool4000000X0oooo1`00
00020?ooo`8000001P3oool<0=7=Z@80oooo1P0000040?ooo`H00000103oool400000080oooo0P00
00020?ooo`8000000P3oool500000080oooo0P0000020?ooo`8000000P3oool4000000@0oooo1P00
00040?ooo`H000000P3oool;0=7=Z@P0oooo2P0000060?ooo`8000000P3oool2000000@0oooo0P00
00020?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`8000001P3oool:000000P0oooo2`3A
cJT20?ooo`H00000103oool3000000H0oooo0P0000020?ooo`@000001P3oool2000000<0oooo0P00
00060?ooo`@000000P3oool2000000H0oooo0`0000040?ooo`H000000P3oool<0=7=Z@H000001@3o
ool400000080oooo100000020?ooo`D000001P3oool200000080oooo00<000000?ooo`3oool00P00
00060?ooo`D000000P3oool400000080oooo100000050?ooo`H000003P3AcJT000`0dLfY0P3oool6
00000080oooo1@00000<0?ooo`@00000103oool7000000@0oooo1000000<0?ooo`D000000P3oool6
00000080oooo303AcJT20?ooo`H00000103oool6000000@0oooo100000020?ooo`8000000P3oool2
00000080oooo1@0000020?ooo`8000000P3oool200000080oooo100000040?ooo`H00000103oool6
00000080oooo2`3AcJT80?ooo`X000001P3oool200000080oooo0P0000040?ooo`8000000P3oool2
00000080oooo0P0000040?ooo`8000000P3oool2000000H0oooo2P0000080?ooo`/0dLfY0P3oool6
000000@0oooo0`0000060?ooo`8000000P3oool4000000H0oooo0P0000030?ooo`8000001P3oool4
00000080oooo0P0000060?ooo`<00000103oool600000080oooo303AcJT200000080oooo0P000002
0?ooo`/00000103oool300000080oooo0P0000080?ooo`030000003oool0oooo00H0oooo0P000002
0?ooo`<00000103oool<000000030?ooo`00000000000080oooo0P00000>0=7=Z@00303AcJT20?oo
o`H000000P3oool5000000`0oooo100000040?ooo`L00000103oool4000000`0oooo1@0000020?oo
o`H000000P3oool<0=7=Z@8000000P3oool4000000@0oooo100000020?ooo`@00000103oool20000
0080oooo0P0000020?ooo`T000000P3oool200000080oooo0P0000040?ooo`@000000P3oool40000
00@0oooo100000020?ooo`8000002`3AcJT2000000@0oooo0P0000020?ooo`P000000P3oool20000
00@0oooo0P0000060?ooo`X000001P3oool2000000@0oooo0P0000020?ooo`P000000P3oool20000
00@0oooo0P00000;0=7=Z@8000000P3oool4000000@0oooo0`0000040?ooo`8000000P3oool20000
00@0oooo0P0000060?ooo`<000001P3oool2000000@0oooo0P0000020?ooo`800000103oool30000
00@0oooo100000020?ooo`800000303AcJT200000080oooo0P0000020?ooo`/00000103oool30000
0080oooo0P0000080?ooo`030000003oool0oooo00H0oooo0P0000020?ooo`<00000103oool<0000
00030?ooo`00000000000080oooo0P00000>0=7=Z@00303AcJT200000080oooo0P0000040?ooo`<0
00000P3oool2000000H0oooo0P0000020?ooo`8000000P3oool2000000@0oooo0`0000040?ooo`80
00000P3oool200000080oooo0P0000060?ooo`8000000`3oool2000000@0oooo0P0000020?ooo`80
0000303AcJT200000080oooo100000040?ooo`@000000P3oool4000000@0oooo0P0000020?ooo`80
00000P3oool900000080oooo0P0000020?ooo`800000103oool400000080oooo100000040?ooo`@0
00000P3oool2000000/0dLfY0P0000040?ooo`8000000P3oool800000080oooo0P0000040?ooo`80
00001P3oool:000000H0oooo0P0000040?ooo`8000000P3oool800000080oooo0P0000040?ooo`80
00002`3AcJT200000080oooo100000040?ooo`<00000103oool200000080oooo0P0000040?ooo`80
00001P3oool3000000H0oooo0P0000040?ooo`8000000P3oool2000000@0oooo0`0000040?ooo`@0
00000P3oool2000000`0dLfY100000020?ooo`8000001@3oool800000080oooo00<000000?ooo`3o
ool00P0000020?ooo`@000000P3oool500000080oooo100000020?ooo`8000000P3oool00`000000
oooo0?ooo`08000000H0oooo00<000000?ooo`3oool01000000>0=7=Z@00303AcJT200000080oooo
0P0000040?ooo`<000000P3oool2000000H0oooo0P0000020?ooo`8000000P3oool2000000@0oooo
0`0000040?ooo`8000000P3oool200000080oooo0P0000060?ooo`8000000`3oool2000000@0oooo
0P0000020?ooo`800000303AcJT60?ooo`8000000P3oool400000080oooo2P0000040?ooo`800000
0P3oool2000000D0oooo0P0000020?ooo`800000103oool:00000080oooo100000020?ooo`800000
1P3oool;0=7=Z@8000000P3oool400000080oooo200000020?ooo`8000000P3oool6000000@0oooo
0P0000020?ooo`8000000P3oool2000000@0oooo1P0000020?ooo`8000000P3oool800000080oooo
100000020?ooo`8000002`3AcJT800000080oooo0P0000030?ooo`H000000P3oool200000080oooo
0P0000040?ooo`@000000`3oool4000000@0oooo0P0000020?ooo`8000000P3oool6000000<0oooo
0P0000020?ooo`P00000303AcJT400000080oooo0P0000050?ooo`P000000P3oool00`000000oooo
0?ooo`0200000080oooo100000020?ooo`D000000P3oool400000080oooo0P0000020?ooo`030000
003oool0oooo00P000001P3oool00`000000oooo0?ooo`04000000h0dLfY000<0=7=Z@8000000P3o
ool2000000/0oooo0P0000040?ooo`@000000P3oool2000000H0oooo0`0000060?ooo`8000000P3o
ool4000000@0oooo0P00000;0?ooo`8000000P3oool2000000`0dLfY1P3oool200000080oooo1000
00020?ooo`X00000103oool200000080oooo0P0000050?ooo`8000000P3oool2000000@0oooo2P00
00020?ooo`@000000P3oool2000000H0oooo2`3AcJT200000080oooo100000020?ooo`P000000P3o
ool200000080oooo1P0000040?ooo`8000000P3oool200000080oooo0P0000040?ooo`H000000P3o
ool200000080oooo200000020?ooo`@000000P3oool2000000/0dLfY200000020?ooo`8000000`3o
ool600000080oooo0P0000020?ooo`800000103oool4000000<0oooo100000040?ooo`8000000P3o
ool200000080oooo1P0000030?ooo`8000000P3oool8000000`0dLfY100000020?ooo`<000000P3o
ool<000000030?ooo`000000000000H000000P3oool200000080oooo00<000000?ooo`3oool00P00
00020?ooo`P0000000<0oooo0000000000002P0000020?ooo`<000000P3oool4000000h0dLfY000<
0=7=Z@8000000P3oool2000000/0oooo0P0000040?ooo`@000000P3oool2000000H0oooo0`000006
0?ooo`8000000P3oool4000000@0oooo0P00000;0?ooo`8000000P3oool2000000`0dLfY103oool2
00000080oooo0P0000040?ooo`X000000P3oool400000080oooo0P0000090?ooo`8000000P3oool4
00000080oooo2P0000040?ooo`8000000P3oool2000000@0oooo2`3AcJT:0?ooo`8000001P3oool2
00000080oooo0P0000020?ooo`P00000103oool2000000@0oooo200000020?ooo`8000000P3oool2
000000H0oooo0P00000:0?ooo`/0dLfY2P0000050?ooo`@000000P3oool200000080oooo0P000002
0?ooo`@00000103oool3000000@0oooo100000020?ooo`8000000P3oool200000080oooo10000005
0?ooo`X00000303AcJT400000080oooo0`0000020?ooo``0000000<0oooo0000000000001P000002
0?ooo`8000000P3oool00`000000oooo0?ooo`0200000080oooo200000000`3oool000000000000:
00000080oooo0`0000020?ooo`@000003P3AcJT000`0dLfY0P0000020?ooo`8000003@3oool20000
00@0oooo0P0000020?ooo`H000000P3oool300000080oooo1P0000020?ooo`800000103oool20000
00d0oooo0P0000020?ooo`800000303AcJT40?ooo`8000000P3oool2000000@0oooo2P0000020?oo
o`@000000P3oool2000000T0oooo0P0000020?ooo`@000000P3oool:000000@0oooo0P0000020?oo
o`800000103oool;0=7=Z@X0oooo0P0000060?ooo`8000000P3oool200000080oooo200000040?oo
o`800000103oool800000080oooo0P0000020?ooo`8000001P3oool2000000X0oooo2`3AcJT:0000
00D0oooo100000020?ooo`8000000P3oool200000080oooo100000040?ooo`<00000103oool40000
0080oooo0P0000020?ooo`8000000P3oool4000000D0oooo2P00000<0=7=Z@@0oooo0P0000050?oo
o`8000000P3oool8000000D0oooo0P0000020?ooo`d000000P3oool2000000D0oooo200000020?oo
o`8000001@3oool2000000@0oooo3P3AcJT000`0dLfY0P0000020?ooo`8000003@3oool2000000@0
oooo0P0000020?ooo`H000000P3oool300000080oooo1P0000020?ooo`800000103oool2000000d0
oooo0P0000020?ooo`800000303AcJT40?ooo`8000000P3oool2000000@0oooo2P0000020?ooo`@0
00000P3oool2000000T0oooo0P0000020?ooo`@000000P3oool:000000@0oooo0P0000020?ooo`80
0000103oool;0=7=Z@8000000P3oool4000000H0oooo100000020?ooo`@000000P3oool2000000@0
oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000020?ooo`@000000P3oool4000000H0
oooo100000020?ooo`8000002`3AcJT4000000H0oooo0P0000000`3oool000000000000200000080
oooo100000040?ooo`@00000103oool7000000@0oooo100000040?ooo`@000000P3oool400000003
0?ooo`000000000000H0oooo1000000<0=7=Z@@0oooo0P0000050?ooo`8000000P3oool8000000D0
oooo0P0000020?ooo`d000000P3oool2000000D0oooo200000020?ooo`8000001@3oool2000000@0
oooo3P3AcJT000`0dLfY0P3oool200000080oooo1000000;0?ooo`8000000P3oool2000000@0oooo
100000020?ooo`<000000P3oool4000000@0oooo0P0000020?ooo`8000002`3oool400000080oooo
0P0000020?ooo``0dLfY103oool4000000H0oooo2P0000020?ooo`H000003@3oool600000080oooo
2P0000060?ooo`@00000103oool;0=7=Z@8000000P3oool4000000H0oooo100000020?ooo`@00000
0P3oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000020?ooo`@00000
0P3oool4000000H0oooo100000020?ooo`8000002`3AcJT4000000@0oooo0P0000020?ooo`030000
003oool0oooo0080oooo1P0000040?ooo`@00000103oool7000000@0oooo100000040?ooo`H00000
103oool00`000000oooo0?ooo`02000000@0oooo1000000<0=7=Z@@000000P3oool3000000P0oooo
1P0000030?ooo`8000000P3oool600000080oooo00<000000?ooo`3oool01P0000020?ooo`800000
0`3oool6000000P0oooo0`0000020?ooo`@000003P3AcJT000`0dLfY0P3oool200000080oooo1000
000;0?ooo`8000000P3oool2000000@0oooo100000020?ooo`<000000P3oool4000000@0oooo0P00
00020?ooo`8000002`3oool400000080oooo0P0000020?ooo``0dLfY103oool4000000H0oooo2P00
00020?ooo`H000003@3oool600000080oooo2P0000060?ooo`@00000103oool;0=7=Z@`000001P3o
ool6000000@0oooo100000020?ooo`8000000P3oool200000080oooo0P0000020?ooo`@00000103o
ool6000000H0oooo3000000;0=7=Z@@00000103oool200000080oooo00<000000?ooo`3oool00P3o
ool6000000@0oooo100000040?ooo`L00000103oool4000000@0oooo1P0000040?ooo`030000003o
ool0oooo00800000103oool4000000`0dLfY100000020?ooo`<00000203oool6000000<0oooo0P00
00020?ooo`H000000P3oool00`000000oooo0?ooo`0600000080oooo0P0000030?ooo`H00000203o
ool300000080oooo1000000>0=7=Z@00303AcJT8000000L0oooo100000040?ooo`H00000203oool3
000000P0oooo1P0000040?ooo`@000001`3oool8000000`0dLfY103oool4000000@0oooo0P000002
0?ooo`X000000P3oool4000000d0oooo100000020?ooo`X000000P3oool2000000@0oooo10000004
0?ooo`/0dLfY300000060?ooo`H00000103oool400000080oooo0P0000020?ooo`8000000P3oool2
00000080oooo100000040?ooo`H000001P3oool<000000/0dLfY103oool6000000<0oooo10000006
0?ooo`@000005`3oool4000000H0oooo100000030?ooo`H00000103oool<0=7=Z@P0oooo2@000006
0?ooo`D000000P3oool200000080oooo0P0000020?ooo`030000003oool0oooo008000000P3oool2
00000080oooo1@0000060?ooo`X000001`3oool>0=7=Z@00303AcJT8000000L0oooo100000040?oo
o`H00000203oool3000000P0oooo1P0000040?ooo`@000001`3oool8000000`0dLfY103oool40000
00@0oooo0P0000020?ooo`X000000P3oool4000000d0oooo100000020?ooo`X000000P3oool20000
00@0oooo100000040?ooo`/0dLfY0P3oool2000000P0oooo0P0000020?ooo`8000001P3oool60000
0080oooo100000020?ooo`8000000P3oool400000080oooo1P0000060?ooo`8000000P3oool20000
00P0oooo0P0000020?ooo`/0dLfY103oool6000000<0oooo100000060?ooo`@000005`3oool40000
00H0oooo100000030?ooo`H00000103oool<0=7=Z@P0oooo2@0000060?ooo`D000000P3oool20000
0080oooo0P0000020?ooo`030000003oool0oooo008000000P3oool200000080oooo1@0000060?oo
o`X000001`3oool>0=7=Z@00303AcJT20?ooo`@000000P3oool2000000L0oooo300000020?ooo`80
0000103oool3000000@0oooo0P0000020?ooo``000001`3oool200000080oooo100000020?ooo``0
dLfY3P0000020?ooo`800000103oool8000000@0oooo0P0000050?ooo`800000103oool8000000@0
oooo0P0000020?ooo`h000002`3AcJT20?ooo`800000203oool200000080oooo0P0000060?ooo`H0
00000P3oool400000080oooo0P0000020?ooo`@000000P3oool6000000H0oooo0P0000020?ooo`80
0000203oool200000080oooo2`3AcJT40?ooo`@000000P3oool3000000@0oooo0P0000040?ooo`@0
00005`3oool4000000@0oooo0P0000040?ooo`<000000P3oool4000000@0oooo303AcJT40?ooo`80
00000P3oool00`000000oooo0?ooo`0400000080oooo0P0000040?ooo`L000000P3oool2000000@0
oooo00<000000?ooo`3oool00P3oool200000080oooo1`0000040?ooo`8000000P3oool400000080
oooo0P0000000`3oool00000000000040?ooo`h0dLfY000<0=7=Z@80oooo100000020?ooo`800000
1`3oool<00000080oooo0P0000040?ooo`<00000103oool200000080oooo300000070?ooo`800000
0P3oool400000080oooo303AcJT>00000080oooo0P0000040?ooo`P00000103oool2000000D0oooo
0P0000040?ooo`P00000103oool200000080oooo3P00000;0=7=Z@80oooo100000040?ooo`800000
0P3oool800000080oooo100000040?ooo`@000000P3oool200000080oooo100000040?ooo`@00000
0P3oool800000080oooo0P0000040?ooo`@000000P3oool;0=7=Z@@0oooo100000020?ooo`<00000
103oool2000000@0oooo1000000G0?ooo`@00000103oool2000000@0oooo0`0000020?ooo`@00000
103oool<0=7=Z@@0oooo0P0000020?ooo`030000003oool0oooo00@000000P3oool2000000@0oooo
1`0000020?ooo`800000103oool00`000000oooo0?ooo`020?ooo`8000000P3oool7000000@0oooo
0P0000020?ooo`@000000P3oool2000000030?ooo`000000000000@0oooo3P3AcJT000`0dLfY1000
00020?ooo`/000001P3oool6000000P0oooo0`0000080?ooo`H000001P3oool;00000080oooo1000
000<0=7=Z@`000000P3oool200000080oooo100000020?ooo`@000000P3oool4000000T0oooo1000
00020?ooo`@000000P3oool400000080oooo0P0000020?ooo``000002`3AcJT20?ooo`@00000103o
ool200000080oooo200000020?ooo`@00000103oool400000080oooo0P0000020?ooo`@00000103o
ool400000080oooo200000020?ooo`800000103oool400000080oooo2`3AcJT20?ooo`@000000P3o
ool200000080oooo00<000000?ooo`3oool00P0000020?ooo`@00000103oool400000080oooo0P00
00070?ooo`8000000P3oool4000000@0oooo100000020?ooo`8000000P3oool00`000000oooo0?oo
o`0200000080oooo100000020?ooo``0dLfY103oool2000000D0oooo0P0000020?ooo`@000000P3o
ool700000080oooo100000040?ooo`030000003oool0oooo0080oooo100000020?ooo`L000000P3o
ool400000080oooo0P0000050?ooo`800000103oool>0=7=Z@00303AcJT400000080oooo2`000006
0?ooo`H00000203oool3000000P0oooo1P0000060?ooo`/000000P3oool4000000`0dLfY30000002
0?ooo`8000000P3oool400000080oooo100000020?ooo`@000002@3oool400000080oooo10000002
0?ooo`@000000P3oool200000080oooo3000000;0=7=Z@@000000P3oool200000080oooo10000002
0?ooo`@000000P3oool400000080oooo100000060?ooo`8000001P3oool400000080oooo10000002
0?ooo`@000000P3oool400000080oooo0P0000020?ooo`@000002`3AcJT20?ooo`@000000P3oool2
00000080oooo00<000000?ooo`3oool00P0000020?ooo`@00000103oool400000080oooo0P000007
0?ooo`8000000P3oool4000000@0oooo100000020?ooo`8000000P3oool00`000000oooo0?ooo`02
00000080oooo100000020?ooo``0dLfY103oool2000000D0oooo0P0000020?ooo`@000000P3oool7
00000080oooo100000040?ooo`030000003oool0oooo0080oooo100000020?ooo`L000000P3oool4
00000080oooo0P0000050?ooo`800000103oool>0=7=Z@00303AcJT400000080oooo2`0000060?oo
o`H00000203oool3000000P0oooo1P0000060?ooo`/000000P3oool4000000`0dLfY103oool40000
0080oooo100000040?ooo`P000000P3oool4000000d0oooo100000020?ooo`P00000103oool40000
0080oooo100000040?ooo`/0dLfY100000020?ooo`8000000P3oool400000080oooo100000020?oo
o`@000000P3oool4000000H0oooo0P0000060?ooo`@000000P3oool400000080oooo100000020?oo
o`@000000P3oool200000080oooo1000000;0=7=Z@800000103oool200000080oooo0P0000000`3o
ool00000000000020?ooo`H00000103oool6000000/0oooo1P0000040?ooo`H000000P3oool20000
00030?ooo`00000000000080oooo0P0000040?ooo`800000303AcJT20?ooo`800000103oool00`00
0000oooo0?ooo`020?ooo`8000000P3oool4000000<0oooo0P0000020?ooo`@000000P3oool20000
0080oooo00<000000?ooo`3oool00P0000020?ooo`@000000P3oool2000000<0oooo100000020?oo
o`800000103oool2000000<0oooo0P0000020?ooo`h0dLfY000<0=7=Z@80oooo0P0000040?ooo`L0
00000P3oool4000000P0oooo0P0000060?ooo`<000001P3oool2000000P0oooo100000020?ooo`L0
0000103oool200000080oooo303AcJT40?ooo`@000000P3oool4000000@0oooo200000020?ooo`@0
00003@3oool400000080oooo200000040?ooo`@000000P3oool4000000@0oooo2`3AcJT2000000@0
oooo0P00000:0?ooo`8000000P3oool2000000@0oooo200000020?ooo`8000000P3oool8000000@0
oooo0P0000020?ooo`8000002P3oool2000000@0oooo0P00000;0=7=Z@800000103oool200000080
oooo0P0000000`3oool00000000000020?ooo`H00000103oool6000000/0oooo1P0000040?ooo`H0
00000P3oool2000000030?ooo`00000000000080oooo0P0000040?ooo`800000303AcJT2000000H0
oooo00<000000?ooo`3oool0103oool400000080oooo0`0000020?oooaT000000P3oool300000080
oooo100000060?ooo`8000001@3oool2000000h0dLfY000<0=7=Z@80oooo0P0000040?ooo`L00000
0P3oool4000000P0oooo0P0000060?ooo`<000001P3oool2000000P0oooo100000020?ooo`L00000
103oool200000080oooo303AcJT40?ooo`H00000103oool400000080oooo100000020?ooo`H00000
3@3oool600000080oooo100000020?ooo`@00000103oool6000000@0oooo2`3AcJT2000000@0oooo
0P00000:0?ooo`8000000P3oool2000000@0oooo200000020?ooo`8000000P3oool8000000@0oooo
0P0000020?ooo`8000002P3oool2000000@0oooo0P00000;0=7=Z@8000001P3oool4000000D0oooo
0P00000:0?ooo`H000000P3oool300000080oooo1P00000:0?ooo`8000001@3oool4000000H0oooo
0P00000<0=7=Z@8000001P3oool00`000000oooo0?ooo`040?ooo`@000000P3oool300000080oooo
6@0000020?ooo`<000000P3oool4000000H0oooo0P0000050?ooo`8000003P3AcJT000`0dLfY1P3o
ool2000000L0oooo0P0000020?ooo`@000000P3oool2000000@0oooo0P0000020?ooo`L000000P3o
ool2000000@0oooo0P0000020?ooo`@000000P3oool2000000L0oooo0P0000060?ooo``0dLfY103o
ool6000000@0oooo100000020?ooo`@000000P3oool6000000d0oooo1P0000020?ooo`@000000P3o
ool4000000@0oooo1P0000040?ooo`/0dLfY103oool8000000H0oooo100000020?ooo`@000000P3o
ool4000000@0oooo0P0000040?ooo`@000000P3oool400000080oooo100000060?ooo`P00000103o
ool;0=7=Z@8000001P3oool4000000D0oooo0P00000:0?ooo`H000000P3oool300000080oooo1P00
000:0?ooo`8000001@3oool4000000H0oooo0P00000<0=7=Z@800000103oool5000000@0oooo0P00
00020?ooo`@0000000<0oooo0000000000000P0000020?ooo`@00000103oool00`000000oooo0?oo
o`020?ooo`@000000P3oool4000000030?ooo`0000000000008000000P3oool2000000@0oooo1@00
00040?ooo`8000003P3AcJT000`0dLfY1P3oool2000000L0oooo0P0000020?ooo`@000000P3oool2
000000@0oooo0P0000020?ooo`L000000P3oool2000000@0oooo0P0000020?ooo`@000000P3oool2
000000L0oooo0P0000060?ooo``0dLfY103oool600000080oooo0P0000040?ooo`8000001P3oool2
000000@0oooo100000050?ooo`@00000103oool2000000H0oooo0P0000040?ooo`8000000P3oool6
000000@0oooo2`3AcJT40?ooo`P000001P3oool400000080oooo100000020?ooo`@00000103oool2
000000@0oooo100000020?ooo`@000000P3oool4000000H0oooo200000040?ooo`/0dLfY0P3oool2
000000@0oooo100000030?ooo`8000002P3oool200000080oooo1P0000030?ooo`H000000P3oool2
000000X0oooo0P0000030?ooo`@00000103oool200000080oooo303AcJT2000000@0oooo1@000004
0?ooo`8000000P3oool4000000030?ooo`0000000000008000000P3oool4000000@0oooo00<00000
0?ooo`3oool00P3oool400000080oooo100000000`3oool000000000000200000080oooo0P000004
0?ooo`D00000103oool2000000h0dLfY000<0=7=Z@8000001P3oool5000000H0oooo1000000:0?oo
o`8000000P3oool300000080oooo0P00000:0?ooo`@000001`3oool4000000H0oooo0P00000<0=7=
Z@@0oooo1P0000020?ooo`800000103oool2000000H0oooo0P0000040?ooo`@000001@3oool40000
00@0oooo0P0000060?ooo`800000103oool200000080oooo1P0000040?ooo`/0dLfY303oool60000
00@0oooo1P0000020?ooo`8000000P3oool:00000080oooo0P0000020?ooo`H00000103oool60000
00`0oooo2`3AcJT20?ooo`800000103oool4000000<0oooo0P00000:0?ooo`8000000P3oool60000
00<0oooo1P0000020?ooo`8000002P3oool2000000<0oooo100000040?ooo`8000000P3oool<0=7=
Z@@0oooo0P0000020?ooo`030000003oool0oooo00800000103oool7000000@0oooo100000020?oo
o`T000000P3oool4000000@0oooo1`0000040?ooo`8000000P3oool2000000030?ooo`0000000000
00@0oooo3P3AcJT000`0dLfY0P0000060?ooo`D000001P3oool4000000X0oooo0P0000020?ooo`<0
00000P3oool2000000X0oooo100000070?ooo`@000001P3oool2000000`0dLfY103oool400000080
oooo0P0000020?ooo`@000001P3oool2000000H0oooo100000050?ooo`@000001P3oool2000000H0
oooo100000020?ooo`8000000P3oool4000000@0oooo2`3AcJT<0?ooo`H00000103oool600000080
oooo0P0000020?ooo`X000000P3oool200000080oooo1P0000040?ooo`H00000303oool;0=7=Z@80
oooo2`0000020?ooo`8000000P3oool4000000X0oooo2`00000:0?ooo`@000000P3oool200000080
oooo2`0000020?ooo``0dLfY103oool200000080oooo00<000000?ooo`3oool00P0000040?ooo`L0
0000103oool400000080oooo2@0000020?ooo`@00000103oool7000000@0oooo0P0000020?ooo`80
000000<0oooo000000000000103oool>0=7=Z@00303AcJT=0?ooo`800000403oool200000080oooo
1`0000020?ooo`800000403oool3000000`0oooo303AcJT40?ooo`@000000P3oool200000080oooo
100000060?ooo`8000001P3oool4000000D0oooo100000060?ooo`8000001P3oool400000080oooo
0P0000020?ooo`@00000103oool;0=7=Z@@0oooo1P0000040?ooo`8000004P3oool:00000180oooo
0P0000040?ooo`H00000103oool;0=7=Z@80oooo2`0000020?ooo`8000000P3oool4000000X0oooo
2`00000:0?ooo`@000000P3oool200000080oooo2`0000020?ooo``0dLfY0P0000040?ooo`D00000
103oool200000080oooo0P0000090?ooo`8000000P3oool900000080oooo0P0000090?ooo`800000
0P3oool2000000@0oooo1@0000040?ooo`8000003P3AcJT000`0dLfY3@3oool200000100oooo0P00
00020?ooo`L000000P3oool200000100oooo0`00000<0?ooo``0dLfY4000000D0?ooo`D00000503o
ool@000000/0dLfY103oool6000000@0oooo0P00000B0?ooo`X000004P3oool2000000@0oooo1P00
00040?ooo`/0dLfY0P0000020?ooo`P0000000<0oooo0000000000000P3oool6000000P0oooo0P00
00020?ooo`L000000P3oool2000000P0oooo1P0000020?ooo`80000000<0oooo0000000000001P00
00020?ooo`800000303AcJT2000000@0oooo1@0000040?ooo`8000000P3oool2000000T0oooo0P00
00020?ooo`T000000P3oool2000000T0oooo0P0000020?ooo`800000103oool5000000@0oooo0P00
000>0=7=Z@00303AcJU=000000`0dLfY4000000D0?ooo`D00000503oool@000000/0dLfYCP00000;
0=7=Z@8000000P3oool8000000030?ooo`00000000000080oooo1P0000080?ooo`8000000P3oool7
00000080oooo0P0000080?ooo`H000000P3oool2000000030?ooo`000000000000H000000P3oool2
000000`0dLfYC@00000>0=7=Z@00303AcJU=000000`0dLfY4000000D0?ooo`D00000503oool@0000
00/0dLfYCP00000;0=7=Z@8000000P3oool8000000030?ooo`00000000000080oooo1P0000080?oo
o`8000000P3oool700000080oooo0P0000080?ooo`H000000P3oool2000000030?ooo`0000000000
00H000000P3oool2000000`0dLfYC@00000>0=7=Z@00303AcJT=0?ooo`800000403oool200000080
oooo1`0000020?ooo`800000403oool3000000`0oooo303AcJT@000001@0oooo1@00000D0?oooa00
00002`3AcJT40?ooo`H00000103oool200000180oooo2P00000B0?ooo`800000103oool6000000@0
oooo2`3AcJT200000080oooo200000000`3oool00000000000020?ooo`H00000203oool200000080
oooo1`0000020?ooo`800000203oool600000080oooo0P0000000`3oool000000000000600000080
oooo0P00000<0=7=Z@800000103oool5000000@0oooo0P0000020?ooo`8000002@3oool200000080
oooo2@0000020?ooo`8000002@3oool200000080oooo0P0000040?ooo`D00000103oool2000000h0
dLfY000<0=7=Z@d0oooo0P00000@0?ooo`8000000P3oool700000080oooo0P00000@0?ooo`<00000
303oool<0=7=Z@@0oooo100000020?ooo`8000000P3oool4000000H0oooo0P0000060?ooo`@00000
1@3oool4000000H0oooo0P0000060?ooo`@000000P3oool200000080oooo100000040?ooo`/0dLfY
103oool6000000@0oooo0P00000B0?ooo`X000004P3oool2000000@0oooo1P0000040?ooo`/0dLfY
0P3oool;00000080oooo0P0000020?ooo`@000002P3oool;000000X0oooo100000020?ooo`800000
0P3oool;00000080oooo303AcJT2000000@0oooo1@0000040?ooo`8000000P3oool2000000T0oooo
0P0000020?ooo`T000000P3oool2000000T0oooo0P0000020?ooo`800000103oool5000000@0oooo
0P00000>0=7=Z@00303AcJT2000000H0oooo1@0000060?ooo`@000002P3oool200000080oooo0`00
00020?ooo`8000002P3oool4000000L0oooo100000060?ooo`800000303AcJT40?ooo`@000000P3o
ool200000080oooo100000060?ooo`8000001P3oool4000000D0oooo100000060?ooo`8000001P3o
ool400000080oooo0P0000020?ooo`@00000103oool;0=7=Z@`0oooo1P0000040?ooo`H000000P3o
ool200000080oooo2P0000020?ooo`8000000P3oool6000000@0oooo1P00000<0?ooo`/0dLfY0P3o
ool;00000080oooo0P0000020?ooo`@000002P3oool;000000X0oooo100000020?ooo`8000000P3o
ool;00000080oooo303AcJT40?ooo`8000000P3oool00`000000oooo0?ooo`02000000@0oooo1`00
00040?ooo`@000000P3oool900000080oooo100000040?ooo`L00000103oool200000080oooo0P00
00000`3oool00000000000040?ooo`h0dLfY000<0=7=Z@8000001P3oool5000000H0oooo1000000:
0?ooo`8000000P3oool300000080oooo0P00000:0?ooo`@000001`3oool4000000H0oooo0P00000<
0=7=Z@@0oooo1P0000020?ooo`800000103oool2000000H0oooo0P0000040?ooo`@000001@3oool4
000000@0oooo0P0000060?ooo`800000103oool200000080oooo1P0000040?ooo`/0dLfY303oool6
000000@0oooo1P0000020?ooo`8000000P3oool:00000080oooo0P0000020?ooo`H00000103oool6
000000`0oooo2`3AcJT20?ooo`800000103oool4000000<0oooo0P00000:0?ooo`8000000P3oool6
000000<0oooo1P0000020?ooo`8000002P3oool2000000<0oooo100000040?ooo`8000000P3oool<
0=7=Z@@0oooo0P0000020?ooo`030000003oool0oooo00800000103oool7000000@0oooo10000002
0?ooo`T000000P3oool4000000@0oooo1`0000040?ooo`8000000P3oool2000000030?ooo`000000
000000@0oooo3P3AcJT000`0dLfY1P3oool2000000L0oooo0P0000020?ooo`@000000P3oool20000
00@0oooo0P0000020?ooo`L000000P3oool2000000@0oooo0P0000020?ooo`@000000P3oool20000
00L0oooo0P0000060?ooo``0dLfY103oool600000080oooo0P0000040?ooo`8000001P3oool20000
00@0oooo100000050?ooo`@00000103oool2000000H0oooo0P0000040?ooo`8000000P3oool60000
00@0oooo2`3AcJT40?ooo`P000001P3oool400000080oooo100000020?ooo`@00000103oool20000
00@0oooo100000020?ooo`@000000P3oool4000000H0oooo200000040?ooo`/0dLfY0P3oool20000
00@0oooo100000030?ooo`8000002P3oool200000080oooo1P0000030?ooo`H000000P3oool20000
00X0oooo0P0000030?ooo`@00000103oool200000080oooo303AcJT2000000@0oooo1@0000040?oo
o`8000000P3oool4000000030?ooo`0000000000008000000P3oool4000000@0oooo00<000000?oo
o`3oool00P3oool400000080oooo100000000`3oool000000000000200000080oooo0P0000040?oo
o`D00000103oool2000000h0dLfY000<0=7=Z@H0oooo0P0000070?ooo`8000000P3oool400000080
oooo0P0000040?ooo`8000000P3oool700000080oooo0P0000040?ooo`8000000P3oool400000080
oooo0P0000070?ooo`8000001P3oool<0=7=Z@@0oooo1P0000040?ooo`@000000P3oool400000080
oooo1P00000=0?ooo`H000000P3oool400000080oooo100000040?ooo`H00000103oool;0=7=Z@@0
oooo200000060?ooo`@000000P3oool400000080oooo100000040?ooo`800000103oool400000080
oooo100000020?ooo`@000001P3oool8000000@0oooo2`3AcJT2000000H0oooo100000050?ooo`80
00002P3oool600000080oooo0`0000020?ooo`H000002P3oool2000000D0oooo100000060?ooo`80
0000303AcJT2000000@0oooo1@0000040?ooo`8000000P3oool4000000030?ooo`00000000000080
00000P3oool4000000@0oooo00<000000?ooo`3oool00P3oool400000080oooo100000000`3oool0
00000000000200000080oooo0P0000040?ooo`D00000103oool2000000h0dLfY000<0=7=Z@80oooo
0P0000040?ooo`L000000P3oool4000000P0oooo0P0000060?ooo`<000001P3oool2000000P0oooo
100000020?ooo`L00000103oool200000080oooo303AcJT40?ooo`H00000103oool400000080oooo
100000020?ooo`H000003@3oool600000080oooo100000020?ooo`@00000103oool6000000@0oooo
2`3AcJT2000000@0oooo0P00000:0?ooo`8000000P3oool2000000@0oooo200000020?ooo`800000
0P3oool8000000@0oooo0P0000020?ooo`8000002P3oool2000000@0oooo0P00000;0=7=Z@800000
1P3oool4000000D0oooo0P00000:0?ooo`H000000P3oool300000080oooo1P00000:0?ooo`800000
1@3oool4000000H0oooo0P00000<0=7=Z@8000001P3oool00`000000oooo0?ooo`040?ooo`@00000
0P3oool300000080oooo6@0000020?ooo`<000000P3oool4000000H0oooo0P0000050?ooo`800000
3P3AcJT000`0dLfY0P3oool2000000@0oooo1`0000020?ooo`@00000203oool2000000H0oooo0`00
00060?ooo`800000203oool400000080oooo1`0000040?ooo`8000000P3oool<0=7=Z@@0oooo1000
00020?ooo`@00000103oool800000080oooo1000000=0?ooo`@000000P3oool8000000@0oooo1000
00020?ooo`@00000103oool;0=7=Z@800000103oool2000000X0oooo0P0000020?ooo`800000103o
ool800000080oooo0P0000020?ooo`P00000103oool200000080oooo0P00000:0?ooo`800000103o
ool2000000/0dLfY0P0000040?ooo`8000000P3oool2000000030?ooo`00000000000080oooo1P00
00040?ooo`H000002`3oool6000000@0oooo1P0000020?ooo`80000000<0oooo0000000000000P3o
ool2000000@0oooo0P00000<0=7=Z@8000001P3oool00`000000oooo0?ooo`040?ooo`@000000P3o
ool300000080oooo6@0000020?ooo`<000000P3oool4000000H0oooo0P0000050?ooo`8000003P3A
cJT000`0dLfY100000020?ooo`/000001P3oool6000000P0oooo0`0000080?ooo`H000001P3oool;
00000080oooo1000000<0=7=Z@@0oooo100000020?ooo`@00000103oool800000080oooo1000000=
0?ooo`@000000P3oool8000000@0oooo100000020?ooo`@00000103oool;0=7=Z@@000000P3oool2
00000080oooo100000020?ooo`@000000P3oool400000080oooo100000060?ooo`8000001P3oool4
00000080oooo100000020?ooo`@000000P3oool400000080oooo0P0000020?ooo`@000002`3AcJT2
000000@0oooo0P0000020?ooo`80000000<0oooo0000000000000P3oool6000000@0oooo1P00000;
0?ooo`H00000103oool600000080oooo0P0000000`3oool00000000000020?ooo`800000103oool2
000000`0dLfY0P3oool2000000@0oooo00<000000?ooo`3oool00P3oool200000080oooo10000003
0?ooo`8000000P3oool400000080oooo0P0000020?ooo`030000003oool0oooo008000000P3oool4
00000080oooo0P0000030?ooo`@000000P3oool2000000@0oooo0P0000030?ooo`8000000P3oool>
0=7=Z@00303AcJT400000080oooo2`0000060?ooo`H00000203oool3000000P0oooo1P0000060?oo
o`/000000P3oool4000000`0dLfY300000020?ooo`8000000P3oool400000080oooo100000020?oo
o`@000002@3oool400000080oooo100000020?ooo`@000000P3oool200000080oooo3000000;0=7=
Z@@000000P3oool200000080oooo100000020?ooo`@000000P3oool400000080oooo100000060?oo
o`8000001P3oool400000080oooo100000020?ooo`@000000P3oool400000080oooo0P0000020?oo
o`@000002`3AcJT20?ooo`@000000P3oool200000080oooo00<000000?ooo`3oool00P0000020?oo
o`@00000103oool400000080oooo0P0000070?ooo`8000000P3oool4000000@0oooo100000020?oo
o`8000000P3oool00`000000oooo0?ooo`0200000080oooo100000020?ooo``0dLfY103oool20000
00D0oooo0P0000020?ooo`@000000P3oool700000080oooo100000040?ooo`030000003oool0oooo
0080oooo100000020?ooo`L000000P3oool400000080oooo0P0000050?ooo`800000103oool>0=7=
Z@00303AcJT400000080oooo2`0000060?ooo`H00000203oool3000000P0oooo1P0000060?ooo`/0
00000P3oool4000000`0dLfY300000020?ooo`8000000P3oool400000080oooo100000020?ooo`@0
00002@3oool400000080oooo100000020?ooo`@000000P3oool200000080oooo3000000;0=7=Z@80
oooo100000040?ooo`8000000P3oool800000080oooo100000040?ooo`@000000P3oool200000080
oooo100000040?ooo`@000000P3oool800000080oooo0P0000040?ooo`@000000P3oool;0=7=Z@80
oooo100000020?ooo`8000000P3oool00`000000oooo0?ooo`0200000080oooo100000040?ooo`@0
00000P3oool2000000L0oooo0P0000020?ooo`@00000103oool400000080oooo0P0000020?ooo`03
0000003oool0oooo008000000P3oool400000080oooo303AcJT40?ooo`8000001@3oool200000080
oooo100000020?ooo`L000000P3oool4000000@0oooo00<000000?ooo`3oool00P3oool400000080
oooo1`0000020?ooo`@000000P3oool2000000D0oooo0P0000040?ooo`h0dLfY000<0=7=Z@80oooo
100000020?ooo`8000001`3oool<00000080oooo0P0000040?ooo`<00000103oool200000080oooo
300000070?ooo`8000000P3oool400000080oooo303AcJT>00000080oooo0P0000040?ooo`P00000
103oool2000000D0oooo0P0000040?ooo`P00000103oool200000080oooo3P00000;0=7=Z@80oooo
100000040?ooo`8000000P3oool800000080oooo100000040?ooo`@000000P3oool200000080oooo
100000040?ooo`@000000P3oool800000080oooo0P0000040?ooo`@000000P3oool;0=7=Z@@0oooo
100000020?ooo`<00000103oool2000000@0oooo1000000G0?ooo`@00000103oool2000000@0oooo
0`0000020?ooo`@00000103oool<0=7=Z@@0oooo0P0000020?ooo`030000003oool0oooo00@00000
0P3oool2000000@0oooo1`0000020?ooo`800000103oool00`000000oooo0?ooo`020?ooo`800000
0P3oool7000000@0oooo0P0000020?ooo`@000000P3oool2000000030?ooo`000000000000@0oooo
3P3AcJT000`0dLfY0P3oool400000080oooo0P0000070?ooo``000000P3oool2000000@0oooo0`00
00040?ooo`8000000P3oool<000000L0oooo0P0000020?ooo`@000000P3oool<0=7=Z@h000000P3o
ool2000000@0oooo200000040?ooo`8000001@3oool2000000@0oooo200000040?ooo`8000000P3o
ool>000000/0dLfY0P3oool2000000P0oooo0P0000020?ooo`8000001P3oool600000080oooo1000
00020?ooo`8000000P3oool400000080oooo1P0000060?ooo`8000000P3oool2000000P0oooo0P00
00020?ooo`/0dLfY103oool400000080oooo0`0000040?ooo`800000103oool4000001L0oooo1000
00040?ooo`800000103oool300000080oooo100000040?ooo``0dLfY103oool200000080oooo00<0
00000?ooo`3oool0100000020?ooo`800000103oool700000080oooo0P0000040?ooo`030000003o
ool0oooo0080oooo0P0000020?ooo`L00000103oool200000080oooo100000020?ooo`80000000<0
oooo000000000000103oool>0=7=Z@00303AcJT8000000L0oooo100000040?ooo`H00000203oool3
000000P0oooo1P0000040?ooo`@000001`3oool8000000`0dLfY103oool4000000@0oooo0P000002
0?ooo`X000000P3oool4000000d0oooo100000020?ooo`X000000P3oool2000000@0oooo10000004
0?ooo`/0dLfY0P3oool2000000P0oooo0P0000020?ooo`8000001P3oool600000080oooo10000002
0?ooo`8000000P3oool400000080oooo1P0000060?ooo`8000000P3oool2000000P0oooo0P000002
0?ooo`/0dLfY103oool6000000<0oooo100000060?ooo`@000005`3oool4000000H0oooo10000003
0?ooo`H00000103oool<0=7=Z@P0oooo2@0000060?ooo`D000000P3oool200000080oooo0P000002
0?ooo`030000003oool0oooo008000000P3oool200000080oooo1@0000060?ooo`X000001`3oool>
0=7=Z@00303AcJT8000000L0oooo100000040?ooo`H00000203oool3000000P0oooo1P0000040?oo
o`@000001`3oool8000000`0dLfY103oool4000000@0oooo0P0000020?ooo`X000000P3oool40000
00d0oooo100000020?ooo`X000000P3oool2000000@0oooo100000040?ooo`/0dLfY300000060?oo
o`H00000103oool400000080oooo0P0000020?ooo`8000000P3oool200000080oooo100000040?oo
o`H000001P3oool<000000/0dLfY103oool6000000<0oooo100000060?ooo`@000005`3oool40000
00H0oooo100000030?ooo`H00000103oool<0=7=Z@P0oooo2@0000060?ooo`D000000P3oool20000
0080oooo0P0000020?ooo`030000003oool0oooo008000000P3oool200000080oooo1@0000060?oo
o`X000001`3oool>0=7=Z@00303AcJT20?ooo`8000000P3oool4000000/0oooo0P0000020?ooo`80
0000103oool400000080oooo0`0000020?ooo`@00000103oool200000080oooo0P00000;0?ooo`@0
00000P3oool200000080oooo303AcJT40?ooo`@000001P3oool:00000080oooo1P00000=0?ooo`H0
00000P3oool:000000H0oooo100000040?ooo`/0dLfY300000060?ooo`H00000103oool400000080
oooo0P0000020?ooo`8000000P3oool200000080oooo100000040?ooo`H000001P3oool<000000/0
dLfY100000040?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`H00000103oool4000000@0
oooo1`0000040?ooo`@00000103oool6000000@0oooo00<000000?ooo`3oool00P0000040?ooo`@0
0000303AcJT400000080oooo0`0000080?ooo`H000000`3oool200000080oooo1P0000020?ooo`03
0000003oool0oooo00H000000P3oool2000000<0oooo1P0000080?ooo`<000000P3oool4000000h0
dLfY000<0=7=Z@80oooo0P0000020?ooo`@000002`3oool200000080oooo0P0000040?ooo`@00000
0P3oool300000080oooo100000040?ooo`8000000P3oool2000000/0oooo100000020?ooo`800000
0P3oool<0=7=Z@@0oooo100000060?ooo`X000000P3oool6000000d0oooo1P0000020?ooo`X00000
1P3oool4000000@0oooo2`3AcJT200000080oooo100000060?ooo`@000000P3oool400000080oooo
0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000000P3oool400000080oooo
100000060?ooo`@000000P3oool2000000/0dLfY100000040?ooo`8000000P3oool00`000000oooo
0?ooo`020?ooo`H00000103oool4000000@0oooo1`0000040?ooo`@00000103oool6000000@0oooo
00<000000?ooo`3oool00P0000040?ooo`@00000303AcJT400000080oooo0`0000080?ooo`H00000
0`3oool200000080oooo1P0000020?ooo`030000003oool0oooo00H000000P3oool2000000<0oooo
1P0000080?ooo`<000000P3oool4000000h0dLfY000<0=7=Z@8000000P3oool2000000d0oooo0P00
00040?ooo`8000000P3oool600000080oooo0`0000020?ooo`H000000P3oool2000000@0oooo0P00
000=0?ooo`8000000P3oool2000000`0dLfY103oool200000080oooo0P0000040?ooo`X000000P3o
ool400000080oooo0P0000090?ooo`8000000P3oool400000080oooo2P0000040?ooo`8000000P3o
ool2000000@0oooo2`3AcJT200000080oooo100000060?ooo`@000000P3oool400000080oooo0P00
00040?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000000P3oool400000080oooo1000
00060?ooo`@000000P3oool2000000/0dLfY100000060?ooo`80000000<0oooo0000000000000P00
00020?ooo`@00000103oool4000000@0oooo1`0000040?ooo`@00000103oool400000080oooo1000
00000`3oool00000000000060?ooo`@00000303AcJT40?ooo`8000001@3oool200000080oooo2000
00050?ooo`8000000P3oool=00000080oooo0P0000050?ooo`P000000P3oool2000000D0oooo0P00
00040?ooo`h0dLfY000<0=7=Z@8000000P3oool2000000d0oooo0P0000040?ooo`8000000P3oool6
00000080oooo0`0000020?ooo`H000000P3oool2000000@0oooo0P00000=0?ooo`8000000P3oool2
000000`0dLfY103oool200000080oooo0P0000040?ooo`X000000P3oool400000080oooo0P000009
0?ooo`8000000P3oool400000080oooo2P0000040?ooo`8000000P3oool2000000@0oooo2`3AcJT:
0?ooo`8000001P3oool200000080oooo0P0000020?ooo`P00000103oool2000000@0oooo20000002
0?ooo`8000000P3oool2000000H0oooo0P00000:0?ooo`/0dLfY100000060?ooo`80000000<0oooo
0000000000000P0000020?ooo`@00000103oool4000000@0oooo1`0000040?ooo`@00000103oool4
00000080oooo100000000`3oool00000000000060?ooo`@00000303AcJT40?ooo`8000001@3oool2
00000080oooo200000050?ooo`8000000P3oool=00000080oooo0P0000050?ooo`P000000P3oool2
000000D0oooo0P0000040?ooo`h0dLfY000<0=7=Z@8000000P3oool2000000/0oooo0P0000040?oo
o`@000000P3oool2000000H0oooo0`0000060?ooo`8000000P3oool4000000@0oooo0P00000;0?oo
o`8000000P3oool2000000`0dLfY103oool200000080oooo0P0000040?ooo`X000000P3oool40000
0080oooo0P0000090?ooo`8000000P3oool400000080oooo2P0000040?ooo`8000000P3oool20000
00@0oooo2`3AcJT:0?ooo`8000001P3oool200000080oooo0P0000020?ooo`P00000103oool20000
00@0oooo200000020?ooo`8000000P3oool2000000H0oooo0P00000:0?ooo`/0dLfY2P0000050?oo
o`@000000P3oool200000080oooo0P0000020?ooo`@00000103oool3000000@0oooo100000020?oo
o`8000000P3oool200000080oooo100000050?ooo`X00000303AcJT400000080oooo0`0000020?oo
o``0000000<0oooo0000000000001P0000020?ooo`8000000P3oool00`000000oooo0?ooo`020000
0080oooo200000000`3oool000000000000:00000080oooo0`0000020?ooo`@000003P3AcJT000`0
dLfY0P0000020?ooo`8000002`3oool2000000@0oooo100000020?ooo`8000001P3oool3000000H0
oooo0P0000020?ooo`@00000103oool2000000/0oooo0P0000020?ooo`800000303AcJT60?ooo`80
00000P3oool400000080oooo2P0000040?ooo`8000000P3oool2000000D0oooo0P0000020?ooo`80
0000103oool:00000080oooo100000020?ooo`8000001P3oool;0=7=Z@8000000P3oool400000080
oooo200000020?ooo`8000000P3oool6000000@0oooo0P0000020?ooo`8000000P3oool2000000@0
oooo1P0000020?ooo`8000000P3oool800000080oooo100000020?ooo`8000002`3AcJT800000080
oooo0P0000030?ooo`H000000P3oool200000080oooo0P0000040?ooo`@000000`3oool4000000@0
oooo0P0000020?ooo`8000000P3oool6000000<0oooo0P0000020?ooo`P00000303AcJT400000080
oooo0`0000020?ooo``0000000<0oooo0000000000001P0000020?ooo`8000000P3oool00`000000
oooo0?ooo`0200000080oooo200000000`3oool000000000000:00000080oooo0`0000020?ooo`@0
00003P3AcJT000`0dLfY0P0000020?ooo`800000103oool300000080oooo0P0000060?ooo`800000
0P3oool200000080oooo0P0000040?ooo`<00000103oool200000080oooo0P0000020?ooo`800000
1P3oool2000000<0oooo0P0000040?ooo`8000000P3oool2000000`0dLfY1P3oool200000080oooo
100000020?ooo`X00000103oool200000080oooo0P0000050?ooo`8000000P3oool2000000@0oooo
2P0000020?ooo`@000000P3oool2000000H0oooo2`3AcJT200000080oooo100000020?ooo`P00000
0P3oool200000080oooo1P0000040?ooo`8000000P3oool200000080oooo0P0000040?ooo`H00000
0P3oool200000080oooo200000020?ooo`@000000P3oool2000000/0dLfY200000020?ooo`800000
0`3oool600000080oooo0P0000020?ooo`800000103oool4000000<0oooo100000040?ooo`800000
0P3oool200000080oooo1P0000030?ooo`8000000P3oool8000000`0dLfY100000020?ooo`800000
1@3oool800000080oooo00<000000?ooo`3oool00P0000020?ooo`@000000P3oool500000080oooo
100000020?ooo`8000000P3oool00`000000oooo0?ooo`08000000H0oooo00<000000?ooo`3oool0
1000000>0=7=Z@00303AcJT200000080oooo0P0000040?ooo`<000000P3oool2000000H0oooo0P00
00020?ooo`8000000P3oool2000000@0oooo0`0000040?ooo`8000000P3oool200000080oooo0P00
00060?ooo`8000000`3oool2000000@0oooo0P0000020?ooo`800000303AcJT200000080oooo1000
00040?ooo`@000000P3oool4000000@0oooo0P0000020?ooo`8000000P3oool900000080oooo0P00
00020?ooo`800000103oool400000080oooo100000040?ooo`@000000P3oool2000000/0dLfY0P00
00040?ooo`8000000P3oool800000080oooo0P0000040?ooo`8000001P3oool:000000H0oooo0P00
00040?ooo`8000000P3oool800000080oooo0P0000040?ooo`8000002`3AcJT200000080oooo1000
00040?ooo`<00000103oool200000080oooo0P0000040?ooo`8000001P3oool3000000H0oooo0P00
00040?ooo`8000000P3oool2000000@0oooo0`0000040?ooo`@000000P3oool2000000`0dLfY1000
00020?ooo`8000001@3oool800000080oooo00<000000?ooo`3oool00P0000020?ooo`@000000P3o
ool500000080oooo100000020?ooo`8000000P3oool00`000000oooo0?ooo`08000000H0oooo00<0
00000?ooo`3oool01000000>0=7=Z@00303AcJT20?ooo`H000000P3oool5000000`0oooo10000004
0?ooo`L00000103oool4000000`0oooo1@0000020?ooo`H000000P3oool<0=7=Z@8000000P3oool4
000000@0oooo100000020?ooo`@00000103oool200000080oooo0P0000020?ooo`T000000P3oool2
00000080oooo0P0000040?ooo`@000000P3oool4000000@0oooo100000020?ooo`8000002`3AcJT2
000000@0oooo0P0000020?ooo`P000000P3oool2000000@0oooo0P0000060?ooo`X000001P3oool2
000000@0oooo0P0000020?ooo`P000000P3oool2000000@0oooo0P00000;0=7=Z@8000000P3oool4
000000@0oooo0`0000040?ooo`8000000P3oool2000000@0oooo0P0000060?ooo`<000001P3oool2
000000@0oooo0P0000020?ooo`800000103oool3000000@0oooo100000020?ooo`800000303AcJT2
00000080oooo0P0000020?ooo`/00000103oool300000080oooo0P0000080?ooo`030000003oool0
oooo00H0oooo0P0000020?ooo`<00000103oool<000000030?ooo`00000000000080oooo0P00000>
0=7=Z@00303AcJT20?ooo`H000000P3oool5000000`0oooo100000040?ooo`L00000103oool40000
00`0oooo1@0000020?ooo`H000000P3oool<0=7=Z@80oooo1P0000040?ooo`H00000103oool40000
0080oooo0P0000020?ooo`8000000P3oool500000080oooo0P0000020?ooo`8000000P3oool40000
00@0oooo1P0000040?ooo`H000000P3oool;0=7=Z@P0oooo2P0000060?ooo`8000000P3oool20000
00@0oooo0P0000020?ooo`8000000P3oool2000000@0oooo0P0000020?ooo`8000001P3oool:0000
00P0oooo2`3AcJT20?ooo`H00000103oool3000000H0oooo0P0000020?ooo`@000001P3oool20000
00<0oooo0P0000060?ooo`@000000P3oool2000000H0oooo0`0000040?ooo`H000000P3oool<0=7=
Z@8000000P3oool200000080oooo2`0000040?ooo`<000000P3oool2000000P0oooo00<000000?oo
o`3oool01P3oool200000080oooo0`0000040?ooo``0000000<0oooo0000000000000P3oool20000
00h0dLfY000<0=7=Z@H0oooo0P0000020?ooo`L000002P3oool400000080oooo0P0000020?ooo`<0
00000P3oool200000080oooo1000000:0?ooo`L000000P3oool2000000H0oooo303AcJT20?ooo`H0
0000103oool6000000@0oooo100000020?ooo`8000000P3oool200000080oooo1@0000020?ooo`80
00000P3oool200000080oooo100000040?ooo`H00000103oool600000080oooo2`3AcJT80?ooo`X0
00001P3oool200000080oooo0P0000040?ooo`8000000P3oool200000080oooo0P0000040?ooo`80
00000P3oool2000000H0oooo2P0000080?ooo`/0dLfY0P3oool6000000@0oooo0`0000060?ooo`80
00000P3oool4000000H0oooo0P0000030?ooo`8000001P3oool400000080oooo0P0000060?ooo`<0
0000103oool600000080oooo303AcJT6000000D0oooo100000020?ooo`@000000P3oool5000000H0
oooo0P0000020?ooo`030000003oool0oooo008000001P3oool500000080oooo100000020?ooo`@0
00001@3oool6000000h0dLfY000<0=7=Z@H0oooo0P0000020?ooo`L000002P3oool400000080oooo
0P0000020?ooo`<000000P3oool200000080oooo1000000:0?ooo`L000000P3oool2000000H0oooo
303AcJT<000000@0oooo0P0000060?ooo`H00000103oool9000000@0oooo1P0000060?ooo`800000
103oool<000000/0dLfY0P3oool2000000H0oooo2P0000020?ooo`8000000P3oool400000080oooo
0P0000040?ooo`800000103oool200000080oooo100000020?ooo`8000000P3oool:000000H0oooo
0P0000020?ooo`/0dLfY100000040?ooo`@000000`3oool200000080oooo0P0000040?ooo`800000
0P3ooolC00000080oooo0P0000040?ooo`8000000P3oool2000000<0oooo100000040?ooo`@00000
303AcJT6000000D0oooo100000020?ooo`@000000P3oool5000000H0oooo0P0000020?ooo`030000
003oool0oooo008000001P3oool500000080oooo100000020?ooo`@000001@3oool6000000h0dLfY
000<0=7=Z@800000103oool4000000/0oooo0P0000020?ooo`H000000P3oool200000080oooo0`00
00020?ooo`8000000P3oool600000080oooo0P00000;0?ooo`@00000103oool2000000`0dLfY3000
00040?ooo`8000001P3oool6000000@0oooo2@0000040?ooo`H000001P3oool2000000@0oooo3000
000;0=7=Z@80oooo0P0000060?ooo`X000000P3oool200000080oooo100000020?ooo`800000103o
ool2000000@0oooo0P0000020?ooo`@000000P3oool200000080oooo2P0000060?ooo`8000000P3o
ool;0=7=Z@@00000103oool4000000<0oooo0P0000020?ooo`800000103oool200000080oooo4`00
00020?ooo`800000103oool200000080oooo0P0000030?ooo`@00000103oool4000000`0dLfY103o
ool200000080oooo0`0000020?ooo`800000203oool00`000000oooo0?ooo`060?ooo`8000000P3o
ool500000080oooo0P0000080?ooo`030000003oool0oooo00H0oooo0P0000020?ooo`@0000000<0
oooo000000000000103oool>0=7=Z@00303AcJT2000000@0oooo1000000;0?ooo`8000000P3oool6
00000080oooo0P0000020?ooo`<000000P3oool200000080oooo1P0000020?ooo`8000002`3oool4
000000@0oooo0P00000<0=7=Z@`000001P3oool2000000@0oooo100000020?ooo`@000000P3oool5
00000080oooo100000020?ooo`@00000103oool2000000H0oooo3000000;0=7=Z@80oooo0P000004
0?ooo`8000000P3oool2000000P0oooo0P0000080?ooo`8000000P3oool600000080oooo0P000008
0?ooo`800000203oool200000080oooo0P0000040?ooo`8000000P3oool;0=7=Z@@00000103oool4
000000D0oooo0P0000020?ooo`@000000P3oool200000080oooo3`0000020?ooo`8000000P3oool4
00000080oooo0P0000050?ooo`@00000103oool4000000`0dLfY100000040?ooo`<000000P3oool2
00000080oooo0P0000020?ooo`D000000P3ooolE00000080oooo1@0000020?ooo`8000000P3oool2
00000080oooo100000030?ooo`@000003P3AcJT000`0dLfY0P0000040?ooo`@000002`3oool20000
0080oooo1P0000020?ooo`8000000P3oool300000080oooo0P0000020?ooo`H000000P3oool20000
00/0oooo100000040?ooo`800000303AcJT<000000H0oooo0P0000040?ooo`@000000P3oool40000
0080oooo1@0000020?ooo`@000000P3oool4000000@0oooo0P0000060?ooo``000002`3AcJT20?oo
o`800000103oool200000080oooo0P0000080?ooo`800000203oool200000080oooo1P0000020?oo
o`800000203oool2000000P0oooo0P0000020?ooo`800000103oool200000080oooo2`3AcJT40000
00@0oooo100000050?ooo`8000000P3oool400000080oooo0P0000020?ooo`l000000P3oool20000
0080oooo100000020?ooo`8000001@3oool4000000@0oooo1000000<0=7=Z@@00000103oool30000
0080oooo0P0000020?ooo`8000000P3oool500000080oooo5@0000020?ooo`D000000P3oool20000
0080oooo0P0000020?ooo`@000000`3oool4000000h0dLfY000<0=7=Z@800000103oool9000000H0
oooo100000020?ooo`8000000P3oool2000000@0oooo0`0000040?ooo`8000000P3oool200000080
oooo100000060?ooo`T00000103oool2000000`0dLfY0P0000020?ooo`h000000P3ooolU00000080
oooo3P0000020?ooo`8000002`3AcJT20?ooo`H000001P3oool400000080oooo100000040?ooo`H0
00000P3oool600000080oooo1P0000040?ooo`@000000P3oool4000000H0oooo1P0000020?ooo`/0
dLfY0P3oool6000000@0oooo1`0000040?ooo`@000000P3oool2000000@0oooo1`0000040?ooo`80
00000P3oool4000000@0oooo1`0000040?ooo`H000000P3oool<0=7=Z@800000103oool2000000L0
oooo100000020?ooo`8000002@3oool200000080oooo1@0000020?ooo`8000002@3oool200000080
oooo100000080?ooo`030000003oool0oooo0080oooo0P00000>0=7=Z@00303AcJT2000000@0oooo
2@0000060?ooo`@000000P3oool200000080oooo0P0000040?ooo`<00000103oool200000080oooo
0P0000020?ooo`@000001P3oool9000000@0oooo0P00000<0=7=Z@8000000P3oool>00000080oooo
9@0000020?ooo`h000000P3oool2000000/0dLfY0P3oool6000000H0oooo100000020?ooo`@00000
103oool600000080oooo1P0000020?ooo`H00000103oool400000080oooo100000060?ooo`H00000
0P3oool;0=7=Z@80oooo1P0000040?ooo`L00000103oool400000080oooo0P0000040?ooo`L00000
103oool200000080oooo100000040?ooo`L00000103oool600000080oooo303AcJT2000000@0oooo
0P0000070?ooo`@000000P3oool2000000T0oooo0P0000020?ooo`D000000P3oool2000000T0oooo
0P0000020?ooo`@00000203oool00`000000oooo0?ooo`020?ooo`8000003P3AcJT000`0dLfY1P00
00070?ooo`P000000P3oool4000000X0oooo0`00000:0?ooo`@000000P3oool9000000H0oooo1P00
000<0=7=Z@80oooo3P0000020?ooobT000000P3oool>00000080oooo2`3AcJT40?ooo`@00000203o
ool200000080oooo100000020?ooo`800000103oool200000080oooo1P0000020?ooo`800000103o
ool200000080oooo100000020?ooo`800000203oool4000000@0oooo2`3AcJT200000080oooo1000
00040?ooo`L00000103oool6000000H0oooo1`0000060?ooo`H00000103oool7000000@0oooo1000
00020?ooo`800000303AcJT40?ooo`8000000`3oool6000000@0oooo0P0000030?ooo`@000001P3o
ool200000080oooo00<000000?ooo`3oool00P0000060?ooo`@000000`3oool2000000@0oooo1P00
00030?ooo`800000103oool>0=7=Z@00303AcJT6000000L0oooo200000020?ooo`@000002P3oool3
000000X0oooo100000020?ooo`T000001P3oool6000000`0dLfY0P3oool>00000080oooo:@000002
0?ooo`h000000P3oool;0=7=Z@@0oooo100000080?ooo`8000000P3oool400000080oooo0P000004
0?ooo`8000000P3oool600000080oooo0P0000040?ooo`8000000P3oool400000080oooo0P000008
0?ooo`@00000103oool;0=7=Z@8000000P3oool4000000@0oooo1`0000040?ooo`H000001P3oool7
000000H0oooo1P0000040?ooo`L00000103oool400000080oooo0P00000<0=7=Z@@0oooo0P000003
0?ooo`H00000103oool2000000<0oooo100000060?ooo`8000000P3oool00`000000oooo0?ooo`02
000000H0oooo100000030?ooo`800000103oool6000000<0oooo0P0000040?ooo`h0dLfY000<0=7=
Z@H000001`3oool2000000H0oooo2P0000060?ooo`<000001P3oool:000000H0oooo0`0000060?oo
o`H00000303AcJT20?ooo`@000000P3oool6000000X0oooo100000080?ooo`D00000203oool40000
00X0oooo1P0000020?ooo`@000000P3oool;0=7=Z@@000000P3oool6000000X0oooo200000080?oo
o`800000203oool8000000X0oooo1P0000020?ooo`@000002`3AcJT20?ooo`8000000P3oool70000
0080oooo200000040?ooo`800000103oool4000000<0oooo100000040?ooo`800000103oool80000
0080oooo1`0000020?ooo`8000000P3oool<0=7=Z@80oooo0P0000040?ooo`030000003oool0oooo
008000000P3oool400000080oooo0P0000050?ooo`800000203oool00`000000oooo0?ooo`060?oo
o`8000001@3oool200000080oooo100000020?ooo`8000000P3oool2000000<0oooo0P0000020?oo
o`h0dLfY000<0=7=Z@H000001`3oool2000000H0oooo2P0000060?ooo`<000001P3oool:000000H0
oooo0`0000060?ooo`H00000303AcJT20?ooo`@000000P3oool6000000X0oooo100000080?ooo`D0
0000203oool4000000X0oooo1P0000020?ooo`@000000P3oool;0=7=Z@@000000P3oool6000000X0
oooo200000080?ooo`800000203oool8000000X0oooo1P0000020?ooo`@000002`3AcJT20?ooo`80
00000P3oool700000080oooo200000040?ooo`800000103oool4000000<0oooo100000040?ooo`80
0000103oool800000080oooo1`0000020?ooo`8000000P3oool<0=7=Z@80oooo0P0000040?ooo`03
0000003oool0oooo008000000P3oool400000080oooo0P0000050?ooo`800000203oool00`000000
oooo0?ooo`060?ooo`8000001@3oool200000080oooo100000020?ooo`8000000P3oool2000000<0
oooo0P0000020?ooo`h0dLfY000<0=7=Z@X000001@3oool600000080oooo0P0000020?ooo`800000
103oool200000080oooo0`0000020?ooo`800000103oool200000080oooo0P0000020?ooo`H00000
1@3oool:000000`0dLfY0P0000040?ooo`H000000P3oool2000000P0oooo100000080?ooo`D00000
203oool4000000P0oooo0P0000020?ooo`H00000103oool2000000/0dLfY1000000:0?ooo`@00000
0P3oool4000000@0oooo100000060?ooo`8000001P3oool4000000@0oooo100000020?ooo`@00000
2P3oool4000000/0dLfY0P0000020?ooo`8000000P3oool4000000030?ooo`000000000000P00000
1P3oool4000000@0oooo0`0000040?ooo`@000001P3oool:000000030?ooo`000000000000800000
0P3oool200000080oooo0P00000<0=7=Z@800000103oool300000080oooo200000020?ooo`800000
1`3oool400000080oooo1@0000020?ooo`@000001`3oool200000080oooo200000020?ooo`<00000
103oool2000000h0dLfY000<0=7=Z@X000001@3oool600000080oooo0P0000020?ooo`800000103o
ool200000080oooo0`0000020?ooo`800000103oool200000080oooo0P0000020?ooo`H000001@3o
ool:000000`0dLfY0P0000040?ooo`H000000P3oool2000000P0oooo100000080?ooo`D00000203o
ool4000000P0oooo0P0000020?ooo`H00000103oool2000000/0dLfY1000000:0?ooo`@000000P3o
ool4000000@0oooo100000060?ooo`8000001P3oool4000000@0oooo100000020?ooo`@000002P3o
ool4000000/0dLfY0P0000020?ooo`8000000P3oool4000000030?ooo`000000000000P000001P3o
ool4000000@0oooo0`0000040?ooo`@000001P3oool:000000030?ooo`0000000000008000000P3o
ool200000080oooo0P00000<0=7=Z@800000103oool300000080oooo200000020?ooo`8000001`3o
ool400000080oooo1@0000020?ooo`@000001`3oool200000080oooo200000020?ooo`<00000103o
ool2000000h0dLfY003o0=7=ZL/0dLfY003o0=7=ZL/0dLfY003o0=7=ZL/0dLfY003o0=7=ZL/0dLfY
003o0=7=ZL/0dLfY003o0=7=ZL/0dLfY003o0=7=ZL/0dLfY003o0=7=ZL/0dLfY003o0=7=ZL/0dLfY
003o0=7=ZL/0dLfY003o0=7=ZL/0dLfY000<0=7=Z@8000000`3oool5000000@0oooo200000020?oo
o`8000000`3oool500000080oooo1@0000020?ooo`D000000`3oool200000080oooo200000040?oo
o`D000000`3oool2000000`0dLfY0P3oool3000000T0oooo1@0000020?ooo`8000000`3oool20000
0080oooo3P00000Q0?ooo`/0dLfY1@0000060?ooo`<00000103oool3000000@0oooo0`0000060?oo
o`<00000:@3oool;0=7=Z@L000000P3oool4000000D0oooo0P0000020?ooo`@000000`3oool40000
0080oooo0P0000070?ooo`L000006P3oool<0=7=Z@8000000P3oool2000000D0oooo0P0000020?oo
o`@000001@3oool2000000H0oooo100000050?ooo`@000001P3oool2000000D0oooo100000020?oo
o`8000001@3oool200000080oooo0P00000>0=7=Z@00303AcJT2000000<0oooo1@0000040?ooo`P0
00000P3oool2000000<0oooo1@0000020?ooo`D000000P3oool5000000<0oooo0P0000020?ooo`P0
0000103oool5000000<0oooo0P00000<0=7=Z@80oooo0`0000090?ooo`D000000P3oool2000000<0
oooo0P0000020?ooo`h000008@3oool;0=7=Z@D000001P3oool3000000@0oooo0`0000040?ooo`<0
00001P3oool3000002T0oooo2`3AcJT700000080oooo100000050?ooo`8000000P3oool4000000<0
oooo100000020?ooo`8000001`3oool7000001X0oooo303AcJT200000080oooo0P0000050?ooo`80
00000P3oool4000000D0oooo0P0000060?ooo`@000001@3oool4000000H0oooo0P0000050?ooo`@0
00000P3oool2000000D0oooo0P0000020?ooo`8000003P3AcJT000`0dLfY0P3oool8000000@0oooo
1@0000030?ooo`8000000P3oool:000000D0oooo2P0000020?ooo`8000000`3oool5000000@0oooo
200000020?ooo``0dLfY2@3oool7000000D0oooo0P0000050?oooa0000000`3oool4000000<0oooo
0P0000050?ooo`8000001@3oool200000080oooo1@00000;0=7=Z@80oooo3P0000070?ooo`800000
0`3oool2000000L0oooo100000030?ooo`@000000P3oool300000080oooo0P00000C0?ooo`800000
2`3AcJT9000000@0oooo0P0000050?ooo`8000000P3oool5000000H0oooo0P0000030?ooo`800000
103oool9000000@0oooo0`0000060?ooo`8000001`3oool<0=7=Z@80oooo0P0000020?ooo`D00000
0P3oool2000000@0oooo1@0000060?ooo`800000103oool5000000@0oooo0P0000060?ooo`D00000
103oool200000080oooo1@0000020?ooo`8000000P3oool>0=7=Z@00303AcJT20?ooo`P00000103o
ool5000000<0oooo0P0000020?ooo`X000001@3oool:00000080oooo0P0000030?ooo`D00000103o
ool800000080oooo303AcJT90?ooo`L000001@3oool2000000D0oooo400000030?ooo`@000000`3o
ool2000000D0oooo0P0000050?ooo`8000000P3oool5000000/0dLfY0P3oool>000000L0oooo0P00
00030?ooo`8000001`3oool4000000<0oooo100000020?ooo`<000000P3oool2000001<0oooo0P00
000;0=7=Z@T00000103oool2000000D0oooo0P0000020?ooo`D000001P3oool2000000<0oooo0P00
00040?ooo`T00000103oool3000000H0oooo0P0000070?ooo``0dLfY0P3oool200000080oooo1@00
00020?ooo`800000103oool5000000H0oooo0P0000040?ooo`D00000103oool2000000H0oooo1@00
00040?ooo`8000000P3oool500000080oooo0P0000020?ooo`h0dLfY000<0=7=Z@80oooo20000004
0?ooo`D000000`3oool200000080oooo2P0000050?ooo`X000000P3oool2000000<0oooo1@000004
0?ooo`P000000P3oool<0=7=Z@T0oooo1`0000050?ooo`8000001@3oool@000000<0oooo10000003
0?ooo`8000001@3oool2000000D0oooo0P0000020?ooo`D000002`3AcJT20?ooo`h000001`3oool2
000000<0oooo0P0000070?ooo`@000000`3oool400000080oooo0`0000020?ooo`8000004`3oool2
000000/0dLfY100000090?ooo`L000000P3oool4000000D0oooo0P0000040?ooo`/000002@3oool2
000000D0oooo100000050?ooo`8000000P3oool<0=7=Z@8000000P3oool900000080oooo1P000005
0?ooo`@00000103oool2000000D0oooo0P0000040?ooo`@000001@3oool600000080oooo2@000002
0?ooo`8000003P3AcJT000`0dLfY2P0000040?ooo`<000001@3oool4000000D0oooo3`0000050?oo
o`@000001@3oool3000000@0oooo2P00000<0=7=Z@h000004`3oool200000080oooo0`0000070?oo
o`8000000P3oool300000080oooo0P0000030?oooa0000002`3AcJT500000080oooo1000000<0?oo
o`8000000`3oool2000000@0oooo1@0000020?ooo``000001`3oool2000000D0oooo100000020?oo
o`D000002`3AcJT4000000T0oooo1`0000020?ooo`@000001@3oool2000000@0oooo2`0000090?oo
o`8000001@3oool4000000D0oooo0P0000020?ooo``0dLfY0P0000020?ooo`T000000P3oool60000
00D0oooo100000040?ooo`8000001@3oool2000000@0oooo100000050?ooo`H000000P3oool90000
0080oooo0P00000>0=7=Z@00303AcJT:000000@0oooo0`0000050?ooo`@000001@3oool?000000D0
oooo100000050?ooo`<00000103oool:000000`0dLfY3P00000C0?ooo`8000000P3oool3000000L0
oooo0P0000020?ooo`<000000P3oool2000000<0oooo4000000;0=7=Z@D000000P3oool4000000`0
oooo0P0000030?ooo`800000103oool500000080oooo300000070?ooo`8000001@3oool400000080
oooo1@00000;0=7=Z@@000002@3oool700000080oooo100000050?ooo`800000103oool;000000T0
oooo0P0000050?ooo`@000001@3oool200000080oooo303AcJT200000080oooo2@0000020?ooo`H0
00001@3oool4000000@0oooo0P0000050?ooo`800000103oool4000000D0oooo1P0000020?ooo`T0
00000P3oool2000000h0dLfY000<0=7=Z@X000001`3oool5000000@0oooo1@0000030?ooo`T00000
0`3oool5000000@0oooo1@0000070?ooo`X00000303AcJT70?ooo`8000000`3oool2000000D0oooo
0P0000020?ooo`D000000P3oool300000080oooo0P0000050?ooo``000000P3oool<00000080oooo
1@0000020?ooo`/0dLfY0P3oool5000000L0oooo0P0000020?ooo`<000000P3oool2000000D0oooo
0P0000050?ooo`@000001@3oool200000080oooo2P0000070?ooo`H000000`3oool2000000/0dLfY
0P3oool2000000D0oooo1P0000030?ooo`800000103oool700000080oooo100000030?ooo`H00000
2`3oool5000000@0oooo2@0000020?ooo``0dLfY0P3oool=00000080oooo100000050?ooo`@00000
1P3oool5000000H0oooo100000050?ooo`@000000P3oool=00000080oooo3P3AcJT000`0dLfY2P00
00070?ooo`D00000103oool5000000<0oooo2@0000030?ooo`D00000103oool5000000L0oooo2P00
000<0=7=Z@L0oooo0P0000030?ooo`8000001@3oool200000080oooo1@0000020?ooo`<000000P3o
ool2000000D0oooo300000020?ooo``000000P3oool500000080oooo2`3AcJT20?ooo`D000001`3o
ool200000080oooo0`0000020?ooo`8000001@3oool2000000D0oooo100000050?ooo`8000000P3o
ool:000000L0oooo1P0000030?ooo`8000002`3AcJT20?ooo`8000001@3oool6000000<0oooo0P00
00040?ooo`L000000P3oool4000000<0oooo1P00000;0?ooo`D00000103oool900000080oooo303A
cJT20?ooo`d000000P3oool4000000D0oooo100000060?ooo`D000001P3oool4000000D0oooo1000
00020?ooo`d000000P3oool>0=7=Z@00303AcJT:000000L0oooo1@0000040?ooo`D000000`3oool9
000000<0oooo1@0000040?ooo`D000001`3oool:000000`0dLfY1@0000020?ooo`8000002P3oool7
00000080oooo1@0000020?ooo`8000001`3oool5000000D0oooo0P0000050?ooo`8000000P3oool5
00000080oooo1@00000;0=7=Z@L00000103oool300000080oooo1@0000020?ooo`L00000103oool5
00000080oooo0`0000020?ooo`8000000P3oool300000080oooo2@0000030?ooo`T000000P3oool;
0=7=Z@@0oooo0`0000020?ooo`@000001@3oool2000000H0oooo1@0000060?ooo`D000000P3oool2
00000080oooo0`0000040?ooo`8000001@3oool600000080oooo0`0000020?ooo`800000303AcJT2
0?oooa<000000`3oool2000000H0oooo3@0000060?ooo`8000000`3ooolC00000080oooo3P3AcJT0
00`0dLfY2P3oool<00000080oooo1@0000020?ooo`<000002@3oool300000080oooo1@0000020?oo
o``000002P3oool<0=7=Z@D000000P3oool2000000X0oooo1`0000020?ooo`D000000P3oool20000
00L0oooo1@0000050?ooo`8000001@3oool200000080oooo1@0000020?ooo`D000002`3AcJT70000
00@0oooo0`0000020?ooo`D000000P3oool7000000@0oooo1@0000020?ooo`<000000P3oool20000
0080oooo0`0000020?ooo`T000000`3oool900000080oooo2`3AcJT40?ooo`<000000P3oool40000
00D0oooo0P0000060?ooo`D000001P3oool500000080oooo0P0000020?ooo`<00000103oool20000
00D0oooo1P0000020?ooo`<000000P3oool2000000`0dLfY0P3ooolC000000<0oooo0P0000060?oo
o`d000001P3oool2000000<0oooo4`0000020?ooo`h0dLfY000<0=7=Z@X0oooo300000020?ooo`D0
00000P3oool3000000T0oooo0`0000020?ooo`D000000P3oool<000000X0oooo303AcJT500000080
oooo0P00000:0?ooo`L000000P3oool500000080oooo0P0000070?ooo`D000001@3oool2000000D0
oooo0P0000020?ooo`D000000P3oool5000000/0dLfY0P3oool3000000T0oooo100000030?ooo`80
00001@3oool6000000<0oooo1`0000040?ooo`8000004@3oool200000080oooo1`00000;0=7=Z@L0
00000P3oool6000000D0oooo2@0000020?ooo`8000000P3oool=000000D0oooo0P0000020?ooo`80
00001@3oool4000000T0oooo303AcJT200000080oooo500000060?ooo`8000000P3oool900000080
oooo0P0000060?oooa@000000P3oool2000000h0dLfY000<0=7=Z@X0oooo2@0000030?ooo`T00000
3`3oool9000000<0oooo2@00000:0?ooo``0dLfY0P00000:0?ooo`8000000P3oool300000080oooo
1@0000070?ooo`@000000`3oool;000000D0oooo0P0000050?ooo``000000P3oool;0=7=Z@80oooo
0`0000090?ooo`@000000`3oool2000000D0oooo1P0000030?ooo`L00000103oool200000140oooo
0P0000020?ooo`L000002`3AcJT700000080oooo1P0000050?ooo`T000000P3oool200000080oooo
3@0000050?ooo`8000000P3oool2000000D0oooo100000090?ooo``0dLfY0P0000020?oooa@00000
1P3oool200000080oooo2@0000020?ooo`8000001P3ooolD00000080oooo0P00000>0=7=Z@00303A
cJT:0?ooo`T000000`3oool9000000l0oooo2@0000030?ooo`T000002P3oool<0=7=Z@8000002P3o
ool200000080oooo0`0000020?ooo`D000001`3oool4000000<0oooo2`0000050?ooo`8000001@3o
ool<00000080oooo2`3AcJT20?ooo`<000002@3oool4000000<0oooo0P0000050?ooo`H000000`3o
ool7000000@0oooo0P00000A0?ooo`8000000P3oool7000000/0dLfY2@0000040?ooo`T000001`3o
ool2000000H0oooo0`0000020?ooo`d000000P3oool2000000D0oooo2@0000020?ooo`800000303A
cJT20?ooo`8000000P3oool;000000L0oooo0P0000020?ooo`8000000P3oool2000000T0oooo0P00
00020?ooo`8000000P3oool2000000L0oooo2`0000020?ooo`8000000P3oool>0=7=Z@00303AcJT:
0?ooo`T000000`3oool9000000l0oooo2@0000030?ooo`T000002P3oool<0=7=Z@80oooo2P000002
0?ooo``00000103oool3000000/0oooo0`0000040?ooo`D000001@3oool4000000L0oooo1@00000;
0=7=Z@8000002@3oool300000080oooo1@0000070?ooo`8000000P3oool5000000@0oooo0`000002
0?ooo`8000000P3oool7000000<0oooo1`00000;0?ooo`/0dLfY2@0000040?ooo`T000001`3oool2
000000H0oooo0`0000020?ooo`d000000P3oool2000000D0oooo2@0000020?ooo`800000303AcJT2
0?ooo`8000000P3oool;000000L0oooo0P0000020?ooo`8000000P3oool2000000T0oooo0P000002
0?ooo`8000000P3oool2000000L0oooo2`0000020?ooo`8000000P3oool>0=7=Z@00303AcJT70000
00<0oooo2@00000W0?ooo`T000000`3oool7000000`0dLfY0P3oool:00000080oooo300000040?oo
o`<000002`3oool3000000@0oooo1@0000050?ooo`@000001`3oool5000000/0dLfY0P0000090?oo
o`<000000P3oool5000000L0oooo0P0000020?ooo`D00000103oool300000080oooo0P0000020?oo
o`L000000`3oool7000000/0oooo2`3AcJT9000000@0oooo2@0000070?ooo`8000001P3oool30000
0080oooo3@0000020?ooo`8000001@3oool900000080oooo0P00000<0=7=Z@8000000P3oool20000
00<0oooo200000040?ooo`<000000P3oool200000080oooo0P00000=0?ooo`8000000P3oool20000
0080oooo0`0000040?ooo`P000000`3oool200000080oooo0P00000>0=7=Z@00303AcJT7000000<0
oooo2@00000W0?ooo`T000000`3oool7000000`0dLfY0P3oool:00000080oooo300000040?ooo`<0
00002`3oool3000000@0oooo1@0000050?ooo`@000001`3oool5000000/0dLfY1@0000020?oooa00
00001`3oool;000000<0oooo0P0000040?ooo`<000000P3oool5000000@0oooo1`0000020?ooo`D0
00002`3AcJT4000000h0oooo0P0000020?ooo`8000000P3oool300000080oooo2@0000040?ooo`80
00001`3oool4000000D0oooo200000050?ooo`800000303AcJT200000080oooo0P0000030?ooo`P0
0000103oool300000080oooo0P0000020?ooo`8000003@3oool200000080oooo0P0000020?ooo`<0
0000103oool8000000<0oooo0P0000020?ooo`8000003P3AcJT000`0dLfY1@0000020?ooo``00000
9`3oool<00000080oooo1@00000<0=7=Z@D000000P3oool5000000@0oooo1`0000030?ooo`800000
1`3oool2000000<0oooo0P0000020?ooo`<000001`3oool;000000D0oooo0P0000030?ooo`800000
2`3AcJT500000080oooo400000070?ooo`/000000`3oool2000000@0oooo0`0000020?ooo`D00000
103oool700000080oooo1@00000;0=7=Z@@000003P3oool200000080oooo0P0000020?ooo`<00000
0P3oool9000000@0oooo0P0000070?ooo`@000001@3oool8000000D0oooo0P00000<0=7=Z@800000
0P3oool9000000@0oooo1`00000M0?ooo`L00000103oool900000080oooo0P00000>0=7=Z@00303A
cJT500000080oooo3000000W0?ooo``000000P3oool5000000`0dLfY1@0000020?ooo`D00000103o
ool7000000<0oooo0P0000070?ooo`8000000`3oool200000080oooo0`0000070?ooo`/000001@3o
ool2000000<0oooo0P00000;0=7=Z@T000000P3oool500000080oooo1@0000020?ooo`D000001`3o
ool4000000<0oooo0P0000020?ooo`8000002P3oool200000080oooo1@0000020?ooo`D000000P3o
ool;0=7=Z@@000001@3oool200000080oooo1@0000080?ooo`<000001P3oool500000080oooo1000
00070?ooo`8000001`3oool400000080oooo0P0000070?ooo``0dLfY0P0000020?ooo`T00000103o
ool7000001d0oooo1`0000040?ooo`T000000P3oool2000000h0dLfY000<0=7=Z@D000000P3oool<
000002L0oooo300000020?ooo`D00000303AcJT70?ooo`8000003P3oool3000000T0oooo1`000007
0?ooo`T000001@3oool2000000D0oooo1`00000;0=7=Z@T000000P3oool500000080oooo1@000002
0?ooo`D000001`3oool4000000<0oooo0P0000020?ooo`8000002P3oool200000080oooo1@000002
0?ooo`D000000P3oool;0=7=Z@@000001@3oool200000080oooo1@0000080?ooo`<000001P3oool5
00000080oooo100000070?ooo`8000001`3oool400000080oooo0P0000070?ooo``0dLfY0P000002
0?ooo`T00000103oool7000001d0oooo1`0000040?ooo`T000000P3oool2000000h0dLfY000<0=7=
Z@8000001@3oool5000000L0oooo1`00000:0?ooo`D000002P3oool7000000L0oooo1@0000050?oo
o`800000303AcJT70?ooo`8000003P3oool3000000T0oooo1`0000070?ooo`T000001@3oool20000
00D0oooo1`00000;0=7=Z@T000000P3oool500000080oooo1@0000020?ooo`D000001`3oool40000
00<0oooo0P0000020?ooo`8000002P3oool200000080oooo1@0000020?ooo`D000000P3oool;0=7=
Z@8000001@3oool400000080oooo0P0000050?ooo`8000000P3oool5000000H0oooo2`0000070?oo
o`8000002@3oool4000000D0oooo1000000<0=7=Z@80oooo2`0000040?ooo`@000000`3oool20000
01T0oooo0P0000030?ooo`@00000103oool;00000080oooo3P3AcJT000`0dLfY0P0000050?ooo`D0
00001`3oool7000000X0oooo1@00000:0?ooo`L000001`3oool5000000D0oooo0P00000<0=7=Z@D0
00000P3oool500000080oooo1@0000070?ooo`@000001@3oool5000000T0oooo1@0000020?ooo`D0
00000P3oool5000000T0oooo2`3AcJT50?ooo`8000001`3oool700000080oooo0P0000050?ooo`80
00000P3oool500000080oooo0`0000060?ooo`L000000`3oool200000080oooo1`0000070?ooo`/0
dLfY0P0000050?ooo`@000000P3oool2000000D0oooo0P0000020?ooo`D000001P3oool;000000L0
oooo0P0000090?ooo`@000001@3oool4000000`0dLfY0P3oool;000000@0oooo100000030?ooo`80
00006@3oool2000000<0oooo100000040?ooo`/000000P3oool>0=7=Z@00303AcJT20?ooo`D00000
1@3oool2000000D0oooo1@0000020?ooo`<000001@3oool2000000D0oooo0P0000050?ooo`<00000
0P3oool5000000D0oooo0P0000050?ooo`D000000P3oool<0=7=Z@D000000P3oool500000080oooo
1@0000070?ooo`@000001@3oool5000000T0oooo1@0000020?ooo`D000000P3oool5000000T0oooo
2`3AcJT50?ooo`8000001`3oool700000080oooo0P0000050?ooo`8000000P3oool500000080oooo
0`0000060?ooo`L000000`3oool200000080oooo1`0000070?ooo`/0dLfY0P3oool700000080oooo
100000050?ooo`@000000P3oool500000080oooo100000030?ooo`@000001`3oool2000000@0oooo
0P0000050?ooo`8000000P3oool9000000`0dLfY0P3oool2000000L0oooo0P0000020?ooo`@00000
0P3oool700000080oooo0P0000040?ooo`D00000103oool200000080oooo1`0000020?ooo`@00000
0P3oool2000000L0oooo0P0000020?ooo`h0dLfY000<0=7=Z@80oooo1@0000050?ooo`8000001@3o
ool500000080oooo0`0000050?ooo`8000001@3oool2000000D0oooo0`0000020?ooo`D000001@3o
ool2000000D0oooo1@0000020?ooo``0dLfY1@0000020?ooo`D000000P3oool5000000L0oooo1000
00050?ooo`D000002@3oool500000080oooo1@0000020?ooo`D000002@3oool;0=7=Z@80oooo0`00
00020?ooo`8000001@3oool9000000T0oooo0P0000050?ooo`8000001@3oool200000080oooo0`00
00020?ooo`L000000P3oool3000000H0oooo0`0000020?ooo`/0dLfY0P3oool700000080oooo1000
00050?ooo`@000000P3oool500000080oooo100000030?ooo`@000001`3oool2000000@0oooo0P00
00050?ooo`8000000P3oool9000000`0dLfY0P3oool2000000L0oooo0P0000020?ooo`@000000P3o
ool700000080oooo0P0000040?ooo`D00000103oool200000080oooo1`0000020?ooo`@000000P3o
ool2000000L0oooo0P0000020?ooo`h0dLfY000<0=7=Z@8000000`3oool2000000<0oooo10000005
0?ooo`<000000P3oool<000000D0oooo300000020?ooo`<000001@3oool4000000<0oooo0P000003
0?ooo`800000303AcJT70?ooo`8000001@3oool9000000D0oooo0P0000070?ooo`<00000103oool5
000000D0oooo0P0000050?ooo`@000000`3oool4000000D0oooo2`3AcJT20?ooo`<000000P3oool2
000000D0oooo2@0000090?ooo`8000001@3oool2000000D0oooo0P0000020?ooo`<000000P3oool7
00000080oooo0`0000060?ooo`<000000P3oool;0=7=Z@80oooo1`0000020?ooo`@000001@3oool4
00000080oooo1@0000020?ooo`@000000`3oool4000000L0oooo0P0000040?ooo`8000001@3oool2
00000080oooo2@00000<0=7=Z@8000001`3oool200000080oooo0P0000040?ooo`L000000P3oool2
00000080oooo100000050?ooo`@000000P3oool200000080oooo1`0000040?ooo`8000000P3oool2
000000L0oooo0P00000>0=7=Z@00303AcJT2000000<0oooo0P0000030?ooo`@000001@3oool30000
0080oooo300000050?ooo``000000P3oool3000000D0oooo100000030?ooo`8000000`3oool20000
00`0dLfY1`3oool2000000D0oooo2@0000050?ooo`8000001`3oool3000000@0oooo1@0000050?oo
o`8000001@3oool4000000<0oooo100000050?ooo`/0dLfY1`00000;0?ooo`<000000P3oool20000
00D0oooo0P0000070?ooo`T000004`3oool400000080oooo0`0000020?ooo`/0dLfY103oool30000
00@0oooo100000030?ooo`800000103oool2000000T0oooo2`0000050?ooo`8000000P3oool90000
0080oooo0P0000050?ooo`@00000303AcJT2000000L0oooo0P0000020?ooo`800000103oool70000
0080oooo0P0000020?ooo`@000001@3oool400000080oooo0P0000020?ooo`L00000103oool20000
0080oooo0P0000070?ooo`8000003P3AcJT000`0dLfY0P0000030?ooo`8000000`3oool4000000D0
oooo0`0000020?ooo``000001@3oool<00000080oooo0`0000050?ooo`@000000`3oool2000000<0
oooo0P00000<0=7=Z@D00000103oool3000000T0oooo1@0000090?ooo`L000000P3oool5000000D0
oooo400000020?ooo`<000000P3oool;0=7=Z@L000002`3oool300000080oooo0P0000050?ooo`80
00001`3oool9000001<0oooo100000020?ooo`<000000P3oool;0=7=Z@@0oooo0`0000040?ooo`@0
00000`3oool2000000@0oooo0P0000090?ooo`/000001@3oool200000080oooo2@0000020?ooo`80
00001@3oool4000000`0dLfY103oool5000000H0oooo0P0000040?ooo`<000000P3oool600000080
oooo2@0000020?ooo`H000000P3oool3000000@0oooo0P0000060?ooo`D00000103oool>0=7=Z@00
303AcJT20?ooo`<000000P3oool7000000P0oooo300000020?ooo`D000000P3oool<000000P0oooo
1`0000020?ooo`<000000P3oool<0=7=Z@D00000103oool3000000T0oooo1@0000090?ooo`L00000
0P3oool5000000D0oooo400000020?ooo`<000000P3oool;0=7=Z@L000002`3oool300000080oooo
0P0000050?ooo`8000001`3oool9000001<0oooo100000020?ooo`<000000P3oool;0=7=Z@L00000
0P3oool2000000@0oooo0`0000020?ooo`8000000P3oool700000080oooo100000030?ooo`800000
1P3oool300000080oooo0P0000020?ooo`8000000`3oool8000000L0oooo303AcJT40?ooo`D00000
1P3oool2000000@0oooo0`0000020?ooo`H000000P3oool900000080oooo1P0000020?ooo`<00000
103oool2000000H0oooo1@0000040?ooo`h0dLfY000<0=7=Z@80oooo0`0000020?ooo`L00000203o
ool<00000080oooo1@0000020?ooo``00000203oool700000080oooo0`0000020?ooo``0dLfY3000
00070?ooo`8000001`3oool7000000L0oooo3P0000020?ooo`D000001@3oool2000000L0oooo2`3A
cJT2000000<0oooo0P0000020?ooo`8000001@3oool2000000<0oooo0P0000090?ooo`D000000P3o
ool500000080oooo100000050?ooo`8000000`3oool2000000T0oooo0P0000050?ooo`/0dLfY1`00
00020?ooo`800000103oool300000080oooo0P0000020?ooo`L000000P3oool4000000<0oooo0P00
00060?ooo`<000000P3oool200000080oooo0P0000030?ooo`P000001`3oool<0=7=Z@@0oooo1@00
00040?ooo`8000002@3oool600000080oooo3@0000020?ooo`H000002@3oool2000000@0oooo1@00
00040?ooo`h0dLfY000<0=7=Z@D000000P3oool300000080oooo0P00000:0?ooo`X000002@3oool:
000000X0oooo0P0000020?ooo`<000000P3oool5000000`0dLfY300000070?ooo`8000001`3oool7
000000L0oooo3P0000020?ooo`D000001@3oool2000000L0oooo2`3AcJT2000000<0oooo0P000002
0?ooo`8000001@3oool2000000<0oooo0P0000090?ooo`D000000P3oool500000080oooo10000005
0?ooo`8000000`3oool2000000T0oooo0P0000050?ooo`/0dLfY100000050?ooo`H000001@3oool4
000000D0oooo100000020?ooo`D000000P3oool200000080oooo0P0000030?oooa4000001`3oool2
000000`0dLfY103oool5000000@0oooo0P0000090?ooo`H000000P3oool=00000080oooo1P000009
0?ooo`800000103oool5000000@0oooo3P3AcJT000`0dLfY1@0000020?ooo`<000000P3oool20000
00X0oooo2P0000090?ooo`X000002P3oool200000080oooo0`0000020?ooo`D00000303AcJT<0000
00L0oooo0P0000070?ooo`L000001`3oool>00000080oooo1@0000050?ooo`8000001`3oool;0=7=
Z@T000001@3oool2000000L0oooo2@0000070?oooa0000001@3oool200000080oooo0`0000040?oo
o`8000000`3oool2000000/0dLfY100000050?ooo`H000001@3oool4000000D0oooo100000020?oo
o`D000000P3oool200000080oooo0P0000030?oooa4000001`3oool2000000`0dLfY0P3oool20000
00L0oooo0P0000020?ooo`800000103oool300000080oooo0P0000020?ooo`@000000P3oool50000
0080oooo100000020?ooo`8000000P3oool3000000@0oooo0P0000020?ooo`8000001`3oool20000
0080oooo3P3AcJT000`0dLfY1@0000020?ooo`<000000P3oool2000000X0oooo2P0000090?ooo`X0
00002P3oool200000080oooo0`0000020?ooo`D00000303AcJT2000000D0oooo1@0000020?ooo`D0
0000103oool7000000<0oooo1`0000070?oooaT000000`3oool2000000/0dLfY2@0000050?ooo`80
00001`3oool9000000L0oooo400000050?ooo`8000000P3oool3000000@0oooo0P0000030?ooo`80
00002`3AcJT2000000L0oooo2`0000020?ooo`L000000P3oool6000000L0oooo100000070?ooo`80
00001@3oool8000000D0oooo0P00000<0=7=Z@80oooo0P0000070?ooo`8000000P3oool2000000@0
oooo0`0000020?ooo`8000000P3oool400000080oooo1@0000020?ooo`@000000P3oool200000080
oooo0`0000040?ooo`8000000P3oool2000000L0oooo0P0000020?ooo`h0dLfY000<0=7=Z@L00000
0`3oool2000000`0oooo2P0000090?ooo`X00000303oool2000000<0oooo1`00000<0=7=Z@800000
1@3oool500000080oooo1@0000040?ooo`L000000`3oool7000000L0oooo6@0000030?ooo`800000
2`3AcJT20?ooo`<000000P3oool7000000h0oooo100000050?ooo`8000000P3oool5000000@0oooo
1`0000030?ooo`8000000P3oool5000000@0oooo0`0000020?ooo`/0dLfY0P0000070?ooo`/00000
0P3oool700000080oooo1P0000070?ooo`@000001`3oool2000000D0oooo200000050?ooo`800000
303AcJT20?ooo`8000001`3oool200000080oooo0P0000040?ooo`<000000P3oool200000080oooo
100000020?ooo`D000000P3oool400000080oooo0P0000020?ooo`<00000103oool200000080oooo
0P0000070?ooo`8000000P3oool>0=7=Z@00303AcJT7000000<0oooo0P00000<0?ooo`X000002@3o
ool:000000`0oooo0P0000030?ooo`L00000303AcJT2000000D0oooo3P0000020?ooo`D000001`3o
ool7000000D0oooo0P0000020?ooo`D000001@3oool;000000<0oooo0P00000;0=7=Z@80oooo0`00
00020?ooo`L000003P3oool4000000D0oooo0P0000020?ooo`D00000103oool7000000<0oooo0P00
00020?ooo`D00000103oool300000080oooo2`3AcJT4000000L0oooo1`0000040?ooo`8000002`3o
ool900000080oooo2`0000050?ooo`8000000P3oool200000080oooo1`00000<0=7=Z@8000001`3o
ool200000080oooo0P0000090?ooo`8000000P3oool8000000D0oooo200000020?ooo`8000002@3o
ool200000080oooo0P0000070?ooo`8000003P3AcJT000`0dLfY0P3oool8000000`0oooo10000008
0?ooo`T00000203oool4000000`0oooo200000020?ooo``0dLfY0P0000050?ooo`h000000P3oool5
000000L0oooo1`0000050?ooo`8000000P3oool5000000D0oooo2`0000030?ooo`8000002`3AcJT2
000000L0oooo0P00000:0?ooo`8000001@3oool2000000L0oooo100000030?ooo`8000000P3oool5
000000T0oooo0P0000050?ooo`8000001@3oool2000000/0dLfY100000070?ooo`L00000103oool2
000000/0oooo2@0000020?ooo`/000001@3oool200000080oooo0P0000020?ooo`L00000303AcJT2
000000L0oooo0P0000020?ooo`8000002@3oool200000080oooo200000050?ooo`P000000P3oool2
000000T0oooo0P0000020?ooo`8000001`3oool2000000h0dLfY000<0=7=Z@80oooo2000000<0?oo
o`@00000203oool9000000P0oooo1000000<0?ooo`P000000P3oool<0=7=Z@8000000`3oool20000
00L0oooo0P00000A0?ooo`@000000`3oool200000080oooo0`0000020?ooo`8000001@3oool20000
00D0oooo1@0000020?ooo`8000001@3oool;0=7=Z@8000001`3oool2000000X0oooo0P0000050?oo
o`8000001`3oool4000000<0oooo0P0000020?ooo`D000002@3oool2000000D0oooo0P0000050?oo
o`8000002`3AcJT4000000L0oooo1`0000040?ooo`8000002`3oool900000080oooo2`0000050?oo
o`8000000P3oool200000080oooo1`00000<0=7=Z@8000000P3oool2000000<0oooo1000000;0?oo
o`H000000P3oool=00000080oooo1P00000;0?ooo`@000000`3oool200000080oooo0P00000>0=7=
Z@00303AcJT20?ooo`P00000303oool4000000P0oooo2@0000080?ooo`@00000303oool800000080
oooo303AcJT2000000<0oooo0P0000070?ooo`8000004@3oool4000000<0oooo0P0000020?ooo`<0
00000P3oool2000000D0oooo0P0000050?ooo`D000000P3oool2000000D0oooo2`3AcJT2000000L0
oooo0P00000:0?ooo`8000001@3oool2000000L0oooo100000030?ooo`8000000P3oool5000000T0
oooo0P0000050?ooo`8000001@3oool2000000/0dLfY0P3oool5000000/0oooo0P0000020?ooo`80
00001@3oool200000080oooo0P0000050?ooo`P000001@3oool4000000T0oooo100000030?ooo`@0
0000303AcJT200000080oooo0P0000030?ooo`@000002`3oool600000080oooo3@0000020?ooo`H0
00002`3oool4000000<0oooo0P0000020?ooo`8000003P3AcJT000`0dLfY0P0000030?ooo`D00000
2@3oool3000000@0oooo0`0000050?ooo`T000001@3oool3000000@0oooo0`0000090?ooo`D00000
0`3oool2000000`0dLfY0P0000030?ooo`8000001`3oool200000140oooo100000030?ooo`800000
0P3oool300000080oooo0P0000050?ooo`8000001@3oool500000080oooo0P0000050?ooo`/0dLfY
1@3oool2000000T0oooo0P00000:0?ooo`H000001@3oool2000000L0oooo1`0000050?ooo`/00000
1`3oool;0=7=Z@80oooo1@00000;0?ooo`8000000P3oool2000000D0oooo0P0000020?ooo`800000
1@3oool8000000D0oooo100000090?ooo`@000000`3oool4000000`0dLfY0P3oool200000080oooo
1`0000080?ooo`<000000P3oool600000080oooo2@0000020?ooo`H000000P3oool3000000P0oooo
1`0000020?ooo`8000000P3oool>0=7=Z@00303AcJT2000000<0oooo1@0000090?ooo`<00000103o
ool3000000D0oooo2@0000050?ooo`<00000103oool3000000T0oooo1@0000030?ooo`800000303A
cJT>0?ooo`D000001`3oool4000000<0oooo0P0000020?ooo`<000000P3oool2000000<0oooo1000
00070?ooo`D000003P3oool;0=7=Z@D0oooo0P0000090?ooo`8000002P3oool6000000D0oooo0P00
00070?ooo`L000001@3oool;000000L0oooo2`3AcJT2000000/0oooo0P0000030?ooo`P000001@3o
ool200000080oooo1`0000020?ooo`8000001@3oool8000000<0oooo0P00000;0?ooo`800000303A
cJT20?ooo`8000000P3oool7000000P0oooo0`0000020?ooo`H000000P3oool900000080oooo1P00
00020?ooo`<00000203oool700000080oooo0P0000020?ooo`h0dLfY000<0=7=Z@8000000`3oool5
000000T0oooo0`0000040?ooo`<000001@3oool9000000D0oooo0`0000040?ooo`<000002@3oool5
000000<0oooo0P00000<0=7=Z@h0oooo1@0000070?ooo`@000000`3oool200000080oooo0`000002
0?ooo`8000000`3oool4000000L0oooo1@00000>0?ooo`/0dLfY0P0000030?ooo`8000000P3oool2
000000<0oooo0P0000050?ooo`8000000P3oool500000080oooo1`0000020?ooo`<000000P3oool2
000000D0oooo1`0000020?ooo`8000000`3oool6000000<0oooo0P00000;0=7=Z@8000002`3oool2
000000<0oooo200000050?ooo`8000000P3oool700000080oooo0P0000050?ooo`P000000`3oool2
000000/0oooo0P00000<0=7=Z@80oooo0P0000020?ooo`L00000203oool300000080oooo1P000002
0?ooo`T000000P3oool600000080oooo0`0000080?ooo`L000000P3oool200000080oooo3P3AcJT0
00`0dLfY0P0000030?ooo`D000002@3oool3000000@0oooo0`0000050?ooo`T000001@3oool30000
00@0oooo0`0000090?ooo`D000000`3oool2000000`0dLfY0P0000050?ooo`T000001@3oool20000
00<0oooo2`0000030?ooo`8000001@3oool2000000D0oooo1000000:0?ooo`8000001`3oool;0=7=
Z@8000000`3oool200000080oooo0P0000030?ooo`8000001@3oool200000080oooo1@0000020?oo
o`L000000P3oool300000080oooo0P0000050?ooo`L000000P3oool2000000<0oooo1P0000030?oo
o`8000002`3AcJT4000000<0oooo0P0000020?ooo`8000000P3oool5000000T0oooo200000050?oo
o`8000000P3oool2000000L0oooo0P0000020?ooo`<000000P3oool400000080oooo1@0000020?oo
o``0dLfY0P3oool200000080oooo1`0000080?ooo`<000000P3oool600000080oooo2@0000020?oo
o`H000000P3oool3000000P0oooo1`0000020?ooo`8000000P3oool>0=7=Z@00303AcJT20?ooo`P0
0000303oool4000000P0oooo2@0000080?ooo`@00000303oool800000080oooo303AcJT2000000D0
oooo2@0000050?ooo`8000000`3oool;000000<0oooo0P0000050?ooo`8000001@3oool4000000X0
oooo0P0000070?ooo`/0dLfY0P3oool9000000<0oooo0P0000020?ooo`<000000P3oool9000000D0
oooo1`0000020?ooo`8000001@3oool2000000L0oooo0P0000070?ooo`D000000P3oool;0=7=Z@@0
00000`3oool200000080oooo0P0000020?ooo`D000002@3oool8000000D0oooo0P0000020?ooo`80
00001`3oool200000080oooo0`0000020?ooo`@000000P3oool500000080oooo303AcJT200000080
oooo0P0000030?ooo`@000002`3oool600000080oooo3@0000020?ooo`H000002`3oool4000000<0
oooo0P0000020?ooo`8000003P3AcJT000`0dLfY0P3oool8000000`0oooo100000080?ooo`T00000
203oool4000000`0oooo200000020?ooo``0dLfY0P0000050?ooo`T000001@3oool2000000<0oooo
2`0000030?ooo`8000001@3oool2000000D0oooo1000000:0?ooo`8000001`3oool;0=7=Z@80oooo
2@0000030?ooo`8000000P3oool300000080oooo2@0000050?ooo`L000000P3oool2000000D0oooo
0P0000070?ooo`8000001`3oool500000080oooo2`3AcJT40?ooo`L000000P3oool2000000/0oooo
1@0000060?ooo`<000000P3oool2000000L0oooo0P0000020?ooo`8000000P3oool700000080oooo
0P0000070?ooo``0dLfY0P0000020?ooo`8000000`3oool4000000/0oooo1P0000020?ooo`d00000
0P3oool6000000/0oooo100000030?ooo`8000000P3oool2000000h0dLfY000<0=7=Z@80oooo2000
000<0?ooo`@00000203oool9000000P0oooo1000000<0?ooo`P000000P3oool<0=7=Z@8000001@3o
ool9000000<0oooo0P0000020?ooo`D000002@3oool3000000L0oooo0P0000020?ooo`D000000P3o
ool>000000<0oooo0P00000;0=7=Z@80oooo2@0000030?ooo`8000000P3oool300000080oooo2@00
00050?ooo`L000000P3oool2000000D0oooo0P0000070?ooo`8000001`3oool500000080oooo2`3A
cJT40?ooo`L000000P3oool2000000/0oooo1@0000060?ooo`<000000P3oool2000000L0oooo0P00
00020?ooo`8000000P3oool700000080oooo0P0000070?ooo``0dLfY0P0000070?ooo`8000000P3o
ool2000000T0oooo0P0000020?ooo`P000001@3oool800000080oooo0P0000090?ooo`8000000P3o
ool2000000L0oooo0P00000>0=7=Z@00303AcJT7000000<0oooo0P00000<0?ooo`X000002@3oool:
000000`0oooo0P0000030?ooo`L00000303AcJT2000000D0oooo2@0000030?ooo`8000000P3oool5
000000T0oooo0`0000070?ooo`8000000P3oool500000080oooo3P0000030?ooo`8000002`3AcJT5
0?ooo`@000002@3oool300000080oooo1@0000020?ooo`@000001@3oool2000000<0oooo0P000002
0?ooo`800000303oool>00000080oooo2`3AcJT40?ooo`L000000P3oool2000000/0oooo1@000006
0?ooo`<000000P3oool2000000L0oooo0P0000020?ooo`8000000P3oool700000080oooo0P000007
0?ooo``0dLfY0P0000070?ooo`8000000P3oool2000000T0oooo0P0000020?ooo`P000001@3oool8
00000080oooo0P0000090?ooo`8000000P3oool2000000L0oooo0P00000>0=7=Z@00303AcJT70000
00<0oooo0P00000<0?ooo`X000002@3oool:000000`0oooo0P0000030?ooo`L00000303AcJT70?oo
o`8000000`3oool700000080oooo1@0000020?ooo`8000001`3oool7000000<0oooo0P0000020?oo
o`<000000P3oool7000000D0oooo100000050?ooo`/0dLfY1@3oool4000000T0oooo0`0000020?oo
o`D000000P3oool4000000D0oooo0P0000030?ooo`8000000P3oool2000000`0oooo3P0000020?oo
o`/0dLfY2@3oool2000000@0oooo0`0000060?ooo`8000000`3oool6000000D0oooo0P0000020?oo
o`8000000P3oool300000080oooo1P0000070?ooo`@000001`3oool<0=7=Z@8000001`3oool20000
0080oooo0P0000090?ooo`8000000P3oool8000000D0oooo200000020?ooo`8000002@3oool20000
0080oooo0P0000070?ooo`8000003P3AcJT000`0dLfY1@0000020?ooo`<000000P3oool2000000X0
oooo2P0000090?ooo`X000002P3oool200000080oooo0`0000020?ooo`D00000303AcJT70?ooo`80
00000`3oool700000080oooo1@0000020?ooo`8000001`3oool7000000<0oooo0P0000020?ooo`<0
00000P3oool7000000D0oooo100000050?ooo`/0dLfY0P3oool300000080oooo100000030?ooo`L0
00001`3oool2000000h0oooo2@0000070?ooo`8000001@3oool;000000/0dLfY2@3oool2000000@0
oooo0`0000060?ooo`8000000`3oool6000000D0oooo0P0000020?ooo`8000000P3oool300000080
oooo1P0000070?ooo`@000001`3oool<0=7=Z@80oooo0P0000070?ooo`8000000P3oool2000000@0
oooo0`0000020?ooo`8000000P3oool400000080oooo1@0000020?ooo`@000000P3oool200000080
oooo0`0000040?ooo`8000000P3oool2000000L0oooo0P0000020?ooo`h0dLfY000<0=7=Z@D00000
0P3oool300000080oooo0P00000:0?ooo`X000002@3oool:000000X0oooo0P0000020?ooo`<00000
0P3oool5000000`0dLfY0P0000050?ooo`8000000`3oool200000080oooo0`0000020?ooo`D00000
0P3oool200000140oooo100000050?ooo`8000000`3oool>00000080oooo2`3AcJT20?ooo`<00000
0P3oool4000000<0oooo1`0000070?ooo`8000003P3oool9000000L0oooo0P0000050?ooo`/00000
2`3AcJT20?ooo`/000000P3oool300000080oooo0P0000020?ooo`8000002@3oool500000080oooo
100000090?ooo`@000001@3oool9000000@0oooo303AcJT20?ooo`8000001`3oool200000080oooo
0P0000040?ooo`<000000P3oool200000080oooo100000020?ooo`D000000P3oool400000080oooo
0P0000020?ooo`<00000103oool200000080oooo0P0000070?ooo`8000000P3oool>0=7=Z@00303A
cJT500000080oooo0`0000020?ooo`8000002P3oool:000000T0oooo2P00000:0?ooo`8000000P3o
ool300000080oooo1@00000<0=7=Z@8000001@3oool2000000<0oooo0P0000020?ooo`<000000P3o
ool500000080oooo0P00000A0?ooo`@000001@3oool2000000<0oooo3P0000020?ooo`/0dLfY1@3o
ool200000080oooo0P0000030?ooo`T000000P3oool3000000@0oooo0P0000050?ooo`T000001`3o
ool7000000/0oooo1@00000;0=7=Z@80oooo2`0000020?ooo`<000000P3oool200000080oooo0P00
00090?ooo`D000000P3oool4000000T0oooo100000050?ooo`T00000103oool<0=7=Z@@0oooo1@00
00040?ooo`8000002@3oool600000080oooo3@0000020?ooo`H000002@3oool2000000@0oooo1@00
00040?ooo`h0dLfY000<0=7=Z@80oooo0`0000020?ooo`L00000203oool<00000080oooo1@000002
0?ooo``00000203oool700000080oooo0`0000020?ooo``0dLfY0P0000050?ooo`8000000`3oool2
00000080oooo0`0000020?ooo`D000000P3oool200000140oooo100000050?ooo`8000000`3oool>
00000080oooo2`3AcJT50?ooo`8000000P3oool2000000<0oooo2@0000020?ooo`<00000103oool2
000000D0oooo2@0000070?ooo`L000002`3oool5000000/0dLfY0P0000020?ooo`D000001P3oool5
00000080oooo0P0000020?ooo`<000000P3oool2000000T0oooo2`0000020?ooo`8000001@3oool4
000000L0oooo0P0000020?ooo``0dLfY103oool5000000@0oooo0P0000090?ooo`H000000P3oool=
00000080oooo1P0000090?ooo`800000103oool5000000@0oooo3P3AcJT000`0dLfY0P3oool30000
0080oooo1`0000080?ooo``000000P3oool500000080oooo300000080?ooo`L000000P3oool30000
0080oooo303AcJT20?ooo`<00000103oool3000000@0oooo0`0000090?ooo`8000000`3oool>0000
00@0oooo0`0000020?ooo`8000000`3oool900000080oooo1@00000;0=7=Z@h0oooo100000030?oo
o`8000000P3oool500000080oooo0P0000050?ooo`D00000103oool5000000@0oooo0`0000040?oo
o`<000000P3oool2000000L0oooo2`3AcJT200000080oooo1@0000060?ooo`D000000P3oool20000
0080oooo0`0000020?ooo`8000002@3oool;00000080oooo0P0000050?ooo`@000001`3oool20000
0080oooo303AcJT40?ooo`D000001P3oool2000000@0oooo0`0000020?ooo`H000000P3oool90000
0080oooo1P0000020?ooo`<00000103oool2000000H0oooo1@0000040?ooo`h0dLfY000<0=7=Z@80
00000`3oool2000000<0oooo100000050?ooo`<000000P3oool<000000D0oooo300000020?ooo`<0
00001@3oool4000000<0oooo0P0000030?ooo`800000303AcJT20?ooo`<00000103oool3000000@0
oooo0`0000090?ooo`8000000`3oool>000000@0oooo0`0000020?ooo`8000000`3oool900000080
oooo1@00000;0=7=Z@h0oooo100000030?ooo`8000000P3oool500000080oooo0P0000050?ooo`D0
0000103oool5000000@0oooo0`0000040?ooo`<000000P3oool2000000L0oooo2`3AcJT70?ooo`80
00000P3oool4000000L0oooo1`0000020?ooo`/000001P3oool900000080oooo1@0000020?ooo`/0
0000303AcJT40?ooo`D000001P3oool2000000@0oooo0`0000020?ooo`H000000P3oool900000080
oooo1P0000020?ooo`<00000103oool2000000H0oooo1@0000040?ooo`h0dLfY000<0=7=Z@800000
0`3oool2000000<0oooo100000050?ooo`<000000P3oool<000000D0oooo300000020?ooo`<00000
1@3oool4000000<0oooo0P0000030?ooo`800000303AcJT2000000D0oooo1`0000070?ooo`800000
1@3oool700000080oooo0`0000020?ooo`8000000`3oool2000000D0oooo1`0000040?ooo`L00000
0`3oool2000000/0dLfY3P3oool4000000<0oooo0P0000020?ooo`D000000P3oool2000000D0oooo
1@0000040?ooo`D00000103oool3000000@0oooo0`0000020?ooo`8000001`3oool;0=7=Z@L0oooo
0P0000020?ooo`@000001`3oool700000080oooo2`0000060?ooo`T000000P3oool500000080oooo
2`00000<0=7=Z@8000001`3oool200000080oooo0P0000040?ooo`L000000P3oool200000080oooo
100000050?ooo`@000000P3oool200000080oooo1`0000040?ooo`8000000P3oool2000000L0oooo
0P00000>0=7=Z@00303AcJT2000000<0oooo0P0000030?ooo`@000001@3oool300000080oooo3000
00050?ooo``000000P3oool3000000D0oooo100000030?ooo`8000000`3oool2000000`0dLfY0P00
00050?ooo`L000001`3oool2000000D0oooo1`0000020?ooo`<000000P3oool2000000<0oooo0P00
00050?ooo`L00000103oool7000000<0oooo0P00000;0=7=Z@80oooo1`00000>0?ooo`T000001@3o
ool2000000D0oooo100000020?ooo`L000000`3oool200000080oooo0`0000020?ooo`@000001@3o
ool;0=7=Z@@000001`3oool4000000D0oooo0P0000020?ooo`8000000`3oool400000080oooo0P00
00030?ooo`8000000P3oool200000080oooo0`0000020?ooo`8000000P3oool2000000D0oooo0P00
00070?ooo`8000000P3oool<0=7=Z@8000001`3oool200000080oooo0P0000040?ooo`L000000P3o
ool200000080oooo100000050?ooo`@000000P3oool200000080oooo1`0000040?ooo`8000000P3o
ool2000000L0oooo0P00000>0=7=Z@00303AcJT20?ooo`D000001@3oool2000000D0oooo1@000002
0?ooo`<000001@3oool2000000D0oooo0P0000050?ooo`<000000P3oool5000000D0oooo0P000005
0?ooo`D000000P3oool<0=7=Z@L000001`3oool2000000L0oooo0`0000020?ooo`8000000`3oool7
00000080oooo0P00000<0?ooo`8000001@3oool2000000<0oooo100000050?ooo`/0dLfY0P3oool7
000000h0oooo2@0000050?ooo`8000001@3oool400000080oooo1`0000030?ooo`8000000P3oool3
00000080oooo100000050?ooo`/0dLfY100000070?ooo`@000001@3oool200000080oooo0P000003
0?ooo`@000000P3oool2000000<0oooo0P0000020?ooo`8000000P3oool300000080oooo0P000002
0?ooo`8000001@3oool2000000L0oooo0P0000020?ooo``0dLfY0P3oool2000000L0oooo0P000002
0?ooo`@000000P3oool700000080oooo0P0000040?ooo`D00000103oool200000080oooo1`000002
0?ooo`@000000P3oool2000000L0oooo0P0000020?ooo`h0dLfY000<0=7=Z@80oooo1@0000050?oo
o`8000001@3oool500000080oooo0`0000050?ooo`8000001@3oool2000000D0oooo0`0000020?oo
o`D000001@3oool2000000D0oooo1@0000020?ooo``0dLfY1`0000070?ooo`8000001`3oool30000
0080oooo0P0000030?ooo`L000000P3oool2000000`0oooo0P0000050?ooo`8000000`3oool40000
00D0oooo2`3AcJT2000000<0oooo0P0000040?ooo`D000002@3oool<000000T0oooo100000050?oo
o`8000000`3oool2000000L0oooo0P0000020?ooo`<000000P3oool;0=7=Z@@000001`3oool40000
00D0oooo0P0000020?ooo`8000000`3oool400000080oooo0P0000030?ooo`8000000P3oool20000
0080oooo0`0000020?ooo`8000000P3oool2000000D0oooo0P0000070?ooo`8000000P3oool<0=7=
Z@80oooo0P0000070?ooo`8000000P3oool400000080oooo1`0000020?ooo`800000103oool50000
00@0oooo0P0000020?ooo`L000000P3oool400000080oooo0P0000070?ooo`8000000P3oool>0=7=
Z@00303AcJT2000000D0oooo1@0000070?ooo`L000002P3oool5000000X0oooo1`0000070?ooo`D0
00001@3oool2000000`0dLfY1`0000070?ooo`8000001`3oool300000080oooo0P0000030?ooo`L0
00000P3oool2000000`0oooo0P0000050?ooo`8000000`3oool4000000D0oooo2`3AcJT2000000<0
oooo0P0000040?ooo`D000002@3oool<000000T0oooo100000050?ooo`8000000`3oool2000000L0
oooo0P0000020?ooo`<000000P3oool;0=7=Z@80oooo1@0000020?ooo`@000001@3oool400000080
oooo0P0000030?ooo`8000000P3oool200000080oooo0`0000040?ooo`L000000P3oool200000080
oooo0P0000030?ooo`8000000P3oool7000000@0oooo303AcJT20?ooo`/00000103oool4000000<0
oooo0P00000I0?ooo`8000000`3oool4000000@0oooo2`0000020?ooo`h0dLfY000<0=7=Z@800000
1@3oool5000000L0oooo1`00000:0?ooo`D000002P3oool7000000L0oooo1@0000050?ooo`800000
303AcJT>00000080oooo1@0000020?ooo`<00000103ooolA00000080oooo1`0000020?ooo`<00000
103oool3000000T0oooo2`3AcJT50?ooo`@000000P3oool300000080oooo1@0000090?ooo`800000
2@3oool3000000@0oooo0P0000030?ooo`8000001@3oool4000000D0oooo0P0000070?ooo`/0dLfY
0P3oool500000080oooo100000050?ooo`@000000P3oool2000000<0oooo0P0000020?ooo`800000
0P3oool3000000@0oooo1`0000020?ooo`8000000P3oool2000000<0oooo0P0000020?ooo`L00000
103oool<0=7=Z@80oooo2`0000040?ooo`@000000`3oool2000001T0oooo0P0000030?ooo`@00000
103oool;00000080oooo3P3AcJT000`0dLfY0P0000050?ooo`D000001`3oool7000000X0oooo1@00
000:0?ooo`L000001`3oool5000000D0oooo0P00000<0=7=Z@h000000P3oool500000080oooo0`00
00040?oooa4000000P3oool700000080oooo0`0000040?ooo`<000002@3oool;0=7=Z@D0oooo1000
00020?ooo`<000000P3oool5000000T0oooo0P0000090?ooo`<00000103oool2000000<0oooo0P00
00050?ooo`@000001@3oool2000000L0oooo2`3AcJT20?ooo`D000001P3oool500000080oooo0P00
00070?ooo`8000000P3oool7000000@0oooo1`0000020?ooo`@000001@3oool;00000080oooo0P00
000<0=7=Z@80oooo2`0000040?ooo`@000000`3oool2000001T0oooo0P0000030?ooo`@00000103o
ool;00000080oooo3P3AcJT000`0dLfY1@0000020?ooo``000009`3oool<00000080oooo1@00000<
0=7=Z@L0oooo1`0000020?ooo`<000002@3oool9000000<0oooo100000030?ooo`@000001`3oool5
000000L0oooo1@0000020?ooo`/0dLfY1@3oool400000080oooo0`0000020?ooo`D000002@3oool2
000000T0oooo0`0000040?ooo`8000000`3oool2000000D0oooo100000050?ooo`8000001`3oool;
0=7=Z@80oooo1@0000060?ooo`D000000P3oool2000000L0oooo0P0000020?ooo`L00000103oool7
00000080oooo100000050?ooo`/000000P3oool2000000`0dLfY0P0000020?ooo`T00000103oool7
000001d0oooo1`0000040?ooo`T000000P3oool2000000h0dLfY000<0=7=Z@D000000P3oool<0000
02L0oooo300000020?ooo`D00000303AcJT70?ooo`L000000P3oool3000000T0oooo2@0000030?oo
o`@000000`3oool4000000L0oooo1@0000070?ooo`D000000P3oool;0=7=Z@8000001`3oool90000
00<0oooo100000070?ooo`8000001@3oool7000000T0oooo0P0000030?ooo`L00000103oool20000
00<0oooo0P00000;0=7=Z@/0oooo0P0000020?ooo`L000000P3oool2000000T0oooo1@0000020?oo
o`800000103oool5000000H0oooo1@0000020?ooo`@000000`3oool200000080oooo303AcJT20000
0080oooo2@0000040?ooo`L000007@3oool7000000@0oooo2@0000020?ooo`8000003P3AcJT000`0
dLfY1`0000030?ooo`T000009`3oool9000000<0oooo1`00000<0=7=Z@80oooo0`0000040?ooo`<0
0000103oool500000080oooo1@00000E0?ooo`D000002@3oool2000000<0oooo2@00000;0=7=Z@80
00001`3oool9000000<0oooo100000070?ooo`8000001@3oool7000000T0oooo0P0000030?ooo`L0
0000103oool2000000<0oooo0P00000;0=7=Z@/0oooo0P0000020?ooo`L000000P3oool2000000T0
oooo1@0000020?ooo`800000103oool5000000H0oooo1@0000020?ooo`@000000`3oool200000080
oooo303AcJT200000080oooo0P0000030?ooo`P00000103oool300000080oooo0P0000020?ooo`80
00003@3oool200000080oooo0P0000020?ooo`<00000103oool8000000<0oooo0P0000020?ooo`80
00003P3AcJT000`0dLfY1`0000030?ooo`T000009`3oool9000000<0oooo1`00000<0=7=Z@80oooo
0`0000040?ooo`<00000103oool500000080oooo1@00000E0?ooo`D000002@3oool2000000<0oooo
2@00000;0=7=Z@L00000103oool7000000L0oooo1`00000@0?ooo`D000002@3oool2000000<0oooo
100000050?ooo`8000002`3AcJT20?ooo`T000001`3oool2000000@0oooo0P0000070?ooo`T00000
0P3oool200000080oooo0`0000020?ooo`d000000P3oool5000000@0oooo303AcJT200000080oooo
0P0000030?ooo`P00000103oool300000080oooo0P0000020?ooo`8000003@3oool200000080oooo
0P0000020?ooo`<00000103oool8000000<0oooo0P0000020?ooo`8000003P3AcJT000`0dLfY2P3o
ool9000000<0oooo2@00000?0?ooo`T000000`3oool9000000X0oooo303AcJT20?ooo`<00000103o
ool3000000@0oooo1@0000020?ooo`D000005@3oool5000000T0oooo0P0000030?ooo`T000002`3A
cJT7000000@0oooo1`0000070?ooo`L00000403oool5000000T0oooo0P0000030?ooo`@000001@3o
ool2000000/0dLfY0P3oool9000000L0oooo0P0000040?ooo`8000001`3oool900000080oooo0P00
00020?ooo`<000000P3oool=00000080oooo1@0000040?ooo``0dLfY0P3oool200000080oooo2`00
00070?ooo`8000000P3oool200000080oooo0P0000090?ooo`8000000P3oool200000080oooo0P00
00070?ooo`/000000P3oool200000080oooo3P3AcJT000`0dLfY2P3oool9000000<0oooo2@00000?
0?ooo`T000000`3oool9000000X0oooo303AcJT700000080oooo1`0000030?ooo`@000001`3oool3
00000080oooo0P0000030?ooo`8000001@3oool7000000@0oooo1`0000030?ooo`8000001`3oool;
0=7=Z@T0oooo0P0000030?ooo`8000001`3oool700000080oooo1`0000020?ooo`<000001P3oool3
00000080oooo0P0000030?ooo`8000000P3oool700000080oooo1@00000;0=7=Z@80oooo2@000007
0?ooo`800000103oool2000000L0oooo2@0000020?ooo`8000000P3oool300000080oooo3@000002
0?ooo`D00000103oool<0=7=Z@80oooo0P0000020?ooo`/000001`3oool200000080oooo0P000002
0?ooo`8000002@3oool200000080oooo0P0000020?ooo`8000001`3oool;00000080oooo0P000002
0?ooo`h0dLfY000<0=7=Z@X0oooo2@0000030?ooo`T000003`3oool9000000<0oooo2@00000:0?oo
o``0dLfY1`0000020?ooo`L000000`3oool4000000L0oooo0`0000020?ooo`8000000`3oool20000
00D0oooo1`0000040?ooo`L000000`3oool2000000L0oooo2`3AcJT90?ooo`8000000`3oool20000
00L0oooo1`0000020?ooo`L000000P3oool3000000H0oooo0`0000020?ooo`8000000`3oool20000
0080oooo1`0000020?ooo`D000002`3AcJT40?ooo`D00000103oool2000000<0oooo0P0000090?oo
o`8000001P3oool300000080oooo0P0000040?ooo`D000000P3oool2000000/0oooo0P0000030?oo
o`@00000303AcJT200000080oooo500000060?ooo`8000000P3oool900000080oooo0P0000060?oo
oa@000000P3oool2000000h0dLfY000<0=7=Z@X0oooo300000020?ooo`D000000P3oool3000000T0
oooo0`0000020?ooo`D000000P3oool<000000X0oooo303AcJT20?oooa`000000`3oool2000000D0
oooo100000030?ooo`@000000`3oool200000080oooo0`0000020?ooo`8000000`3oool700000080
oooo2`3AcJT90?ooo`8000000`3oool2000000L0oooo1`0000020?ooo`L000000P3oool3000000H0
oooo0`0000020?ooo`8000000`3oool200000080oooo1`0000020?ooo`D000002`3AcJT40?ooo`D0
0000103oool2000000<0oooo0P0000090?ooo`8000001P3oool300000080oooo0P0000040?ooo`D0
00000P3oool2000000/0oooo0P0000030?ooo`@00000303AcJT200000080oooo500000060?ooo`80
00000P3oool900000080oooo0P0000060?oooa@000000P3oool2000000h0dLfY000<0=7=Z@X0oooo
300000020?ooo`D000000P3oool3000000T0oooo0`0000020?ooo`D000000P3oool<000000X0oooo
303AcJT20?oooa`000000`3oool2000000D0oooo100000030?ooo`@000000`3oool200000080oooo
0`0000020?ooo`8000000`3oool700000080oooo2`3AcJT50?ooo`800000103oool7000000<0oooo
0P0000020?ooo`D000000P3oool2000000<0oooo2@0000040?ooo`<00000103oool:000000@0oooo
1`00000;0=7=Z@80oooo0P00000@0?oooa@000000P3oool2000000@0oooo1`0000020?ooo`800000
0`3oool2000000T0oooo1000000<0=7=Z@80oooo4`0000030?ooo`8000001P3oool=000000H0oooo
0P0000030?oooa<000000P3oool>0=7=Z@00303AcJT:000000L0oooo1@0000040?ooo`D000000`3o
ool9000000<0oooo1@0000040?ooo`D000001`3oool:000000`0dLfY0P3ooolL000000<0oooo0P00
00050?ooo`@000000`3oool4000000<0oooo0P0000020?ooo`<000000P3oool2000000<0oooo1`00
00020?ooo`/0dLfY1@3oool2000000@0oooo1`0000030?ooo`8000000P3oool500000080oooo0P00
00030?ooo`T00000103oool3000000@0oooo2P0000040?ooo`L000002`3AcJT20?ooo`800000403o
oolD00000080oooo0P0000040?ooo`L000000P3oool2000000<0oooo0P0000090?ooo`@00000303A
cJT20?oooa<000000`3oool2000000H0oooo3@0000060?ooo`8000000`3ooolC00000080oooo3P3A
cJT000`0dLfY2P0000070?ooo`D00000103oool5000000<0oooo2@0000030?ooo`D00000103oool5
000000L0oooo2P00000<0=7=Z@80oooo1@00000<0?ooo`8000000P3oool3000000@0oooo0`000002
0?ooo`8000001@3oool700000080oooo0`0000020?ooo`L000000P3oool5000000L0oooo2`3AcJT9
000000D0oooo0P0000050?ooo`8000001@3oool6000000D0oooo1@0000020?ooo`/000001`3oool7
00000080oooo1@00000;0=7=Z@8000000P3oool700000080oooo0P0000050?ooo`800000103oool3
00000080oooo0P00000=0?ooo`8000000`3oool200000080oooo0P0000020?ooo`<000000P3oool4
000000L0oooo0P00000<0=7=Z@80oooo3@0000020?ooo`@000001@3oool4000000H0oooo1@000006
0?ooo`@000001@3oool400000080oooo3@0000020?ooo`h0dLfY000<0=7=Z@X000001`3oool50000
00@0oooo1@0000030?ooo`T000000`3oool5000000@0oooo1@0000070?ooo`X00000303AcJT20?oo
o`D00000303oool200000080oooo0`0000040?ooo`<000000P3oool2000000D0oooo1`0000020?oo
o`<000000P3oool700000080oooo1@0000070?ooo`/0dLfY2@0000050?ooo`8000001@3oool20000
00D0oooo1P0000050?ooo`D000000P3oool;000000L0oooo1`0000020?ooo`D000002`3AcJT20000
0080oooo1`0000020?ooo`8000001@3oool2000000@0oooo0`0000020?ooo`8000003@3oool20000
00<0oooo0P0000020?ooo`8000000P3oool300000080oooo100000070?ooo`800000303AcJT20?oo
o`d000000P3oool4000000D0oooo100000060?ooo`D000001P3oool4000000D0oooo100000020?oo
o`d000000P3oool>0=7=Z@00303AcJT:000000@0oooo0`0000050?ooo`@000001@3oool?000000D0
oooo100000050?ooo`<00000103oool:000000`0dLfY1`3oool2000000D0oooo0P0000050?ooo`80
00002P3oool200000080oooo0`0000070?ooo`8000000P3oool7000000X0oooo0P0000070?ooo`/0
dLfY1`0000040?ooo`<000001`3oool7000000T0oooo0P00000;0?ooo`<000001`3oool700000080
oooo0P0000050?ooo`8000002`3AcJT40?ooo`D000000P3oool2000000D0oooo1000000=0?ooo`D0
00000P3oool200000080oooo0P0000030?ooo`d000000P3oool700000080oooo0P00000<0=7=Z@80
oooo3@0000020?ooo`@000001@3oool4000000H0oooo1@0000060?ooo`@000001@3oool400000080
oooo3@0000020?ooo`h0dLfY000<0=7=Z@X00000103oool3000000D0oooo100000050?ooo`l00000
1@3oool4000000D0oooo0`0000040?ooo`X00000303AcJT70?ooo`8000001@3oool2000000D0oooo
0P00000:0?ooo`8000000P3oool3000000L0oooo0P0000020?ooo`L000002P3oool2000000L0oooo
2`3AcJT7000000@0oooo0`0000070?ooo`L000002@3oool2000000/0oooo0`0000070?ooo`L00000
0P3oool2000000D0oooo0P00000;0=7=Z@@0oooo1@0000020?ooo`8000001@3oool4000000d0oooo
1@0000020?ooo`8000000P3oool2000000<0oooo3@0000020?ooo`L000000P3oool2000000`0dLfY
0P0000020?ooo`T000000P3oool6000000D0oooo100000040?ooo`8000001@3oool2000000@0oooo
100000050?ooo`H000000P3oool900000080oooo0P00000>0=7=Z@00303AcJT20?ooo`P00000103o
ool5000000<0oooo0P0000020?ooo`X000001@3oool:00000080oooo0P0000030?ooo`D00000103o
ool800000080oooo303AcJT900000140oooo100000050?ooo`L000000P3oool5000000h0oooo1@00
00020?ooo`8000001@3oool;0=7=Z@8000000`3oool@00000080oooo1@00000=0?ooo`<00000103o
ool2000000<0oooo1`0000090?ooo`8000001`3oool;0=7=Z@@0oooo1@0000020?ooo`8000001@3o
ool4000000d0oooo1@0000020?ooo`8000000P3oool2000000<0oooo3@0000020?ooo`L000000P3o
ool2000000`0dLfY0P0000020?ooo`T000000P3oool6000000D0oooo100000040?ooo`8000001@3o
ool2000000@0oooo100000050?ooo`H000000P3oool900000080oooo0P00000>0=7=Z@00303AcJT2
0?ooo`P00000103oool5000000<0oooo0P0000020?ooo`X000001@3oool:00000080oooo0P000003
0?ooo`D00000103oool800000080oooo303AcJT900000140oooo100000050?ooo`L000000P3oool5
000000h0oooo1@0000020?ooo`8000001@3oool;0=7=Z@8000000`3oool@00000080oooo1@00000=
0?ooo`<00000103oool2000000<0oooo1`0000090?ooo`8000001`3oool;0=7=Z@80oooo1@000006
0?ooo`/000000P3oool500000080oooo0P0000070?ooo`800000103oool3000000H0oooo0P00000@
0?ooo`800000303AcJT20?ooo`8000000P3oool500000080oooo0P0000040?ooo`D000001P3oool2
000000@0oooo1@0000040?ooo`8000001P3oool5000000@0oooo0P0000020?ooo`D000000P3oool2
00000080oooo3P3AcJT000`0dLfY0P3oool8000000@0oooo1@0000030?ooo`8000000P3oool:0000
00D0oooo2P0000020?ooo`8000000`3oool5000000@0oooo200000020?ooo``0dLfY2@00000A0?oo
o`@000001@3oool700000080oooo1@00000>0?ooo`D000000P3oool2000000D0oooo2`3AcJT20000
00<0oooo400000020?ooo`D000003@3oool3000000@0oooo0P0000030?ooo`L000002@3oool20000
00L0oooo2`3AcJT20?ooo`D000001P3oool;00000080oooo1@0000020?ooo`8000001`3oool20000
00@0oooo0`0000060?ooo`800000403oool2000000`0dLfY0P3oool200000080oooo1@0000020?oo
o`800000103oool5000000H0oooo0P0000040?ooo`D00000103oool2000000H0oooo1@0000040?oo
o`8000000P3oool500000080oooo0P0000020?ooo`h0dLfY000<0=7=Z@8000000`3oool5000000@0
oooo200000020?ooo`8000000`3oool500000080oooo1@0000020?ooo`D000000`3oool200000080
oooo200000040?ooo`D000000`3oool2000000`0dLfY1@3oool200000080oooo1`0000070?ooo`L0
00000`3oool200000080oooo0`0000020?ooo`L000000P3oool500000080oooo0`0000020?ooo`D0
00000P3oool500000080oooo2`3AcJT2000000D0oooo0P0000020?ooo`<000003P3oool200000080
oooo0P0000070?ooo`<00000103oool2000000D0oooo1`0000020?ooo`L000000P3oool5000000/0
dLfY1`3oool400000080oooo1@0000020?ooo`8000000P3oool2000000L0oooo0P0000050?ooo`@0
0000103oool300000080oooo3@0000020?ooo`T00000303AcJT200000080oooo0P0000050?ooo`80
00000P3oool4000000D0oooo0P0000060?ooo`@000001@3oool4000000H0oooo0P0000050?ooo`@0
00000P3oool2000000D0oooo0P0000020?ooo`8000003P3AcJT000`0dLfY0P0000030?ooo`D00000
103oool800000080oooo0P0000030?ooo`D000000P3oool500000080oooo1@0000030?ooo`800000
0P3oool8000000@0oooo1@0000030?ooo`800000303AcJT50?ooo`8000000P3oool7000000L0oooo
1`0000030?ooo`8000000P3oool300000080oooo1`0000020?ooo`D000000P3oool300000080oooo
1@0000020?ooo`D000000P3oool;0=7=Z@8000001@3oool200000080oooo0`00000>0?ooo`800000
0P3oool2000000L0oooo0`0000040?ooo`8000001@3oool700000080oooo1`0000020?ooo`D00000
2`3AcJT70?ooo`@000000P3oool500000080oooo0P0000020?ooo`8000001`3oool2000000D0oooo
100000040?ooo`<000000P3oool=00000080oooo2@00000<0=7=Z@8000000P3oool2000000D0oooo
0P0000020?ooo`@000001@3oool2000000H0oooo100000050?ooo`@000001P3oool2000000D0oooo
100000020?ooo`8000001@3oool200000080oooo0P00000>0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;
0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;
0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00303AcJT9
0?ooo`8000001P3oool6000000/0oooo3000000;0?ooo`H000003P3oool<0=7=Z@P0oooo50000002
0?ooo`H000003P3oool2000001T0oooo2`3AcJT=0?ooo`<000001P3oool2000000<0oooo0`000005
0?ooo`<000000P3oool600000080oooo0`0000030?ooo`<000005@3oool;0=7=Z@<000000P3oool5
000000D0oooo0`0000050?ooo`<000000P3oool5000000/0oooo1@0000020?ooo`<000001@3oool3
000000D0oooo1@0000020?ooo`<00000303AcJT300000080oooo0P0000030?ooo`D000000P3oool8
000000D0oooo1@0000020?ooo`<000000P3oool5000000D0oooo200000020?ooo`D000000`3oool2
000000<0oooo0P00000>0=7=Z@00303AcJT90?ooo`8000001P3oool6000000/0oooo3000000;0?oo
o`H000003P3oool<0=7=Z@P0oooo500000020?ooo`H000003P3oool2000001T0oooo2`3AcJT=0?oo
o`<000001P3oool2000000<0oooo0`0000050?ooo`<000000P3oool600000080oooo0`0000030?oo
o`<000005@3oool;0=7=Z@<000000P3oool5000000D0oooo0`0000050?ooo`<000000P3oool50000
00/0oooo1@0000020?ooo`<000001@3oool3000000D0oooo1@0000020?ooo`<00000303AcJT30000
0080oooo0P0000030?ooo`D000000P3oool8000000D0oooo1@0000020?ooo`<000000P3oool50000
00D0oooo200000020?ooo`D000000`3oool2000000<0oooo0P00000>0=7=Z@00303AcJT90?ooo`80
00001P3oool6000000/0oooo3000000;0?ooo`H000003P3oool<0=7=Z@P0oooo500000020?ooo`H0
00003P3oool2000001T0oooo2`3AcJT=0?ooo`<000001P3oool2000000<0oooo0`0000050?ooo`<0
00000P3oool600000080oooo0`0000030?ooo`<000005@3oool;0=7=Z@<000000P3oool5000000D0
oooo0`0000050?ooo`<000000P3oool5000000/0oooo1@0000020?ooo`<000001@3oool3000000D0
oooo1@0000020?ooo`<00000303AcJT30?ooo`8000000P3oool:000000<0oooo1@0000070?ooo`<0
00000P3oool300000080oooo0`0000070?ooo`D000000`3oool:00000080oooo0`0000020?ooo`h0
dLfY000<0=7=Z@<0oooo0`0000050?ooo`<000002@3oool3000000D0oooo0`0000030?ooo``00000
3P3oool300000080oooo1P0000030?ooo``0dLfY0`0000030?ooo`8000000`3oool8000000h0oooo
0`0000030?ooo`D000000`3oool5000000<0oooo0`00000@0?ooo`<000002`3AcJT5000000P0oooo
2`00000;0?ooo`P00000203oool600000080oooo0`00000=0?ooo`<000002`3AcJT30?ooo`L00000
203oool5000000<0oooo0P0000050?ooo`<000001@3oool3000000D0oooo0P0000030?ooo`D00000
203oool7000000<0oooo303AcJT30?ooo`8000000P3oool:000000<0oooo1@0000070?ooo`<00000
0P3oool300000080oooo0`0000070?ooo`D000000`3oool:00000080oooo0`0000020?ooo`h0dLfY
000<0=7=Z@<0oooo0`0000050?ooo`<000002@3oool3000000D0oooo0`0000030?ooo``000003P3o
ool300000080oooo1P0000030?ooo``0dLfY0`0000030?ooo`8000000`3oool8000000h0oooo0`00
00030?ooo`D000000`3oool5000000<0oooo0`00000@0?ooo`<000002`3AcJT5000000P0oooo2`00
000;0?ooo`P00000203oool600000080oooo0`00000=0?ooo`<000002`3AcJT30?ooo`L00000203o
ool5000000<0oooo0P0000050?ooo`<000001@3oool3000000D0oooo0P0000030?ooo`D00000203o
ool7000000<0oooo303AcJT30?ooo`8000000P3oool:000000<0oooo1@0000070?ooo`<000000P3o
ool300000080oooo0`0000070?ooo`D000000`3oool:00000080oooo0`0000020?ooo`h0dLfY000<
0=7=Z@<0oooo0`0000050?ooo`<000002@3oool3000000D0oooo0`0000030?ooo``000003P3oool3
00000080oooo1P0000030?ooo``0dLfY0`0000030?ooo`8000000`3oool8000000h0oooo0`000003
0?ooo`D000000`3oool5000000<0oooo0`00000@0?ooo`<000002`3AcJT30?ooo`P000000P3oool;
000000<0oooo2`0000050?ooo`D000001P3oool;00000080oooo200000030?ooo`/0dLfY2P000003
0?ooo`D00000203oool2000000D0oooo2`0000050?ooo`800000203oool5000000<0oooo2P00000<
0=7=Z@<000000P3oool5000000D0oooo1`0000030?ooo`800000203oool7000000P0oooo0P000003
0?ooo`L000001@3oool5000000<0oooo0P00000>0=7=Z@00303AcJT30?ooo`P000001P3oool30000
00<0oooo3P0000030?ooo`H000000`3oool2000000<0oooo1P0000030?ooo`<000000P3oool30000
00H0oooo303AcJT60?ooo`D000000`3oool3000000D0oooo3P0000030?ooo`8000000`3oool80000
00<0oooo0`0000080?ooo`P000000`3oool;0=7=Z@<0oooo200000020?ooo`/000000`3oool;0000
00D0oooo1@0000060?ooo`/000000P3oool8000000<0oooo2`3AcJT:000000<0oooo1@0000080?oo
o`8000001@3oool;000000D0oooo0P0000080?ooo`D000000`3oool:000000`0dLfY0`0000020?oo
o`D000001@3oool7000000<0oooo0P0000080?ooo`L00000203oool2000000<0oooo1`0000050?oo
o`D000000`3oool2000000h0dLfY000<0=7=Z@<0oooo200000060?ooo`<000000`3oool>000000<0
oooo1P0000030?ooo`8000000`3oool6000000<0oooo0`0000020?ooo`<000001P3oool<0=7=Z@H0
oooo1@0000030?ooo`<000001@3oool>000000<0oooo0P0000030?ooo`P000000`3oool3000000P0
oooo200000030?ooo`/0dLfY0`3oool800000080oooo2`0000030?ooo`/000001@3oool5000000H0
oooo2`0000020?ooo`P000000`3oool;0=7=Z@X000000`3oool5000000P0oooo0P0000050?ooo`/0
00001@3oool2000000P0oooo1@0000030?ooo`X00000303AcJT30?ooo`L000001@3oool500000080
oooo0`0000020?ooo`D000000`3oool7000000<0oooo1@0000020?ooo`<000000P3oool5000000D0
oooo200000020?ooo`h0dLfY000<0=7=Z@<0oooo200000060?ooo`<000000`3oool>000000<0oooo
1P0000030?ooo`8000000`3oool6000000<0oooo0`0000020?ooo`<000001P3oool<0=7=Z@<0oooo
1@0000090?ooo`D00000203oool9000000D0oooo0`0000030?ooo`8000000`3oool3000000D0oooo
0`0000030?ooo`P000002`3AcJT30?ooo`D000000`3oool=000000P0oooo2000000;0?ooo`<00000
0`3oool2000000<0oooo1@0000060?ooo`8000000`3oool;0=7=Z@d000001@3oool3000000L0oooo
1@0000030?ooo`D000000`3oool5000000L0oooo0`0000050?ooo`d00000303AcJT30?ooo`L00000
1@3oool500000080oooo0`0000020?ooo`D000000`3oool7000000<0oooo1@0000020?ooo`<00000
0P3oool5000000D0oooo200000020?ooo`h0dLfY000<0=7=Z@T0oooo0P00000?0?ooo`h000000`3o
ool3000000<0oooo0P0000060?ooo`<000000`3oool8000000<0oooo0`00000<0=7=Z@<0oooo1@00
00090?ooo`D00000203oool9000000D0oooo0`0000030?ooo`8000000`3oool3000000D0oooo0`00
00030?ooo`P000002`3AcJT30?ooo`D000000`3oool=000000P0oooo2000000;0?ooo`<000000`3o
ool2000000<0oooo1@0000060?ooo`8000000`3oool;0=7=Z@d000001@3oool3000000L0oooo1@00
00030?ooo`D000000`3oool5000000L0oooo0`0000050?ooo`d00000303AcJT30?ooo`L000001@3o
ool500000080oooo0`0000020?ooo`D000000`3oool7000000<0oooo1@0000020?ooo`<000000P3o
ool5000000D0oooo200000020?ooo`h0dLfY000<0=7=Z@T0oooo0P00000?0?ooo`h000000`3oool3
000000<0oooo0P0000060?ooo`<000000`3oool8000000<0oooo0`00000<0=7=Z@<0oooo1@000009
0?ooo`D00000203oool9000000D0oooo0`0000030?ooo`8000000`3oool3000000D0oooo0`000003
0?ooo`P000002`3AcJT30?ooo`D000000`3oool=000000P0oooo2000000;0?ooo`<000000`3oool2
000000<0oooo1@0000060?ooo`8000000`3oool;0=7=Z@P0oooo1`0000030?ooo`<000002P3oool2
000000/0oooo0P00000:0?ooo`<000000`3oool7000000P0oooo303AcJT5000000D0oooo1@000002
0?ooo`<000000P3oool3000000D0oooo1@0000020?ooo`<000000P3oool5000000D0oooo0`000002
0?ooo`<000000P3oool5000000D0oooo1@00000>0=7=Z@00303AcJT30?ooo`P000000`3oool60000
0140oooo300000020?ooo`T000002`3oool3000000<0oooo303AcJT6000000D0oooo1P0000020?oo
o`<000000`3oool@000000H0oooo0`0000050?ooo`<000000`3oool8000000P0oooo2`3AcJT30000
0080oooo0`0000030?ooo`/000000P3oool6000000D0oooo2`00000;0?ooo`8000000`3oool@0000
00/0dLfY203oool7000000<0oooo0`00000:0?ooo`8000002`3oool2000000X0oooo0`0000030?oo
o`L00000203oool<0=7=Z@D000001@3oool500000080oooo0`0000020?ooo`<000001@3oool50000
0080oooo0`0000020?ooo`D000001@3oool300000080oooo0`0000020?ooo`D000001@3oool50000
00h0dLfY000<0=7=Z@<0oooo200000030?ooo`H000004@3oool<00000080oooo2@00000;0?ooo`<0
00000`3oool<0=7=Z@H000001@3oool600000080oooo0`0000030?oooa0000001P3oool3000000D0
oooo0`0000030?ooo`P00000203oool;0=7=Z@<000000P3oool3000000<0oooo2`0000020?ooo`H0
00001@3oool;000000/0oooo0P0000030?oooa0000002`3AcJT80?ooo`L000000`3oool3000000X0
oooo0P00000;0?ooo`8000002P3oool3000000<0oooo1`0000080?ooo``0dLfY1@0000050?ooo`L0
00000`3oool2000000X0oooo3@00000:0?ooo`8000000`3oool7000000D0oooo1@00000>0=7=Z@00
303AcJT30?ooo`P000000`3oool600000140oooo300000020?ooo`T000002`3oool3000000<0oooo
303AcJT6000000D0oooo1P0000020?ooo`<000000`3oool@000000H0oooo0`0000050?ooo`<00000
0`3oool8000000P0oooo2`3AcJT300000080oooo200000030?ooo`<000001@3oool600000080oooo
0`0000050?ooo`H000000P3oool900000080oooo1P0000050?ooo`D000000`3oool;0=7=Z@D0oooo
0`0000020?ooo`P000003`3oool3000000D0oooo0`00000?0?ooo`P000000P3oool3000000D0oooo
303AcJT5000000D0oooo1`0000030?ooo`8000002P3oool=000000X0oooo0P0000030?ooo`L00000
1@3oool5000000h0dLfY000<0=7=Z@<000002`3oool3000000<0oooo0`0000030?ooo`<00000203o
ool3000000T0oooo4@00000;0?ooo``0dLfY0`00000;0?ooo`D000001P3oool300000080oooo0`00
00030?ooo`<000001@3oool;000000<0oooo1@0000060?ooo`D000000`3oool;0=7=Z@<000000P3o
ool8000000<0oooo0`0000050?ooo`H000000P3oool3000000D0oooo1P0000020?ooo`T000000P3o
ool6000000D0oooo1@0000030?ooo`/0dLfY1@3oool300000080oooo2000000?0?ooo`<000001@3o
ool3000000l0oooo200000020?ooo`<000001@3oool<0=7=Z@D000001@3oool7000000<0oooo0P00
000:0?ooo`d000002P3oool2000000<0oooo1`0000050?ooo`D000003P3AcJT000`0dLfY0`00000;
0?ooo`<000000`3oool3000000<0oooo0`0000080?ooo`<000002@3ooolA000000/0oooo303AcJT3
000000/0oooo1@0000060?ooo`<000000P3oool3000000<0oooo0`0000050?ooo`/000000`3oool5
000000H0oooo1@0000030?ooo`/0dLfY0`0000020?ooo`P000000`3oool3000000D0oooo1P000002
0?ooo`<000001@3oool600000080oooo2@0000020?ooo`H000001@3oool5000000<0oooo2`3AcJT3
00000080oooo0`0000050?oooa8000000P3oool3000000D0oooo0`0000020?oooa8000001@3oool3
00000080oooo0`00000<0=7=Z@<0oooo1`0000020?ooo`l000000`3oool2000000<0oooo1`000003
0?ooo`8000000`3oool?00000080oooo200000020?ooo`h0dLfY000<0=7=Z@<000002`3oool30000
00<0oooo0`0000030?ooo`<00000203oool3000000T0oooo4@00000;0?ooo``0dLfY0`00000;0?oo
o`D000001P3oool300000080oooo0`0000030?ooo`<000001@3oool;000000<0oooo1@0000060?oo
o`D000000`3oool;0=7=Z@D000002`3oool8000000P0oooo3P0000080?ooo`<000000P3oool;0000
00D0oooo0`00000;0=7=Z@<000000P3oool3000000D0oooo4P0000020?ooo`<000001@3oool30000
0080oooo4P0000050?ooo`<000000P3oool3000000`0dLfY0`3oool700000080oooo3`0000030?oo
o`8000000`3oool7000000<0oooo0P0000030?ooo`l000000P3oool800000080oooo3P3AcJT000`0
dLfY0`0000030?ooo`/000000`3oool3000000H0oooo0P0000060?ooo`<000000`3oool6000000h0
oooo0`0000020?ooo`<000000`3oool3000000`0dLfY0`3oool5000000<0oooo1P0000020?ooo`T0
00001@3oool8000000<0oooo0`0000050?ooo`H000000`3oool;00000080oooo0`00000;0=7=Z@D0
00002`3oool8000000P0oooo3P0000080?ooo`<000000P3oool;000000D0oooo0`00000;0=7=Z@<0
00000P3oool3000000D0oooo4P0000020?ooo`<000001@3oool300000080oooo4P0000050?ooo`<0
00000P3oool3000000`0dLfY0`0000020?ooo`L000000`3oool:00000080oooo5`0000020?ooo`X0
00000`3oool7000000<0oooo0P00000>0=7=Z@00303AcJT3000000<0oooo2`0000030?ooo`<00000
1P3oool2000000H0oooo0`0000030?ooo`H000003P3oool300000080oooo0`0000030?ooo`<00000
303AcJT30?ooo`D000000`3oool600000080oooo2@0000050?ooo`P000000`3oool3000000D0oooo
1P0000030?ooo`/000000P3oool3000000/0dLfY1@00000;0?ooo`P00000203oool>000000P0oooo
0`0000020?ooo`/000001@3oool3000000/0dLfY0`3oool2000000<0oooo1@0000020?oooa800000
2`3ooolB00000080oooo1@0000030?ooo`8000000`3oool<0=7=Z@<000000P3oool7000000<0oooo
2P0000020?oooaL000000P3oool:000000<0oooo1`0000030?ooo`8000003P3AcJT000`0dLfY0`00
00030?ooo`/000000`3oool3000000H0oooo0P0000060?ooo`<000000`3oool6000000h0oooo0`00
00020?ooo`<000000`3oool3000000`0dLfY0`0000030?ooo`/000000P3oool3000000H0oooo1@00
00030?ooo`<000001@3oool3000000D0oooo1P0000030?ooo`P000000`3oool2000000<0oooo2`3A
cJT300000080oooo0`0000030?ooo`8000002@3oool5000000<0oooo200000050?ooo`<00000203o
ool5000000/0oooo2000000;0=7=Z@<0oooo0P0000030?ooo`D000000P3ooolB000000/0oooo4P00
00020?ooo`D000000`3oool2000000<0oooo303AcJT300000080oooo1`0000030?ooo`X000000P3o
oolG00000080oooo2P0000030?ooo`L000000`3oool2000000h0dLfY000<0=7=Z@H0oooo0`000002
0?ooo`H000000`3oool3000000<0oooo0`0000050?ooo`H000001P3oool5000000<0oooo2@00000;
0?ooo`<00000303AcJT3000000<0oooo2`0000020?ooo`<000001P3oool5000000<0oooo0`000005
0?ooo`<000001@3oool6000000<0oooo200000030?ooo`8000000`3oool;0=7=Z@<000000P3oool3
000000<0oooo0P0000090?ooo`D000000`3oool8000000D0oooo0`0000080?ooo`D000002`3oool8
000000/0dLfY0`3oool2000000<0oooo1@0000020?oooa8000002`3ooolB00000080oooo1@000003
0?ooo`8000000`3oool<0=7=Z@L000001@3ooolB000000D0oooo1`0000050?oooa8000001@3oool7
000000h0dLfY000<0=7=Z@H0oooo0`0000020?ooo`H000000`3oool3000000<0oooo0`0000050?oo
o`H000001P3oool5000000<0oooo2@00000;0?ooo`<00000303AcJT3000000<0oooo2`0000020?oo
o`<000001P3oool5000000<0oooo0`0000050?ooo`<000001@3oool6000000<0oooo200000030?oo
o`8000000`3oool;0=7=Z@D0oooo1P0000080?ooo`P000001@3oool3000000P0oooo0`0000020?oo
o`T000002P3oool8000000<0oooo2`3AcJT30?ooo`8000002P3oool@00000080oooo0`0000050?oo
o`<000000P3oool@000000X0oooo0P0000030?ooo``0dLfY1`0000050?oooa8000001@3oool70000
00D0oooo4P0000050?ooo`L000003P3AcJT000`0dLfY1P3oool300000080oooo1P0000030?ooo`<0
00000`3oool3000000D0oooo1P0000060?ooo`D000000`3oool9000000/0oooo0`00000<0=7=Z@<0
oooo0`0000020?ooo`<000001P3oool2000000/0oooo0`0000080?ooo`T000001@3oool8000000<0
oooo2`00000;0=7=Z@D0oooo1P0000080?ooo`P000001@3oool3000000P0oooo0`0000020?ooo`T0
00002P3oool8000000<0oooo2`3AcJT30?ooo`8000002P3oool@00000080oooo0`0000050?ooo`<0
00000P3oool@000000X0oooo0P0000030?ooo``0dLfY1@0000020?ooo`D000000`3ooolA000000<0
oooo1`0000030?oooa4000000`3oool500000080oooo1@00000>0=7=Z@00303AcJT;0?ooo`H00000
1P3oool6000000D0oooo0`0000060?ooo`<000000`3oool5000000h0oooo1P0000030?ooo``0dLfY
0`3oool300000080oooo0`0000060?ooo`8000002`3oool3000000P0oooo2@0000050?ooo`P00000
0`3oool;000000/0dLfY1@3oool6000000P0oooo200000050?ooo`<00000203oool300000080oooo
2@00000:0?ooo`P000000`3oool;0=7=Z@<00000303ooolB000000/0oooo4P00000<0?ooo`<00000
303AcJT500000080oooo1@0000030?oooa4000000`3oool7000000<0oooo4@0000030?ooo`D00000
0P3oool5000000h0dLfY000<0=7=Z@/0oooo1P0000060?ooo`H000001@3oool3000000H0oooo0`00
00030?ooo`D000003P3oool6000000<0oooo303AcJT30?ooo`<000000P3oool3000000H0oooo0P00
000;0?ooo`<00000203oool9000000D0oooo200000030?ooo`/000002`3AcJT=000000<0oooo1P00
00020?ooo`/000000`3oool2000000H0oooo200000080?ooo`<000000P3oool3000000D0oooo0`00
000;0=7=Z@<00000303ooolB000000/0oooo4P00000<0?ooo`<00000303AcJT500000080oooo1@00
00030?oooa4000000`3oool7000000<0oooo4@0000030?ooo`D000000P3oool5000000h0dLfY000<
0=7=Z@/0oooo1P0000060?ooo`H000001@3oool3000000H0oooo0`0000030?ooo`D000003P3oool6
000000<0oooo303AcJT30?ooo`D000001P3oool8000000H0oooo0P0000030?ooo`<000000`3oool;
000000D0oooo0`0000030?ooo`/000001@3oool;0=7=Z@d000000`3oool600000080oooo2`000003
0?ooo`8000001P3oool8000000P0oooo0`0000020?ooo`<000001@3oool3000000/0dLfY0`00000<
0?oooa8000002`3ooolB000000`0oooo0`00000<0=7=Z@D0oooo0P0000080?ooo`8000000`3oool7
000000P0oooo1`0000080?ooo`L000000`3oool2000000P0oooo0P0000050?ooo`h0dLfY000<0=7=
Z@H0oooo1@0000030?ooo`<000000`3oool900000080oooo3`0000030?ooo`P000000`3oool30000
00<0oooo1@0000060?ooo``0dLfY0`3oool5000000H0oooo200000060?ooo`8000000`3oool30000
00<0oooo2`0000050?ooo`<000000`3oool;000000D0oooo2`3AcJT=000000<0oooo1P0000020?oo
o`/000000`3oool2000000H0oooo200000080?ooo`<000000P3oool3000000D0oooo0`00000;0=7=
Z@<0oooo1@0000070?oooa0000003`3oool@000000L0oooo1@0000030?ooo``0dLfY1@3oool20000
00P0oooo0P0000030?ooo`L00000203oool7000000P0oooo1`0000030?ooo`800000203oool20000
00D0oooo3P3AcJT000`0dLfY1P3oool5000000<0oooo0`0000030?ooo`T000000P3oool?000000<0
oooo200000030?ooo`<000000`3oool5000000H0oooo303AcJT30?ooo`D000001P3oool8000000H0
oooo0P0000030?ooo`<000000`3oool;000000D0oooo0`0000030?ooo`/000001@3oool;0=7=Z@D0
oooo1P0000020?ooo`<00000203oool3000000<0oooo1@0000080?ooo`D000000`3oool6000000D0
oooo200000080?ooo`/0dLfY0`3oool5000000L0oooo4000000?0?oooa0000001`3oool5000000<0
oooo303AcJT70?ooo`<000001`3oool800000080oooo5`0000020?ooo`P000001`3oool3000000L0
oooo3P3AcJT000`0dLfY1P3oool5000000<0oooo0`0000030?ooo`T000000P3oool?000000<0oooo
200000030?ooo`<000000`3oool5000000H0oooo303AcJT3000000<0oooo0P0000060?ooo`D00000
0`3oool3000000D0oooo0`0000060?ooo`P00000203oool6000000P0oooo2000000;0=7=Z@D0oooo
1P0000020?ooo`<00000203oool3000000<0oooo1@0000080?ooo`D000000`3oool6000000D0oooo
200000080?ooo`/0dLfY0`0000050?ooo`8000001@3oool@000000l0oooo400000050?ooo`800000
1@3oool3000000`0dLfY1`3oool3000000L0oooo200000020?oooaL000000P3oool8000000L0oooo
0`0000070?ooo`h0dLfY000<0=7=Z@<0oooo0`0000050?ooo`<000000`3oool600000140oooo0`00
000>0?ooo`<000001P3oool5000000H0oooo303AcJT3000000<0oooo0P0000060?ooo`D000000`3o
ool3000000D0oooo0`0000060?ooo`P00000203oool6000000P0oooo2000000;0=7=Z@/0oooo0P00
00060?ooo`<000000P3oool6000000P0oooo1@0000030?ooo`/000001@3oool300000080oooo1P00
00050?ooo`/0dLfY0`0000050?ooo`8000001@3oool@000000l0oooo400000050?ooo`8000001@3o
ool3000000`0dLfY1`3oool3000000L0oooo200000020?oooaL000000P3oool8000000L0oooo0`00
00070?ooo`h0dLfY000<0=7=Z@<0oooo0`0000050?ooo`<000000`3oool600000140oooo0`00000>
0?ooo`<000001P3oool5000000H0oooo303AcJT3000000P0oooo0`0000030?ooo`D000000`3oool3
00000080oooo0`0000060?ooo`P00000203oool3000001<0oooo2`3AcJT;0?ooo`8000001P3oool3
00000080oooo1P0000080?ooo`D000000`3oool;000000D0oooo0`0000020?ooo`H000001@3oool;
0=7=Z@<000001@3oool2000000D0oooo4000000?0?oooa0000001@3oool2000000D0oooo0`00000<
0=7=Z@<00000103oool5000000<0oooo1@0000020?ooo`<000000P3oool5000000<0oooo1`000003
0?ooo`D000000P3oool300000080oooo1@0000030?ooo`D000001@3oool2000000h0dLfY000<0=7=
Z@h000000`3oool3000000<0oooo1P0000020?ooo`<000000`3oool3000000<0oooo0`0000030?oo
o`8000003`3oool8000000<0oooo303AcJT3000000P0oooo0`0000030?ooo`D000000`3oool30000
0080oooo0`0000060?ooo`P00000203oool3000001<0oooo2`3AcJT;0?ooo`8000001P3oool30000
0080oooo1P0000080?ooo`D000000`3oool;000000D0oooo0`0000020?ooo`H000001@3oool;0=7=
Z@<000001@3oool5000000D0oooo0`0000020?ooo`<000001@3oool5000000D0oooo1@0000050?oo
o`<000000P3oool3000000D0oooo1@0000050?ooo`<00000303AcJT3000000@0oooo1@0000030?oo
o`D000000P3oool300000080oooo1@0000030?ooo`L000000`3oool500000080oooo0`0000020?oo
o`D000000`3oool5000000D0oooo0P00000>0=7=Z@00303AcJT>000000<0oooo0`0000030?ooo`H0
00000P3oool3000000<0oooo0`0000030?ooo`<000000`3oool2000000l0oooo200000030?ooo``0
dLfY0`0000080?ooo`<000000`3oool5000000<0oooo0`0000020?ooo`<000001P3oool8000000P0
oooo0`00000C0?ooo`/0dLfY1@3oool3000000<0oooo0P00000A0?oooa8000002@3oool2000000<0
oooo0`0000020?ooo`/000002`3AcJT3000000D0oooo1@0000050?ooo`<000000P3oool3000000D0
oooo1@0000050?ooo`D000001@3oool300000080oooo0`0000050?ooo`D000001@3oool3000000`0
dLfY1@0000050?ooo`D000000P3oool3000000L0oooo0`0000020?ooo`d000000P3oool3000000L0
oooo0`0000020?ooo`D000001@3oool5000000h0dLfY000<0=7=Z@h000000`3oool3000000<0oooo
1P0000020?ooo`<000000`3oool3000000<0oooo0`0000030?ooo`8000003`3oool8000000<0oooo
303AcJT3000000P0oooo1P0000080?ooo`<000001@3ooolF000000<0oooo1@0000030?ooo`H00000
1@3oool;0=7=Z@D0oooo0`0000030?ooo`8000004@3ooolB000000T0oooo0P0000030?ooo`<00000
0P3oool;000000/0dLfY0`3oool5000000D0oooo1@0000030?ooo`800000203oool5000000D0oooo
1@0000080?ooo`8000000`3oool5000000D0oooo1@0000030?ooo``0dLfY1@0000050?ooo`D00000
0P3oool3000000L0oooo0`0000020?ooo`d000000P3oool3000000L0oooo0`0000020?ooo`D00000
1@3oool5000000h0dLfY000<0=7=Z@T000000P3oool3000000`0oooo1@0000030?ooo`<000000`3o
ool3000000H0oooo200000090?ooo`D000000`3oool3000000`0dLfY0`0000080?ooo`H00000203o
ool3000000D0oooo5P0000030?ooo`D000000`3oool6000000D0oooo2`3AcJT50?ooo`<000000`3o
ool200000140oooo4P0000090?ooo`8000000`3oool300000080oooo2`00000;0=7=Z@<0oooo1@00
00050?ooo`D000000`3oool2000000P0oooo1@0000050?ooo`D00000203oool2000000<0oooo1@00
00050?ooo`D000000`3oool<0=7=Z@D000001@3oool500000080oooo0`0000070?ooo`<000000P3o
ool=00000080oooo0`0000070?ooo`<000000P3oool5000000D0oooo1@00000>0=7=Z@00303AcJT9
00000080oooo0`00000<0?ooo`D000000`3oool3000000<0oooo0`0000060?ooo`P000002@3oool5
000000<0oooo0`00000<0=7=Z@<00000203oool6000000P0oooo0`0000050?oooaH000000`3oool5
000000<0oooo1P0000050?ooo`/0dLfY0`0000020?ooo`<000000`3oool8000000D0oooo2000000>
0?ooo`D000000`3oool;00000080oooo1P0000020?ooo`<000002`3AcJT30?ooo`D000001@3oool5
000000<0oooo0P0000080?ooo`D000001@3oool5000000P0oooo0P0000030?ooo`D000001@3oool5
000000<0oooo303AcJT50?ooo`D000000P3ooole00000080oooo1@0000050?ooo`h0dLfY000<0=7=
Z@T000000P3oool3000000`0oooo1@0000030?ooo`<000000`3oool3000000H0oooo200000090?oo
o`D000000`3oool3000000`0dLfY0`0000030?ooo`P000000`3oool2000000<0oooo200000030?oo
o`h000001@3oool>000000H0oooo1@00000;0=7=Z@<000000P3oool3000000<0oooo200000050?oo
o`P000003P3oool5000000<0oooo2`0000020?ooo`H000000P3oool3000000/0dLfY1@3oool50000
01X0oooo1@00000J0?ooo`D000001@3oool<0=7=Z@D0oooo1@0000020?ooocD000000P3oool50000
00D0oooo3P3AcJT000`0dLfY1P0000030?ooo`h000000`3oool300000080oooo0`0000030?ooo`<0
00000`3oool3000000<0oooo0P0000030?ooo`h000000`3oool6000000`0dLfY0`0000030?ooo`P0
00000`3oool2000000<0oooo200000030?ooo`h000001@3oool>000000H0oooo1@00000;0=7=Z@<0
00000P3oool300000100oooo1P0000080?ooo`800000203oool600000100oooo0`0000020?ooo`<0
00002`3AcJT50?ooo`D000006P3oool5000001X0oooo1@0000050?ooo``0dLfYC@00000>0=7=Z@00
303AcJT6000000<0oooo3P0000030?ooo`<000000P3oool3000000<0oooo0`0000030?ooo`<00000
0`3oool2000000<0oooo3P0000030?ooo`H00000303AcJT3000000<0oooo200000030?ooo`800000
0`3oool8000000<0oooo3P0000050?ooo`h000001P3oool5000000/0dLfY0`0000020?ooo`<00000
403oool6000000P0oooo0P0000080?ooo`H00000403oool300000080oooo0`00000;0=7=Z@D0oooo
1@00000J0?ooo`D000006P3oool5000000D0oooo303AcJU=000000h0dLfY000<0=7=Z@H000000`3o
ool>000000<0oooo0`0000020?ooo`<000000`3oool3000000<0oooo0`0000030?ooo`8000000`3o
ool>000000<0oooo1P00000<0=7=Z@<0oooo0`00000;0?ooo`D000000`3ooolC000000h0oooo1@00
00030?ooo`H000001@3oool;0=7=Z@<000000P3oool300000100oooo1P0000080?ooo`800000203o
ool600000100oooo0`0000020?ooo`<000002`3AcJT50?ooo`D000006P3oool5000001X0oooo1@00
00050?ooo``0dLfYC@00000>0=7=Z@00303AcJT3000000<0oooo1@0000090?ooo`T000001@3oool3
000000<0oooo0`0000030?ooo`D00000303oool300000080oooo2@00000<0=7=Z@<0oooo0`00000;
0?ooo`D000000`3ooolC000000h0oooo1@0000030?ooo`H000001@3oool;0=7=Z@<000003@3oool3
000000<0oooo0P0000030?ooo`<000004P3oool6000000<0oooo1@0000030?ooo`D000001@3oool3
000000/0dLfY1@3oool5000001X0oooo1@00000J0?ooo`D000001@3oool<0=7=Z@D0oooo1@000002
0?ooocD000000P3oool5000000D0oooo3P3AcJT000`0dLfY0`0000030?ooo`D000002@3oool90000
00D0oooo0`0000030?ooo`<000000`3oool5000000`0oooo0`0000020?ooo`T00000303AcJT;0?oo
o`/000000`3oool300000080oooo3P0000030?ooo`/000000`3oool2000000<0oooo1P0000020?oo
o`<000002`3AcJT3000000d0oooo0`0000030?ooo`8000000`3oool300000180oooo1P0000030?oo
o`D000000`3oool5000000D0oooo0`00000;0=7=Z@<0oooo1@0000050?ooo`D000000`3oool20000
00P0oooo1@0000050?ooo`D00000203oool2000000<0oooo1@0000050?ooo`D000000`3oool<0=7=
Z@D0oooo1@0000020?ooocD000000P3oool5000000D0oooo3P3AcJT000`0dLfY0`0000030?ooo`D0
00002@3oool9000000D0oooo0`0000030?ooo`<000000`3oool5000000`0oooo0`0000020?ooo`T0
0000303AcJT;0?ooo`/000000`3oool300000080oooo3P0000030?ooo`/000000`3oool2000000<0
oooo1P0000020?ooo`<000002`3AcJT30?ooo`8000003P3oool5000000P0oooo3P0000080?ooo`<0
00001@3oool8000000D0oooo0`00000;0=7=Z@<0oooo1@0000050?ooo`D000000`3oool2000000P0
oooo1@0000050?ooo`D00000203oool2000000<0oooo1@0000050?ooo`D000000`3oool<0=7=Z@D0
00001@3oool500000080oooo0`0000070?ooo`<000000P3oool=00000080oooo0`0000070?ooo`<0
00000P3oool5000000D0oooo1@00000>0=7=Z@00303AcJT30?ooo`P000003`3oool300000080oooo
0`0000030?ooo`<000000`3oool3000000<0oooo1@0000030?ooo`<000000`3oool>000000`0dLfY
2`3oool;000000<0oooo0`0000020?ooo`h000000`3oool;000000<0oooo0P0000030?ooo`H00000
0P3oool3000000/0dLfY0`3oool2000000h0oooo1@0000080?ooo`h00000203oool3000000D0oooo
200000050?ooo`<000002`3AcJT30?ooo`D000001@3oool5000000<0oooo0P0000080?ooo`D00000
1@3oool5000000P0oooo0P0000030?ooo`D000001@3oool5000000<0oooo303AcJT5000000D0oooo
1@0000020?ooo`<000001`3oool300000080oooo3@0000020?ooo`<000001`3oool300000080oooo
1@0000050?ooo`D000003P3AcJT000`0dLfY0`3oool8000000l0oooo0`0000020?ooo`<000000`3o
ool3000000<0oooo0`0000030?ooo`D000000`3oool3000000<0oooo3P00000<0=7=Z@<000000`3o
ool2000000H0oooo0`0000020?ooo`H000000`3oool2000000T0oooo1@0000030?oooa<000000`3o
ool3000000D0oooo2`3AcJT30?ooo`8000003P3oool5000000P0oooo3P0000080?ooo`<000001@3o
ool8000000D0oooo0`00000;0=7=Z@<000001@3oool5000000D0oooo0`0000020?ooo`<000001@3o
ool5000000D0oooo1@0000050?ooo`<000000P3oool3000000D0oooo1@0000050?ooo`<00000303A
cJT5000000D0oooo1@0000020?ooo`<000001`3oool300000080oooo3@0000020?ooo`<000001`3o
ool300000080oooo1@0000050?ooo`D000003P3AcJT000`0dLfY0`3oool8000000l0oooo0`000002
0?ooo`<000000`3oool3000000<0oooo0`0000030?ooo`D000000`3oool3000000<0oooo3P00000<
0=7=Z@<000000`3oool2000000H0oooo0`0000020?ooo`H000000`3oool2000000T0oooo1@000003
0?oooa<000000`3oool3000000D0oooo2`3AcJT30?ooo`X000000`3oool3000000P0oooo0`000002
0?ooo`P000000`3oool8000000<0oooo2`0000080?ooo`8000000`3oool;0=7=Z@<000001@3oool5
000000D0oooo0`0000020?ooo`<000001@3oool5000000D0oooo1@0000050?ooo`<000000P3oool3
000000D0oooo1@0000050?ooo`<00000303AcJT3000000@0oooo1@0000030?ooo`D000000P3oool3
00000080oooo1@0000030?ooo`L000000`3oool500000080oooo0`0000020?ooo`D000000`3oool5
000000D0oooo0P00000>0=7=Z@00303AcJT60?ooo`D000001P3oool3000000h0oooo0`00000A0?oo
o`H000000`3oool3000000D0oooo0`0000030?ooo``0dLfY0`0000030?ooo`8000001P3oool30000
0080oooo1P0000030?ooo`8000002@3oool5000000<0oooo4`0000030?ooo`<000001@3oool;0=7=
Z@<0oooo2P0000030?ooo`<00000203oool300000080oooo200000030?ooo`P000000`3oool;0000
00P0oooo0P0000030?ooo`/0dLfY0`0000050?ooo`8000001@3oool@000000l0oooo400000050?oo
o`8000001@3oool3000000`0dLfY0`0000040?ooo`D000000`3oool500000080oooo0`0000020?oo
o`D000000`3oool7000000<0oooo1@0000020?ooo`<000000P3oool5000000<0oooo1@0000050?oo
o`8000003P3AcJT000`0dLfY1P3oool5000000H0oooo0`00000>0?ooo`<000004@3oool6000000<0
oooo0`0000050?ooo`<000000`3oool<0=7=Z@H0oooo1@0000080?ooo`<000001P3oool2000000<0
oooo1P0000080?ooo`<000000P3oool3000000H0oooo0P0000030?ooo`P000000`3oool;0=7=Z@<0
oooo2P0000030?ooo`<00000203oool300000080oooo200000030?ooo`P000000`3oool;000000P0
oooo0P0000030?ooo`/0dLfY0`0000050?ooo`8000001@3oool@000000l0oooo400000050?ooo`80
00001@3oool3000000`0dLfY1`3oool3000000L0oooo200000020?oooaL000000P3oool8000000L0
oooo0`0000070?ooo`h0dLfY000<0=7=Z@H0oooo1@0000030?ooo`<000000`3oool900000080oooo
3`0000030?ooo`P000000`3oool3000000<0oooo1@0000060?ooo``0dLfY1P3oool5000000P0oooo
0`0000060?ooo`8000000`3oool6000000P0oooo0`0000020?ooo`<000001P3oool2000000<0oooo
200000030?ooo`/0dLfY1@3oool600000080oooo0`0000080?ooo`<000000`3oool5000000P0oooo
1@0000030?ooo`H000001@3oool8000000P0oooo2`3AcJT3000000D0oooo0P0000050?oooa000000
3`3oool@000000D0oooo0P0000050?ooo`<00000303AcJT70?ooo`<000001`3oool800000080oooo
5`0000020?ooo`P000001`3oool3000000L0oooo3P3AcJT000`0dLfY1P3oool5000000<0oooo0`00
00030?ooo`T000000P3oool?000000<0oooo200000030?ooo`<000000`3oool5000000H0oooo303A
cJT60?ooo`D00000203oool3000000H0oooo0P0000030?ooo`H00000203oool300000080oooo0`00
00060?ooo`8000000`3oool8000000<0oooo2`3AcJT50?ooo`H000000P3oool3000000P0oooo0`00
00030?ooo`D00000203oool5000000<0oooo1P0000050?ooo`P00000203oool;0=7=Z@<0oooo1@00
00070?oooa0000003`3oool@000000L0oooo1@0000030?ooo``0dLfY1`3oool3000000L0oooo2000
00020?oooaL000000P3oool8000000L0oooo0`0000070?ooo`h0dLfY000<0=7=Z@H0oooo1@000003
0?ooo`<000000`3oool900000080oooo3`0000030?ooo`P000000`3oool3000000<0oooo1@000006
0?ooo``0dLfY0`0000030?ooo`8000000`3oool8000000T0oooo0P0000030?ooo`H000000P3oool9
000000/0oooo0P0000030?ooo`/000002`3AcJT300000080oooo0`0000030?ooo`P000001@3oool6
00000080oooo2`0000050?ooo`H000000`3oool2000000h0oooo1@00000;0=7=Z@<0oooo1@000007
0?oooa0000003`3oool@000000L0oooo1@0000030?ooo``0dLfY1@3oool2000000P0oooo0P000003
0?ooo`L00000203oool7000000P0oooo1`0000030?ooo`800000203oool2000000D0oooo3P3AcJT0
00`0dLfY0`3oool6000000h0oooo1P0000020?ooo`<000001P3oool3000000H0oooo1@0000060?oo
o`H000002`3oool<0=7=Z@<000000`3oool2000000<0oooo200000090?ooo`8000000`3oool60000
0080oooo2@00000;0?ooo`8000000`3oool;000000/0dLfY0`0000020?ooo`<000000`3oool80000
00D0oooo1P0000020?ooo`/000001@3oool6000000<0oooo0P00000>0?ooo`D000002`3AcJT30000
00`0oooo4P00000;0?oooa800000303oool3000000`0dLfY1@3oool2000000P0oooo0P0000030?oo
o`L00000203oool7000000P0oooo1`0000030?ooo`800000203oool2000000D0oooo3P3AcJT000`0
dLfY0`3oool6000000h0oooo1P0000020?ooo`<000001P3oool3000000H0oooo1@0000060?ooo`H0
00002`3oool<0=7=Z@H000001@3oool8000000h0oooo200000060?ooo`<000001@3oool600000080
oooo0`0000030?ooo`D000000`3oool;0=7=Z@<000000P3oool3000000<0oooo200000050?ooo`H0
00000P3oool;000000D0oooo1P0000030?ooo`8000003P3oool5000000/0dLfY0`00000<0?oooa80
00002`3ooolB000000`0oooo0`00000<0=7=Z@D000000P3oool5000000<0oooo4@0000030?ooo`L0
00000`3ooolA000000<0oooo1@0000020?ooo`D000003P3AcJT000`0dLfY0`3oool6000000h0oooo
1P0000020?ooo`<000001P3oool3000000H0oooo1@0000060?ooo`H000002`3oool<0=7=Z@H00000
1@3oool8000000h0oooo200000060?ooo`<000001@3oool600000080oooo0`0000030?ooo`D00000
0`3oool;0=7=Z@d0oooo3P0000080?ooo`<000000P3oool3000000D0oooo2@0000020?ooo`H00000
203oool2000000<0oooo2`3AcJT3000000`0oooo4P00000;0?oooa800000303oool3000000`0dLfY
1@0000020?ooo`D000000`3ooolA000000<0oooo1`0000030?oooa4000000`3oool500000080oooo
1@00000>0=7=Z@00303AcJT3000000/0oooo2@0000030?ooo`D000001P3oool6000000H0oooo0P00
00030?ooo`<000000`3oool600000080oooo0`0000060?ooo``0dLfY1P0000050?ooo`P000003P3o
ool8000000H0oooo0`0000050?ooo`H000000P3oool3000000<0oooo1@0000030?ooo`/0dLfY3@3o
ool>000000P0oooo0`0000020?ooo`<000001@3oool900000080oooo1P0000080?ooo`8000000`3o
ool;0=7=Z@<0oooo0P00000:0?oooa0000000P3oool3000000D0oooo0`0000020?oooa0000002P3o
ool2000000<0oooo303AcJT500000080oooo1@0000030?oooa4000000`3oool7000000<0oooo4@00
00030?ooo`D000000P3oool5000000h0dLfY000<0=7=Z@<000002`3oool9000000<0oooo1@000006
0?ooo`H000001P3oool2000000<0oooo0`0000030?ooo`H000000P3oool3000000H0oooo303AcJT3
0?ooo`<000000P3oool3000000P0oooo500000020?ooo`H000000`3oool2000000<0oooo0`000008
0?ooo`H000000P3oool3000000/0dLfY3@3oool>000000P0oooo0`0000020?ooo`<000001@3oool9
00000080oooo1P0000080?ooo`8000000`3oool;0=7=Z@<0oooo0P00000:0?oooa0000000P3oool3
000000D0oooo0`0000020?oooa0000002P3oool2000000<0oooo303AcJT7000000D0oooo4P000005
0?ooo`L000001@3ooolB000000D0oooo1`00000>0=7=Z@00303AcJT3000000/0oooo2@0000030?oo
o`D000001P3oool6000000H0oooo0P0000030?ooo`<000000`3oool600000080oooo0`0000060?oo
o``0dLfY0`3oool300000080oooo0`0000080?oooa@000000P3oool6000000<0oooo0P0000030?oo
o`<00000203oool600000080oooo0`00000;0=7=Z@<00000203oool8000000<0oooo0P00000;0?oo
o`<00000203oool2000000<0oooo3P0000080?ooo`D000002`3AcJT30?ooo`8000000`3oool50000
0080oooo4P00000;0?oooa8000000P3oool5000000<0oooo0P0000030?ooo``0dLfY1`0000050?oo
oa8000001@3oool7000000D0oooo4P0000050?ooo`L000003P3AcJT000`0dLfY0`0000030?ooo`<0
00000P3oool3000000l0oooo1@0000030?ooo`<000001P3oool3000000D0oooo0`0000030?ooo`/0
00000`3oool3000000`0dLfY0`3oool300000080oooo0`0000080?oooa@000000P3oool6000000<0
oooo0P0000030?ooo`<00000203oool600000080oooo0`00000;0=7=Z@<00000203oool8000000<0
oooo0P00000;0?ooo`<00000203oool2000000<0oooo3P0000080?ooo`D000002`3AcJT30?ooo`80
00000`3oool500000080oooo4P00000;0?oooa8000000P3oool5000000<0oooo0P0000030?ooo``0
dLfY0`0000020?ooo`L000000`3oool:00000080oooo5`0000020?ooo`X000000`3oool7000000<0
oooo0P00000>0=7=Z@00303AcJT3000000<0oooo0`0000020?ooo`<000003`3oool5000000<0oooo
0`0000060?ooo`<000001@3oool3000000<0oooo2`0000030?ooo`<00000303AcJT30?ooo`<00000
0P3oool3000000P0oooo1P0000030?ooo`8000000`3oool8000000<0oooo3P00000@0?ooo`<00000
2`3AcJT300000080oooo0`0000030?ooo`8000000`3oool3000000/0oooo4P0000090?ooo`P00000
0P3oool;000000/0dLfY0`3oool2000000<0oooo1@0000020?oooa8000002`3ooolB00000080oooo
1@0000030?ooo`8000000`3oool<0=7=Z@<000000P3oool7000000<0oooo2P0000020?oooaL00000
0P3oool:000000<0oooo1`0000030?ooo`8000003P3AcJT000`0dLfY0`0000030?ooo`<000000P3o
ool3000000l0oooo1@0000030?ooo`<000001P3oool3000000D0oooo0`0000030?ooo`/000000`3o
ool3000000`0dLfY0`3oool300000080oooo0`0000080?ooo`H000000`3oool2000000<0oooo2000
00030?ooo`h00000403oool3000000/0dLfY0`0000020?ooo`<000000`3oool2000000<0oooo0`00
000;0?oooa8000002@3oool800000080oooo2`00000;0=7=Z@<000000P3oool3000000D0oooo4P00
00020?ooo`<000001@3oool300000080oooo4P0000050?ooo`<000000P3oool3000000`0dLfY0`00
00020?ooo`L000000`3oool:00000080oooo5`0000020?ooo`X000000`3oool7000000<0oooo0P00
000>0=7=Z@00303AcJT;0?oooa800000203oool3000000T0oooo0P0000030?ooo`<000000`3oool3
000000/0oooo0`00000<0=7=Z@<0oooo0`0000020?ooo`<00000203oool6000000<0oooo0P000003
0?ooo`P000000`3oool>00000100oooo0`00000;0=7=Z@<000000P3oool3000000<0oooo0P000003
0?ooo`<000002`3ooolB000000T0oooo200000020?ooo`/000002`3AcJT300000080oooo0`000005
0?oooa8000000P3oool3000000D0oooo0`0000020?oooa8000001@3oool300000080oooo0`00000<
0=7=Z@<0oooo1`0000020?ooo`l000000`3oool2000000<0oooo1`0000030?ooo`8000000`3oool?
00000080oooo200000020?ooo`h0dLfY000<0=7=Z@/0oooo4P0000080?ooo`<000002@3oool20000
00<0oooo0`0000030?ooo`<000002`3oool3000000`0dLfY1P0000050?ooo`H000000P3oool30000
00<0oooo0`00000;0?ooo`8000001P3oool;000000<0oooo1@0000030?ooo`<000001@3oool;0=7=
Z@D000002`3oool8000000<0oooo0`0000020?ooo`H000001@3oool300000080oooo0`0000060?oo
o`d00000203oool;0=7=Z@<000000P3oool3000000D0oooo4P0000020?ooo`<000001@3oool30000
0080oooo4P0000050?ooo`<000000P3oool3000000`0dLfY0`3oool700000080oooo3`0000030?oo
o`8000000`3oool7000000<0oooo0P0000030?ooo`l000000P3oool800000080oooo3P3AcJT000`0
dLfY2`3ooolB000000P0oooo0`0000090?ooo`8000000`3oool3000000<0oooo0`00000;0?ooo`<0
0000303AcJT6000000D0oooo1P0000020?ooo`<000000`3oool3000000/0oooo0P0000060?ooo`/0
00000`3oool5000000<0oooo0`0000050?ooo`/0dLfY1@00000;0?ooo`P000000`3oool300000080
oooo1P0000050?ooo`<000000P3oool3000000H0oooo3@0000080?ooo`/0dLfY1@3oool300000080
oooo2000000?0?ooo`<000001@3oool3000000l0oooo200000020?ooo`<000001@3oool<0=7=Z@D0
00001@3oool7000000<0oooo0P00000:0?ooo`d000002P3oool2000000<0oooo1`0000050?ooo`D0
00003P3AcJT000`0dLfY0`3oool3000000/0oooo2@0000030?ooo`/000004@3oool6000000<0oooo
200000030?ooo``0dLfY0`0000030?ooo`8000000`3oool3000000<0oooo0P0000030?ooo`/00000
203oool3000000<0oooo0`0000020?ooo`<000000`3oool300000080oooo2`0000030?ooo`/0dLfY
1@00000;0?ooo`P000000`3oool300000080oooo1P0000050?ooo`<000000P3oool3000000H0oooo
3@0000080?ooo`/0dLfY1@3oool300000080oooo2000000?0?ooo`<000001@3oool3000000l0oooo
200000020?ooo`<000001@3oool<0=7=Z@D000001@3oool7000000<0oooo0P00000:0?ooo`d00000
2P3oool2000000<0oooo1`0000050?ooo`D000003P3AcJT000`0dLfY0`3oool3000000/0oooo2@00
00030?ooo`/000004@3oool6000000<0oooo200000030?ooo``0dLfY0`0000030?ooo`8000000`3o
ool3000000<0oooo0P0000030?ooo`/00000203oool3000000<0oooo0`0000020?ooo`<000000`3o
ool300000080oooo2`0000030?ooo`/0dLfY0`0000050?ooo`D000001P3oool300000080oooo1P00
00020?ooo`<000000`3oool200000140oooo1@0000030?ooo`8000001P3oool5000000/0dLfY203o
ool7000000<0oooo0`00000:0?ooo`8000002`3oool2000000X0oooo0`0000030?ooo`L00000203o
ool<0=7=Z@D000001@3oool7000000<0oooo0P00000:0?ooo`d000002P3oool2000000<0oooo1`00
00050?ooo`D000003P3AcJT000`0dLfY0`3oool3000000/0oooo2@0000030?ooo`/000004@3oool6
000000<0oooo200000030?ooo``0dLfY0`0000030?ooo`8000000`3oool3000000<0oooo0P000003
0?ooo`/00000203oool3000000<0oooo0`0000020?ooo`<000000`3oool300000080oooo2`000003
0?ooo`/0dLfY0`0000050?ooo`D000001P3oool300000080oooo1P0000020?ooo`<000000`3oool2
00000140oooo1@0000030?ooo`8000001P3oool5000000/0dLfY203oool7000000<0oooo0`00000:
0?ooo`8000002`3oool2000000X0oooo0`0000030?ooo`L00000203oool<0=7=Z@D000001@3oool5
00000080oooo0`0000020?ooo`<000001@3oool500000080oooo0`0000020?ooo`D000001@3oool3
00000080oooo0`0000020?ooo`D000001@3oool5000000h0dLfY000<0=7=Z@<000000`3oool80000
00<0oooo0`0000060?ooo`<000000P3oool3000000<0oooo3P00000?0?ooo`8000002@3oool<0=7=
Z@H0oooo200000030?oooa0000000`3oool300000080oooo2@0000020?ooo`H00000203oool60000
0080oooo0`00000;0=7=Z@<0oooo0P00000;0?ooo`H000000P3oool3000000<0oooo2P0000060?oo
o`8000001P3oool5000000/0oooo1@0000030?ooo`/0dLfY203oool7000000<0oooo0`00000:0?oo
o`8000002`3oool2000000X0oooo0`0000030?ooo`L00000203oool<0=7=Z@D000001@3oool50000
0080oooo0`0000020?ooo`<000001@3oool500000080oooo0`0000020?ooo`D000001@3oool30000
0080oooo0`0000020?ooo`D000001@3oool5000000h0dLfY000<0=7=Z@<000000`3oool8000000<0
oooo0`0000060?ooo`<000000P3oool3000000<0oooo3P00000?0?ooo`8000002@3oool<0=7=Z@H0
oooo200000030?oooa0000000`3oool300000080oooo2@0000020?ooo`H00000203oool600000080
oooo0`00000;0=7=Z@<0oooo0P00000;0?ooo`H000000P3oool3000000<0oooo2P0000060?ooo`80
00001P3oool5000000/0oooo1@0000030?ooo`/0dLfY3@0000050?ooo`<000001`3oool5000000<0
oooo1@0000030?ooo`D000001`3oool3000000D0oooo3@00000<0=7=Z@<0oooo1`0000050?ooo`D0
00000P3oool300000080oooo1@0000030?ooo`L000000`3oool500000080oooo0`0000020?ooo`D0
00001@3oool800000080oooo3P3AcJT000`0dLfY1P3oool300000080oooo0`0000030?ooo`H00000
0`3oool300000080oooo1P0000030?ooo`h000000`3oool3000000H0oooo200000030?ooo``0dLfY
1P3oool8000000<0oooo400000030?ooo`<000000P3oool900000080oooo1P0000080?ooo`H00000
0P3oool3000000/0dLfY0`3oool2000000/0oooo1P0000020?ooo`<000000`3oool:000000H0oooo
0P0000060?ooo`D000002`3oool5000000<0oooo2`3AcJT=000000D0oooo0`0000070?ooo`D00000
0`3oool5000000<0oooo1@0000070?ooo`<000001@3oool=000000`0dLfY0`3oool7000000D0oooo
1@0000020?ooo`<000000P3oool5000000<0oooo1`0000030?ooo`D000000P3oool300000080oooo
1@0000050?ooo`P000000P3oool>0=7=Z@00303AcJT60?ooo`<000000P3oool3000000<0oooo1P00
00030?ooo`<000000P3oool6000000<0oooo3P0000030?ooo`<000001P3oool8000000<0oooo303A
cJT80?ooo`H000000`3oool2000000H0oooo1@0000090?ooo`D000000`3ooolF000000<0oooo0P00
00030?ooo`/0dLfY1@3oool3000000<0oooo0P00000>0?ooo`<000002P3oool3000001H0oooo0P00
00030?ooo`<000001@3oool;0=7=Z@X000000`3oool5000000P0oooo0P0000050?ooo`/000001@3o
ool2000000P0oooo1@0000030?ooo`X00000303AcJT30?ooo`L000001@3oool500000080oooo0`00
00020?ooo`D000000`3oool7000000<0oooo1@0000020?ooo`<000000P3oool5000000D0oooo2000
00020?ooo`h0dLfY000<0=7=Z@H0oooo0`0000020?ooo`<000000`3oool6000000<0oooo0`000002
0?ooo`H000000`3oool>000000<0oooo0`0000060?ooo`P000000`3oool<0=7=Z@P0oooo1P000003
0?ooo`8000001P3oool5000000T0oooo1@0000030?oooaH000000`3oool2000000<0oooo2`3AcJT5
0?ooo`<000000`3oool2000000h0oooo0`00000:0?ooo`<000005P3oool2000000<0oooo0`000005
0?ooo`/0dLfY2P0000030?ooo`D00000203oool2000000D0oooo2`0000050?ooo`800000203oool5
000000<0oooo2P00000<0=7=Z@<000000P3oool5000000D0oooo1`0000030?ooo`800000203oool7
000000P0oooo0P0000030?ooo`L000001@3oool5000000<0oooo0P00000>0=7=Z@00303AcJT30?oo
o`H000000P3oool3000000l0oooo2`0000030?ooo`<000001@3oool3000000T0oooo0`0000050?oo
o`<000000`3oool<0=7=Z@P0oooo1P0000030?ooo`8000001P3oool5000000T0oooo1@0000030?oo
oaH000000`3oool2000000<0oooo2`3AcJT50?ooo`<000000`3oool2000000h0oooo0`00000:0?oo
o`<000005P3oool2000000<0oooo0`0000050?ooo`/0dLfY2P0000030?ooo`D00000203oool20000
00D0oooo2`0000050?ooo`800000203oool5000000<0oooo2P00000<0=7=Z@<000000P3oool50000
00D0oooo1`0000030?ooo`800000203oool7000000P0oooo0P0000030?ooo`L000001@3oool50000
00<0oooo0P00000>0=7=Z@00303AcJT30?ooo`H000000P3oool3000000l0oooo2`0000030?ooo`<0
00001@3oool3000000T0oooo0`0000050?ooo`<000000`3oool<0=7=Z@H000000P3oool9000000/0
oooo0P0000030?ooo`<000000`3oool5000000H0oooo0P0000030?ooo`H000001@3oool;000000/0
dLfY2000000;0?ooo`P000000`3ooolB000000H0oooo0`0000050?ooo`<000001@3oool300000080
oooo0`00000;0=7=Z@<0oooo1`0000080?ooo`D000000`3oool2000000D0oooo0`0000050?ooo`<0
00001@3oool2000000<0oooo1@0000080?ooo`L000000`3oool<0=7=Z@<0oooo0P0000020?ooo`X0
00000`3oool5000000L0oooo0`0000020?ooo`<000000P3oool3000000L0oooo1@0000030?ooo`X0
00000P3oool300000080oooo3P3AcJT000`0dLfY0`3oool600000080oooo0`00000?0?ooo`/00000
0`3oool3000000D0oooo0`0000090?ooo`<000001@3oool3000000<0oooo303AcJT600000080oooo
2@00000;0?ooo`8000000`3oool3000000<0oooo1@0000060?ooo`8000000`3oool6000000D0oooo
2`00000;0=7=Z@P000002`3oool8000000<0oooo4P0000060?ooo`<000001@3oool3000000D0oooo
0`0000020?ooo`<000002`3AcJT30?ooo`L00000203oool5000000<0oooo0P0000050?ooo`<00000
1@3oool3000000D0oooo0P0000030?ooo`D00000203oool7000000<0oooo303AcJT30?ooo`800000
0P3oool:000000<0oooo1@0000070?ooo`<000000P3oool300000080oooo0`0000070?ooo`D00000
0`3oool:00000080oooo0`0000020?ooo`h0dLfY000<0=7=Z@h0oooo1P00000;0?ooo``000002`3o
ool6000000H0oooo0P0000090?ooo``0dLfY0`00000@0?ooo`H000000`3oool2000000<0oooo2000
00030?ooo`H00000203oool;000000D0oooo0`00000;0=7=Z@d0oooo0`0000060?ooo`8000000`3o
ool3000000D0oooo0`0000020?ooo`H000000P3oool3000000<0oooo0`00000E0?ooo`/0dLfY0`00
00020?ooo`D000001@3oool3000000D0oooo0`0000020?ooo`D000002`3oool500000080oooo0`00
00050?ooo`<000001@3oool500000080oooo0`00000<0=7=Z@<0oooo0P0000020?ooo`X000000`3o
ool5000000L0oooo0`0000020?ooo`<000000P3oool3000000L0oooo1@0000030?ooo`X000000P3o
ool300000080oooo3P3AcJT000`0dLfY3P3oool6000000/0oooo3000000;0?ooo`H000001P3oool2
000000T0oooo303AcJT300000100oooo1P0000030?ooo`8000000`3oool8000000<0oooo1P000008
0?ooo`/000001@3oool3000000/0dLfY3@3oool3000000H0oooo0P0000030?ooo`<000001@3oool3
00000080oooo1P0000020?ooo`<000000`3oool3000001D0oooo2`3AcJT300000080oooo1@000005
0?ooo`<000001@3oool300000080oooo1@00000;0?ooo`D000000P3oool3000000D0oooo0`000005
0?ooo`D000000P3oool3000000`0dLfY0`0000020?ooo`8000000`3oool500000080oooo20000005
0?ooo`D000000P3oool300000080oooo1@0000050?ooo`P000000P3oool5000000<0oooo0P000003
0?ooo`8000003P3AcJT000`0dLfY3P3oool6000000/0oooo3000000;0?ooo`H000001P3oool20000
00T0oooo303AcJT300000100oooo1P0000030?ooo`8000000`3oool8000000<0oooo1P0000080?oo
o`/000001@3oool3000000/0dLfY3@3oool3000000H0oooo0P0000030?ooo`<000001@3oool30000
0080oooo1P0000020?ooo`<000000`3oool3000001D0oooo2`3AcJT300000080oooo1@0000050?oo
o`<000001@3oool300000080oooo1@00000;0?ooo`D000000P3oool3000000D0oooo0`0000050?oo
o`D000000P3oool3000000`0dLfY0`0000020?ooo`8000000`3oool500000080oooo200000050?oo
o`D000000P3oool300000080oooo1@0000050?ooo`P000000P3oool5000000<0oooo0P0000030?oo
o`8000003P3AcJT00?l0dLfYb`3AcJT00?l0dLfYb`3AcJT00?l0dLfYb`3AcJT00?l0dLfYb`3AcJT0
0?l0dLfYb`3AcJT00?l0dLfYb`3AcJT00?l0dLfYb`3AcJT00?l0dLfYb`3AcJT00?l0dLfYb`3AcJT0
0?l0dLfYb`3AcJT00?l0dLfYb`3AcJT000`0dLfY0`000004ooooo`@000001oooool3000000Oooooo
20000007ooooo`L000001oooool4000000Oooooo0`000004ooooo`<000002`3AcJT6000000Oooooo
1000000Dooooo`<000005Oooool3000000Oooooo1`00000:0=7=Z@d000001?oooolF000002Sooooo
2P3AcJT9000000Oooooo0`000009ooooo`<000001oooool<000000gooooo0`000009ooooo`<00000
2`3AcJT30?ooo`<000001P3oool3000000<0oooo1P0000030?ooo`<000000`3oool3000000D0oooo
0`0000030?ooo`<000000`3oool6000000<0oooo0`0000060?ooo`<000000`3oool>0=7=Z@00303A
cJT3000000Cooooo10000007ooooo`<000001oooool8000000Oooooo1`000007ooooo`@000001ooo
ool3000000Cooooo0`00000;0=7=Z@H000001oooool4000001Cooooo0`00000Eooooo`<000001ooo
ool7000000X0dLfY3@000004oooooaH00000:?ooool:0=7=Z@T000001oooool3000000Wooooo0`00
0007ooooo``000003Oooool3000000Wooooo0`00000;0=7=Z@<0oooo0`0000060?ooo`<000000`3o
ool6000000<0oooo0`0000030?ooo`<000001@3oool3000000<0oooo0`0000030?ooo`H000000`3o
ool3000000H0oooo0`0000030?ooo`h0dLfY000<0=7=Z@<000001?ooool4000000Oooooo0`000007
ooooo`P000001oooool7000000Oooooo10000007ooooo`<000001?ooool3000000/0dLfY1P000007
ooooo`@000005?ooool3000001Gooooo0`000007ooooo`L000002P3AcJT=000000Cooooo5P00000X
ooooo`X0dLfY2@000007ooooo`<000002Oooool3000000Oooooo3000000=ooooo`<000002Oooool3
000000/0dLfY0`3oool3000000H0oooo0`0000030?ooo`H000000`3oool3000000<0oooo0`000005
0?ooo`<000000`3oool3000000<0oooo1P0000030?ooo`<000001P3oool3000000<0oooo3P3AcJT0
00`0dLfY0`000004ooooo`@000001oooool3000000Oooooo20000007ooooo`L000001oooool40000
00Oooooo0`000004ooooo`<000002`3AcJT6000000Oooooo1000000Dooooo`<000005Oooool30000
00Oooooo1`00000:0=7=Z@d000001?oooolF000002Sooooo2P3AcJT@ooooo``000001_ooool40000
00?ooooo0`000003ooooo`T000001?ooool3000000cooooo0`00000;0=7=Z@<000000`3oool<0000
00T0oooo1P0000080?ooo`T00000303oool6000000H0oooo0`00000>0=7=Z@00303AcJT3ooooo`@0
00001?ooool7000000[ooooo20000007ooooo`L000002oooool7000000?ooooo10000003ooooo`/0
dLfY5000000>ooooo`X000003_oooolD000000X0dLfY3Oooool7000001?ooooo5`000004ooooo`d0
00002P3AcJT@ooooo``000001_ooool4000000?ooooo0`000003ooooo`T000001?ooool3000000co
oooo0`00000;0=7=Z@<000000`3oool<000000T0oooo1P0000080?ooo`T00000303oool6000000H0
oooo0`00000>0=7=Z@00303AcJT3ooooo`@000001?ooool7000000[ooooo20000007ooooo`L00000
2oooool7000000?ooooo10000003ooooo`/0dLfY5000000>ooooo`X000003_oooolD000000X0dLfY
3Oooool7000001?ooooo5`000004ooooo`d000002P3AcJT@ooooo``000001_ooool4000000?ooooo
0`000003ooooo`T000001?ooool3000000cooooo0`00000;0=7=Z@<000000`3oool<000000T0oooo
1P0000080?ooo`T00000303oool6000000H0oooo0`00000>0=7=Z@00303AcJT3ooooo`@000001?oo
ool7000000[ooooo20000007ooooo`L000002oooool7000000?ooooo10000003ooooo`/0dLfY5000
000>ooooo`X000003_oooolD000000X0dLfY3Oooool7000001?ooooo5`000004ooooo`d000002P3A
cJT3000000?ooooo0`000003ooooo`@000007oooool3000000Kooooo10000003ooooo`<000000ooo
ool3000000Kooooo2`3AcJT60?ooo`T000000`3oool?000000H0oooo0P0000060?ooo`T00000303o
ool6000000<0oooo3P3AcJT000`0dLfY0`000004ooooo`/000001oooool3000000Cooooo10000007
ooooo`<000001?ooool3000000Sooooo2P000004ooooo`<000002`3AcJT3ooooo`L000001oooool3
000000?ooooo10000003ooooo`@000000oooool3000000Cooooo0`000004ooooo`<000001?ooool3
000000Oooooo1`000003ooooo`X0dLfY0`000004ooooo`H000002_ooool=000000gooooo1`000003
ooooo`L000003Oooool:0=7=Z@<000000oooool3000000?ooooo1000000Oooooo`<000001_ooool4
000000?ooooo0`000003ooooo`<000001_ooool;0=7=Z@H0oooo2@0000030?ooo`l000001P3oool2
000000H0oooo2@00000<0?ooo`H000000`3oool>0=7=Z@00303AcJT3000000Cooooo2`000007oooo
o`<000001?ooool4000000Oooooo0`000004ooooo`<000002?ooool:000000Cooooo0`00000;0=7=
Z@?ooooo1`000007ooooo`<000000oooool4000000?ooooo10000003ooooo`<000001?ooool30000
00Cooooo0`000004ooooo`<000001oooool7000000?ooooo2P3AcJT3000000Cooooo1P00000:oooo
o`d000003Oooool7000000?ooooo1`00000=ooooo`X0dLfY0`000003ooooo`<000000oooool40000
01oooooo0`000006ooooo`@000000oooool3000000?ooooo0`000006ooooo`/0dLfY1P3oool90000
00<0oooo3`0000060?ooo`8000001P3oool9000000`0oooo1P0000030?ooo`h0dLfY000<0=7=Z@<0
00001?ooool;000000Oooooo0`000004ooooo`@000001oooool3000000Cooooo0`000008ooooo`X0
00001?ooool3000000/0dLfY0oooool7000000Oooooo0`000003ooooo`@000000oooool4000000?o
oooo0`000004ooooo`<000001?ooool3000000Cooooo0`000007ooooo`L000000oooool:0=7=Z@<0
00001?ooool6000000[ooooo3@00000=ooooo`L000000oooool7000000gooooo2P3AcJT3000000?o
oooo0`000003ooooo`@000007oooool3000000Kooooo10000003ooooo`<000000oooool3000000Ko
oooo2`3AcJT30?ooo`<000000`3oool6000000T0oooo0`0000060?ooo`<000003P3oool3000000H0
oooo3`0000030?ooo`h0dLfY000<0=7=Z@<000001?ooool;000000Oooooo0`000004ooooo`@00000
1oooool3000000Cooooo0`000008ooooo`X000001?ooool3000000/0dLfY0oooool3000000Cooooo
1`00000:oooooaP000002_ooool7000000?ooooo10000003ooooo`X0dLfY1`000006ooooo`X00000
0oooool4000000?ooooo1P000004ooooo`<000002_ooool3000000Oooooo1P000003ooooo`@00000
2P3AcJT3ooooo`T000002_ooool3000000?ooooo5P000003ooooo`<000002_ooool9000000?ooooo
2`3AcJT30?ooo`<000000`3oool6000000T0oooo0`0000060?ooo`<000003P3oool3000000H0oooo
3`0000030?ooo`h0dLfY000<0=7=Z@?ooooo2`000004ooooo`L000000oooool4000000kooooo1000
0003ooooo`P000000oooool;000000?ooooo2`3AcJT3ooooo`<000001?ooool7000000[ooooo6000
000:ooooo`L000000oooool4000000?ooooo2P3AcJT7000000Kooooo2P000003ooooo`@000000ooo
ool6000000Cooooo0`00000:ooooo`<000001oooool6000000?ooooo1000000:0=7=Z@?ooooo2@00
000:ooooo`<000000ooooolF000000?ooooo0`00000:ooooo`T000000oooool;0=7=Z@<0oooo0`00
00030?ooo`H000002@3oool3000000H0oooo0`00000>0?ooo`<000001P3oool?000000<0oooo3P3A
cJT000`0dLfY0oooool;000000Cooooo1`000003ooooo`@000003_ooool4000000?ooooo20000003
ooooo`/000000oooool;0=7=Z@?ooooo0`000004ooooo`L000002_oooolH000000[ooooo1`000003
ooooo`@000000oooool:0=7=Z@L000001_ooool:000000?ooooo10000003ooooo`H000001?ooool3
000000[ooooo0`000007ooooo`H000000oooool4000000X0dLfY0oooool9000000[ooooo0`000003
oooooaH000000oooool3000000[ooooo2@000003ooooo`/0dLfY1P0000030?ooo`H000002@3oool6
000000/0oooo0`0000030?ooo`H000001P3ooolB000000h0dLfY000<0=7=Z@?ooooo2`000004oooo
o`L000000oooool4000000kooooo10000003ooooo`P000000oooool;000000?ooooo2`3AcJT3oooo
o`<000001?ooool7000000[ooooo6000000:ooooo`L000000oooool4000000?ooooo2P3AcJT70000
01[ooooo0`000003ooooo`@000001_ooool4000000?ooooo0`00000:ooooo`H000001?ooool:0=7=
Z@<000000oooool:000000?ooooo1P000003ooooo`X000000oooool6000000Kooooo0`000007oooo
o`T000001_ooool;0=7=Z@H000000`3oool6000000T0oooo1P00000;0?ooo`<000000`3oool60000
00H0oooo4P00000>0=7=Z@00303AcJT3ooooo`P000000oooool7000000Oooooo20000007ooooo`L0
00001oooool7000000Cooooo1`000003ooooo`/0dLfY1P000004ooooo`X000000oooool4000000[o
oooo0`00000;ooooo`<000001?ooool:000000?ooooo1`00000:0=7=Z@L000006_ooool3000000?o
oooo10000006ooooo`@000000oooool3000000[ooooo1P000004ooooo`X0dLfY0`000003ooooo`X0
00000oooool6000000?ooooo2P000003ooooo`H000001_ooool3000000Oooooo2@000006ooooo`/0
dLfY1P0000030?ooo`H000002@3oool6000000/0oooo0`0000030?ooo`H000001P3ooolB000000h0
dLfY000<0=7=Z@?ooooo20000003ooooo`L000001oooool8000000Oooooo1`000007ooooo`L00000
1?ooool7000000?ooooo2`3AcJT6000000Cooooo2P000003ooooo`@000002_ooool3000000_ooooo
0`000004ooooo`X000000oooool7000000X0dLfY1`00000Jooooo`<000000oooool4000000Kooooo
10000003ooooo`<000002_ooool6000000Cooooo2P3AcJT3000000?ooooo2P000003ooooo`H00000
0oooool:000000?ooooo1P000006ooooo`<000001oooool9000000Kooooo2`3AcJT90?ooo`T00000
0`3oool6000000`0oooo0P0000030?ooo`<000000`3oool<000000T0oooo0`0000030?ooo`h0dLfY
000<0=7=Z@?ooooo20000003ooooo`L000001oooool8000000Oooooo1`000007ooooo`L000001?oo
ool7000000?ooooo2`3AcJT6000000Cooooo2P000003ooooo`@000002_ooool3000000_ooooo0`00
0004ooooo`X000000oooool7000000X0dLfY0oooool7000000[ooooo0`000003ooooo`@000000ooo
ool3000000?ooooo10000003ooooo`d000001oooool6000000Oooooo2P3AcJT6000000?ooooo0`00
000:ooooo`T000004oooool:000000Kooooo0`000003ooooo`<000000oooool;0=7=Z@T0oooo2@00
00030?ooo`H00000303oool2000000<0oooo0`0000030?ooo``000002@3oool3000000<0oooo3P3A
cJT000`0dLfY0oooool8000000?ooooo1`000007ooooo`P000001oooool7000000Oooooo1`000004
ooooo`L000000oooool;0=7=Z@?ooooo1`000003ooooo`L000003_ooool:000000kooooo1P000004
ooooo`L000000oooool:0=7=Z@?ooooo1`00000:ooooo`<000000oooool4000000?ooooo0`000003
ooooo`@000000oooool=000000Oooooo1P000007ooooo`X0dLfY1P000003ooooo`<000002_ooool9
000001?ooooo2P000006ooooo`<000000oooool3000000?ooooo2`3AcJT90?ooo`T000000`3oool6
000000`0oooo0P0000030?ooo`<000000`3oool<000000T0oooo0`0000030?ooo`h0dLfY000<0=7=
Z@<000002?ooool:000000Oooooo20000007ooooo`L000001oooool;000000Oooooo0`00000;0=7=
Z@?ooooo1`000003ooooo`L000003_ooool:000000kooooo1P000004ooooo`L000000oooool:0=7=
Z@?ooooo1`00000:ooooo`<000000oooool4000000?ooooo0`000003ooooo`@000000oooool=0000
00Oooooo1P000007ooooo`X0dLfY1P000003ooooo`<000002_ooool9000001?ooooo2P000006oooo
o`<000000oooool3000000?ooooo2`3AcJT3000000`0oooo0`0000030?ooo`<000000`3oool30000
00<0oooo200000060?ooo`<000000`3oool3000000`0oooo0`0000030?ooo`<000003P3AcJT000`0
dLfY0`000008ooooo`X000001oooool8000000Oooooo1`000007ooooo`/000001oooool3000000/0
dLfY0oooool7000000?ooooo1`00000>ooooo`X000003_ooool6000000Cooooo1`000003ooooo`X0
dLfY0oooool7000000[ooooo0`000003ooooo`@000000oooool3000000?ooooo10000003ooooo`d0
00001oooool6000000Oooooo2P3AcJT3ooooo`H000000oooool:000000?ooooo0`00000:ooooo`T0
00000oooool3000000?ooooo1000000Booooo`/0dLfY0`00000<0?ooo`<000000`3oool3000000<0
oooo0`0000030?ooo`P000001P3oool3000000<0oooo0`00000<0?ooo`<000000`3oool3000000h0
dLfY000<0=7=Z@<000002?ooool:000000Oooooo20000007ooooo`L000001oooool;000000Oooooo
0`00000;0=7=ZACooooo0`000004ooooo`L000000oooool3000000Cooooo1`000003ooooo`@00000
5?ooool:0=7=Z@?ooooo10000003ooooo`L000001_ooool7000000?ooooo0`000007ooooo`d00000
1_ooool4000000?ooooo2P00000:0=7=Z@?ooooo1P000003ooooo`X000000oooool3000000[ooooo
2@000003ooooo`<000000oooool4000001;ooooo2`3AcJT3000000`0oooo0`0000030?ooo`<00000
0`3oool3000000<0oooo200000060?ooo`<000000`3oool3000000`0oooo0`0000030?ooo`<00000
3P3AcJT000`0dLfY2oooool3000000Oooooo2`000004ooooo`L000000oooool;000000Oooooo1000
000:ooooo`/0dLfY5?ooool3000000Cooooo1`000003ooooo`<000001?ooool7000000?ooooo1000
000Dooooo`X0dLfY0oooool4000000?ooooo1`000006ooooo`L000000oooool3000000Oooooo3@00
0006ooooo`@000000oooool:000000X0dLfY0oooool6000000?ooooo2P000003ooooo`<000002_oo
ool9000000?ooooo0`000003ooooo`@000004_ooool;0=7=Z@<000000`3oool3000000H0oooo1P00
00030?ooo`<000000`3oool3000000<0oooo1@0000030?ooo`<000000`3oool3000000<0oooo1P00
00060?ooo`<000000`3oool3000000h0dLfY000<0=7=Z@_ooooo0`000007ooooo`/000001?ooool7
000000?ooooo2`000007ooooo`@000002_ooool;0=7=ZACooooo0`000004ooooo`L000000oooool3
000000Cooooo1`000003ooooo`@000005?ooool:0=7=Z@?ooooo10000003ooooo`L000001_ooool7
000000?ooooo0`000007ooooo`d000001_ooool4000000?ooooo2P00000:0=7=Z@?ooooo0`000003
ooooo`X000002Oooool6000000Cooooo0`000003ooooo`H000002_ooool9000000?ooooo0`000003
ooooo`/0dLfY0`0000030?ooo`<000001P3oool6000000<0oooo0`0000030?ooo`<000000`3oool5
000000<0oooo0`0000030?ooo`<000000`3oool6000000H0oooo0`0000030?ooo`<000003P3AcJT0
00`0dLfY2oooool3000000Oooooo2`000004ooooo`L000000oooool;000000Oooooo1000000:oooo
o`/0dLfY5?ooool3000000Cooooo1`000003ooooo`<000001?ooool7000000?ooooo1000000Doooo
o`X0dLfY2_ooool3000000Cooooo1P00000=ooooo`L000001_ooool4000000?ooooo1P000007oooo
o`H000001?ooool:0=7=Z@?ooooo0`000003ooooo`X000002Oooool6000000Cooooo0`000003oooo
o`H000002_ooool9000000?ooooo0`000003ooooo`/0dLfY0`0000030?ooo`<000001P3oool60000
00<0oooo0`0000030?ooo`<000000`3oool5000000<0oooo0`0000030?ooo`<000000`3oool60000
00H0oooo0`0000030?ooo`<000003P3AcJT000`0dLfY2oooool3000000Oooooo2`000004ooooo`L0
00000oooool;000000Oooooo1000000:ooooo`/0dLfY1_ooool4000000?ooooo10000006ooooo`@0
00002_ooool3000000_ooooo0`000007ooooo`<000001?ooool3000000Oooooo2P3AcJT:ooooo`<0
00001?ooool6000000gooooo1`000006ooooo`@000000oooool6000000Oooooo1P000004ooooo`X0
dLfY0oooool3000000?ooooo2P000009ooooo`H000001?ooool3000000?ooooo1P00000:ooooo`T0
00000oooool3000000?ooooo2`3AcJT60?ooo``000000`3oool<000000<0oooo1@0000030?ooo``0
00000`3oool<000000H0oooo3P3AcJT000`0dLfY1oooool4000000[ooooo1`000004ooooo`h00000
1?ooool7000000_ooooo0`000007ooooo`/0dLfY1_ooool4000000?ooooo10000006ooooo`@00000
2_ooool3000000_ooooo0`000007ooooo`<000001?ooool3000000Oooooo2P3AcJT:ooooo`<00000
1?ooool6000000gooooo1`000006ooooo`@000000oooool6000000Oooooo1P000004ooooo`X0dLfY
0oooool3000000[ooooo1P000006ooooo`H000001?ooool3000000?ooooo1P000006ooooo`L00000
2Oooool3000000?ooooo2`3AcJT60?ooo``000000`3oool<000000<0oooo1@0000030?ooo``00000
0`3oool<000000H0oooo3P3AcJT000`0dLfY1oooool4000000[ooooo1`000004ooooo`h000001?oo
ool7000000_ooooo0`000007ooooo`/0dLfY1_ooool4000000?ooooo10000006ooooo`@000002_oo
ool3000000_ooooo0`000007ooooo`<000001?ooool3000000Oooooo2P3AcJT3ooooo`@000000ooo
ool3000000gooooo1`000006oooooa@000000oooool4000000?ooooo2P00000:0=7=Z@?ooooo0`00
000:ooooo`H000001_ooool6000000Cooooo0`000003ooooo`H000001_ooool7000000Wooooo0`00
0003ooooo`/0dLfY1P3oool<000000<0oooo300000030?ooo`D000000`3oool<000000<0oooo3000
00060?ooo`h0dLfY000<0=7=Z@Oooooo1000000:ooooo`L000001?ooool>000000Cooooo1`00000;
ooooo`<000001oooool;0=7=Z@[ooooo0`000007ooooo`<000001?ooool3000000Oooooo0`000007
ooooo`@000000oooool4000000Kooooo1000000:ooooo`X0dLfY0oooool4000000?ooooo0`00000=
ooooo`L000001_oooolD000000?ooooo10000003ooooo`X000002P3AcJT3ooooo`<000002_ooool6
000000Kooooo1P000004ooooo`<000000oooool6000000Kooooo1`000009ooooo`<000000oooool;
0=7=Z@T000000`3oool3000000<0oooo0`0000030?ooo`<000001P3oool;000000H0oooo0`000003
0?ooo`<000000`3oool3000000<0oooo2@00000>0=7=Z@00303AcJT7000000Cooooo3P000003oooo
oaH000000oooool?000000?ooooo1`00000;0=7=Z@[ooooo0`000007ooooo`<000001?ooool30000
00Oooooo0`000007ooooo`@000000oooool4000000Kooooo1000000:ooooo`X0dLfY0oooool40000
00?ooooo0`00000=ooooo`L000001_oooolD000000?ooooo10000003ooooo`X000002P3AcJT60000
00?ooooo0`000004ooooo`<000000oooool9000000?ooooo1`000003ooooo``000001oooool90000
00?ooooo0`00000;0=7=Z@T000000`3oool3000000<0oooo0`0000030?ooo`<000001P3oool;0000
00H0oooo0`0000030?ooo`<000000`3oool3000000<0oooo2@00000>0=7=Z@00303AcJT7000000Co
oooo3P000003oooooaH000000oooool?000000?ooooo1`00000;0=7=Z@[ooooo0`000007ooooo`<0
00001?ooool3000000Oooooo0`000007ooooo`@000000oooool4000000Kooooo1000000:ooooo`X0
dLfY2_ooool7000000?ooooo4`000007ooooo`L000001_ooool7000000?ooooo1P000004ooooo`X0
dLfY1P000003ooooo`<000001?ooool3000000?ooooo2@000003ooooo`L000000oooool<000000Oo
oooo2@000003ooooo`<000002`3AcJT9000000<0oooo0`0000030?ooo`<000000`3oool3000000H0
oooo2`0000060?ooo`<000000`3oool3000000<0oooo0`0000030?ooo`T000003P3AcJT000`0dLfY
1`000004ooooo`h000000ooooolF000000?ooooo3`000003ooooo`L000002`3AcJT6ooooo`L00000
1oooool3000000Oooooo10000003ooooo`<000001?ooool3000000Oooooo10000006ooooo`L00000
1oooool:0=7=Z@[ooooo1`000003oooooa<000001oooool7000000Kooooo1`000003ooooo`H00000
1?ooool:0=7=Z@H000000oooool3000000Cooooo0`000003ooooo`T000000oooool7000000?ooooo
30000007ooooo`T000000oooool3000000/0dLfY0`3oool3000000T0oooo0`0000030?ooo`H00000
3P3oool3000000H0oooo1P00000<0?ooo`H000000`3oool>0=7=Z@00303AcJT7000000Cooooo3P00
0003oooooaH000000oooool?000000?ooooo1`00000;0=7=Z@Kooooo1`000007ooooo`<000001ooo
ool4000000?ooooo0`000004ooooo`<000001oooool4000000Kooooo1`000007ooooo`X0dLfY2_oo
ool7000000?ooooo4`000007ooooo`L000001_ooool7000000?ooooo1P000004ooooo`X0dLfY0`00
0009ooooo`@000001_ooool9000001?ooooo2P000003ooooo`<000003?ooool;0=7=Z@<0oooo0`00
00090?ooo`<000000`3oool6000000h0oooo0`0000060?ooo`H00000303oool6000000<0oooo3P3A
cJT000`0dLfY2`000003ooooo`L000001?oooolL000000Cooooo1`000004ooooo`X000002`3AcJT6
ooooo`L000001oooool3000000Oooooo10000003ooooo`<000001?ooool3000000Oooooo10000006
ooooo`L000001oooool:0=7=Z@<000001?ooool3000000?ooooo1000000@ooooo`H000001oooool7
000000?ooooo0`000003ooooo`L000000oooool3000000Cooooo2P3AcJT3000000Wooooo10000006
ooooo`T000004oooool:000000?ooooo0`00000<ooooo`/0dLfY0`3oool3000000T0oooo0`000003
0?ooo`H000003P3oool3000000H0oooo1P00000<0?ooo`H000000`3oool>0=7=Z@00303AcJT;0000
00?ooooo1`000004oooooa`000001?ooool7000000Cooooo2P00000;0=7=Z@Kooooo1`000007oooo
o`<000001oooool4000000?ooooo0`000004ooooo`<000001oooool4000000Kooooo1`000007oooo
o`X0dLfY0`000004ooooo`<000000oooool40000013ooooo1P000007ooooo`L000000oooool30000
00?ooooo1`000003ooooo`<000001?ooool:0=7=Z@<000002Oooool4000000Kooooo2@00000Coooo
o`X000000oooool3000000cooooo2`3AcJT6000000H0oooo0`00000<0?ooo``000000P3oool30000
00<0oooo0`0000060?ooo`<000001P3oool3000000H0oooo0`00000>0=7=Z@00303AcJT;000000?o
oooo1`000004oooooa`000001?ooool7000000Cooooo2P00000;0=7=Z@?ooooo0`000004ooooo`<0
00001?ooool3000000kooooo2P00000>ooooo`<000000oooool4000000?ooooo10000003ooooo`X0
dLfY0`000004ooooo`<000000oooool40000013ooooo1P000007ooooo`L000000oooool3000000?o
oooo1`000003ooooo`<000001?ooool:0=7=Z@?ooooo0`000006ooooo`@000000oooool3000000Ko
oooo0`000003ooooo`@000000oooool3000001?ooooo0`000006ooooo`H000002`3AcJT6000000H0
oooo0`00000<0?ooo``000000P3oool3000000<0oooo0`0000060?ooo`<000001P3oool3000000H0
oooo0`00000>0=7=Z@00303AcJTEooooob@000005Oooool;0=7=Z@?ooooo0`000004ooooo`<00000
1?ooool3000000kooooo2P00000>ooooo`<000000oooool4000000?ooooo10000003ooooo`X0dLfY
0`000004ooooo`<000001oooool6000000?ooooo1`000006ooooo`L000001oooool9000000Cooooo
0`000003ooooo`<000001?ooool:0=7=Z@?ooooo0`000006ooooo`@000000oooool3000000Kooooo
0`000003ooooo`@000000oooool3000001?ooooo0`000006ooooo`H000002`3AcJT6000000H0oooo
0`00000<0?ooo``000000P3oool3000000<0oooo0`0000060?ooo`<000001P3oool3000000H0oooo
0`00000>0=7=Z@00303AcJTEooooob@000005Oooool;0=7=Z@?ooooo0`000004ooooo`<000001?oo
ool3000000kooooo2P00000>ooooo`<000000oooool4000000?ooooo10000003ooooo`X0dLfY0`00
0004ooooo`<000001oooool6000000?ooooo1`000006ooooo`L000001oooool9000000Cooooo0`00
0003ooooo`<000001?ooool:0=7=Z@?ooooo0`000006ooooo`@000000oooool3000000Kooooo0`00
0003ooooo`@000000oooool3000001?ooooo0`000006ooooo`H000002`3AcJT60?ooo`<000001P3o
ool?000000H0oooo200000030?ooo``000004P3oool>0=7=Z@00303AcJTEooooob@000005Oooool;
0=7=ZDh000002P3AcJT3000000Cooooo0`000007ooooo`H000000oooool7000000Kooooo1`000007
ooooo`T000001?ooool3000000?ooooo0`000004ooooo`X0dLfYCP00000;0=7=Z@H0oooo0`000006
0?ooo`l000001P3oool8000000<0oooo3000000B0?ooo`h0dLfY000<0=7=ZAGooooo9000000Eoooo
o`/0dLfYCP00000:0=7=Z@<000001?ooool3000000Oooooo1P000003ooooo`L000001_ooool70000
00Oooooo2@000004ooooo`<000000oooool3000000Cooooo2P3AcJU>000000/0dLfY1P3oool30000
00H0oooo3`0000060?ooo`P000000`3oool<00000180oooo3P3AcJT000`0dLfY5OoooolT000001Go
oooo2`3AcJU>000000X0dLfY5?ooool3000000Oooooo0`000003ooooo`<000001?ooool@000000go
oooo1`00000:0=7=ZDh000002`3AcJTB0?ooo``000000`3oool8000000H0oooo3`0000060?ooo`<0
00001P3oool>0=7=Z@00303AcJTEooooob@000005Oooool;0=7=Z@?ooooo0`000004ooooo`<00000
1?ooool3000000kooooo2P00000>ooooo`<000000oooool4000000?ooooo10000003ooooo`X0dLfY
5?ooool3000000Oooooo0`000003ooooo`<000001?ooool@000000gooooo1`00000:0=7=Z@?ooooo
0`000006ooooo`@000000oooool3000000Kooooo0`000003ooooo`@000000oooool3000001?ooooo
0`000006ooooo`H000002`3AcJTB0?ooo``000000`3oool8000000H0oooo3`0000060?ooo`<00000
1P3oool>0=7=Z@00303AcJTEooooob@000005Oooool;0=7=Z@?ooooo0`000004ooooo`<000001?oo
ool3000000kooooo2P00000>ooooo`<000000oooool4000000?ooooo10000003ooooo`X0dLfY5?oo
ool3000000Oooooo0`000003ooooo`<000001?ooool@000000gooooo1`00000:0=7=Z@?ooooo0`00
0006ooooo`@000000oooool3000000Kooooo0`000003ooooo`@000000oooool3000001?ooooo0`00
0006ooooo`H000002`3AcJTB0?ooo``000000`3oool8000000H0oooo3`0000060?ooo`<000001P3o
ool>0=7=Z@00303AcJT;000000?ooooo1`000004oooooa`000001?ooool7000000Cooooo2P00000;
0=7=Z@?ooooo0`000004ooooo`<000001?ooool3000000kooooo2P00000>ooooo`<000000oooool4
000000?ooooo10000003ooooo`X0dLfY1`00000Mooooo`<000001?ooool6000000Oooooo0`00000D
ooooo`X0dLfY0oooool3000000Kooooo10000003ooooo`<000001_ooool3000000?ooooo10000003
ooooo`<000004oooool3000000Kooooo1P00000;0=7=Z@<000001P3oool3000000H0oooo0`000006
0?ooo`<000000`3oool3000000<0oooo2`00000<0?ooo`<000001P3oool6000000h0dLfY000<0=7=
Z@/000000oooool7000000Cooooo70000004ooooo`L000001?ooool:000000/0dLfY0oooool30000
00Cooooo0`000004ooooo`<000003_ooool:000000kooooo0`000003ooooo`@000000oooool40000
00?ooooo2P3AcJT7000001gooooo0`000004ooooo`H000001oooool3000001Cooooo2P3AcJT30000
00Wooooo10000006ooooo`T000004oooool:000000?ooooo0`00000<ooooo`/0dLfY0`0000060?oo
o`<000001P3oool3000000H0oooo0`0000030?ooo`<000000`3oool;000000`0oooo0`0000060?oo
o`H000003P3AcJT000`0dLfY2`000003ooooo`L000001?oooolL000000Cooooo1`000004ooooo`X0
00002`3AcJT6ooooo`L000001oooool3000000Oooooo10000003ooooo`<000001?ooool3000000Oo
oooo10000006ooooo`L000001oooool:0=7=Z@L000007Oooool3000000Cooooo1P000007ooooo`<0
00005?ooool:0=7=Z@<000002Oooool4000000Kooooo2@00000Cooooo`X000000oooool3000000co
oooo2`3AcJT3000000H0oooo0`0000060?ooo`<000001P3oool3000000<0oooo0`0000030?ooo`/0
0000303oool3000000H0oooo1P00000>0=7=Z@00303AcJT;000000?ooooo1`000004oooooa`00000
1?ooool7000000Cooooo2P00000;0=7=Z@Kooooo1`000007ooooo`<000001oooool4000000?ooooo
0`000004ooooo`<000001oooool4000000Kooooo1`000007ooooo`X0dLfY1oooool6000000[ooooo
50000003ooooo`L000000oooool3000000gooooo1`00000:0=7=Z@<000002Oooool4000000Kooooo
2@00000Cooooo`X000000oooool3000000cooooo2`3AcJT30?ooo`H00000303oool6000000H0oooo
0`00000>0?ooo`H000000`3oool3000000T0oooo0`0000030?ooo`h0dLfY000<0=7=Z@L000001?oo
ool>000000?ooooo5P000003ooooo`l000000oooool7000000/0dLfY1_ooool7000000Oooooo0`00
0007ooooo`@000000oooool3000000Cooooo0`000007ooooo`@000001_ooool7000000Oooooo2P3A
cJT7ooooo`H000002_oooolD000000?ooooo1`000003ooooo`<000003Oooool7000000X0dLfY1P00
0003ooooo`<000001?ooool3000000?ooooo2@000003ooooo`L000000oooool<000000Oooooo2@00
0003ooooo`<000002`3AcJT30?ooo`H00000303oool6000000H0oooo0`00000>0?ooo`H000000`3o
ool3000000T0oooo0`0000030?ooo`h0dLfY000<0=7=Z@L000001?ooool>000000?ooooo5P000003
ooooo`l000000oooool7000000/0dLfY2_ooool3000000Oooooo0`000004ooooo`<000001oooool3
000000Oooooo10000003ooooo`@000001_ooool4000000[ooooo2P3AcJT7ooooo`H000002_oooolD
000000?ooooo1`000003ooooo`<000003Oooool7000000X0dLfY1P000003ooooo`<000001?ooool3
000000?ooooo2@000003ooooo`L000000oooool<000000Oooooo2@000003ooooo`<000002`3AcJT3
0?ooo`H00000303oool6000000H0oooo0`00000>0?ooo`H000000`3oool3000000T0oooo0`000003
0?ooo`h0dLfY000<0=7=Z@L000001?ooool>000000?ooooo5P000003ooooo`l000000oooool70000
00/0dLfY2_ooool3000000Oooooo0`000004ooooo`<000001oooool3000000Oooooo10000003oooo
o`@000001_ooool4000000[ooooo2P3AcJT70000013ooooo2P000003ooooo`<000001oooool70000
00?ooooo0`000007ooooo`H000001oooool:0=7=Z@H000000oooool3000000Cooooo0`000003oooo
o`T000000oooool7000000?ooooo30000007ooooo`T000000oooool3000000/0dLfY2@0000030?oo
o`<000000`3oool3000000<0oooo0`0000060?ooo`/000001P3oool3000000<0oooo0`0000030?oo
o`<000000`3oool9000000h0dLfY000<0=7=Z@Oooooo1000000:ooooo`L000001?ooool>000000Co
oooo1`00000;ooooo`<000001oooool;0=7=Z@[ooooo0`000007ooooo`<000001?ooool3000000Oo
oooo0`000007ooooo`@000000oooool4000000Kooooo1000000:ooooo`X0dLfY1`00000@ooooo`X0
00000oooool3000000Oooooo1`000003ooooo`<000001oooool6000000Oooooo2P3AcJT3ooooo`<0
00002_ooool6000000Kooooo1P000004ooooo`<000000oooool6000000Kooooo1`000009ooooo`<0
00000oooool;0=7=Z@T000000`3oool3000000<0oooo0`0000030?ooo`<000001P3oool;000000H0
oooo0`0000030?ooo`<000000`3oool3000000<0oooo2@00000>0=7=Z@00303AcJT7ooooo`@00000
2_ooool7000000Cooooo3P000004ooooo`L000002oooool3000000Oooooo2`3AcJT6ooooo`@00000
0oooool4000000Kooooo1000000:ooooo`<000002oooool3000000Oooooo0`000004ooooo`<00000
1oooool:0=7=Z@L000004?ooool:000000?ooooo0`000007ooooo`L000000oooool3000000Oooooo
1P000007ooooo`X0dLfY0oooool3000000[ooooo1P000006ooooo`H000001?ooool3000000?ooooo
1P000006ooooo`L000002Oooool3000000?ooooo2`3AcJT9000000<0oooo0`0000030?ooo`<00000
0`3oool3000000H0oooo2`0000060?ooo`<000000`3oool3000000<0oooo0`0000030?ooo`T00000
3P3AcJT000`0dLfY1oooool4000000[ooooo1`000004ooooo`h000001?ooool7000000_ooooo0`00
0007ooooo`/0dLfY1_ooool4000000?ooooo10000006ooooo`@000002_ooool3000000_ooooo0`00
0007ooooo`<000001?ooool3000000Oooooo2P3AcJT7000000?ooooo0`000007ooooo`<000000ooo
ool7000000gooooo0`000007ooooo`<000002_ooool3000000?ooooo1000000:0=7=Z@?ooooo0`00
000:ooooo`H000001_ooool6000000Cooooo0`000003ooooo`H000001_ooool7000000Wooooo0`00
0003ooooo`/0dLfY1P3oool<000000<0oooo300000030?ooo`D000000`3oool<000000<0oooo3000
00060?ooo`h0dLfY000<0=7=Z@Oooooo1000000:ooooo`L000001?ooool>000000Cooooo1`00000;
ooooo`<000001oooool;0=7=Z@Kooooo10000003ooooo`@000001_ooool4000000[ooooo0`00000;
ooooo`<000001oooool3000000Cooooo0`000007ooooo`X0dLfY1`000003ooooo`<000001oooool3
000000?ooooo1`00000=ooooo`<000001oooool3000000[ooooo0`000003ooooo`@000002P3AcJT3
ooooo`<000000oooool:000000Wooooo1P000004ooooo`<000000oooool6000000[ooooo2@000003
ooooo`<000000oooool;0=7=Z@H0oooo300000030?ooo``000000`3oool5000000<0oooo30000003
0?ooo``000001P3oool>0=7=Z@00303AcJT;ooooo`<000001oooool;000000Cooooo1`000003oooo
o`/000001oooool4000000[ooooo2`3AcJT6ooooo`@000000oooool4000000Kooooo1000000:oooo
o`<000002oooool3000000Oooooo0`000004ooooo`<000001oooool:0=7=Z@L000000oooool30000
00Oooooo0`000003ooooo`L000003Oooool3000000Oooooo0`00000:ooooo`<000000oooool40000
00X0dLfY0oooool3000000?ooooo2P000009ooooo`H000001?ooool3000000?ooooo1P00000:oooo
o`T000000oooool3000000?ooooo2`3AcJT60?ooo``000000`3oool<000000<0oooo1@0000030?oo
o``000000`3oool<000000H0oooo3P3AcJT000`0dLfY2oooool3000000Oooooo2`000004ooooo`L0
00000oooool;000000Oooooo1000000:ooooo`/0dLfY5?ooool3000000Cooooo1`000003ooooo`<0
00001?ooool7000000?ooooo1000000Dooooo`X0dLfY1`000003ooooo`<000001oooool3000000?o
oooo1`00000=ooooo`<000001oooool3000000[ooooo0`000003ooooo`@000002P3AcJT3ooooo`<0
00000oooool:000000Wooooo1P000004ooooo`<000000oooool6000000[ooooo2@000003ooooo`<0
00000oooool;0=7=Z@<000000`3oool3000000H0oooo1P0000030?ooo`<000000`3oool3000000<0
oooo1@0000030?ooo`<000000`3oool3000000<0oooo1P0000060?ooo`<000000`3oool3000000h0
dLfY000<0=7=Z@_ooooo0`000007ooooo`/000001?ooool7000000?ooooo2`000007ooooo`@00000
2_ooool;0=7=ZACooooo0`000004ooooo`L000000oooool3000000Cooooo1`000003ooooo`@00000
5?ooool:0=7=Z@<000001oooool3000000[ooooo0`000004ooooo`<000005?ooool3000000gooooo
0`000007ooooo`X0dLfY0oooool6000000?ooooo2P000003ooooo`<000002_ooool9000000?ooooo
0`000003ooooo`@000004_ooool;0=7=Z@<000000`3oool3000000H0oooo1P0000030?ooo`<00000
0`3oool3000000<0oooo1@0000030?ooo`<000000`3oool3000000<0oooo1P0000060?ooo`<00000
0`3oool3000000h0dLfY000<0=7=Z@<000002?ooool:000000Oooooo20000007ooooo`L000001ooo
ool;000000Oooooo0`00000;0=7=ZACooooo0`000004ooooo`L000000oooool3000000Cooooo1`00
0003ooooo`@000005?ooool:0=7=Z@<000001oooool3000000[ooooo0`000004ooooo`<000005?oo
ool3000000gooooo0`000007ooooo`X0dLfY0oooool6000000?ooooo2P000003ooooo`<000002_oo
ool9000000?ooooo0`000003ooooo`@000004_ooool;0=7=Z@<000000`3oool3000000H0oooo1P00
00030?ooo`<000000`3oool3000000<0oooo1@0000030?ooo`<000000`3oool3000000<0oooo1P00
00060?ooo`<000000`3oool3000000h0dLfY000<0=7=Z@<000002?ooool:000000Oooooo20000007
ooooo`L000001oooool;000000Oooooo0`00000;0=7=Z@?ooooo1`000003ooooo`L000003_ooool:
000000kooooo1P000004ooooo`L000000oooool:0=7=Z@<000001oooool3000000[ooooo0`000004
ooooo`<000005?ooool3000000gooooo0`000007ooooo`X0dLfY0oooool6000000?ooooo2P000003
ooooo`<000002_ooool9000000?ooooo0`000003ooooo`@000004_ooool;0=7=Z@<000000`3oool3
000000`0oooo0`0000030?ooo`<000001P3oool8000000<0oooo0`0000030?ooo`<000000`3oool3
000000`0oooo0`00000>0=7=Z@00303AcJT3000000Sooooo2P000007ooooo`P000001oooool70000
00Oooooo2`000007ooooo`<000002`3AcJT3ooooo`L000000oooool7000000kooooo2P00000>oooo
o`H000001?ooool7000000?ooooo2P3AcJT3000000Cooooo0`000003ooooo`@000000oooool30000
00?ooooo10000009ooooo`L000000oooool:000000?ooooo10000006ooooo`L000002P3AcJT3oooo
o`H000000oooool:000000?ooooo0`00000:ooooo`T000000oooool3000000?ooooo1000000Boooo
o`/0dLfY0`0000030?ooo`<00000303oool3000000<0oooo0`0000060?ooo`P000000`3oool30000
00<0oooo0`0000030?ooo`<00000303oool3000000h0dLfY000<0=7=Z@<000002?ooool:000000Oo
oooo20000007ooooo`L000001oooool;000000Oooooo0`00000;0=7=Z@?ooooo1`000003ooooo`L0
00003_ooool:000000kooooo1P000004ooooo`L000000oooool:0=7=Z@<000001?ooool3000000?o
oooo10000003ooooo`<000000oooool4000000Wooooo1`000003ooooo`X000000oooool4000000Ko
oooo1`00000:0=7=Z@H000000oooool3000000[ooooo2@00000Cooooo`X000001_ooool3000000?o
oooo0`000003ooooo`/0dLfY0`0000030?ooo`<00000303oool3000000<0oooo0`0000060?ooo`P0
00000`3oool3000000<0oooo0`0000030?ooo`<00000303oool3000000h0dLfY000<0=7=Z@?ooooo
20000003ooooo`L000001oooool8000000Oooooo1`000007ooooo`L000001?ooool7000000?ooooo
2`3AcJT6000000Cooooo2P000003ooooo`@000002_ooool3000000_ooooo0`000004ooooo`X00000
0oooool7000000X0dLfY0`000004ooooo`<000000oooool4000000?ooooo0`000003ooooo`@00000
2Oooool7000000?ooooo2P000003ooooo`@000001_ooool7000000X0dLfY1P000003ooooo`<00000
2_ooool9000001?ooooo2P000006ooooo`<000000oooool3000000?ooooo2`3AcJT30?ooo`<00000
2@3oool<000000<0oooo0`0000030?ooo`<000002`3oool6000000<0oooo2@0000090?ooo`h0dLfY
000<0=7=Z@?ooooo20000003ooooo`L000001oooool8000000Oooooo1`000007ooooo`L000001?oo
ool7000000?ooooo2`3AcJT6000000Cooooo2P000003ooooo`@000002_ooool3000000_ooooo0`00
0004ooooo`X000000oooool7000000X0dLfY1oooool6000000Cooooo0`00000:ooooo`T000001ooo
ool3000000Oooooo1P000007ooooo`<000000oooool4000000X0dLfY1P000003ooooo`<000002_oo
ool9000001?ooooo2P000006ooooo`<000000oooool3000000?ooooo2`3AcJT30?ooo`<000002@3o
ool<000000<0oooo0`0000030?ooo`<000002`3oool6000000<0oooo2@0000090?ooo`h0dLfY000<
0=7=Z@?ooooo20000003ooooo`L000001oooool8000000Oooooo1`000007ooooo`L000001?ooool7
000000?ooooo2`3AcJT6000000Cooooo2P000003ooooo`@000002_ooool3000000_ooooo0`000004
ooooo`X000000oooool7000000X0dLfY1oooool6000000Cooooo0`00000:ooooo`T000001oooool3
000000Oooooo1P000007ooooo`<000000oooool4000000X0dLfY0`000003ooooo`X000000oooool6
000000?ooooo2P000003ooooo`H000001_ooool3000000Oooooo2@000006ooooo`/0dLfY0`3oool3
000000T0oooo300000030?ooo`<000000`3oool3000000/0oooo1P0000030?ooo`T000002@3oool>
0=7=Z@00303AcJT3ooooo`/000001?ooool7000000?ooooo1000000>ooooo`@000000oooool80000
00?ooooo2`000003ooooo`/0dLfY1P000004ooooo`X000000oooool4000000[ooooo0`00000;oooo
o`<000001?ooool:000000?ooooo1`00000:0=7=Z@Oooooo1P000004ooooo`<000002_ooool90000
00Oooooo0`000007ooooo`H000001oooool3000000?ooooo1000000:0=7=Z@<000000oooool:0000
00?ooooo1P000003ooooo`X000000oooool6000000Kooooo0`000007ooooo`T000001_ooool;0=7=
ZA8000001P3oool6000000<0oooo0`00000;0?ooo`H000002@3oool6000000<0oooo1P00000>0=7=
Z@00303AcJT3ooooo`/000001?ooool7000000?ooooo1000000>ooooo`@000000oooool8000000?o
oooo2`000003ooooo`/0dLfY0oooool3000000Cooooo1`00000:oooooaP000002_ooool7000000?o
oooo10000003ooooo`X0dLfY0`000004ooooo`d000000oooool3000000Cooooo0`000003oooooa@0
00000oooool7000000gooooo2P3AcJT3000000?ooooo2P000003ooooo`H000000oooool:000000?o
oooo1P000006ooooo`<000001oooool9000000Kooooo2`3AcJTB000000H0oooo1P0000030?ooo`<0
00002`3oool6000000T0oooo1P0000030?ooo`H000003P3AcJT000`0dLfY0oooool;000000Cooooo
1`000003ooooo`@000003_ooool4000000?ooooo20000003ooooo`/000000oooool;0=7=Z@?ooooo
0`000004ooooo`L000002_oooolH000000[ooooo1`000003ooooo`@000000oooool:0=7=Z@<00000
1?ooool=000000?ooooo0`000004ooooo`<000000ooooolD000000?ooooo1`00000=ooooo`X0dLfY
0oooool9000000[ooooo0`000003oooooaH000000oooool3000000[ooooo2@000003ooooo`/0dLfY
4P0000060?ooo`H000000`3oool3000000/0oooo1P0000090?ooo`H000000`3oool6000000h0dLfY
000<0=7=Z@<000001?ooool;000000Oooooo0`000004ooooo`@000001oooool3000000Cooooo0`00
0008ooooo`X000001?ooool3000000/0dLfY0oooool3000000Cooooo1`00000:oooooaP000002_oo
ool7000000?ooooo10000003ooooo`X0dLfY0`000004ooooo`d000000oooool3000000Cooooo0`00
0003oooooa@000000oooool7000000gooooo2P3AcJT3ooooo`T000002_ooool3000000?ooooo5P00
0003ooooo`<000002_ooool9000000?ooooo2`3AcJT30?ooo`l000001P3oool3000000h0oooo0`00
00060?ooo`<000002@3oool6000000<0oooo0`0000030?ooo`h0dLfY000<0=7=Z@<000001?ooool;
000000Oooooo0`000004ooooo`@000001oooool3000000Cooooo0`000008ooooo`X000001?ooool3
000000/0dLfY0oooool7000000Oooooo0`000003ooooo`@000000oooool4000000?ooooo0`000004
ooooo`<000001?ooool3000000Cooooo0`000007ooooo`L000000oooool:0=7=Z@L000001_ooool:
0000013ooooo10000003ooooo`<000001oooool@000000?ooooo1000000:0=7=Z@?ooooo2@00000:
ooooo`<000000ooooolF000000?ooooo0`00000:ooooo`T000000oooool;0=7=Z@<0oooo3`000006
0?ooo`<000003P3oool3000000H0oooo0`0000090?ooo`H000000`3oool3000000<0oooo3P3AcJT0
00`0dLfY0`000004ooooo`/000001oooool3000000Cooooo10000007ooooo`<000001?ooool30000
00Sooooo2P000004ooooo`<000002`3AcJT3ooooo`L000001oooool3000000?ooooo10000003oooo
o`@000000oooool3000000Cooooo0`000004ooooo`<000001?ooool3000000Oooooo1`000003oooo
o`X0dLfY1`000006ooooo`X000004?ooool4000000?ooooo0`000007oooooa0000000oooool40000
00X0dLfY0`000003ooooo`<000000oooool4000001oooooo0`000006ooooo`@000000oooool30000
00?ooooo0`000006ooooo`/0dLfY0`3oool?000000H0oooo0`00000>0?ooo`<000001P3oool30000
00T0oooo1P0000030?ooo`<000000`3oool>0=7=Z@00303AcJT3000000Cooooo2`000007ooooo`<0
00001?ooool4000000Oooooo0`000004ooooo`<000002?ooool:000000Cooooo0`00000;0=7=Z@?o
oooo1`000007ooooo`<000000oooool4000000?ooooo10000003ooooo`<000001?ooool3000000Co
oooo0`000004ooooo`<000001oooool7000000?ooooo2P3AcJT7000000Kooooo2P00000@ooooo`@0
00000oooool3000000Oooooo40000003ooooo`@000002P3AcJT3000000?ooooo0`000003ooooo`@0
00007oooool3000000Kooooo10000003ooooo`<000000oooool3000000Kooooo2`3AcJT30?ooo`H0
0000303oool9000000H0oooo0`0000050?ooo`l000000`3oool9000000H0oooo3P3AcJT000`0dLfY
0oooool4000000Cooooo1`00000:ooooo`P000001oooool7000000_ooooo1`000003ooooo`@00000
0oooool;0=7=ZA@000003_ooool:000000kooooo5000000:0=7=Z@L000001_ooool:0000013ooooo
10000003ooooo`<000001oooool@000000?ooooo1000000:0=7=Z@<000000oooool3000000?ooooo
1000000Oooooo`<000001_ooool4000000?ooooo0`000003ooooo`<000001_ooool;0=7=Z@<0oooo
1P00000<0?ooo`T000001P3oool3000000D0oooo3`0000030?ooo`T000001P3oool>0=7=Z@00303A
cJT3ooooo`@000001?ooool7000000[ooooo20000007ooooo`L000002oooool7000000?ooooo1000
0003ooooo`/0dLfY5000000>ooooo`X000003_oooolD000000X0dLfY0oooool4000000?ooooo2P00
0003ooooo`L000000oooool3000000?ooooo10000003ooooo`L000000oooool6000000Cooooo0`00
0006ooooo`@000002P3AcJT@ooooo``000001_ooool4000000?ooooo0`000003ooooo`T000001?oo
ool3000000cooooo0`00000;0=7=Z@<0oooo1P00000<0?ooo`T000001P3oool3000000D0oooo3`00
00030?ooo`T000001P3oool>0=7=Z@00303AcJT3ooooo`@000001?ooool7000000[ooooo20000007
ooooo`L000002oooool7000000?ooooo10000003ooooo`/0dLfY5000000>ooooo`X000003_oooolD
000000X0dLfY0oooool4000000?ooooo2P000003ooooo`L000000oooool3000000?ooooo10000003
ooooo`L000000oooool6000000Cooooo0`000006ooooo`@000002P3AcJT@ooooo``000001_ooool4
000000?ooooo0`000003ooooo`T000001?ooool3000000cooooo0`00000;0=7=Z@<000001P3oool6
000000`0oooo2@0000080?ooo`H000002@3oool<000000<0oooo0`00000>0=7=Z@00303AcJT30000
00Cooooo10000007ooooo`<000001oooool8000000Oooooo1`000007ooooo`@000001oooool30000
00Cooooo0`00000;0=7=ZA@000003_ooool:000000kooooo5000000:0=7=Z@?ooooo10000003oooo
o`X000000oooool7000000?ooooo0`000003ooooo`@000000oooool7000000?ooooo1P000004oooo
o`<000001_ooool4000000X0dLfY4?ooool<000000Kooooo10000003ooooo`<000000oooool90000
00Cooooo0`00000<ooooo`<000002`3AcJT3000000H0oooo1P00000<0?ooo`T00000203oool60000
00T0oooo300000030?ooo`<000003P3AcJT000`0dLfY0`000004ooooo`@000001oooool3000000Oo
oooo20000007ooooo`L000001oooool4000000Oooooo0`000004ooooo`<000002`3AcJT6000000Oo
oooo1000000Dooooo`<000005Oooool3000000Oooooo1`00000:0=7=Z@?ooooo1`000007ooooo`<0
00000oooool3000000Oooooo0`000003ooooo`@000001_ooool4000000?ooooo0`00000:ooooo`<0
00000oooool4000000X0dLfY2@000007ooooo`<000002Oooool3000000Oooooo3000000=ooooo`<0
00002Oooool3000000/0dLfY0`0000060?ooo`H00000303oool9000000P0oooo1P0000090?ooo``0
00000`3oool3000000h0dLfY000<0=7=Z@<000001?ooool4000000Oooooo0`000007ooooo`P00000
1oooool7000000Oooooo10000007ooooo`<000001?ooool3000000/0dLfY1P000007ooooo`@00000
5?ooool3000001Gooooo0`000007ooooo`L000002P3AcJT3ooooo`L000001oooool3000000?ooooo
0`000007ooooo`<000000oooool4000000Kooooo10000003ooooo`<000002_ooool3000000?ooooo
1000000:0=7=Z@T000001oooool3000000Wooooo0`000007ooooo``000003Oooool3000000Wooooo
0`00000;0=7=Z@<0oooo0`0000060?ooo`<000000`3oool6000000<0oooo0`0000030?ooo`<00000
1@3oool3000000<0oooo0`0000030?ooo`H000000`3oool3000000H0oooo0`0000030?ooo`h0dLfY
000<0=7=Z@<000001?ooool4000000Oooooo0`000007ooooo`P000001oooool7000000Oooooo1000
0007ooooo`<000001?ooool3000000/0dLfY1P000007ooooo`@000005?ooool3000001Gooooo0`00
0007ooooo`L000002P3AcJT3ooooo`L000001oooool3000000?ooooo0`000007ooooo`<000000ooo
ool4000000Kooooo10000003ooooo`<000002_ooool3000000?ooooo1000000:0=7=Z@T000001ooo
ool3000000Wooooo0`000007ooooo``000003Oooool3000000Wooooo0`00000;0=7=Z@<0oooo0`00
00060?ooo`<000000`3oool6000000<0oooo0`0000030?ooo`<000001@3oool3000000<0oooo0`00
00030?ooo`H000000`3oool3000000H0oooo0`0000030?ooo`h0dLfY003o0=7=ZG00dLfY0`3oool3
000000H0oooo0`0000030?ooo`H000000`3oool3000000<0oooo0`0000050?ooo`<000000`3oool3
000000<0oooo1P0000030?ooo`<000001P3oool3000000<0oooo3P3AcJT00?l0dLfYb`3AcJT00?l0
dLfYb`3AcJT00?l0dLfYb`3AcJT00?l0dLfYb`3AcJT00?l0dLfYb`3AcJT00?l0dLfYb`3AcJT00?l0
dLfYb`3AcJT00?l0dLfYb`3AcJT00?l0dLfYb`3AcJT00?l0dLfYb`3AcJT00?l0dLfYb`3AcJT000`0
dLfY9Oooool4000002Gooooo2`3AcJT4000000Cooooo3@000005oooooaX000001?ooool=000000Go
oooo1000000:0=7=Z@P000001Oooool4000001Cooooo1@00000Dooooo`@000001?ooool9000000X0
dLfY1000000Koooooa0000006oooool4000000/0dLfY4P00000Cooooo`@000004_oooolC000000d0
dLfY000<0=7=ZBGooooo1000000Uooooo`/0dLfY10000004ooooo`d000001OoooolJ000000Cooooo
3@000005ooooo`@000002P3AcJT8000000Gooooo1000000Dooooo`D000005?ooool4000000Cooooo
2@00000:0=7=Z@@000006oooool@000001_ooooo1000000;0=7=ZA8000004oooool4000001;ooooo
4`00000=0=7=Z@00303AcJTUooooo`@000009Oooool;0=7=Z@@000001?ooool=000000Gooooo6P00
0004ooooo`d000001Oooool4000000X0dLfY20000005ooooo`@000005?ooool5000001Cooooo1000
0004ooooo`T000002P3AcJT4000001_ooooo4000000Kooooo`@000002`3AcJTB000001?ooooo1000
000Boooooa<000003@3AcJT000`0dLfY9Oooool4000002Gooooo2`3AcJT4000000Cooooo3@000005
oooooaX000001?ooool=000000Gooooo1000000:0=7=Z@P000001Oooool4000001Cooooo1@00000D
ooooo`@000001?ooool9000000X0dLfY1000000Koooooa0000006oooool4000000/0dLfY4P00000C
ooooo`@000004_oooolC000000d0dLfY000<0=7=ZBGooooo1000000Uooooo`/0dLfY1?ooool=0000
00Cooooo8`000005ooooo`d000001?ooool:0=7=ZA4000001?ooool<000000Cooooo1@000004oooo
o``000001?oooolA000000X0dLfY1?ooool4000001Oooooo4000000Hooooo`<000001?ooool;0=7=
Z@/000002oooool4000000?ooooo10000004ooooo`@000000oooool4000000Cooooo1000000;oooo
o`/000003@3AcJT000`0dLfY3_ooool4000000Gooooo80000005ooooo`D000003Oooool;0=7=Z@Co
oooo3@000004ooooob<000001Oooool=000000Cooooo2P3AcJTA000000Cooooo30000004ooooo`D0
00001?ooool<000000Cooooo4@00000:0=7=Z@Cooooo1000000Goooooa0000006?ooool3000000Co
oooo2`3AcJT;000000_ooooo10000003ooooo`@000001?ooool4000000?ooooo10000004ooooo`@0
00002oooool;000000d0dLfY000<0=7=Z@kooooo10000005ooooob0000001Oooool5000000gooooo
2`3AcJT4ooooo`d000001?oooolS000000Gooooo3@000004ooooo`X0dLfY4@000004ooooo``00000
1?ooool5000000Cooooo30000004oooooa4000002P3AcJT4ooooo`@000005oooool@000001Sooooo
0`000004ooooo`/0dLfY2`00000;ooooo`@000000oooool4000000Cooooo10000003ooooo`@00000
1?ooool4000000_ooooo2`00000=0=7=Z@00303AcJT>ooooo`@000001OoooolP000000Gooooo1@00
000=ooooo`/0dLfY1?ooool=000000Cooooo8`000005ooooo`d000001?ooool:0=7=ZA4000001?oo
ool<000000Cooooo1@000004ooooo``000001?oooolA000000X0dLfY1?ooool4000001Oooooo4000
000Hooooo`<000001?ooool;0=7=Z@/000002oooool4000000Oooooo2`000008ooooo`@000002ooo
ool;000000d0dLfY000<0=7=Z@kooooo10000005ooooob0000001Oooool5000000gooooo2`3AcJT4
ooooo`d000001?oooolS000000Gooooo3@000004ooooo`X0dLfY1?oooolA000000Sooooo5@000008
oooooa4000001?ooool:0=7=Z@Sooooo2`00000@ooooo`P000004?ooool<000000Oooooo2`3AcJT;
000000_ooooo10000007ooooo`/000002?ooool4000000_ooooo2`00000=0=7=Z@00303AcJT>0000
00Cooooo1@00000>ooooo`@000003_ooool5000000Gooooo3@00000;0=7=ZAX000006_oooolJ0000
00X0dLfY1?oooolA000000Sooooo5@000008oooooa4000001?ooool:0=7=Z@Sooooo2`00000@oooo
o`P000004?ooool<000000Oooooo2`3AcJT;000000_ooooo10000007ooooo`/000002?ooool40000
00_ooooo2`00000=0=7=Z@00303AcJT>000000Cooooo1@00000>ooooo`@000003_ooool5000000Go
oooo3@00000;0=7=ZAX000006_oooolJ000000X0dLfY1?oooolA000000Sooooo5@000008oooooa40
00001?ooool:0=7=Z@Sooooo2`00000@ooooo`P000004?ooool<000000Oooooo2`3AcJT;000000_o
oooo10000007ooooo`/000002?ooool4000000_ooooo2`00000=0=7=Z@00303AcJT>000000Cooooo
1@00000>ooooo`@000003_ooool5000000Gooooo3@00000;0=7=ZAX000006_oooolJ000000X0dLfY
1?oooolA000000Sooooo5@000008oooooa4000001?ooool:0=7=Z@Sooooo2`00000@ooooo`P00000
4?ooool<000000Oooooo2`3AcJT3000000Sooooo3`000003oooooa<000001?ooool?000000Oooooo
1000000=0=7=Z@00303AcJT>000000Cooooo1@00000>ooooo`@000003_ooool5000000Gooooo3@00
000;0=7=ZAX000006_oooolJ000000X0dLfY6@000004ooooo`@000001?ooool5000000Cooooo1000
0004oooooaT000002P3AcJT8ooooo`P000000oooool4000000Sooooo10000008ooooo`@000002?oo
ool4000000Cooooo20000007ooooo`/0dLfY0`000008ooooo`l000000ooooolC000000Cooooo3`00
0007ooooo`@000003@3AcJT000`0dLfY3P000004ooooo`D000003_ooool4000000kooooo1@000005
ooooo`d000002`3AcJTJ000001[ooooo6P00000:0=7=ZAT000001?ooool4000000Cooooo1@000004
ooooo`@000001?oooolI000000X0dLfY2?ooool8000000?ooooo10000008ooooo`@000002?ooool4
000000Sooooo10000004ooooo`P000001oooool;0=7=Z@<000002?ooool?000000?ooooo4`000004
ooooo`l000001oooool4000000d0dLfY000<0=7=Z@@000002_oooolB000000Gooooo10000005oooo
oa<000002Oooool4000000/0dLfY6P00000JoooooaX000002P3AcJTI000000Cooooo10000004oooo
o`D000001?ooool4000000Cooooo6@00000:0=7=Z@Sooooo20000003ooooo`@000002?ooool40000
00Sooooo10000008ooooo`@000001?ooool8000000Oooooo2`3AcJT3000000Sooooo3`000003oooo
oa<000001?ooool?000000Oooooo1000000=0=7=Z@00303AcJT4000000[ooooo4P000005ooooo`@0
00001OoooolC000000Wooooo1000000;0=7=ZAX000006_oooolJ000000X0dLfY6@000004ooooo`@0
00001?ooool5000000Cooooo10000004oooooaT000002P3AcJT8ooooo`@000001?ooool;000000Co
oooo40000004ooooo``000001?ooool4000000Oooooo2`3AcJT3000000Sooooo1`000008ooooo`L0
00001?ooool4000000?ooooo20000007ooooo`P000001oooool4000000d0dLfY000<0=7=Z@@00000
2_oooolB000000Gooooo10000005oooooa<000002Oooool4000000/0dLfY6P00000JoooooaX00000
2P3AcJT8oooooa4000001?ooool4000000Cooooo1@000004ooooo`@000001?ooool@000000Wooooo
2P3AcJT8ooooo`@000001?ooool;000000Cooooo40000004ooooo``000001?ooool4000000Oooooo
2`3AcJT3000000Sooooo1`000008ooooo`L000001?ooool4000000?ooooo20000007ooooo`P00000
1oooool4000000d0dLfY000<0=7=Z@@000002_oooolB000000Gooooo10000005oooooa<000002Ooo
ool4000000/0dLfY10000004oooooa8000001?ooool4000000Wooooo1@000004oooooa4000001Ooo
ool4000000X0dLfY2?oooolA000000Cooooo10000004ooooo`D000001?ooool4000000Cooooo4000
0009ooooo`X0dLfY2?ooool4000000Cooooo2`000004oooooa0000001?ooool<000000Cooooo1000
0007ooooo`/0dLfY0`000008ooooo`L000002?ooool7000000Cooooo10000003ooooo`P000001ooo
ool8000000Oooooo1000000=0=7=Z@00303AcJT4000000Gooooo1@00000Gooooo`@000006?ooool4
000000Gooooo1000000;0=7=Z@@000001?oooolB000000Cooooo10000009ooooo`D000001?oooolA
000000Gooooo1000000:0=7=Z@Sooooo4@000004ooooo`@000001?ooool5000000Cooooo10000004
oooooa0000002Oooool:0=7=Z@Sooooo10000004ooooo`/000001?ooool@000000Cooooo30000004
ooooo`@000001oooool;0=7=Z@_ooooo0`000004ooooo`l000001?ooool4000000?ooooo3`000004
ooooo`@000002oooool=0=7=Z@00303AcJT4000000Gooooo1@00000Gooooo`@000006?ooool40000
00Gooooo1000000;0=7=Z@@000001?oooolB000000Cooooo10000009ooooo`D000001?oooolA0000
00Gooooo1000000:0=7=Z@Sooooo4@000004ooooo`@000001?ooool5000000Cooooo10000004oooo
oa0000002Oooool:0=7=Z@cooooo2`000004oooooaP000001?ooool<000000_ooooo2`3AcJT;oooo
o`<000001?ooool?000000Cooooo10000003ooooo`l000001?ooool4000000_ooooo3@3AcJT000`0
dLfY10000005ooooo`D000005oooool4000001Sooooo10000005ooooo`@000002`3AcJT4000000Co
oooo4P000004ooooo`@000002Oooool5000000Cooooo4@000005ooooo`@000002P3AcJT4ooooo`@0
00001Oooool<000000Cooooo10000004ooooo`D000001?ooool4000000Cooooo30000004ooooo`D0
00001?ooool:0=7=Z@cooooo2`000004oooooaP000001?ooool<000000_ooooo2`3AcJT;ooooo`<0
00001?ooool?000000Cooooo10000003ooooo`l000001?ooool4000000_ooooo3@3AcJT000`0dLfY
10000005ooooo`D000005oooool4000001Sooooo10000005ooooo`@000002`3AcJT4oooooaX00000
4_oooolJ000000Cooooo2P3AcJT4ooooo`@000001Oooool<000000Cooooo10000004ooooo`D00000
1?ooool4000000Cooooo30000004ooooo`D000001?ooool:0=7=Z@cooooo2`000004oooooaP00000
1?ooool<000000_ooooo2`3AcJT;ooooo`<000001?ooool?000000Cooooo10000003ooooo`l00000
1?ooool4000000_ooooo3@3AcJT000`0dLfY10000005ooooo`D000005oooool4000001Sooooo1000
0005ooooo`@000002`3AcJT4oooooaX000004_oooolJ000000Cooooo2P3AcJT4ooooo`@000001Ooo
ool<000000Cooooo10000004ooooo`D000001?ooool4000000Cooooo30000004ooooo`D000001?oo
ool:0=7=Z@cooooo2`000004oooooaP000001?ooool<000000_ooooo2`3AcJT3ooooo`/000001?oo
ool?000000Cooooo10000003ooooo`l000001?ooool;000000Cooooo3@3AcJT000`0dLfY1000000:
ooooo`h000002Oooool4000000[ooooo3P000009ooooo`@000002`3AcJT4oooooaX000004_oooolJ
000000Cooooo2P3AcJT4ooooo`@000001Oooool<000000Cooooo10000004ooooo`D000001?ooool4
000000Cooooo30000004ooooo`D000001?ooool:0=7=ZA3ooooo0`000004ooooob0000001?ooool4
000000oooooo2`3AcJT3ooooo`/000001?ooool?000000Cooooo10000003ooooo`l000001?ooool;
000000Cooooo3@3AcJT000`0dLfY1000000:ooooo`h000002Oooool4000000[ooooo3P000009oooo
o`@000002`3AcJT4oooooaX000004_oooolJ000000Cooooo2P3AcJT4ooooo`@000004Oooool40000
00Sooooo1@000008ooooo`@000004?ooool5000000Cooooo2P3AcJT@ooooo`<000001?oooolP0000
00Cooooo1000000?ooooo`/0dLfY0oooool;000000Cooooo3`000004ooooo`@000000oooool?0000
00Cooooo2`000004ooooo`d0dLfY000<0=7=Z@@000002_ooool>000000Wooooo1000000:ooooo`h0
00002Oooool4000000/0dLfY1?oooolJ000001;ooooo6P000004ooooo`X0dLfY1?ooool40000017o
oooo10000008ooooo`D000002?ooool40000013ooooo1@000004ooooo`X0dLfY4?ooool3000000Co
oooo80000004ooooo`@000003oooool;0=7=Z@?ooooo2`000004ooooo`l000001?ooool4000000?o
oooo3`000004ooooo`/000001?ooool=0=7=Z@00303AcJT4000000[ooooo3P000009ooooo`@00000
2_ooool>000000Wooooo1000000;0=7=Z@P000003OoooolS000000gooooo2@00000:0=7=Z@Cooooo
1000000Aooooo`@000002?ooool5000000Sooooo1000000@ooooo`D000001?ooool:0=7=ZA3ooooo
0`000004ooooob0000001?ooool4000000oooooo2`3AcJT>ooooo`l000001?ooool;000000Cooooo
3`00000?ooooo`d0dLfY000<0=7=Z@T000002Oooool5000000Gooooo5`000004ooooo`D000002Ooo
ool9000000/0dLfY2000000=ooooob<000003Oooool9000000X0dLfY1?ooool40000017ooooo1000
0008ooooo`D000002?ooool40000013ooooo1@000004ooooo`X0dLfY4ooooolX000001?ooooo2`3A
cJT>ooooo`l000001?ooool;000000Cooooo3`00000?ooooo`d0dLfY000<0=7=Z@T000002Oooool5
000000Gooooo5`000004ooooo`D000002Oooool9000000/0dLfY2000000=ooooob<000003Oooool9
000000X0dLfY1?oooolE000000Cooooo5@000004oooooaD000001?ooool:0=7=ZA?ooooo:000000C
ooooo`/0dLfY3_ooool?000000Cooooo2`000004ooooo`l000003oooool=0=7=Z@00303AcJT90000
00Wooooo1@000005oooooaL000001?ooool5000000Wooooo2@00000;0=7=Z@P000003OoooolS0000
00gooooo2@00000:0=7=Z@Cooooo5@000004oooooaD000001?oooolE000000Cooooo2P3AcJTCoooo
obP000004oooool;0=7=Z@?ooooo10000004ooooo`l000000ooooolC000000Cooooo3`000004oooo
o`<000001?ooool=0=7=Z@00303AcJT9000000Wooooo1@000005oooooaL000001?ooool5000000Wo
oooo2@00000;0=7=Z@P000002Oooool4000000Gooooo6P000004ooooo`D000002?ooool9000000X0
dLfY1?oooolE000000Cooooo5@000004oooooaD000001?ooool:0=7=ZA?ooooo:000000Cooooo`/0
dLfY0oooool4000000Cooooo3`000003oooooa<000001?ooool?000000Cooooo0`000004ooooo`d0
dLfY000<0=7=Z@T000002Oooool5000000Gooooo5`000004ooooo`D000002Oooool9000000/0dLfY
20000009ooooo`@000001OoooolJ000000Cooooo1@000008ooooo`T000002P3AcJT4oooooaD00000
1?oooolE000000Cooooo5@000004ooooo`X0dLfY20000004ooooocL000001?ooool7000000/0dLfY
0oooool4000000Cooooo3`000003oooooa<000001?ooool?000000Cooooo0`000004ooooo`d0dLfY
000<0=7=Z@Cooooo1@00000CoooooaL000004_ooool5000000Cooooo2`3AcJT8000000Wooooo1000
0005oooooaX000001?ooool5000000Sooooo2@00000:0=7=Z@Sooooo1@00000@oooooaD000004?oo
ool4000000Wooooo2P3AcJT8000000Cooooo=`000004ooooo`L000002`3AcJT3ooooo`@000001?oo
ool?000000?ooooo4`000004ooooo`l000001?ooool3000000Cooooo3@3AcJT000`0dLfY1?ooool5
000001?ooooo5`00000Booooo`D000001?ooool;0=7=Z@P000002Oooool4000000Gooooo6P000004
ooooo`D000002?ooool9000000X0dLfY2?ooool50000013ooooo5@00000@ooooo`@000002Oooool:
0=7=Z@P000001?oooolg000000Cooooo1`00000;0=7=Z@Oooooo1`00000<oooooaX000002oooool8
000000Oooooo3@3AcJT000`0dLfY1?ooool5000001?ooooo5`00000Booooo`D000001?ooool;0=7=
Z@P000004_oooolJ0000017ooooo2@00000:0=7=Z@Sooooo1@00000@oooooaD000004?ooool40000
00Wooooo2P3AcJT8000000Cooooo=`000004ooooo`L000002`3AcJT7ooooo`L000003?oooolJ0000
00_ooooo20000007ooooo`d0dLfY000<0=7=Z@Cooooo1@00000CoooooaL000004_ooool5000000Co
oooo2`3AcJT8000001;ooooo6P00000Aooooo`T000002P3AcJT8ooooo`D000004?oooolE0000013o
oooo10000009ooooo`X0dLfY30000004ooooobl000001?ooool;000000/0dLfY1oooool7000000co
oooo6P00000;ooooo`P000001oooool=0=7=Z@00303AcJT9ooooo`h000002Oooool>000000Wooooo
3P000009ooooo`/0dLfY2000000BoooooaX000004Oooool9000000X0dLfYC`00000:0=7=Z@`00000
1?ooool_000000Cooooo2`00000;0=7=Z@Oooooo1`00000<oooooaX000002oooool8000000Oooooo
3@3AcJT000`0dLfY2Oooool>000000Wooooo3P000009ooooo`h000002Oooool;0=7=Z@P000004_oo
oolJ0000017ooooo2@00000:0=7=ZDl000002P3AcJT<000000Cooooo;`000004ooooo`/000002`3A
cJU>000000d0dLfY000<0=7=Z@Wooooo3P000009ooooo`h000002Oooool>000000Wooooo2`3AcJT8
000001;ooooo6P00000Aooooo`T000002P3AcJU?000000X0dLfY30000004ooooobl000001?ooool;
000000/0dLfYCP00000=0=7=Z@00303AcJT9ooooo`h000002Oooool>000000Wooooo3P000009oooo
o`/0dLfY2000000BoooooaX000004Oooool9000000X0dLfYC`00000:0=7=Z@`000001?ooool_0000
00Cooooo2`00000;0=7=ZDh000003@3AcJT000`0dLfY2Oooool>000000Wooooo3P000009ooooo`h0
00002Oooool;0=7=Z@P000004_oooolJ0000017ooooo2@00000:0=7=Z@Sooooo1@00000@oooooaD0
00004?ooool4000000Wooooo2P3AcJT<000000Cooooo;`000004ooooo`/000002`3AcJT7ooooo`L0
00003?oooolJ000000_ooooo20000007ooooo`d0dLfY000<0=7=Z@kooooo2@000009ooooo`h00000
2Oooool:000000gooooo2`3AcJT8000001;ooooo6P00000Aooooo`T000002P3AcJT8ooooo`D00000
4?oooolE0000013ooooo10000009ooooo`X0dLfY30000004ooooobl000001?ooool;000000/0dLfY
1oooool7000000cooooo6P00000;ooooo`P000001oooool=0=7=Z@00303AcJT>ooooo`T000002Ooo
ool>000000Wooooo2P00000=ooooo`/0dLfY2000000BoooooaX000004Oooool9000000X0dLfY2?oo
ool50000013ooooo5@00000@ooooo`@000002Oooool:0=7=Z@P000001?oooolg000000Cooooo1`00
000;0=7=Z@Oooooo1`00000<oooooaX000002oooool8000000Oooooo3@3AcJT000`0dLfY3_ooool9
000000Wooooo3P000009ooooo`X000003Oooool;0=7=Z@P000002Oooool4000000Gooooo6P000004
ooooo`D000002?ooool9000000X0dLfY2?ooool50000013ooooo5@00000@ooooo`@000002Oooool:
0=7=Z@P000001?oooolg000000Cooooo1`00000;0=7=Z@Oooooo1`00000<oooooaX000002oooool8
000000Oooooo3@3AcJT000`0dLfY3_ooool9000000Wooooo3P000009ooooo`X000003Oooool;0=7=
Z@P000002Oooool4000000Gooooo6P000004ooooo`D000002?ooool9000000X0dLfY1?oooolE0000
00Cooooo5@000004oooooaD000001?ooool:0=7=Z@P000001?oooolg000000Cooooo1`00000;0=7=
Z@?ooooo10000004ooooo`l000000ooooolC000000Cooooo3`000004ooooo`<000001?ooool=0=7=
Z@00303AcJT9ooooo`D000001?ooool>000000Gooooo10000005ooooo`h000001Oooool4000000Wo
oooo2`3AcJT8000000Wooooo10000005oooooaX000001?ooool5000000Sooooo2@00000:0=7=Z@Co
oooo5@000004oooooaD000001?oooolE000000Cooooo2P3AcJT8000000Cooooo=`000004ooooo`L0
00002`3AcJT3ooooo`@000001?ooool?000000?ooooo4`000004ooooo`l000001?ooool3000000Co
oooo3@3AcJT000`0dLfY2Oooool5000000Cooooo3P000005ooooo`@000001Oooool>000000Gooooo
10000009ooooo`/0dLfY20000009ooooo`@000001OoooolJ000000Cooooo1@000008ooooo`T00000
2P3AcJT4oooooaD000001?oooolE000000Cooooo5@000004ooooo`X0dLfY4ooooolX000001?ooooo
2`3AcJT3ooooo`@000001?ooool?000000?ooooo4`000004ooooo`l000001?ooool3000000Cooooo
3@3AcJT000`0dLfY2Oooool5000000Cooooo3P000005ooooo`@000001Oooool>000000Gooooo1000
0009ooooo`/0dLfY2000000=ooooob<000003Oooool9000000X0dLfY1?oooolE000000Cooooo5@00
0004oooooaD000001?ooool:0=7=ZA?ooooo:000000Cooooo`/0dLfY3_ooool?000000Cooooo2`00
0004ooooo`l000003oooool=0=7=Z@00303AcJT9ooooo`D000001?ooool>000000Gooooo10000005
ooooo`h000001Oooool4000000Wooooo2`3AcJT8000000gooooo8`00000=ooooo`T000002P3AcJT4
ooooo`@000004Oooool4000000Sooooo1@000008ooooo`@000004?ooool5000000Cooooo2P3AcJTC
ooooobP000004oooool;0=7=Z@kooooo3`000004ooooo`/000001?ooool?000000oooooo3@3AcJT0
00`0dLfY2Oooool5000000Cooooo3P000005ooooo`@000001Oooool>000000Gooooo10000009oooo
o`/0dLfY2000000=ooooob<000003Oooool9000000X0dLfY1?ooool40000017ooooo10000008oooo
o`D000002?ooool40000013ooooo1@000004ooooo`X0dLfY4ooooolX000001?ooooo2`3AcJT>oooo
o`l000001?ooool;000000Cooooo3`00000?ooooo`d0dLfY000<0=7=ZA;ooooo:P00000Booooo`/0
dLfY2000000=ooooob<000003Oooool9000000X0dLfY1?ooool40000017ooooo10000008ooooo`D0
00002?ooool40000013ooooo1@000004ooooo`X0dLfY4?ooool3000000Cooooo80000004ooooo`@0
00003oooool;0=7=Z@kooooo3`000004ooooo`/000001?ooool?000000oooooo3@3AcJT000`0dLfY
4_oooolZ000001;ooooo2`3AcJT4oooooaX000004_oooolJ000000Cooooo2P3AcJT4ooooo`@00000
4Oooool4000000Sooooo1@000008ooooo`@000004?ooool5000000Cooooo2P3AcJT@ooooo`<00000
1?oooolP000000Cooooo1000000?ooooo`/0dLfY0oooool;000000Cooooo3`000004ooooo`@00000
0oooool?000000Cooooo2`000004ooooo`d0dLfY000<0=7=ZA;ooooo:P00000Booooo`/0dLfY1?oo
oolJ000001;ooooo6P000004ooooo`X0dLfY1?ooool4000000Gooooo30000004ooooo`@000001?oo
ool5000000Cooooo10000004ooooo``000001?ooool5000000Cooooo2P3AcJT@ooooo`<000001?oo
oolP000000Cooooo1000000?ooooo`/0dLfY0oooool;000000Cooooo3`000004ooooo`@000000ooo
ool?000000Cooooo2`000004ooooo`d0dLfY000<0=7=ZA;ooooo:P00000Booooo`/0dLfY1?oooolJ
000001;ooooo6P000004ooooo`X0dLfY1?ooool4000000Gooooo30000004ooooo`@000001?ooool5
000000Cooooo10000004ooooo``000001?ooool5000000Cooooo2P3AcJT@ooooo`<000001?oooolP
000000Cooooo1000000?ooooo`/0dLfY0oooool;000000Cooooo3`000004ooooo`@000000oooool?
000000Cooooo2`000004ooooo`d0dLfY000<0=7=Z@T000005oooool>000001Oooooo2@00000;0=7=
Z@Cooooo6P00000BoooooaX000001?ooool:0=7=Z@Cooooo10000005ooooo``000001?ooool40000
00Cooooo1@000004ooooo`@000001?ooool<000000Cooooo1@000004ooooo`X0dLfY3?ooool;0000
00Cooooo60000004ooooo``000002oooool;0=7=Z@?ooooo2`000004ooooo`l000001?ooool40000
00?ooooo3`000004ooooo`/000001?ooool=0=7=Z@00303AcJT9000001Oooooo3P00000Gooooo`T0
00002`3AcJT4000000Cooooo4P000004ooooo`@000002Oooool5000000Cooooo4@000005ooooo`@0
00002P3AcJT4ooooo`@000001Oooool<000000Cooooo10000004ooooo`D000001?ooool4000000Co
oooo30000004ooooo`D000001?ooool:0=7=Z@cooooo2`000004oooooaP000001?ooool<000000_o
oooo2`3AcJT;ooooo`<000001?ooool?000000Cooooo10000003ooooo`l000001?ooool4000000_o
oooo3@3AcJT000`0dLfY2@00000Gooooo`h000005oooool9000000/0dLfY10000004oooooa800000
1?ooool4000000Wooooo1@000004oooooa4000001Oooool4000000X0dLfY2?oooolA000000Cooooo
10000004ooooo`D000001?ooool4000000Cooooo40000009ooooo`X0dLfY3?ooool;000000Cooooo
60000004ooooo``000002oooool;0=7=Z@_ooooo0`000004ooooo`l000001?ooool4000000?ooooo
3`000004ooooo`@000002oooool=0=7=Z@00303AcJT9000001Oooooo3P00000Gooooo`T000002`3A
cJT4000000Cooooo4P000004ooooo`@000002Oooool5000000Cooooo4@000005ooooo`@000002P3A
cJT8oooooa4000001?ooool4000000Cooooo1@000004ooooo`@000001?ooool@000000Wooooo2P3A
cJT8ooooo`@000001?ooool;000000Cooooo40000004ooooo``000001?ooool4000000Oooooo2`3A
cJT;ooooo`<000001?ooool?000000Cooooo10000003ooooo`l000001?ooool4000000_ooooo3@3A
cJT000`0dLfY2@00000Gooooo`h000005oooool9000000/0dLfY10000004oooooa8000001?ooool4
000000Wooooo1@000004oooooa4000001Oooool4000000X0dLfY2?oooolA000000Cooooo10000004
ooooo`D000001?ooool4000000Cooooo40000009ooooo`X0dLfY2?ooool4000000Cooooo2`000004
oooooa0000001?ooool<000000Cooooo10000007ooooo`/0dLfY0`000008ooooo`L000002?ooool7
000000Cooooo10000003ooooo`P000001oooool8000000Oooooo1000000=0=7=Z@00303AcJT40000
01?ooooo1@000004ooooo`h000001Oooool4000001?ooooo1000000;0=7=Z@@000001?oooolB0000
00Cooooo10000009ooooo`D000001?oooolA000000Gooooo1000000:0=7=Z@Sooooo4@000004oooo
o`@000001?ooool5000000Cooooo10000004oooooa0000002Oooool:0=7=Z@Sooooo10000004oooo
o`/000001?ooool@000000Cooooo30000004ooooo`@000001oooool;0=7=Z@<000002?ooool70000
00Sooooo1`000004ooooo`@000000oooool8000000Oooooo20000007ooooo`@000003@3AcJT000`0
dLfY1000000Cooooo`D000001?ooool>000000Gooooo1000000Cooooo`@000002`3AcJTJ000001[o
oooo6P00000:0=7=ZAT000001?ooool4000000Cooooo1@000004ooooo`@000001?oooolI000000X0
dLfY2?ooool4000000Cooooo2`000004oooooa0000001?ooool<000000Cooooo10000007ooooo`/0
dLfY0`000008ooooo`L000002?ooool7000000Cooooo10000003ooooo`P000001oooool8000000Oo
oooo1000000=0=7=Z@00303AcJT4000001?ooooo1@000004ooooo`h000001Oooool4000001?ooooo
1000000;0=7=ZAX000006_oooolJ000000X0dLfY6@000004ooooo`@000001?ooool5000000Cooooo
10000004oooooaT000002P3AcJT8ooooo`P000000oooool4000000Sooooo10000008ooooo`@00000
2?ooool4000000Cooooo20000007ooooo`/0dLfY0`000008ooooo`L000002?ooool7000000Cooooo
10000003ooooo`P000001oooool8000000Oooooo1000000=0=7=Z@00303AcJT4000001?ooooo1@00
0004ooooo`h000001Oooool4000001?ooooo1000000;0=7=ZAX000006_oooolJ000000X0dLfY6@00
0004ooooo`@000001?ooool5000000Cooooo10000004oooooaT000002P3AcJT8ooooo`P000000ooo
ool4000000Sooooo10000008ooooo`@000002?ooool4000000Cooooo20000007ooooo`/0dLfY0`00
0008ooooo`l000000ooooolC000000Cooooo3`000007ooooo`@000003@3AcJT000`0dLfY2Oooool9
000000[ooooo5`000009ooooo`T000002Oooool;0=7=ZAX000006_oooolJ000000X0dLfY6@000004
ooooo`@000001?ooool5000000Cooooo10000004oooooaT000002P3AcJT8ooooo`P000000oooool4
000000Sooooo10000008ooooo`@000002?ooool4000000Cooooo20000007ooooo`/0dLfY0`000008
ooooo`l000000ooooolC000000Cooooo3`000007ooooo`@000003@3AcJT000`0dLfY2Oooool90000
00[ooooo5`000009ooooo`T000002Oooool;0=7=ZAX000006_oooolJ000000X0dLfY1?oooolA0000
00Sooooo5@000008oooooa4000001?ooool:0=7=Z@Sooooo20000003ooooo`@000002?ooool40000
00Sooooo10000008ooooo`@000001?ooool8000000Oooooo2`3AcJT3000000Sooooo3`000003oooo
oa<000001?ooool?000000Oooooo1000000=0=7=Z@00303AcJT9ooooo`T000002_oooolG000000Wo
oooo2@000009ooooo`/0dLfY6P00000JoooooaX000002P3AcJT4oooooa4000002?oooolE000000So
oooo4@000004ooooo`X0dLfY2?ooool;0000013ooooo2000000@ooooo``000001oooool;0=7=Z@<0
00002?ooool?000000?ooooo4`000004ooooo`l000001oooool4000000d0dLfY000<0=7=Z@Wooooo
2@00000:oooooaL000002Oooool9000000Wooooo2`3AcJTJ000001[ooooo6P00000:0=7=Z@Cooooo
4@000008oooooaD000002?oooolA000000Cooooo2P3AcJT8ooooo`/000004?ooool80000013ooooo
30000007ooooo`/0dLfY2`00000;ooooo`@000001oooool;000000Sooooo1000000;ooooo`/00000
3@3AcJT000`0dLfY2Oooool9000000[ooooo5`000009ooooo`T000002Oooool;0=7=ZAX000006_oo
oolJ000000X0dLfY1?oooolA000000Sooooo5@000008oooooa4000001?ooool:0=7=Z@Sooooo2`00
000@ooooo`P000004?ooool<000000Oooooo2`3AcJT;000000_ooooo10000007ooooo`/000002?oo
ool4000000_ooooo2`00000=0=7=Z@00303AcJTB000000Gooooo2@000005ooooo`@000001Oooool9
000000Gooooo4P00000;0=7=Z@Cooooo3@000004ooooob<000001Oooool=000000Cooooo2P3AcJT4
oooooa4000002?oooolE000000Sooooo4@000004ooooo`X0dLfY2?ooool;0000013ooooo2000000@
ooooo``000001oooool;0=7=Z@/000002oooool4000000Oooooo2`000008ooooo`@000002oooool;
000000d0dLfY000<0=7=ZA8000001Oooool9000000Gooooo10000005ooooo`T000001OoooolB0000
00/0dLfY1?ooool=000000Cooooo8`000005ooooo`d000001?ooool:0=7=ZA4000001?ooool<0000
00Cooooo1@000004ooooo``000001?oooolA000000X0dLfY1?ooool4000001Oooooo4000000Hoooo
o`<000001?ooool;0=7=Z@/000002oooool4000000?ooooo10000004ooooo`@000000oooool40000
00Cooooo1000000;ooooo`/000003@3AcJT000`0dLfY4P000005ooooo`T000001Oooool4000000Go
oooo2@000005oooooa8000002`3AcJT4ooooo`d000001?oooolS000000Gooooo3@000004ooooo`X0
dLfY4@000004ooooo``000001?ooool5000000Cooooo30000004oooooa4000002P3AcJT4ooooo`@0
00005oooool@000001Sooooo0`000004ooooo`/0dLfY2`00000;ooooo`@000000oooool4000000Co
oooo10000003ooooo`@000001?ooool4000000_ooooo2`00000=0=7=Z@00303AcJTB000000Gooooo
2@000005ooooo`@000001Oooool9000000Gooooo4P00000;0=7=Z@Cooooo3@000004ooooob<00000
1Oooool=000000Cooooo2P3AcJTA000000Cooooo30000004ooooo`D000001?ooool<000000Cooooo
4@00000:0=7=Z@Cooooo1000000Goooooa0000006?ooool3000000Cooooo2`3AcJT;000000_ooooo
10000003ooooo`@000001?ooool4000000?ooooo10000004ooooo`@000002oooool;000000d0dLfY
000<0=7=Z@Cooooo2P000009ooooo`T000001Oooool4000000Gooooo2@00000:ooooo`T000001?oo
ool;0=7=Z@@000001?ooool=000000Gooooo6P000004ooooo`d000001Oooool4000000X0dLfY4@00
0004ooooo``000001?ooool5000000Cooooo30000004oooooa4000002P3AcJT4ooooo`@000005ooo
ool@000001Sooooo0`000004ooooo`/0dLfY2`00000;ooooo`@000000oooool4000000Cooooo1000
0003ooooo`@000001?ooool4000000_ooooo2`00000=0=7=Z@00303AcJT4ooooo`X000002Oooool9
000000Gooooo10000005ooooo`T000002_ooool9000000Cooooo2`3AcJT4000000Cooooo3@000005
oooooaX000001?ooool=000000Gooooo1000000:0=7=Z@P000001Oooool4000001Cooooo1@00000D
ooooo`@000001?ooool9000000X0dLfY1000000Koooooa0000006oooool4000000/0dLfY4P00000C
ooooo`@000004_oooolC000000d0dLfY000<0=7=Z@Cooooo2P000009ooooo`T000001Oooool40000
00Gooooo2@00000:ooooo`T000001?ooool;0=7=Z@@000001?ooool=000000Gooooo6P000004oooo
o`d000001Oooool4000000X0dLfY20000005ooooo`@000005?ooool5000001Cooooo10000004oooo
o`T000002P3AcJT4000001_ooooo4000000Kooooo`@000002`3AcJTB000001?ooooo1000000Boooo
oa<000003@3AcJT000`0dLfY1?ooool:000000Wooooo2@000005ooooo`@000001Oooool9000000[o
oooo2@000004ooooo`/0dLfY10000004ooooo`d000001OoooolJ000000Cooooo3@000005ooooo`@0
00002P3AcJT8000000Gooooo1000000Dooooo`D000005?ooool4000000Cooooo2@00000:0=7=Z@@0
00006oooool@000001_ooooo1000000;0=7=ZA8000004oooool4000001;ooooo4`00000=0=7=Z@00
303AcJT4ooooo`X000002Oooool9000000Gooooo10000005ooooo`T000002_ooool9000000Cooooo
2`3AcJT4000000Cooooo3@000005oooooaX000001?ooool=000000Gooooo1000000:0=7=Z@P00000
1Oooool4000001Cooooo1@00000Dooooo`@000001?ooool9000000X0dLfY1000000Koooooa000000
6oooool4000000/0dLfY4P00000Cooooo`@000004_oooolC000000d0dLfY003o0=7=ZL/0dLfY003o
0=7=ZL/0dLfY003o0=7=ZL/0dLfY003o0=7=ZL/0dLfY003o0=7=ZL/0dLfY003o0=7=ZL/0dLfY003o
0=7=ZL/0dLfY003o0=7=ZL/0dLfY003o0=7=ZL/0dLfY003o0=7=ZL/0dLfY003o0=7=ZL/0dLfY003o
0=7=ZL/0dLfY000<0=7=Z@gooooo1`00000jooooo`/0dLfY4_ooool6000000Kooooo4P000006oooo
o`H000004_ooool:0=7=ZA7ooooo1P00000;ooooo`/000002oooool60000017ooooo2P3AcJTE0000
01oooooo1@00000Eooooo`/0dLfY8_ooool:000002;ooooo3@3AcJT000`0dLfY3Oooool7000003[o
oooo2`3AcJTBooooo`H000001_oooolB000000Kooooo1P00000Booooo`X0dLfY4Oooool6000000_o
oooo2`00000;ooooo`H000004Oooool:0=7=ZAD000007oooool5000001Gooooo2`3AcJTRooooo`X0
00008_ooool=0=7=Z@00303AcJT=ooooo`L00000>_ooool;0=7=ZA;ooooo1P000006oooooa800000
1_ooool6000001;ooooo2P3AcJTAooooo`H000002oooool;000000_ooooo1P00000Aooooo`X0dLfY
5@00000Oooooo`D000005Oooool;0=7=ZB;ooooo2P00000Rooooo`d0dLfY000<0=7=Z@gooooo1`00
000jooooo`/0dLfY4_ooool6000000Kooooo4P000006ooooo`H000004_ooool:0=7=ZA7ooooo1P00
000;ooooo`/000002oooool60000017ooooo2P3AcJTE000001oooooo1@00000Eooooo`/0dLfY8_oo
ool:000002;ooooo3@3AcJT000`0dLfY3Oooool7000003[ooooo2`3AcJTBooooo`H000001_oooolB
000000Kooooo1P00000Booooo`X0dLfY4Oooool6000000_ooooo2`00000;ooooo`H000004Oooool:
0=7=ZAD000007oooool5000001Gooooo2`3AcJTRooooo`X000008_ooool=0=7=Z@00303AcJT=oooo
o`L00000>_ooool;0=7=ZA;ooooo1P000006oooooa8000001_ooool6000001;ooooo2P3AcJT6oooo
oaH000004Oooool6000000Gooooo1P000005ooooo`H000001_ooool:0=7=ZA3ooooo1@000005oooo
o`X000001_ooool?0000013ooooo1@00000;0=7=Z@@000002_ooool?000000oooooo1@00000Hoooo
o`D000003@3AcJT000`0dLfY3@000007ooooo`H000001oooool6000000Oooooo1P000007oooooa<0
00002`3AcJTN000000Kooooo4P00000Booooo`H000002P3AcJT6oooooaH000004Oooool6000000Go
oooo1P000005ooooo`H000001_ooool:0=7=ZA3ooooo1@000005ooooo`X000001_ooool?0000013o
oooo1@00000;0=7=Z@@000002_ooool?000000oooooo1@00000Hooooo`D000003@3AcJT000`0dLfY
3@000007ooooo`H000001oooool6000000Oooooo1P000007oooooa<000002`3AcJTN000000Kooooo
4P00000Booooo`H000002P3AcJT6oooooaH000004Oooool6000000Gooooo1P000005ooooo`H00000
1_ooool:0=7=ZA3ooooo1@000005ooooo`X000001_ooool?0000013ooooo1@00000;0=7=Z@@00000
2_ooool?000000oooooo1@00000Hooooo`D000003@3AcJT000`0dLfY3@000007ooooo`H000001ooo
ool6000000Oooooo1P000007oooooa<000002`3AcJTN000000Kooooo4P00000Booooo`H000002P3A
cJT6oooooaH000004Oooool6000000Gooooo1P000005ooooo`H000001_ooool:0=7=ZA3ooooo1@00
0005ooooo`X000001_ooool?0000013ooooo1@00000;0=7=Z@@000002_ooool?000000oooooo1@00
000Hooooo`D000003@3AcJT000`0dLfY3@000007ooooo`H000001oooool6000000Oooooo1P000007
oooooa<000002`3AcJTN000000Kooooo4P00000Booooo`H000002P3AcJT6oooooaH000004Oooool6
000000Gooooo1P000005ooooo`H000001_ooool:0=7=ZA3ooooo1@000005ooooo`X000001_ooool?
0000013ooooo1@00000;0=7=Z@Cooooo1@00000?ooooo`D000001Oooool5000000Gooooo2@000005
ooooo`l000001Oooool=0=7=Z@00303AcJT=000000Oooooo1P000007ooooo`H000001oooool60000
00Oooooo4`00000;0=7=ZAh000001_oooolB000001;ooooo1P00000:0=7=Z@Kooooo5P00000Aoooo
o`H000001Oooool6000000Gooooo1P000006ooooo`X0dLfY1@00000@ooooo`D000001Oooool50000
00_ooooo2P000006ooooo`X000001Oooool;0=7=Z@Cooooo1@00000?ooooo`D000001Oooool50000
00Gooooo2@000005ooooo`l000001Oooool=0=7=Z@00303AcJT=000000Oooooo1P000007ooooo`H0
00001oooool6000000Oooooo4`00000;0=7=Z@H000001_ooool<000002Cooooo30000006ooooo`X0
dLfY5oooool5000000Kooooo1@000006ooooo`H000004?ooool6000000Kooooo2P3AcJT50000013o
oooo1@000005ooooo`D000002oooool:000000Kooooo2P000005ooooo`/0dLfY1?ooool5000000oo
oooo1@000005ooooo`D000001Oooool9000000Gooooo3`000005ooooo`d0dLfY000<0=7=Z@Kooooo
1`00000=ooooo`d000003Oooool7000000gooooo1P00000;0=7=Z@H000001_ooool<000002Cooooo
30000006ooooo`X0dLfY5oooool5000000Kooooo1@000006ooooo`H000004?ooool6000000Kooooo
2P3AcJT50000013ooooo1@000005ooooo`D000002oooool:000000Kooooo2P000005ooooo`/0dLfY
1?ooool5000000oooooo1@000005ooooo`D000001Oooool9000000Gooooo3`000005ooooo`d0dLfY
000<0=7=Z@Kooooo1`00000=ooooo`d000003Oooool7000000gooooo1P00000;0=7=Z@H000001_oo
ool<000002Cooooo30000006ooooo`X0dLfY5oooool5000000Kooooo1@000006ooooo`H000004?oo
ool6000000Kooooo2P3AcJT50000013ooooo1@000005ooooo`D000002oooool:000000Kooooo2P00
0005ooooo`/0dLfY1?ooool5000000oooooo1@000005ooooo`D000001Oooool9000000Gooooo3`00
0005ooooo`d0dLfY000<0=7=Z@Kooooo1`00000=ooooo`d000003Oooool7000000gooooo1P00000;
0=7=Z@H000001_ooool<000002Cooooo30000006ooooo`X0dLfY5oooool5000000Kooooo1@000006
ooooo`H000004?ooool6000000Kooooo2P3AcJT50000013ooooo1@000005ooooo`D000002oooool:
000000Kooooo2P000005ooooo`/0dLfY1000000:ooooo`D000001Oooool5000000Gooooo4`00000:
ooooo`l000003@3AcJT000`0dLfY1_ooool7000000gooooo3@00000=ooooo`L000003Oooool60000
00/0dLfY1P000006ooooo``000009?ooool<000000Kooooo2P3AcJTGooooo`D000001_ooool50000
00Kooooo1P00000@ooooo`H000001_ooool:0=7=Z@D000001Oooool6000000[ooooo2P000006oooo
o`l000002oooool:000000/0dLfY1000000:ooooo`D000001Oooool5000000Gooooo4`00000:oooo
o`l000003@3AcJT000`0dLfY1_ooool7000000gooooo3@00000=ooooo`L000003Oooool6000000/0
dLfY1P000006ooooo``000009?ooool<000000Kooooo2P3AcJT;000001Oooooo2`00000Fooooo``0
00002P3AcJT5000000Gooooo1P00000:ooooo`X000001_ooool?000000_ooooo2P00000;0=7=Z@@0
00002_ooool5000000Gooooo1@000005oooooa<000002_ooool?000000d0dLfY000<0=7=Z@Kooooo
1`00000=ooooo`d000003Oooool7000000gooooo1P00000;0=7=Z@Kooooo1P00000<ooooo`H00000
1_ooool6000000Kooooo1P00000<ooooo`H000001_ooool:0=7=Z@/000005oooool;000001Kooooo
3000000:0=7=Z@D000001Oooool6000000[ooooo2P000006ooooo`l000002oooool:000000/0dLfY
1000000:ooooo`D000001Oooool5000000Gooooo4`00000:ooooo`l000003@3AcJT000`0dLfY1_oo
ool7000000gooooo3@00000=ooooo`L000003Oooool6000000/0dLfY1_ooool6000000cooooo1P00
0006ooooo`H000001_ooool6000000cooooo1P000006ooooo`X0dLfY2`00000Gooooo`/000005_oo
ool<000000X0dLfY1@000005ooooo`H000002_ooool:000000Kooooo3`00000;ooooo`X000002`3A
cJT4000000[ooooo1@000005ooooo`D000001OoooolC000000[ooooo3`00000=0=7=Z@00303AcJT6
ooooo`L000001oooool6000000Oooooo1P00000=ooooo`d000003Oooool;0=7=Z@Kooooo1P00000<
ooooo`H000001_ooool6000000Kooooo1P00000<ooooo`H000001_ooool:0=7=Z@/000005oooool;
000001Kooooo3000000:0=7=Z@D000001Oooool6000000[ooooo2P000006ooooo`l000002oooool:
000000/0dLfY4`00000:ooooo`D000002_ooool5000001gooooo3@3AcJT000`0dLfY1_ooool70000
00Oooooo1P000007ooooo`H000003Oooool=000000gooooo2`3AcJT6ooooo`H000003?ooool60000
00Kooooo1P000006ooooo`H000003?ooool6000000Kooooo2P3AcJT;000001Oooooo2`00000Foooo
o``000002P3AcJT5000000Gooooo1P000005ooooo`D000001Oooool5000000_ooooo40000005oooo
o`D000001Oooool;0=7=ZA<000002_ooool5000000[ooooo1@00000Mooooo`d0dLfY000<0=7=Z@Ko
oooo1`000007ooooo`H000001oooool6000000gooooo3@00000=ooooo`/0dLfY1_ooool6000000co
oooo1P000006ooooo`H000001_ooool6000000cooooo1P000006ooooo`X0dLfY2`00000Gooooo`/0
00005_ooool<000000X0dLfY1@000005ooooo`H000001Oooool5000000Gooooo1@00000;oooooa00
00001Oooool5000000Gooooo2`3AcJTC000000[ooooo1@00000:ooooo`D000007Oooool=0=7=Z@00
303AcJT6ooooo`L000001oooool6000000Oooooo1P00000=ooooo`d000003Oooool;0=7=Z@Kooooo
1P00000<ooooo`H000001_ooool6000000Kooooo1P00000<ooooo`H000001_ooool:0=7=ZAOooooo
40000006ooooo`/000001_ooool;000000Kooooo2P3AcJT5000000Gooooo1P000005ooooo`D00000
1Oooool5000000_ooooo40000005ooooo`D000001Oooool;0=7=ZA<000002_ooool5000000[ooooo
1@00000Mooooo`d0dLfY000<0=7=Z@Kooooo1`000007ooooo`H000001oooool6000000gooooo3@00
000=ooooo`/0dLfY1_ooool6000000Kooooo1P000006ooooo`H000004_oooolH000000X0dLfY5ooo
ool@000000Kooooo2`000006ooooo`/000001_ooool:0=7=Z@D000001Oooool6000000Gooooo1@00
0005ooooo`D000002oooool@000000Gooooo1@000005ooooo`/0dLfY4`00000:ooooo`D000002_oo
ool5000001gooooo3@3AcJT000`0dLfY1_ooool7000000Oooooo1P000007ooooo`H000003Oooool=
000000gooooo2`3AcJT6ooooo`H000001_ooool6000000Kooooo1P00000BoooooaP000002P3AcJTG
oooooa0000001_ooool;000000Kooooo2`000006ooooo`X0dLfY1@000005ooooo`H000001Oooool5
000000Gooooo1@00000;oooooa0000001Oooool5000000Gooooo2`3AcJT9000000oooooo3`00000:
ooooo`@000001OoooolD000000d0dLfY000<0=7=Z@Kooooo8@000007ooooo`d000004oooool;0=7=
Z@Kooooo1P000006ooooo`H000001_ooool6000001;ooooo6000000:0=7=ZAOooooo40000006oooo
o`/000001_ooool;000000Kooooo2P3AcJT5ooooo`/000003oooool;000000[ooooo1@000006oooo
o`l000002`3AcJT9000000oooooo3`00000:ooooo`@000001OoooolD000000d0dLfY000<0=7=Z@Ko
oooo8@000007ooooo`d000004oooool;0=7=Z@Kooooo1P000006ooooo`H000001_ooool6000001;o
oooo6000000:0=7=ZAOooooo40000006ooooo`/000001_ooool;000000Kooooo2P3AcJT5ooooo`/0
00003oooool;000000[ooooo1@000006ooooo`l000002`3AcJT9000000oooooo3`00000:ooooo`@0
00001OoooolD000000d0dLfY000<0=7=Z@Kooooo8@000007ooooo`d000004oooool;0=7=Z@Kooooo
1P000006ooooo`H000001_ooool6000001;ooooo6000000:0=7=Z@Kooooo2`000006ooooo`D00000
1_ooool5000000cooooo1@00000Gooooo`X0dLfY1Oooool;000000oooooo2`00000:ooooo`D00000
1_ooool?000000/0dLfY2@00000?ooooo`l000002_ooool4000000Gooooo5000000=0=7=Z@00303A
cJT6ooooob4000001oooool=000001?ooooo2`3AcJT6ooooo`H000001_ooool6000000Kooooo1P00
000BoooooaP000002P3AcJT6ooooo`/000001_ooool5000000Kooooo1@00000<ooooo`D000005ooo
ool:0=7=Z@Gooooo2`00000?ooooo`/000002_ooool5000000Kooooo3`00000;0=7=Z@Cooooo2P00
000:ooooo`D000005?ooool4000000Gooooo1@00000:ooooo`D000003@3AcJT000`0dLfY1_oooolQ
000000Oooooo3@00000Cooooo`/0dLfY1_ooool6000000Kooooo4P00000<oooooah000002P3AcJT6
ooooo`/000001_ooool5000000Kooooo1@00000<ooooo`D000005oooool:0=7=Z@Gooooo2`00000?
ooooo`/000002_ooool5000000Kooooo3`00000;0=7=Z@Cooooo2P00000:ooooo`D000005?ooool4
000000Gooooo1@00000:ooooo`D000003@3AcJT000`0dLfY1_oooolQ000000Oooooo3@00000Coooo
o`/0dLfY1_ooool6000000Kooooo4P00000<oooooah000002P3AcJT6ooooo`/000001_ooool50000
00Kooooo1@00000<ooooo`D000005oooool:0=7=Z@D000001OoooolJ000000Kooooo1@000005oooo
o`/000001Oooool:000000/0dLfY1?ooool:000000[ooooo1@00000Dooooo`@000001Oooool50000
00[ooooo1@00000=0=7=Z@00303AcJT6ooooob4000001oooool=000001?ooooo2`3AcJT6ooooo`H0
00001_oooolB000000cooooo7P00000:0=7=Z@Kooooo2`000006ooooo`D000001_ooool5000000co
oooo1@00000Gooooo`X0dLfY1@000005oooooaX000001_ooool5000000Gooooo2`000005ooooo`X0
00002`3AcJT4ooooo`X000002_ooool5000001Cooooo10000005ooooo`D000002_ooool5000000d0
dLfY000<0=7=Z@Kooooo1`00000Qoooooa<000003Oooool;0=7=Z@Kooooo1P000006oooooa800000
3?oooolN000000X0dLfY1_ooool;000000Kooooo1@000006ooooo`D000003?ooool5000001Oooooo
2P3AcJT5000000Gooooo6P000006ooooo`D000001Oooool;000000Gooooo2P00000;0=7=Z@Cooooo
2P00000:ooooo`D000005?ooool4000000Gooooo1@00000:ooooo`D000003@3AcJT000`0dLfY1_oo
ool70000027ooooo4`00000=ooooo`/0dLfY1_ooool6000000Kooooo4P00000<oooooah000002P3A
cJT6000000_ooooo1P00000;ooooob4000001_ooool6000000X0dLfY1@000005oooooaX000001_oo
ool5000000Gooooo2`000005ooooo`X000002`3AcJT4000000Gooooo50000005ooooo`X000003_oo
ool5000000Gooooo2P00000=0=7=Z@00303AcJT6ooooo`L000008OoooolC000000gooooo2`3AcJT6
ooooo`H000001_oooolB000000cooooo7P00000:0=7=Z@H000002oooool6000000_ooooo8@000006
ooooo`H000002P3AcJT5000000Gooooo6P000006ooooo`D000001Oooool;000000Gooooo2P00000;
0=7=Z@@000001OoooolD000000Gooooo2P00000>ooooo`D000001Oooool:000000d0dLfY000<0=7=
Z@Kooooo1`00000Qoooooa<000003Oooool;0=7=Z@`000001_ooool6000000cooooo3000000<oooo
o`H000001_ooool6000000X0dLfY1P00000;ooooo`H000002ooooolQ000000Kooooo1P00000:0=7=
Z@X000001_ooool?000000Gooooo1P000005oooooa0000001Oooool:000000/0dLfY10000005oooo
oa@000001Oooool:000000kooooo1@000005ooooo`X000003@3AcJT000`0dLfY1_ooool70000027o
oooo4`00000=ooooo`/0dLfY30000006ooooo`H000003?ooool<000000cooooo1P000006ooooo`H0
00002P3AcJT6000000_ooooo1P00000;ooooob4000001_ooool6000000X0dLfY2P000006ooooo`l0
00001Oooool6000000Gooooo40000005ooooo`X000002`3AcJT4000000Gooooo50000005ooooo`X0
00003_ooool5000000Gooooo2P00000=0=7=Z@00303AcJT6ooooo`L000008OoooolC000000gooooo
2`3AcJT<000000Kooooo1P00000<ooooo``000003?ooool6000000Kooooo1P00000:0=7=Z@H00000
2oooool6000000_ooooo8@000006ooooo`H000002P3AcJT:000000Kooooo3`000005ooooo`H00000
1Oooool@000000Gooooo2P00000;0=7=Z@@000001OoooolD000000Gooooo2P00000>ooooo`D00000
1Oooool:000000d0dLfY000<0=7=Z@gooooo5000000Pooooo`L000001_ooool;0=7=Z@`000001_oo
ool6000000cooooo3000000<ooooo`H000001_ooool6000000X0dLfY1P000005ooooob8000002ooo
ool6000000_ooooo1P00000:0=7=Z@X000001_ooool?000000Gooooo1P000005oooooa0000001Ooo
ool:000000/0dLfY2@00000:ooooo`D000001OoooolD000000Cooooo1@00000:ooooo`X000003@3A
cJT000`0dLfY3OoooolD0000023ooooo1`000006ooooo`/0dLfY30000006ooooo`H000003?ooool<
000000cooooo1P000006ooooo`H000002P3AcJT6000000Gooooo8P00000;ooooo`H000002oooool6
000000X0dLfY2P000006ooooo`l000001Oooool6000000Gooooo40000005ooooo`X000002`3AcJT9
000000[ooooo1@000005oooooa@000001?ooool5000000[ooooo2P00000=0=7=Z@00303AcJT=oooo
oa@000008?ooool7000000Kooooo2`3AcJT<000000Kooooo1P00000<ooooo``000003?ooool60000
00Kooooo1P00000:0=7=Z@H000001OoooolR000000_ooooo1P00000;ooooo`H000002P3AcJT:0000
00Kooooo3`000005ooooo`H000001Oooool@000000Gooooo2P00000;0=7=Z@T000002_ooool50000
00Gooooo50000004ooooo`D000002_ooool:000000d0dLfY000<0=7=Z@gooooo5000000Pooooo`L0
00001_ooool;0=7=ZA;ooooo1P00000<ooooo``000003?ooool<000000Kooooo2P3AcJT6000000Go
oooo8P00000;ooooo`H000002oooool6000000X0dLfY5@000005ooooo`X000001_ooool5000000[o
oooo1P00000:ooooo`D000002`3AcJT9000000[ooooo1@000005oooooa@000001?ooool5000000[o
oooo2P00000=0=7=Z@00303AcJT=oooooa@000008?ooool7000000Kooooo2`3AcJTBooooo`H00000
3?ooool<000000cooooo30000006ooooo`X0dLfY1P000005ooooob8000002oooool6000000_ooooo
1P00000:0=7=ZAD000001Oooool:000000Kooooo1@00000:ooooo`H000002_ooool5000000/0dLfY
2@00000:ooooo`D000001OoooolD000000Cooooo1@00000:ooooo`X000003@3AcJT000`0dLfY3Ooo
oolD0000023ooooo1`000006ooooo`/0dLfY4_ooool6000000cooooo3000000<ooooo``000001_oo
ool:0=7=ZAOooooo1@00000;ooooo`H000001_ooool5000000Kooooo2`000006ooooo`X0dLfY5@00
0005ooooo`X000001_ooool5000000[ooooo1P00000:ooooo`D000002`3AcJT4000000Gooooo2P00
000?ooooo`X000001Oooool>000000Gooooo2P00000=0=7=Z@00303AcJTDooooo`d000001_oooolQ
000000Kooooo2`3AcJTBooooo`H000003?ooool<000000cooooo30000006ooooo`X0dLfY5oooool5
000000_ooooo1P000006ooooo`D000001_ooool;000000Kooooo2P3AcJTE000000Gooooo2P000006
ooooo`D000002_ooool6000000[ooooo1@00000;0=7=Z@@000001Oooool:000000oooooo2P000005
ooooo`h000001Oooool:000000d0dLfY000<0=7=ZACooooo3@000006ooooob4000001_ooool;0=7=
ZA;ooooo1P00000<ooooo``000003?ooool<000000Kooooo2P3AcJTGooooo`D000002oooool60000
00Kooooo1@000006ooooo`/000001_ooool:0=7=ZAD000001Oooool:000000Kooooo1@00000:oooo
o`H000002_ooool5000000/0dLfY10000005ooooo`X000003oooool:000000Gooooo3P000005oooo
o`X000003@3AcJT000`0dLfY5?ooool=000000Kooooo8@000006ooooo`/0dLfY4_ooool6000000co
oooo3000000<ooooo``000001_ooool:0=7=ZAOooooo1@00000;ooooo`H000001_ooool5000000Ko
oooo2`000006ooooo`X0dLfY2P00000Eooooo`/000002_ooool5000000_ooooo1@000005ooooo`/0
dLfY10000005ooooo`X000003oooool:000000Gooooo3P000005ooooo`X000003@3AcJT000`0dLfY
5?ooool=000000Kooooo8@000006ooooo`/0dLfY1_ooool6000000Kooooo1P000006ooooo`H00000
4_oooolH000000X0dLfY5oooool5000000_ooooo1P000006ooooo`D000001_ooool;000000Kooooo
2P3AcJT:000001Gooooo2`00000:ooooo`D000002oooool5000000Gooooo2`3AcJT4000000Gooooo
2P00000?ooooo`X000001Oooool>000000Gooooo2P00000=0=7=Z@00303AcJTDooooo`d000001_oo
oolQ000000Kooooo2`3AcJT6ooooo`H000001_ooool6000000Kooooo1P00000BoooooaP000002P3A
cJTGooooo`D000002oooool6000000Kooooo1@000006ooooo`/000001_ooool:0=7=Z@X000005Ooo
ool;000000[ooooo1@00000;ooooo`D000001Oooool;0=7=Z@T000002_ooool:000000Gooooo2P00
0005oooooa<000002_ooool=0=7=Z@00303AcJTDooooo`d000001_oooolQ000000Kooooo2`3AcJT6
ooooo`H000001_ooool6000000Kooooo1P00000BoooooaP000002P3AcJT6ooooo`/000001_ooool;
000000Gooooo4@00000Gooooo`X0dLfY2P00000Eooooo`/000002_ooool5000000_ooooo1@000005
ooooo`/0dLfY2@00000:ooooo`X000001Oooool:000000Gooooo4`00000:ooooo`d0dLfY000<0=7=
ZACooooo3@000006ooooob4000001_ooool;0=7=Z@Kooooo1P000006ooooo`H000001_ooool60000
01;ooooo6000000:0=7=Z@Kooooo2`000006ooooo`/000001OoooolA000001Oooooo2P3AcJT:0000
01Gooooo2`00000:ooooo`D000002oooool5000000Gooooo2`3AcJT9000000[ooooo2P000005oooo
o`X000001OoooolC000000[ooooo3@3AcJT000`0dLfY3Oooool=000000gooooo1`000006ooooo`L0
00001_ooool7000000Kooooo2`3AcJT6ooooo`H000001_ooool6000000Kooooo1P00000BoooooaP0
00002P3AcJT6ooooo`/000001_ooool;000000Gooooo4@00000Gooooo`X0dLfY1@00000@ooooo`D0
00004?oooolO000000Gooooo2`3AcJT9000000[ooooo2P000005ooooo`X000001OoooolC000000[o
oooo3@3AcJT000`0dLfY3Oooool=000000gooooo1`000006ooooo`L000001_ooool7000000Kooooo
2`3AcJT6ooooo`H000001_ooool6000000Kooooo1P00000BoooooaP000002P3AcJT6ooooo`/00000
1_ooool;000000Gooooo4@00000Gooooo`X0dLfY1@00000@ooooo`D000004?oooolO000000Gooooo
2`3AcJT9ooooo`X000001Oooool5000000[ooooo3P00000Iooooo`d0dLfY000<0=7=Z@gooooo3@00
000=ooooo`L000001_ooool7000000Kooooo1`000006ooooo`/0dLfY3?ooool6000000Kooooo1P00
000<ooooo``000004_ooool6000000X0dLfY1_ooool;000000Kooooo2`000005oooooa4000005ooo
ool:0=7=Z@D000004?ooool50000013ooooo7`000005ooooo`/0dLfY2Oooool:000000Gooooo1@00
000:ooooo`h000006Oooool=0=7=Z@00303AcJT=ooooo`d000003Oooool7000000Kooooo1`000006
ooooo`L000001_ooool;0=7=Z@cooooo1P000006ooooo`H000003?ooool<000001;ooooo1P00000:
0=7=Z@/000005oooool;000001Kooooo3000000:0=7=Z@D000004?ooool50000013ooooo7`000005
ooooo`/0dLfY2Oooool:000000Gooooo1@00000:ooooo`h000006Oooool=0=7=Z@00303AcJT=oooo
o`d000003Oooool7000000Kooooo1`000006ooooo`L000001_ooool;0=7=Z@cooooo1P000006oooo
o`H000003?ooool<000001;ooooo1P00000:0=7=Z@/000005oooool;000001Kooooo3000000:0=7=
Z@D000004?ooool50000013ooooo7`000005ooooo`/0dLfY2Oooool:000000Gooooo1@00000:oooo
o`h000006Oooool=0=7=Z@00303AcJT=ooooo`d000003Oooool7000000Kooooo1`000006ooooo`L0
00001_ooool;0=7=Z@cooooo1P000006ooooo`H000003?ooool<000001;ooooo1P00000:0=7=Z@/0
00005oooool;000001Kooooo3000000:0=7=ZA[ooooo2P000006ooooo`l000001_ooool:000000Go
oooo2`3AcJT9ooooo`X000001Oooool5000000[ooooo3P00000Iooooo`d0dLfY000<0=7=Z@H00000
3_ooool6000000gooooo3@00000=ooooo`L000001_ooool;0=7=Z@cooooo1P000006ooooo`H00000
3?ooool<000001;ooooo1P00000:0=7=Z@/000005oooool;000001Kooooo3000000:0=7=ZA[ooooo
2P000006ooooo`l000001_ooool:000000Gooooo2`3AcJT9000000[ooooo1@00000Mooooo`l00000
2_ooool=0=7=Z@00303AcJT6000000kooooo1P00000=ooooo`d000003Oooool7000000Kooooo2`3A
cJT<ooooo`H000001_ooool6000000cooooo3000000Booooo`H000002P3AcJT;000001Oooooo2`00
000Fooooo``000002P3AcJTJooooo`X000001_ooool?000000Kooooo2P000005ooooo`/0dLfY2@00
000:ooooo`D000007Oooool?000000[ooooo3@3AcJT000`0dLfY1P00000>ooooo`H000003Oooool=
000000gooooo1`000006ooooo`/0dLfYCP00000:0=7=Z@/000005oooool;000001Kooooo3000000:
0=7=ZA[ooooo2P000006ooooo`l000001_ooool:000000Gooooo2`3AcJT9000000[ooooo1@00000M
ooooo`l000002_ooool=0=7=Z@00303AcJT6000000kooooo1P00000=ooooo`d000003Oooool70000
00Kooooo2`3AcJU>000000X0dLfY1_ooool50000017ooooo1P000005ooooo`H000001_ooool50000
01Oooooo2P3AcJTJooooo`X000001_ooool?000000Kooooo2P000005ooooo`/0dLfY2@00000:oooo
o`D000007Oooool?000000[ooooo3@3AcJT000`0dLfY1P00000>ooooo`H000003Oooool=000000go
oooo1`000006ooooo`/0dLfYCP00000:0=7=Z@Kooooo1@00000Aooooo`H000001Oooool6000000Ko
oooo1@00000Gooooo`X0dLfY2P000006ooooo`D000001Oooool:000001Gooooo2`00000:ooooo`/0
dLfY2@00000:ooooo`D000007Oooool?000000[ooooo3@3AcJT000`0dLfY1P00000>ooooo`H00000
3Oooool=000000gooooo1`000006ooooo`/0dLfYCP00000:0=7=Z@Kooooo1@00000Aooooo`H00000
1Oooool6000000Kooooo1@00000Gooooo`X0dLfY2P000006ooooo`D000001Oooool:000001Gooooo
2`00000:ooooo`/0dLfY1?ooool:000000Gooooo1@00000:ooooo`l000001?ooool:000000oooooo
3@3AcJT000`0dLfY50000006ooooo`L000001_ooool7000000Kooooo1`000006ooooo`d000002`3A
cJU>000000X0dLfY1_ooool50000017ooooo1P000005ooooo`H000001_ooool5000001Oooooo2P3A
cJT:000000Kooooo1@000005ooooo`X000005Oooool;000000[ooooo2`3AcJT4ooooo`X000001Ooo
ool5000000[ooooo3`000004ooooo`X000003oooool=0=7=Z@00303AcJTD000000Kooooo1`000006
ooooo`L000001_ooool7000000Kooooo3@00000;0=7=Z@H000003?ooool<000001;ooooo1P00000<
ooooo`H000001_ooool:0=7=Z@Kooooo1@00000Aooooo`H000001Oooool6000000Kooooo1@00000G
ooooo`X0dLfY2P000006ooooo`D000001Oooool:000001Gooooo2`00000:ooooo`/0dLfY1?ooool:
000000Gooooo1@00000:ooooo`l000001?ooool:000000oooooo3@3AcJT000`0dLfY50000006oooo
o`L000001_ooool7000000Kooooo1`000006ooooo`d000002`3AcJT6000000cooooo3000000Boooo
o`H000003?ooool6000000Kooooo2P3AcJT6ooooo`D000001_ooool6000000Gooooo1P00000Aoooo
oaH000001_ooool:0=7=Z@X000001_ooool5000000Gooooo2P00000Eooooo`/000002_ooool;0=7=
Z@Cooooo2P000005ooooo`D000002_ooool?000000Cooooo2P00000?ooooo`d0dLfY000<0=7=ZA@0
00001_ooool7000000Kooooo1`000006ooooo`L000001_ooool=000000/0dLfY1P00000<ooooo``0
00004_ooool6000000cooooo1P000006ooooo`X0dLfY1_ooool5000000Kooooo1P000005ooooo`H0
00004OoooolF000000Kooooo2P3AcJT:ooooo`/000001Oooool50000013ooooo2P000006ooooo`D0
00001Oooool5000000/0dLfY1?ooool:000000Gooooo1@00000:ooooo`l000001?ooool:000000oo
oooo3@3AcJT000`0dLfY50000006ooooo`L000001_ooool7000000Kooooo1`000006ooooo`d00000
2`3AcJT6000000cooooo3000000Booooo`H000003?ooool6000000Kooooo2P3AcJT6ooooo`D00000
1_ooool6000000Gooooo1P00000AoooooaH000001_ooool:0=7=Z@[ooooo2`000005ooooo`D00000
4?ooool:000000Kooooo1@000005ooooo`D000002`3AcJT>000000Gooooo5000000:ooooo`h00000
1Oooool:000000d0dLfY000<0=7=ZA@000001_ooool7000000Kooooo1`000006ooooo`L000001_oo
ool=000000/0dLfY1P00000<ooooo``000004_ooool6000000cooooo1P000006ooooo`X0dLfY1_oo
ool5000000Kooooo1P000005ooooo`H000004OoooolF000000Kooooo2P3AcJT:ooooo`/000001Ooo
ool50000013ooooo2P000006ooooo`D000001Oooool5000000/0dLfY3P000005oooooa@000002_oo
ool>000000Gooooo2P00000=0=7=Z@00303AcJTD000000Kooooo1`000006ooooo`L000001_ooool7
000000Kooooo3@00000;0=7=Z@H000003?ooool<000001;ooooo1P00000<ooooo`H000001_ooool:
0=7=Z@Kooooo1@000006ooooo`H000001Oooool60000017ooooo5P000006ooooo`X0dLfY2_ooool;
000000Gooooo1@00000@ooooo`X000001_ooool5000000Gooooo1@00000;0=7=Z@h000001OoooolD
000000[ooooo3P000005ooooo`X000003@3AcJT000`0dLfY>oooool6000000gooooo2`3AcJT<oooo
oa8000001_oooolB000000cooooo1P000006ooooo`X0dLfY1_ooool5000000Kooooo1P000005oooo
o`H000004OoooolF000000Kooooo2P3AcJT:ooooo`/000001Oooool50000013ooooo2P000006oooo
o`D000001Oooool5000000/0dLfY3P000005oooooa@000002_ooool>000000Gooooo2P00000=0=7=
Z@00303AcJTkooooo`H000003Oooool;0=7=Z@cooooo4P000006oooooa8000003?ooool6000000Ko
oooo2P3AcJTAooooo`H000002oooool;000000_ooooo1P00000Aooooo`X0dLfY4000000:ooooo`D0
00004?ooool@000000oooooo2`3AcJT4000000[ooooo7P00000Mooooo`D000003@3AcJT000`0dLfY
>oooool6000000gooooo2`3AcJT<oooooa8000001_oooolB000000cooooo1P000006ooooo`X0dLfY
4Oooool6000000_ooooo2`00000;ooooo`H000004Oooool:0=7=ZA0000002_ooool50000013ooooo
4000000?ooooo`/0dLfY1000000:oooooah000007Oooool5000000d0dLfY000<0=7=ZC_ooooo1P00
000=ooooo`/0dLfY3?oooolB000000Kooooo4P00000<ooooo`H000001_ooool:0=7=ZA7ooooo1P00
000;ooooo`/000002oooool60000017ooooo2P3AcJT@000000[ooooo1@00000@oooooa0000003ooo
ool;0=7=Z@@000002_oooolN000001gooooo1@00000=0=7=Z@00303AcJTkooooo`H000003Oooool;
0=7=Z@cooooo4P000006oooooa8000003?ooool6000000Kooooo2P3AcJTAooooo`H000002oooool;
000000_ooooo1P00000Aooooo`X0dLfY4000000:ooooo`D000004?ooool@000000oooooo2`3AcJT4
000000[ooooo7P00000Mooooo`D000003@3AcJT000`0dLfY>oooool6000000gooooo2`3AcJT<oooo
oa8000001_oooolB000000cooooo1P000006ooooo`X0dLfY4Oooool6000000_ooooo2`00000;oooo
o`H000004Oooool:0=7=ZA0000002_ooool50000013ooooo4000000?ooooo`/0dLfY1000000:oooo
oah000007Oooool5000000d0dLfY003o0=7=ZL/0dLfY003o0=7=ZL/0dLfY003o0=7=ZL/0dLfY003o
0=7=ZL/0dLfY003o0=7=ZL/0dLfY003o0=7=ZL/0dLfY003o0=7=ZL/0dLfY003o0=7=ZL/0dLfY003o
0=7=ZL/0dLfY003o0=7=ZL/0dLfY003o0=7=ZL/0dLfY003o0=7=ZL/0dLfY000<0=7=ZBd000005_oo
ool;000000/0dLfYC_ooool:0=7=Z@Wooooo2@000008ooooo`T00000;?ooool:0=7=Z@P000002?oo
ool7000000Sooooo40000008ooooo`P000002?ooool7000000/0dLfYCP00000=0=7=Z@00303AcJT]
000001Kooooo2`00000;0=7=ZDkooooo2P3AcJT9ooooo`T000002?ooool9000002cooooo2P3AcJT8
000000Sooooo1`000008oooooa0000002?ooool8000000Sooooo1`00000;0=7=ZDh000003@3AcJT0
00`0dLfY;@00000Fooooo`/000002`3AcJU>ooooo`X0dLfY2Oooool9000000Sooooo2@00000/oooo
o`X0dLfY20000008ooooo`L000002?ooool@000000Sooooo20000008ooooo`L000002`3AcJU>0000
00d0dLfY000<0=7=ZBd000005_ooool;000000/0dLfYC_ooool:0=7=Z@Wooooo2@000008ooooo`T0
0000;?ooool:0=7=Z@P000002?ooool7000000Sooooo40000008ooooo`P000002?ooool7000000/0
dLfYCP00000=0=7=Z@00303AcJT]000001Kooooo2`00000;0=7=ZDkooooo2P3AcJT9ooooo`T00000
2?ooool9000002cooooo2P3AcJT8000000Sooooo1`000008oooooa0000002?ooool8000000Sooooo
1`00000;0=7=ZDh000003@3AcJT000`0dLfY;@00000Fooooo`/000002`3AcJU>ooooo`X0dLfY2Ooo
ool9000000Sooooo2@00000/ooooo`X0dLfY20000008ooooo`L000002?ooool@000000Sooooo2000
0008ooooo`L000002`3AcJU>000000d0dLfY000<0=7=ZBd000005_ooool;000000/0dLfYC_ooool:
0=7=Z@Wooooo2@000008ooooo`T00000;?ooool:0=7=Z@P000002?ooool7000000Sooooo40000008
ooooo`P000002?ooool7000000/0dLfYCP00000=0=7=Z@00303AcJT]000001Kooooo2`00000;0=7=
ZDkooooo2P3AcJT9ooooo`T000002?ooool9000002cooooo2P3AcJT8000000Sooooo1`000008oooo
oa0000002?ooool8000000Sooooo1`00000;0=7=Z@h000003_oooolE000000oooooo3P00000=0=7=
Z@00303AcJT]000001Kooooo2`00000;0=7=ZDkooooo2P3AcJT9ooooo`T000002?ooool9000002co
oooo2P3AcJT8ooooo`P000001ooooolP000000Sooooo20000007ooooo`/0dLfY3P00000>oooooaD0
00003oooool>000000d0dLfY000<0=7=ZBd000005_ooool;000000/0dLfYC_ooool:0=7=ZA[ooooo
4P000009ooooo`P000002Oooool9000000X0dLfY2?ooool8000000Oooooo80000008ooooo`P00000
1oooool;0=7=Z@h000003_oooolE000000oooooo3P00000=0=7=Z@00303AcJT]000001Kooooo2`00
000;0=7=ZDkooooo2P3AcJTJoooooa8000002Oooool8000000Wooooo2@00000:0=7=Z@Sooooo2000
0007ooooob0000002?ooool8000000Oooooo2`3AcJT>000000kooooo5@00000?ooooo`h000003@3A
cJT000`0dLfY@oooool;000000/0dLfYC_ooool:0=7=ZA[ooooo4P000009ooooo`P000002Oooool9
000000X0dLfY2?ooool8000000Oooooo80000008ooooo`P000001oooool;0=7=Z@h000003_oooolE
000000oooooo3P00000=0=7=Z@00303AcJU3ooooo`/000002`3AcJU>ooooo`X0dLfY6_oooolB0000
00Wooooo20000009ooooo`T000002P3AcJT8ooooo`P000001ooooolP000000Sooooo20000007oooo
o`/0dLfY3P00000>oooooaD000003oooool>000000d0dLfY000<0=7=ZD?ooooo2`00000;0=7=ZDko
oooo2P3AcJTJoooooa8000002Oooool8000000Wooooo2@00000:0=7=Z@Sooooo20000007ooooob00
00002?ooool8000000Oooooo2`3AcJT>000000kooooo5@00000?ooooo`h000003@3AcJT000`0dLfY
@oooool;000000/0dLfYC_ooool:0=7=ZA[ooooo4P000009ooooo`P000002Oooool9000000X0dLfY
2?ooool8000000Oooooo80000008ooooo`P000001oooool;0=7=Z@L000001oooool7000000Oooooo
5@000008ooooo`L000001oooool7000000d0dLfY000<0=7=ZD?ooooo2`00000;0=7=ZDkooooo2P3A
cJTJoooooa8000002Oooool8000000Wooooo2@00000:0=7=Z@Sooooo20000007ooooob0000002?oo
ool8000000Oooooo2`3AcJT7000000Oooooo1`000007oooooaD000002?ooool7000000Oooooo1`00
000=0=7=Z@00303AcJU3ooooo`/000002`3AcJU>ooooo`X0dLfY6_oooolB000000Wooooo20000009
ooooo`T000002P3AcJT8000000Sooooo3`00000@oooooa0000002?ooool7000000/0dLfY1`000007
ooooo`L000001ooooolE000000Sooooo1`000007ooooo`L000003@3AcJT000`0dLfY@oooool;0000
00/0dLfYC_ooool:0=7=Z@Wooooo=000000Booooo`X0dLfY20000008ooooo`l000004?ooool@0000
00Sooooo1`00000;0=7=Z@L000001oooool7000000Oooooo5@000008ooooo`L000001oooool70000
00d0dLfY000<0=7=ZD?ooooo2`00000;0=7=ZDkooooo2P3AcJT9oooooc@000004_ooool:0=7=Z@P0
00002?ooool?0000013ooooo40000008ooooo`L000002`3AcJT7000000Oooooo1`000007oooooaD0
00002?ooool7000000Oooooo1`00000=0=7=Z@00303AcJU3ooooo`/000002`3AcJU>ooooo`X0dLfY
2Ooooold000001;ooooo2P3AcJT8000000Sooooo3`00000@oooooa0000002?ooool7000000/0dLfY
1`000007ooooo`L000001ooooolE000000Sooooo1`000007ooooo`L000003@3AcJT000`0dLfY@ooo
ool;000000/0dLfY2OoooolD000001Cooooo4`00000:ooooo`X0dLfY2Ooooold000001;ooooo2P3A
cJT8000000Sooooo3`00000@oooooa0000002?ooool7000000/0dLfY1`000007ooooo`L000001ooo
oolE000000Sooooo1`000007ooooo`L000003@3AcJT000`0dLfY@oooool;000000/0dLfY2OoooolD
000001Cooooo4`00000:ooooo`X0dLfY2Ooooold000001;ooooo2P3AcJT8000000Sooooo3`00000@
oooooa0000002?ooool7000000/0dLfY1`00000>ooooo`L000001oooool7000000Oooooo2000000>
ooooo`L000003@3AcJT000`0dLfY2`00000;ooooo``000002oooool;000001Kooooo2`3AcJT9oooo
oa@000005?oooolC000000[ooooo2P3AcJT9oooooc@000004_ooool:0=7=Z@P000002?ooool?0000
013ooooo40000008ooooo`L000002`3AcJT7000000kooooo1`000007ooooo`L000001oooool80000
00kooooo1`00000=0=7=Z@00303AcJT;000000_ooooo3000000;ooooo`/000005_ooool;0=7=Z@Wo
oooo5000000Doooooa<000002_ooool:0=7=Z@Wooooo=000000Booooo`X0dLfY2?oooolG0000013o
oooo60000007ooooo`/0dLfY1`00000>ooooo`L000001oooool7000000Oooooo2000000>ooooo`L0
00003@3AcJT000`0dLfY2`00000;ooooo``000002oooool;000001Kooooo2`3AcJT9oooooa@00000
5?oooolC000000[ooooo2P3AcJT9oooooc@000004_ooool:0=7=Z@Sooooo5`00000@oooooaP00000
1oooool;0=7=Z@L000003_ooool7000000Oooooo1`000007ooooo`P000003_ooool7000000d0dLfY
000<0=7=Z@/000002oooool<000000_ooooo2`00000Fooooo`/0dLfY2OoooolD000001Cooooo4`00
000:ooooo`X0dLfY2Ooooold000001;ooooo2P3AcJT8oooooaL000004?oooolH000000Oooooo2`3A
cJT7000000kooooo1`000007ooooo`L000001oooool8000000kooooo1`00000=0=7=Z@00303AcJT;
000000_ooooo3000000;ooooo`/000005_ooool;0=7=Z@Wooooo5000000Doooooa<000002_ooool:
0=7=ZA;ooooo2000000KoooooaX000002P3AcJT8oooooaL000004?oooolH000000Oooooo2`3AcJT7
000000kooooo1`000007ooooo`L000001oooool8000000kooooo1`00000=0=7=Z@00303AcJT;0000
00_ooooo3000000;ooooo`/000005_ooool;0=7=Z@Wooooo5000000Doooooa<000002_ooool:0=7=
ZA;ooooo2000000KoooooaX000002P3AcJT8oooooaL000004?oooolH000000Oooooo2`3AcJT70000
00kooooo1`000007ooooo`L000001oooool8000000kooooo1`00000=0=7=Z@00303AcJT;000000_o
oooo3000000;ooooo`/000005_ooool;0=7=Z@Wooooo5000000Doooooa<000002_ooool:0=7=ZA;o
oooo2000000KoooooaX000002P3AcJT8oooooaL000004?oooolH000000Oooooo2`3AcJTE000000Oo
oooo5@000008oooooaD000003@3AcJT000`0dLfY2`00000;ooooo``000002oooool;000001Kooooo
2`3AcJT9000001Cooooo5000000Cooooo`X000002P3AcJTBooooo`P000006ooooolJ000000X0dLfY
2?oooolG0000013ooooo60000007ooooo`/0dLfY5@000007oooooaD000002?oooolE000000d0dLfY
000<0=7=Z@/000002oooool<000000_ooooo2`00000Fooooo`/0dLfY2@00000Doooooa@000004ooo
ool:000000X0dLfY4_ooool8000001_ooooo6P00000:0=7=Z@Sooooo5`00000@oooooaP000001ooo
ool;0=7=ZAD000001ooooolE000000Sooooo5@00000=0=7=Z@00303AcJT;000000_ooooo3000000;
ooooo`/000005_ooool;0=7=Z@T000005?oooolD000001?ooooo2P00000:0=7=ZA;ooooo2000000K
oooooaX000002P3AcJT@000000oooooo4000000@ooooo`l000002`3AcJTE000000Oooooo5@000008
oooooaD000003@3AcJT000`0dLfY2`00000;ooooo``000002oooool;000001Kooooo2`3AcJT90000
01Cooooo5000000Cooooo`X000002P3AcJTBooooo`P000006ooooolJ000000X0dLfY4000000?oooo
oa0000004?ooool?000000/0dLfY5@000007oooooaD000002?oooolE000000d0dLfY000<0=7=ZDh0
00002`3AcJT9000001Cooooo5000000Cooooo`X000002P3AcJTBooooo`P000006ooooolJ000000X0
dLfY4000000?oooooa0000004?ooool?000000/0dLfY5@000007oooooaD000002?oooolE000000d0
dLfY000<0=7=ZDh000002`3AcJT9000001Cooooo5000000Cooooo`X000002P3AcJT9oooooa400000
2Oooool9000000Wooooo4@000009ooooo`X0dLfY4000000?oooooa0000004?ooool?000000/0dLfY
5@000007oooooaD000002?oooolE000000d0dLfY000<0=7=ZDh000002`3AcJT9000001Cooooo5000
000Cooooo`X000002P3AcJT9oooooa4000002Oooool9000000Wooooo4@000009ooooo`X0dLfY4000
000?oooooa0000004?ooool?000000/0dLfYCP00000=0=7=Z@00303AcJU>000000/0dLfY2@00000D
oooooa@000004oooool:000000X0dLfY2OoooolA000000Wooooo2@000009oooooa4000002Oooool:
0=7=ZA0000003oooool@0000013ooooo3`00000;0=7=ZDh000003@3AcJT000`0dLfYCP00000;0=7=
Z@T000005?oooolD000001?ooooo2P00000:0=7=Z@Wooooo4@000009ooooo`T000002OoooolA0000
00Wooooo2P3AcJT@000000oooooo4000000@ooooo`l000002`3AcJU>000000d0dLfY000<0=7=ZDh0
00002`3AcJT9000001Cooooo5000000Cooooo`X000002P3AcJT9oooooa4000002Oooool9000000Wo
oooo4@000009ooooo`X0dLfY4000000?oooooa0000004?ooool?000000/0dLfYCP00000=0=7=Z@00
303AcJU>000000/0dLfY4`00000:oooooa@000002OoooolD000000X0dLfY2OoooolA000000Wooooo
2@000009oooooa4000002Oooool:0=7=ZA0000003oooool@0000013ooooo3`00000;0=7=ZDh00000
3@3AcJT000`0dLfYCP00000;0=7=ZA<000002_oooolD000000Wooooo5000000:0=7=Z@Wooooo4@00
0009ooooo`T000002OoooolA000000Wooooo2P3AcJT@000000oooooo4000000@ooooo`l000002`3A
cJU>000000d0dLfY000<0=7=ZDh000002`3AcJTC000000[ooooo50000009oooooa@000002P3AcJT9
oooooa4000002Oooool9000000Wooooo4@000009ooooo`X0dLfY4000000?oooooa0000004?ooool?
000000/0dLfYCP00000=0=7=Z@00303AcJU>000000/0dLfY4`00000:oooooa@000002OoooolD0000
00X0dLfY2OoooolA000000Wooooo2@000009oooooa4000002Oooool:0=7=ZA0000003oooool@0000
013ooooo3`00000;0=7=ZAD000001ooooolE000000Sooooo5@00000=0=7=Z@00303AcJU>000000/0
dLfY4`00000:oooooa@000002OoooolD000000X0dLfY6P00000Kooooo`P000004_ooool:0=7=ZA00
00003oooool@0000013ooooo3`00000;0=7=ZAD000001ooooolE000000Sooooo5@00000=0=7=Z@00
303AcJT;000000_ooooo3000000;ooooo`/000005_ooool;0=7=ZA<000002_oooolD000000Wooooo
5000000:0=7=ZAX000006oooool8000001;ooooo2P3AcJT@000000oooooo4000000@ooooo`l00000
2`3AcJTE000000Oooooo5@000008oooooaD000003@3AcJT000`0dLfY2`00000;ooooo``000002ooo
ool;000001Kooooo2`3AcJTC000000[ooooo50000009oooooa@000002P3AcJTJ000001_ooooo2000
000Booooo`X0dLfY4000000?oooooa0000004?ooool?000000/0dLfY5@000007oooooaD000002?oo
oolE000000d0dLfY000<0=7=Z@/000002oooool<000000_ooooo2`00000Fooooo`/0dLfY4`00000:
oooooa@000002OoooolD000000X0dLfY6P00000Kooooo`P000004_ooool:0=7=Z@Sooooo5`00000@
oooooaP000001oooool;0=7=ZAD000001ooooolE000000Sooooo5@00000=0=7=Z@00303AcJT;0000
00_ooooo3000000;ooooo`/000005_ooool;0=7=ZA<000002_oooolD000000Wooooo5000000:0=7=
ZAX000006oooool8000001;ooooo2P3AcJT8oooooaL000004?oooolH000000Oooooo2`3AcJTE0000
00Oooooo5@000008oooooaD000003@3AcJT000`0dLfY2`00000;ooooo``000002oooool;000001Ko
oooo2`3AcJTM000001Cooooo7@00000:0=7=ZAX000006oooool8000001;ooooo2P3AcJT8oooooaL0
00004?oooolH000000Oooooo2`3AcJTE000000Oooooo5@000008oooooaD000003@3AcJT000`0dLfY
2`00000;ooooo``000002oooool;000001Kooooo2`3AcJTM000001Cooooo7@00000:0=7=ZAX00000
6oooool8000001;ooooo2P3AcJT8oooooaL000004?oooolH000000Oooooo2`3AcJT7000000kooooo
1`000007ooooo`L000001oooool8000000kooooo1`00000=0=7=Z@00303AcJT;000000_ooooo3000
000;ooooo`/000005_ooool;0=7=ZAd000005?oooolM000000X0dLfY6P00000Kooooo`P000004_oo
ool:0=7=Z@Sooooo5`00000@oooooaP000001oooool;0=7=Z@L000003_ooool7000000Oooooo1`00
0007ooooo`P000003_ooool7000000d0dLfY000<0=7=Z@/000002oooool<000000_ooooo2`00000F
ooooo`/0dLfY7@00000Doooooad000002P3AcJTBoooooc@000002Oooool:0=7=Z@Sooooo5`00000@
oooooaP000001oooool;0=7=Z@L000003_ooool7000000Oooooo1`000007ooooo`P000003_ooool7
000000d0dLfY000<0=7=Z@/000002oooool<000000_ooooo2`00000Fooooo`/0dLfY7@00000Doooo
oad000002P3AcJTBoooooc@000002Oooool:0=7=Z@Sooooo5`00000@oooooaP000001oooool;0=7=
Z@L000003_ooool7000000Oooooo1`000007ooooo`P000003_ooool7000000d0dLfY000<0=7=Z@/0
00002oooool<000000_ooooo2`00000Fooooo`/0dLfY7@00000Doooooad000002P3AcJTBoooooc@0
00002Oooool:0=7=Z@Sooooo5`00000@oooooaP000001oooool;0=7=Z@L000003_ooool7000000Oo
oooo1`000007ooooo`P000003_ooool7000000d0dLfY000<0=7=Z@/000002oooool<000000_ooooo
2`00000Fooooo`/0dLfY7@00000Doooooad000002P3AcJTBoooooc@000002Oooool:0=7=Z@P00000
2?ooool?0000013ooooo40000008ooooo`L000002`3AcJT7000000kooooo1`000007ooooo`L00000
1oooool8000000kooooo1`00000=0=7=Z@00303AcJU3ooooo`/000002`3AcJTM000001Cooooo7@00
000:0=7=ZA;ooooo=0000009ooooo`X0dLfY20000008ooooo`l000004?ooool@000000Sooooo1`00
000;0=7=Z@L000003_ooool7000000Oooooo1`000007ooooo`P000003_ooool7000000d0dLfY000<
0=7=ZD?ooooo2`00000;0=7=ZAd000005?oooolM000000X0dLfY4_oooold000000Wooooo2P3AcJT8
000000Sooooo3`00000@oooooa0000002?ooool7000000/0dLfY1`000007ooooo`L000001ooooolE
000000Sooooo1`000007ooooo`L000003@3AcJT000`0dLfY@oooool;000000/0dLfY7@00000Doooo
oad000002P3AcJTBoooooc@000002Oooool:0=7=Z@P000002?ooool?0000013ooooo40000008oooo
o`L000002`3AcJT7000000Oooooo1`000007oooooaD000002?ooool7000000Oooooo1`00000=0=7=
Z@00303AcJU3ooooo`/000002`3AcJTMoooooa@000007Oooool:0=7=ZA;ooooo=0000009ooooo`X0
dLfY20000008ooooo`l000004?ooool@000000Sooooo1`00000;0=7=Z@L000001oooool7000000Oo
oooo5@000008ooooo`L000001oooool7000000d0dLfY000<0=7=ZD?ooooo2`00000;0=7=ZAgooooo
5000000Mooooo`X0dLfY4_oooold000000Wooooo2P3AcJT8000000Sooooo3`00000@oooooa000000
2?ooool7000000/0dLfY1`000007ooooo`L000001ooooolE000000Sooooo1`000007ooooo`L00000
3@3AcJT000`0dLfY@oooool;000000/0dLfY7OoooolD000001gooooo2P3AcJT9000000Wooooo2000
0009oooooa8000006_ooool:0=7=Z@P000002?ooool?0000013ooooo40000008ooooo`L000002`3A
cJT7000000Oooooo1`000007oooooaD000002?ooool7000000Oooooo1`00000=0=7=Z@00303AcJU3
ooooo`/000002`3AcJTMoooooa@000007Oooool:0=7=Z@T000002Oooool8000000Wooooo4P00000J
ooooo`X0dLfY20000008ooooo`l000004?ooool@000000Sooooo1`00000;0=7=Z@L000001oooool7
000000Oooooo5@000008ooooo`L000001oooool7000000d0dLfY000<0=7=ZD?ooooo2`00000;0=7=
ZAgooooo5000000Mooooo`X0dLfY2@000009ooooo`P000002OoooolB000001[ooooo2P3AcJT8oooo
o`P000001ooooolP000000Sooooo20000007ooooo`/0dLfY1`000007ooooo`L000001ooooolE0000
00Sooooo1`000007ooooo`L000003@3AcJT000`0dLfY@oooool;000000/0dLfY7OoooolD000001go
oooo2P3AcJT9000000Wooooo20000009oooooa8000006_ooool:0=7=Z@Sooooo20000007ooooob00
00002?ooool8000000Oooooo2`3AcJT>000000kooooo5@00000?ooooo`h000003@3AcJT000`0dLfY
@oooool;000000/0dLfY7OoooolD000001gooooo2P3AcJT9000000Wooooo20000009oooooa800000
6_ooool:0=7=Z@Sooooo20000007ooooob0000002?ooool8000000Oooooo2`3AcJT>000000kooooo
5@00000?ooooo`h000003@3AcJT000`0dLfY@oooool;000000/0dLfY7OoooolD000001gooooo2P3A
cJT9000000Wooooo20000009oooooa8000006_ooool:0=7=Z@Sooooo20000007ooooob0000002?oo
ool8000000Oooooo2`3AcJT>000000kooooo5@00000?ooooo`h000003@3AcJT000`0dLfY;@00000F
ooooo`/000002`3AcJTMoooooa@000007Oooool:0=7=Z@T000002Oooool8000000Wooooo4P00000J
ooooo`X0dLfY2?ooool8000000Oooooo80000008ooooo`P000001oooool;0=7=Z@h000003_oooolE
000000oooooo3P00000=0=7=Z@00303AcJT]000001Kooooo2`00000;0=7=ZA?ooooo2P00000Doooo
o`T000005?ooool:0=7=Z@T000002Oooool8000000Wooooo4P00000Jooooo`X0dLfY2?ooool80000
00Oooooo80000008ooooo`P000001oooool;0=7=Z@h000003_oooolE000000oooooo3P00000=0=7=
Z@00303AcJT]000001Kooooo2`00000;0=7=ZA?ooooo2P00000Dooooo`T000005?ooool:0=7=ZBco
oooo2@000008ooooo`T000002Oooool:0=7=Z@Sooooo20000007ooooob0000002?ooool8000000Oo
oooo2`3AcJT>000000kooooo5@00000?ooooo`h000003@3AcJT000`0dLfY;@00000Fooooo`/00000
2`3AcJTCooooo`X000005?ooool9000001Cooooo2P3AcJT/ooooo`T000002?ooool9000000Wooooo
2P3AcJT8000000Sooooo1`000008oooooa0000002?ooool8000000Sooooo1`00000;0=7=Z@h00000
3_oooolE000000oooooo3P00000=0=7=Z@00303AcJT]000001Kooooo2`00000;0=7=ZA?ooooo2P00
000Dooooo`T000005?ooool:0=7=ZBcooooo2@000008ooooo`T000002Oooool:0=7=Z@P000002?oo
ool7000000Sooooo40000008ooooo`P000002?ooool7000000/0dLfYCP00000=0=7=Z@00303AcJT]
000001Kooooo2`00000;0=7=ZA?ooooo2P00000Dooooo`T000005?ooool:0=7=ZBcooooo2@000008
ooooo`T000002Oooool:0=7=Z@P000002?ooool7000000Sooooo40000008ooooo`P000002?ooool7
000000/0dLfYCP00000=0=7=Z@00303AcJT]000001Kooooo2`00000;0=7=ZA?ooooo2P00000Doooo
o`T000005?ooool:0=7=ZBcooooo2@000008ooooo`T000002Oooool:0=7=Z@P000002?ooool70000
00Sooooo40000008ooooo`P000002?ooool7000000/0dLfYCP00000=0=7=Z@00303AcJT]000001Ko
oooo2`00000;0=7=ZA?ooooo2P00000Dooooo`T000005?ooool:0=7=ZBcooooo2@000008ooooo`T0
00002Oooool:0=7=Z@P000002?ooool7000000Sooooo40000008ooooo`P000002?ooool7000000/0
dLfYCP00000=0=7=Z@00303AcJT]000001Kooooo2`00000;0=7=ZA?ooooo2P00000Dooooo`T00000
5?ooool:0=7=ZBcooooo2@000008ooooo`T000002Oooool:0=7=Z@P000002?ooool7000000Sooooo
40000008ooooo`P000002?ooool7000000/0dLfYCP00000=0=7=Z@00303AcJT]000001Kooooo2`00
000;0=7=ZA?ooooo2P00000Dooooo`T000005?ooool:0=7=ZBcooooo2@000008ooooo`T000002Ooo
ool:0=7=Z@P000002?ooool7000000Sooooo40000008ooooo`P000002?ooool7000000/0dLfYCP00
000=0=7=Z@00303AcJT]000001Kooooo2`00000;0=7=ZA?ooooo2P00000Dooooo`T000005?ooool:
0=7=ZBcooooo2@000008ooooo`T000002Oooool:0=7=Z@P000002?ooool7000000Sooooo40000008
ooooo`P000002?ooool7000000/0dLfYCP00000=0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00
o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00
o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00
303AcJU>0820P0/0dLfYCP20P80:0=7=ZA@000009ooooolD000000X0dLfY4000000?oooooa000000
4?ooool?000000/0dLfYC_ooool=0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=ZA@000009ooo
oolD000000X0dLfY4000000?oooooa0000004?ooool?000000/0dLfYC_ooool=0=7=Z@00303AcJU>
0820P0/0dLfYCP20P80:0=7=ZA@000009ooooolD000000X0dLfY4000000?oooooa0000004?ooool?
000000/0dLfYC_ooool=0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=ZA@000009ooooolD0000
00X0dLfY4000000?oooooa0000004?ooool?000000/0dLfYC_ooool=0=7=Z@00303AcJU>0820P0/0
dLfYCP20P80:0=7=ZA@000009ooooolD000000X0dLfY4000000?oooooa0000004?ooool?000000/0
dLfYC_ooool=0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=ZA@000009ooooolD000000X0dLfY
4000000?oooooa0000004?ooool?000000/0dLfYC_ooool=0=7=Z@00303AcJU>0820P0/0dLfYCP20
P80:0=7=ZA@000009ooooolD000000X0dLfY4000000?oooooa0000004?ooool?000000/0dLfYC_oo
ool=0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=ZA@000009ooooolD000000X0dLfY4000000?
oooooa0000004?ooool?000000/0dLfYC_ooool=0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=
ZA@000009ooooolD000000X0dLfY4000000?oooooa0000004?ooool?000000/0dLfYC_ooool=0=7=
Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=ZA@000009ooooolD000000X0dLfY4000000?oooooa00
00004?ooool?000000/0dLfYC_ooool=0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=ZA@00000
9ooooolD000000X0dLfY4000000?oooooa0000004?ooool?000000/0dLfYC_ooool=0=7=Z@00303A
cJU>0820P0/0dLfYCP20P80:0=7=ZA@000009ooooolD000000X0dLfY4000000?oooooa0000004?oo
ool?000000/0dLfYC_ooool=0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=ZA@000009ooooolD
000000X0dLfY4000000?oooooa0000004?ooool?000000/0dLfYC_ooool=0=7=Z@00303AcJU>0820
P0/0dLfYCP20P80:0=7=ZA@000009ooooolD000000X0dLfY4000000?oooooa0000004?ooool?0000
00/0dLfY6_oooolJ000001[ooooo3@3AcJT000`0dLfYCP20P80;0=7=ZDh0P8202P3AcJTD000002Oo
oooo5000000:0=7=ZA0000003oooool@0000013ooooo3`00000;0=7=ZA[ooooo6P00000Jooooo`d0
dLfY000<0=7=ZDh0P8202`3AcJU>0820P0X0dLfY5000000Woooooa@000002P3AcJT@ooooobl00000
3oooool;0=7=ZA[ooooo6P00000Jooooo`d0dLfY000<0=7=ZDh0P8202`3AcJU>0820P0X0dLfY5000
000Woooooa@000002P3AcJT@ooooobl000003oooool;0=7=ZA[ooooo6P00000Jooooo`d0dLfY000<
0=7=ZDh0P8202`3AcJU>0820P0X0dLfY5000000Woooooa@000002P3AcJT@ooooobl000003oooool;
0=7=ZA[ooooo6P00000Jooooo`d0dLfY000<0=7=ZDh0P8202`3AcJU>0820P0X0dLfY5000000Woooo
oa@000002P3AcJT@ooooobl000003oooool;0=7=ZA[ooooo6P00000Jooooo`d0dLfY000<0=7=ZDh0
P8202`3AcJU>0820P0X0dLfY5?oooolW000001Cooooo2P3AcJT@ooooobl000003oooool;0=7=ZA[o
oooo6P00000Jooooo`d0dLfY000<0=7=ZDh0P8202`3AcJU>0820P0X0dLfY5?oooolW000001Cooooo
2P3AcJT@ooooobl000003oooool;0=7=ZA[ooooo6P00000Jooooo`d0dLfY000<0=7=ZDh0P8202`3A
cJU>0820P0X0dLfY5?oooolW000001Cooooo2P3AcJT@ooooobl000003oooool;0=7=ZA[ooooo6P00
000Jooooo`d0dLfY000<0=7=ZDh0P8202`3AcJU>0820P0X0dLfY5?oooolW000001Cooooo2P3AcJT@
ooooobl000003oooool;0=7=ZA[ooooo6P00000Jooooo`d0dLfY000<0=7=ZDh0P8202`3AcJU>0820
P0X0dLfY5?oooolW000001Cooooo2P3AcJT@ooooobl000003oooool;0=7=ZA[ooooo6P00000Joooo
o`d0dLfY000<0=7=ZDh0P8202`3AcJU>0820P0X0dLfY5?oooolW000001Cooooo2P3AcJT@ooooobl0
00003oooool;0=7=ZA[ooooo6P00000Jooooo`d0dLfY000<0=7=ZDh0P8202`3AcJU>0820P0X0dLfY
5?oooolW000001Cooooo2P3AcJT@ooooobl000003oooool;0=7=ZA[ooooo6P00000Jooooo`d0dLfY
000<0=7=ZDh0P8202`3AcJU>0820P0X0dLfY5?oooolW000001Cooooo2P3AcJT@ooooobl000003ooo
ool;0=7=Z@d000003OoooolJ000000gooooo3@00000=0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:
0=7=ZACooooo9`00000Dooooo`X0dLfY4?ooool_000000oooooo2`3AcJT=000000gooooo6P00000=
ooooo`d000003@3AcJT000`0dLfYCP20P80;0=7=ZDh0P8202P3AcJTDooooobL000005?ooool:0=7=
ZA3ooooo;`00000?ooooo`/0dLfY3@00000=oooooaX000003Oooool=000000d0dLfY000<0=7=ZDh0
P8202`3AcJU>0820P0X0dLfY5?oooolW000001Cooooo2P3AcJT@ooooobl000003oooool;0=7=Z@d0
00003OoooolJ000000gooooo3@00000=0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=ZACooooo
9`00000Dooooo`X0dLfY4?ooool_000000oooooo2`3AcJT=000000gooooo6P00000=ooooo`d00000
3@3AcJT000`0dLfYCP20P80;0=7=ZDh0P8202P3AcJTDooooobL000005?ooool:0=7=ZDh000002`3A
cJT=000000gooooo6P00000=ooooo`d000003@3AcJT000`0dLfYCP20P80;0=7=ZDh0P8202P3AcJTD
ooooobL000005?ooool:0=7=ZDh000002`3AcJT=000000gooooo6P00000=ooooo`d000003@3AcJT0
00`0dLfYCP20P80;0=7=ZDh0P8202P3AcJTDooooobL000005?ooool:0=7=ZDh000002`3AcJT=0000
00gooooo6P00000=ooooo`d000003@3AcJT000`0dLfYCP20P80;0=7=ZDh0P8202P3AcJTDooooobL0
00005?ooool:0=7=ZDh000002`3AcJT=000000gooooo6P00000=ooooo`d000003@3AcJT000`0dLfY
CP20P80;0=7=ZDh0P8202P3AcJTDooooobL000005?ooool:0=7=ZDh000002`3AcJT=000000gooooo
6P00000=ooooo`d000003@3AcJT000`0dLfYCP20P80;0=7=ZDh0P8202P3AcJTDooooobL000005?oo
ool:0=7=ZDh000002`3AcJT=000000gooooo6P00000=ooooo`d000003@3AcJT000`0dLfYCP20P80;
0=7=ZDh0P8202P3AcJTDooooobL000005?ooool:0=7=ZDh000002`3AcJT=000000gooooo6P00000=
ooooo`d000003@3AcJT000`0dLfYCP20P80;0=7=ZDh0P8202P3AcJTDooooobL000005?ooool:0=7=
ZDh000002`3AcJT=000000gooooo6P00000=ooooo`d000003@3AcJT000`0dLfYCP20P80;0=7=ZDh0
P8202P3AcJTDooooobL000005?ooool:0=7=ZDh000002`3AcJT=000000gooooo6P00000=ooooo`d0
00003@3AcJT000`0dLfYCP20P80;0=7=ZDh0P8202P3AcJTDooooobL000005?ooool:0=7=ZDh00000
2`3AcJT=000000gooooo6P00000=ooooo`d000003@3AcJT000`0dLfYCP20P80;0=7=ZDh0P8202P3A
cJTDooooobL000005?ooool:0=7=ZDh000002`3AcJT=000000gooooo6P00000=ooooo`d000003@3A
cJT000`0dLfYCP20P80;0=7=ZDh0P8202P3AcJTDooooobL000005?ooool:0=7=ZDh000002`3AcJT=
000000gooooo6P00000=ooooo`d000003@3AcJT000`0dLfYCP20P80;0=7=ZDh0P8202P3AcJTDoooo
obL000005?ooool:0=7=ZDh000002`3AcJT=000000gooooo6P00000=ooooo`d000003@3AcJT000`0
dLfYCP20P80;0=7=ZDh0P8202P3AcJTDooooobL000005?ooool:0=7=ZDh000002`3AcJT=000000go
oooo6P00000=ooooo`d000003@3AcJT000`0dLfYCP20P80;0=7=ZDh0P8202P3AcJTDooooobL00000
5?ooool:0=7=ZDh000002`3AcJT=000000gooooo6P00000=ooooo`d000003@3AcJT000`0dLfYCP20
P80;0=7=ZDh0P8202P3AcJTDooooobL000005?ooool:0=7=ZA3ooooo;`00000?ooooo`/0dLfY3@00
000=oooooaX000003Oooool=000000d0dLfY000<0=7=ZDh0P8202`3AcJU>0820P0X0dLfY5?oooolW
000001Cooooo2P3AcJT@ooooobl000003oooool;0=7=Z@d000003OoooolJ000000gooooo3@00000=
0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=ZACooooo9`00000Dooooo`X0dLfY4?ooool_0000
00oooooo2`3AcJT=000000gooooo6P00000=ooooo`d000003@3AcJT000`0dLfYCP20P80;0=7=ZDh0
P8202P3AcJTDooooobL000005?ooool:0=7=ZA3ooooo;`00000?ooooo`/0dLfY3@00000=oooooaX0
00003Oooool=000000d0dLfY000<0=7=ZDh0P8202`3AcJU>0820P0X0dLfY5?oooolW000001Cooooo
2P3AcJT@ooooobl000003oooool;0=7=Z@d000003OoooolJ000000gooooo3@00000=0=7=Z@00303A
cJU>0820P0/0dLfYCP20P80:0=7=ZACooooo9`00000Dooooo`X0dLfY4?ooool_000000oooooo2`3A
cJTJoooooaX000006_ooool=0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=ZACooooo9`00000D
ooooo`X0dLfY4?ooool_000000oooooo2`3AcJTJoooooaX000006_ooool=0=7=Z@00303AcJU>0820
P0/0dLfYCP20P80:0=7=ZACooooo9`00000Dooooo`X0dLfY4?ooool_000000oooooo2`3AcJTJoooo
oaX000006_ooool=0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=ZACooooo9`00000Dooooo`X0
dLfY4?ooool_000000oooooo2`3AcJTJoooooaX000006_ooool=0=7=Z@00303AcJU>0820P0/0dLfY
CP20P80:0=7=ZACooooo9`00000Dooooo`X0dLfY4?ooool_000000oooooo2`3AcJTJoooooaX00000
6_ooool=0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=ZACooooo9`00000Dooooo`X0dLfY4?oo
ool_000000oooooo2`3AcJTJoooooaX000006_ooool=0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:
0=7=ZA@000009ooooolD000000X0dLfY4?ooool_000000oooooo2`3AcJTJoooooaX000006_ooool=
0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=ZA@000009ooooolD000000X0dLfY4?ooool_0000
00oooooo2`3AcJTJoooooaX000006_ooool=0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=ZA@0
00009ooooolD000000X0dLfY4?ooool_000000oooooo2`3AcJTJoooooaX000006_ooool=0=7=Z@00
303AcJU>0820P0/0dLfYCP20P80:0=7=ZA@000009ooooolD000000X0dLfY4?ooool_000000oooooo
2`3AcJTJoooooaX000006_ooool=0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=ZA@000009ooo
oolD000000X0dLfY4000000?oooooa0000004?ooool?000000/0dLfY6_oooolJ000001[ooooo3@3A
cJT000`0dLfYCP20P80;0=7=ZDh0P8202P3AcJTD000002Oooooo5000000:0=7=ZA0000003oooool@
0000013ooooo3`00000;0=7=ZA[ooooo6P00000Jooooo`d0dLfY000<0=7=ZDh0P8202`3AcJU>0820
P0X0dLfY5000000Woooooa@000002P3AcJT@000000oooooo4000000@ooooo`l000002`3AcJTJoooo
oaX000006_ooool=0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=ZA@000009ooooolD000000X0
dLfY4000000?oooooa0000004?ooool?000000/0dLfYC_ooool=0=7=Z@00303AcJU>0820P0/0dLfY
CP20P80:0=7=ZA@000009ooooolD000000X0dLfY4000000?oooooa0000004?ooool?000000/0dLfY
C_ooool=0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=ZA@000009ooooolD000000X0dLfY4000
000?oooooa0000004?ooool?000000/0dLfYC_ooool=0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:
0=7=ZA@000009ooooolD000000X0dLfY4000000?oooooa0000004?ooool?000000/0dLfYC_ooool=
0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=ZA@000009ooooolD000000X0dLfY4000000?oooo
oa0000004?ooool?000000/0dLfYC_ooool=0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=ZA@0
00009ooooolD000000X0dLfY4000000?oooooa0000004?ooool?000000/0dLfYC_ooool=0=7=Z@00
303AcJU>0820P0/0dLfYCP20P80:0=7=ZA@000009ooooolD000000X0dLfY4000000?oooooa000000
4?ooool?000000/0dLfYC_ooool=0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=ZA@000009ooo
oolD000000X0dLfY4000000?oooooa0000004?ooool?000000/0dLfYC_ooool=0=7=Z@00303AcJU>
0820P0/0dLfYCP20P80:0=7=ZA@000009ooooolD000000X0dLfY4000000?oooooa0000004?ooool?
000000/0dLfYC_ooool=0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=ZA@000009ooooolD0000
00X0dLfY4000000?oooooa0000004?ooool?000000/0dLfYC_ooool=0=7=Z@00303AcJU>0820P0/0
dLfYCP20P80:0=7=ZA@000009ooooolD000000X0dLfY4000000?oooooa0000004?ooool?000000/0
dLfYC_ooool=0=7=Z@00303AcJU>0820P0/0dLfYCP20P80:0=7=ZA@000009ooooolD000000X0dLfY
4000000?oooooa0000004?ooool?000000/0dLfYC_ooool=0=7=Z@00303AcJU>0820P0/0dLfYCP20
P80:0=7=ZA@000009ooooolD000000X0dLfY4000000?oooooa0000004?ooool?000000/0dLfYC_oo
ool=0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3A
cJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3A
cJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3A
cJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3A
cJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00o`3AcJW;0=7=Z@00\
\>"],
  ImageRangeCache->{{{0, 457}, {923.438, 0}} -> {-0.125026, -0.257962, \
0.0114881, 0.0114881}, {{10.875, 91.4375}, {900.938, 820.375}} -> {-7.53853, \
-14.5919, 0.606739, 0.606739}, {{99.5, 180.125}, {900.938, 820.375}} -> \
{-62.6346, -14.9023, 0.619648, 0.619648}, {{188.188, 268.75}, {900.938, \
820.375}} -> {-120.02, -15.2129, 0.63256, 0.63256}, {{276.813, 357.438}, \
{900.938, 820.375}} -> {-179.694, -15.5233, 0.645467, 0.645467}, {{365.5, \
446.063}, {900.938, 820.375}} -> {-241.657, -15.8338, 0.658377, 0.658377}, \
{{10.875, 91.4375}, {812.313, 731.688}} -> {-6.73656, -61.1083, 0.542193, \
0.542193}, {{99.5, 180.125}, {812.313, 731.688}} -> {-56.05, -62.4981, \
0.554671, 0.554671}, {{188.188, 268.75}, {812.313, 731.688}} -> {-107.773, \
-64.0184, 0.568013, 0.568013}, {{276.813, 357.438}, {812.313, 731.688}} -> \
{-161.582, -65.4051, 0.580472, 0.580472}, {{365.5, 446.063}, {812.313, \
731.688}} -> {-217.965, -66.9283, 0.593831, 0.593831}, {{10.875, 91.4375}, \
{723.625, 643.063}} -> {-5.9346, -96.18, 0.477647, 0.477647}, {{99.5, \
180.125}, {723.625, 643.063}} -> {-49.5859, -98.7795, 0.490557, 0.490557}, \
{{188.188, 268.75}, {723.625, 643.063}} -> {-95.5262, -101.379, 0.503466, \
0.503466}, {{276.813, 357.438}, {723.625, 643.063}} -> {-143.755, -103.978, \
0.516374, 0.516374}, {{365.5, 446.063}, {723.625, 643.063}} -> {-194.273, \
-106.578, 0.529283, 0.529283}, {{10.875, 91.4375}, {635, 554.375}} -> \
{-5.13262, -119.806, 0.413099, 0.413099}, {{99.5, 180.125}, {635, 554.375}} -> \
{-43.0152, -123.442, 0.425679, 0.425679}, {{188.188, 268.75}, {635, 554.375}} -> \
{-83.2792, -127.295, 0.438919, 0.438919}, {{276.813, 357.438}, {635, \
554.375}} -> {-125.675, -130.923, 0.451478, 0.451478}, {{365.5, 446.063}, \
{635, 554.375}} -> {-170.582, -134.782, 0.464737, 0.464737}, {{10.875, \
91.4375}, {546.313, 465.75}} -> {-4.33066, -131.988, 0.348553, 0.348553}, \
{{99.5, 180.125}, {546.313, 465.75}} -> {-36.5369, -136.876, 0.361462, \
0.361462}, {{188.188, 268.75}, {546.313, 465.75}} -> {-71.0322, -141.765, \
0.374371, 0.374371}, {{276.813, 357.438}, {546.313, 465.75}} -> {-107.816, \
-146.653, 0.387281, 0.387281}, {{365.5, 446.063}, {546.313, 465.75}} -> \
{-146.89, -151.542, 0.40019, 0.40019}, {{10.875, 91.4375}, {457.688, \
377.063}} -> {-3.52868, -132.725, 0.284006, 0.284006}, {{99.5, 180.125}, \
{457.688, 377.063}} -> {-29.9803, -138.641, 0.296685, 0.296685}, {{188.188, \
268.75}, {457.688, 377.063}} -> {-58.7853, -144.791, 0.309825, 0.309825}, \
{{276.813, 357.438}, {457.688, 377.063}} -> {-89.7678, -150.697, 0.322484, \
0.322484}, {{365.5, 446.063}, {457.688, 377.063}} -> {-123.198, -156.857, \
0.335644, 0.335644}, {{10.875, 91.4375}, {369, 288.375}} -> {-2.72671, \
-122.023, 0.219459, 0.219459}, {{99.5, 180.125}, {369, 288.375}} -> \
{-23.4628, -129.094, 0.232188, 0.232188}, {{188.188, 268.75}, {369, 288.375}} -> \
{-46.5383, -136.379, 0.245278, 0.245278}, {{276.813, 357.438}, {369, \
288.375}} -> {-71.8142, -143.438, 0.257987, 0.257987}, {{365.5, 446.063}, \
{369, 288.375}} -> {-99.506, -150.735, 0.271097, 0.271097}, {{10.875, \
91.4375}, {280.375, 199.75}} -> {-1.92473, -99.8632, 0.154912, 0.154912}, \
{{99.5, 180.125}, {280.375, 199.75}} -> {-16.9454, -108.096, 0.167692, \
0.167692}, {{188.188, 268.75}, {280.375, 199.75}} -> {-34.2914, -116.507, \
0.180731, 0.180731}, {{276.813, 357.438}, {280.375, 199.75}} -> {-53.8606, \
-124.726, 0.19349, 0.19349}, {{365.5, 446.063}, {280.375, 199.75}} -> \
{-75.814, -133.151, 0.20655, 0.20655}, {{10.875, 91.4375}, {191.688, \
111.063}} -> {-1.12276, -66.2677, 0.0903653, 0.0903653}, {{99.5, 180.125}, \
{191.688, 111.063}} -> {-10.428, -75.673, 0.103195, 0.103195}, {{188.188, \
268.75}, {191.688, 111.063}} -> {-22.0444, -85.2012, 0.116184, 0.116184}, \
{{276.813, 357.438}, {191.688, 111.063}} -> {-35.9071, -94.5911, 0.128994, \
0.128994}, {{365.5, 446.063}, {191.688, 111.063}} -> {-52.1221, -104.135, \
0.142003, 0.142003}, {{10.875, 91.4375}, {103, 22.4375}} -> {-0.320789, \
-21.2227, 0.0258187, 0.0258187}, {{99.5, 180.125}, {103, 22.4375}} -> \
{-3.91467, -31.834, 0.0387281, 0.0387281}, {{188.188, 268.75}, {103, \
22.4375}} -> {-9.79753, -42.4452, 0.0516374, 0.0516374}, {{276.813, 357.438}, \
{103, 22.4375}} -> {-17.9694, -53.0566, 0.0645467, 0.0645467}, {{365.5, \
446.063}, {103, 22.4375}} -> {-28.4303, -63.6681, 0.0774564, 0.0774564}}],

Cell["We include the data above in file allOnes5.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TOROIDAL KNIGHT DOMAINS", "Subsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.01852 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.04806 0.190476 [
[ 0 0 0 0 ]
[ 1 2.01852 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 2.01852 L
0 2.01852 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.04806 0.200176 0.224427 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0204583 0.0192308 0.0204583 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
47 string
47 47 8 [47 0 0 47 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000FF00FFFFFF0000FFFF0000FFFF00FFFFFFFF0000FFFF00FF00FF00FFFF00FFFFFF
00FF00000000FFFFFFFFFF
000000FF00FFFFFF00FF0000000000FFFF00FF00FF00FF0000000000FF000000FF000000
00FFFF00FF0000FFFFFFFF
0000000000FF0000FFFFFFFFFFFFFF00FF00FFFF00FFFFFF00000000FFFF0000FF00FF00
0000FFFFFF00FFFF000000
FFFF00000000FF00FFFFFF00FFFFFF00FF00FFFF0000FF00FF00FFFF00FF00FF0000FF00
FFFFFF000000FFFF0000FF
00000000000000FF0000FF000000FFFFFFFF00FFFF0000000000FF000000FFFFFFFFFF00
00FF00FFFFFF00FF0000FF
FFFFFF0000000000FFFF00FF0000FFFF0000FF000000FF00FFFF00FFFFFF000000FF0000
00FF00FF00FFFFFF00FF00
FFFF00FF000000FF0000FF0000FF00FF0000FF00FFFFFFFFFFFFFFFFFFFFFF0000000000
0000FF00FFFFFF00FF00FF
FFFF0000FF00FF00FF0000FF00FF0000FF0000FFFF0000000000FFFFFF0000000000FFFF
FF00FFFF00FF0000000000
0000FFFF00FF00FF00FFFF0000FFFFFFFFFF0000FF0000FF000000000000000000FFFFFF
0000FF00FFFF0000FFFFFF
00FFFFFF00FF0000FF000000000000000000FFFFFF0000FF000000FF0000000000FFFFFF
FF0000FFFF00FF00FFFF00
FF00FFFFFF00FF00FF0000FF0000000000FF000000FFFFFF0000FFFFFF00FF00FF0000FF
0000FF000000FFFFFFFFFF
FF00FF0000FF00FF0000FF00FF00FF00FFFFFFFF0000FFFFFFFFFFFF00000000FF00FFFF
FF00FF000000FFFF00FFFF
0000FFFF00000000000000FF0000FF0000FF000000FF00FF0000000000000000FF0000FF
FFFFFFFFFFFF00FF0000FF
0000FFFF0000FFFFFF000000000000FF00FF00FFFFFF00FFFFFFFF0000FFFF00FFFF00FF
00FF00FFFFFF0000FF0000
FF00FFFFFFFF0000FF0000FFFF0000FF000000FFFF00FFFF00FF0000FF00000000FFFFFF
00FFFF00FFFFFF00000000
FFFF0000FFFFFF00FF00000000FFFF00FF0000FF0000FF000000FF00FFFF00000000FFFF
FFFFFF00FF00FFFF0000FF
00FFFFFFFF0000FFFF0000FF000000FF00FFFF0000FFFF0000000000FF00FF00FF00FF00
00000000FFFFFFFF0000FF
FF000000FF000000FF00FFFFFFFF0000FF0000FF0000FF000000FF00FFFFFFFF00FF00FF
FFFFFF00FF00FF00FFFF00
FFFFFFFF00FFFF0000FF00FF00000000FF000000FFFF00FFFFFFFF00000000FFFFFFFF00
FFFF0000000000FFFF0000
FF00FFFFFF0000FF00FF00FF00FFFFFF00FF000000FF0000000000FFFFFF000000FFFFFF
0000FF00FF00FF00FF0000
FFFF0000FF00FFFFFFFF000000FFFF000000FF0000FFFF0000FF0000FF00FF0000FF00FF
00FFFF00FFFFFFFF00FFFF
0000FF000000FF000000FF00FFFF0000FF00FFFFFF000000FF00FF0000000000FF0000FF
00FFFFFF000000FF00FFFF
00FFFFFF00FFFF000000FFFF0000FFFFFFFF0000FF0000FF000000FF00FFFFFF0000FF00
0000FFFF00FFFFFF000000
FF00FF000000FF00FFFFFFFFFFFFFF000000FF000000FF00FF00FFFF00FFFFFFFF000000
000000000000FFFFFF0000
FF0000FF00FFFF00000000FF00FF00000000FF0000FF00FF00FFFF0000FFFF00000000FF
FF00000000FF00FFFFFFFF
0000000000FFFF00000000FF00FFFF000000FF00FF000000FF0000FFFF0000FF00FFFFFF
FFFF0000FFFF000000FF00
FF0000FFFF00FFFF0000FFFF00FF00FF00FFFF0000FF00FFFF0000FFFFFFFF0000FF00FF
00FF0000FFFF00FF0000FF
000000FF00FFFFFF00FFFFFF00000000000000FF0000FFFF00FFFF00000000FF00000000
FFFF00FFFF00FFFF000000
FFFFFF0000FFFFFF0000FF000000FFFFFFFF00FFFF00000000FFFF0000FFFF00FFFFFF00
00000000FFFF00FF0000FF
0000FFFF00FFFF000000000000FF00FF00FF00FF0000FFFFFF00FF00FF00FFFF000000FF
FFFF0000FF000000FFFFFF
FF000000FF00FF000000FF0000FF0000FFFF0000FF00FFFFFF00FF00FFFF0000FFFFFF00
FF00FFFF000000FF000000
FF0000FFFF000000000000000000000000FFFF000000FFFF00FF00FF00FF0000FF00FFFF
FF00000000FFFFFFFF0000
00FFFF00FF0000000000FFFFFFFF0000FF00FF0000FF00FF00000000FF00FFFF00FF0000
00000000000000FFFF0000
FF000000FFFF0000FFFF000000FFFF0000FFFFFFFF00000000FFFF00FF00FF00FF000000
00FF00FFFF0000000000FF
FF00FFFFFF0000FFFFFF00FF0000FFFFFF00FFFF0000FF0000FF0000FF00FFFF00000000
FFFFFF00000000FF00FFFF
FF000000000000FFFFFFFFFFFFFFFFFF00FF00FFFFFF0000FFFFFF0000FF00FF00000000
000000FF0000FFFF00FF00
000000FF000000FF00FF00FFFF0000FF00FFFF0000000000FFFF00FF00FFFFFF0000FF00
00FFFFFF0000FF0000FFFF
FFFF00FFFFFF000000000000FFFFFFFF00FFFF00FFFF000000FFFFFF00FF000000FFFF00
FF0000FF00FFFF0000FF00
00FFFFFF0000FFFFFF00FFFFFF00FFFF00FF00FFFFFFFF00000000000000FF000000FF00
FF0000FFFFFF00FFFFFF00
0000FF00FFFF00FF00FF0000FFFF00000000000000FFFF00000000FF0000FF0000FF00FF
FFFFFF0000FFFFFFFFFFFF
00FFFF00FF00FF00FFFF0000FFFFFFFFFFFF00FFFF00000000FFFFFFFFFF000000FF0000
0000FF0000FF000000FF00
00000000FFFFFFFFFF000000FFFFFF00FF000000FF00FF00FFFFFF00FF0000FF00000000
00FFFFFFFF00FF00FF00FF
FF00FFFF00FFFF0000FFFFFF0000FFFFFFFF00FFFF00FFFF000000FF000000FF000000FF
FFFF00FF00FF0000FF0000
FFFFFFFFFFFF00000000FFFFFF0000FFFF00FF00FFFFFFFFFF00FFFFFF00FFFFFF00FFFF
0000FFFF00000000FFFF00
FFFF00000000FF00FFFFFF0000FF000000FFFFFF000000FFFF00000000FF00FFFF000000
0000FFFF00FFFFFF00FFFF
FFFF000000FF0000FFFFFFFF0000000000FF0000FFFF0000FFFF000000FF00000000FFFF
FFFFFFFFFF0000FFFF00FF
FFFF00FFFF00FF00FF00FFFFFF0000FFFF000000FFFF0000FF00FF00FFFF000000FFFF00
FF0000FF00FF0000FFFF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.04806 0.39418 0.224427 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0200321 0.0192308 0.0200321 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
48 string
48 48 8 [48 0 0 48 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000FFFF00FF00FF0000FF00FF0000FF00FFFF00FFFFFFFF00FFFF00FF0000FF00FF
0000FF00FF00FFFF0000FFFF
00000000FFFF00FF00FF00FFFF0000FFFF00FFFFFF00FF0000FF00FFFFFF00FFFF0000FF
FF00FF00FF00FFFF00000000
FFFFFF00000000FFFFFF000000FF00FF0000000000FF00000000FF0000000000FF00FF00
0000FFFFFF00000000FFFFFF
00FF00FF00FFFFFFFFFF00FF000000FFFFFFFF00FFFFFF0000FFFFFF00FFFFFFFF000000
FF00FFFFFFFFFF00FF00FF00
FF0000FF00FF00FFFFFF0000FF0000FFFF000000FFFFFF0000FFFFFF000000FFFF0000FF
0000FFFFFF00FF00FF0000FF
00FF00FF00FFFF00FFFF0000FFFF0000FF00000000FFFFFFFFFFFF00000000FF0000FFFF
0000FFFF00FFFF00FF00FF00
FF00FFFFFFFFFF00FFFFFFFF00FF0000FFFF0000FFFFFFFFFFFFFFFF0000FFFF0000FF00
FFFFFFFF00FFFFFFFFFF00FF
FFFF0000FF00000000FF0000FFFF00FFFF0000FFFF00FFFFFFFF00FFFF0000FFFF00FFFF
0000FF00000000FF0000FFFF
FF000000000000FF00FF00000000FFFF00FF0000000000FFFF0000000000FF00FFFF0000
0000FF00FF000000000000FF
FF00FFFF0000FFFF0000000000000000FF00FF00FFFF00FFFF00FFFF00FF00FF00000000
00000000FFFF0000FFFF00FF
FF000000FF00FF00FF00FFFF00FFFF00000000FF0000FF0000FF0000FF00000000FFFF00
FFFF00FF00FF00FF000000FF
00FFFF00FFFFFF00FFFFFFFF00FFFFFF00FFFFFFFF000000000000FFFFFFFF00FFFFFF00
FFFFFFFF00FFFFFF00FFFF00
00FFFFFFFF00FF00FF00FFFF00FF0000FFFFFFFF00FF00000000FF00FFFFFFFF0000FF00
FFFF00FF00FF00FFFFFFFF00
FF0000FF0000FF000000FFFF0000FF000000FF000000FF0000FF000000FF000000FF0000
FFFF000000FF0000FF0000FF
00FF00000000FFFFFF00FFFFFFFF0000FFFF00000000FFFFFFFF00000000FFFF0000FFFF
FFFF00FFFFFF00000000FF00
FF00FF00000000FF0000FF00FF000000FFFFFF0000FFFFFFFFFFFF0000FFFFFF000000FF
00FF0000FF00000000FF00FF
0000FF00FFFFFF00000000FF00FF000000FFFF000000FFFFFFFF000000FFFF000000FF00
FF00000000FFFFFF00FF0000
FF0000FF00FF00FFFF00FF0000FFFFFF00FF00FFFF00FFFFFFFF00FFFF00FF00FFFFFF00
00FF00FFFF00FF00FF0000FF
0000FF000000FFFF000000FF0000FFFFFF00FF0000FF00000000FF0000FF00FFFFFF0000
FF000000FFFF000000FF0000
FFFFFF0000000000000000FFFF0000000000000000FF00FFFF00FF0000000000000000FF
FF0000000000000000FFFFFF
00FF0000000000FFFF00FFFFFFFFFF0000FFFF0000FFFFFFFFFFFF0000FFFF0000FFFFFF
FFFF00FFFF0000000000FF00
00FF00FFFFFFFF0000FF00FFFF00FF000000FFFFFFFFFFFFFFFFFFFFFFFF000000FF00FF
FF00FF0000FFFFFFFF00FF00
FFFFFFFFFFFFFFFFFF00FF00FFFFFFFFFF00FF0000FF00000000FF0000FF00FFFFFFFFFF
00FF00FFFFFFFFFFFFFFFFFF
0000FFFF00000000FFFFFF00FF000000FF00000000FF00FFFF00FF00000000FF000000FF
00FFFFFF00000000FFFF0000
FF0000FFFF000000FF0000FF000000FF00FF00FFFF0000FFFF0000FFFF00FF00FF000000
FF0000FF000000FFFF0000FF
FFFFFF00FF0000FF00FFFFFFFFFF00FFFF00FFFFFF000000000000FFFFFF00FFFF00FFFF
FFFFFF00FF0000FF00FFFFFF
0000000000FF00FF00FF000000FF00FF00FFFF0000FF00000000FF0000FFFF00FF00FF00
0000FF00FF00FF0000000000
000000000000000000FFFF0000FFFFFF00FF00FF0000000000000000FF00FF00FFFFFF00
00FFFF000000000000000000
FF00FFFFFFFF000000000000000000FF00FFFF00FF00FF0000FF00FF00FFFF00FF000000
000000000000FFFFFFFF00FF
000000FF0000FF000000FFFFFFFFFF0000FFFFFFFFFF00000000FFFFFFFFFF0000FFFFFF
FFFF000000FF0000FF000000
00FFFF0000FF00FFFF000000FFFFFF0000FFFF00FFFFFF0000FFFFFF00FFFF0000FFFFFF
000000FFFF00FF0000FFFF00
00FF00FF00FF000000FF00FFFF00000000FF00000000FF0000FF00000000FF00000000FF
FF00FF000000FF00FF00FF00
FF00000000FF0000FFFFFFFFFF000000FF0000FFFF00FF0000FF00FFFF0000FF000000FF
FFFFFFFF0000FF00000000FF
FFFFFFFFFFFF00FF000000FFFF000000FFFF000000FF00FFFF00FF000000FFFF000000FF
FF000000FF00FFFFFFFFFFFF
FFFFFF00000000FF00FFFF0000000000FF00000000FFFF0000FFFF00000000FF00000000
00FFFF00FF00000000FFFFFF
00FFFF000000000000FF00FF00FF000000000000FF0000FFFF0000FF000000000000FF00
FF00FF000000000000FFFF00
FF00FFFF0000000000FF00FF0000FF0000FFFF0000FFFFFFFFFFFF0000FFFF0000FF0000
FF00FF0000000000FFFF00FF
000000FFFFFF00FF00FFFF00FFFF000000FFFFFF0000FFFFFFFF0000FFFFFF000000FFFF
00FFFF00FF00FFFFFF000000
FFFF000000FF00FFFF00FF00FFFF00FF0000FF0000FFFF0000FFFF0000FF0000FF00FFFF
00FF00FFFF00FF000000FFFF
000000FF00FFFF000000FFFFFF00000000FF0000FF00FFFFFFFF00FF0000FF00000000FF
FFFF000000FFFF00FF000000
FFFF00FFFFFFFF00FFFFFF00FF000000FF00FFFF00FFFFFFFFFFFF00FFFF00FF000000FF
00FFFFFF00FFFFFFFF00FFFF
0000FF00FFFFFFFF00000000FF00FF0000FF0000FF0000FFFF0000FF0000FF0000FF00FF
00000000FFFFFFFF00FF0000
0000FF0000FFFFFF0000FFFFFFFFFFFFFF0000FF00FF00FFFF00FF00FF0000FFFFFFFFFF
FFFF0000FFFFFF0000FF0000
FFFFFFFF00FF00FFFFFF00FF0000FFFF000000FFFF00FFFFFFFF00FFFF000000FFFF0000
FF00FFFFFF00FF00FFFFFFFF
FF0000FF000000000000FF00FFFFFFFF000000FFFF000000000000FFFF000000FFFFFFFF
00FF000000000000FF0000FF
FF00FF00FFFF00FFFF0000000000FF00FFFFFF0000FF00FFFF00FF0000FFFFFF00FF0000
000000FFFF00FFFF00FF00FF
FF00FFFF000000FF00000000FFFF00FF00FFFF0000FFFF0000FFFF0000FFFF00FF00FFFF
00000000FF000000FFFF00FF
000000FFFFFFFFFFFFFFFFFFFF000000000000FFFF00FF0000FF00FFFF000000000000FF
FFFFFFFFFFFFFFFFFF000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.04806 0.588183 0.224427 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0196232 0.0192308 0.0196232 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
49 string
49 49 8 [49 0 0 49 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFF00FF0000FF00FFFFFFFFFF00FF00FF00FF000000FF00FF00FF00FFFFFFFF
FF00FF0000FF00FFFFFFFFFFFF
FFFFFF00FFFF000000FF000000FFFFFFFFFF0000000000FF00FF0000000000FFFFFFFFFF
000000FF000000FFFF00FFFFFF
00000000FF0000FF0000FFFF00000000FF0000FFFF00000000000000FFFF0000FF000000
00FFFF0000FF0000FF00000000
FF000000FFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFF00FF00FF00FFFFFFFFFFFFFFFF00
FFFF00FFFF00FFFFFF000000FF
FF00FF0000FFFF00000000FF0000FFFF0000FFFFFFFF0000000000FFFFFFFF0000FFFF00
00FF00000000FFFF0000FF00FF
00FFFF000000FFFF00FF0000FF00FF0000FFFF00FF0000FF00FF0000FF00FFFF0000FF00
FF0000FF00FFFF000000FFFF00
FF0000FFFF000000FFFF00FF000000000000FFFF00FFFFFF00FFFFFF00FFFF0000000000
00FF00FFFF000000FFFF0000FF
0000FF00FFFF00FFFFFFFF00FFFF00FF00000000000000FF00FF00000000000000FF00FF
FF00FFFFFFFF00FFFF00FF0000
000000FF0000FFFFFF00000000FF0000FFFFFF00FFFFFF000000FFFFFF00FFFFFF0000FF
00000000FFFFFF0000FF000000
FFFFFFFF00FFFFFF00FFFFFF000000FF000000FFFFFF00FF00FF00FFFFFF000000FF0000
00FFFFFF00FFFFFF00FFFFFFFF
0000FFFF00FF000000FF00FFFF00FFFF0000FFFFFF00000000000000FFFFFF0000FFFF00
FFFF00FF000000FF00FFFF0000
000000FF0000FF00FFFF00FFFFFF00FFFFFFFF00000000FF00FF00000000FFFFFFFF00FF
FFFF00FFFF00FF0000FF000000
0000FFFF00FFFFFF00FFFFFFFF00FF00FF000000FFFF00FF00FF00FFFF000000FF00FF00
FFFFFFFF00FFFFFF00FFFF0000
0000000000FF0000FFFF00FF00000000FFFF000000FFFFFF00FFFFFF000000FFFF000000
00FF00FFFF0000FF0000000000
FFFFFFFF000000000000FF000000FFFFFF00FFFF00FF00FF00FF00FF00FFFF00FFFFFF00
0000FF000000000000FFFFFFFF
00FFFFFFFFFF00FF000000FFFFFF0000FF000000FFFFFF000000FFFFFF000000FF0000FF
FFFF000000FF00FFFFFFFFFF00
FFFF0000FFFF00FF00FF000000FF00FFFF000000FFFF0000000000FFFF000000FFFF00FF
000000FF00FF00FFFF0000FFFF
FF00FF00FFFF00FF00FF00FFFFFF00FF00FF00FF000000000000000000FF00FF00FF00FF
FFFF00FF00FF00FFFF00FF00FF
0000FFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FF00FFFF00FFFF00FF0000FF00FF00FF
FFFFFFFFFFFFFFFFFFFFFF0000
0000FF0000FFFF0000FF00000000FFFF00FF00000000FFFF00FFFF00000000FF00FFFF00
000000FF0000FFFF0000FF0000
FF00FF00FFFF00FFFFFF000000FF0000FF000000FFFF00FF00FF00FFFF000000FF0000FF
000000FFFFFF00FFFF00FF00FF
FFFFFFFFFFFF0000000000FFFF0000FF00FF0000000000FF00FF0000000000FF00FF0000
FFFF0000000000FFFFFFFFFFFF
0000FF00000000FF00FF0000FFFF0000000000FFFFFF0000000000FFFFFF0000000000FF
FF0000FF00FF00000000FF0000
0000FFFF00FF000000FF0000FFFF0000000000000000FFFF00FFFF0000000000000000FF
FF0000FF000000FF00FFFF0000
0000FFFF0000FFFF00FFFF00FF0000FFFFFFFFFF000000000000000000FFFFFFFFFF0000
FF00FFFF00FFFF0000FFFF0000
0000FFFF0000FFFFFFFF000000FFFFFFFF0000FF000000FF00FF000000FF0000FFFFFFFF
000000FFFFFFFF0000FFFF0000
0000FFFF0000FFFFFF00FF0000FF0000FF0000FF000000FF00FF000000FF0000FF0000FF
0000FF00FFFFFF0000FFFF0000
FFFF00FF00FF00000000FFFF0000FFFF00FFFFFFFF00FFFF00FFFF00FFFFFFFF00FFFF00
00FFFF00000000FF00FF00FFFF
FFFFFF00FFFFFF00FFFF000000FFFFFF00FF00FFFF00FFFF00FFFF00FFFF00FF00FFFFFF
000000FFFF00FFFFFF00FFFFFF
000000FF0000000000FF00FF000000000000FF00FFFFFF000000FFFFFF00FF0000000000
00FF00FF0000000000FF000000
0000FFFF00FF00FF0000FF00FFFFFFFF000000FFFFFFFFFF00FFFFFFFFFF000000FFFFFF
FF00FF0000FF00FF00FFFF0000
FF00000000FF0000FF0000FFFFFF00FF00FFFF00FF00000000000000FF00FFFF00FF00FF
FFFF0000FF0000FF00000000FF
00FF000000FF00FFFF0000000000FF00FF00000000FFFFFF00FFFFFF00000000FF00FF00
00000000FFFF00FF000000FF00
0000FFFF00FF000000FF00FF00000000000000FF00FFFFFF00FFFFFF00FF000000000000
00FF00FF000000FF00FFFF0000
00000000FFFFFF00FF00000000FFFFFF00000000FF00000000000000FF00000000FFFFFF
00000000FF00FFFFFF00000000
FF00000000000000FFFF0000FF00FFFF00FF000000FFFFFF00FFFFFF000000FF00FFFF00
FF0000FFFF00000000000000FF
00FF00FFFF00FF00FF00FF00FFFFFFFFFF000000FF00FF000000FF00FF000000FFFFFFFF
FF00FF00FF00FF00FFFF00FF00
00FF0000FF0000FFFF0000FF000000FFFFFF00FF000000FF00FF000000FF00FFFFFF0000
00FF0000FFFF0000FF0000FF00
00FF00FFFFFF0000FFFF00FFFF0000FF0000FFFFFFFFFF000000FFFFFFFFFF0000FF0000
FFFF00FFFF0000FFFFFF00FF00
00FF00FFFFFFFFFFFFFFFF00FF000000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF000000
FF00FFFFFFFFFFFFFFFF00FF00
00FF00FFFF00FF00FFFFFF00FFFFFF0000000000FFFF00FF00FF00FFFF0000000000FFFF
FF00FFFFFF00FF00FFFF00FF00
FF0000FFFFFFFFFF00FFFFFF00FF000000FF0000FF00000000000000FF0000FF000000FF
00FFFFFF00FFFFFFFFFF0000FF
000000FFFF0000FFFFFF00000000FF0000000000FFFF0000000000FFFF0000000000FF00
000000FFFFFF0000FFFF000000
00000000FF00FFFF00FF000000FF000000FFFFFFFF00000000000000FFFFFFFF000000FF
000000FF00FFFF00FF00000000
FFFFFF000000FF00FFFFFF00FF000000FFFF00FFFF00000000000000FFFF00FFFF000000
FF00FFFFFF00FF000000FFFFFF
00FFFF00FFFFFFFFFFFF0000FF0000FFFFFFFF00FFFFFFFF00FFFFFFFF00FFFFFFFF0000
FF0000FFFFFFFFFFFF00FFFF00
FFFF00FFFFFF000000FF00FFFF00FF00FFFF0000FFFF0000000000FFFF0000FFFF00FF00
FFFF00FF000000FFFFFF00FFFF
00FF00FF00000000FFFFFFFFFFFF0000FFFF0000FF0000FF00FF0000FF0000FFFF0000FF
FFFFFFFFFF00000000FF00FF00
00000000FFFFFF0000FFFF00FF0000FF0000FF00FF00FF000000FF00FF00FF0000FF0000
FF00FFFF0000FFFFFF00000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.04806 0.782187 0.224427 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0192308 0.0192308 0.0192308 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
50 string
50 50 8 [50 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000FFFF0000FFFF00000000000000FFFF00FF0000FFFF00FFFFFF00FFFF0000
00FFFFFF00FFFFFF0000FFFF00FF
00FF00FFFFFF00000000FFFFFF0000000000FFFFFF00FF00000000000000FF0000000000
00FFFFFF00FF00FF00FFFFFF0000
FF00FFFF0000000000FF00FFFF0000FFFFFF000000FFFFFFFF0000FFFF0000FFFF00FF00
FFFFFF0000000000FFFFFF00FFFF
FF00FF00FF00FFFF000000FF00000000000000FFFFFF0000FF00FF0000FFFF000000FF00
FF00FFFF0000FF00000000FFFFFF
FF00FF000000FFFFFF00000000FF0000FF0000FF0000FF000000FF00FFFFFF00FFFF0000
FFFFFFFF00000000FF0000FFFF00
00FF0000FF0000FF0000FFFF0000FFFFFFFF0000FF0000FF00FF00FFFFFFFF000000FFFF
000000FF00FFFF0000FF00FF0000
00FFFF00FFFFFF0000000000FFFF00FF00FFFFFF0000FF00FF00000000FFFF00000000FF
000000FFFF00FF0000000000FFFF
00FF00FF0000FFFF0000FF0000FFFF00FF00FF00FF00000000FFFFFFFF00FF00FF00FFFF
0000FFFF000000FFFF00FF0000FF
FF000000FF0000FF00FF00FFFFFF000000FFFFFFFFFFFF0000000000FF0000FFFF000000
00000000FF000000FF000000FFFF
0000FF00FF00FF000000FF00FFFFFFFFFF00FFFFFF0000FFFFFF0000FF0000000000FFFF
FF00FF0000FF00FF000000000000
FF000000FFFFFFFFFFFFFF00FF0000FF00FF00000000000000FFFF00FF00FF00FF00FFFF
FF0000000000FFFFFFFFFF00FFFF
FFFFFF0000FFFF00FFFFFFFFFF00FF00FF00FF00FFFFFF0000000000FF000000000000FF
00000000FF00FF0000FFFFFFFFFF
00000000FFFFFFFF00000000FFFF000000FF00FFFF00FF0000FF00FF0000FF0000FFFFFF
000000000000000000FF00FFFFFF
FFFFFFFFFFFF00FF00FF00FFFF0000FFFFFFFF00FFFF0000FF00FF0000000000FF0000FF
000000FFFF00000000FFFFFF0000
FF0000FFFF0000FFFFFF00FF0000FFFF000000FF00FF00FF000000FFFF00FFFFFFFF0000
FFFFFFFFFF00FFFFFF0000000000
0000FFFF0000FF0000000000FFFFFF000000000000FF00FFFFFF00FF00FF00FF00FF0000
00FF00FFFF00FF00FF00FFFF0000
00FF00FF0000FFFFFF0000000000FFFF0000FF00000000FFFFFFFFFF0000FF00FF00FFFF
00FF00000000000000FF000000FF
00FFFF00FFFF00FFFF0000000000FF0000FFFF000000FF00FF000000FFFFFF0000FF00FF
FF0000FF00FFFF0000FF00FF00FF
00FF00FF00FFFFFF00FF00FFFF0000FF00FF00FF00FFFFFF0000FFFF00FF00000000FFFF
0000000000FF0000000000FF0000
FF000000000000FF0000FF00FF0000FF00FF000000FFFFFF00FFFF00FF000000FFFF00FF
00FF00FF0000FFFFFFFFFF00FFFF
0000FF000000000000000000FFFFFFFFFF000000FFFFFF00FFFF00FF000000FFFF00FF00
00000000000000FFFFFFFF0000FF
0000FFFFFF0000000000FFFFFFFFFF00FF0000FF00FF000000FFFFFF0000FF00FF0000FF
0000FFFFFFFFFF00FFFF00FF00FF
FF0000FF0000FFFF00FF00FF000000FFFFFFFF00000000FFFF00FF00FFFF00FF00FFFFFF
00FF00000000FF00FF0000FF0000
FF000000FFFFFF000000FF000000FFFFFF00FF0000FFFF00000000FFFF00FFFF00FF0000
FF0000FF0000FF0000FFFF0000FF
000000FFFFFF000000FF0000FFFFFF00FFFFFF0000FFFF00FF000000FFFFFF0000FFFF00
00FF00FFFF00FF00FF00000000FF
FFFFFF0000FFFFFF0000FFFF000000FF00FF00FFFF00FF0000FF00FF00FF0000FFFFFF00
FF000000FF0000FF0000FFFF0000
FF00FF00FFFF00FFFFFF00FF000000FF00000000FFFFFF00000000FF0000FFFF00FFFFFF
00000000FF000000FF0000FF0000
00FF00FFFFFF00000000FFFF0000FFFF00000000FFFF00FFFFFFFF0000FFFFFFFF000000
00FFFF0000FF00FF00FF00FFFFFF
FF00FF0000FF00FFFF00FFFFFFFFFF00FF0000FFFF00FFFF00FFFF00FFFFFFFF0000FFFF
FF00FF0000FF00000000FFFF0000
FF000000000000FF00FFFF00FFFF00FF000000FF00FFFFFFFF00000000FF000000000000
FFFFFF00FFFFFF00FF00FF00FFFF
0000FFFFFF00FFFFFF000000FFFFFF0000FFFF00FFFF0000FF000000FF0000FF000000FF
00FF0000FFFF00FF00FFFF00FFFF
FF00FF00FFFFFFFFFFFF00FFFF000000FF0000FF0000000000FFFFFF00000000FFFF0000
FF00FF00FFFFFFFF00000000FF00
0000FF00000000FFFFFF00FFFFFF0000FF0000FF00000000FFFF00FF0000FFFFFF000000
FFFF00FF00FF00FFFF0000FF0000
FFFF00FF00FF00000000FFFFFF00FFFF00FFFF0000FF000000FFFFFFFFFF000000000000
FF00FF00FF00FF00FFFF00FF0000
000000FFFF00FFFFFFFF0000FF00FF00FF000000FF00FFFFFF00FFFF00FFFFFF00FF00FF
FF0000FFFF0000FFFF0000FF0000
000000FFFF00FFFFFF00FFFF000000FFFF0000FF00FFFF0000FFFF00FFFF0000FFFFFFFF
0000FF00FF00FF00FF0000000000
0000FF00FF000000FF000000FF00000000FF00FFFFFF000000FF0000FFFF00000000FF00
00FF0000FFFFFFFF00FF00000000
FF00FF0000FF00FF00FF00FF00FF00FFFFFFFFFFFFFF000000FF0000FFFFFFFF0000FF00
FFFFFFFFFFFF00FF000000FFFF00
FF0000000000FFFFFF000000FF00FF00FFFFFF0000FFFFFFFF0000FFFF0000FF000000FF
FF00FF0000FF0000FF00FFFFFFFF
FF000000FFFFFFFF00FF00000000FF00FF000000FFFFFF00FF00FF00FF00FF0000000000
0000FFFFFF00FF00FF000000FFFF
00FF00000000FF00FF00FF00FF0000FF00FFFF00FF0000FF00FF00FF000000FF000000FF
FF00FFFF00FF0000000000FF0000
0000FFFFFFFFFF0000FF00FF00FFFFFF00FFFFFF00FF00FF0000000000000000FFFF00FF
0000FFFF0000000000FF00000000
FF00FFFFFF0000000000FFFFFF00FFFF00FFFFFFFFFF00FFFF0000FF0000FFFFFFFF00FF
FFFF00FF00FFFF00FFFFFF0000FF
0000FFFF00FF0000FFFFFFFF0000FFFF0000FFFF00000000FF00FFFF000000FF00FFFF00
00FFFFFFFF00FFFF00FFFF0000FF
00FFFF000000FF00FF00FF00FF000000FF00FF0000FFFFFFFFFFFF00000000FFFF000000
FFFFFFFF000000FF00000000FF00
FFFF00FF000000FFFF00FF0000FFFFFF0000FFFF0000FFFF00FFFF00FF000000FF0000FF
FFFF00FFFFFF00FFFF00FF00FF00
FFFFFF00FF00FFFFFF0000000000FFFFFF0000FF0000FF0000FF00FFFF0000FF00FFFFFF
FF0000000000FF00000000FFFF00
000000FF00FFFFFFFF000000FFFF000000FFFFFF00FF00FFFF000000FFFF0000FF00FF00
FF00FF00FF0000FF00FFFFFF0000
000000FFFFFF000000FF000000000000FF0000000000FF00FF000000000000FFFFFF0000
FF00FF000000FFFFFF000000FF00
000000FFFF0000FF0000FFFFFF000000FF00FF00FFFF00FFFF00FFFF0000FF00000000FF
FF00FFFF00FF000000FFFFFF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.04806 0.97619 0.224427 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0188537 0.0192308 0.0188537 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
51 string
51 51 8 [51 0 0 51 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFF00FFFF00FF00FF0000FF00FFFF00000000FFFFFF000000FFFFFF00000000FFFF
00FF0000FF00FF00FFFF00FFFFFFFF
0000FFFF00000000FFFF0000FF0000000000FF000000FFFF000000FFFF000000FF000000
0000FF0000FFFF00000000FFFF0000
00FF0000FFFFFF0000000000000000FFFFFFFF0000FF0000FF00FF0000FF0000FFFFFFFF
0000000000000000FFFFFF0000FF00
FFFFFF0000FFFFFF000000FFFF0000FF00FFFF0000FFFF00FF00FF00FFFF0000FFFF00FF
0000FFFF000000FFFFFF0000FFFFFF
00FFFF00000000FF000000FF00000000FF0000FF0000FFFFFF00FFFFFF0000FF0000FF00
000000FF000000FF00000000FFFF00
FFFFFF00FFFFFFFF00FFFF00FFFF00FF000000FFFFFFFFFFFF00FFFFFFFFFFFF000000FF
00FFFF00FFFF00FFFFFFFF00FFFFFF
00FFFF0000FF00FFFF000000FFFF0000FF000000FF00FFFFFF00FFFFFF00FF000000FF00
00FFFF000000FFFF00FF0000FFFF00
00FFFFFFFFFFFFFF000000000000FF00FF00FF00FF0000FFFF00FFFF0000FF00FF00FF00
FF000000000000FFFFFFFFFFFFFF00
FFFFFF00000000FF000000000000000000FFFFFF00FF00FF000000FF00FF00FFFFFF0000
00000000000000FF00000000FFFFFF
FF00FFFFFFFF00FFFFFF0000FFFF000000FFFFFF0000FF00FF00FF00FF0000FFFFFF0000
00FFFF0000FFFFFF00FFFFFFFF00FF
FF0000FF00FF0000FF000000FF0000FFFF0000FFFF000000FF00FF000000FFFF0000FFFF
0000FF000000FF0000FF00FF0000FF
00FF0000FF0000FFFFFFFFFFFF000000FFFFFF0000FF00FF000000FF00FF0000FFFFFF00
0000FFFFFFFFFFFF0000FF0000FF00
FF00FF00FFFFFF0000FFFFFF00FFFF00FF00FFFF00FF0000FF00FF0000FF00FFFF00FF00
FFFF00FFFFFF0000FFFFFF00FF00FF
FFFFFFFFFF00FF0000FFFFFFFFFF00FFFFFF00FF00FF00000000000000FF00FF00FFFFFF
00FFFFFFFFFF0000FF00FFFFFFFFFF
0000FFFFFF0000FFFF000000FF00000000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFF0000
0000FF000000FFFF0000FFFFFF0000
FF0000FFFFFF0000FF0000FFFFFF00FF0000FFFF00FF00FF000000FF00FF00FFFF0000FF
00FFFFFF0000FF0000FFFFFF0000FF
000000FFFFFFFFFFFFFF00000000FF0000FFFF00000000000000000000000000FFFF0000
FF00000000FFFFFFFFFFFFFF000000
000000000000FF0000FFFF00FF00FFFFFF00FF00FFFF00FF000000FF00FFFF00FF00FFFF
FF00FF00FFFF0000FF000000000000
FF0000FF0000FF00FF0000FFFFFFFFFF00FFFF00FF0000FFFF00FFFF0000FF00FFFF00FF
FFFFFFFF0000FF00FF0000FF0000FF
000000FF00FF0000FF00FFFF0000FF00FF00FFFF00000000FF00FF00000000FFFF00FF00
FF0000FFFF00FF0000FF00FF000000
00FFFF0000FFFFFFFFFFFF00FFFFFFFFFF00FFFFFF00FF00FF00FF00FF00FFFFFF00FFFF
FFFFFF00FFFFFFFFFFFF0000FFFF00
000000FFFF00FF0000FFFFFFFF0000FFFFFF00FF00FFFFFFFF00FFFFFFFF00FF00FFFFFF
0000FFFFFFFF0000FF00FFFF000000
00FF0000FF00FFFF00FF00FF00FF00FFFF00FF0000FF00FF000000FF00FF0000FF00FFFF
00FF00FF00FF00FFFF00FF0000FF00
FF00FF00FF00FF00FFFFFFFFFFFFFF0000000000FF0000FFFF00FFFF0000FF0000000000
FFFFFFFFFFFFFF00FF00FF00FF00FF
00FF00FFFF00FF000000FF00FF00FFFF00000000000000FF000000FF00000000000000FF
FF00FF00FF000000FF00FFFF00FF00
00FFFFFF00FF000000FF00FFFFFF00FF00FFFF000000FF00FF00FF00FF000000FFFF00FF
00FFFFFF00FF000000FF00FFFFFF00
FFFF00000000FF00FF00FF00FFFF0000FFFF000000FFFF0000000000FFFF000000FFFF00
00FFFF00FF00FF00FF00000000FFFF
0000FFFF00FF00FF0000FFFFFFFFFFFFFF00FF0000FF00FF000000FF00FF0000FF00FFFF
FFFFFFFFFF0000FF00FF00FFFF0000
FFFF00FF0000FFFFFFFFFF0000FFFFFFFF0000FF000000FFFF00FFFF000000FF0000FFFF
FFFF0000FFFFFFFFFF0000FF00FFFF
00FF00000000FFFFFF000000FF0000000000FF0000FF00000000000000FF0000FF000000
0000FF000000FFFFFF00000000FF00
0000FFFF00FF00FF00000000FFFFFF0000FF00FFFF00FFFFFF00FFFFFF00FFFF00FF0000
FFFFFF00000000FF00FF00FFFF0000
0000FF0000000000FF0000FFFFFF00FFFF0000FF00FFFF00FF00FF00FFFF00FF0000FFFF
00FFFFFF0000FF0000000000FF0000
FF0000FF0000FFFF000000FF00FF00FFFFFFFFFF00FFFF00FF00FF00FFFF00FFFFFFFFFF
00FF00FF000000FFFF0000FF0000FF
00FFFF000000FFFF000000FF00FF00FFFF00FF00000000FFFF00FFFF00000000FF00FFFF
00FF00FF000000FFFF000000FFFF00
00FFFF0000FFFFFF00FFFFFFFF00000000FF0000FFFF00FFFF00FFFF00FFFF0000FF0000
0000FFFFFFFF00FFFFFF0000FFFF00
FFFFFFFF0000FFFFFF00000000FFFFFF0000FF00FF000000FF00FF000000FF00FF0000FF
FFFF00000000FFFFFF0000FFFFFFFF
FFFFFF00FFFF000000FF0000FF0000FFFF000000FFFF00FFFF00FFFF00FFFF000000FFFF
0000FF0000FF000000FFFF00FFFFFF
00FFFFFFFF00FFFFFFFFFF00FFFF00FFFF00000000FF0000FF00FF0000FF00000000FFFF
00FFFF00FFFFFFFFFF00FFFFFFFF00
FF000000FF00FFFFFF00FFFF00FFFFFF00FF000000FF0000FF00FF0000FF000000FF00FF
FFFF00FFFF00FFFFFF00FF000000FF
FF0000FF00FF0000FF00FFFFFFFF00FF0000FF000000FFFF000000FFFF000000FF0000FF
00FFFFFFFF00FF0000FF00FF0000FF
00FFFF00FF00FFFF00000000FF0000FF00FF000000FFFF00FF00FF00FFFF000000FF00FF
0000FF00000000FFFF00FF00FFFF00
000000FF00FFFFFFFFFF00FF00FFFF000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFF000000
FFFF00FF00FFFFFFFFFF00FF000000
FFFF00FFFFFF00FF0000FF00FFFFFF00FFFF00FFFF00FF00FF00FF00FF00FFFF00FFFF00
FFFFFF00FF0000FF00FFFFFF00FFFF
00FFFFFFFFFFFFFF0000FFFFFFFF00FFFFFF0000FFFF0000FF00FF0000FFFF0000FFFFFF
00FFFFFFFF0000FFFFFFFFFFFFFF00
FF00FF00FF0000FFFFFFFF00FFFF00FFFF0000000000FF00FF00FF00FF0000000000FFFF
00FFFF00FFFFFFFF0000FF00FF00FF
00FF00FFFFFF00FFFFFF00FF00FFFF0000000000FFFFFF00FF00FF00FFFFFF0000000000
FFFF00FF00FFFFFF00FFFFFF00FF00
0000FFFF0000FFFFFFFFFF00000000FF000000FF00FF00000000000000FF00FF000000FF
00000000FFFFFFFFFF0000FFFF0000
00000000FF00FFFFFF00FF00FF00FFFFFFFFFFFFFF0000FF000000FF0000FFFFFFFFFFFF
FF00FF00FF00FFFFFF00FF00000000
FF0000FFFF00FF00FFFFFF00FF0000000000FFFF00FF0000FF00FF0000FF00FFFF000000
0000FF00FFFFFF00FF00FFFF0000FF
FF000000FF00FF00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFF000000FFFFFFFF00FFFFFFFF
FF00FFFFFFFFFF00FF00FF000000FF
0000000000000000FFFF00FF0000FFFFFF00000000FF0000FF00FF0000FF00000000FFFF
FF0000FF00FFFF0000000000000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.242063 0.200176 0.41843 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0228938 0.0192308 0.0228938 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
42 string
42 42 8 [42 0 0 42 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFF000000FF00FFFF0000FF00FFFFFFFFFF00FFFF00FFFFFFFFFF00FF0000FFFF00FF
000000FFFFFF
FF000000FFFFFFFF00FFFFFFFFFF00FFFF0000FF0000FF0000FFFF00FFFFFFFFFF00FFFF
FFFF000000FF
00FFFFFFFFFFFFFF00FF00FFFFFF000000FF00FFFFFFFF00FF000000FFFFFF00FF00FFFF
FFFFFFFFFF00
FF0000FF00FF00FF00FF00FF000000000000FF00000000FF000000000000FF00FF00FF00
FF00FF0000FF
000000FF00FFFFFF00000000FF00FFFF0000FF00000000FF0000FFFF00FF00000000FFFF
FF00FF000000
00FFFF000000FFFF00FFFFFF0000FF0000FFFF00FFFF00FFFF0000FF0000FFFFFF00FFFF
000000FFFF00
FF0000FFFFFFFF0000000000FFFF00FF00FF00FFFFFFFF00FF00FF00FFFF0000000000FF
FFFFFF0000FF
0000FF00FF000000FF00FFFFFFFFFF00FF000000FFFF000000FF00FFFFFFFFFF00FF0000
00FF00FF0000
FF00FF00FF0000FF00FFFFFF0000FFFFFFFFFF00000000FFFFFFFFFF0000FFFFFF00FF00
00FF00FF00FF
FFFFFFFFFF0000FFFF0000000000FFFFFFFFFF00000000FFFFFFFFFF0000000000FFFF00
00FFFFFFFFFF
FF0000FF000000FF0000FF000000FF0000000000FFFF0000000000FF000000FF0000FF00
0000FF0000FF
0000FF00000000FFFF0000FFFFFFFF00FF0000FFFFFFFF0000FF00FFFFFFFF0000FFFF00
000000FF0000
00FF00FF00FF00FFFFFFFFFFFF0000FF00000000FFFF00000000FF0000FFFFFFFFFFFF00
FF00FF00FF00
00FFFFFFFF00000000000000000000FF00FFFF00FFFF00FFFF00FF000000000000000000
00FFFFFFFF00
FF00000000FFFF00000000FFFFFF00FF00FF000000000000FF00FF00FFFFFF00000000FF
FF00000000FF
00FF00FFFFFFFFFFFF00FF0000FF0000FF00FFFF0000FFFF00FF0000FF0000FF00FFFFFF
FFFFFF00FF00
FF00FF00000000000000FFFFFF000000FFFF00FFFFFFFF00FFFF000000FFFFFF00000000
000000FF00FF
FFFFFFFFFFFFFF00FFFFFF0000FF00FFFF0000000000000000FFFF00FF0000FFFFFF00FF
FFFFFFFFFFFF
00000000000000FF00FFFFFF000000000000FFFF0000FFFF000000000000FFFFFF00FF00
000000000000
FFFFFFFFFFFFFF000000000000FFFF00000000FFFFFFFF00000000FFFF000000000000FF
FFFFFFFFFFFF
00FF00FFFFFFFF00FFFFFF00FFFFFF000000FFFF0000FFFF000000FFFFFF00FFFFFF00FF
FFFFFF00FF00
FF00FF000000FF00000000FF00FF00FF00FFFFFF0000FFFFFF00FF00FF00FF00000000FF
000000FF00FF
FFFFFF0000FF0000FFFF0000FFFF0000FF00FFFFFFFFFFFF00FF0000FFFF0000FFFF0000
FF0000FFFFFF
FF00FFFFFFFF0000FF00FF0000FF00FF0000FF00000000FF0000FF00FF0000FF00FF0000
FFFFFFFF00FF
FFFFFFFFFF00FFFF00FF00FF000000FF00000000FFFF00000000FF000000FF00FF00FFFF
00FFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFF00FFFFFFFF000000FFFF000000FFFFFFFF00FFFFFFFFFFFF
FFFFFF00FFFF
FFFF00FFFFFF00FFFFFFFF0000000000000000FFFFFFFF0000000000000000FFFFFFFF00
FFFFFF00FFFF
FF0000FF000000FFFF00FF00FF0000FFFFFF00FFFFFFFF00FFFFFF0000FF00FF00FFFF00
0000FF0000FF
FF0000FFFF000000000000000000FF00FF000000FFFF000000FF00FF0000000000000000
00FFFF0000FF
FF0000000000FFFF00FFFFFFFF0000FFFF0000FF0000FF0000FFFF0000FFFFFFFF00FFFF
0000000000FF
00FF00FF00FF000000FFFFFFFFFF0000FFFFFFFF0000FFFFFFFF0000FFFFFFFFFF000000
FF00FF00FF00
FF00FFFFFF00FFFFFFFFFFFF0000000000FF000000000000FF0000000000FFFFFFFFFFFF
00FFFFFF00FF
0000FF00FF0000000000FFFF0000FF0000FF00FFFFFFFF00FF0000FF0000FFFF00000000
00FF00FF0000
FF00FF00000000FF00000000FF0000FF000000FFFFFFFF000000FF0000FF00000000FF00
000000FF00FF
00FFFFFFFFFF0000FFFFFF00FFFF000000FFFF00FFFF00FFFF000000FFFF00FFFFFF0000
FFFFFFFFFF00
FFFF00FF0000FF000000FF0000FFFF00FFFF0000FFFF0000FFFF00FFFF0000FF000000FF
0000FF00FFFF
FF0000FF0000000000FFFF00FF000000FF0000000000000000FF000000FF00FFFF000000
0000FF0000FF
0000000000FF00FFFF00FF00FF00FFFFFF0000FFFFFFFF0000FFFFFF00FF00FF00FFFF00
FF0000000000
FF0000FFFF00000000000000FF00FF00FF0000FFFFFFFF0000FF00FF00FF000000000000
00FFFF0000FF
0000FFFFFF00FFFF00FFFF00FF000000FFFFFFFF0000FFFFFFFF000000FF00FFFF00FFFF
00FFFFFF0000
FF00FF00FF0000000000FF00000000FF000000FFFFFFFF000000FF00000000FF00000000
00FF00FF00FF
00FFFF0000FFFF00FF00000000FFFF00FFFF000000000000FFFF00FFFF00000000FF00FF
FF0000FFFF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.242063 0.39418 0.41843 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0223614 0.0192308 0.0223614 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
43 string
43 43 8 [43 0 0 43 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00FFFFFF00FFFFFFFFFF00FF0000FFFF000000FFFFFFFF0000FF0000FFFFFFFF00FFFF
FFFFFFFFFFFFFF
0000FFFFFFFFFF000000FFFFFF00FF00FFFF00000000FF00FF000000FFFFFF00FF00FFFF
00FF00FF0000FF
FF00FFFF0000000000FFFFFFFFFF00FFFF00FFFF00000000FF00FFFF0000FF00FFFF0000
00FF00FFFFFFFF
0000FFFFFF00FFFFFF00FFFF0000FFFF0000000000000000000000FFFF0000FFFF00FFFF
FF00FFFFFF0000
00FFFFFFFF000000FF00FF0000FFFF0000000000FF00FFFF00000000FF0000FFFF00FF00
00FFFFFFFF0000
00FF00FF00000000FFFFFFFFFFFFFF0000FFFF00FF0000000000FF00FF00FF00FFFF00FF
FF00FFFFFFFFFF
00FF0000FF0000FFFF00FF00FF000000FF00000000FF00FF0000FFFF00FFFFFFFFFFFFFF
00FFFF00000000
FF0000FFFFFFFF00FF00FFFF000000000000FFFF00FF0000FF0000FF00FF0000FFFFFF00
FF00FFFF00FFFF
00FF00FF0000FFFFFFFFFFFF0000FF000000FFFF00FF0000FF0000FFFFFF0000FF00FFFF
FFFF00FF000000
0000FFFF0000000000FFFFFFFF0000FFFF00FFFF000000FF00FF00FFFFFFFF0000FFFFFF
FF0000FFFF00FF
0000FFFF00FFFFFFFF0000FF00FF0000FF00FF00FFFFFF00FF00FFFF00FF00FF00FFFFFF
FFFF00FFFF0000
FF00000000FF000000FFFFFFFFFFFF00FF00FF00FFFF00FF00FF00FFFFFFFFFFFF00FFFF
FF00FF00FFFF00
00FF00FF00FFFFFFFF00FF000000FF00FF0000FF000000FF0000FF00FF000000FF00FFFF
FFFF00FF00FF00
0000FFFFFFFF00FF00FFFF00FF0000000000FFFFFFFF000000FFFFFF0000FF00FF00FF00
FF0000FF00FFFF
FFFFFF00FFFFFFFF00FFFFFF0000FFFFFFFF0000FFFFFF0000FFFF00FF0000FFFF0000FF
FFFFFF00FFFFFF
00FFFF0000FF000000FFFFFF000000FFFFFFFFFF000000FF000000FFFFFF000000FFFFFF
FFFF0000FFFFFF
00000000FFFFFFFF0000FF00FF0000FF0000FFFFFFFFFF00FF00000000FFFFFFFFFF00FF
FF00FF0000FF00
FF0000FFFF00FF000000FFFFFF00FF00FFFF000000FF00FF00FFFFFFFFFFFF00FFFF0000
FFFFFFFF00FFFF
00FFFF00FF00FF00FFFF00FF00000000FF000000FFFFFFFF0000FFFF00FF00000000FF00
FFFFFF00FF0000
FF0000FF0000FFFFFFFF0000FFFFFFFF00FFFF000000FF000000FFFFFF00FFFF00FF0000
0000FFFFFF0000
FF00FF000000FFFFFF00FFFF0000FF0000FF00FFFF00FF0000FF0000FFFF0000FF00FFFF
FFFF0000FFFFFF
00FF0000FFFF00FFFFFF0000FF0000000000FFFFFF00FFFFFF0000000000FF0000FFFFFF
00FFFF0000FF00
0000000000FFFFFFFF0000FF00FFFF0000FF0000FF00FFFF00FF0000FF0000000000FFFF
FF00000000FF00
00FFFFFF000000FF00FF000000FF00FF00FF00FF0000FFFFFF00FFFF000000FF00FFFF00
FF00FFFF00FFFF
00FF000000FFFFFFFFFFFF0000FFFFFF00FF000000FF00FF00FF0000FF0000FFFF00FFFF
FF000000000000
00FFFFFF0000FF0000FFFF00FFFFFFFF00FFFFFFFFFFFF00FFFF0000FF00FFFFFF000000
FFFF00FFFF0000
FF00FF00FF0000FFFFFF0000000000FF0000FF00FFFFFFFFFF00000000FF00FF0000FFFF
00FFFF00FFFFFF
FF0000FF000000FFFFFF00FFFFFF0000FF00000000000000FFFF0000FF00FF00FFFF0000
FF0000FF000000
FF00FFFF00FF0000FFFF00FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FF00
00FF00FFFF00FF
FF00FFFF0000FFFF00FF00FFFFFFFFFFFF00FFFF00FFFF0000FF0000FFFFFFFF0000FF00
00FFFFFF00FF00
00FF0000FF00FF0000000000FF0000FFFFFFFF00FF00FF00FFFFFFFF0000FF0000000000
FF00FF0000FF00
FFFF00FFFF00000000FFFF0000FFFFFFFF00FFFFFFFF000000FF0000FFFF0000FF00FFFF
FFFF00FFFF0000
FFFF00FF0000FFFF0000FFFF0000000000FFFFFFFFFFFFFFFFFF00FF000000FFFFFF00FF
FF0000FF00FFFF
FF0000FF00FFFFFF0000FF0000FFFF00000000FFFF00FFFFFFFFFF00000000FF0000FF00
00FF00FF000000
FFFF00FF0000FF00FFFF0000FF00FF0000FF000000FF00FF00FF00FFFFFFFFFF0000FF00
FFFF00FF0000FF
FFFF00FF0000FF00FF00000000FFFFFFFF000000FFFFFFFF0000FF00FF0000FF00FFFF00
FFFF00FF0000FF
FFFF00FFFF00FFFFFF000000FFFF00FF000000FFFFFFFF00000000000000FFFF00FFFFFF
FFFFFFFF0000FF
FFFFFFFF00FF00FF00FF00FFFFFF00FF00FF00FF0000FFFFFF00FFFF0000FF0000FFFF00
FFFFFFFF00FF00
00FFFFFFFFFFFFFF0000FFFFFFFFFFFF00FFFF00000000FFFFFF00FFFF00FF00FF0000FF
FF00FFFFFF0000
FF000000000000FF0000FFFF00FFFFFFFF0000FF000000FF0000FFFFFFFF00FFFF0000FF
000000000000FF
FFFFFF00FFFFFFFF00FFFFFF00FF00000000FFFFFF00FF00FF00000000000000FFFF00FF
FF00FF00FF00FF
FFFFFF000000FF00FF00FF0000FFFFFFFFFFFF00FF000000000000FFFF0000FFFF0000FF
0000FF0000FF00
0000FFFF00000000000000FFFFFFFFFFFF00FFFF00FF0000FF00FF00FF00FF0000FF0000
00FF00FFFFFF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.242063 0.588183 0.41843 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0218531 0.0192308 0.0218531 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
44 string
44 44 8 [44 0 0 44 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.242063 0.782187 0.41843 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0213675 0.0192308 0.0213675 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
45 string
45 45 8 [45 0 0 45 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF000000000000FF0000FFFF000000FFFF00FFFF0000FFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFF0000FF00FFFFFF000000FF0000FF00FF000000FF00FFFFFFFF000000FFFFFF00
FF000000FFFF00FFFF
FF000000FF0000FFFF00FF00FFFFFFFF000000FFFFFFFFFF00FF0000FF00FF00FF00FF00
FFFF00FF0000FFFFFF
FF00FF00000000FF000000FFFFFFFFFFFF0000000000FFFF0000FF0000FFFF0000FF0000
FF00FF00FF00FFFFFF
FF0000FFFFFFFF0000FFFFFF000000FF0000FFFF0000FF0000FFFF000000FFFF00000000
00FFFFFFFFFFFF00FF
0000FFFFFFFF0000FF00FFFFFFFF00FFFFFFFF000000FFFFFF00FF00FF0000FFFFFFFF00
FFFF000000FF00FFFF
FFFFFFFF0000000000000000FFFFFFFF00000000FFFFFFFF00FFFFFFFF0000FF00FFFF00
00FF00FFFFFFFF00FF
FF00FF00FFFF00FF00FFFF00FFFFFF00FF000000FFFF0000FF000000FFFFFFFF00FFFFFF
FF00000000FFFF0000
00FF00000000000000FFFF00FFFF00FF00000000FF000000FFFF00FFFF000000FF00FF00
00FFFFFFFFFFFF0000
FF0000FF00FFFF0000FFFFFF000000FFFFFFFF00FF000000FF0000FF00FFFF00000000FF
0000FFFFFFFF00FF00
00FF0000FFFFFF00FFFF00FF0000FFFFFF000000FFFFFFFFFF0000FFFFFF00FFFFFFFF00
FFFFFF00FFFF000000
000000FF00FF0000FF00000000FFFF00FF00FF00FFFFFF000000000000FF0000FF00FFFF
FF00FF0000FFFF00FF
000000000000FF000000FF0000FFFF0000FFFFFF00FF00FFFF00FFFFFF0000FF0000FFFF
0000FFFFFFFF000000
00FFFFFF00FF0000FFFFFF000000FFFF00FF00FFFF000000FF0000FFFF00FF0000FFFFFF
00FFFF000000FFFFFF
FFFFFF00FF00FF000000FFFFFFFF00000000000000FF000000FF00FFFFFFFFFFFF00FF00
00FF0000FF0000FFFF
0000000000FFFFFF0000FF00FF00FFFFFFFFFFFFFF00FF00FF0000FFFFFFFF00FFFFFF00
FF0000FFFFFF0000FF
000000FFFF00000000FF0000FF00FFFF00FFFF000000FF000000FFFFFFFFFF00FF00FF00
FF00FFFFFF00000000
FF0000FF00FF00FFFF000000FFFF00FF000000FF00FFFF0000FFFF0000FF0000FF000000
00000000FF00FF0000
FFFFFFFF00FFFF0000000000FFFF0000FF0000FF00FF00FF00FFFF0000FF00FFFFFFFFFF
FF0000FFFFFFFFFF00
FFFFFFFF000000FF0000FF00FF00FF00000000FFFF0000FF000000FF0000FF0000FF0000
FFFFFF00FFFFFFFF00
00FFFFFFFFFFFFFF00FF00FF000000FF00FF00FFFF0000FF00FF00FF00FF00FFFFFF0000
FF00FF0000FFFF00FF
0000FF000000FFFF0000FF000000FFFFFF0000FFFF000000FF00FFFFFFFF00FFFF000000
00FFFFFF00FFFF0000
00FF00FFFFFF00FF0000FFFFFF00FFFFFFFF00FFFF0000FFFF0000FFFF00FF00FF00FF00
00000000FF00000000
0000FFFF0000000000FFFFFF00FF0000000000000000FF0000000000FFFF00000000FF00
FFFF00FF0000FFFFFF
FFFFFFFF00FFFFFF000000FFFF00FFFFFFFF00FF000000FFFF0000FFFFFFFFFF00FF00FF
FFFFFF00FFFFFFFF00
FF0000FF00FFFFFF000000FF000000FF0000FF0000FFFFFF00FF0000FFFF0000FF0000FF
00FFFF00FF00FF00FF
0000FF000000FFFF000000FFFF0000000000FF00000000FF00FF0000FF000000FFFFFFFF
FF0000FFFFFFFFFFFF
0000FF00FFFFFF00FFFF00FF0000FF00FF00FF0000FFFFFF00FF0000FFFFFFFF000000FF
0000FFFF000000FFFF
0000FFFF0000FFFF0000FF0000FFFFFFFF00FF00FFFFFF00FFFFFF000000FFFF00FF00FF
FF00000000FFFFFF00
FFFF00FF0000FFFF0000000000FF00FFFF00FFFFFFFF0000FF00FFFF00FFFFFFFFFFFFFF
000000FFFFFF00FFFF
FFFFFF00FFFF00FF000000FFFFFFFF00FF000000FF000000FFFF00FF000000FFFFFF0000
0000FF00FFFF00FFFF
FFFFFFFF00FFFF00FFFFFF00FF00FFFF00FFFF000000000000FFFFFFFF00FF00FFFFFFFF
00FF00000000FFFF00
00FFFFFFFF00000000000000000000FF0000FF00FF0000FF00FFFF00FF00FF0000FF00FF
0000000000FFFFFF00
FFFFFFFFFF00FF00FF000000FFFFFF0000FF000000FF00FFFF00000000FFFF00FF000000
00000000FF0000FFFF
00FF00000000FFFFFFFFFF0000FFFF00FFFFFF00FF00FFFFFFFFFF00FFFF0000FFFF0000
FFFFFF00000000FF00
0000000000FFFFFF00FFFFFFFF00FFFF0000FF00FFFF0000FFFF0000FF000000FFFF00FF
0000FF00FFFF0000FF
FFFF00FF00FFFF000000FF00FFFF00FF0000FF00000000FF0000FFFFFFFF0000FFFFFFFF
000000FFFFFFFFFFFF
FF00FFFF0000FF000000FFFF0000FF000000FF0000FFFFFFFF0000FFFFFFFF00FF0000FF
00FF0000FFFF0000FF
00FF00FF000000000000FFFFFFFF00FFFF0000FF0000FF00FFFFFFFF0000FFFF00000000
000000FFFFFF00FF00
FF0000000000FFFFFF00FFFF0000FFFF00FF00FF000000FFFF00FFFFFFFF0000FF0000FF
00FFFFFFFF00FF00FF
FF000000FFFF00FFFFFFFFFF00FFFFFFFF0000000000FF0000000000FF00000000000000
FF0000FFFF00FF00FF
FFFFFF0000FFFF00FFFFFFFF00FFFFFFFF00000000FF000000FF00FFFF00000000000000
FF0000FFFF00FFFF00
0000FF00FFFFFFFF0000FF00000000000000000000FFFFFFFFFF0000FFFF00FF0000FF00
0000FF000000000000
00FFFFFFFFFFFF0000FF0000000000FFFFFF0000FFFFFFFF00000000FFFFFF00FFFFFFFF
FF00FF000000FFFFFF
FF0000FFFFFF000000FFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF00FFFFFF0000FF000000
0000FFFF00FFFFFF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.242063 0.97619 0.41843 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.020903 0.0192308 0.020903 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
46 string
46 46 8 [46 0 0 46 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF000000000000FFFF00FF0000FF0000FFFFFF00FF00000000FF00000000FF00FF00FFFF
00FFFFFF00FFFF00FFFF
000000FF00FFFF0000FF00FFFF000000FF00FFFF00FFFF0000FF00FFFFFFFFFF00000000
00FFFFFF0000FFFF00FF
00FF000000FF00FF000000FF00FF00FF0000FF00FF00FFFF000000FFFF00FF0000000000
000000FFFFFF0000FF00
FFFFFF0000FF0000FFFF0000FFFF0000000000FF0000FFFF00FF0000FFFF00FFFFFFFFFF
FFFFFFFFFF000000FFFF
00FFFF00000000000000FFFF00000000FF00FFFF00FF000000FF0000FF00FF000000FFFF
FF00FF00FF0000FF00FF
00000000FFFF000000FF00FF0000FFFFFFFFFF0000FFFF00FF00000000FF00FF00000000
FF00FF0000FFFFFF0000
FF00FF000000000000FFFFFFFF00FF00FF000000FFFF00FFFF00FFFFFFFFFF00FFFF00FF
FFFFFF000000FFFFFFFF
00FF00FF00FFFF00FFFFFFFF00FFFF0000FF00000000000000000000FF0000FF000000FF
00FF00FFFFFFFF00FFFF
FFFF000000FFFFFFFFFFFF0000FFFFFFFFFF00FF0000FF00FFFFFFFF0000FF00FFFF00FF
0000FFFF0000FF00FFFF
00FFFFFFFF0000FFFF0000FF000000FF00FFFFFF00FFFFFFFF00FFFFFFFFFF00FFFFFF00
000000FFFFFFFF000000
FFFFFF00FF00FF000000FFFFFF00FFFFFF00FF0000FFFFFFFFFF0000000000FF00FF0000
00FFFFFF00FFFF0000FF
FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FFFFFF00FFFF0000
FF00000000FFFF0000FF
00FF00FFFF00FF0000FF00000000FFFFFFFF00FFFF00FFFF00FF00FF00000000FF00FFFF
FFFF00FF0000FF000000
00FFFF00FF00FFFF0000FFFFFF00FFFFFFFF00FF000000FF00FF000000FFFF0000FFFF00
FFFF00FF0000FF0000FF
FFFF000000FF000000FF00FF0000000000FFFFFFFFFF00FFFFFFFF0000FF0000000000FF
0000FF00FF00FF00FF00
0000FFFF00FFFF0000FFFF0000000000FFFFFF0000FFFFFFFFFFFFFF00FF0000FF00FF00
FFFF00FF00FF00FFFFFF
000000FFFF0000FFFF00000000FFFFFFFFFFFF0000000000FFFFFFFFFF00FFFFFF00FF00
FF0000FFFF00FF00FF00
FF00FF000000FF0000FF000000000000FF00FFFF0000FFFFFF0000FF00FF00000000FF00
FF00FFFF00FFFFFFFF00
0000FF00FF0000FF000000000000FFFFFFFF000000000000FF000000FFFFFF0000FF0000
FFFF00FF000000FFFF00
00FF00FFFF00FFFF000000000000000000FF00FF00FFFF00FF00000000FFFFFF0000FF00
FFFF00FF000000000000
0000FF00FFFF00FFFF00FF0000FFFFFFFFFF00FFFF0000000000000000FFFFFFFFFFFFFF
00FF000000FFFF00FFFF
FFFFFFFF0000FF0000000000FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF0000FFFF
FFFF00FFFF0000000000
FFFF00000000FF000000FF0000FFFFFFFF0000FF0000000000000000FF00FFFFFFFFFFFF
FF0000FF0000FFFF0000
FF00FFFFFF0000000000FFFFFF0000FF00FFFFFFFF0000000000FF00FF00FF0000FFFFFF
FFFF0000FF00FFFFFF00
FF00FFFF00FFFFFF0000FFFFFF0000000000FFFFFF0000000000FF000000FFFF000000FF
FF0000FFFFFF0000FF00
0000FFFFFF00000000000000FFFFFFFFFFFFFF0000FFFF00FFFF0000000000FF00FF0000
000000FF000000FF00FF
FFFFFF00000000FF000000FFFFFFFF000000000000FFFFFFFFFFFF00FF0000FFFFFFFF00
FFFF000000FFFF00FF00
00FFFFFF00000000FF0000FFFFFFFFFFFF000000FFFFFF00FF000000FFFFFFFF0000FFFF
FF000000FFFF00FFFFFF
0000FFFFFFFF00FF00000000FF0000FFFF000000FF00FF00FFFFFFFF00FFFFFFFFFFFF00
FFFFFF00FF00000000FF
FFFFFFFF000000FFFF000000FFFF00FF00FFFF00FF0000FFFFFF00FFFFFFFF00FFFFFFFF
00FF00FFFFFF0000FFFF
FFFFFF00FFFFFF0000FF0000FF000000FFFFFF00FF00FFFFFFFF00FF00FF0000FFFFFFFF
FFFF0000FF0000FF0000
00000000FF00FF00000000FF000000000000FFFFFF0000FFFFFF00FF00FF0000FFFFFFFF
00FFFFFFFF0000000000
FFFFFFFF000000FF00FFFFFFFF000000FF00FFFFFF0000FFFFFF000000FF00000000FF00
00FFFF000000FFFF00FF
FFFFFF00FFFFFF00FFFF00FF00FF00FFFFFFFFFFFFFFFF00FF00000000000000FF00FFFF
000000FF0000FF00FF00
00FFFF000000000000FFFF00FFFFFF000000FFFF00FFFF0000000000000000FFFF00FFFF
FF00FFFFFFFF00FFFF00
FFFF00FFFF0000FFFF0000FF00FF00000000000000FFFFFF00FF00000000FF00FF00FFFF
00FFFFFF00FF000000FF
0000FFFFFF00FFFFFF0000FFFFFF00FF000000000000000000000000FF00FFFF00FFFF00
00FFFFFFFF00FF00FF00
00FF00FF000000FF00FFFF00FF000000FF00FF000000000000FF000000FF00000000FF00
FFFFFF000000FF0000FF
0000FF00FFFFFF00FFFFFF0000FF0000FFFF00FF00FF000000FFFFFF00FF0000FF00FF00
FFFF0000000000FF00FF
00FF00FFFF0000FF00FF0000FF00FFFF0000000000FF00FFFF00FF00FF00FF00FFFF00FF
00FFFF0000000000FF00
FFFFFF00FF0000FF00000000FF0000FF00FF000000FF000000FF00000000FFFF00000000
00FFFF00FF00FFFFFF00
FFFFFF0000FFFFFF00FFFF00FF00FFFF00FF0000FF00FF0000FFFFFF00FF0000FFFF00FF
FF000000FF0000000000
00FFFF000000FF00FFFFFF0000FF0000FFFFFF00FFFFFF00FF00FF0000FFFF0000FF0000
FF00FF0000000000FF00
FF0000FFFFFF00FF00FF00FFFFFF00FFFFFFFFFFFFFFFF00FFFF00FFFF00FF00FF0000FF
FF0000FF00FFFF000000
000000FFFFFFFF00FF00FFFFFFFF00FFFF00FFFF000000FFFF00FF00000000FFFFFF00FF
FFFFFF0000FFFFFF0000
0000FF00FFFF00000000FF00FFFF00FFFF0000FF00FFFFFFFF000000FF0000FF0000FFFF
00FF00FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.436067 0.200176 0.612434 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0259875 0.0192308 0.0259875 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
37 string
37 37 8 [37 0 0 37 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00000000000000FFFF0000FF00FFFF00FFFFFF00FF00000000FF00000000FF00FF00
FF
FF0000FF00FF00FFFFFF00FF000000FFFF000000FF0000FFFFFFFFFF0000FFFFFFFF00FF
00
00000000FFFFFFFF00000000FF0000FF000000FFFF00FF0000FFFF0000FF0000FF000000
00
00FF0000FFFF00FF00FFFFFF00FFFFFF00FFFF0000FF00FFFF00FFFF00FFFFFF00FF0000
00
0000FFFF000000FFFFFF00FF00FF000000FF0000FFFFFFFF00FFFFFFFF0000FF0000FFFF
00
00FFFFFF0000000000FFFF0000FFFF00FFFFFF00000000FFFF00FF0000FF00FF000000FF
00
0000FF00000000FFFFFF00FF00FF00FF000000000000FFFF0000FF00FFFF0000FFFFFF00
FF
00FFFFFFFF00FF00FF00FFFF00FFFF00FFFF0000FFFFFF00FF000000FF00FFFFFFFFFF00
FF
00FF0000FF00FFFF00FFFF00FF00FFFF00FF00FF0000FF0000000000FF00FFFFFFFF00FF
00
FFFF00FFFFFFFF00FF00FF0000FFFF00FFFFFF00FFFF00FFFF0000000000FFFFFFFF0000
00
FF0000FF00FF00FFFFFF000000FFFF000000FF0000000000FF00FFFFFFFF000000FFFFFF
FF
00FF00FFFF00FFFF0000000000FFFF00FFFFFFFFFFFFFFFF000000FF00FF000000FF0000
FF
0000FF0000000000FF00000000FFFFFF00FFFF00FF00FFFF00FFFFFF00FFFFFF0000FFFF
FF
FF0000FFFFFFFFFF00FFFFFFFF000000FF00FFFFFF0000FFFFFFFFFFFF000000FFFF0000
00
000000FF00FF00FFFFFFFFFFFF0000FF000000FFFFFFFFFFFFFF00FFFF00FF00FFFF0000
00
FFFFFFFF0000FF00FF000000FF00FF00FF0000FFFFFF0000FFFF00FF00FFFF00FFFF0000
00
FFFF000000FF00FF00FF00FF00FF00FF00FFFF00FF00FF000000FFFF0000FF00FFFFFF00
FF
000000FFFFFF00FFFFFF00FFFF000000FF0000FFFF00FF000000000000000000FFFFFFFF
00
FF0000FF00FF000000FFFFFFFFFF0000FF0000000000000000FF00FF00FFFF000000FF00
00
FF00FF0000000000FF0000FF00FFFFFF00FF0000FFFF000000FFFFFFFF00000000000000
00
FFFFFF00FF0000FF00FF00FFFFFFFFFFFFFF00FF0000FF000000FF000000FFFF00FFFF00
FF
000000FFFF0000FF00FF00FF0000FFFF000000FF00000000000000FFFFFFFFFF0000FFFF
FF
FF00FF00FF00FFFFFF0000FFFF00FF00FFFF0000FF000000000000FF00FF00FFFFFFFFFF
FF
00FF00FFFFFFFF0000FF00FFFFFFFF00000000000000000000FF00FF00FFFFFFFF000000
FF
00FF00FF00FF00FF00FFFF0000FFFFFF00000000000000000000FFFF00FF00000000FFFF
00
00FFFF00FF00000000000000FFFFFFFF0000FFFF000000FF0000FFFFFF00FF00000000FF
00
00FFFFFFFFFFFF000000FF00FFFF0000FF0000FFFF000000FFFF0000FFFFFFFFFFFFFF00
00
FFFF00FFFF0000000000FFFFFFFFFFFFFF00FFFF00FFFFFFFFFF000000FFFF000000FFFF
00
00000000FF00FFFFFF00FF0000FFFF00000000FF00FF000000FFFF00000000FF00FF00FF
00
0000FFFF00FFFF000000FFFFFF0000FF0000FF0000FFFFFFFF00FFFF0000FFFFFFFF0000
FF
00FF00FF000000FFFFFF0000FF00FFFFFF00FF00FFFF00FF00FFFFFF00FF0000FFFF0000
00
00FF00FFFFFF00FFFFFF0000FF00000000000000FFFFFFFF0000FF00FFFF0000FFFFFFFF
00
FFFFFF000000FFFFFFFF000000FFFFFFFFFF00000000FFFF0000FF0000FFFFFF0000FFFF
FF
00FF00FF0000FFFFFFFFFFFF00FFFFFFFFFF0000FF00FF000000FF00FFFFFFFF00000000
00
FF000000FF00FFFF0000FF00FF000000FFFFFF00FFFFFF00FF00FFFF000000FFFF0000FF
00
00FF0000FFFF0000FF00FF00FF00000000FF000000FFFF00FFFF00FFFF0000FFFF00FF00
00
FF0000000000FFFF0000FFFFFF000000FF000000FFFFFFFF0000000000FF0000FF000000
FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.436067 0.39418 0.612434 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0253036 0.0192308 0.0253036 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
38 string
38 38 8 [38 0 0 38 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000000000000000FFFFFF00FF0000FF0000FF0000FF000000FF00FFFF00FF00FF0000
FFFF
FFFFFFFF0000FFFF0000000000FFFF0000FF000000FF00FFFF00FFFFFFFFFF00FF00FF00
00FF
00FF00FFFFFF0000FF0000FFFFFF0000FFFFFFFFFF00FF0000000000FF0000FFFF00FF00
0000
00000000000000FFFFFFFFFF00FFFF0000FF00FFFF00FFFFFF0000FF00FF00FF000000FF
FF00
000000FF000000FFFFFFFF00000000FFFF0000FF000000000000FFFFFFFFFFFF00000000
00FF
00FFFF0000FF00FF0000FF00000000FFFFFFFFFFFFFFFFFFFFFF000000000000000000FF
FF00
FFFFFFFFFF00000000FFFF0000FFFFFF00FFFF00FF00FF000000FFFFFF00FF0000FFFFFF
00FF
00FFFF0000FF00000000FF00FFFF00FF00FF0000FF00FFFF000000FFFFFF00FF00FF0000
FF00
FFFF00FFFFFF0000FF00FFFFFFFF00FFFFFF0000FFFF00FF00FF00FFFF00FF0000FFFF00
FFFF
FFFFFFFFFFFF000000FF0000000000FF00FFFF0000FFFF00000000FF00FFFFFF00FF00FF
FFFF
FF000000FF0000FFFF0000FF000000FFFFFFFFFF00FF0000FF000000FFFFFFFF00FFFF00
FF00
FF00FF00FF0000FFFF0000FFFFFF000000FF0000FFFF00FF00000000000000FF00FF0000
FFFF
FFFFFFFF0000FF00FFFFFF000000FFFF00FFFF00FFFF00000000000000FF0000FF000000
0000
0000FF0000FFFFFFFFFFFF00FFFFFFFFFF0000FFFFFF0000000000FF00000000FF00FF00
FF00
0000FFFF0000FFFF00FFFFFF000000FFFF00000000FFFF000000FF0000FFFF00FF00FF00
FF00
FF00FF000000FFFFFFFFFF000000FFFFFFFFFF00000000FF00000000FF00FFFFFF00FFFF
00FF
0000FF0000FFFF00FFFF0000FF00000000000000000000FFFFFFFFFFFFFF0000FF000000
FF00
00FF000000FFFFFFFFFF00FF00FF0000FF0000FF00000000FFFFFF0000FFFFFFFF00FFFF
0000
00FF0000FF00FF00FF000000000000FFFF000000FF000000FF0000FF00000000FFFFFFFF
00FF
00FF0000FFFFFF0000FFFFFF00FFFF00FFFF00000000FF0000FF00FFFF0000FFFF0000FF
0000
FF00FFFF00FF00FF00000000FF0000000000FF000000FF0000FFFFFFFFFFFFFFFF00FFFF
FF00
FF0000FF00FF0000FFFF0000FF00FF000000FFFFFF00FFFFFF0000FF00FF0000FFFF00FF
00FF
FF00FF0000FF00FFFFFFFFFF00FFFF00000000FF0000FFFFFFFF00FFFFFFFFFFFFFF0000
0000
FF0000FF0000000000FFFFFF000000FFFF00FF000000FF00FFFF0000000000FF0000FF00
FF00
00FFFFFFFFFF000000FF0000000000FF0000FF00FF000000FF00FF0000FFFFFF0000FFFF
FFFF
FFFF0000000000FFFFFFFF0000000000FFFF000000FF0000FF00FF0000FFFF00000000FF
0000
FFFFFF000000FFFF00FFFF000000FFFF0000FF00FF0000FF0000FFFF00FF00000000FFFF
00FF
FF0000FFFFFFFF00FF0000FFFF00FFFF0000FF000000FFFFFFFF000000FFFFFFFFFFFF00
00FF
FFFFFFFFFF0000FFFF0000FFFFFFFFFFFF00FF00FFFFFFFFFFFF0000FF0000FF00FFFF00
00FF
FF00FF000000000000FFFF00FF0000FFFF0000FFFFFFFF00FFFFFFFF00FF000000FFFFFF
0000
00FFFF0000FF000000FF00FFFF0000FF00FF0000FF00FFFFFF00FFFF00000000FFFFFF00
FF00
FFFF00FF00FF00000000FFFF000000000000FFFFFFFFFFFFFFFF00000000000000000000
FF00
00FF00000000FFFF0000FF0000FF00FFFFFFFF00FFFF0000FF000000FFFFFF00FF0000FF
0000
0000FF000000000000FFFF0000FF00000000FFFF000000000000FFFFFFFF00FF000000FF
0000
0000FF000000FF0000FFFF0000FFFF00FFFF0000000000FF00FF0000FFFF00FF00FF00FF
FF00
FF0000FFFF0000FFFFFF00FF00FF00FF00FF000000FFFFFFFFFFFF00FF00FFFFFF000000
FF00
FF00000000FFFFFF00FF00FFFFFF00000000FFFFFF00000000FF0000FFFFFFFFFF0000FF
FF00
00FFFF000000FF00FFFFFFFFFF00FFFFFFFF00000000FF0000FFFFFFFFFF00FF00000000
FFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.436067 0.588183 0.612434 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0246548 0.0192308 0.0246548 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
39 string
39 39 8 [39 0 0 39 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFF00FF00FF000000FFFF00FF00FF00FFFF0000FF0000FF00FF0000FF00FF0000FF
FF00FF
0000FF00000000FF0000000000FFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFF000000
FF0000
0000FF000000000000FFFFFF00FF00FF0000FFFF000000FFFFFFFF00FF00FFFF0000FFFF
FF0000
FFFF00FF00FF00FFFFFF00FFFF00FFFFFFFFFF00FFFFFFFFFFFF0000FF00FFFF00FF00FF
FFFFFF
00FFFF0000FFFF00FFFFFFFFFF00FFFFFFFF00FFFF00FF0000FF00FFFF00FFFF00FF0000
00FF00
0000000000FFFFFFFF00000000FFFF0000FFFF0000000000FFFF0000FF00FFFFFFFF0000
0000FF
00FFFFFFFF00FFFF0000FF00FFFFFF00FF0000FFFF0000FF000000FFFF00FFFFFF0000FF
FF00FF
0000FFFF00FFFF00FFFF0000FFFF00FF00FF00FFFFFF00FFFFFF000000FF0000FFFFFFFF
0000FF
FF00000000FFFFFFFF000000FFFFFF00FFFF0000FFFFFF0000FFFF0000FFFF0000FF0000
FFFF00
00FF0000FF0000FFFF00FFFFFF00FFFF0000FFFFFFFF00FF00FF00FFFF0000FF000000FF
FF0000
00FFFF00FFFF00000000FF00FF00FF00FFFFFF00FFFFFF00FFFFFFFFFF0000000000FFFF
FFFF00
FFFFFF00FFFFFF00000000FFFF0000FF000000FF00FF00000000FFFFFF00000000FFFFFF
0000FF
00FFFFFF00FFFF0000FF00FFFFFFFFFFFFFFFF0000FF000000FFFFFF000000FF00FFFF00
0000FF
FFFF0000FF0000FF0000FFFF000000FFFF00FF0000FF00FF000000FF00FF00FFFF0000FF
00FF00
FFFF00FF0000FF000000FFFF00FFFF0000FF00000000FFFFFFFFFFFFFFFFFFFF0000FFFF
FFFF00
00FF00FFFF00FFFFFF00FFFF00FF0000FFFF0000FF00FF00FFFFFF00FF00FFFF000000FF
00FF00
FF0000FF000000FFFFFFFFFF00FF000000FF00FFFF000000FF00FFFFFFFFFFFFFF0000FF
0000FF
0000FFFF00FF000000FF0000FF0000FFFF00FFFF00000000FFFFFFFF000000000000FFFF
FFFF00
FFFF0000FFFFFFFFFF00FF00FFFFFFFF00FFFFFFFF00FF00FF000000FF00000000000000
FFFF00
000000000000000000000000000000000000000000000000000000000000000000000000
000000
FFFF0000FFFFFFFFFF00FF00FFFFFFFF00FFFFFFFF00FF00FF000000FF00000000000000
FFFF00
0000FFFF00FF000000FF0000FF0000FFFF00FFFF00000000FFFFFFFF000000000000FFFF
FFFF00
FF0000FF000000FFFFFFFFFF00FF000000FF00FFFF000000FF00FFFFFFFFFFFFFF0000FF
0000FF
00FF00FFFF00FFFFFF00FFFF00FF0000FFFF0000FF00FF00FFFFFF00FF00FFFF000000FF
00FF00
FFFF00FF0000FF000000FFFF00FFFF0000FF00000000FFFFFFFFFFFFFFFFFFFF0000FFFF
FFFF00
FFFF0000FF0000FF0000FFFF000000FFFF00FF0000FF00FF000000FF00FF00FFFF0000FF
00FF00
00FFFFFF00FFFF0000FF00FFFFFFFFFFFFFFFF0000FF000000FFFFFF000000FF00FFFF00
0000FF
FFFFFF00FFFFFF00000000FFFF0000FF000000FF00FF00000000FFFFFF00000000FFFFFF
0000FF
00FFFF00FFFF00000000FF00FF00FF00FFFFFF00FFFFFF00FFFFFFFFFF0000000000FFFF
FFFF00
00FF0000FF0000FFFF00FFFFFF00FFFF0000FFFFFFFF00FF00FF00FFFF0000FF000000FF
FF0000
FF00000000FFFFFFFF000000FFFFFF00FFFF0000FFFFFF0000FFFF0000FFFF0000FF0000
FFFF00
0000FFFF00FFFF00FFFF0000FFFF00FF00FF00FFFFFF00FFFFFF000000FF0000FFFFFFFF
0000FF
00FFFFFFFF00FFFF0000FF00FFFFFF00FF0000FFFF0000FF000000FFFF00FFFFFF0000FF
FF00FF
0000000000FFFFFFFF00000000FFFF0000FFFF0000000000FFFF0000FF00FFFFFFFF0000
0000FF
00FFFF0000FFFF00FFFFFFFFFF00FFFFFFFF00FFFF00FF0000FF00FFFF00FFFF00FF0000
00FF00
FFFF00FF00FF00FFFFFF00FFFF00FFFFFFFFFF00FFFFFFFFFFFF0000FF00FFFF00FF00FF
FFFFFF
0000FF000000000000FFFFFF00FF00FF0000FFFF000000FFFFFFFF00FF00FFFF0000FFFF
FF0000
0000FF00000000FF0000000000FFFFFFFFFFFFFFFF00FFFFFFFFFFFF00FFFFFFFF000000
FF0000
0000FFFF00FF00FF000000FFFF00FF00FF00FFFF0000FF0000FF00FF0000FF00FF0000FF
FF00FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.436067 0.782187 0.612434 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0240385 0.0192308 0.0240385 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
40 string
40 40 8 [40 0 0 40 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00FF00FF00FF0000FFFFFFFF00FF000000FF00FFFF0000FF00FF0000FF00FFFFFF00
FFFFFFFF
000000FFFFFFFFFF00FF00FFFFFF0000FFFF00FFFFFFFFFF0000FFFFFF00FF00FF00FFFF
000000FF
FFFFFF0000FFFFFFFFFF0000FF0000FF00FFFFFF0000FF0000000000FF00000000FF00FF
000000FF
FFFFFFFF00000000FF00FF0000FF00FFFFFFFF0000FF000000FFFFFF0000FF00FF00FFFF
000000FF
0000FFFFFFFFFF00000000FFFFFF0000FF0000FFFFFF00000000FFFF00FFFF00FFFF0000
FFFFFF00
0000FF000000000000FF00FFFFFFFFFFFF0000FFFFFF000000FFFF00FFFF0000FF000000
FF00FFFF
00FFFF000000FF0000FF0000FFFF00FFFF00FFFF0000FFFF00FFFFFF0000FF00000000FF
00FF00FF
FF00FF0000FFFF0000000000FF0000FF00FFFFFF00FF00FF00FFFF00000000FF0000FFFF
FF00FFFF
FF00FFFF00000000FFFFFF000000FF00FFFF00FFFF00FFFF00FFFF0000000000FF000000
00000000
FF00000000FF00FF0000000000FFFF0000FFFF0000FF00FFFF0000000000000000FF00FF
FF00FFFF
0000FF00FF00FF0000FF00000000000000FFFF00FF00FFFF00000000000000000000FFFF
00000000
FF000000FF0000FF00FF0000FF00FFFFFFFF00FFFF00FF00FF0000FF000000000000FF00
00FFFF00
FF0000FF00FF00FFFF000000FF00FF00000000FF00FF0000FFFF0000FF00000000FF00FF
FF00FFFF
0000FF0000000000FF00FF0000FFFF000000FF00FF00FFFF00000000000000FFFFFFFFFF
FF00FF00
FFFF00FFFF00FF0000FFFF00FF0000FF00FFFFFFFF000000FF0000FF000000FFFFFFFF00
FF0000FF
0000FF0000FF000000FFFF00FF00FF0000000000FFFFFFFF00FF00FFFF00FF0000000000
00000000
000000FF00000000FFFFFF0000FF0000FFFF00FF00FF0000FF00FF0000FFFFFFFFFF0000
0000FF00
FF00FFFFFF000000FFFF00000000000000FF00FFFFFF0000FF00FF00FFFF00FF00FF0000
00FFFFFF
0000FF0000FFFFFFFF00FF00FF00FF000000FF00FF00FFFFFF0000FF0000FF00FF00FFFF
FF00FFFF
00FFFF00000000FF0000FF00FFFFFFFF00FF00FF00FFFF00FFFFFF00FFFF00FF0000FFFF
0000FF00
FF00FF0000FFFF0000FFFFFF00FFFF00FF00FF00FF00FFFF00FF00FFFF0000FFFFFFFFFF
00FFFFFF
00FFFF00FFFFFF0000FFFFFFFF00FFFFFF0000FF00FF000000FFFF0000FFFF00FFFF0000
FFFF0000
0000FF00FF0000000000FFFF00FF00FFFF000000FF00FFFF00FF0000FFFFFFFFFF000000
FFFFFF00
FF0000000000FFFFFFFFFF00FFFF000000FFFFFF000000FF00000000FF0000FF00FFFFFF
FF00FF00
00FF0000FFFFFF00FFFF00FFFF00FF0000FFFF00FF00000000FF0000FF000000FFFFFF00
FFFF00FF
000000FF000000FF00FF0000000000FF0000FFFFFFFF0000FF00FFFFFF00FFFF0000FF00
00000000
00FFFF00FF00000000FF0000FF000000FFFF00FFFF0000FF0000FF000000FF0000FFFFFF
FF00FFFF
0000FF00FF00000000FF00FF00FF00FFFF00FF00FFFF0000FFFF00FFFF000000FFFFFFFF
00FFFFFF
FFFF0000FFFFFFFFFF00FF00FF0000FF00FFFFFF0000000000000000000000000000FFFF
0000FFFF
000000FFFFFF00FF00FF00FF00000000FFFFFFFFFFFF00FFFFFFFF00000000FF00000000
FF0000FF
0000FFFF00FF00000000FF00FFFFFFFFFF00FFFF0000FFFFFFFF0000FFFF00FF00FFFF00
00FFFF00
00FFFFFFFF00FF00000000FF000000FFFF00000000FFFFFF0000FFFF000000FF00000000
FFFF0000
00FF00FF000000000000FFFF0000FF00FF000000FFFF0000000000FFFF00FF0000000000
00FFFFFF
FFFFFFFFFFFF0000FF0000FF000000FFFF00FFFF00FF000000FF000000FF0000FFFF00FF
00FFFF00
00FF00FFFF00FF0000FFFFFF000000FF0000FFFF00FF0000FF0000FF0000FF00FF0000FF
00FFFFFF
FF00FF0000FFFF00FF00FFFFFFFF00FF00FFFF000000FF0000FF0000FFFF0000000000FF
0000FF00
00FF000000FFFFFFFFFFFF000000FF00000000000000FFFF00FF00FF000000FF000000FF
FF00FFFF
FF000000FF00FF00FFFF0000FFFF000000FFFFFFFFFFFF00FF00FF0000FF00FFFFFFFFFF
FFFF0000
FF0000FF00FFFFFFFF0000FF00FF00FF0000FF00FF00000000FF00000000000000FF0000
FFFF00FF
00FFFF00FF00FF00000000FF00000000FF0000FF0000FF0000FF00FFFF00FFFFFF000000
FFFF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.436067 0.97619 0.612434 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0234522 0.0192308 0.0234522 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
41 string
41 41 8 [41 0 0 41 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000FF0000FF00FFFFFFFFFFFFFFFF0000FF0000FFFFFF0000FF000000FFFFFFFF00FF
FFFFFF00FF
00FF0000000000FFFFFF00FF00FF00FF00FFFF0000FFFF000000FF00FFFF0000FFFFFF00
000000FF00
00FF00000000FFFFFFFFFFFF0000FF000000FFFFFF0000FF0000000000FF000000FF0000
FFFF00FFFF
FF00FFFF0000FF00000000FF00FF0000FFFFFFFFFFFF00FF0000FFFFFF000000FF00FF00
00FF0000FF
0000FF0000FFFFFFFF00FF00FF000000FFFF000000FFFF00FF0000000000FFFFFFFFFFFF
00000000FF
00000000FFFFFFFF00FF000000FF00FFFF000000000000FFFF00FF00FFFFFFFFFFFFFFFF
FF000000FF
FFFF00FFFF00FFFF000000FF00FFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF0000FFFF00
FFFFFF0000
000000FFFF0000FFFF00FFFF00FFFFFF00FF00000000FFFFFF00FFFF00FFFF00FFFF0000
FFFF0000FF
FFFF00FFFF00FF0000FFFF00FF000000FFFFFF00FFFFFF000000FFFFFF0000FF0000FFFF
FF00FFFFFF
FFFF00FF00FFFFFF00FF0000FFFF00FFFFFFFFFFFF00FFFF00FF00FF0000FFFF00FFFFFF
FFFFFF00FF
0000000000FF00FFFF00FF0000FF00FF000000FF00FFFF00FFFF00000000FFFF00FFFF00
0000FF0000
0000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FF00FF00FF00FF0000FF00FFFFFFFF0000
FF00FF00FF
0000FF00FF00000000FFFFFFFFFFFF00FFFFFFFFFF0000FF00FFFFFFFF00FF000000FFFF
00FFFFFFFF
FF00FF00FF0000FF0000FF00FF00FFFF00000000FFFFFF000000FF00FFFF0000FFFFFFFF
FF00FFFF00
FF00FF0000FFFF000000FFFFFFFF0000000000000000FF00FFFF00FFFF00FF00FF000000
00FF00FFFF
00FFFFFF00FF0000FFFFFFFFFF00000000000000FFFF00000000FFFF00FFFFFFFFFF0000
00FFFF00FF
FF0000FF00FF000000FFFFFFFFFF00000000FF00FF0000000000FFFF00000000FFFF00FF
00000000FF
FFFFFF000000FFFF000000FF000000FFFFFFFF000000FFFFFFFF000000FF0000FFFFFFFF
FF00000000
FF00FFFF00FF00FFFFFF00FF00FFFF0000FFFF00FFFFFFFFFF000000FFFFFFFFFF00FFFF
FF000000FF
FF00FFFF0000FFFFFFFF00FFFF0000FF00FFFF00000000FF000000FF00FF000000FFFF00
FFFF00FF00
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000
FF00FFFF0000FFFFFFFF00FFFF0000FF00FFFF00000000FF000000FF00FF000000FFFF00
FFFF00FF00
FF00FFFF00FF00FFFFFF00FF00FFFF0000FFFF00FFFFFFFFFF000000FFFFFFFFFF00FFFF
FF000000FF
FFFFFF000000FFFF000000FF000000FFFFFFFF000000FFFFFFFF000000FF0000FFFFFFFF
FF00000000
FF0000FF00FF000000FFFFFFFFFF00000000FF00FF0000000000FFFF00000000FFFF00FF
00000000FF
00FFFFFF00FF0000FFFFFFFFFF00000000000000FFFF00000000FFFF00FFFFFFFFFF0000
00FFFF00FF
FF00FF0000FFFF000000FFFFFFFF0000000000000000FF00FFFF00FFFF00FF00FF000000
00FF00FFFF
FF00FF00FF0000FF0000FF00FF00FFFF00000000FFFFFF000000FF00FFFF0000FFFFFFFF
FF00FFFF00
0000FF00FF00000000FFFFFFFFFFFF00FFFFFFFFFF0000FF00FFFFFFFF00FF000000FFFF
00FFFFFFFF
0000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFF00FF00FF00FF00FF0000FF00FFFFFFFF0000
FF00FF00FF
0000000000FF00FFFF00FF0000FF00FF000000FF00FFFF00FFFF00000000FFFF00FFFF00
0000FF0000
FFFF00FF00FFFFFF00FF0000FFFF00FFFFFFFFFFFF00FFFF00FF00FF0000FFFF00FFFFFF
FFFFFF00FF
FFFF00FFFF00FF0000FFFF00FF000000FFFFFF00FFFFFF000000FFFFFF0000FF0000FFFF
FF00FFFFFF
000000FFFF0000FFFF00FFFF00FFFFFF00FF00000000FFFFFF00FFFF00FFFF00FFFF0000
FFFF0000FF
FFFF00FFFF00FFFF000000FF00FFFFFFFFFFFFFFFFFF00FFFFFF0000FF00FF0000FFFF00
FFFFFF0000
00000000FFFFFFFF00FF000000FF00FFFF000000000000FFFF00FF00FFFFFFFFFFFFFFFF
FF000000FF
0000FF0000FFFFFFFF00FF00FF000000FFFF000000FFFF00FF0000000000FFFFFFFFFFFF
00000000FF
FF00FFFF0000FF00000000FF00FF0000FFFFFFFFFFFF00FF0000FFFFFF000000FF00FF00
00FF0000FF
00FF00000000FFFFFFFFFFFF0000FF000000FFFFFF0000FF0000000000FF000000FF0000
FFFF00FFFF
00FF0000000000FFFFFF00FF00FF00FF00FFFF0000FFFF000000FF00FFFF0000FFFFFF00
000000FF00
000000FF0000FF00FFFFFFFFFFFFFFFF0000FF0000FFFFFF0000FF000000FFFFFFFF00FF
FFFFFF00FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.630071 0.200176 0.806437 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0300481 0.0192308 0.0300481 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.630071 0.39418 0.806437 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0291375 0.0192308 0.0291375 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
33 string
33 33 8 [33 0 0 33 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFF000000000000000000FF00000000FF000000FFFFFF0000FFFF00FFFF
00FFFF0000FFFFFF00FF000000FF0000000000FFFF0000FFFF0000FF0000FF00FF
00FFFF000000FFFF000000FF0000FF00FFFF00FFFF0000FF0000FFFFFFFF00FF00
00FF0000000000FF00FFFFFF0000FF00FFFF00FF0000FF00FFFFFF000000FF00FF
000000FF0000FFFFFFFF00FF00FF00FFFFFF000000FFFFFF00FFFFFF0000FF00FF
FF00FFFFFFFFFF000000FFFF00FFFFFF00FFFFFF00FF0000FFFFFF00FF00FFFF00
FFFF00000000FFFFFF00FFFF0000FFFFFF0000FF00000000000000FFFFFFFF0000
FFFFFF00FFFFFFFF0000FFFFFF00FFFF00FFFF0000000000000000FFFFFF0000FF
0000FFFF0000FF0000FF00FF00FF00FFFF00FFFFFF00FFFF000000FF00FF00FFFF
0000FFFF00FFFF0000FF000000FFFF0000000000FF000000FF000000FF00FFFFFF
00FF00FF00FFFF000000FF00FF00FF0000FF000000FF0000FF000000FFFF000000
0000FF000000FFFF00FFFFFFFF000000FF0000FFFF00FF00000000FFFF00000000
FF00FFFF000000FF00FF00FFFF0000FF00FF00FF00FF00FFFF0000000000FFFF00
00FFFF000000000000FFFFFFFFFF0000FF00FF00FFFF0000FF00FFFF00FFFFFFFF
FFFF000000FF000000FFFFFFFF00FF00000000FF00000000FFFF00FF0000000000
00FFFF0000FFFF00FFFF0000FF00000000000000FF00FF0000FF00FFFFFFFF0000
000000FF00FFFFFF00FF00FFFF00FFFF000000FF00FF0000FF00FF00FFFFFF0000
FF0000FF0000FFFFFFFF00FF00FF0000FF000000FF000000FFFFFFFFFF00000000
FFFFFFFF00FFFFFFFF00FFFFFFFF0000FF00FF000000FFFF00FFFFFF00FFFF00FF
00000000FF0000FF000000000000FFFF000000FF000000FFFF0000FFFF0000FF00
00FF00FFFF0000FFFFFF00FF0000FF00FFFFFFFFFFFFFF0000FF00000000000000
FF00FFFF00FFFFFF00FFFF00FF00FFFFFF00FFFFFFFF0000FFFFFFFFFFFFFF0000
FFFFFFFF000000FFFFFF00FF0000FF000000FFFF00FFFF0000FFFFFF00FF000000
FF00FFFFFF00FFFF0000FFFFFF0000FFFFFFFFFFFFFF00FFFF000000FFFF00FF00
FF000000FFFF00FF0000FF00FF00FFFF00FF0000000000000000FF00FF00000000
0000FFFFFFFFFF00FFFFFFFFFFFFFFFFFF000000FFFF000000FFFF00FFFFFFFF00
000000FF00FF00FF00FF00FF0000FFFFFFFF000000FFFFFFFFFFFFFFFF00FFFF00
FF000000FF00FFFFFF0000FF0000FF00FFFFFF000000FFFF00FF00FF000000FF00
FF00FFFF00FF00FFFFFF0000FFFF0000000000000000000000FF00FF00000000FF
FF00FF00FF00FFFF00FFFFFFFF00FFFFFF000000FF00FFFFFF0000FFFF000000FF
FFFF00FFFF0000FF00FFFFFF0000FF0000FF00FFFFFF00FFFFFF00FF0000FFFF00
FF00FF00000000000000FF00FF00FF0000FFFFFF0000FF0000FFFF0000FFFFFFFF
00FFFFFFFFFF0000FFFFFFFF0000FFFF0000FF00FF00000000FFFFFF00000000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.630071 0.588183 0.806437 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0282805 0.0192308 0.0282805 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
34 string
34 34 8 [34 0 0 34 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF0000000000FFFFFF00FF00FFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFF00FF00FF00FF0000FF00FF00FF000000FFFF0000FF0000FFFF0000FF00
00FF0000FFFFFF00FFFFFF000000FFFF0000FF00FFFF00FF000000FFFFFFFF00FFFF
FF0000000000FF00FF00FF00FFFFFF000000FF00FFFF00FFFF0000FF0000FFFFFF00
FFFF0000FFFF00000000FF00FF00FFFF0000000000FF00FF00000000FF000000FF00
FFFFFF0000000000FF00FFFFFFFF00FF000000FF000000000000FFFF00FF00FF0000
0000FFFFFFFF00000000FF000000FF00FFFF0000FF00FF00FF00000000FF00FFFF00
FF000000FFFFFFFFFF00FF00000000FFFFFFFFFF00FF00FF00FF00FF0000FF00FF00
FF0000FF00FFFFFF0000FF000000FF0000FFFF00FFFF000000FFFFFF00FFFF000000
FF00FFFF000000000000FF00FF0000FFFF0000FF0000FFFF00FFFFFF00FF00FF00FF
FFFF00FF00FF00FF000000FFFFFF00FFFFFFFFFF0000FF00000000FF00000000FF00
FF0000FFFFFFFFFFFF00000000FF0000FF00FF0000FFFFFF00FFFF0000FF000000FF
00FF00FF00FFFFFF00000000FF0000FFFF00FF00FF00FF0000FF00FF00FFFF0000FF
0000FF00FFFF0000FF00FF000000FFFF00FF0000FFFF0000FF00FFFF0000FFFFFFFF
FFFF0000FF0000FFFF0000FF000000FF0000FFFFFFFFFF00FFFF00FFFFFF00FF00FF
FF00FF00FF00FF0000FF000000FFFFFFFFFFFF00FF0000FF0000FF00FF0000FFFFFF
00FFFF000000FFFFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF0000
FFFFFF00FF0000FF00FF0000FFFF00FF0000FFFFFFFFFF00FF000000FF0000FF00FF
FFFFFFFFFF00FF00FFFF000000FFFF00FFFF0000FF0000FF00FFFF00FF00FFFF00FF
00FFFF00FFFFFF00FF00FF00FF0000FFFFFFFFFFFF0000FFFFFFFF0000FF00000000
0000FFFF00FF000000FF00FF00FF00FFFF0000FF00FFFFFF00FFFFFF00FF00FFFFFF
FF00000000000000FF0000FFFF00000000FF0000FF0000000000FF00FFFF0000FF00
FF00FFFF0000FFFF0000FFFF00FF00FFFF00000000FF00000000FF00FF0000FF00FF
FF000000FF0000FF0000FF00FF0000FFFFFFFFFFFF0000FF000000FFFFFFFF000000
0000FFFFFFFF00FFFFFFFFFF0000FFFFFF00000000FF00FFFF0000FFFF0000FF0000
FF00FF000000000000FFFF0000FFFFFFFF00000000FF0000FFFF0000FFFF00FF0000
FF00FFFFFF000000FF0000FF00000000000000FF00FFFF0000FFFF00FF0000FFFF00
FF000000000000FF00FFFF000000FFFFFFFFFF00FF00FF000000FF00FF00FF00FFFF
00000000FF00FF0000FFFFFF0000FFFFFFFF0000FFFF0000FFFFFF0000000000FFFF
000000FFFFFF000000FF000000FF00FF000000FFFF000000FF000000FF00FF0000FF
00FFFF000000FF00FFFF00FF00000000FFFFFFFF0000FF00000000FF0000FF0000FF
FF0000FF00FFFF00FFFFFFFF00FFFF000000000000FFFFFF000000FFFF0000000000
FF00FFFF000000FFFFFF000000FFFF00FF00FFFF00FFFFFFFFFFFFFFFF0000FF0000
FF00FF0000FF00FF0000FF00FF00FFFFFFFFFF0000FFFFFFFF00FF0000FFFF00FFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.630071 0.782187 0.806437 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0274725 0.0192308 0.0274725 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
35 string
35 35 8 [35 0 0 35 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.630071 0.97619 0.806437 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0267094 0.0192308 0.0267094 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
36 string
36 36 8 [36 0 0 36 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.824074 0.200176 1.00044 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0356125 0.0192308 0.0356125 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
27 string
27 27 8 [27 0 0 27 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000FF0000FFFFFF00FF000000FFFF0000FFFFFFFFFFFFFFFFFF
FFFF00FFFFFF0000000000000000FF00FF00FF0000FF00000000FF
00FF0000FF0000FF000000FF000000FFFFFFFF0000FF00000000FF
FFFF00FFFFFF0000FF00FF00FFFFFFFF00FFFF00FFFF000000FF00
00FF00000000FF0000000000FFFFFF00FF000000FF0000FFFF00FF
FF00FFFFFFFF00FF00FF00FFFFFFFFFF00FF00FFFF00FFFF00FFFF
000000FF000000FFFFFFFFFF00000000FF0000FF00FF000000FF00
0000FFFF00FF00FFFFFF00FFFFFFFFFF0000FF00FF000000FF00FF
FFFFFF000000FF00FFFF00FF000000FFFFFFFFFF00FF00FF00FFFF
00FF000000000000FFFFFFFFFFFFFF0000FFFF00FFFF0000FF0000
FFFF00FF00FF00FF00FF00FF00FFFFFF0000FF000000FFFFFFFF00
FF00FFFFFFFFFF00FF000000FF000000FF0000000000FFFFFF00FF
FFFF00000000FFFF0000FF0000FF0000000000FFFFFF00FF000000
0000FF00FF00FFFF00FFFFFF000000FFFFFF00FFFF00FF00FF0000
FFFFFF0000000000FFFFFF0000FF000000FFFF0000FF00FFFF0000
FFFFFFFFFF0000FF0000FF000000FF000000FFFFFFFFFFFFFFFFFF
000000FFFF00FFFFFF0000FF00FFFFFF00FF0000FFFF00FFFF00FF
00FF000000FF00FFFFFF000000FF00FFFFFFFFFFFF000000FF0000
FF00FFFF00FFFF00FFFFFFFFFF00FFFF00FFFFFF000000000000FF
0000FF000000FF0000FFFF0000FF0000FF0000FF00FF00FFFF00FF
FFFF00FF000000FFFFFF0000FF00FFFF000000FF00FF00000000FF
FFFFFFFFFF0000FF00FF00FF00FF00FF00FF00FFFFFFFFFF0000FF
FF00FFFF0000FF000000FF00FFFFFF0000000000FF00000000FF00
00FFFF0000FF0000FFFF00FF00FF0000FF00FF00FFFFFFFFFFFFFF
000000FF00000000000000FFFF00FFFFFFFFFFFF00FFFFFF00FFFF
0000000000FF000000FF00FF0000FFFFFFFFFF0000FFFFFF00FF00
FF0000FFFFFF0000FF0000FF0000FF00FF00FF00000000FFFFFF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.824074 0.39418 1.00044 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0343407 0.0192308 0.0343407 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
28 string
28 28 8 [28 0 0 28 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFFFF0000FFFF00FF000000FFFF00000000FFFFFFFFFFFFFF
0000FF0000FFFF00FF0000FFFF00FF00FF00FFFF0000FFFFFF00FF00
FFFF00FFFFFF00FFFF000000FFFFFF0000FF0000FFFF000000FF0000
000000000000FF00FFFFFFFFFFFF00000000FF00000000FFFFFF00FF
FFFF00FFFFFFFF00FFFF00FF00FFFF00FF0000FF0000FF0000000000
FF000000FF00FF00000000FFFFFFFFFF00FFFFFF00FF00FFFF000000
00FFFFFFFF00FFFFFF00FFFF0000000000FF000000FF00FF0000FF00
FFFFFF00000000FF00FFFFFF000000FFFF00000000FFFF0000FF0000
00000000FFFF000000000000FF0000FF00FFFFFF000000FFFF000000
FF0000FFFFFFFF000000FF00FFFFFF00FF00000000FF00FF00FF0000
000000FF00FFFFFFFFFFFFFF000000FF00FF00FFFFFF00FFFF00FF00
00FFFFFFFFFF00FFFFFF000000FF0000FFFF0000FF00FF000000FFFF
FFFF0000FFFF000000FF0000FF00000000FF000000FF00FF00FFFFFF
FF00FF000000FFFFFF00FF00FF00000000FF00000000FFFF00FFFFFF
FF00FFFFFFFF00000000FFFF000000FFFFFF00FFFFFF0000FFFFFFFF
000000FFFF00FFFF00FF0000FFFFFF0000FF0000FF00FFFFFFFF0000
FFFF00FF0000FFFF00FF00000000FF00FFFF00FFFFFF00FF00FFFF00
00FFFF00FFFFFF0000FFFFFF000000FF00FF000000FF000000FF0000
FFFFFF0000FFFFFFFF00FF00FFFFFF00FF0000FFFFFF0000FF00FF00
FF00FF00FFFFFF0000FFFFFFFFFFFFFFFF0000FF00FF00FFFFFF00FF
0000FF0000FF00FF000000FFFFFFFF00FFFFFF0000FF000000FFFFFF
FF00FFFF0000FFFF0000FF00FFFFFFFFFFFF00FF00FF0000000000FF
0000FFFFFF00FFFF0000000000000000FFFFFFFFFFFF00FF00FF00FF
00FFFFFFFFFF0000FF00FF000000000000FFFFFF00FFFF0000FF00FF
FFFF000000FFFF00FF0000FF0000FFFF00FF00000000FFFFFFFFFF00
FFFF00FF000000FF00FFFFFFFFFFFF00FF00FFFFFFFFFFFF00FF0000
0000FFFF00FF00FFFFFFFFFF0000FFFFFFFF00FFFFFFFFFF0000FF00
FFFF00000000FFFF00FF0000FF000000000000FFFF00000000FFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.824074 0.588183 1.00044 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0331565 0.0192308 0.0331565 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
29 string
29 29 8 [29 0 0 29 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFF000000FF00FF00FF00FF00FFFFFF0000FF00FFFFFFFFFFFF00
FF00FFFFFF00FFFF000000FF0000000000FF00FF0000FFFFFFFFFFFFFF
00FFFFFF0000FF000000FFFFFFFFFF0000FFFFFF00FF00000000000000
FFFF00FFFFFF00FF0000FF00FF000000FF00FF0000FF00FFFFFF00FFFF
00FF00FF00000000FF000000FF00FFFFFF0000FF00FF0000FF00FF0000
FF0000FFFFFF00FF0000FFFF000000FF0000FF0000000000FF0000FFFF
00FF00FFFF000000FFFFFFFFFF00FF00FF00FFFF00FF000000FFFF0000
00FFFF00FFFFFF00FF00FFFFFF00000000FFFF00000000FF0000FFFF00
FF0000FF00FF0000FF0000FF0000FFFF00FF00FF00FF00FFFF00FFFFFF
0000FF0000FF00FF0000FFFF0000FFFF00FFFFFFFF0000FFFFFF00FF00
FFFFFF000000FF0000FFFFFF00FFFFFF0000FF00FF00FFFFFF0000FFFF
FFFFFFFFFF00FF00000000FFFFFF0000FF0000FF0000FF00FF00FFFFFF
FF00FF00FFFFFF00FF0000FF0000FF00FF0000FFFF000000FF000000FF
FF00FF00FF00FFFFFFFF00FF0000FF00FF0000FFFF000000FF0000FFFF
00FFFFFFFF00FF00FF00FF00FFFF00FF0000FFFF00FF00FF00FFFF0000
FFFFFFFFFFFF0000FF00FF000000FF00FFFFFF00FFFFFFFFFFFF0000FF
00FF0000FFFFFFFFFF000000FFFF00FF0000000000FF00FF000000FF00
FF00FFFFFFFF0000FF00FFFFFFFF00000000FF0000FFFF000000FFFFFF
FF00FF000000FFFF0000FFFF0000FF000000FFFFFFFFFFFFFF000000FF
00FFFF00000000FF00FFFF0000FF0000FFFFFF00FFFFFF00FFFFFFFF00
00FF00FFFF00FFFF0000FFFF000000FFFF00FFFFFFFF0000000000FF00
FF000000FFFFFFFFFFFF00FF0000FF00FF000000FFFF0000FF00FF00FF
FF00FF00FFFF00FFFF00FFFF0000000000FFFFFFFF000000FF00FFFFFF
0000FF0000FF00000000000000FFFF00FF0000000000FF0000FF000000
FFFF0000FF00FFFF0000FFFFFF0000FF0000FFFFFFFF000000FF00FFFF
0000FFFF0000FFFF0000FF00FFFF00FFFF00FF0000FFFF0000FFFF0000
00000000FFFF0000FFFF00000000FFFF000000FF0000000000FFFF0000
FF00FF00FF0000FFFFFFFF000000FF0000FFFFFF00000000000000FFFF
00FFFF00000000FF000000FF00FF00FFFFFF00FFFF00FFFFFF00FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.824074 0.782187 1.00044 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0320513 0.0192308 0.0320513 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
30 string
30 30 8 [30 0 0 30 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFF0000FFFF0000FFFFFF0000FF0000FFFFFFFFFFFFFFFFFFFFFF
FF0000FF0000FF00FF00000000FFFFFFFFFFFFFFFFFF0000FF00FF0000FF
00FFFFFFFF00FFFF00FF00FFFF00FF00000000FF00FF00FFFF00FF0000FF
FFFFFF0000000000FF00FFFF0000FF000000FFFFFFFFFFFFFF00FFFF0000
FF0000FF00FF00FF0000FFFF00FFFF0000000000FFFFFFFF00FF0000FF00
0000FF00FFFF000000FFFFFF00FFFFFF00FFFFFF00FFFFFF000000FF0000
FF000000FFFF00000000000000FF0000FF000000FFFF00000000FFFF00FF
00FF0000FFFF0000FFFF00FF0000FF00FFFFFF0000FF000000FF00FF00FF
FFFFFF000000FFFFFFFF00FF0000FF00FFFFFF0000FFFFFFFF0000000000
0000FFFFFFFF000000FF000000FF0000FFFFFFFFFFFF00FFFF0000000000
000000FF00FF0000FFFFFF00FF0000000000FF0000FF00FF0000FF000000
00FFFF00FF00FFFFFF00FFFFFF000000FFFF0000FFFF00FFFFFFFF00FF00
00FFFF00FFFFFFFFFF00FFFFFF00FFFF00FFFFFF00FFFFFFFFFF00FFFF00
0000FFFF0000FFFFFF00FF00FFFFFF00FFFF00FFFFFF0000FF0000FFFFFF
00FFFF0000FF00000000FF00FF00FFFFFF0000FF0000FFFFFF00FF00FF00
00FFFF0000FFFFFF000000FF00FFFFFFFF00FF00FFFFFFFF00FFFF00FF00
0000000000FF0000FF00000000FF0000FF000000FF00000000FFFFFF0000
00FF00FF00FF0000FF00FF00FFFFFF00FFFF00FFFFFFFFFF0000000000FF
00FFFF0000FFFFFFFF00000000FFFFFF0000FFFF000000FFFFFF00FFFF00
000000FFFF000000FFFF00FF00FFFFFFFFFF00FFFF0000FF000000FF0000
FFFFFFFFFF0000FF00FF0000FF0000FF00FF0000FFFF00FF0000FF000000
0000FF00FF0000FFFFFF00FFFFFF0000FF0000FF00FFFFFFFFFF00FF0000
00FFFFFFFF000000FFFF000000FF0000FF000000FFFF000000FFFFFFFF00
FF00FFFF00FF00000000FF00FFFF00FF000000FFFF0000000000FF00FF00
FFFFFF00FF0000FF00FFFFFFFF00FF00FFFF000000FFFFFFFF00FFFF0000
00FF00FFFFFFFFFF0000FFFFFF00000000FFFFFFFFFFFFFF000000FFFF00
000000FFFFFFFF00FF00FF00FF00FF000000FF0000FFFFFFFFFF0000FFFF
FF00000000FFFF0000FFFFFFFFFFFF000000FFFF000000FF000000FFFF00
FF0000FF000000FFFF00FFFFFF00FFFFFFFF00000000000000FFFF0000FF
FFFFFFFFFF00FF00FF00FF0000000000FF00FF000000FFFF0000FFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.824074 0.97619 1.00044 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0310174 0.0192308 0.0310174 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
31 string
31 31 8 [31 0 0 31 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000FFFFFFFFFFFFFFFF000000FFFFFF0000FFFF0000FF00FFFFFFFF
FF0000FFFFFF00FFFFFF00FFFFFF0000FFFF00000000FFFFFFFF00FFFF0000
00000000FFFF00FF000000000000FFFF0000FFFF00FF0000FFFF00FF000000
00FF000000FFFF00FFFFFF00FFFFFF00FFFF00FFFFFF0000FFFFFFFF0000FF
00FFFF0000FF0000FF00FF00FFFFFF00FF0000FFFFFFFFFFFFFFFF00FF0000
FFFFFFFFFF0000FFFFFF00000000FF00FFFF0000FFFF00FF00000000000000
FF0000FF000000FFFFFF00FFFFFFFF00FF00FFFFFF0000FFFF00FF00000000
FFFFFF0000FFFF0000FFFF000000FF00FFFFFFFFFF00FFFFFFFFFF00FFFFFF
FFFF00FFFFFFFF0000FF0000FFFF00FF00FF00FFFF0000FFFF00FF00FF0000
FFFF00FF00FFFFFFFF00FFFFFF000000FF0000FFFF0000FFFFFF00FF0000FF
FF0000FFFF0000FF00FF00FF00FF00FF00FFFF00FF0000FF00FFFFFFFFFF00
FFFF00000000FF0000FFFF00FFFFFF00FFFF00FFFF00000000FF00FFFF0000
FFFF00FFFF00FF00FFFF00FF00FFFFFF0000FFFFFFFFFFFFFF00FFFF00FF00
00FF00FFFF00FF00FF00FFFFFF00FFFFFFFF000000FF00FFFF00FF00FF0000
0000FFFFFFFFFFFF000000FFFFFF00000000FFFFFF00FF000000FF00FFFFFF
0000FF0000000000FF00FF00FFFF0000FFFF00FF0000FFFFFFFFFF0000FFFF
FFFF00FFFFFFFFFF00FF00FF00FF00FF00FFFFFFFFFF0000000000FFFFFF00
FFFF00FF00FF00FFFF00FFFF00FF00FFFF0000FFFFFFFF00000000FF00FF00
FF00FF000000FFFF0000FF00FF00FF00FF0000FFFFFFFFFF0000FFFFFFFF00
0000FFFFFF00FFFFFFFF00FFFF00FFFFFFFFFF00FF0000000000FFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFF00FF00FFFFFFFF0000FF00FF00FFFFFF0000
FF00FFFFFFFF000000000000FFFF0000FFFFFF000000FFFFFFFF000000FF00
FFFF0000FF0000FF00000000FF00FFFF00FFFF00FFFF00000000FF00FFFF00
00FF0000FFFFFFFFFFFFFF00FFFF00FF0000FF0000FF00000000FF000000FF
00FFFFFFFF00FFFFFFFF0000FFFF00FF00000000FFFF00000000FFFFFFFF00
FFFFFFFFFF0000FF00FFFFFF000000FF0000000000FF00000000000000FF00
000000FFFF00FFFFFF00FF00FFFFFFFF0000FFFFFF00FFFFFF0000FF00FFFF
FFFFFFFF0000000000FFFFFFFF000000FFFFFFFFFF000000FF00FF00000000
FFFF0000FF0000FFFF00FFFF00FFFF00FF00FFFFFF00FF00FF00000000FF00
FF000000000000FF0000FF00FF00FFFFFFFFFFFF00FFFF00FFFFFF00FF00FF
FF0000FF000000FF00FF00000000FFFF000000FF000000FF0000FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.01808 0.200176 1.19444 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0437063 0.0192308 0.0437063 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
22 string
22 22 8 [22 0 0 22 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00FFFF00FFFF00FF00FFFF00FFFF00FFFFFF00FF
FF00FFFF00FF00FF00FFFF00FF00000000FFFFFF0000
FF00FF00FF00FFFF00FF00FF00FF00FF0000FFFF0000
FF00FF00000000FF00FFFFFFFF00FF0000FF000000FF
000000FF00FFFFFF00FF00FF00FF0000000000FFFF00
0000FF00FFFF000000000000FFFFFF00FF0000FFFF00
FF000000000000FF0000FF0000FF000000FF000000FF
FFFFFFFFFFFFFF00FF00FF0000FF00000000FF0000FF
00000000FFFFFF00FF00FFFFFFFF0000000000FF0000
FFFF000000FFFFFF00FF0000FFFFFFFF00FF00FFFFFF
00FF00000000FF0000FF0000FF00FF0000FF00FF00FF
00FF00000000FF0000FF0000FF00FF0000FF00FF00FF
FFFF000000FFFFFF00FF0000FFFFFFFF00FF00FFFFFF
00000000FFFFFF00FF00FFFFFFFF0000000000FF0000
FFFFFFFFFFFFFF00FF00FF0000FF00000000FF0000FF
FF000000000000FF0000FF0000FF000000FF000000FF
0000FF00FFFF000000000000FFFFFF00FF0000FFFF00
000000FF00FFFFFF00FF00FF00FF0000000000FFFF00
FF00FF00000000FF00FFFFFFFF00FF0000FF000000FF
FF00FF00FF00FFFF00FF00FF00FF00FF0000FFFF0000
FF00FFFF00FF00FF00FFFF00FF00000000FFFFFF0000
00FF00FFFF00FFFF00FF00FFFF00FFFF00FFFFFF00FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.01808 0.39418 1.19444 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.041806 0.0192308 0.041806 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
23 string
23 23 8 [23 0 0 23 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFF00000000FFFF00FF0000000000FFFF00FF00FFFF
0000FF00FFFF00FF00000000FFFFFF00FF0000FFFF0000
0000FFFF00FF0000FFFFFF00FF00FFFF000000FFFF00FF
00FF00FFFF0000FF0000FFFFFFFFFF00FFFFFFFF0000FF
FFFF00FF000000FF000000FFFFFF0000FF0000FF0000FF
FFFFFF0000FF0000FF00FF00FF0000FFFFFF00FF000000
FF00FFFF000000FFFF00FF00FF0000FF00FFFF00FFFF00
000000FF00FF00FF000000FFFFFFFFFF0000FF00FFFFFF
FFFF00FF00FF00FFFF00FFFFFF00FF00FF000000000000
000000FF00FFFF000000FF00000000FFFFFFFF00FFFF00
FF00FFFFFFFFFF00FF00FF00FFFFFFFFFFFF00FFFFFF00
0000000000000000000000000000000000000000000000
FF00FFFFFFFFFF00FF00FF00FFFFFFFFFFFF00FFFFFF00
000000FF00FFFF000000FF00000000FFFFFFFF00FFFF00
FFFF00FF00FF00FFFF00FFFFFF00FF00FF000000000000
000000FF00FF00FF000000FFFFFFFFFF0000FF00FFFFFF
FF00FFFF000000FFFF00FF00FF0000FF00FFFF00FFFF00
FFFFFF0000FF0000FF00FF00FF0000FFFFFF00FF000000
FFFF00FF000000FF000000FFFFFF0000FF0000FF0000FF
00FF00FFFF0000FF0000FFFFFFFFFF00FFFFFFFF0000FF
0000FFFF00FF0000FFFFFF00FF00FFFF000000FFFF00FF
0000FF00FFFF00FF00000000FFFFFF00FF0000FFFF0000
00FFFF00000000FFFF00FF0000000000FFFF00FF00FFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.01808 0.588183 1.19444 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0400641 0.0192308 0.0400641 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
24 string
24 24 8 [24 0 0 24 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
00FFFF00FF00000000FFFF0000FFFF00000000FF00FFFF00
FF000000000000FFFF0000FFFF0000FFFF000000000000FF
FF00FFFFFF00FF000000FFFFFFFF000000FF00FFFFFF00FF
FFFF00FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF00FFFF
FFFFFF0000000000000000FFFF0000000000000000FFFFFF
FFFF0000000000FF00FF00000000FF00FF0000000000FFFF
000000FFFFFF00FF0000FF0000FF0000FF00FFFFFF000000
FF00FF0000FF000000FF00FFFF00FF000000FF0000FF00FF
00FF000000000000000000FFFF000000000000000000FF00
00FF00000000FF0000FFFFFFFFFFFF0000FF00000000FF00
FFFFFFFF00FFFFFF0000FF0000FF0000FFFFFF00FFFFFFFF
00FFFF00FFFFFFFF0000FF0000FF0000FFFFFFFF00FFFF00
FF0000FF00000000FF00FFFFFFFF00FF00000000FF0000FF
FFFF00FF0000FF000000FFFFFFFF000000FF0000FF00FFFF
00FF00FFFF0000FF00FFFFFFFFFFFF00FF0000FFFF00FF00
FF0000FF0000FFFFFF00FF0000FF00FFFFFF0000FF0000FF
FF00FFFFFFFF00000000FF0000FF00000000FFFFFFFF00FF
00FF0000FF00FFFFFF0000FFFF0000FFFFFF00FF0000FF00
00FF0000FF00000000FF00FFFF00FF00000000FF0000FF00
00FF00FF00000000FFFF00000000FFFF00000000FF00FF00
00FF00FF00FFFFFF000000FFFF000000FFFFFF00FF00FF00
00FF00FFFF00FF00FFFF00000000FFFF00FF00FFFF00FF00
00FFFFFFFF00FF00000000000000000000FF00FFFFFFFF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.01808 0.782187 1.19444 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0384615 0.0192308 0.0384615 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
25 string
25 25 8 [25 0 0 25 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00FFFFFF00FFFFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFF
00FF0000FF000000FFFFFFFFFF00FFFF00FFFF000000FFFFFF
FF0000FF00FF00FFFFFF000000FF00FFFFFF000000FF00FFFF
0000FF0000000000FFFF00FF00FF00FFFF0000000000FF0000
0000FF00FF000000FF00000000FF0000FF0000FFFF00FFFF00
FF00FF00FFFF0000FF00FF00FFFFFF0000FFFFFF0000000000
00FFFFFF000000FFFFFFFFFF0000FF00FFFF00FF00FFFF0000
00FF00FF0000FFFFFF0000FF000000FFFFFFFFFF00FF000000
00FFFF000000FFFF0000000000FF00FF00FFFFFF0000FF0000
FF00FF00000000FFFF0000FFFF00FF000000FF000000FF0000
FFFF00FF0000FF00FFFFFF000000FF00FF00FF0000FF00FFFF
FF00FF00FF00000000FF00FFFFFF0000FFFFFFFF000000FF00
00000000000000000000000000000000000000000000000000
FF00FF00FF00000000FF00FFFFFF0000FFFFFFFF000000FF00
FFFF00FF0000FF00FFFFFF000000FF00FF00FF0000FF00FFFF
FF00FF00000000FFFF0000FFFF00FF000000FF000000FF0000
00FFFF000000FFFF0000000000FF00FF00FFFFFF0000FF0000
00FF00FF0000FFFFFF0000FF000000FFFFFFFFFF00FF000000
00FFFFFF000000FFFFFFFFFF0000FF00FFFF00FF00FFFF0000
FF00FF00FFFF0000FF00FF00FFFFFF0000FFFFFF0000000000
0000FF00FF000000FF00000000FF0000FF0000FFFF00FFFF00
0000FF0000000000FFFF00FF00FF00FFFF0000000000FF0000
FF0000FF00FF00FFFFFF000000FF00FFFFFF000000FF00FFFF
00FF0000FF000000FFFFFFFFFF00FFFF00FFFF000000FFFFFF
FF00FFFFFF00FFFFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.01808 0.97619 1.19444 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0369822 0.0192308 0.0369822 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
26 string
26 26 8 [26 0 0 26 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.21208 0.200176 1.38845 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0565611 0.0192308 0.0565611 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
17 string
17 17 8 [17 0 0 17 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FFFFFFFF00FF00FF00FFFFFFFFFF00
0000FF000000FFFFFFFFFFFFFF00FFFFFF
0000FFFFFFFF00FF00FFFF000000FF0000
00FFFFFFFFFF0000FF00FF0000000000FF
FFFFFF00000000FFFF00000000FF00FFFF
000000FF0000FFFFFFFFFFFFFF00000000
FF0000FF00FF0000FF0000000000FF00FF
00000000FFFF00FFFF00FFFF00FFFFFFFF
00000000FFFFFFFF0000FFFFFFFF000000
FFFFFF00FFFFFF0000FF000000FFFF0000
FF00FF0000FF0000FF000000000000FFFF
000000FFFFFF0000FFFF000000FF000000
FFFF00FF000000FFFF00000000FFFF00FF
FF0000FFFF0000FF00FF0000FF0000FF00
0000FFFF0000FF0000FF00FFFFFFFF0000
0000FF0000FF00FFFFFFFF000000FFFFFF
0000FFFFFFFF00FF00FF00FFFFFFFFFF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.21208 0.39418 1.38845 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0534188 0.0192308 0.0534188 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
18 string
18 18 8 [18 0 0 18 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00FF00FFFFFF00FFFFFFFFFFFFFFFFFF0000
FF00FF00000000FFFFFFFFFF00FFFF0000FF
0000FF00FFFFFF00FF0000FFFFFFFFFF00FF
00000000FF00FF00FFFFFF00FFFF0000FF00
FFFF0000FFFF00FFFFFFFF00000000FFFF00
00FFFF00FFFF00FF0000FF0000FFFF000000
0000000000000000FF00000000FF00FF00FF
000000FFFF00FFFF00FFFFFFFFFFFF0000FF
0000FFFF00000000FF00000000000000FFFF
000000FFFF00FFFF000000FFFFFF00000000
FFFF0000FF00FF00FF000000FFFFFFFF00FF
0000FFFF00FFFF00FFFF0000000000FF0000
0000000000FFFF0000FFFFFFFF000000FFFF
0000000000FFFFFF00000000FF0000000000
FFFFFF0000FFFFFF00FFFF000000FFFF0000
FF00FF00FFFF00FFFF000000000000FFFF00
FF0000FF00000000000000FF000000FF00FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.21208 0.588183 1.38845 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0506073 0.0192308 0.0506073 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
19 string
19 19 8 [19 0 0 19 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFF00000000FFFF00FFFF00000000FFFFFF
000000FFFF000000FF00FF000000FFFF000000
00FF00000000FFFFFF00FFFFFF00000000FF00
00FFFFFF00FFFFFFFF00FFFFFFFF00FFFFFF00
FF000000FF0000FFFF00FFFF0000FF000000FF
FF00FF00000000000000000000000000FF00FF
FF00FF00FF000000000000000000FF00FF00FF
00FFFF0000FF00000000000000FF0000FFFF00
00FF00FFFF0000FF000000FF0000FFFF00FF00
00FFFFFFFF000000000000000000FFFFFFFF00
00FF000000FF00000000000000FF000000FF00
00FFFF0000000000FF00FF0000000000FFFF00
00FF0000FFFF00000000000000FFFF0000FF00
00FF00FF0000FFFFFF00FFFFFF0000FF00FF00
FFFFFF00FF0000FF000000FF0000FF00FFFFFF
00FFFFFF0000FFFF000000FFFF0000FFFFFF00
FF000000FFFF00FFFF00FFFF00FFFF000000FF
0000FFFF00FFFF00FF00FF00FFFF00FFFF0000
00FF000000FFFFFFFF00FFFFFFFF000000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.21208 0.782187 1.38845 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0480769 0.0192308 0.0480769 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
20 string
20 20 8 [20 0 0 20 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF00FFFF000000FF0000FF000000FFFF00FFFF
0000FFFF000000FFFF0000FFFF000000FFFF0000
FFFF0000000000FF00FFFF00FF0000000000FFFF
FFFFFFFF0000FF0000FFFF0000FF0000FFFFFFFF
0000FFFFFFFFFF000000000000FFFFFFFFFF0000
FF00FF00FFFFFF0000FFFF0000FFFFFF00FF00FF
000000FFFF00FFFF00FFFF00FFFF00FFFF000000
FFFFFF00FFFF0000FF0000FF0000FFFF00FFFFFF
0000FFFFFFFFFF000000000000FFFFFFFFFF0000
FF0000FFFF00FFFF00000000FFFF00FFFF0000FF
FF0000000000FFFFFF0000FFFFFF0000000000FF
00FF000000FFFFFF00FFFF00FFFFFF000000FF00
0000FFFFFFFF0000000000000000FFFFFFFF0000
00FF000000FFFFFF00FFFF00FFFFFF000000FF00
00FFFF0000FF000000FFFF000000FF0000FFFF00
00FF00FFFF000000FFFFFFFF000000FFFF00FF00
0000FFFF000000FFFF0000FFFF000000FFFF0000
00FF0000FF0000FFFFFFFFFFFF0000FF0000FF00
FF00FF00FFFFFF000000000000FFFFFF00FF00FF
0000FF00FFFF00FFFF0000FFFF00FFFF00FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.21208 0.97619 1.38845 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0457875 0.0192308 0.0457875 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
21 string
21 21 8 [21 0 0 21 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF0000FF00FF00FFFFFF00FF0000FF00FFFF00FF
FF00FF000000FF00FF00FF00FF00FFFF0000FF0000
00FF000000FF00FFFFFFFFFFFF00FFFF00FF00FFFF
00000000FFFF00FFFF00FFFF0000FFFF00FFFF0000
FF0000FF00FF000000FFFF0000FF0000000000FFFF
0000FFFFFF00FFFF000000FF000000FF00FFFF0000
FFFF000000FF00000000FF00FFFF0000FFFFFFFFFF
0000FFFF00FF0000FFFFFFFF0000FFFF000000FF00
FFFFFFFF000000FF000000FF00FFFF0000FF00FFFF
FF00FF00FF0000FF0000FFFF0000FF000000FF00FF
FFFFFFFFFF00FFFF00FF000000FFFFFF00FFFF00FF
0000FFFF00FF00FFFFFF0000FFFF00FFFFFFFFFFFF
FFFFFF000000FF00000000FF00FF00FF00FFFFFF00
00000000FF00FF00FF00FFFFFF0000000000FF0000
00FFFFFF000000FFFFFFFF00000000FF00FF00FF00
FFFFFFFF00FF00FF0000FFFFFF00FF00FFFFFF0000
000000000000FF00000000FF000000FF000000FF00
FF00FFFF00FFFF00FF00FFFFFF00FFFF000000FF00
FFFF00FF00FFFF0000FFFFFFFFFF00FF000000FF00
0000FF00FF00FFFFFF0000FFFF00FF00FFFFFF0000
FF00FF00FF00FF00FFFFFFFF0000000000000000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.40608 0.200176 1.58245 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0801282 0.0192308 0.0801282 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
12 string
12 12 8 [12 0 0 12 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFF0000FFFFFFFFFF
FF000000FF0000FF000000FF
FFFFFF00FFFFFFFF00FFFFFF
0000FFFFFF0000FFFFFF0000
00FFFFFFFF0000FFFFFFFF00
0000FF000000000000FF0000
FFFFFF000000000000FFFFFF
00FFFFFFFF0000FFFFFFFF00
FFFF00FFFF0000FFFF00FFFF
00FFFFFFFFFFFFFFFFFFFF00
FF0000FFFFFFFFFFFF0000FF
00FF0000FFFFFFFF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.40608 0.39418 1.58245 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0739645 0.0192308 0.0739645 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
13 string
13 13 8 [13 0 0 13 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFF0000FF0000FF0000FFFF
FF00FF0000FFFF0000FFFFFFFF
FF00FFFF00FFFF0000FF0000FF
FFFF000000FFFFFF0000000000
FF000000FF00FF00FFFFFFFFFF
FF00FFFFFFFF00FFFFFFFF00FF
FFFFFFFFFF00FF00FF000000FF
0000000000FFFFFF000000FFFF
FF0000FF0000FFFF00FFFF00FF
FFFFFFFF0000FFFF0000FF00FF
FFFF0000FF0000FF0000FFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.40608 0.588183 1.58245 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0686813 0.0192308 0.0686813 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
14 string
14 14 8 [14 0 0 14 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFFFF000000000000FFFFFF00
FF00FF00FFFF0000FFFF00FF00FF
FF00FFFFFF00000000FFFFFF00FF
FF00FFFFFFFF0000FFFFFFFF00FF
000000FF00FFFFFFFF00FF000000
0000FFFFFFFF0000FFFFFFFF0000
0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000
0000FFFFFFFF0000FFFFFFFF0000
000000FF00FFFFFFFF00FF000000
FF00FFFFFFFF0000FFFFFFFF00FF
FF00FFFFFF00000000FFFFFF00FF
FF00FF00FFFF0000FFFF00FF00FF
00FFFFFF000000000000FFFFFF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.40608 0.782187 1.58245 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0641026 0.0192308 0.0641026 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
15 string
15 15 8 [15 0 0 15 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00FF0000000000FFFFFFFFFFFF
0000FF00FF0000FFFF00FFFF00FFFF
FFFFFFFF0000FF0000FF00FFFFFF00
00FF00FF00000000FF000000FF0000
FFFF00FF00FF00FF00FF000000FF00
FF00FF00FF00FFFFFF00FF0000FF00
FF00FF0000FF000000FF000000FFFF
FFFFFF0000FF000000FF0000FFFFFF
00FF00FF00000000000000FFFF0000
FFFF00FF000000FF000000FFFF0000
0000FF00000000FF000000FFFF00FF
FF0000FFFFFFFF0000FFFF00FFFFFF
00FFFFFFFFFF0000FF00FFFFFFFFFF
FF00FFFF00FFFFFF00FF000000FF00
0000FF00FF00FF00FFFF00000000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.40608 0.97619 1.58245 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0600962 0.0192308 0.0600962 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
16 string
16 16 8 [16 0 0 16 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF0000000000FFFFFFFFFFFF00FFFF
00FF0000FF0000FFFFFF00FFFF00FF00
FFFF0000FFFFFF0000FF00000000FFFF
00FF00FFFF000000FFFFFFFFFF0000FF
00FF000000FFFFFF0000000000FFFFFF
0000FFFFFF00FF00FFFF0000000000FF
000000FF0000FF00FFFF00FF0000FFFF
FFFF00000000FF000000FFFFFF00FFFF
FF0000FF00FF000000FF00FF000000FF
FF00FF0000000000FF0000FFFFFFFF00
00FFFF00FFFFFF00FFFFFF00FF00FFFF
FF00FF0000000000FFFFFF0000000000
FFFFFFFFFF000000FFFFFFFFFFFF0000
FFFFFFFFFF0000000000FF00FFFFFFFF
000000FF00FFFF000000FF0000000000
FFFF000000FF00FFFFFF00FFFF00FFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.60009 0.200176 1.77646 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.137363 0.0192308 0.137363 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
7 string
7 7 8 [7 0 0 7 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00FFFFFFFFFF
FFFF0000FFFF00
00FF0000000000
FF0000000000FF
0000000000FF00
00FFFF0000FFFF
FFFFFFFFFF00FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.60009 0.39418 1.77646 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.120192 0.0192308 0.120192 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
8 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFF00FFFFFFFF
FF000000FFFF00FF
FF00FFFF00FFFFFF
FFFFFF0000000000
FFFFFF0000000000
FF00FFFF00FFFFFF
FF000000FFFF00FF
00FFFF00FFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.60009 0.588183 1.77646 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.106838 0.0192308 0.106838 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
9 string
9 9 8 [9 0 0 9 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFF
00000000FF00FFFFFF
00FF00FF0000FF00FF
0000FFFF00FF00FFFF
00FF00000000FF0000
00FF000000000000FF
FF00FF00FF0000FFFF
FF0000FF00FFFFFFFF
0000FFFFFFFF00FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.60009 0.782187 1.77646 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0961538 0.0192308 0.0961538 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
10 string
10 10 8 [10 0 0 10 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFFFF00FFFFFFFFFF
FF00FF00FF00FF00FF00
FF000000FF00FFFFFF00
000000FFFF00000000FF
00FFFF0000FF00FF0000
FF00FF0000FF00FFFFFF
0000FFFFFF0000FF00FF
000000FFFF0000FFFFFF
FF00FF0000FFFF00FF00
00FF00FFFF00FF00FFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.60009 0.97619 1.77646 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0874126 0.0192308 0.0874126 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
11 string
11 11 8 [11 0 0 11 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFF000000FFFF00FFFF
000000FF00FF0000000000
FF00FF000000FF00FF0000
FFFFFFFF00FFFFFFFF0000
FF0000FF00FF0000FF0000
0000000000000000000000
FF0000FF00FF0000FF0000
FFFFFFFF00FFFFFFFF0000
FF00FF000000FF00FF0000
000000FF00FF0000000000
00FFFF000000FFFF00FFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.79409 0.200176 1.97046 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.480769 0.0192308 0.480769 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
2 string
2 2 8 [2 0 0 2 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF
00FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 1.79409 0.39418 1.97046 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.320513 0.0192308 0.320513 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
3 string
3 3 8 [3 0 0 3 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFF
00FFFF
000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 1.79409 0.588183 1.97046 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.240385 0.0192308 0.240385 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
4 string
4 4 8 [4 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFF
FF0000FF
00000000
FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 1.79409 0.782187 1.97046 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.192308 0.0192308 0.192308 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
5 string
5 5 8 [5 0 0 5 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF00FFFF
00000000FF
FFFF000000
0000FF00FF
0000FF0000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 1.79409 0.97619 1.97046 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.160256 0.0192308 0.160256 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
6 string
6 6 8 [6 0 0 6 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF00FF00FFFF
00000000FF00
FF0000FF00FF
0000FF00FFFF
FFFF00FF00FF
FF00FFFFFF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{524, 1057.63},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008<00048B000`400?l00000o`00003oo`3AcJWo
0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY
003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0
dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT0
0?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3A
cJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00
o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=
Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o
0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY000>0=7=Z@80oooo
100000020?ooo`030000003oool0oooo00@0oooo100000030?ooo`@00000103oool2000000L0oooo
100000040?ooo`8000000P3oool00`000000oooo0?ooo`02000000@0oooo0P0000050?ooo`800000
0P3oool8000000T0oooo3@3AcJT40?ooo`<00000103oool200000080oooo0P0000020?ooo`<00000
0P3oool200000080oooo100000000`3oool00000000000040?ooo`8000001`3oool2000000@0oooo
0P0000000`3oool000000000000200000080oooo0P0000020?ooo`<000000P3oool200000080oooo
0P0000040?ooo`<00000103oool=0=7=Z@/0oooo0P0000000`3oool000000000000200000080oooo
0P0000090?ooo`030000003oool0oooo008000000P3oool2000000030?ooo`000000000000@00000
0P3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool01`3oool200000080oooo
100000000`3oool000000000000;0?ooo`d0dLfY2`0000030?ooo`@000000`3oool=000000<0oooo
0P0000020?ooo`@000000`3oool2000000D0oooo0P0000040?ooo`D000001@3oool2000000D0oooo
100000030?ooo`8000000P3oool=0=7=Z@L0oooo0P0000030?ooo`8000000P3oool00`000000oooo
0?ooo`0300000080oooo0P0000030?ooo`L000001@3oool6000000D0oooo1`0000030?ooo`800000
0P3oool300000080oooo00<000000?ooo`3oool00P0000030?ooo`8000001`3oool@0=7=Z@003P3A
cJT20?ooo`@000000P3oool00`000000oooo0?ooo`040?ooo`@000000`3oool4000000@0oooo0P00
00070?ooo`@00000103oool200000080oooo00<000000?ooo`3oool00P0000040?ooo`8000001@3o
ool200000080oooo200000090?ooo`d0dLfY103oool3000000@0oooo0P0000020?ooo`8000000P3o
ool300000080oooo0P0000020?ooo`@0000000<0oooo000000000000103oool2000000L0oooo0P00
00040?ooo`80000000<0oooo0000000000000P0000020?ooo`8000000P3oool300000080oooo0P00
00020?ooo`800000103oool3000000@0oooo3@3AcJT;0?ooo`80000000<0oooo0000000000000P00
00020?ooo`8000002@3oool00`000000oooo0?ooo`0200000080oooo0P0000000`3oool000000000
000400000080oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo00L0oooo0P00
00020?ooo`@0000000<0oooo0000000000002`3oool=0=7=Z@/000000`3oool4000000<0oooo3@00
00030?ooo`8000000P3oool4000000<0oooo0P0000050?ooo`800000103oool5000000D0oooo0P00
00050?ooo`@000000`3oool200000080oooo3@3AcJT70?ooo`8000000`3oool200000080oooo00<0
00000?ooo`3oool00`0000020?ooo`8000000`3oool7000000D0oooo1P0000050?ooo`L000000`3o
ool200000080oooo0`0000020?ooo`030000003oool0oooo008000000`3oool2000000L0oooo403A
cJT000h0dLfY1P0000020?ooo`030000003oool0oooo00@0oooo0P0000020?ooo`T00000103oool2
00000080oooo00<000000?ooo`3oool00P0000020?ooo`T000000P3oool600000080oooo1`000004
0?ooo`8000000P3oool4000000L0oooo3@3AcJT7000000@0oooo0P0000020?ooo`8000000P3oool0
0`000000oooo0?ooo`020?ooo`@00000103oool00`000000oooo0?ooo`040?ooo`8000000P3oool3
00000080oooo0P0000060?ooo`030000003oool0oooo0080oooo100000040?ooo`030000003oool0
oooo008000000P3oool2000000@0oooo1`00000=0=7=Z@D0oooo0P0000040?ooo`D000000P3oool5
000000T0oooo2@0000020?ooo`8000000P3oool9000000T0oooo1@0000020?ooo`D00000103oool2
000000D0oooo3@3AcJT200000080oooo00<000000?ooo`3oool0103oool7000000D0oooo2@000005
0?ooo`8000000P3oool<00000080oooo2`0000050?ooo`8000000P3oool2000000030?ooo`000000
000000D0oooo1000000=0=7=Z@<00000103oool7000000<0oooo100000000`3oool0000000000007
00000080oooo1@0000030?ooo`H000000`3oool500000080oooo2@0000000`3oool0000000000002
000000<0oooo1`0000040?ooo`<00000403AcJT000h0dLfY1P0000020?ooo`030000003oool0oooo
00@0oooo0P0000020?ooo`T00000103oool200000080oooo00<000000?ooo`3oool00P0000020?oo
o`T000000P3oool600000080oooo1`0000040?ooo`8000000P3oool4000000L0oooo3@3AcJT70000
00@0oooo0P0000020?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`@00000103oool00`00
0000oooo0?ooo`040?ooo`8000000P3oool300000080oooo0P0000060?ooo`030000003oool0oooo
0080oooo100000040?ooo`030000003oool0oooo008000000P3oool2000000@0oooo1`00000=0=7=
Z@D0oooo0P0000040?ooo`D000000P3oool5000000T0oooo2@0000020?ooo`8000000P3oool90000
00T0oooo1@0000020?ooo`D00000103oool2000000D0oooo3@3AcJT200000080oooo00<000000?oo
o`3oool0103oool7000000D0oooo2@0000050?ooo`8000000P3oool<00000080oooo2`0000050?oo
o`8000000P3oool2000000030?ooo`000000000000D0oooo1000000=0=7=Z@80000000<0oooo0000
000000000P0000050?ooo`h000001`3oool300000080oooo0`0000020?ooo`8000000P3oool30000
0080oooo0`0000070?ooo`h000001@3oool4000000030?ooo`00000000000100dLfY000>0=7=Z@T0
00000P3oool4000000d0oooo0P0000020?ooo`8000000`3oool2000000H0oooo1`0000040?ooo`@0
00000P3oool200000080oooo1@0000060?ooo`8000000`3oool6000000d0dLfY1P3oool7000000H0
oooo1@0000020?ooo`8000000P3oool900000080oooo1`0000020?ooo`T000000P3oool200000080
oooo1@0000060?ooo`L000001P3oool=0=7=Z@L000000P3oool4000000030?ooo`00000000000080
0000103oool700000080oooo0`0000040?ooo``00000103oool300000080oooo1`0000040?ooo`@0
000000<0oooo0000000000000P0000020?ooo`L000003@3AcJT20?ooo`8000000`3oool900000080
oooo0P0000030?ooo`@000001@3oool5000000P0oooo0`0000040?ooo`<00000103oool200000003
0?ooo`000000000000D0oooo2@0000060?ooo`030000003oool0oooo0080oooo3@3AcJT200000003
0?ooo`0000000000008000001@3oool>000000L0oooo0`0000020?ooo`<000000P3oool200000080
oooo0`0000020?ooo`<000001`3oool>000000D0oooo100000000`3oool000000000000@0=7=Z@00
3P3AcJT900000080oooo1000000=0?ooo`8000000P3oool2000000<0oooo0P0000060?ooo`L00000
103oool400000080oooo0P0000020?ooo`D000001P3oool2000000<0oooo1P00000=0=7=Z@H0oooo
1`0000060?ooo`D000000P3oool200000080oooo2@0000020?ooo`L000000P3oool900000080oooo
0P0000020?ooo`D000001P3oool7000000H0oooo3@3AcJT20?ooo`D000001P3oool00`000000oooo
0?ooo`020?ooo`8000000`3oool2000000l0oooo00<000000?ooo`3oool00P0000020?ooo`800000
3P3oool2000000<0oooo0P0000040?ooo`030000003oool0oooo00@0oooo1@0000020?ooo`d0dLfY
0P3oool2000000030?ooo`00000000000080oooo0P0000030?ooo`H0000000<0oooo000000000000
2`0000050?ooo`@000000P3oool00`000000oooo0?ooo`04000000<0oooo1P0000000`3oool00000
000000020?ooo`8000000`3oool400000080oooo1`0000050?ooo`d0dLfY1@3oool4000000D0oooo
1@0000030?ooo`@000000P3oool00`000000oooo0?ooo`020?ooo`<00000103oool00`000000oooo
0?ooo`0200000080oooo00<000000?ooo`3oool00P3oool3000000@0oooo00<000000?ooo`3oool0
100000030?ooo`D000001@3oool4000000D0oooo403AcJT000h0dLfY103oool700000080oooo0P00
00060?ooo`030000003oool0oooo00@0oooo0P0000020?ooo`8000000`3oool400000080oooo0P00
00020?ooo`8000000`3oool200000080oooo0P0000020?ooo`@000000P3oool00`000000oooo0?oo
o`040?ooo`H000000`3oool400000080oooo3@3AcJT200000080oooo0P0000000`3oool000000000
000:0?ooo`030000003oool0oooo00H000001`3oool2000000H0oooo0`0000060?ooo`8000001`3o
ool600000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`00000000000080oooo0P00
000=0=7=Z@80oooo1@0000060?ooo`030000003oool0oooo0080oooo0P0000030?ooo`8000003`3o
ool00`000000oooo0?ooo`0200000080oooo0P00000>0?ooo`8000000`3oool2000000@0oooo00<0
00000?ooo`3oool0103oool500000080oooo3@3AcJT20?ooo`80000000<0oooo0000000000000P3o
ool2000000<0oooo1P0000000`3oool000000000000;000000D0oooo100000020?ooo`030000003o
ool0oooo00@000000`3oool6000000030?ooo`00000000000080oooo0P0000030?ooo`@000000P3o
ool7000000D0oooo3@3AcJT50?ooo`@000001@3oool5000000<0oooo100000020?ooo`030000003o
ool0oooo0080oooo0`0000040?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?oo
o`020?ooo`<00000103oool00`000000oooo0?ooo`04000000<0oooo1@0000050?ooo`@000001@3o
ool@0=7=Z@003P3AcJT40?ooo`L000000P3oool2000000H0oooo00<000000?ooo`3oool0103oool2
00000080oooo0P0000030?ooo`@000000P3oool200000080oooo0P0000030?ooo`8000000P3oool2
00000080oooo100000020?ooo`030000003oool0oooo00@0oooo1P0000030?ooo`@000000P3oool=
0=7=Z@80oooo100000000`3oool00000000000020?ooo`8000001P3oool300000080oooo10000004
0?ooo`D000001P3oool3000000H0oooo1@0000040?ooo`@000000P3oool3000000H0oooo0P000002
0?ooo`80000000<0oooo0000000000000P0000020?ooo`d0dLfY0P3oool2000000030?ooo`000000
000000800000103oool700000080oooo0`0000040?ooo`<00000203oool9000000L0oooo0`000004
0?ooo`<000000P3oool7000000@0oooo100000000`3oool00000000000020?ooo`d0dLfY0P3oool2
000000030?ooo`000000000000@000001@3oool700000080oooo0`0000020?ooo`@000000P3oool3
00000080oooo1@0000020?ooo`8000001@3oool2000000@0oooo0`0000070?ooo`L000000P3oool4
000000<0oooo0P00000=0=7=Z@8000000`3oool700000080oooo1@0000020?ooo`L0000000<0oooo
0000000000000P0000020?ooo`<000001@3oool2000000D0oooo100000000`3oool0000000000002
000000030?ooo`000000000000D000000P3oool500000080oooo1`0000030?ooo`800000403AcJT0
00h0dLfY3@0000020?ooo`@000000P3oool5000000P0oooo0P0000030?ooo`X000000P3oool50000
00X0oooo0`0000020?ooo`8000001P3oool2000000030?ooo`0000000000008000000P3oool=0=7=
Z@80oooo100000000`3oool00000000000020?ooo`8000001P3oool300000080oooo100000040?oo
o`D000001P3oool3000000H0oooo1@0000040?ooo`@000000P3oool3000000H0oooo0P0000020?oo
o`80000000<0oooo0000000000000P0000020?ooo`d0dLfY0P3oool2000000030?ooo`0000000000
00800000103oool700000080oooo0`0000040?ooo`<00000203oool9000000L0oooo0`0000040?oo
o`<000000P3oool7000000@0oooo100000000`3oool00000000000020?ooo`d0dLfY0P3oool20000
00030?ooo`000000000000@000001@3oool700000080oooo0`0000020?ooo`@000000P3oool30000
0080oooo1@0000020?ooo`8000001@3oool2000000@0oooo0`0000070?ooo`L000000P3oool40000
00<0oooo0P00000=0=7=Z@8000000`3oool700000080oooo1@0000020?ooo`L0000000<0oooo0000
000000000P0000020?ooo`<000001@3oool2000000D0oooo100000000`3oool00000000000020000
00030?ooo`000000000000D000000P3oool500000080oooo1`0000030?ooo`800000403AcJT000h0
dLfY1P3oool9000000@0oooo0P0000000`3oool0000000000002000000@0oooo100000020?ooo`D0
00000P3oool2000000@0oooo0P0000050?ooo`H000000P3oool500000080oooo0P0000020?ooo`80
00001@3oool200000080oooo0P00000=0=7=Z@8000000P3oool2000000030?ooo`000000000000@0
oooo0P0000040?ooo`<00000103oool400000080oooo1`00000;0?ooo`L000000P3oool4000000@0
oooo0`0000040?ooo`800000103oool2000000030?ooo`00000000000080oooo0P00000=0=7=Z@80
00000`3oool6000000<0oooo0P0000020?ooo`@0000000<0oooo0000000000000P3oool4000000<0
oooo0P0000020?ooo`<000000P3oool200000080oooo0`0000020?ooo`8000000`3oool400000080
oooo0P0000000`3oool000000000000200000080oooo0P0000030?ooo`H000000`3oool2000000d0
dLfY0P0000020?ooo`<000000P3oool300000080oooo100000030?ooo`@000001`3oool400000003
0?ooo`0000000000008000000P3oool2000000030?ooo`000000000000L0oooo1P0000030?ooo`D0
00000P3oool2000000@0oooo0`0000020?ooo`80000000<0oooo0000000000000P00000=0=7=Z@D0
oooo0P0000070?ooo`8000000`3oool2000000<0oooo0P0000020?ooo`D000002P3oool2000000X0
oooo1@0000020?ooo`8000000`3oool2000000<0oooo0P0000070?ooo`8000001@3oool@0=7=Z@00
3P3AcJT60?ooo`T00000103oool2000000030?ooo`000000000000800000103oool400000080oooo
1@0000020?ooo`800000103oool2000000D0oooo1P0000020?ooo`D000000P3oool200000080oooo
0P0000050?ooo`8000000P3oool2000000d0dLfY0P0000020?ooo`80000000<0oooo000000000000
103oool2000000@0oooo0`0000040?ooo`@000000P3oool7000000/0oooo1`0000020?ooo`@00000
103oool3000000@0oooo0P0000040?ooo`80000000<0oooo0000000000000P3oool2000000d0dLfY
0P0000030?ooo`H000000`3oool200000080oooo100000000`3oool00000000000020?ooo`@00000
0`3oool200000080oooo0`0000020?ooo`8000000P3oool300000080oooo0P0000030?ooo`@00000
0P3oool2000000030?ooo`0000000000008000000P3oool2000000<0oooo1P0000030?ooo`800000
3@3AcJT200000080oooo0`0000020?ooo`<000000P3oool4000000<0oooo100000070?ooo`@00000
00<0oooo0000000000000P0000020?ooo`80000000<0oooo0000000000001`3oool6000000<0oooo
1@0000020?ooo`800000103oool300000080oooo0P0000000`3oool0000000000002000000d0dLfY
0P0000030?ooo`@0000000<0oooo000000000000103oool5000000<0oooo100000000`3oool00000
00000004000000030?ooo`000000000000D0oooo0P0000050?ooo`8000000P3oool5000000030?oo
o`0000000000008000000`3oool5000000@0oooo0P0000000`3oool0000000000002000000<0oooo
0P00000@0=7=Z@003P3AcJT40?ooo`8000000P3oool500000080oooo100000020?ooo`<000000P3o
ool200000080oooo100000020?ooo`030000003oool0oooo01<0oooo3@0000020?ooo`8000001P3o
ool00`000000oooo0?ooo`0200000080oooo3@3AcJT20?ooo`8000002@3oool2000000L0oooo0P00
00020?ooo`@000000`3oool4000000l0oooo100000030?ooo`@000000P3oool2000000L0oooo0P00
00090?ooo`8000000P3oool=0=7=Z@80oooo0`0000040?ooo`D00000103oool200000080oooo2P00
00040?ooo`8000001@3oool2000000D0oooo0P0000040?ooo`X000000P3oool2000000@0oooo1@00
00040?ooo`<000000P3oool=0=7=Z@8000000`3oool2000000D0oooo2@0000040?ooo`80000000<0
oooo0000000000001P3oool300000080oooo0P0000020?ooo`L000000`3oool700000080oooo1@00
00040?ooo`8000000P3oool8000000@0oooo3@3AcJT2000000<0oooo100000000`3oool000000000
00040?ooo`D000000`3oool4000000030?ooo`000000000000@0000000<0oooo0000000000001@3o
ool2000000D0oooo0P0000020?ooo`D0000000<0oooo0000000000000P0000030?ooo`D00000103o
ool2000000030?ooo`0000000000008000000`3oool200000100dLfY000>0=7=Z@@0oooo0P000002
0?ooo`D000000P3oool400000080oooo0`0000020?ooo`8000000P3oool400000080oooo00<00000
0?ooo`3oool04`3oool=00000080oooo0P0000060?ooo`030000003oool0oooo008000000P3oool=
0=7=Z@80oooo0P0000090?ooo`8000001`3oool200000080oooo100000030?ooo`@000003`3oool4
000000<0oooo100000020?ooo`8000001`3oool2000000T0oooo0P0000020?ooo`d0dLfY0P3oool3
000000@0oooo1@0000040?ooo`8000000P3oool:000000@0oooo0P0000050?ooo`8000001@3oool2
000000@0oooo2P0000020?ooo`800000103oool5000000@0oooo0`0000020?ooo`d0dLfY0P000002
0?ooo`030000003oool0oooo00@000000`3oool400000080oooo0`0000040?ooo`030000003oool0
oooo008000000P3oool2000000030?ooo`000000000000H000001`3oool00`000000oooo0?ooo`02
00000080oooo0P0000030?ooo`@000000`3oool6000000<0oooo0P0000020?ooo`<000000P3oool=
0=7=Z@800000303oool:00000080oooo0P0000000`3oool00000000000020?ooo`80000000<0oooo
0000000000000P0000030?ooo`8000000`3oool400000080oooo00<000000?ooo`3oool00P000000
0`3oool00000000000020?ooo`X00000303oool200000100dLfY000>0=7=Z@@0oooo100000000`3o
ool00000000000020?ooo`8000000P3oool4000000030?ooo`00000000000080oooo100000020?oo
o`@000000`3oool:000000D0oooo2P0000050?ooo`800000103oool200000080oooo2@00000=0=7=
Z@@0oooo0`0000020?ooo`P000000P3oool3000000@0oooo0P0000040?ooo`<00000103oool20000
00L0oooo0P0000040?ooo`<00000103oool2000000@0oooo0`0000020?ooo`P000000P3oool30000
00@0oooo3@3AcJT4000000030?ooo`000000000000@0oooo0P0000070?ooo`8000000`3oool20000
0080oooo300000020?ooo`8000000P3oool<00000080oooo0P0000030?ooo`8000001`3oool20000
00@0oooo0P0000000`3oool0000000000002000000d0dLfY0P0000020?ooo`030000003oool0oooo
00@000000`3oool400000080oooo0`0000040?ooo`030000003oool0oooo008000000P3oool20000
00030?ooo`000000000000H000001`3oool00`000000oooo0?ooo`0200000080oooo0P0000030?oo
o`@000000`3oool6000000<0oooo0P0000020?ooo`<000000P3oool=0=7=Z@800000303oool:0000
0080oooo0P0000000`3oool00000000000020?ooo`80000000<0oooo0000000000000P0000030?oo
o`8000000`3oool400000080oooo00<000000?ooo`3oool00P0000000`3oool00000000000020?oo
o`X00000303oool200000100dLfY000>0=7=Z@@0oooo100000000`3oool00000000000020?ooo`80
00000P3oool4000000030?ooo`00000000000080oooo100000020?ooo`@000000`3oool:000000D0
oooo2P0000050?ooo`800000103oool200000080oooo2@00000=0=7=Z@@0oooo0`0000020?ooo`P0
00000P3oool3000000@0oooo0P0000040?ooo`<00000103oool2000000L0oooo0P0000040?ooo`<0
0000103oool2000000@0oooo0`0000020?ooo`P000000P3oool3000000@0oooo3@3AcJT400000003
0?ooo`000000000000@0oooo0P0000070?ooo`8000000`3oool200000080oooo300000020?ooo`80
00000P3oool<00000080oooo0P0000030?ooo`8000001`3oool2000000@0oooo0P0000000`3oool0
000000000002000000d0dLfY0P3oool500000080oooo0`0000020?ooo`8000000P3oool2000000D0
oooo1@00000;0?ooo`T000000P3oool3000000@0oooo300000020?ooo`D000000P3oool5000000@0
oooo3@3AcJT50?ooo`L000000P3oool?000000H0oooo00<000000?ooo`3oool00P0000000`3oool0
000000000004000000030?ooo`00000000000080oooo0P0000050?ooo`l000000P3oool7000000D0
oooo403AcJT000h0dLfY100000040?ooo`030000003oool0oooo008000000P3oool2000000@0oooo
0`00000:0?ooo`<000000P3oool400000080oooo4@0000050?ooo`@000000P3oool2000000@0oooo
0`0000060?ooo`d0dLfY0P3oool;00000080oooo0P0000020?ooo`L00000103oool2000000030?oo
o`000000000000P000000`3oool:000000030?ooo`000000000000@0oooo1`0000020?ooo`800000
0P3oool;00000080oooo3@3AcJT500000080oooo100000050?ooo`L000000P3oool4000000D0oooo
0P0000050?ooo`H000001@3oool2000000D0oooo100000020?ooo`L000001@3oool400000080oooo
1@00000=0=7=Z@80oooo1@0000020?ooo`<000000P3oool200000080oooo0P0000050?ooo`D00000
2`3oool900000080oooo0`0000040?ooo``000000P3oool500000080oooo1@0000040?ooo`d0dLfY
1@3oool700000080oooo3`0000060?ooo`030000003oool0oooo0080000000<0oooo000000000000
100000000`3oool00000000000020?ooo`8000001@3oool?00000080oooo1`0000050?oooa00dLfY
000>0=7=Z@@00000103oool00`000000oooo0?ooo`0200000080oooo0P0000040?ooo`<000002P3o
ool300000080oooo100000020?oooa4000001@3oool400000080oooo0P0000040?ooo`<000001P3o
ool=0=7=Z@80oooo2`0000020?ooo`8000000P3oool7000000@0oooo0P0000000`3oool000000000
0008000000<0oooo2P0000000`3oool00000000000040?ooo`L000000P3oool200000080oooo2`00
00020?ooo`d0dLfY1`3oool2000000D0oooo0P0000060?ooo`D000000P3oool5000000H0oooo00<0
00000?ooo`3oool00P0000020?ooo`8000001@3oool500000080oooo1@0000060?ooo`8000001@3o
ool2000000L0oooo3@3AcJT4000000030?ooo`00000000000080oooo0P0000000`3oool000000000
000400000080oooo00<000000?ooo`3oool01`3oool2000000D0oooo100000050?ooo`@000000P3o
ool9000000D0oooo0P0000000`3oool000000000000200000080oooo0P0000000`3oool000000000
0009000000d0dLfY0P3oool00`000000oooo0?ooo`050?ooo`8000001@3oool4000000<0oooo1@00
00060?ooo`<000000P3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool01000
00050?ooo`D000000`3oool4000000D0oooo0P0000070?ooo`030000003oool0oooo0100dLfY000>
0=7=Z@8000001P3oool00`000000oooo0?ooo`0400000080oooo4@0000050?ooo`@000000P3oool6
000000030?ooo`000000000000P000001`3oool4000000@0oooo0P0000020?ooo`030000003oool0
oooo0080oooo0P00000=0=7=Z@80oooo0P0000030?ooo`@00000103oool?00000080oooo00<00000
0?ooo`3oool00P0000040?ooo`8000000`3oool2000000@0oooo0P0000020?ooo`030000003oool0
oooo00l00000103oool4000000<0oooo0P0000020?ooo`d0dLfY1`3oool2000000D0oooo0P000006
0?ooo`D000000P3oool5000000H0oooo00<000000?ooo`3oool00P0000020?ooo`8000001@3oool5
00000080oooo1@0000060?ooo`8000001@3oool2000000L0oooo3@3AcJT4000000030?ooo`000000
00000080oooo0P0000000`3oool000000000000400000080oooo00<000000?ooo`3oool01`3oool2
000000D0oooo100000050?ooo`@000000P3oool9000000D0oooo0P0000000`3oool0000000000002
00000080oooo0P0000000`3oool0000000000009000000d0dLfY0P3oool300000080oooo0P000000
0`3oool000000000000200000080oooo1@0000000`3oool0000000000002000000<0oooo10000003
0?ooo`D000000P3oool200000080oooo1@0000030?ooo`@000000`3oool4000000030?ooo`000000
000000<000000P3oool4000000030?ooo`00000000000080oooo0`0000020?oooa00dLfY000>0=7=
Z@8000001P3oool00`000000oooo0?ooo`0400000080oooo4@0000050?ooo`@000000P3oool60000
00030?ooo`000000000000P000001`3oool4000000@0oooo0P0000020?ooo`030000003oool0oooo
0080oooo0P00000=0=7=Z@80oooo0P0000030?ooo`@00000103oool?00000080oooo00<000000?oo
o`3oool00P0000040?ooo`8000000`3oool2000000@0oooo0P0000020?ooo`030000003oool0oooo
00l00000103oool4000000<0oooo0P0000020?ooo`d0dLfY100000030?ooo`8000000P3oool50000
0080oooo0P0000030?ooo`800000103oool3000000H0oooo300000060?ooo`<00000103oool20000
00<0oooo0P0000020?ooo`D000000P3oool2000000<0oooo1000000=0=7=Z@80oooo1@00000=0?oo
o`030000003oool0oooo00@0000000<0oooo0000000000000P3oool=000000<0oooo0P0000020?oo
o`030000003oool0oooo008000000P3oool2000000D0oooo2@0000090?ooo`030000003oool0oooo
0080oooo3@3AcJT20?ooo`<000000P3oool2000000030?ooo`0000000000008000000P3oool50000
00030?ooo`0000000000008000000`3oool4000000<0oooo1@0000020?ooo`8000000P3oool50000
00<0oooo100000030?ooo`@0000000<0oooo0000000000000`0000020?ooo`@0000000<0oooo0000
000000000P3oool300000080oooo403AcJT000h0dLfY0P3oool2000000D0oooo0P0000020?ooo`80
00000P3oool4000000030?ooo`000000000000P000000P3oool5000000H0oooo100000050?ooo`80
00000P3oool200000080oooo100000000`3oool000000000000200000080oooo1P0000090?ooo`d0
dLfY0P3oool500000080oooo0P0000020?ooo`8000000P3oool2000000<0oooo0P0000040?ooo`L0
00000P3oool400000080oooo0`0000020?ooo`@000000P3oool7000000@0oooo0P0000030?ooo`80
00000P3oool200000080oooo0P0000020?ooo`D000000P3oool=0=7=Z@@000000`3oool200000080
oooo1@0000020?ooo`8000000`3oool2000000@0oooo0`0000060?ooo``000001P3oool3000000@0
oooo0P0000030?ooo`8000000P3oool500000080oooo0P0000030?ooo`@000003@3AcJT20?ooo`D0
00003@3oool00`000000oooo0?ooo`04000000030?ooo`00000000000080oooo3@0000030?ooo`80
00000P3oool00`000000oooo0?ooo`0200000080oooo0P0000050?ooo`T000002@3oool00`000000
oooo0?ooo`020?ooo`d0dLfY0P0000000`3oool000000000000200000080oooo0`00000:0?ooo`H0
00001@3oool300000080oooo0P0000000`3oool0000000000004000000030?ooo`00000000000080
oooo0`0000050?ooo`H000002P3oool300000080oooo100000000`3oool000000000000@0=7=Z@00
3P3AcJT20?ooo`8000001@3oool200000080oooo0P0000020?ooo`@0000000<0oooo000000000000
200000020?ooo`D000001P3oool4000000D0oooo0P0000020?ooo`8000000P3oool4000000030?oo
o`0000000000008000000P3oool6000000T0oooo3@3AcJT2000000@0oooo00<000000?ooo`3oool0
103oool2000000L0oooo0P0000060?ooo`8000001`3oool;000000L0oooo0P0000060?ooo`800000
1`3oool2000000H0oooo00<000000?ooo`3oool00P3oool2000000d0dLfY1@0000020?ooo`@00000
0P3oool00`000000oooo0?ooo`020?ooo`8000001@3oool2000000L0oooo1`0000020?ooo`800000
0P3oool7000000L0oooo0P0000050?ooo`800000103oool00`000000oooo0?ooo`0400000080oooo
1@00000=0=7=Z@D0oooo100000030?ooo`8000002@3oool200000080oooo00<000000?ooo`3oool0
0P0000020?ooo`8000001@3oool900000080oooo2P0000020?ooo`L000000P3oool200000080oooo
0`0000090?ooo`d0dLfY0P0000000`3oool000000000000200000080oooo0`00000:0?ooo`H00000
1@3oool300000080oooo0P0000000`3oool0000000000004000000030?ooo`00000000000080oooo
0`0000050?ooo`H000002P3oool300000080oooo100000000`3oool000000000000@0=7=Z@003P3A
cJT20?ooo`8000000P3oool300000080oooo0P0000020?ooo`@000000P3oool00`000000oooo0?oo
o`0200000080oooo0P0000070?ooo`@000002`3oool800000080oooo0P0000050?ooo`8000000P3o
ool6000000<0oooo0P0000040?ooo`d0dLfY0P0000040?ooo`030000003oool0oooo00@0oooo0P00
00070?ooo`8000001P3oool2000000L0oooo2`0000070?ooo`8000001P3oool2000000L0oooo0P00
00060?ooo`030000003oool0oooo0080oooo0P00000=0=7=Z@D000000P3oool400000080oooo00<0
00000?ooo`3oool00P3oool2000000D0oooo0P0000070?ooo`L000000P3oool200000080oooo1`00
00070?ooo`8000001@3oool2000000@0oooo00<000000?ooo`3oool0100000020?ooo`D000003@3A
cJT7000000L0oooo1`0000040?ooo`D000000P3oool2000000<0oooo0P0000020?ooo`@0000000<0
oooo0000000000000P3oool300000080oooo100000050?oooa0000000P3oool2000000D0oooo3@3A
cJT20?ooo`030000003oool0oooo008000001@3oool4000000D0oooo00<000000?ooo`3oool00P3o
ool2000000030?ooo`000000000000@0oooo00<000000?ooo`3oool00`0000020?ooo`8000000P3o
ool300000080oooo0P0000030?ooo`80000000<0oooo000000000000103oool00`000000oooo0?oo
o`030?ooo`@000001@3oool200000080oooo00<000000?ooo`3oool0403AcJT000h0dLfY0P3oool2
00000080oooo0`0000020?ooo`8000000P3oool400000080oooo00<000000?ooo`3oool00P000002
0?ooo`8000001`3oool4000000/0oooo200000020?ooo`8000001@3oool200000080oooo1P000003
0?ooo`800000103oool=0=7=Z@8000001`3oool200000080oooo0P0000020?ooo`8000000`3oool2
00000080oooo100000070?ooo`8000000P3oool700000080oooo0P0000070?ooo`@000000P3oool2
000000<0oooo0P0000020?ooo`8000000P3oool2000000L0oooo0P00000=0=7=Z@@000000`3oool2
000000D0oooo0P0000070?ooo`8000000P3oool200000080oooo1@0000040?ooo`030000003oool0
oooo008000000P3oool2000000<0oooo1@0000020?ooo`8000000P3oool2000000L0oooo0P000005
0?ooo`8000000`3oool4000000d0dLfY1`0000070?ooo`L00000103oool500000080oooo0P000003
0?ooo`8000000P3oool4000000030?ooo`00000000000080oooo0`0000020?ooo`@000001@3oool@
00000080oooo0P0000050?ooo`d0dLfY0P3oool00`000000oooo0?ooo`02000000D0oooo10000005
0?ooo`030000003oool0oooo0080oooo0P0000000`3oool00000000000040?ooo`030000003oool0
oooo00<000000P3oool200000080oooo0`0000020?ooo`8000000`3oool2000000030?ooo`000000
000000@0oooo00<000000?ooo`3oool00`3oool4000000D0oooo0P0000020?ooo`030000003oool0
oooo0100dLfY000>0=7=Z@@00000103oool=000000030?ooo`0000000000008000000P3oool40000
0080oooo1@0000020?ooo`8000000P3oool?00000080oooo1000000=0?ooo`80000000<0oooo0000
000000000P0000020?ooo`d0dLfY0P0000070?ooo`8000000P3oool200000080oooo0P0000030?oo
o`8000000P3oool4000000L0oooo0P0000020?ooo`L000000P3oool2000000L0oooo100000020?oo
o`8000000`3oool200000080oooo0P0000020?ooo`8000001`3oool2000000d0dLfY100000030?oo
o`8000001@3oool2000000L0oooo0P0000020?ooo`8000000P3oool5000000@0oooo00<000000?oo
o`3oool00P0000020?ooo`8000000`3oool500000080oooo0P0000020?ooo`8000001`3oool20000
00D0oooo0P0000030?ooo`@000003@3AcJT;0?ooo`030000003oool0oooo008000000P3oool20000
00<0oooo100000070?ooo`8000000`3oool400000080oooo00<000000?ooo`3oool02@0000020?oo
o`<000000P3oool5000000@0oooo1`0000050?ooo`@000003@3AcJT90?ooo`030000003oool0oooo
00@00000203oool2000000D0oooo0P0000020?ooo`030000003oool0oooo00`000000P3oool20000
00030?ooo`000000000000D0oooo0P0000080?ooo`@000000P3oool00`000000oooo0?ooo`070?oo
oa00dLfY000>0=7=Z@@00000103oool=000000030?ooo`0000000000008000000P3oool400000080
oooo1@0000020?ooo`8000000P3oool?00000080oooo1000000=0?ooo`80000000<0oooo00000000
00000P0000020?ooo`d0dLfY0P3oool4000000030?ooo`0000000000008000000P3oool6000000<0
oooo100000020?ooo`D000000P3oool600000080oooo0`0000020?ooo`H000000P3oool500000080
oooo100000030?ooo`H000000P3oool4000000030?ooo`0000000000008000000P3oool=0=7=Z@T0
00000P3oool3000000@0oooo0P0000020?ooo`L000000`3oool6000000D0oooo0P0000050?ooo`H0
00000`3oool700000080oooo0P0000040?ooo`<000000P3oool9000000d0dLfY2`3oool00`000000
oooo0?ooo`0200000080oooo0P0000030?ooo`@000001`3oool2000000<0oooo100000020?ooo`03
0000003oool0oooo00T000000P3oool300000080oooo1@0000040?ooo`L000001@3oool4000000d0
dLfY0`0000060?ooo`<00000103oool5000000030?ooo`000000000000D00000303oool6000000`0
oooo1`0000000`3oool0000000000003000000@0oooo0`0000060?ooo`<00000403AcJT000h0dLfY
100000040?ooo`<000001P3oool;00000080oooo0P0000020?ooo`8000001@3oool2000000P0oooo
0`0000040?ooo`800000103oool2000000030?ooo`00000000000080oooo0P0000060?ooo`<00000
0P3oool4000000d0dLfY0P3oool4000000030?ooo`0000000000008000000P3oool6000000<0oooo
100000020?ooo`D000000P3oool600000080oooo0`0000020?ooo`H000000P3oool500000080oooo
100000030?ooo`H000000P3oool4000000030?ooo`0000000000008000000P3oool=0=7=Z@L0oooo
2`0000020?ooo`D000001P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo
0?ooo`0200000080oooo0P0000000`3oool00000000000040?ooo`030000003oool0oooo00@0oooo
1@0000020?ooo`/000001`3oool=0=7=Z@80oooo0`0000040?ooo`<000001P3oool2000000030?oo
o`0000000000008000000`3oool600000080oooo00<000000?ooo`3oool00P0000020?ooo`D00000
103oool00`000000oooo0?ooo`060?ooo`<000002@3oool2000000D0oooo2@00000=0=7=Z@<00000
1P3oool3000000@0oooo1@0000000`3oool0000000000005000000`0oooo1P00000<0?ooo`L00000
00<0oooo0000000000000`0000040?ooo`<000001P3oool300000100dLfY000>0=7=Z@@00000103o
ool3000000H0oooo2`0000020?ooo`8000000P3oool2000000D0oooo0P0000080?ooo`<00000103o
ool2000000@0oooo0P0000000`3oool00000000000020?ooo`8000001P3oool300000080oooo1000
000=0=7=Z@8000000P3oool7000000H0oooo0P0000070?ooo`@000000`3oool8000000L0oooo2000
00030?ooo`@000001`3oool2000000H0oooo1`0000020?ooo`8000003@3AcJT70?ooo`/000000P3o
ool5000000H0oooo00<000000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3oool00P00
00020?ooo`80000000<0oooo000000000000103oool00`000000oooo0?ooo`040?ooo`D000000P3o
ool;000000L0oooo3@3AcJT20?ooo`<00000103oool3000000H0oooo0P0000000`3oool000000000
0002000000<0oooo1P0000020?ooo`030000003oool0oooo008000000P3oool5000000@0oooo00<0
00000?ooo`3oool01P3oool3000000T0oooo0P0000050?ooo`T000003@3AcJT20?ooo`<000001@3o
ool400000080oooo0`0000050?ooo`8000000P3oool3000000@0oooo00<000000?ooo`3oool00P00
00000`3oool0000000000004000000030?ooo`00000000000080oooo0P0000030?ooo`<000000P3o
ool2000000D0oooo0`0000020?ooo`@000001@3oool300000080oooo403AcJT000h0dLfY0P3oool2
000000L0oooo100000020?ooo`@000000`3oool400000080oooo1P0000030?ooo`800000103oool2
00000080oooo0`0000020?ooo`P000001@3oool2000000@0oooo0P0000060?ooo`L000003@3AcJT2
00000080oooo1`0000060?ooo`8000001`3oool4000000<0oooo200000070?ooo`P000000`3oool4
000000L0oooo0P0000060?ooo`L000000P3oool2000000d0dLfY0P0000090?ooo`80000000<0oooo
000000000000100000050?ooo`@000000P3oool5000000D0oooo1P0000050?ooo`D000000P3oool4
000000D0oooo1P0000000`3oool00000000000090?ooo`8000003@3AcJT4000000<0oooo10000000
0`3oool0000000000007000000H0oooo2P0000020?ooo`8000001@3oool200000080oooo0P000000
0`3oool00000000000020?ooo`8000000P3oool500000080oooo00<000000?ooo`3oool00P3oool2
00000080oooo00<000000?ooo`3oool00P0000030?ooo`@000003@3AcJT20?ooo`<000001@3oool4
00000080oooo0`0000050?ooo`8000000P3oool3000000@0oooo00<000000?ooo`3oool00P000000
0`3oool0000000000004000000030?ooo`00000000000080oooo0P0000030?ooo`<000000P3oool2
000000D0oooo0`0000020?ooo`@000001@3oool300000080oooo403AcJT000h0dLfY103oool40000
00D0oooo0P0000020?ooo`L00000103oool200000080oooo100000000`3oool00000000000020000
0080oooo1P0000020?ooo`030000003oool0oooo0080oooo200000090?ooo`8000000P3oool20000
00<0oooo100000020?ooo`d0dLfY0P3oool200000080oooo1`0000020?ooo`@0000000<0oooo0000
000000000P3oool6000000D0oooo1000000;0?ooo`@000001@3oool600000080oooo0P0000000`3o
ool000000000000200000080oooo1`0000020?ooo`8000000P3oool=0=7=Z@8000002@3oool20000
00030?ooo`000000000000@000001@3oool400000080oooo1@0000050?ooo`H000001@3oool50000
0080oooo100000050?ooo`H0000000<0oooo0000000000002@3oool2000000d0dLfY0P0000020?oo
o`030000003oool0oooo00@000001@3oool9000000<0oooo100000020?ooo`L000002@3oool30000
0080oooo0P0000020?ooo`8000000`3oool200000080oooo300000020?ooo`D000000P3oool=0=7=
Z@D00000303oool700000080oooo0`0000040?oooaH00000103oool300000080oooo1`00000<0?oo
o`D00000403AcJT000h0dLfY103oool4000000D0oooo0P0000020?ooo`L00000103oool200000080
oooo100000000`3oool000000000000200000080oooo1P0000020?ooo`030000003oool0oooo0080
oooo200000090?ooo`8000000P3oool2000000<0oooo100000020?ooo`d0dLfY0P3oool200000080
oooo1`0000020?ooo`@0000000<0oooo0000000000000P3oool6000000D0oooo1000000;0?ooo`@0
00001@3oool600000080oooo0P0000000`3oool000000000000200000080oooo1`0000020?ooo`80
00000P3oool=0=7=Z@@0oooo0`0000040?ooo`80000000<0oooo0000000000000P3oool500000080
oooo0P0000040?ooo`D00000103oool9000000<0oooo1@0000040?ooo`8000000P3oool500000080
oooo0P0000000`3oool00000000000040?ooo`<00000103oool=0=7=Z@8000000P3oool00`000000
oooo0?ooo`04000000D0oooo2@0000030?ooo`@000000P3oool7000000T0oooo0`0000020?ooo`80
00000P3oool2000000<0oooo0P0000020?ooo``000000P3oool500000080oooo3@3AcJT5000000`0
oooo1`0000020?ooo`<00000103ooolF000000@0oooo0`0000020?ooo`L00000303oool500000100
dLfY000>0=7=Z@8000001`3oool4000000@0oooo100000000`3oool000000000000400000080oooo
0P0000040?ooo`<00000103oool900000080oooo0P0000020?ooo`8000000P3oool200000080oooo
2@0000070?ooo`@000000P3oool=0=7=Z@@000000P3oool00`000000oooo0?ooo`040?ooo`L00000
0P3oool200000080oooo1P0000030?ooo`H000001`3oool6000000<0oooo1P0000020?ooo`800000
0P3oool7000000H0oooo00<000000?ooo`3oool01000000=0=7=Z@@0oooo0`0000040?ooo`800000
00<0oooo0000000000000P3oool500000080oooo0P0000040?ooo`D00000103oool9000000<0oooo
1@0000040?ooo`8000000P3oool500000080oooo0P0000000`3oool00000000000040?ooo`<00000
103oool=0=7=Z@8000000`3oool2000000@0oooo00<000000?ooo`3oool00P3oool900000080oooo
0`0000040?ooo`D000000P3oool200000080oooo1@0000050?ooo`@000000P3oool00`000000oooo
0?ooo`020?ooo`<000000P3oool2000000@0oooo0`0000020?ooo`80000000<0oooo000000000000
0P3oool=0=7=Z@X000000P3oool4000000<0oooo0P0000000`3oool00000000000050?ooo`800000
0P3oool2000000<0oooo0P0000000`3oool0000000000004000000030?ooo`000000000000@0oooo
00<000000?ooo`3oool00P0000050?ooo`80000000<0oooo0000000000000`3oool400000080oooo
2P00000@0=7=Z@003P3AcJT2000000L0oooo100000040?ooo`@0000000<0oooo0000000000001000
00020?ooo`800000103oool3000000@0oooo2@0000020?ooo`8000000P3oool200000080oooo0P00
00020?ooo`T000001`3oool400000080oooo3@3AcJT400000080oooo00<000000?ooo`3oool0103o
ool700000080oooo0P0000020?ooo`H000000`3oool6000000L0oooo1P0000030?ooo`H000000P3o
ool200000080oooo1`0000060?ooo`030000003oool0oooo00@000003@3AcJT20?ooo`80000000<0
oooo000000000000103oool2000000030?ooo`00000000000080oooo0P0000050?ooo`8000000P3o
ool2000000030?ooo`00000000000080oooo400000020?ooo`80000000<0oooo0000000000000P3o
ool2000000D0oooo0P0000020?ooo`80000000<0oooo000000000000103oool2000000030?ooo`00
000000000080oooo3@3AcJT2000000<0oooo0P0000040?ooo`030000003oool0oooo0080oooo2@00
00020?ooo`<00000103oool500000080oooo0P0000020?ooo`D000001@3oool400000080oooo00<0
00000?ooo`3oool00P3oool300000080oooo0P0000040?ooo`<000000P3oool2000000030?ooo`00
000000000080oooo3@3AcJT20?ooo`<000000P3oool300000080oooo0P0000020?ooo`<000002@3o
ool00`000000oooo0?ooo`020?ooo`80000000<0oooo0000000000000P0000030?ooo`8000000`3o
ool400000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`<000000P3o
ool200000080oooo0`0000020?ooo`<000000P3oool@0=7=Z@003P3AcJT20?ooo`H0000000<0oooo
000000000000100000020?ooo`8000001`3oool400000080oooo100000000`3oool0000000000002
00000080oooo1P0000020?ooo`030000003oool0oooo00H0oooo0P0000020?ooo`8000001`3oool2
00000080oooo0P0000020?ooo`030000003oool0oooo0080oooo0P00000=0=7=Z@80oooo10000000
0`3oool00000000000020?ooo`800000103oool2000000030?ooo`0000000000008000001P3oool2
000000030?ooo`000000000000@0oooo0P0000070?ooo`800000103oool2000000030?ooo`000000
000000H0oooo100000000`3oool00000000000040?ooo`8000000P3oool2000000030?ooo`000000
0000008000000P3oool=0=7=Z@80oooo0P0000000`3oool00000000000040?ooo`80000000<0oooo
0000000000000P3oool2000000D0oooo0P0000020?ooo`80000000<0oooo0000000000000P3oool@
00000080oooo0P0000000`3oool00000000000020?ooo`8000001@3oool200000080oooo0P000000
0`3oool00000000000040?ooo`80000000<0oooo0000000000000P3oool=0=7=Z@8000000P3oool0
0`000000oooo0?ooo`02000000D0oooo0P0000020?ooo`8000000`3oool4000000030?ooo`000000
00000080oooo0P0000020?ooo`030000003oool0oooo00@0oooo0`0000040?ooo`80000000<0oooo
0000000000001P0000030?ooo`T000000P3oool9000000030?ooo`0000000000008000003@3AcJT2
0?ooo`<000000P3oool300000080oooo0P0000020?ooo`<000002@3oool00`000000oooo0?ooo`02
0?ooo`80000000<0oooo0000000000000P0000030?ooo`8000000`3oool400000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`<000000P3oool200000080oooo0`000002
0?ooo`<000000P3oool@0=7=Z@003P3AcJT20?ooo`H0000000<0oooo000000000000100000020?oo
o`8000001`3oool400000080oooo100000000`3oool000000000000200000080oooo1P0000020?oo
o`030000003oool0oooo00H0oooo0P0000020?ooo`8000001`3oool200000080oooo0P0000020?oo
o`030000003oool0oooo0080oooo0P00000=0=7=Z@@000000P3oool5000000@0oooo1@0000020?oo
o`@000001P3oool00`000000oooo0?ooo`0400000080oooo1`0000020?ooo`@000000P3oool00`00
0000oooo0?ooo`040?ooo`@000000P3oool5000000@0oooo1@0000020?ooo`@000003@3AcJT40000
01D0oooo0P0000020?ooo`80000000<0oooo0000000000000P0000020?ooo`8000000`3oool20000
00@0oooo00<000000?ooo`3oool0100000000`3oool00000000000020?ooo`8000005@3oool40000
00d0dLfY0P0000020?ooo`030000003oool0oooo008000001@3oool200000080oooo0P0000030?oo
o`@0000000<0oooo0000000000000P3oool200000080oooo00<000000?ooo`3oool0103oool30000
00@0oooo0P0000000`3oool0000000000006000000<0oooo2@0000020?ooo`T0000000<0oooo0000
000000000P00000=0=7=Z@D000000P3oool2000000030?ooo`0000000000008000000P3oool00`00
0000oooo0?ooo`020?ooo`<000000P3oool2000000030?ooo`000000000000@0oooo1P0000020?oo
o`8000000P3oool7000000<0oooo0P0000000`3oool00000000000020?ooo`<00000103oool00`00
0000oooo0?ooo`04000000030?ooo`00000000000080oooo1@00000@0=7=Z@003P3AcJT80?ooo`03
0000003oool0oooo0080oooo100000020?ooo`80000000<0oooo0000000000001P0000020?ooo`D0
0000103oool2000000P0oooo1`0000080?ooo`030000003oool0oooo0080oooo2P0000030?ooo`@0
00003@3AcJT400000080oooo1@0000040?ooo`D000000P3oool4000000H0oooo00<000000?ooo`3o
ool0100000020?ooo`L000000P3oool400000080oooo00<000000?ooo`3oool0103oool400000080
oooo1@0000040?ooo`D000000P3oool4000000d0dLfY1000000E0?ooo`8000000P3oool200000003
0?ooo`0000000000008000000P3oool2000000<0oooo0P0000040?ooo`030000003oool0oooo00@0
000000<0oooo0000000000000P3oool2000001D0oooo1000000=0=7=Z@80oooo2P0000020?ooo`@0
00000P3oool00`000000oooo0?ooo`04000000030?ooo`00000000000080oooo1@0000060?ooo`80
00000`3oool200000080oooo1@0000040?ooo`030000003oool0oooo008000000P3oool00`000000
oooo0?ooo`04000000T0oooo00<000000?ooo`3oool00P3oool=0=7=Z@D000000P3oool200000003
0?ooo`0000000000008000000P3oool00`000000oooo0?ooo`020?ooo`<000000P3oool200000003
0?ooo`000000000000@0oooo1P0000020?ooo`8000000P3oool7000000<0oooo0P0000000`3oool0
0000000000020?ooo`<00000103oool00`000000oooo0?ooo`04000000030?ooo`00000000000080
oooo1@00000@0=7=Z@003P3AcJT80?ooo`030000003oool0oooo0080oooo100000020?ooo`800000
00<0oooo0000000000001P0000020?ooo`D00000103oool2000000P0oooo1`0000080?ooo`030000
003oool0oooo0080oooo2P0000030?ooo`@000003@3AcJT60?ooo`h00000103oool?00000080oooo
0P0000030?ooo`8000000P3oool?000000@0oooo3P0000060?ooo`d0dLfY100000000`3oool00000
00000002000000@0oooo0`0000020?ooo`L00000103oool2000000030?ooo`000000000000H00000
0`3oool2000000@0oooo1`0000000`3oool00000000000040?ooo`L000000P3oool3000000@0oooo
100000000`3oool0000000000002000000d0dLfY0P3oool:00000080oooo100000020?ooo`030000
003oool0oooo00@0000000<0oooo0000000000000P3oool5000000H0oooo0P0000030?ooo`800000
0P3oool5000000@0oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo00@00000
2@3oool00`000000oooo0?ooo`020?ooo`d0dLfY0P0000030?ooo`@000002P3oool2000000P0oooo
0P0000050?ooo`8000000P3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool0
0P0000050?ooo`800000203oool2000000X0oooo100000030?ooo`800000403AcJT000h0dLfY0P3o
ool2000000D0oooo100000020?ooo`8000000P3oool2000000030?ooo`000000000000H0oooo0P00
00020?ooo`D000000P3oool:000000D0oooo1P0000050?ooo`@000000P3oool200000080oooo0P00
00020?ooo`030000003oool0oooo00@000003@3AcJT60?ooo`h00000103oool?00000080oooo0P00
00030?ooo`8000000P3oool?000000@0oooo3P0000060?ooo`d0dLfY0P3oool2000000030?ooo`00
0000000000@0oooo0P0000050?ooo`D000000P3oool400000080oooo1@0000040?ooo`030000003o
ool0oooo008000000P3oool2000000<0oooo1@0000020?ooo`@000000P3oool5000000D0oooo0P00
00040?ooo`80000000<0oooo0000000000000P3oool=0=7=Z@@0000000<0oooo0000000000003P00
00090?ooo`H000001@3oool2000000<0oooo0P0000020?ooo`D00000103oool2000000030?ooo`00
0000000000d000001`3oool300000080oooo3@3AcJT2000000<0oooo1000000:0?ooo`800000203o
ool2000000D0oooo0P0000020?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?oo
o`02000000D0oooo0P0000080?ooo`8000002P3oool4000000<0oooo0P00000@0=7=Z@003P3AcJT2
0?ooo`8000001@3oool400000080oooo0P0000020?ooo`80000000<0oooo0000000000001P3oool2
00000080oooo1@0000020?ooo`X000001@3oool6000000D0oooo100000020?ooo`8000000P3oool2
00000080oooo00<000000?ooo`3oool01000000=0=7=Z@8000000P3oool9000000@0oooo0P000009
0?ooo`@000000`3oool4000000/0oooo100000030?ooo`@000002@3oool2000000@0oooo2@000002
0?ooo`8000003@3AcJT20?ooo`80000000<0oooo000000000000103oool2000000D0oooo1@000002
0?ooo`@000000P3oool5000000@0oooo00<000000?ooo`3oool00P0000020?ooo`8000000`3oool5
00000080oooo100000020?ooo`D000001@3oool2000000@0oooo0P0000000`3oool0000000000002
0?ooo`d0dLfY100000050?ooo`T000002@3oool00`000000oooo0?ooo`0400000080oooo00<00000
0?ooo`3oool01P0000050?ooo`<000000P3oool200000080oooo0`0000020?ooo`@000002@3oool0
0`000000oooo0?ooo`020?ooo`80000000<0oooo0000000000000P3oool=0=7=Z@D00000103oool0
0`000000oooo0?ooo`04000000H0oooo100000050?ooo`8000000P3oool00`000000oooo0?ooo`05
0?ooo`8000001`3oool2000000030?ooo`000000000000D0oooo100000060?ooo`@000000P3oool0
0`000000oooo0?ooo`020?ooo`D00000403AcJT000h0dLfY103oool4000000030?ooo`0000000000
00P0oooo1@0000040?ooo`H000000P3oool3000000@0oooo100000020?ooo`<000000P3oool20000
0080oooo100000020?ooo`80000000<0oooo000000000000103oool2000000L0oooo0P0000040?oo
o`d0dLfY0P0000020?ooo`T00000103oool2000000T0oooo100000030?ooo`@000002`3oool40000
00<0oooo100000090?ooo`800000103oool900000080oooo0P00000=0=7=Z@/0oooo2@0000030?oo
o`@000000P3oool2000000030?ooo`000000000000L000000P3oool200000080oooo2@0000000`3o
ool00000000000020?ooo`@000000`3oool9000000/0oooo3@3AcJT4000000D0oooo2@0000090?oo
o`030000003oool0oooo00@000000P3oool00`000000oooo0?ooo`06000000D0oooo0`0000020?oo
o`8000000P3oool300000080oooo100000090?ooo`030000003oool0oooo0080oooo0P0000000`3o
ool00000000000020?ooo`d0dLfY0P0000000`3oool000000000000200000080oooo00<000000?oo
o`3oool00P3oool2000000030?ooo`00000000000080oooo00<000000?ooo`3oool00P0000030?oo
o`8000000P3oool300000080oooo0P0000000`3oool0000000000004000000030?ooo`0000000000
0080oooo0`0000020?ooo`8000000`3oool200000080oooo00<000000?ooo`3oool00P0000000`3o
ool00000000000040?ooo`030000003oool0oooo00@0000000<0oooo000000000000403AcJT000h0
dLfY103oool4000000030?ooo`000000000000P0oooo1@0000040?ooo`H000000P3oool3000000@0
oooo100000020?ooo`<000000P3oool200000080oooo100000020?ooo`80000000<0oooo00000000
0000103oool2000000L0oooo0P0000040?ooo`d0dLfY0P0000020?ooo`8000001`3oool400000080
oooo00<000000?ooo`3oool00P3oool200000080oooo1@00000G0?ooo`D000000P3oool2000000@0
oooo00<000000?ooo`3oool0100000070?ooo`8000000P3oool2000000d0dLfY2`3oool9000000<0
oooo100000020?ooo`80000000<0oooo0000000000001`0000020?ooo`8000000P3oool900000003
0?ooo`00000000000080oooo100000030?ooo`T000002`3oool=0=7=Z@80oooo0`0000020?ooo`@0
00000`3oool200000080oooo0P0000000`3oool0000000000004000000L0oooo1`0000040?ooo`03
0000003oool0oooo008000000`3oool200000080oooo0P0000050?ooo`8000000P3oool700000080
oooo00<000000?ooo`3oool0100000000`3oool0000000000002000000d0dLfY0P0000000`3oool0
00000000000200000080oooo00<000000?ooo`3oool00P3oool2000000030?ooo`00000000000080
oooo00<000000?ooo`3oool00P0000030?ooo`8000000P3oool300000080oooo0P0000000`3oool0
000000000004000000030?ooo`00000000000080oooo0`0000020?ooo`8000000`3oool200000080
oooo00<000000?ooo`3oool00P0000000`3oool00000000000040?ooo`030000003oool0oooo00@0
000000<0oooo000000000000403AcJT000h0dLfY100000020?ooo`D000000P3oool600000080oooo
00<000000?ooo`3oool00P3oool400000080oooo0P0000050?ooo`H000000P3oool200000080oooo
2@0000020?ooo`@0000000<0oooo0000000000001P3oool6000000030?ooo`000000000000@0oooo
3@3AcJT200000080oooo0P0000070?ooo`@000000P3oool00`000000oooo0?ooo`020?ooo`800000
0P3oool5000001L0oooo1@0000020?ooo`800000103oool00`000000oooo0?ooo`04000000L0oooo
0P0000020?ooo`8000003@3AcJT4000000030?ooo`000000000000H0000000<0oooo000000000000
0P3oool4000000<0oooo2@0000060?ooo`T000001@3oool9000000<0oooo100000020?ooo`800000
00<0oooo0000000000001P0000000`3oool0000000000002000000d0dLfY0P3oool300000080oooo
100000030?ooo`8000000P3oool2000000030?ooo`000000000000@000001`3oool7000000@0oooo
00<000000?ooo`3oool00P0000030?ooo`8000000P3oool2000000D0oooo0P0000020?ooo`L00000
0P3oool00`000000oooo0?ooo`04000000030?ooo`0000000000008000003@3AcJT20?ooo`030000
003oool0oooo008000000P3oool00`000000oooo0?ooo`02000000`0oooo2@0000000`3oool00000
00000002000000<0oooo0P0000030?ooo`@000000P3oool8000000`0oooo0P0000020?ooo`030000
003oool0oooo008000000P3oool00`000000oooo0?ooo`0@0=7=Z@003P3AcJT400000080oooo1@00
00020?ooo`H000000P3oool00`000000oooo0?ooo`020?ooo`@000000P3oool2000000D0oooo1P00
00020?ooo`8000000P3oool900000080oooo100000000`3oool00000000000060?ooo`H0000000<0
oooo000000000000103oool=0=7=ZA40oooo0P0000000`3oool000000000000:0?ooo`030000003o
ool0oooo00@000000P3oool700000080oooo100000020?ooo`030000003oool0oooo00P0oooo0P00
00000`3oool000000000000A0?ooo`d0dLfY100000000`3oool0000000000006000000030?ooo`00
000000000080oooo100000030?ooo`T000001P3oool9000000D0oooo2@0000030?ooo`@000000P3o
ool2000000030?ooo`000000000000H0000000<0oooo0000000000000P00000=0=7=Z@80oooo1@00
00050?ooo`H000000P3oool5000000D0oooo0P0000020?ooo`<00000103oool7000000@0oooo00<0
00000?ooo`3oool00P3oool200000080oooo0`0000020?ooo`<000000P3oool400000080oooo0`00
00040?ooo`<000000P3oool=0=7=Z@80oooo00<000000?ooo`3oool00P0000020?ooo`030000003o
ool0oooo00800000303oool9000000030?ooo`0000000000008000000`3oool2000000<0oooo1000
00020?ooo`P00000303oool200000080oooo00<000000?ooo`3oool00P0000020?ooo`030000003o
ool0oooo0100dLfY000>0=7=Z@8000001P3oool00`000000oooo0?ooo`020?ooo`H000000`3oool4
000000P0oooo0`0000020?ooo`@000000P3oool6000000030?ooo`000000000000H0oooo10000002
0?ooo`D00000103oool2000000D0oooo1P00000=0=7=ZA40oooo0P0000000`3oool000000000000:
0?ooo`030000003oool0oooo00@000000P3oool700000080oooo100000020?ooo`030000003oool0
oooo00P0oooo0P0000000`3oool000000000000A0?ooo`d0dLfY100000030?ooo`8000000P3oool5
00000080oooo100000030?ooo`l000000`3oool2000000@0oooo3P0000030?ooo`@000000P3oool5
00000080oooo0P0000030?ooo`@000003@3AcJT20?ooo`D000001@3oool600000080oooo1@000005
0?ooo`8000000P3oool3000000@0oooo1`0000040?ooo`030000003oool0oooo0080oooo0P000002
0?ooo`<000000P3oool300000080oooo100000020?ooo`<00000103oool300000080oooo3@3AcJT2
000000030?ooo`000000000000@0oooo00<000000?ooo`3oool01@0000020?ooo`80000000<0oooo
000000000000103oool<000000030?ooo`000000000000@0000000<0oooo0000000000002P000004
0?ooo`80000000<0oooo0000000000000P3oool500000080oooo00<000000?ooo`3oool00P3oool2
000000030?ooo`00000000000100dLfY000>0=7=Z@8000001P3oool00`000000oooo0?ooo`020?oo
o`H000000`3oool4000000P0oooo0`0000020?ooo`@000000P3oool6000000030?ooo`0000000000
00H0oooo100000020?ooo`D00000103oool2000000D0oooo1P00000=0=7=Z@@000000`3oool80000
00D0oooo0P0000020?ooo`H000000P3oool700000080oooo0P0000030?ooo`8000000P3oool70000
0080oooo1P0000020?ooo`8000001@3oool8000000<0oooo1000000=0=7=Z@@000000`3oool20000
0080oooo1@0000020?ooo`@000000`3oool?000000<0oooo0P0000040?ooo`h000000`3oool40000
0080oooo1@0000020?ooo`8000000`3oool4000000d0dLfY1@0000060?ooo`D000000P3oool30000
00H0oooo00<000000?ooo`3oool0103oool3000000@0oooo0P0000020?ooo`D000001@3oool40000
00<0oooo100000020?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool0oooo
00L000000P3oool=0=7=Z@80000000<0oooo000000000000103oool00`000000oooo0?ooo`050000
0080oooo0P0000000`3oool00000000000040?ooo``0000000<0oooo000000000000100000000`3o
ool000000000000:000000@0oooo0P0000000`3oool00000000000020?ooo`D000000P3oool00`00
0000oooo0?ooo`020?ooo`80000000<0oooo000000000000403AcJT000h0dLfY0P3oool200000080
oooo1@0000020?ooo`8000003@3oool600000080oooo1@0000020?ooo`8000000P3oool2000000<0
oooo0P0000080?oooa4000001@3oool4000000d0dLfY100000030?ooo`P000001@3oool200000080
oooo1P0000020?ooo`L000000P3oool2000000<0oooo0P0000020?ooo`L000000P3oool600000080
oooo0P0000050?ooo`P000000`3oool4000000d0dLfY100000030?ooo`@000000`3oool2000000@0
oooo0P0000000`3oool0000000000002000000T0oooo400000090?ooo`@0000000<0oooo00000000
0000103oool2000000<0oooo100000030?ooo`@000003@3AcJT5000000H0oooo1@0000020?ooo`<0
00001P3oool00`000000oooo0?ooo`040?ooo`<00000103oool200000080oooo1@0000050?ooo`@0
00000`3oool400000080oooo00<000000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3o
ool01`0000020?ooo`d0dLfY0P0000050?ooo`80000000<0oooo000000000000100000000`3oool0
0000000000050?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`D000000P3oool00`000000
oooo0?ooo`0200000080oooo00<000000?ooo`3oool01@0000040?ooo`030000003oool0oooo0080
00001@3oool2000000030?ooo`000000000000@0000000<0oooo0000000000001@3oool200000100
dLfY000>0=7=Z@80oooo100000020?ooo`030000003oool0oooo0080oooo200000000`3oool00000
000000020?ooo`P000000P3oool300000080oooo0P0000020?ooo`800000103oool3000000@0oooo
200000030?ooo`P000000P3oool2000000L0oooo3@3AcJT20?ooo`@000000`3oool600000080oooo
0`0000020?ooo`H000000P3oool2000000030?ooo`000000000000@0oooo100000030?ooo`@00000
103oool2000000030?ooo`00000000000080oooo1P0000020?ooo`<000000P3oool6000000<0oooo
100000020?ooo`d0dLfY100000030?ooo`@000001`3oool5000000P0oooo0`0000020?ooo`D00000
0P3oool200000080oooo1@0000020?ooo`<00000203oool5000000L0oooo100000030?ooo`@00000
3@3AcJT50?ooo`@000001@3oool4000000<0oooo1P0000000`3oool00000000000020?ooo`800000
0`3oool200000080oooo100000000`3oool00000000000020?ooo`80000000<0oooo000000000000
0P0000050?ooo`8000000P3oool500000080oooo100000000`3oool0000000000002000000<0oooo
1000000=0=7=Z@<0oooo1`0000020?ooo`8000000P3oool00`000000oooo0?ooo`02000000<0oooo
100000030?ooo`D00000103oool8000000@0oooo1@0000030?ooo`@000000`3oool200000080oooo
00<000000?ooo`3oool00P0000020?ooo`L000000`3oool@0=7=Z@003P3AcJT20?ooo`@000000P3o
ool00`000000oooo0?ooo`020?ooo`P0000000<0oooo0000000000000P3oool800000080oooo0`00
00020?ooo`8000000P3oool2000000@0oooo0`0000040?ooo`P000000`3oool800000080oooo0P00
00070?ooo`d0dLfY1P3oool00`000000oooo0?ooo`0400000080oooo0P0000090?ooo`800000103o
ool00`000000oooo0?ooo`040?ooo`/000001P3oool00`000000oooo0?ooo`020?ooo`8000002@3o
ool200000080oooo100000020?ooo`030000003oool0oooo00@0oooo3@3AcJT4000000<0oooo1000
00070?ooo`D00000203oool300000080oooo1@0000020?ooo`8000000P3oool500000080oooo0`00
00080?ooo`D000001`3oool4000000<0oooo1000000=0=7=Z@80oooo0P0000000`3oool000000000
00040?ooo`030000003oool0oooo00@0oooo0P0000000`3oool0000000000004000000030?ooo`00
0000000000H000001@3oool700000080oooo0`0000040?ooo`8000001@3oool700000080oooo1@00
00020?ooo`@0000000<0oooo0000000000000P00000=0=7=Z@<0oooo1`0000020?ooo`8000000P3o
ool00`000000oooo0?ooo`02000000<0oooo100000030?ooo`D00000103oool8000000@0oooo1@00
00030?ooo`@000000`3oool200000080oooo00<000000?ooo`3oool00P0000020?ooo`L000000`3o
ool@0=7=Z@003P3AcJT9000000@0oooo200000000`3oool00000000000040?ooo`H000000P3oool0
0`000000oooo0?ooo`0600000080oooo100000030?ooo`@000000P3oool2000000T0oooo10000004
0?ooo`D000000P3oool2000000d0dLfY1P3oool00`000000oooo0?ooo`0400000080oooo0P000009
0?ooo`800000103oool00`000000oooo0?ooo`040?ooo`/000001P3oool00`000000oooo0?ooo`02
0?ooo`8000002@3oool200000080oooo100000020?ooo`030000003oool0oooo00@0oooo3@3AcJT4
000000<0oooo100000050?ooo`8000000P3oool300000080oooo100000020?ooo`<000000P3oool5
00000080oooo0P0000020?ooo`D000000P3oool300000080oooo100000020?ooo`<000000P3oool2
000000D0oooo100000030?ooo`@000003@3AcJT20?ooo`80000000<0oooo000000000000103oool0
0`000000oooo0?ooo`040?ooo`80000000<0oooo000000000000100000000`3oool0000000000006
000000D0oooo1`0000020?ooo`<00000103oool2000000D0oooo1`0000020?ooo`D000000P3oool4
000000030?ooo`0000000000008000003@3AcJT3000000@0oooo0P0000000`3oool0000000000002
0?ooo`<00000303oool200000080oooo0`0000020?ooo`80000000<0oooo00000000000010000000
0`3oool00000000000020?ooo`<000000P3oool2000000`0oooo0`0000020?ooo`80000000<0oooo
000000000000103oool300000100dLfY000>0=7=Z@T00000103oool8000000030?ooo`0000000000
00@0oooo1P0000020?ooo`030000003oool0oooo00H000000P3oool4000000<0oooo100000020?oo
o`8000002@3oool4000000@0oooo1@0000020?ooo`8000003@3AcJT900000080oooo0P0000020?oo
o`8000000P3oool500000080oooo0P0000020?ooo`8000000`3oool400000080oooo1`0000020?oo
o`@000000`3oool200000080oooo0P0000020?ooo`D000000P3oool200000080oooo0P0000020?oo
o`T000003@3AcJT4000000<0oooo100000050?ooo`8000000P3oool300000080oooo100000020?oo
o`<000000P3oool500000080oooo0P0000020?ooo`D000000P3oool300000080oooo100000020?oo
o`<000000P3oool2000000D0oooo100000030?ooo`@000003@3AcJT200000080oooo00<000000?oo
o`3oool0103oool7000000<0oooo100000030?ooo`P000000`3oool2000000L0oooo100000070?oo
o`L000000`3oool400000080oooo0P0000000`3oool00000000000020?ooo`8000001@3oool=0=7=
Z@<00000103oool2000000030?ooo`00000000000080oooo0`00000<0?ooo`8000000P3oool30000
0080oooo0P0000000`3oool0000000000004000000030?ooo`00000000000080oooo0`0000020?oo
o`800000303oool300000080oooo0P0000000`3oool00000000000040?ooo`<00000403AcJT000h0
dLfY0P3oool4000000<0oooo0P0000040?ooo`@000000`3oool200000080oooo0P0000020?ooo`80
0000103oool300000080oooo0P0000040?ooo`@000001`3oool400000080oooo0P0000000`3oool0
0000000000020?ooo`@00000103oool2000000030?ooo`0000000000008000000P3oool=0=7=Z@T0
00000P3oool200000080oooo0P0000020?ooo`D000000P3oool200000080oooo0P0000030?ooo`@0
00000P3oool700000080oooo100000030?ooo`8000000P3oool200000080oooo1@0000020?ooo`80
00000P3oool200000080oooo2@00000=0=7=Z@@0oooo00<000000?ooo`3oool00P0000020?ooo`L0
0000103oool3000000@0oooo0P0000070?ooo`8000000`3oool2000000@0oooo00<000000?ooo`3o
ool01@3oool2000000@0oooo0`0000040?ooo`L000000P3oool200000080oooo00<000000?ooo`3o
ool00P3oool=0=7=Z@8000000P3oool00`000000oooo0?ooo`040?ooo`L000000`3oool4000000<0
oooo200000030?ooo`8000001`3oool4000000L0oooo1`0000030?ooo`@000000P3oool200000003
0?ooo`00000000000080oooo0P0000050?ooo`d0dLfY0`3oool200000080oooo0`0000090?ooo`<0
00001`3oool400000080oooo1@0000030?ooo`8000000`3oool6000000030?ooo`00000000000080
00001`3oool3000000T0oooo0`0000020?ooo`8000000`3oool@0=7=Z@003P3AcJT20?ooo`@00000
0`3oool2000000@0oooo100000030?ooo`8000000P3oool200000080oooo0P0000040?ooo`<00000
0P3oool2000000@0oooo100000070?ooo`@000000P3oool2000000030?ooo`00000000000080oooo
100000040?ooo`80000000<0oooo0000000000000P0000020?ooo`d0dLfY4@0000030?ooo`@00000
1P3oool2000000030?ooo`00000000000080oooo3`0000020?ooo`80000000<0oooo000000000000
1P3oool4000000<0oooo4@00000=0=7=Z@@0oooo00<000000?ooo`3oool00P0000020?ooo`L00000
103oool3000000@0oooo0P0000070?ooo`8000000`3oool2000000@0oooo00<000000?ooo`3oool0
1@3oool2000000@0oooo0`0000040?ooo`L000000P3oool200000080oooo00<000000?ooo`3oool0
0P3oool=0=7=Z@80oooo0P0000000`3oool000000000000200000080oooo00<000000?ooo`3oool0
0P3oool2000000T0oooo00<000000?ooo`3oool0100000030?ooo`800000103oool2000000<0oooo
0P0000070?ooo`@000001@3oool2000000030?ooo`0000000000008000000P3oool7000000<0oooo
1000000=0=7=Z@<0oooo0P0000020?ooo`<000002@3oool3000000L0oooo100000020?ooo`D00000
0`3oool2000000<0oooo1P0000000`3oool0000000000002000000L0oooo0`0000090?ooo`<00000
0P3oool2000000<0oooo403AcJT000h0dLfY1P0000020?ooo`030000003oool0oooo00@0oooo0P00
00050?ooo`h0000000<0oooo0000000000000P0000040?ooo`800000103oool700000080oooo1`00
00040?ooo`800000103oool2000000<0oooo1P00000=0=7=ZA4000000`3oool4000000H0oooo0P00
00000`3oool00000000000020?ooo`l000000P3oool2000000030?ooo`000000000000H0oooo1000
00030?oooa4000003@3AcJT50?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`D000001P3o
ool2000000030?ooo`000000000000@0oooo0P0000030?ooo`800000103oool00`000000oooo0?oo
o`020?ooo`80000000<0oooo0000000000001P3oool5000000@0oooo00<000000?ooo`3oool0103o
ool2000000D0oooo3@3AcJT20?ooo`80000000<0oooo0000000000000P0000020?ooo`030000003o
ool0oooo0080oooo0P0000090?ooo`030000003oool0oooo00@000000`3oool2000000@0oooo0P00
00030?ooo`8000001`3oool4000000D0oooo0P0000000`3oool000000000000200000080oooo1`00
00030?ooo`@000003@3AcJT2000000030?ooo`000000000000D000001P3oool5000000030?ooo`00
0000000000L000000P3oool300000080oooo300000020?ooo`<000000P3oool9000000030?ooo`00
0000000000<000001P3oool7000000030?ooo`00000000000100dLfY000>0=7=Z@H000000P3oool0
0`000000oooo0?ooo`040?ooo`8000001@3oool>000000030?ooo`000000000000800000103oool2
000000@0oooo1`0000020?ooo`L00000103oool2000000@0oooo0P0000030?ooo`H000003@3AcJT2
0?ooo`8000001`3ooolA00000080oooo0P0000030?ooo`8000000P3oool200000080oooo0`000002
0?ooo`8000000P3oool2000000<0oooo0P0000020?oooa4000001`3oool200000080oooo3@3AcJT5
0?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`D000001P3oool2000000030?ooo`000000
000000@0oooo0P0000030?ooo`800000103oool00`000000oooo0?ooo`020?ooo`80000000<0oooo
0000000000001P3oool5000000@0oooo00<000000?ooo`3oool0103oool2000000D0oooo3@3AcJT2
0?ooo`X000000P3oool2000000@0oooo00<000000?ooo`3oool00P3oool2000000030?ooo`000000
000000@000000P3oool00`000000oooo0?ooo`060?ooo`L0000000<0oooo0000000000002@000005
0?ooo`8000001P3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool00P3oool=
0=7=Z@<00000103oool2000000030?ooo`00000000000080oooo1`0000050?ooo`<000000P3oool2
000000<0oooo0P0000050?ooo`8000001@3oool2000000<0oooo0P0000020?ooo`<000001@3oool7
00000080oooo0P0000000`3oool00000000000040?ooo`<00000403AcJT000h0dLfY1P3oool30000
00H0oooo100000020?ooo`D00000203oool2000000<0oooo200000040?ooo`<00000103oool20000
00H0oooo2@0000040?ooo`80000000<0oooo0000000000000P0000020?ooo`d0dLfY0P3oool20000
00L0oooo4@0000020?ooo`8000000`3oool200000080oooo0P0000020?ooo`<000000P3oool20000
0080oooo0P0000030?ooo`8000000P3ooolA000000L0oooo0P0000020?ooo`d0dLfY1@0000020?oo
o`T000000P3oool200000080oooo2P0000020?ooo`8000001@3oool6000000D0oooo0P0000020?oo
o`X000000P3oool200000080oooo2@0000020?ooo`D000003@3AcJT4000000D0oooo0P0000050?oo
o`D000001P3oool3000000@0oooo0P0000030?ooo`@000000P3oool500000080oooo0`0000020?oo
o`D000000P3oool200000080oooo0`0000040?ooo`80000000<0oooo000000000000103oool00`00
0000oooo0?ooo`020?ooo`d0dLfY0`0000040?ooo`80000000<0oooo0000000000000P3oool70000
00D0oooo0`0000020?ooo`8000000`3oool2000000D0oooo0P0000050?ooo`8000000`3oool20000
0080oooo0`0000050?ooo`L000000P3oool2000000030?ooo`000000000000@0oooo0`00000@0=7=
Z@003P3AcJT60?ooo`<000001P3oool400000080oooo1@0000080?ooo`8000000`3oool8000000@0
oooo0`0000040?ooo`8000001P3oool9000000@0oooo0P0000000`3oool000000000000200000080
oooo3@3AcJT6000000030?ooo`0000000000008000000P3oool6000000T0oooo100000090?ooo`L0
00002@3oool4000000T0oooo1P0000020?ooo`@0000000<0oooo0000000000001000000=0=7=Z@@0
00000`3oool200000080oooo0P0000000`3oool000000000000200000080oooo0P0000070?ooo`D0
00002@3oool2000000T0oooo1@0000070?ooo`8000000P3oool4000000030?ooo`00000000000080
oooo0P0000030?ooo`@000003@3AcJT4000000D0oooo0P0000050?ooo`D000001P3oool3000000@0
oooo0P0000030?ooo`@000000P3oool500000080oooo0`0000020?ooo`D000000P3oool200000080
oooo0`0000040?ooo`80000000<0oooo000000000000103oool00`000000oooo0?ooo`020?ooo`d0
dLfY0`0000020?ooo`T000000P3oool3000000D0oooo0P0000030?ooo`@000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`020?ooo`80
000000<0oooo0000000000000P0000030?ooo`8000001@3oool300000080oooo2@0000020?ooo`<0
0000403AcJT000h0dLfY100000040?ooo`030000003oool0oooo0080oooo2`0000020?ooo`800000
0P3oool200000080oooo0P0000000`3oool0000000000002000000H0oooo0P0000020?ooo`030000
003oool0oooo00800000103oool6000000D0oooo100000020?ooo`D000001P3oool=0=7=Z@H00000
00<0oooo0000000000000P0000020?ooo`H000002@3oool4000000T0oooo1`0000090?ooo`@00000
2@3oool600000080oooo100000000`3oool0000000000004000000d0dLfY100000030?ooo`800000
0P3oool2000000030?ooo`0000000000008000000P3oool2000000L0oooo1@0000090?ooo`800000
2@3oool5000000L0oooo0P0000020?ooo`@0000000<0oooo0000000000000P3oool2000000<0oooo
1000000=0=7=Z@80oooo0P0000000`3oool000000000000;0?ooo`8000000`3oool500000080oooo
100000020?ooo`T000001@3oool7000000@0oooo0`0000020?ooo`80000000<0oooo000000000000
1`3oool700000080oooo0P00000=0=7=Z@<000000P3oool900000080oooo0`0000050?ooo`800000
0`3oool400000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0200000080oooo
00<000000?ooo`3oool00P3oool2000000030?ooo`0000000000008000000`3oool2000000D0oooo
0`0000020?ooo`T000000P3oool300000100dLfY000>0=7=Z@@00000103oool00`000000oooo0?oo
o`020?ooo`/000000P3oool200000080oooo0P0000020?ooo`80000000<0oooo0000000000000P00
00060?ooo`8000000P3oool00`000000oooo0?ooo`02000000@0oooo1P0000050?ooo`@000000P3o
ool5000000H0oooo3@3AcJT2000000@0oooo0`0000020?ooo`800000103oool5000000H0oooo1000
00030?ooo`8000001P3oool3000000H0oooo0P0000030?ooo`@000001P3oool5000000@0oooo0P00
00020?ooo`<00000103oool2000000d0dLfY0P3oool700000080oooo0`0000020?ooo`@000001@3o
ool200000080oooo0P0000030?ooo`8000000P3oool<00000080oooo0P0000030?ooo`8000000P3o
ool2000000D0oooo100000020?ooo`<000000P3oool700000080oooo3@3AcJT20?ooo`80000000<0
oooo0000000000002`3oool2000000<0oooo1@0000020?ooo`@000000P3oool9000000D0oooo1`00
00040?ooo`<000000P3oool2000000030?ooo`000000000000L0oooo1`0000020?ooo`8000003@3A
cJT20?ooo`<000000P3oool3000000@0oooo1@0000020?ooo`030000003oool0oooo008000002@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?oo
o`020?ooo`800000203oool200000080oooo00<000000?ooo`3oool01@0000040?ooo`<000000P3o
ool300000080oooo403AcJT000h0dLfY0P3oool6000000030?ooo`00000000000080oooo1P000002
0?ooo`<000000P3oool4000000@0oooo0`0000020?ooo`8000001P3oool200000080oooo00<00000
0?ooo`3oool00P3oool4000000H0oooo00<000000?ooo`3oool00P0000040?ooo`H0000000<0oooo
0000000000001000000=0=7=Z@8000000P3oool2000000030?ooo`00000000000080oooo1P000002
0?ooo`030000003oool0oooo0080oooo200000000`3oool000000000000600000080oooo0`000002
0?ooo`P0000000<0oooo0000000000001P0000040?ooo`030000003oool0oooo00H000000P3oool2
000000030?ooo`00000000000080oooo0P00000=0=7=Z@80oooo1`0000020?ooo`<000000P3oool4
000000D0oooo0P0000020?ooo`8000000`3oool200000080oooo300000020?ooo`8000000`3oool2
00000080oooo0P0000050?ooo`@000000P3oool300000080oooo1`0000020?ooo`d0dLfY10000000
0`3oool0000000000005000000H0oooo0P0000050?ooo`<000000P3oool400000080oooo1`000003
0?ooo`8000000P3oool3000000H0oooo1@0000040?ooo`030000003oool0oooo008000000P3oool2
000000<0oooo100000000`3oool0000000000002000000d0dLfY0P3oool300000080oooo0`000004
0?ooo`D000000P3oool00`000000oooo0?ooo`02000000T0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool00P3oool2000000P0oooo0P000002
0?ooo`030000003oool0oooo00D00000103oool300000080oooo0`0000020?oooa00dLfY000>0=7=
Z@80oooo1P0000000`3oool00000000000020?ooo`H000000P3oool300000080oooo100000040?oo
o`<000000P3oool2000000H0oooo0P0000020?ooo`030000003oool0oooo0080oooo100000060?oo
o`030000003oool0oooo00800000103oool6000000030?ooo`000000000000@000003@3AcJT20000
0080oooo0P0000000`3oool00000000000020?ooo`H000000P3oool00`000000oooo0?ooo`020?oo
o`P0000000<0oooo0000000000001P0000020?ooo`<000000P3oool8000000030?ooo`0000000000
00H00000103oool00`000000oooo0?ooo`0600000080oooo0P0000000`3oool00000000000020?oo
o`8000003@3AcJT200000080oooo1@0000020?ooo`8000000`3oool900000080oooo0P0000020?oo
o`L000001@3oool2000000D0oooo1`0000020?ooo`8000000P3oool9000000<0oooo0P0000020?oo
o`D000000P3oool2000000d0dLfY100000000`3oool0000000000005000000H0oooo0P0000050?oo
o`<000000P3oool400000080oooo1`0000030?ooo`8000000P3oool3000000H0oooo1@0000040?oo
o`030000003oool0oooo008000000P3oool2000000<0oooo100000000`3oool00000000000020000
00d0dLfY0P0000030?ooo`D00000103oool500000080oooo00<000000?ooo`3oool00P0000030?oo
o`8000000P3oool7000000<0oooo0P0000030?ooo`L000000P3oool2000000<0oooo0P0000020?oo
o`030000003oool0oooo00D00000103oool5000000<0oooo0P00000@0=7=Z@003P3AcJT20?ooo`@0
00000`3ooolG000000@0oooo1@0000040?ooo`8000000P3oool2000000030?ooo`00000000000080
oooo100000020?ooo`8000001@3oool8000000L0oooo1000000=0=7=Z@80oooo1`0000020?ooo`@0
00002@3oool600000080oooo0`0000040?ooo`8000000P3oool300000080oooo0P0000040?ooo`<0
00000P3oool6000000T0oooo100000020?ooo`L000000P3oool=0=7=Z@8000000P3oool500000080
oooo0P0000030?ooo`T000000P3oool200000080oooo1`0000050?ooo`8000001@3oool700000080
oooo0P0000020?ooo`T000000`3oool200000080oooo1@0000020?ooo`8000003@3AcJT40?ooo`03
0000003oool0oooo008000000P3oool7000000D0oooo0P0000030?ooo`800000103oool300000080
oooo1P0000080?ooo`/000000P3oool2000000030?ooo`00000000000080oooo0P0000020?ooo`03
0000003oool0oooo0080oooo0P0000000`3oool0000000000002000000d0dLfY0P0000030?ooo`@0
00001@3oool2000000H0oooo1`0000020?ooo`@000000`3oool2000000<0oooo0P0000030?ooo`80
0000103oool300000080oooo1`0000060?ooo`8000001@3oool4000000<0oooo0P00000@0=7=Z@00
3P3AcJT20?ooo`@000000`3ooolG000000@0oooo1@0000040?ooo`8000000P3oool2000000030?oo
o`00000000000080oooo100000020?ooo`8000001@3oool8000000L0oooo1000000=0=7=Z@80oooo
1`0000020?ooo`@000002@3oool600000080oooo0`0000040?ooo`8000000P3oool300000080oooo
0P0000040?ooo`<000000P3oool6000000T0oooo100000020?ooo`L000000P3oool=0=7=Z@@00000
0`3oool200000080oooo1@0000020?ooo`8000000P3oool<00000080oooo0P0000050?ooo`800000
1@3oool200000080oooo300000020?ooo`8000000P3oool500000080oooo0P0000030?ooo`@00000
3@3AcJT40?ooo`030000003oool0oooo008000000P3oool7000000D0oooo0P0000030?ooo`800000
103oool300000080oooo1P0000080?ooo`/000000P3oool2000000030?ooo`00000000000080oooo
0P0000020?ooo`030000003oool0oooo0080oooo0P0000000`3oool0000000000002000000d0dLfY
0P0000030?ooo`@000001@3oool2000000H0oooo1`0000020?ooo`@000000`3oool2000000<0oooo
0P0000030?ooo`800000103oool300000080oooo1`0000060?ooo`8000001@3oool4000000<0oooo
0P00000@0=7=Z@003P3AcJT2000000@0oooo0P0000000`3oool0000000000008000000L0oooo1000
00020?ooo`8000000P3oool300000080oooo0P0000020?ooo`L000000P3oool2000000@0oooo0P00
00020?oooa4000000`3oool4000000d0dLfY2`3oool200000080oooo1@0000040?ooo`H000000`3o
ool600000080oooo0P0000030?ooo`8000000P3oool6000000<0oooo1P0000040?ooo`D000000P3o
ool2000000/0oooo3@3AcJT4000000<0oooo0P0000020?ooo`D000000P3oool200000080oooo3000
00020?ooo`8000001@3oool2000000D0oooo0P0000020?ooo``000000P3oool200000080oooo1@00
00020?ooo`8000000`3oool4000000d0dLfY1@0000040?ooo`8000001`3oool300000080oooo0P00
00020?ooo`030000003oool0oooo00H0000000<0oooo0000000000001P3oool00`000000oooo0?oo
o`020?ooo`8000001@3oool200000080oooo00<000000?ooo`3oool00P3oool3000000@0oooo1000
00030?ooo`@0000000<0oooo0000000000000P00000=0=7=Z@L0oooo0`0000060?ooo`H000001P3o
ool300000080oooo0P0000000`3oool000000000000300000080oooo0P0000020?ooo`D000000P3o
ool00`000000oooo0?ooo`03000000H0oooo1P0000060?ooo`<000001`3oool@0=7=Z@003P3AcJT2
0?ooo`H000000`3oool4000000@0oooo1@0000040?ooo`@000001`3oool8000000@0oooo00<00000
0?ooo`3oool00P0000020?ooo`8000000P3oool700000080oooo0P0000040?ooo`T000000P3oool=
0=7=Z@/0oooo0P0000020?ooo`D00000103oool6000000<0oooo1P0000020?ooo`8000000`3oool2
00000080oooo1P0000030?ooo`H00000103oool500000080oooo0P00000;0?ooo`d0dLfY1`000006
0?ooo`030000003oool0oooo00L000001P3oool700000080oooo300000020?ooo`L000001P3oool7
00000080oooo00<000000?ooo`3oool0103oool7000000d0dLfY1@0000040?ooo`8000001@3oool2
000000<0oooo1P0000030?ooo`@000000P3oool00`000000oooo0?ooo`020?ooo`@000000`3oool2
000000<0oooo100000070?ooo`@0000000<0oooo0000000000000P3oool200000080oooo00<00000
0?ooo`3oool02@00000=0=7=Z@L0oooo0`0000060?ooo`H000001P3oool300000080oooo0P000000
0`3oool000000000000300000080oooo0P0000020?ooo`D000000P3oool00`000000oooo0?ooo`03
000000H0oooo1P0000060?ooo`<000001`3oool@0=7=Z@003P3AcJT20?ooo`H000000`3oool40000
00@0oooo1@0000040?ooo`@000001`3oool8000000@0oooo00<000000?ooo`3oool00P0000020?oo
o`8000000P3oool700000080oooo0P0000040?ooo`T000000P3oool=0=7=Z@H0oooo1`0000020?oo
o`8000000`3oool:00000080oooo1`0000040?ooo`<00000103oool700000080oooo2P0000030?oo
o`8000000P3oool7000000H0oooo3@3AcJT7000000H0oooo00<000000?ooo`3oool01`0000060?oo
o`L000000P3oool<00000080oooo1`0000060?ooo`L000000P3oool00`000000oooo0?ooo`040?oo
o`L000003@3AcJT5000000@0oooo0P0000050?ooo`8000000`3oool6000000<0oooo100000020?oo
o`030000003oool0oooo0080oooo100000030?ooo`8000000`3oool4000000L0oooo100000000`3o
ool00000000000020?ooo`8000000P3oool00`000000oooo0?ooo`09000000d0dLfY1@3oool20000
00<0oooo1P0000000`3oool0000000000002000000030?ooo`0000000000008000000`3oool60000
00<0oooo0P0000030?ooo`8000000`3oool2000000@0oooo1@0000030?ooo`@0000000<0oooo0000
000000000P0000000`3oool0000000000004000000<0oooo0P0000050?oooa00dLfY000>0=7=Z@80
oooo0P0000050?ooo`@000001P3oool2000000030?ooo`0000000000008000001P3oool2000000<0
oooo100000020?ooo`@000000P3oool300000080oooo0P0000040?ooo`L000001P3oool800000003
0?ooo`000000000000@0oooo3@3AcJT60?ooo`L000000P3oool2000000<0oooo2P0000020?ooo`L0
0000103oool3000000@0oooo1`0000020?ooo`X000000`3oool200000080oooo1`0000060?ooo`d0
dLfY0P3oool<000000@0oooo100000000`3oool00000000000040?ooo`80000000<0oooo00000000
0000100000050?ooo`8000001@3oool6000000030?ooo`000000000000@0oooo0P0000000`3oool0
000000000002000000@0oooo300000020?ooo`d0dLfY100000000`3oool00000000000020?ooo`D0
00000P3oool500000080oooo1`0000020?ooo`8000001@3oool6000000030?ooo`00000000000080
00000`3oool8000000030?ooo`0000000000008000000P3oool3000000L0oooo0P0000020?ooo`L0
00003@3AcJT50?ooo`8000000`3oool6000000030?ooo`00000000000080000000<0oooo00000000
00000P0000030?ooo`H000000`3oool2000000<0oooo0P0000030?ooo`800000103oool5000000<0
oooo100000000`3oool0000000000002000000030?ooo`000000000000@000000`3oool2000000D0
oooo403AcJT000h0dLfY0P3oool2000000D0oooo100000060?ooo`80000000<0oooo000000000000
0P0000060?ooo`8000000`3oool400000080oooo100000020?ooo`<000000P3oool2000000@0oooo
1`0000060?ooo`P0000000<0oooo000000000000103oool=0=7=Z@800000103oool;00000080oooo
00<000000?ooo`3oool00P0000020?ooo`/000000P3oool4000000<0oooo100000020?ooo`/00000
0P3oool200000080oooo00<000000?ooo`3oool02`0000040?ooo`8000003@3AcJT200000080oooo
00<000000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3oool00P0000020?ooo`800000
2@3oool500000080oooo0P0000000`3oool000000000000400000080oooo00<000000?ooo`3oool0
1@0000090?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00P0000040?ooo`030000
003oool0oooo008000003@3AcJT4000000030?ooo`00000000000080oooo1@0000020?ooo`D00000
0P3oool700000080oooo0P0000050?ooo`H0000000<0oooo0000000000000P0000030?ooo`P00000
00<0oooo0000000000000P0000020?ooo`<000001`3oool200000080oooo1`00000=0=7=Z@800000
1`3oool00`000000oooo0?ooo`070?ooo`8000000`3oool2000000<0oooo1`0000020?ooo`<00000
0P3oool200000080oooo0`0000020?ooo`L000000`3oool2000000<0oooo0P0000090?ooo`030000
003oool0oooo00D0oooo0P00000@0=7=Z@003P3AcJT20?ooo`/000004@3oool200000080oooo0P00
00050?ooo`@000001P3oool300000080oooo0P0000020?ooo`d000000P3oool4000000<0oooo0P00
00020?ooo`8000003@3AcJT2000000@0oooo2`0000020?ooo`030000003oool0oooo008000000P3o
ool;00000080oooo100000030?ooo`@000000P3oool;00000080oooo0P0000020?ooo`030000003o
ool0oooo00/00000103oool2000000d0dLfY0P0000020?ooo`030000003oool0oooo0080oooo0P00
00020?ooo`030000003oool0oooo008000000P3oool2000000T0oooo1@0000020?ooo`80000000<0
oooo000000000000100000020?ooo`030000003oool0oooo00D000002@3oool200000080oooo0P00
00020?ooo`030000003oool0oooo00800000103oool00`000000oooo0?ooo`02000000d0dLfY0P3o
ool2000000030?ooo`0000000000008000000P3oool00`000000oooo0?ooo`0200000080oooo0P00
00000`3oool00000000000020?ooo`800000303oool6000000030?ooo`0000000000008000001`3o
ool4000000030?ooo`000000000000/0oooo0P0000000`3oool0000000000004000000<0oooo0P00
000=0=7=Z@80oooo1@0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D000000P3oool300000080oooo0P00
00020?ooo`<000000P3oool500000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@0000020?oooa00dLfY000>
0=7=Z@80oooo2`00000A0?ooo`8000000P3oool2000000D0oooo100000060?ooo`<000000P3oool2
00000080oooo3@0000020?ooo`@000000`3oool200000080oooo0P00000=0=7=Z@80oooo0P000003
0?ooo`X000000P3oool00`000000oooo0?ooo`0400000080oooo100000030?ooo`@000002`3oool4
000000<0oooo100000020?ooo`@000000P3oool00`000000oooo0?ooo`0:000000<0oooo0P000002
0?ooo`d0dLfY0P0000020?ooo`<000000P3oool4000000<0oooo100000020?ooo`D000001@3oool2
00000080oooo1@0000020?ooo`8000000P3oool500000080oooo0P0000050?ooo`D000000P3oool4
000000<0oooo100000020?ooo`<000000P3oool2000000d0dLfY0P3oool2000000030?ooo`000000
0000008000000P3oool00`000000oooo0?ooo`0200000080oooo0P0000000`3oool0000000000002
0?ooo`800000303oool6000000030?ooo`0000000000008000001`3oool4000000030?ooo`000000
000000/0oooo0P0000000`3oool0000000000004000000<0oooo0P00000=0=7=Z@80oooo1@000002
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D000000P3oool300000080oooo0P0000020?ooo`<000000P3oool5
00000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@0000020?oooa00dLfY000>0=7=Z@H000000P3oool50000
0080oooo0P0000020?ooo`8000000`3oool400000080oooo0P0000040?ooo`T00000103oool20000
00030?ooo`000000000000H0oooo100000020?ooo`<000001P3oool400000080oooo0`0000040?oo
o`d0dLfY0P3oool2000000<0oooo2P0000020?ooo`030000003oool0oooo00@000000P3oool40000
00<0oooo1000000;0?ooo`@000000`3oool400000080oooo100000020?ooo`030000003oool0oooo
00X000000`3oool200000080oooo3@3AcJT200000080oooo0`0000020?ooo`@000000`3oool40000
0080oooo1@0000050?ooo`8000000P3oool500000080oooo0P0000020?ooo`D000000P3oool20000
00D0oooo1@0000020?ooo`@000000`3oool400000080oooo0`0000020?ooo`8000003@3AcJT20?oo
o`T000001@3oool500000080oooo0P0000020?ooo`030000003oool0oooo00@0oooo0`0000080?oo
o`<00000103oool300000080oooo1@0000040?ooo`80000000<0oooo0000000000000P0000020?oo
o`<000000P3oool2000000L0oooo3@3AcJT20?ooo`<000000P3oool2000000030?ooo`0000000000
008000000P3oool00`000000oooo0?ooo`050?ooo`8000000P3oool300000080oooo1@0000030?oo
o`H000000`3oool500000080oooo0`0000020?ooo`8000001`3oool00`000000oooo0?ooo`040000
00030?ooo`00000000000080oooo0`0000020?oooa00dLfY000>0=7=Z@H000000P3oool500000080
oooo0P0000020?ooo`8000000`3oool400000080oooo0P0000040?ooo`T00000103oool200000003
0?ooo`000000000000H0oooo100000020?ooo`<000001P3oool400000080oooo0`0000040?ooo`d0
dLfY1P0000050?ooo`8000000P3oool2000000<0oooo0P0000040?ooo`H000001@3oool4000000L0
oooo100000050?ooo`H00000103oool2000000<0oooo0P0000020?ooo`8000001@3oool6000000d0
dLfY0P0000020?ooo`030000003oool0oooo00@0oooo0`0000040?ooo`8000000`3oool400000080
oooo0`0000090?ooo`H000002@3oool300000080oooo100000030?ooo`800000103oool3000000H0
oooo00<000000?ooo`3oool00P00000=0=7=Z@80oooo1@0000070?ooo`8000000P3oool700000080
oooo00<000000?ooo`3oool01P0000050?ooo`8000000P3oool00`000000oooo0?ooo`0200000080
oooo00<000000?ooo`3oool03@0000050?ooo`8000000P3oool00`000000oooo0?ooo`05000000@0
oooo3@3AcJT20?ooo`<000000P3oool2000000030?ooo`0000000000008000000P3oool00`000000
oooo0?ooo`050?ooo`8000000P3oool300000080oooo1@0000030?ooo`H000000`3oool500000080
oooo0`0000020?ooo`8000001`3oool00`000000oooo0?ooo`04000000030?ooo`00000000000080
oooo0`0000020?oooa00dLfY000>0=7=Z@@0oooo0P0000050?ooo`/00000203oool2000000@0oooo
00<000000?ooo`3oool00P3oool6000000D0oooo0P0000020?ooo`H00000103oool00`000000oooo
0?ooo`0400000080oooo0P0000040?ooo`<000000P3oool2000000d0dLfY103oool500000080oooo
0P0000040?ooo`80000000<0oooo000000000000103oool200000080oooo0`0000020?ooo`@00000
103oool3000000@0oooo100000020?ooo`<000000P3oool2000000@0oooo0P0000000`3oool00000
000000040?ooo`8000000P3oool5000000@0oooo3@3AcJT200000080oooo00<000000?ooo`3oool0
103oool3000000@0oooo0P0000030?ooo`@000000P3oool3000000T0oooo1P0000090?ooo`<00000
0P3oool4000000<0oooo0P0000040?ooo`<000001P3oool00`000000oooo0?ooo`02000000d0dLfY
0P3oool5000000L0oooo0P0000020?ooo`L000000P3oool00`000000oooo0?ooo`06000000D0oooo
0P0000020?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`0=000000D0oooo
0P0000020?ooo`030000003oool0oooo00D00000103oool=0=7=Z@8000000`3oool200000080oooo
00<000000?ooo`3oool00P3oool7000000030?ooo`0000000000008000000P3oool00`000000oooo
0?ooo`05000000@0oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo0080oooo
1@0000020?ooo`030000003oool0oooo00@0000000<0oooo0000000000001@0000040?ooo`030000
003oool0oooo008000000`3oool200000100dLfY000>0=7=Z@@0oooo0P0000050?ooo`/00000203o
ool2000000@0oooo00<000000?ooo`3oool00P3oool6000000D0oooo0P0000020?ooo`H00000103o
ool00`000000oooo0?ooo`0400000080oooo0P0000040?ooo`<000000P3oool2000000d0dLfY103o
ool500000080oooo0P0000040?ooo`80000000<0oooo000000000000103oool200000080oooo0`00
00020?ooo`@00000103oool3000000@0oooo100000020?ooo`<000000P3oool2000000@0oooo0P00
00000`3oool00000000000040?ooo`8000000P3oool5000000@0oooo3@3AcJT200000080oooo00<0
00000?ooo`3oool03@3oool2000000030?ooo`000000000000@000003P3oool2000000h0oooo1P00
00000`3oool000000000000?0?ooo`030000003oool0oooo008000003@3AcJT200000080oooo1`00
00000`3oool00000000000020?ooo`8000000P3oool00`000000oooo0?ooo`04000000030?ooo`00
0000000000@0oooo0P0000000`3oool000000000000200000080oooo0P0000000`3oool000000000
00020?ooo`D000000P3oool5000000@0oooo0P0000030?ooo`8000000P3oool9000000030?ooo`00
00000000008000003@3AcJT2000000<0oooo0P0000020?ooo`030000003oool0oooo0080oooo1`00
00000`3oool000000000000200000080oooo00<000000?ooo`3oool01@0000040?ooo`030000003o
ool0oooo008000000P3oool00`000000oooo0?ooo`020?ooo`D000000P3oool00`000000oooo0?oo
o`04000000030?ooo`000000000000D00000103oool00`000000oooo0?ooo`02000000<0oooo0P00
000@0=7=Z@003P3AcJT2000000H0oooo0`0000060?ooo`8000001@3oool2000000@0oooo0P000002
0?ooo`8000001`3oool=00000080oooo1P0000020?ooo`030000003oool0oooo00@000001P3oool2
000000D0oooo0P00000=0=7=Z@H0000000<0oooo000000000000103oool6000000D0oooo20000000
0`3oool000000000000200000080oooo0P0000070?ooo`8000000P3oool4000000030?ooo`000000
000000H000001@3oool6000000@0oooo0P0000000`3oool0000000000004000000d0dLfY0P000002
0?ooo`030000003oool0oooo00d0oooo0P0000000`3oool0000000000004000000h0oooo0P00000>
0?ooo`H0000000<0oooo0000000000003`3oool00`000000oooo0?ooo`02000000d0dLfY0P000002
0?ooo`L0000000<0oooo0000000000000P3oool200000080oooo00<000000?ooo`3oool010000000
0`3oool00000000000040?ooo`80000000<0oooo0000000000000P0000020?ooo`80000000<0oooo
0000000000000P3oool500000080oooo1@0000040?ooo`8000000`3oool200000080oooo2@000000
0`3oool0000000000002000000d0dLfY1@0000020?ooo`800000203oool200000080oooo00<00000
0?ooo`3oool00P3oool5000000`0oooo0P00000<0?ooo`D00000103oool00`000000oooo0?ooo`02
000000P0oooo0P0000020?ooo`D00000403AcJT000h0dLfY0P0000060?ooo`<000001P3oool20000
00D0oooo0P0000040?ooo`8000000P3oool2000000L0oooo3@0000020?ooo`H000000P3oool00`00
0000oooo0?ooo`04000000H0oooo0P0000050?ooo`8000003@3AcJT6000000030?ooo`0000000000
00@0oooo1P0000050?ooo`P0000000<0oooo0000000000000P0000020?ooo`8000001`3oool20000
0080oooo100000000`3oool0000000000006000000D0oooo1P0000040?ooo`80000000<0oooo0000
000000001000000=0=7=Z@8000000P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`00
0000oooo0?ooo`040?ooo`8000001@3oool9000000@0oooo00<000000?ooo`3oool00P0000020?oo
o`8000000`3oool9000000D0oooo0P0000060?ooo`030000003oool0oooo00800000103oool00`00
0000oooo0?ooo`02000000d0dLfY100000080?ooo`@000000P3oool2000000030?ooo`0000000000
00D0oooo0P0000060?ooo`030000003oool0oooo008000000P3oool>000000@0oooo00<000000?oo
o`3oool0100000030?ooo`T000000P3oool7000000d0dLfY0`3oool2000000D0oooo0P0000020?oo
o`<000000P3oool2000000D0oooo0P0000030?ooo`8000000`3oool200000080oooo00<000000?oo
o`3oool00P0000020?ooo`030000003oool0oooo008000000`3oool2000000<0oooo0P0000050?oo
o`8000000P3oool300000080oooo0P0000050?ooo`8000000`3oool@0=7=Z@003P3AcJT400000080
oooo0P0000030?ooo`8000000P3oool200000080oooo0`0000040?ooo`d00000103oool800000003
0?ooo`0000000000008000000P3oool400000080oooo0P0000070?ooo`@000002`3oool=0=7=Z@@0
oooo0P0000070?ooo`8000001@3oool200000080oooo1P0000020?ooo`030000003oool0oooo0080
oooo0P00000;0?ooo`800000103oool00`000000oooo0?ooo`0600000080oooo0P0000050?ooo`80
00001`3oool2000000@0oooo3@3AcJT20?ooo`<000002@3oool2000000H0oooo00<000000?ooo`3o
ool01P0000000`3oool000000000000200000080oooo300000020?ooo`@0000000<0oooo00000000
0000100000020?ooo`030000003oool0oooo00@0oooo0P0000090?ooo`<000000P3oool=0=7=Z@@0
0000203oool400000080oooo0P0000000`3oool00000000000050?ooo`8000001P3oool00`000000
oooo0?ooo`0200000080oooo3P0000040?ooo`030000003oool0oooo00@000000`3oool900000080
oooo1`00000=0=7=Z@<0oooo0P0000050?ooo`8000000P3oool300000080oooo0P0000050?ooo`80
00000`3oool2000000<0oooo0P0000020?ooo`030000003oool0oooo008000000P3oool00`000000
oooo0?ooo`02000000<0oooo0P0000030?ooo`8000001@3oool200000080oooo0`0000020?ooo`80
00001@3oool2000000<0oooo403AcJT000h0dLfY100000020?ooo`8000000`3oool200000080oooo
0P0000020?ooo`<00000103oool=000000@0oooo200000000`3oool000000000000200000080oooo
100000020?ooo`8000001`3oool4000000/0oooo3@3AcJT40?ooo`8000001`3oool2000000D0oooo
0P0000020?ooo`H000000P3oool00`000000oooo0?ooo`020?ooo`8000002`3oool2000000@0oooo
00<000000?ooo`3oool01P0000020?ooo`8000001@3oool2000000L0oooo0P0000040?ooo`d0dLfY
0P3oool3000000T0oooo0P0000060?ooo`030000003oool0oooo00H0000000<0oooo000000000000
0P0000020?ooo``000000P3oool4000000030?ooo`000000000000@000000P3oool00`000000oooo
0?ooo`040?ooo`8000002@3oool300000080oooo3@3AcJT20?ooo`8000001@3oool9000000D0oooo
0P0000030?ooo`8000002@3oool2000000@0oooo0`0000020?ooo`<00000203oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00800000103oool00`000000oooo0?ooo`040?ooo`<00000
0P3oool=0=7=Z@800000303oool3000000L0oooo0P0000050?ooo`@000000`3oool300000080oooo
0P0000020?ooo`<00000103oool3000000D0oooo0P0000070?ooo`<00000303oool200000100dLfY
000>0=7=Z@800000103oool2000000030?ooo`00000000000080oooo0P0000040?ooo`<00000303o
ool2000000<0oooo200000090?ooo`H000000P3oool700000080oooo100000020?ooo`D000000P3o
ool2000000d0dLfY100000020?ooo`030000003oool0oooo00H0oooo1`0000020?ooo`8000000P3o
ool4000000030?ooo`0000000000008000000P3oool4000000<0oooo100000020?ooo`@0000000<0
oooo0000000000000P0000020?ooo`8000000P3oool7000000P0oooo00<000000?ooo`3oool01000
000=0=7=Z@D00000103oool4000000D0oooo1`0000020?ooo`T00000103oool9000000<0oooo2@00
00020?ooo`L000001@3oool4000000@0oooo1@00000=0=7=Z@80oooo0P0000050?ooo`T000001@3o
ool2000000<0oooo0P0000090?ooo`800000103oool300000080oooo0`0000080?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P0000040?ooo`030000003oool0oooo00@0oooo0`00
00020?ooo`d0dLfY0P00000<0?ooo`<000001`3oool2000000D0oooo100000030?ooo`<000000P3o
ool200000080oooo0`0000040?ooo`<000001@3oool2000000L0oooo0`00000<0?ooo`800000403A
cJT000h0dLfY0P0000040?ooo`80000000<0oooo0000000000000P3oool2000000@0oooo0`00000<
0?ooo`8000000`3oool8000000T0oooo1P0000020?ooo`L000000P3oool400000080oooo1@000002
0?ooo`8000003@3AcJT400000080oooo00<000000?ooo`3oool01P3oool700000080oooo0P000002
0?ooo`@0000000<0oooo0000000000000P0000020?ooo`@000000`3oool400000080oooo10000000
0`3oool000000000000200000080oooo0P0000020?ooo`L00000203oool00`000000oooo0?ooo`04
000000d0dLfY1@0000040?ooo`@000001@3oool700000080oooo2@0000040?ooo`T000000`3oool9
00000080oooo1`0000050?ooo`@00000103oool5000000d0dLfY100000030?ooo`8000000P3oool3
000000L0oooo100000030?ooo`@00000103oool700000080oooo00<000000?ooo`3oool00P3oool5
00000080oooo0P0000030?ooo`@000001`3oool2000000<0oooo0P0000040?ooo`<000000P3oool=
0=7=Z@80oooo00<000000?ooo`3oool00P0000020?ooo`<000001`3oool2000000<0oooo0P000003
0?ooo`T000000P3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool02@000003
0?ooo`8000000`3oool2000000L0oooo0`0000020?ooo`8000000P3oool00`000000oooo0?ooo`0@
0=7=Z@003P3AcJT8000000T0oooo1@0000060?ooo`8000000P3oool500000080oooo0P0000020?oo
o`8000001P3oool00`000000oooo0?ooo`0400000080oooo2@0000080?ooo`8000000P3oool00`00
0000oooo0?ooo`0200000080oooo3@3AcJT400000080oooo0`0000060?ooo`@000003@3oool30000
0080oooo0P0000020?ooo`8000000`3oool200000080oooo0P0000020?ooo`<000003@3oool40000
00H0oooo0`0000020?ooo`@000003@3AcJT700000080oooo0P0000030?ooo`8000000P3oool50000
0080oooo1P0000070?ooo``000001`3oool600000080oooo1@0000020?ooo`8000000`3oool20000
0080oooo1`00000=0=7=Z@8000000`3oool6000000030?ooo`00000000000080oooo0P0000020?oo
o`030000003oool0oooo00D000000P3oool200000080oooo0`00000;0?ooo`L00000103oool50000
00L0oooo1P0000000`3oool000000000000500000080oooo0P00000=0=7=Z@80oooo00<000000?oo
o`3oool00P0000020?ooo`<000001`3oool2000000<0oooo0P0000030?ooo`T000000P3oool00`00
0000oooo0?ooo`0200000080oooo00<000000?ooo`3oool02@0000030?ooo`8000000`3oool20000
00L0oooo0`0000020?ooo`8000000P3oool00`000000oooo0?ooo`0@0=7=Z@003P3AcJT8000000T0
oooo1@0000060?ooo`8000000P3oool500000080oooo0P0000020?ooo`8000001P3oool00`000000
oooo0?ooo`0400000080oooo2@0000080?ooo`8000000P3oool00`000000oooo0?ooo`0200000080
oooo3@3AcJT400000080oooo0`0000060?ooo`@000003@3oool300000080oooo0P0000020?ooo`80
00000`3oool200000080oooo0P0000020?ooo`<000003@3oool4000000H0oooo0`0000020?ooo`@0
00003@3AcJT700000080oooo0P0000030?ooo`8000000P3oool500000080oooo1P0000070?ooo``0
00001`3oool600000080oooo1@0000020?ooo`8000000`3oool200000080oooo1`00000=0=7=Z@80
00000`3oool6000000030?ooo`00000000000080oooo0P0000020?ooo`030000003oool0oooo00D0
00000P3oool200000080oooo0`00000;0?ooo`L00000103oool5000000L0oooo1P0000000`3oool0
00000000000500000080oooo0P00000=0=7=Z@80000000<0oooo0000000000001@3oool2000000D0
oooo0P0000020?ooo`030000003oool0oooo0080oooo2@0000050?ooo`030000003oool0oooo0080
00000P3oool00`000000oooo0?ooo`040?ooo`P00000103oool00`000000oooo0?ooo`02000000D0
oooo0P0000050?ooo`80000000<0oooo000000000000403AcJT000h0dLfY0P3oool2000000@0oooo
00<000000?ooo`3oool00P3oool4000000D0oooo100000080?ooo`8000000`3oool2000000@0oooo
1P0000000`3oool000000000000400000080oooo1P0000050?ooo`8000000P3oool200000080oooo
0`0000020?ooo`@000003@3AcJT70?ooo`8000000P3oool2000000H0oooo00<000000?ooo`3oool0
100000040?ooo`D00000103oool2000000L0oooo0P0000040?ooo`D00000103oool400000080oooo
00<000000?ooo`3oool0103oool200000080oooo0P0000070?ooo`d0dLfY1@3oool600000080oooo
00<000000?ooo`3oool0103oool2000000030?ooo`000000000000@000000`3oool2000000@0oooo
300000040?ooo`8000000`3oool6000000030?ooo`000000000000H0oooo00<000000?ooo`3oool0
1P0000050?ooo`d0dLfY103oool00`000000oooo0?ooo`05000000@0oooo0P0000020?ooo`<00000
1@3oool4000000@0oooo0`0000040?ooo`8000000`3oool200000080oooo1@0000020?ooo`<00000
1P3oool00`000000oooo0?ooo`040?ooo`8000000`3oool200000080oooo00<000000?ooo`3oool0
0P00000=0=7=Z@<00000103oool3000000T0oooo1`0000020?ooo`D000000P3oool00`000000oooo
0?ooo`0<00000080oooo0P0000000`3oool000000000000300000080oooo1`0000090?ooo`<00000
103oool300000100dLfY000>0=7=Z@/0oooo200000050?ooo`@00000103oool200000080oooo00<0
00000?ooo`3oool0203oool2000000D0oooo0P0000060?ooo`8000000`3oool4000000@0oooo1`00
00040?ooo`8000003@3AcJT70?ooo`8000000P3oool2000000H0oooo00<000000?ooo`3oool01000
00040?ooo`D00000103oool2000000L0oooo0P0000040?ooo`D00000103oool400000080oooo00<0
00000?ooo`3oool0103oool200000080oooo0P0000070?ooo`d0dLfY1@3oool600000080oooo00<0
00000?ooo`3oool0103oool2000000030?ooo`000000000000@000000`3oool2000000@0oooo3000
00040?ooo`8000000`3oool6000000030?ooo`000000000000H0oooo00<000000?ooo`3oool01P00
00050?ooo`d0dLfY103oool00`000000oooo0?ooo`05000000@0oooo0P0000020?ooo`<000001@3o
ool4000000@0oooo0`0000040?ooo`8000000`3oool200000080oooo1@0000020?ooo`<000001P3o
ool00`000000oooo0?ooo`040?ooo`8000000`3oool200000080oooo00<000000?ooo`3oool00P00
000=0=7=Z@<00000103oool3000000T0oooo1`0000020?ooo`D000000P3oool00`000000oooo0?oo
o`0<00000080oooo0P0000000`3oool000000000000300000080oooo1`0000090?ooo`<00000103o
ool300000100dLfY000>0=7=Z@/0oooo200000050?ooo`@00000103oool200000080oooo00<00000
0?ooo`3oool0203oool2000000D0oooo0P0000060?ooo`8000000`3oool4000000@0oooo1`000004
0?ooo`8000003@3AcJT20?ooo`@0000000<0oooo0000000000002P0000000`3oool0000000000008
0?ooo`D00000103oool;000000@0oooo1@0000080?ooo`80000000<0oooo0000000000002P000000
0`3oool000000000000200000080oooo3@3AcJT2000000<0oooo0P00000;0?ooo`@0000000<0oooo
0000000000000P0000070?ooo`8000001`3oool2000000L0oooo0P0000070?ooo`@0000000<0oooo
0000000000000P00000;0?ooo`8000000`3oool2000000d0dLfY1@3oool200000080oooo0P000005
0?ooo`T000001@3oool400000080oooo0`0000020?ooo`@0000000<0oooo000000000000103oool3
00000080oooo0P0000070?ooo`T000000P3oool7000000<0oooo0P00000=0=7=Z@L000000P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080000000<0oooo000000000000303oool4
000000030?ooo`000000000000@0000000<0oooo0000000000000P00000<0?ooo`80000000<0oooo
0000000000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L00000403AcJT0
00h0dLfY103oool700000080oooo0P0000060?ooo`<000000P3oool6000000D0oooo1P0000040?oo
o`L000000P3oool2000000@0oooo2@0000040?ooo`8000001@3oool2000000@0oooo3@3AcJT20?oo
o`8000000P3oool00`000000oooo0?ooo`020?ooo`800000103oool900000080oooo0P0000050?oo
o`@000000P3oool2000000<0oooo0P0000020?ooo`@000001@3oool200000080oooo2@0000040?oo
o`800000103oool00`000000oooo0?ooo`0200000080oooo3@3AcJT2000000<0oooo0P00000;0?oo
o`@0000000<0oooo0000000000000P0000070?ooo`8000001`3oool2000000L0oooo0P0000070?oo
o`@0000000<0oooo0000000000000P00000;0?ooo`8000000`3oool2000000d0dLfY1@3oool20000
0080oooo0P0000050?ooo`T000001@3oool400000080oooo0`0000020?ooo`@0000000<0oooo0000
00000000103oool300000080oooo0P0000070?ooo`T000000P3oool7000000<0oooo0P00000=0=7=
Z@L000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080000000<0oooo0000
00000000303oool4000000030?ooo`000000000000@0000000<0oooo0000000000000P00000<0?oo
o`80000000<0oooo0000000000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00L00000403AcJT000h0dLfY103oool700000080oooo0P0000060?ooo`<000000P3oool6000000D0
oooo1P0000040?ooo`L000000P3oool2000000@0oooo2@0000040?ooo`8000001@3oool2000000@0
oooo3@3AcJT20?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`800000103oool900000080
oooo0P0000050?ooo`@000000P3oool2000000<0oooo0P0000020?ooo`@000001@3oool200000080
oooo2@0000040?ooo`800000103oool00`000000oooo0?ooo`0200000080oooo3@3AcJT40?ooo`03
0000003oool0oooo00@0oooo1@0000020?ooo`8000000`3oool200000080oooo0P0000030?ooo`@0
0000103oool9000000<0oooo100000030?ooo`8000000P3oool2000000<0oooo0P0000020?ooo`D0
00001P3oool00`000000oooo0?ooo`020?ooo`d0dLfY1@0000020?ooo`8000001`3oool5000000@0
oooo1@0000060?ooo`030000003oool0oooo00800000103oool5000000<0oooo100000020?ooo`80
000000<0oooo0000000000000P3oool2000000030?ooo`00000000000080oooo100000000`3oool0
0000000000050?ooo`@000003@3AcJT20?ooo`<00000103oool00`000000oooo0?ooo`02000000D0
oooo0P0000000`3oool0000000000007000000@0oooo00<000000?ooo`3oool00`0000020?ooo`80
00000P3oool300000080oooo0P0000030?ooo`T0000000<0oooo0000000000001@3oool200000080
oooo00<000000?ooo`3oool00P3oool300000080oooo403AcJT000h0dLfY103oool500000080oooo
100000070?ooo`X000000P3oool3000000@0oooo100000040?ooo`D000000P3oool8000000d0oooo
100000030?ooo`8000000P3oool=0=7=Z@80oooo0P0000030?ooo`H000000P3oool7000000@0oooo
0P0000020?ooo`8000000`3oool4000000@0oooo0`0000040?ooo`@000000`3oool200000080oooo
0P0000040?ooo`L000000P3oool6000000<0oooo0P0000020?ooo`d0dLfY0P0000020?ooo`030000
003oool0oooo00L000002`3oool4000000<0oooo100000020?ooo`<000000P3oool200000080oooo
0`0000020?ooo`@000000`3oool4000000/0oooo1`0000020?ooo`030000003oool0oooo00800000
3@3AcJT5000000H0oooo1@0000020?ooo`X000000P3oool900000080oooo0P0000020?ooo`X00000
1P3oool300000080oooo0P0000000`3oool0000000000004000000D0oooo1@0000020?ooo`800000
3@3AcJT20?ooo`<00000103oool00`000000oooo0?ooo`02000000D0oooo0P0000000`3oool00000
00000007000000@0oooo00<000000?ooo`3oool00`0000020?ooo`8000000P3oool300000080oooo
0P0000030?ooo`T0000000<0oooo0000000000001@3oool200000080oooo00<000000?ooo`3oool0
0P3oool300000080oooo403AcJT000h0dLfY103oool500000080oooo100000070?ooo`X000000P3o
ool3000000@0oooo100000040?ooo`D000000P3oool8000000d0oooo100000030?ooo`8000000P3o
ool=0=7=Z@80oooo0P0000030?ooo`H000000P3oool7000000@0oooo0P0000020?ooo`8000000`3o
ool4000000@0oooo0`0000040?ooo`@000000`3oool200000080oooo0P0000040?ooo`L000000P3o
ool6000000<0oooo0P0000020?ooo`d0dLfY0P0000020?ooo`030000003oool0oooo00L000002`3o
ool4000000<0oooo100000020?ooo`<000000P3oool200000080oooo0`0000020?ooo`@000000`3o
ool4000000/0oooo1`0000020?ooo`030000003oool0oooo008000003@3AcJT5000000H0oooo1@00
00020?ooo`X000000P3oool900000080oooo0P0000020?ooo`X000001P3oool300000080oooo0P00
00000`3oool0000000000004000000D0oooo1@0000020?ooo`8000003@3AcJT20?ooo`D000000P3o
ool00`000000oooo0?ooo`02000000P0oooo0P0000090?ooo`8000001P3oool6000000L0oooo00<0
00000?ooo`3oool01`3oool2000000P0oooo0P0000020?ooo`030000003oool0oooo00D000000P3o
ool@0=7=Z@003P3AcJT40?ooo`8000000`3oool200000080oooo0P0000020?ooo`8000001@3oool4
000000@0oooo1@0000040?ooo`@000000P3oool200000080oooo00<000000?ooo`3oool00P3oool6
000000@0oooo00<000000?ooo`3oool0100000020?ooo`8000000P3oool3000000@0oooo0P00000=
0=7=Z@H000004P3oool;000000@0oooo0P0000020?ooo`<000000P3oool2000000@0oooo2`00000B
0?ooo`H000003@3AcJT7000000H0oooo0`0000040?ooo`80000000<0oooo0000000000000P000002
0?ooo`<000000P3oool200000080oooo0P0000000`3oool000000000000400000080oooo00<00000
0?ooo`3oool00P0000020?ooo`<000000P3oool4000000030?ooo`000000000000@0oooo0`000006
0?ooo`L000003@3AcJT5000000@0oooo0`0000020?ooo`@000001@3oool500000080oooo0P000002
0?ooo`8000000`3oool2000000@0oooo00<000000?ooo`3oool00P3oool300000080oooo1`000004
0?ooo`8000000`3oool200000080oooo1@0000050?ooo`@000003@3AcJT>000000<0oooo0P000002
0?ooo`<000001@3oool700000080oooo0`0000020?ooo`8000000P3oool300000080oooo1`000005
0?ooo`<000000P3oool2000000<0oooo3P00000@0=7=Z@003P3AcJT40?ooo`8000000`3oool20000
0080oooo0P0000020?ooo`8000001@3oool4000000@0oooo1@0000040?ooo`@000000P3oool20000
0080oooo00<000000?ooo`3oool00P3oool6000000@0oooo00<000000?ooo`3oool0100000020?oo
o`8000000P3oool3000000@0oooo0P00000=0=7=Z@H000004P3oool;000000@0oooo0P0000020?oo
o`<000000P3oool2000000@0oooo2`00000B0?ooo`H000003@3AcJT7000000H0oooo0`0000040?oo
o`80000000<0oooo0000000000000P0000020?ooo`<000000P3oool200000080oooo0P0000000`3o
ool000000000000400000080oooo00<000000?ooo`3oool00P0000020?ooo`<000000P3oool40000
00030?ooo`000000000000@0oooo0`0000060?ooo`L000003@3AcJT5000000@0oooo0`0000020?oo
o`@000001@3oool500000080oooo0P0000020?ooo`8000000`3oool2000000@0oooo00<000000?oo
o`3oool00P3oool300000080oooo1`0000040?ooo`8000000`3oool200000080oooo1@0000050?oo
o`@000003@3AcJT>000000<0oooo0P0000020?ooo`<000001@3oool700000080oooo0`0000020?oo
o`8000000P3oool300000080oooo1`0000050?ooo`<000000P3oool2000000<0oooo3P00000@0=7=
Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo
0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY
003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0
dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY000>0=7=Z@H0oooo1`000002
0?ooo`800000103oool400000080oooo0P00000;0?ooo`800000103oool2000000/0oooo0P000002
0?ooo`@00000103oool200000080oooo1`0000060?ooo`d0dLfY0P3oool2000000H0oooo0P00000;
0?ooo`8000000P3oool4000000@0oooo1P0000090?ooo`@000000P3oool4000000P0oooo0P00000C
0?ooo`d0dLfYF020P80=0=7=Z@8000000P3oool<00000080oooo100000040?ooo`H00000103oool2
000000@0oooo100000050?ooo`800000903oool=0=7=Z@80oooo2`0000040?ooo`8000000P3oool4
00000080oooo100000050?ooo`8000000P3oool800000080oooo1`0000020?ooo`8000000P3oool2
000000@0oooo0P0000060?ooo`030000003oool0oooo0080oooo0P0000040?oooa00dLfY000>0=7=
Z@H0oooo1`0000020?ooo`800000103oool400000080oooo0P00000;0?ooo`800000103oool20000
00/0oooo0P0000020?ooo`@00000103oool200000080oooo1`0000060?ooo`d0dLfY0P3oool20000
00H0oooo0P00000;0?ooo`8000000P3oool4000000@0oooo1P0000090?ooo`@000000P3oool40000
00P0oooo0P00000C0?ooo`d0dLfYF020P80=0=7=Z@8000000P3oool<00000080oooo100000040?oo
o`H00000103oool2000000@0oooo100000050?ooo`800000903oool=0=7=Z@80oooo2`0000040?oo
o`8000000P3oool400000080oooo100000050?ooo`8000000P3oool800000080oooo1`0000020?oo
o`8000000P3oool2000000@0oooo0P0000060?ooo`030000003oool0oooo0080oooo0P0000040?oo
oa00dLfY000>0=7=Z@80oooo1P0000090?ooo`8000002P3oool2000000D0oooo100000020?ooo`@0
00000P3oool4000000D0oooo0P00000:0?ooo`8000002@3oool600000080oooo3@3AcJT4000000/0
oooo1P0000060?ooo`8000000P3oool2000000@0oooo2@0000020?ooo`8000000P3oool6000000H0
oooo0P0000020?ooo`8000001@3oool200000080oooo0P0000020?ooo`@000000P3oool=0=7=ZEP0
P8203@3AcJT80?ooo`@000000P3oool2000000H0oooo1P0000020?ooo`@000000P3oool200000080
oooo1P0000000`3oool00000000000080?ooo`H000001P3oool200000080oooo1P0000040?ooo`80
0000103oool=0=7=Z@H000000P3oool2000000<0oooo100000020?ooo`800000103oool600000080
oooo00<000000?ooo`3oool00P3oool2000000@0oooo100000020?ooo`8000002@3oool:000000H0
oooo0`0000040?ooo`8000000P3oool@0=7=Z@003P3AcJT20?ooo`H000002@3oool2000000X0oooo
0P0000050?ooo`@000000P3oool400000080oooo100000050?ooo`8000002P3oool2000000T0oooo
1P0000020?ooo`d0dLfY1000000;0?ooo`H000001P3oool200000080oooo0P0000040?ooo`T00000
0P3oool200000080oooo1P0000060?ooo`8000000P3oool2000000D0oooo0P0000020?ooo`800000
0P3oool400000080oooo3@3AcJUH0820P0d0dLfY203oool400000080oooo0P0000060?ooo`H00000
0P3oool400000080oooo0P0000020?ooo`H0000000<0oooo000000000000203oool6000000H0oooo
0P0000020?ooo`H00000103oool2000000@0oooo3@3AcJT600000080oooo0P0000030?ooo`@00000
0P3oool2000000@0oooo1P0000020?ooo`030000003oool0oooo0080oooo0P0000040?ooo`@00000
0P3oool2000000T0oooo2P0000060?ooo`<00000103oool200000080oooo403AcJT000h0dLfY0P00
000?0?ooo`8000000P3oool2000000H0oooo1`0000020?ooo`800000203oool200000080oooo1`00
00060?ooo`8000000P3oool2000000l0oooo0P00000=0=7=Z@80oooo0P0000040?ooo`/000002P3o
ool2000000@0oooo0P0000040?ooo`T000000P3oool2000000@0oooo100000020?ooo`800000103o
ool700000080oooo0P0000080?ooo`d0dLfYF020P80=0=7=Z@80oooo1P0000020?ooo`@00000103o
ool200000080oooo0P0000080?ooo`H000002@3oool200000080oooo100000020?ooo`8000000P3o
ool200000080oooo0P0000020?ooo`800000103oool200000080oooo100000060?ooo`d0dLfY0P00
00020?ooo`H0000000<0oooo0000000000000P3oool600000080oooo0P0000020?ooo`8000000P3o
ool300000080oooo0P0000020?ooo`800000103oool6000000<0oooo0P0000020?oooa0000001@3o
ool400000080oooo0P00000@0=7=Z@003P3AcJT2000000l0oooo0P0000020?ooo`8000001P3oool7
00000080oooo0P0000080?ooo`8000000P3oool7000000H0oooo0P0000020?ooo`8000003`3oool2
000000d0dLfY0P3oool2000000@0oooo2`00000:0?ooo`800000103oool2000000@0oooo2@000002
0?ooo`800000103oool400000080oooo0P0000040?ooo`L000000P3oool2000000P0oooo3@3AcJUH
0820P0d0dLfY0P3oool600000080oooo100000040?ooo`8000000P3oool2000000P0oooo1P000009
0?ooo`8000000P3oool400000080oooo0P0000020?ooo`8000000P3oool200000080oooo0P000004
0?ooo`8000000P3oool4000000H0oooo3@3AcJT200000080oooo1P0000000`3oool0000000000002
0?ooo`H000000P3oool200000080oooo0P0000020?ooo`<000000P3oool200000080oooo0P000004
0?ooo`H000000`3oool200000080oooo400000050?ooo`@000000P3oool200000100dLfY000>0=7=
Z@80oooo100000020?ooo`8000000`3oool200000080oooo0P0000020?ooo`8000000P3oool=0000
0080oooo200000020?ooo`d000000P3oool200000080oooo0P0000020?ooo`8000000`3oool20000
0080oooo100000020?ooo`d0dLfY100000060?ooo`8000001`3oool2000000@0oooo100000040?oo
oaL00000103oool4000000@0oooo0P0000070?ooo`8000001P3oool4000000d0dLfYF020P80=0=7=
Z@80oooo0P0000020?ooo`P000000P3oool6000000`0oooo2P0000030?ooo`@000000P3oool40000
00@0oooo100000020?ooo`@000000P3oool200000080oooo0P0000020?ooo`8000001P3oool=0=7=
Z@H0oooo100000000`3oool0000000000002000000@0oooo100000040?ooo`T000000P3oool40000
00@0oooo0P0000020?ooo`@000000`3oool2000001<0oooo1P0000040?oooa00dLfY000>0=7=Z@80
oooo100000020?ooo`8000000`3oool200000080oooo0P0000020?ooo`8000000P3oool=00000080
oooo200000020?ooo`d000000P3oool200000080oooo0P0000020?ooo`8000000`3oool200000080
oooo100000020?ooo`d0dLfY100000060?ooo`8000001`3oool2000000@0oooo100000040?oooaL0
0000103oool4000000@0oooo0P0000070?ooo`8000001P3oool4000000d0dLfYF020P80=0=7=Z@80
oooo0P0000020?ooo`P000000P3oool6000000`0oooo2P0000030?ooo`@000000P3oool4000000@0
oooo100000020?ooo`@000000P3oool200000080oooo0P0000020?ooo`8000001P3oool=0=7=Z@H0
oooo100000000`3oool0000000000002000000@0oooo100000040?ooo`T000000P3oool4000000@0
oooo0P0000020?ooo`@000000`3oool2000001<0oooo1P0000040?oooa00dLfY000>0=7=Z@H00000
0P3oool2000000L0oooo200000020?ooo`8000001@3oool400000080oooo200000020?ooo`@00000
1@3oool200000080oooo200000070?ooo`8000000P3oool6000000d0dLfY0P0000080?ooo`L00000
0P3oool200000080oooo100000040?ooo`X000000P3oool3000000@0oooo200000020?ooo`@00000
103oool200000080oooo1@0000080?ooo`@000003@3AcJUH0820P0d0dLfY0P3oool4000000P0oooo
100000060?ooo`H000000P3oool4000000@0oooo100000020?ooo`<00000103oool6000000@0oooo
2P00000<0?ooo`8000000P3oool=0=7=Z@800000103oool=000000@0oooo200000020?ooo`030000
003oool0oooo0080oooo0P0000020?ooo`H000000P3oool4000000030?ooo`00000000000080oooo
1P0000060?ooo`8000000P3oool2000000030?ooo`0000000000008000000P3oool200000080oooo
403AcJT000h0dLfY1P0000020?ooo`8000001`3oool800000080oooo0P0000050?ooo`@000000P3o
ool800000080oooo100000050?ooo`8000000P3oool8000000L0oooo0P0000020?ooo`H000003@3A
cJT2000000P0oooo1`0000020?ooo`8000000P3oool4000000@0oooo2P0000020?ooo`<00000103o
ool800000080oooo100000040?ooo`8000000P3oool5000000P0oooo1000000=0=7=ZEP0P8203@3A
cJT20?ooo`@00000203oool4000000H0oooo1P0000020?ooo`@00000103oool400000080oooo0`00
00040?ooo`H00000103oool:000000`0oooo0P0000020?ooo`d0dLfY0P0000040?ooo`d00000103o
ool800000080oooo00<000000?ooo`3oool00P3oool200000080oooo1P0000020?ooo`@0000000<0
oooo0000000000000P3oool6000000H0oooo0P0000020?ooo`80000000<0oooo0000000000000P00
00020?ooo`8000000P3oool@0=7=Z@003P3AcJT2000000@0oooo1`0000040?ooo`8000001P3oool4
00000080oooo1@0000040?ooo`800000103oool2000000@0oooo1@0000020?ooo`@000001P3oool2
000000@0oooo1`0000040?ooo`8000003@3AcJT200000080oooo0P0000020?ooo`T000003P3oool4
000000@0oooo0P0000020?ooo`/000000P3oool200000080oooo0P0000020?ooo`800000103oool2
000000D0oooo0P00000:0?ooo`d0dLfYF020P80=0=7=Z@@00000203oool400000080oooo0P000008
0?ooo`800000203oool6000000D0oooo0P0000020?ooo`8000000P3oool4000000P0oooo0P000004
0?ooo`H000000P3oool2000000@0oooo3@3AcJT8000000<0oooo1P0000020?ooo`8000000P3oool4
000000T0oooo100000040?ooo`8000000P3oool700000080oooo0P0000020?ooo`P000000P3oool2
00000080oooo0`0000060?ooo`@00000403AcJT000h0dLfY0P0000040?ooo`L00000103oool20000
00H0oooo100000020?ooo`D00000103oool2000000@0oooo0P0000040?ooo`D000000P3oool40000
00H0oooo0P0000040?ooo`L00000103oool2000000d0dLfY0P0000020?ooo`8000000P3oool90000
00h0oooo100000040?ooo`8000000P3oool;00000080oooo0P0000020?ooo`8000000P3oool20000
00@0oooo0P0000050?ooo`8000002P3oool=0=7=ZEP0P8203@3AcJT4000000P0oooo100000020?oo
o`800000203oool2000000P0oooo1P0000050?ooo`8000000P3oool200000080oooo100000080?oo
o`800000103oool600000080oooo0P0000040?ooo`d0dLfY0P3oool200000080oooo2`0000080?oo
o`8000000P3oool200000080oooo1@0000040?ooo`800000103oool2000000T0oooo0P0000040?oo
o`800000203oool5000000P0oooo403AcJT000h0dLfY0P0000040?ooo`L00000103oool2000000H0
oooo100000020?ooo`D00000103oool2000000@0oooo0P0000040?ooo`D000000P3oool4000000H0
oooo0P0000040?ooo`L00000103oool2000000d0dLfY0P0000020?ooo`@000000P3oool5000000@0
oooo0P0000020?ooo`8000000P3oool600000080oooo200000030?ooo`8000000P3oool4000000@0
oooo0P00000?0?ooo`800000103oool8000000d0dLfYF020P80=0=7=Z@P0oooo400000080?ooo`P0
00001`3oool2000000P0oooo100000020?ooo`800000103oool400000080oooo0P0000080?ooo`80
00000P3oool=0=7=Z@80oooo0P0000020?ooo`/00000203oool200000080oooo0P0000020?ooo`D0
0000103oool2000000@0oooo0P0000090?ooo`800000103oool2000000P0oooo1@0000080?oooa00
dLfY000>0=7=Z@80oooo100000090?ooo`X00000103oool2000000<0oooo0P0000020?ooo`800000
203oool200000080oooo0P0000030?ooo`800000103oool:000000T0oooo100000020?ooo`d0dLfY
0P0000020?ooo`@000000P3oool5000000@0oooo0P0000020?ooo`8000000P3oool600000080oooo
200000030?ooo`8000000P3oool4000000@0oooo0P00000?0?ooo`800000103oool8000000d0dLfY
F020P80=0=7=Z@P0oooo400000080?ooo`P000001`3oool2000000P0oooo100000020?ooo`800000
103oool400000080oooo0P0000080?ooo`8000000P3oool=0=7=Z@8000000P3oool200000080oooo
0P0000030?ooo`800000203oool2000000@0oooo100000000`3oool000000000000B000000030?oo
o`0000000000008000000P3oool600000080oooo0P0000020?ooo`8000001`3oool2000000@0oooo
403AcJT000h0dLfY0P3oool4000000T0oooo2P0000040?ooo`8000000`3oool200000080oooo0P00
00080?ooo`8000000P3oool2000000<0oooo0P0000040?ooo`X000002@3oool400000080oooo3@3A
cJT20?ooo`@000002@3oool200000080oooo0P0000040?ooo``00000103oool2000000<0oooo1000
00020?ooo`@000000P3oool200000080oooo100000060?ooo`<000000P3oool2000000@0oooo0P00
00040?ooo`d0dLfYF020P80=0=7=Z@80oooo0P0000020?ooo`800000103oool200000080oooo0P00
00040?ooo`8000001P3oool200000080oooo1P0000040?ooo`<000000P3oool6000000P0oooo0P00
00080?ooo`P00000103oool4000000d0dLfY0P0000020?ooo`8000000P3oool2000000<0oooo0P00
00080?ooo`800000103oool4000000030?ooo`00000000000180000000<0oooo0000000000000P00
00020?ooo`H000000P3oool200000080oooo0P0000070?ooo`800000103oool@0=7=Z@003P3AcJT4
00000080oooo0P0000020?ooo`L000000P3oool2000000X0oooo0`0000020?ooo`H00000103oool6
00000080oooo0`00000:0?ooo`8000000P3oool700000080oooo0P0000020?ooo`@000003@3AcJT2
0?ooo`@000002@3oool200000080oooo0P0000040?ooo``00000103oool2000000<0oooo10000002
0?ooo`@000000P3oool200000080oooo100000060?ooo`<000000P3oool2000000@0oooo0P000004
0?ooo`d0dLfYF020P80=0=7=Z@80oooo0P0000020?ooo`800000103oool200000080oooo0P000004
0?ooo`8000001P3oool200000080oooo1P0000040?ooo`<000000P3oool6000000P0oooo0P000008
0?ooo`P00000103oool4000000d0dLfY103oool6000000/0oooo100000090?ooo`8000000P3oool4
00000080oooo0P0000080?ooo`<000000P3oool2000000@0oooo0P0000020?ooo`@00000103oool3
00000080oooo0P0000040?oooa00dLfY000>0=7=Z@@000000P3oool200000080oooo1`0000020?oo
o`8000002P3oool300000080oooo1P0000040?ooo`H000000P3oool3000000X0oooo0P0000020?oo
o`L000000P3oool200000080oooo1000000=0=7=Z@8000000P3oool200000080oooo1000000=0?oo
o`@000000P3oool6000000@0oooo0P0000030?ooo`@000000P3oool4000000H0oooo100000020?oo
o`8000002@3oool200000080oooo1P00000=0=7=ZEP0P8203@3AcJT200000080oooo3P0000040?oo
o`800000103oool200000080oooo200000020?ooo`D00000103oool2000000@0oooo1P0000020?oo
o`8000000P3oool4000000`0oooo1000000=0=7=Z@@0oooo1P00000;0?ooo`@000002@3oool20000
0080oooo100000020?ooo`800000203oool300000080oooo0P0000040?ooo`8000000P3oool40000
00@0oooo0`0000020?ooo`800000103oool@0=7=Z@003P3AcJT20?ooo`8000000P3oool200000080
oooo1@0000020?ooo`8000001P3oool4000000/0oooo2000000;0?ooo`@000001P3oool200000080
oooo1@0000020?ooo`8000000P3oool200000080oooo3@3AcJT200000080oooo0P0000020?ooo`@0
00003@3oool400000080oooo1P0000040?ooo`8000000`3oool400000080oooo100000060?ooo`@0
00000P3oool2000000T0oooo0P0000020?ooo`H000003@3AcJUH0820P0d0dLfY0P0000020?ooo`h0
0000103oool2000000@0oooo0P0000020?ooo`P000000P3oool5000000@0oooo0P0000040?ooo`H0
00000P3oool200000080oooo1000000<0?ooo`@000003@3AcJT2000000P0oooo0`0000040?ooo`@0
00000P3oool600000080oooo0P0000050?ooo`800000203oool2000000T0oooo0P0000060?ooo`P0
00001`3oool600000100dLfY000>0=7=Z@80oooo0P0000020?ooo`8000000P3oool500000080oooo
0P0000060?ooo`@000002`3oool8000000/0oooo100000060?ooo`8000000P3oool500000080oooo
0P0000020?ooo`8000000P3oool=0=7=Z@@00000103oool;000000P0oooo100000040?ooo`800000
103oool700000080oooo0P0000020?ooo`800000203oool4000000T0oooo100000040?ooo`800000
0P3oool=0=7=ZEP0P8203@3AcJT20?ooo`@000000P3oool2000000@0oooo100000060?ooo`H00000
203oool200000080oooo1@0000020?ooo`@000000P3oool2000000@0oooo200000020?ooo`@00000
203oool200000080oooo0P00000=0=7=Z@800000203oool3000000@0oooo100000020?ooo`H00000
0P3oool2000000D0oooo0P0000080?ooo`8000002@3oool2000000H0oooo200000070?ooo`H00000
403AcJT000h0dLfY2P3oool5000000@0oooo2P00000;0?ooo`P000002`3oool:000000@0oooo1@00
000:0?ooo`d0dLfY100000040?ooo`/00000203oool4000000@0oooo0P0000040?ooo`L000000P3o
ool200000080oooo0P0000080?ooo`@000002@3oool4000000@0oooo0P0000020?ooo`d0dLfYF020
P80=0=7=Z@80oooo100000020?ooo`800000103oool4000000H0oooo1P0000080?ooo`8000000P3o
ool500000080oooo100000020?ooo`800000103oool800000080oooo100000080?ooo`8000000P3o
ool2000000d0dLfY1P3oool200000080oooo00<000000?ooo`3oool01P0000060?ooo`8000001P3o
ool00`000000oooo0?ooo`04000000X0oooo2@0000020?ooo`8000000P3oool6000000H0oooo00<0
00000?ooo`3oool00P3oool400000080oooo403AcJT000h0dLfY2P3oool5000000@0oooo2P00000;
0?ooo`P000002`3oool:000000@0oooo1@00000:0?ooo`d0dLfY100000040?ooo`8000002@3oool4
00000080oooo0P0000020?ooo`@000000P3oool200000080oooo0P0000070?ooo`8000000P3oool2
000000@0oooo0P0000020?ooo`8000000P3oool2000000/0oooo0P0000040?ooo`@000003@3AcJUH
0820P0d0dLfY0P0000020?ooo`@000001P3oool2000000@0oooo0P0000020?ooo`@000001P3oool6
000000T0oooo100000060?ooo`800000203oool2000000H0oooo0P0000040?ooo`H000003@3AcJT6
0?ooo`8000000P3oool00`000000oooo0?ooo`06000000H0oooo0P0000060?ooo`030000003oool0
oooo00@000002P3oool900000080oooo0P0000020?ooo`H000001P3oool00`000000oooo0?ooo`02
0?ooo`@000000P3oool@0=7=Z@003P3AcJT20?ooo`@000000P3oool700000080oooo100000020?oo
o`H000000P3oool;000000@0oooo2`0000020?ooo`H000000P3oool400000080oooo1`0000020?oo
o`@000000P3oool=0=7=Z@@00000103oool2000000T0oooo100000020?ooo`8000000P3oool40000
0080oooo0P0000020?ooo`8000001`3oool200000080oooo0P0000040?ooo`8000000P3oool20000
0080oooo0P00000;0?ooo`800000103oool4000000d0dLfYF020P80=0=7=Z@8000000P3oool40000
00H0oooo0P0000040?ooo`8000000P3oool4000000H0oooo1P0000090?ooo`@000001P3oool20000
00P0oooo0P0000060?ooo`800000103oool6000000d0dLfY0P3oool;000001T0oooo1000000:0?oo
o`8000001@3oool2000000@0oooo100000020?ooo`L00000103oool400000080oooo403AcJT000h0
dLfY0P3oool400000080oooo1`0000020?ooo`@000000P3oool600000080oooo2`0000040?ooo`/0
00000P3oool600000080oooo100000020?ooo`L000000P3oool400000080oooo3@3AcJT4000000@0
oooo0P0000090?ooo`@000000P3oool200000080oooo100000020?ooo`8000000P3oool2000000L0
oooo0P0000020?ooo`800000103oool200000080oooo0P0000020?ooo`8000002`3oool2000000@0
oooo1000000=0=7=ZEP0P8203@3AcJT600000080oooo0P0000020?ooo`@000000P3oool8000000@0
oooo0P0000020?ooo`8000000P3oool2000000H0oooo2`0000020?ooo`@000000P3oool2000000H0
oooo0P0000020?ooo`@00000103oool200000080oooo3@3AcJT20?ooo`/000006@3oool4000000X0
oooo0P0000050?ooo`800000103oool400000080oooo1`0000040?ooo`@000000P3oool@0=7=Z@00
3P3AcJT400000080oooo2@0000040?ooo`@00000203oool300000080oooo100000080?ooo`@00000
0P3oool3000000P0oooo100000040?ooo`T000000P3oool4000000d0dLfY0P3oool800000080oooo
1`00000<0?ooo`8000000P3oool200000080oooo0P0000050?ooo`8000000P3oool200000080oooo
0P00000<0?ooo`8000001`3oool200000080oooo0P0000040?ooo`8000003@3AcJUH0820P0d0dLfY
300000020?ooo`H000000P3oool4000000@0oooo100000060?ooo`8000000P3oool2000000<0oooo
0P0000060?ooo`@000000P3oool4000000@0oooo100000080?ooo`H000003@3AcJT200000080oooo
0P0000040?ooo`030000003oool0oooo00@000000P3oool8000000L0oooo0P0000040?ooo`800000
103oool200000080oooo0P0000020?ooo`L000000P3oool2000000P0oooo0P0000020?ooo`<00000
0P3oool600000100dLfY000>0=7=Z@@000000P3oool9000000@0oooo100000080?ooo`<000000P3o
ool4000000P0oooo100000020?ooo`<00000203oool4000000@0oooo2@0000020?ooo`@000003@3A
cJT20?ooo`P000000P3oool7000000`0oooo0P0000020?ooo`8000000P3oool2000000D0oooo0P00
00020?ooo`8000000P3oool2000000`0oooo0P0000070?ooo`8000000P3oool2000000@0oooo0P00
000=0=7=ZEP0P8203@3AcJT<00000080oooo1P0000020?ooo`@00000103oool4000000H0oooo0P00
00020?ooo`8000000`3oool2000000H0oooo100000020?ooo`@00000103oool4000000P0oooo1P00
000=0=7=Z@8000000P3oool2000000@0oooo00<000000?ooo`3oool0100000020?ooo`P000001`3o
ool2000000@0oooo0P0000040?ooo`8000000P3oool200000080oooo1`0000020?ooo`800000203o
ool200000080oooo0`0000020?ooo`H00000403AcJT000h0dLfY0P0000020?ooo`8000000P3oool2
000000<0oooo0P00000<0?ooo`@000000`3oool8000000@0oooo200000030?ooo`@00000303oool2
000000<0oooo0P0000020?ooo`8000000P3oool2000000d0dLfY0P0000020?ooo`8000000P3oool2
000000T0oooo0P0000020?ooo`H000000P3oool200000080oooo100000020?ooo`L000000P3oool4
00000080oooo0P0000020?ooo`H000000P3oool2000000T0oooo0P0000020?ooo`8000000P3oool2
000000d0dLfYF020P80=0=7=Z@8000001P3oool200000080oooo100000060?ooo`H00000103oool2
00000080oooo0P0000040?ooo`D000000P3oool4000000@0oooo0P0000020?ooo`@000001P3oool2
000000@0oooo1P0000060?ooo`d0dLfY0P0000040?ooo`8000000P3oool00`000000oooo0?ooo`02
0?ooo`@000001P3oool2000000L0oooo0P0000020?ooo`H000000P3oool200000080oooo1@000004
0?ooo`@00000103oool2000000@0oooo0P0000020?ooo`<000000P3oool400000080oooo403AcJT0
00h0dLfY0P0000020?ooo`8000000P3oool2000000<0oooo0P00000<0?ooo`@000000`3oool80000
00@0oooo200000030?ooo`@00000303oool2000000<0oooo0P0000020?ooo`8000000P3oool20000
00d0dLfY0P0000020?ooo`8000000P3oool2000000T0oooo0P0000020?ooo`H000000P3oool20000
0080oooo100000020?ooo`L000000P3oool400000080oooo0P0000020?ooo`H000000P3oool20000
00T0oooo0P0000020?ooo`8000000P3oool2000000d0dLfYF020P80=0=7=Z@8000001P3oool20000
0080oooo100000060?ooo`H00000103oool200000080oooo0P0000040?ooo`D000000P3oool40000
00@0oooo0P0000020?ooo`@000001P3oool2000000@0oooo1P0000060?ooo`d0dLfY0P0000040?oo
o`8000000P3oool00`000000oooo0?ooo`020?ooo`@000001P3oool2000000L0oooo0P0000020?oo
o`H000000P3oool200000080oooo1@0000040?ooo`@00000103oool2000000@0oooo0P0000020?oo
o`<000000P3oool400000080oooo403AcJT000h0dLfY0P0000080?oooaD000000`3oool2000000@0
oooo0P0000040?ooo`800000103oool2000000<0oooo5@0000080?ooo`8000003@3AcJT4000000P0
oooo0`0000020?ooo`800000103oool200000080oooo2P0000090?ooo`H000001P3oool400000080
oooo0P0000020?ooo`8000000P3oool300000080oooo100000020?ooo`800000103oool=0=7=ZEP0
P8203@3AcJT60?ooo`8000000P3oool200000080oooo1P0000080?ooo`h000000P3oool500000080
oooo0P00000<0?ooo`8000000P3oool400000080oooo100000020?ooo`@00000103oool=0=7=Z@@0
oooo1P0000000`3oool000000000000400000080oooo0P0000020?ooo`X000002@3oool2000000P0
oooo0`0000020?ooo`X000000P3oool400000080oooo0P0000000`3oool00000000000020?ooo`80
00000P3oool200000100dLfY000>0=7=Z@800000203ooolE000000<0oooo0P0000040?ooo`800000
103oool2000000@0oooo0P0000030?oooaD00000203oool2000000d0dLfY100000080?ooo`<00000
0P3oool2000000@0oooo0P0000020?ooo`X000002@3oool6000000H0oooo100000020?ooo`800000
0P3oool200000080oooo0`0000020?ooo`@000000P3oool2000000@0oooo3@3AcJUH0820P0d0dLfY
1P3oool200000080oooo0P0000020?ooo`H00000203oool>00000080oooo1@0000020?ooo`800000
303oool200000080oooo100000020?ooo`@000000P3oool4000000@0oooo3@3AcJT40?ooo`H00000
00<0oooo000000000000100000020?ooo`8000000P3oool:000000T0oooo0P0000080?ooo`<00000
0P3oool:00000080oooo100000020?ooo`80000000<0oooo0000000000000P3oool200000080oooo
0P00000@0=7=Z@003P3AcJT20?ooo`P000001@3oool8000000H0oooo0P0000030?ooo`8000000P3o
ool<00000080oooo0P0000030?ooo`8000001P3oool8000000D0oooo200000020?ooo`d0dLfY1P3o
ool2000000T0oooo0P0000060?ooo`@00000203oool4000000L0oooo100000040?ooo`8000000P3o
ool4000000@0oooo100000090?ooo`8000001P3oool=0=7=ZEP0P8203@3AcJT:000000H0oooo1000
00020?ooo`8000000P3oool2000000h0oooo0P0000020?ooo`030000003oool0oooo00@00000203o
ool2000000H0oooo0P0000020?ooo`@000001P3oool400000080oooo3@3AcJT4000000@0oooo0P00
00030?ooo`@00000103oool:000000D0oooo1000000>0?ooo`030000003oool0oooo00@000000P3o
ool200000080oooo0P0000040?ooo`8000000P3oool00`000000oooo0?ooo`02000000H0oooo403A
cJT000h0dLfY0P3oool8000000D0oooo200000060?ooo`8000000`3oool200000080oooo30000002
0?ooo`8000000`3oool2000000H0oooo200000050?ooo`P000000P3oool=0=7=Z@H0oooo0P000009
0?ooo`8000001P3oool4000000P0oooo100000070?ooo`@00000103oool200000080oooo10000004
0?ooo`@000002@3oool2000000H0oooo3@3AcJUH0820P0d0dLfY2P0000060?ooo`@000000P3oool2
00000080oooo0P00000>0?ooo`8000000P3oool00`000000oooo0?ooo`04000000P0oooo0P000006
0?ooo`8000000P3oool4000000H0oooo100000020?ooo`d0dLfY100000040?ooo`8000000`3oool4
000000@0oooo2P0000050?ooo`@000003P3oool00`000000oooo0?ooo`0400000080oooo0P000002
0?ooo`800000103oool200000080oooo00<000000?ooo`3oool00P0000060?oooa00dLfY000>0=7=
Z@8000000P3oool2000000d0oooo0P0000020?ooo`@000000P3oool500000080oooo0P0000040?oo
o`@00000103oool200000080oooo1@0000020?ooo`@000000P3oool2000000d0oooo0P0000020?oo
o`8000003@3AcJT2000000@0oooo100000020?ooo`L000001P3oool6000000X0oooo1`0000020?oo
o`H000001P3oool6000000/0oooo100000060?ooo`d0dLfYF020P80=0=7=Z@H00000103oool80000
0080oooo100000020?ooo`800000103oool2000000@0oooo1P0000020?ooo`D000002P3oool20000
0080oooo0P0000020?ooo`8000000P3oool2000000H0oooo2000000=0=7=Z@H00000103oool30000
00@0oooo2000000;0?ooo`X000002@3oool2000000H0oooo0P0000020?ooo`8000000P3oool40000
00<0oooo0P0000020?ooo`8000000P3oool200000100dLfY000>0=7=Z@8000000P3oool2000000d0
oooo0P0000020?ooo`@000000P3oool500000080oooo0P0000040?ooo`@00000103oool200000080
oooo1@0000020?ooo`@000000P3oool2000000d0oooo0P0000020?ooo`8000003@3AcJT2000000@0
oooo100000020?ooo`L000001P3oool6000000X0oooo1`0000020?ooo`H000001P3oool6000000/0
oooo100000060?ooo`d0dLfYF020P80=0=7=Z@H00000103oool800000080oooo100000020?ooo`80
0000103oool2000000@0oooo1P0000020?ooo`D000002P3oool200000080oooo0P0000020?ooo`80
00000P3oool2000000H0oooo2000000=0=7=Z@H00000103oool3000000@0oooo2000000;0?ooo`X0
00002@3oool2000000H0oooo0P0000020?ooo`8000000P3oool4000000<0oooo0P0000020?ooo`80
00000P3oool200000100dLfY000>0=7=Z@8000000P3oool2000000d0oooo0P0000020?ooo`@00000
0P3oool500000080oooo0P0000040?ooo`@00000103oool200000080oooo1@0000020?ooo`@00000
0P3oool2000000d0oooo0P0000020?ooo`8000003@3AcJT8000000T0oooo100000020?ooo`800000
0P3oool400000080oooo1000000;0?ooo`8000000P3oool8000000X0oooo0P0000050?ooo`800000
0P3oool400000080oooo0P00000=0=7=ZEP0P8203@3AcJT20?ooo`@000000P3oool200000080oooo
0P0000040?ooo`H00000103oool200000080oooo1P0000020?ooo`800000103oool3000000@0oooo
100000020?ooo`@000000P3oool>00000080oooo0P0000020?ooo`@000003@3AcJT20?ooo`800000
0P3oool500000080oooo100000020?ooo``000000P3oool00`000000oooo0?ooo`020?ooo`@00000
1P3oool400000080oooo00<000000?ooo`3oool0200000020?ooo`8000000P3oool2000000@0oooo
00<000000?ooo`3oool01P3oool200000100dLfY000>0=7=Z@80oooo0P0000020?ooo`l000001P3o
ool7000000@0oooo0P0000080?ooo`800000103oool7000000H0oooo3`0000020?ooo`8000000P3o
ool=0=7=Z@P000002@3oool400000080oooo0P0000020?ooo`@000000P3oool4000000/0oooo0P00
00020?ooo`P000002P3oool2000000D0oooo0P0000020?ooo`@000000P3oool2000000d0dLfYF020
P80=0=7=Z@80oooo100000020?ooo`8000000P3oool2000000@0oooo1P0000040?ooo`8000000P3o
ool600000080oooo0P0000040?ooo`<00000103oool400000080oooo100000020?ooo`h000000P3o
ool200000080oooo1000000=0=7=Z@@000000P3oool200000080oooo0`0000020?ooo``000001`3o
ool<00000080oooo1P0000050?ooo`@000000P3oool4000000@0oooo0P0000020?ooo`D00000103o
ool200000100dLfY000>0=7=Z@80oooo0P0000020?ooo`l000001P3oool7000000@0oooo0P000008
0?ooo`800000103oool7000000H0oooo3`0000020?ooo`8000000P3oool=0=7=Z@80oooo10000004
0?ooo`8000000`3oool6000000H0oooo0P0000020?ooo`800000103oool6000000<0oooo0P000002
0?ooo`800000303oool2000000@0oooo1@0000080?ooo`800000103oool=0=7=ZEP0P8203@3AcJT8
0?ooo`800000103oool:000000@0oooo100000020?ooo`@000000P3oool200000080oooo0P000000
0`3oool00000000000040?ooo`@000000P3oool2000000`0oooo1000000:0?ooo`8000003@3AcJT4
00000080oooo0P0000020?ooo`<000000P3oool<000000L0oooo300000020?ooo`H000001@3oool4
00000080oooo100000040?ooo`8000000P3oool5000000@0oooo0P00000@0=7=Z@003P3AcJT?0?oo
o`8000001P3oool400000080oooo0P0000050?oooa0000001@3oool200000080oooo100000060?oo
o`8000003`3oool=0=7=Z@80oooo100000040?ooo`8000000`3oool6000000H0oooo0P0000020?oo
o`800000103oool6000000<0oooo0P0000020?ooo`800000303oool2000000@0oooo1@0000080?oo
o`800000103oool=0=7=ZEP0P8203@3AcJT80?ooo`800000103oool:000000@0oooo100000020?oo
o`@000000P3oool200000080oooo0P0000000`3oool00000000000040?ooo`@000000P3oool20000
00`0oooo1000000:0?ooo`8000003@3AcJT200000080oooo0P0000040?ooo`030000003oool0oooo
0080oooo4P0000000`3oool00000000000020?ooo`800000103oool200000080oooo1`0000060?oo
o`@000000P3oool2000000@0oooo0P0000020?ooo`/00000403AcJT000h0dLfY3`3oool2000000H0
oooo100000020?ooo`8000001@3oool@000000D0oooo0P0000020?ooo`@000001P3oool2000000l0
oooo3@3AcJT2000000@0oooo0P0000020?ooo`8000000`3oool2000000@0oooo0P0000020?ooo`P0
00000P3oool6000000T0oooo100000040?ooo`8000000P3oool800000080oooo0`0000060?ooo`80
00000P3oool4000000d0dLfYF020P80=0=7=Z@P0oooo1P0000020?ooo`@000000P3oool200000080
oooo0P0000020?ooo`P00000103oool4000000030?ooo`000000000000@000000P3oool400000080
oooo100000020?ooo`@000001P3oool2000000P0oooo0P00000=0=7=Z@8000000P3oool2000000@0
oooo00<000000?ooo`3oool00P3ooolB000000030?ooo`00000000000080oooo0P0000040?ooo`80
00000P3oool7000000H0oooo100000020?ooo`800000103oool200000080oooo2`00000@0=7=Z@00
3P3AcJT?00000080oooo0P0000060?ooo`d00000103oool4000000@0oooo3@0000060?ooo`800000
0P3oool?000000d0dLfY0P0000040?ooo`8000000P3oool2000000<0oooo0P0000040?ooo`800000
0P3oool800000080oooo1P0000090?ooo`@00000103oool200000080oooo200000020?ooo`<00000
1P3oool200000080oooo1000000=0=7=ZEP0P8203@3AcJT80?ooo`H000000P3oool400000080oooo
0P0000020?ooo`8000000P3oool8000000@0oooo100000000`3oool000000000000400000080oooo
100000020?ooo`@000000P3oool4000000H0oooo0P0000080?ooo`8000003@3AcJT400000080oooo
0P0000030?ooo`800000103oool200000080oooo100000090?ooo`800000103oool?000000h0oooo
0P0000020?ooo`D00000103oool2000000@0oooo403AcJT000h0dLfY3`0000020?ooo`8000001P3o
ool=000000@0oooo100000040?ooo`d000001P3oool200000080oooo3`00000=0=7=Z@80oooo1000
00020?ooo`@000002@3oool4000000P0oooo0P0000040?ooo`L000000P3oool6000000H0oooo0P00
00040?ooo`8000000P3oool9000000H0oooo1000000=0=7=ZEP0P8203@3AcJT2000000h0oooo0P00
00020?ooo`8000000P3oool600000080oooo0P0000020?ooo`800000103oool4000000030?ooo`00
000000000080oooo0P0000020?ooo`8000000P3oool2000000H0oooo100000020?ooo`8000000P3o
ool4000000@0oooo0P0000020?ooo`d0dLfY100000020?ooo`8000000`3oool2000000@0oooo0P00
00020?ooo`@000002@3oool2000000@0oooo3`00000>0?ooo`8000000P3oool5000000@0oooo0P00
00040?oooa00dLfY000>0=7=Z@l0oooo300000040?ooo`T00000203oool9000000@0oooo3000000?
0?ooo`d0dLfY0P3oool400000080oooo100000090?ooo`@00000203oool2000000@0oooo1`000002
0?ooo`H000001P3oool2000000@0oooo0P0000020?ooo`T000001P3oool4000000d0dLfYF020P80=
0=7=Z@8000003P3oool200000080oooo0P0000020?ooo`H000000P3oool200000080oooo0P000004
0?ooo`@0000000<0oooo0000000000000P3oool200000080oooo0P0000020?ooo`8000001P3oool4
00000080oooo0P0000020?ooo`@00000103oool200000080oooo3@3AcJT80?ooo`<000000P3oool:
00000140oooo2P00000;0?ooo`@00000203oool2000000<0oooo2P00000@0=7=Z@003P3AcJT?0?oo
o``00000103oool9000000P0oooo2@0000040?ooo``000003`3oool=0=7=Z@80oooo0P0000020?oo
o`H000001`3oool2000000@0oooo100000020?ooo`@000000P3oool2000000@0oooo0`0000020?oo
o`@000000P3oool4000000@0oooo100000020?ooo`8000002@3oool4000000H0oooo3@3AcJUH0820
P0d0dLfY100000020?ooo`H00000103oool400000080oooo1P0000060?ooo`@00000103oool50000
0080oooo0P0000080?ooo`800000103oool8000000H0oooo0P0000040?ooo`@000003@3AcJT80?oo
o`<000000P3oool:00000140oooo2P00000;0?ooo`@00000203oool2000000<0oooo2P00000@0=7=
Z@003P3AcJT200000080oooo0P0000090?ooo`8000001P3oool2000000H0oooo1`0000040?ooo`@0
0000103oool7000000H0oooo0P0000060?ooo`8000002@3oool200000080oooo0P00000=0=7=Z@80
oooo0P0000020?ooo`H000001`3oool2000000@0oooo100000020?ooo`@000000P3oool2000000@0
oooo0`0000020?ooo`@000000P3oool4000000@0oooo100000020?ooo`8000002@3oool4000000H0
oooo3@3AcJUH0820P0d0dLfY100000020?ooo`H00000103oool400000080oooo1P0000060?ooo`@0
0000103oool500000080oooo0P0000080?ooo`800000103oool8000000H0oooo0P0000040?ooo`@0
00003@3AcJT40?ooo`L000000P3oool600000080oooo100000080?ooo`<000000P3oool@00000003
0?ooo`000000000000h0oooo100000020?ooo`<00000103oool400000100dLfY000>0=7=Z@800000
0P3oool2000000T0oooo0P0000060?ooo`8000001P3oool7000000@0oooo100000040?ooo`L00000
1P3oool2000000H0oooo0P0000090?ooo`8000000P3oool2000000d0dLfY0P0000020?ooo`@00000
103oool3000000H0oooo100000020?ooo`X000001P3oool3000000H0oooo2P0000020?ooo`@00000
1`3oool2000000@0oooo100000020?ooo`8000003@3AcJUH0820P0d0dLfY0P0000020?ooo`800000
1P3oool200000080oooo100000060?ooo`800000203oool2000000@0oooo100000030?ooo`@00000
103oool200000080oooo0P0000020?ooo`8000000P3oool:00000080oooo2000000=0=7=Z@@0oooo
1`0000020?ooo`H000000P3oool4000000P0oooo0`0000020?oooa00000000<0oooo000000000000
3P3oool400000080oooo0`0000040?ooo`@00000403AcJT000h0dLfY0P3oool200000080oooo1`00
00020?ooo`P000000P3oool200000080oooo0P0000030?ooo`8000001P3oool4000000H0oooo0P00
00030?ooo`8000000P3oool200000080oooo200000020?ooo`L000000P3oool200000080oooo3@3A
cJT200000080oooo100000040?ooo`<000001P3oool400000080oooo2P0000060?ooo`<000001P3o
ool:00000080oooo100000070?ooo`800000103oool400000080oooo0P00000=0=7=ZEP0P8203@3A
cJT200000080oooo0P0000060?ooo`8000000P3oool4000000H0oooo0P0000080?ooo`800000103o
ool4000000<0oooo100000040?ooo`8000000P3oool200000080oooo0P0000020?ooo`X000000P3o
ool8000000d0dLfY0P3oool2000000H0oooo2@0000060?ooo`@000000P3oool2000000L0oooo2P00
00020?ooo`80000000<0oooo0000000000000P3oool4000000X0oooo100000000`3oool000000000
00060?ooo`800000403AcJT000h0dLfY0P3oool200000080oooo1`0000020?ooo`P000000P3oool2
00000080oooo0P0000030?ooo`8000001P3oool4000000H0oooo0P0000030?ooo`8000000P3oool2
00000080oooo200000020?ooo`L000000P3oool200000080oooo3@3AcJT:000000T0oooo10000002
0?ooo`800000103oool400000080oooo100000020?ooo`<00000103oool200000080oooo10000002
0?ooo`X000001`3oool800000080oooo0P00000=0=7=ZEP0P8203@3AcJT4000000@0oooo2P000006
0?ooo`8000000P3oool@00000080oooo2@0000040?ooo`P000000P3oool2000000@0oooo0P000002
0?ooo`@000001P3oool=0=7=Z@80oooo0P0000060?ooo`T000001P3oool400000080oooo0P000007
0?ooo`X000000P3oool2000000030?ooo`00000000000080oooo1000000:0?ooo`@0000000<0oooo
0000000000001P3oool200000100dLfY000>0=7=Z@H0oooo100000030?ooo`@00000103oool40000
00@0oooo1@0000020?ooo`800000303oool200000080oooo1@0000040?ooo`@00000103oool40000
00<0oooo100000060?ooo`d0dLfY2P0000090?ooo`@000000P3oool2000000@0oooo100000020?oo
o`@000000P3oool3000000@0oooo0P0000020?ooo`@000000P3oool:000000L0oooo200000020?oo
o`8000003@3AcJUH0820P0d0dLfY100000040?ooo`X000001P3oool200000080oooo400000020?oo
o`T00000103oool800000080oooo0P0000040?ooo`8000000P3oool4000000H0oooo3@3AcJT20?oo
o`800000103oool2000000D0oooo100000060?ooo`T000001P3oool:00000080oooo1@0000040?oo
o`H00000103oool4000000D0oooo100000020?ooo`800000403AcJT000h0dLfY1P3oool4000000<0
oooo100000040?ooo`@00000103oool500000080oooo0P00000<0?ooo`8000000P3oool5000000@0
oooo100000040?ooo`@000000`3oool4000000H0oooo3@3AcJT2000000H0oooo1`0000020?ooo`80
00000P3oool600000080oooo0P0000020?ooo`8000000P3oool200000080oooo1@0000060?ooo`80
0000103oool600000080oooo0P0000040?ooo`<000000P3oool2000000@0oooo0P0000040?ooo`d0
dLfYF020P80=0=7=Z@P0oooo0P0000060?ooo`H00000103oool2000000P0oooo0P0000020?ooo`H0
00000`3oool4000000X0oooo0P0000020?ooo`800000203oool2000000P0oooo0P00000=0=7=Z@80
oooo0P0000040?ooo`8000001@3oool4000000H0oooo2@0000060?ooo`X000000P3oool5000000@0
oooo1P0000040?ooo`@000001@3oool400000080oooo0P00000@0=7=Z@003P3AcJT20?ooo`800000
2@3oool400000080oooo0P0000020?ooo`@000000P3oool2000000<0oooo100000020?ooo`P00000
0P3oool4000000<0oooo0P0000020?ooo`@000000P3oool200000080oooo100000090?ooo`800000
0P3oool=0=7=Z@8000001P3oool700000080oooo0P0000020?ooo`H000000P3oool200000080oooo
0P0000020?ooo`8000000P3oool5000000H0oooo0P0000040?ooo`H000000P3oool2000000@0oooo
0`0000020?ooo`800000103oool2000000@0oooo3@3AcJUH0820P0d0dLfY203oool2000000H0oooo
1P0000040?ooo`800000203oool200000080oooo1P0000030?ooo`@000002P3oool200000080oooo
0P0000080?ooo`800000203oool2000000d0dLfY100000060?ooo`d000003@3oool4000000@0oooo
0P0000040?ooo`T000000P3oool200000080oooo2P0000020?ooo`D000000P3oool200000080oooo
403AcJT000h0dLfY0P3oool2000000T0oooo100000020?ooo`8000000P3oool400000080oooo0P00
00030?ooo`@000000P3oool800000080oooo100000030?ooo`8000000P3oool400000080oooo0P00
00020?ooo`@000002@3oool200000080oooo3@3AcJT200000080oooo1P00000=0?ooo`@000001P3o
ool200000080oooo1P0000030?ooo`8000000P3oool200000080oooo100000020?ooo`@00000103o
ool2000000L0oooo3000000=0=7=ZEP0P8203@3AcJT20?ooo`@000000P3oool2000000H0oooo1P00
00020?ooo`H000000P3oool400000080oooo100000050?ooo`8000000P3oool4000000@0oooo1000
00020?ooo`@000000P3oool2000000@0oooo0P0000020?ooo`8000000P3oool200000080oooo3@3A
cJT4000000H0oooo3@00000=0?ooo`@00000103oool2000000@0oooo2@0000020?ooo`8000000P3o
ool:00000080oooo1@0000020?ooo`8000000P3oool@0=7=Z@003P3AcJT:0?ooo`<00000103oool2
00000080oooo0P0000020?ooo`H000000`3oool8000000@0oooo200000030?ooo`H000000P3oool2
00000080oooo0P0000040?ooo`<000002P3oool=0=7=Z@8000000P3oool6000000d0oooo10000006
0?ooo`8000000P3oool6000000<0oooo0P0000020?ooo`8000000P3oool400000080oooo10000004
0?ooo`8000001`3oool<000000d0dLfYF020P80=0=7=Z@80oooo100000020?ooo`8000001P3oool6
00000080oooo1P0000020?ooo`@000000P3oool4000000D0oooo0P0000020?ooo`@00000103oool4
00000080oooo100000020?ooo`800000103oool200000080oooo0P0000020?ooo`8000000P3oool=
0=7=Z@H0oooo1`0000020?ooo`H00000203oool;000000`0oooo0P0000000`3oool0000000000002
000000P0oooo0P0000040?ooo`D00000103oool200000080oooo0P00000@0=7=Z@003P3AcJT:0?oo
o`<00000103oool200000080oooo0P0000020?ooo`H000000`3oool8000000@0oooo200000030?oo
o`H000000P3oool200000080oooo0P0000040?ooo`<000002P3oool=0=7=Z@8000001P3oool40000
00<0oooo100000040?ooo`800000203oool2000000d0oooo0P0000040?ooo`@000000P3oool20000
00H0oooo1`0000040?ooo`800000103oool4000000d0dLfYF020P80=0=7=Z@@000000P3oool60000
00@0oooo1P0000040?ooo`X000000P3oool8000000030?ooo`00000000000080oooo100000020?oo
o`H000002P3oool4000000`0oooo3@3AcJT60?ooo`L000000P3oool6000000P0oooo2`00000<0?oo
o`80000000<0oooo0000000000000P0000080?ooo`800000103oool5000000@0oooo0P0000020?oo
o`800000403AcJT000h0dLfY103oool2000001<0oooo0P0000090?ooo`H00000103oool6000000T0
oooo0P00000C0?ooo`800000103oool=0=7=Z@8000001P3oool4000000<0oooo100000040?ooo`80
0000203oool2000000d0oooo0P0000040?ooo`@000000P3oool2000000H0oooo1`0000040?ooo`80
0000103oool4000000d0dLfYF020P80=0=7=Z@@000000P3oool6000000@0oooo1P0000040?ooo`X0
00000P3oool8000000030?ooo`00000000000080oooo100000020?ooo`H000002P3oool4000000`0
oooo3@3AcJT2000000H0oooo1`0000020?ooo`@00000303oool5000000H0oooo0P0000020?ooo`H0
00001`3oool4000000H0oooo1P0000030?ooo`8000001P3oool@0=7=Z@003P3AcJT40?ooo`800000
4`3oool2000000T0oooo1P0000040?ooo`H000002@3oool2000001<0oooo0P0000040?ooo`d0dLfY
0P3oool200000080oooo0P0000020?ooo`D000001P3oool:00000080oooo100000020?ooo`800000
2`3oool800000080oooo0P0000020?ooo`@000001@3oool2000000@0oooo0P0000060?ooo`d0dLfY
F020P80=0=7=Z@@000000P3oool2000000H0oooo0P0000040?ooo`8000000P3oool400000080oooo
0P0000020?ooo`8000000P3oool4000000D0oooo0P0000020?ooo`@00000203oool600000080oooo
100000040?ooo`H00000103oool=0=7=Z@8000001P3oool700000080oooo1000000<0?ooo`D00000
1P3oool200000080oooo1P0000070?ooo`@000001P3oool6000000<0oooo0P0000060?oooa00dLfY
000>0=7=Z@@0oooo0P0000070?ooo`800000203ooolA000000P0oooo4@0000080?ooo`8000001`3o
ool2000000@0oooo3@3AcJT20?ooo`8000000P3oool200000080oooo1@0000060?ooo`X000000P3o
ool400000080oooo0P00000;0?ooo`P000000P3oool200000080oooo100000050?ooo`800000103o
ool2000000H0oooo3@3AcJUH0820P0d0dLfY100000020?ooo`8000001P3oool2000000@0oooo0P00
00020?ooo`@000000P3oool200000080oooo0P0000020?ooo`@000001@3oool200000080oooo1000
00080?ooo`H000000P3oool4000000@0oooo1P0000040?ooo`d0dLfY100000070?ooo`8000000P3o
ool800000080oooo100000040?ooo`D000000P3oool200000080oooo0P0000080?ooo`030000003o
ool0oooo00X0oooo0P0000060?ooo`80000000<0oooo0000000000001P0000020?oooa00dLfY000>
0=7=Z@@0oooo0P0000070?ooo`800000203ooolA000000P0oooo4@0000080?ooo`8000001`3oool2
000000@0oooo3@3AcJT20?ooo`@000000P3oool7000000H0oooo0P0000060?ooo`@000000P3oool?
000000@0oooo100000020?ooo`8000000P3oool2000000@0oooo1@0000020?ooo`@000000P3oool6
000000d0dLfYF020P80=0=7=Z@@00000103oool4000000@0oooo100000020?ooo`@00000203oool2
00000080oooo0P0000060?ooo`030000003oool0oooo00@0oooo1P0000040?ooo`8000000P3oool2
000000@0oooo200000060?ooo`8000003@3AcJT80?ooo`D00000103oool6000000@0oooo0P000002
0?ooo`8000000`3oool200000080oooo100000060?ooo`8000001`3oool2000000P0oooo0P000002
0?ooo`8000001@3oool4000000@0oooo403AcJT000h0dLfY103oool2000000L0oooo0P0000080?oo
oa400000203ooolA000000P0oooo0P0000070?ooo`800000103oool=0=7=Z@80oooo100000020?oo
o`L000001P3oool2000000H0oooo100000020?ooo`l00000103oool400000080oooo0P0000020?oo
o`800000103oool500000080oooo100000020?ooo`H000003@3AcJUH0820P0d0dLfY100000040?oo
o`@00000103oool400000080oooo100000080?ooo`8000000P3oool2000000H0oooo00<000000?oo
o`3oool0103oool6000000@0oooo0P0000020?ooo`800000103oool8000000H0oooo0P00000=0=7=
Z@P0oooo1@0000040?ooo`H00000103oool200000080oooo0P0000030?ooo`8000000P3oool40000
00H0oooo0P0000070?ooo`800000203oool200000080oooo0P0000050?ooo`@00000103oool@0=7=
Z@003P3AcJT20?ooo`@000000P3oool7000000@0oooo0P0000020?ooo`8000000P3oool4000000L0
oooo0P0000080?ooo`8000001`3oool400000080oooo0P0000020?ooo`800000103oool700000080
oooo100000020?ooo`d0dLfY0P3oool2000000@0oooo0P0000020?ooo`D00000103oool2000000@0
oooo1000000I0?ooo`H00000103oool400000080oooo1@0000020?ooo`800000103oool200000080
oooo3@3AcJUH0820P0d0dLfY103oool200000080oooo100000040?ooo`X000000P3oool2000000@0
oooo0P0000080?ooo`<000000P3oool2000000@0oooo0P00000>0?ooo`H000001P3oool2000000@0
oooo3@3AcJT60?ooo`8000001@3oool400000080oooo100000020?ooo`H000001@3oool200000080
oooo0P0000080?ooo`8000000P3oool00`000000oooo0?ooo`04000000`0oooo100000000`3oool0
00000000000200000080oooo1000000@0=7=Z@003P3AcJT20?ooo`@000000P3oool7000000@0oooo
0P0000020?ooo`8000000P3oool4000000L0oooo0P0000080?ooo`8000001`3oool400000080oooo
0P0000020?ooo`800000103oool700000080oooo100000020?ooo`d0dLfY0P3oool2000000@0oooo
0P0000020?ooo`D00000103oool2000000@0oooo1000000I0?ooo`H00000103oool400000080oooo
1@0000020?ooo`800000103oool200000080oooo3@3AcJUH0820P0d0dLfY103oool200000080oooo
100000040?ooo`X000000P3oool2000000@0oooo0P0000080?ooo`<000000P3oool2000000@0oooo
0P00000>0?ooo`H000001P3oool2000000@0oooo3@3AcJT60?ooo`8000001@3oool400000080oooo
100000020?ooo`H000001@3oool200000080oooo0P0000080?ooo`8000000P3oool00`000000oooo
0?ooo`04000000`0oooo100000000`3oool000000000000200000080oooo1000000@0=7=Z@003P3A
cJT20?ooo`@00000103ooolC00000080oooo0`0000020?ooo`H00000103oool600000080oooo0`00
00020?oooa<00000103oool400000080oooo3@3AcJT20?ooo`800000103oool4000000D0oooo0P00
00020?ooo`800000303oool2000000@0oooo0P0000050?ooo`@000000P3oool4000000P0oooo1000
00020?ooo`D000001P3oool200000080oooo0P00000=0=7=ZEP0P8203@3AcJT60?ooo`800000103o
ool200000080oooo1P0000080?ooo`8000000P3oool600000080oooo1@0000040?ooo`8000000P3o
ool6000000H0oooo200000020?ooo`800000103oool2000000@0oooo3@3AcJT800000080oooo00<0
00000?ooo`3oool0200000020?ooo`/000001P3oool4000000H0oooo0P0000020?ooo`030000003o
ool0oooo00@00000203oool2000000L0oooo2P00000@0=7=Z@003P3AcJT20?ooo`@00000103ooolC
00000080oooo0`0000020?ooo`H00000103oool600000080oooo0`0000020?oooa<00000103oool4
00000080oooo3@3AcJT20?ooo`800000103oool4000000D0oooo0P0000020?ooo`800000303oool2
000000@0oooo0P0000050?ooo`@000000P3oool4000000P0oooo100000020?ooo`D000001P3oool2
00000080oooo0P00000=0=7=ZEP0P8203@3AcJT60?ooo`800000103oool200000080oooo1P000008
0?ooo`8000000P3oool600000080oooo1@0000040?ooo`8000000P3oool6000000H0oooo20000002
0?ooo`800000103oool2000000@0oooo3@3AcJT800000080oooo00<000000?ooo`3oool020000002
0?ooo`/000001P3oool4000000H0oooo0P0000020?ooo`030000003oool0oooo00@00000203oool2
000000L0oooo2P00000@0=7=Z@003P3AcJT20?ooo`/00000103oool2000000P0oooo100000050?oo
o`@000000P3oool400000080oooo100000050?ooo`@00000203oool2000000@0oooo2`0000020?oo
o`d0dLfY0P0000020?ooo`@000000P3oool2000000<0oooo2P0000020?ooo`@00000203oool20000
0080oooo0`0000020?ooo`800000203oool400000080oooo2`0000020?ooo`8000000P3oool40000
0080oooo0P00000=0=7=ZEP0P8203@3AcJT80?ooo`800000103oool2000000H0oooo0P0000020?oo
o`800000103oool2000000@0oooo2`0000080?ooo`8000000P3oool2000000P0oooo0P0000020?oo
o`P00000103oool2000000d0dLfY203oool500000080oooo0P0000080?ooo`H000000P3oool00`00
0000oooo0?ooo`040?ooo`@000001P3oool500000080oooo200000020?ooo`@00000103oool50000
00@0oooo0P0000020?oooa00dLfY000>0=7=Z@80oooo2`0000040?ooo`800000203oool4000000D0
oooo100000020?ooo`@000000P3oool4000000D0oooo100000080?ooo`800000103oool;00000080
oooo3@3AcJT200000080oooo100000020?ooo`8000000`3oool:00000080oooo100000080?ooo`80
00000P3oool300000080oooo0P0000080?ooo`@000000P3oool;00000080oooo0P0000020?ooo`@0
00000P3oool2000000d0dLfYF020P80=0=7=Z@P0oooo0P0000040?ooo`8000001P3oool200000080
oooo0P0000040?ooo`800000103oool;000000P0oooo0P0000020?ooo`800000203oool200000080
oooo200000040?ooo`8000003@3AcJT80?ooo`D000000P3oool2000000P0oooo1P0000020?ooo`03
0000003oool0oooo00@0oooo100000060?ooo`D000000P3oool800000080oooo100000040?ooo`D0
0000103oool200000080oooo403AcJT000h0dLfY0P0000020?ooo`8000000P3oool2000000<0oooo
1P00000:0?ooo`D00000203oool4000000P0oooo1@00000:0?ooo`H000000`3oool200000080oooo
0P0000020?ooo`8000003@3AcJT40?ooo`800000103oool9000000@0oooo100000080?ooo`800000
2@3oool600000080oooo100000040?ooo`@000000P3oool2000000T0oooo0P0000040?ooo`@00000
3@3AcJUH0820P0d0dLfY0P0000080?oooa@000000P3oool400000080oooo0P0000020?ooo`@00000
00<0oooo000000000000103oool200000080oooo0P0000020?ooo`@000000P3oool200000080oooo
2P0000060?ooo`8000003@3AcJT60?ooo`8000001@3oool2000000@0oooo0P0000020?ooo`800000
0P3oool2000000l0oooo0P0000020?ooo`d000000P3oool2000000@0oooo1P0000020?ooo`<00000
0P3oool200000080oooo0P00000@0=7=Z@003P3AcJT200000080oooo0P0000020?ooo`8000000`3o
ool6000000X0oooo1@0000080?ooo`@00000203oool5000000X0oooo1P0000030?ooo`8000000P3o
ool200000080oooo0P00000=0=7=Z@@0oooo0P0000040?ooo`T00000103oool4000000P0oooo0P00
00090?ooo`H000000P3oool4000000@0oooo100000020?ooo`8000002@3oool2000000@0oooo1000
000=0=7=ZEP0P8203@3AcJT2000000P0oooo500000020?ooo`@000000P3oool200000080oooo1000
00000`3oool00000000000040?ooo`8000000P3oool200000080oooo100000020?ooo`8000000P3o
ool:000000H0oooo0P00000=0=7=Z@H0oooo0P0000050?ooo`800000103oool200000080oooo0P00
00020?ooo`8000003`3oool200000080oooo3@0000020?ooo`800000103oool600000080oooo0`00
00020?ooo`8000000P3oool200000100dLfY000>0=7=Z@80oooo0P0000060?ooo`<00000303oool;
00000080oooo300000020?ooo`/00000303oool3000000H0oooo0P0000020?ooo`d0dLfY103oool2
00000080oooo100000050?ooo`@00000103oool:000001<0oooo0P0000020?ooo`H000001P3oool2
000000D0oooo100000020?ooo`800000103oool=0=7=ZEP0P8203@3AcJT:0?ooo`8000000P3oool2
00000080oooo1P0000060?ooo`@000000P3oool600000080oooo0P0000030?ooo`P00000103oool2
00000080oooo3P0000020?ooo`@00000103oool=0=7=Z@800000103oool;000000@0oooo0P000006
0?ooo`D00000103oool2000000@0oooo3`0000040?ooo`8000001P3oool2000000L0oooo0P000004
0?ooo`800000403AcJT000h0dLfY0P3oool2000000H0oooo0`00000<0?ooo`/000000P3oool<0000
0080oooo2`00000<0?ooo`<000001P3oool200000080oooo3@3AcJT40?ooo`8000000P3oool40000
00D0oooo100000040?ooo`X000004`3oool200000080oooo1P0000060?ooo`8000001@3oool40000
0080oooo0P0000040?ooo`d0dLfYF020P80=0=7=Z@8000000P3oool8000000X0oooo100000040?oo
o`8000001P3oool200000080oooo0P0000090?ooo`800000103oool4000000@0oooo100000060?oo
o`P000000P3oool2000000d0dLfY0P0000040?ooo`/00000103oool2000000H0oooo1@0000040?oo
o`800000103oool?000000@0oooo0P0000060?ooo`8000001`3oool2000000@0oooo0P00000@0=7=
Z@003P3AcJT400000080oooo0P0000020?ooo`/00000103oool400000080oooo1@0000020?ooo`80
0000203oool200000080oooo1@0000020?ooo`@00000103oool;00000080oooo0P0000020?ooo`@0
00003@3AcJT40?ooo`8000000P3oool4000000D0oooo100000040?ooo`X000004`3oool200000080
oooo1P0000060?ooo`8000001@3oool400000080oooo0P0000040?ooo`d0dLfYF020P80=0=7=Z@80
00000P3oool8000000X0oooo100000040?ooo`8000001P3oool200000080oooo0P0000090?ooo`80
0000103oool4000000@0oooo100000060?ooo`P000000P3oool2000000d0dLfY103oool2000000@0
oooo0`0000040?ooo`@000000P3oool200000080oooo3@0000060?ooo`8000000P3oool700000080
oooo0P0000020?ooo`800000103oool2000000H0oooo00<000000?ooo`3oool01P0000020?oooa00
dLfY000>0=7=Z@@000000P3oool200000080oooo2`0000040?ooo`@000000P3oool500000080oooo
0P0000080?ooo`8000000P3oool500000080oooo100000040?ooo`/000000P3oool200000080oooo
1000000=0=7=Z@80oooo100000020?ooo`8000001`3oool400000080oooo100000040?ooo`P00000
103oool3000000X0oooo200000020?ooo`@000000P3oool500000080oooo0P0000020?ooo`H00000
3@3AcJUH0820P0d0dLfY2P0000060?ooo`800000203oool2000000@0oooo100000020?ooo`800000
103oool3000000@0oooo100000020?ooo`H00000103oool200000080oooo100000020?ooo`800000
103oool400000080oooo3@3AcJT40?ooo`800000103oool3000000@0oooo100000020?ooo`800000
0P3oool=000000H0oooo0P0000020?ooo`L000000P3oool200000080oooo0P0000040?ooo`800000
1P3oool00`000000oooo0?ooo`0600000080oooo403AcJT000h0dLfY0P3oool200000080oooo2@00
00020?ooo`P000000P3oool4000000<0oooo1P0000080?ooo`H000000`3oool400000080oooo2000
00020?ooo`T000000P3oool200000080oooo3@3AcJT20?ooo`@000000P3oool2000000L0oooo1000
00020?ooo`@00000103oool8000000@0oooo0`00000:0?ooo`P000000P3oool400000080oooo1@00
00020?ooo`8000000P3oool6000000d0dLfYF020P80=0=7=Z@X000001P3oool2000000P0oooo0P00
00040?ooo`@000000P3oool2000000@0oooo0`0000040?ooo`@000000P3oool6000000@0oooo0P00
00020?ooo`@000000P3oool2000000@0oooo100000020?ooo`d0dLfY100000060?ooo`030000003o
ool0oooo00@0oooo100000060?ooo`8000000P3ooolG000000030?ooo`000000000000@0oooo0P00
00040?ooo`@000001`3oool200000080oooo0P0000020?ooo`800000403AcJT000h0dLfY0P3oool2
00000080oooo2@0000020?ooo`P000000P3oool4000000<0oooo1P0000080?ooo`H000000`3oool4
00000080oooo200000020?ooo`T000000P3oool200000080oooo3@3AcJT40?ooo`8000000P3oool4
000000<0oooo0P0000040?ooo`@000000P3oool200000080oooo100000020?ooo`H000000`3oool2
00000080oooo0P0000020?ooo`8000002P3oool400000080oooo0`0000040?ooo`8000000P3oool4
00000080oooo3@3AcJUH0820P0d0dLfY103oool200000080oooo0P0000040?ooo`H000000P3oool2
000000@0oooo0P0000020?ooo`@000000P3oool8000000030?ooo`000000000000800000203oool4
000000P0oooo1P00000<0?ooo`d0dLfY100000060?ooo`030000003oool0oooo00@0oooo10000006
0?ooo`8000000P3ooolG000000030?ooo`000000000000@0oooo0P0000040?ooo`@000001`3oool2
00000080oooo0P0000020?ooo`800000403AcJT000h0dLfY0P00000;0?ooo`@000001P3oool20000
00@0oooo1`0000040?ooo`800000103oool2000000@0oooo1`0000040?ooo`8000001P3oool40000
00/0oooo0P00000=0=7=Z@@0oooo0P0000020?ooo`@000000`3oool2000000@0oooo100000020?oo
o`8000000P3oool400000080oooo1P0000030?ooo`8000000P3oool200000080oooo0P00000:0?oo
o`@000000P3oool3000000@0oooo0P0000020?ooo`@000000P3oool=0=7=ZEP0P8203@3AcJT40?oo
o`8000000P3oool2000000@0oooo1P0000020?ooo`800000103oool200000080oooo100000020?oo
o`P0000000<0oooo0000000000000P0000080?ooo`@00000203oool6000000`0oooo3@3AcJT20000
0080oooo0P0000020?ooo`D000000P3oool2000000@0oooo0P0000020?ooo`H000000P3oool00`00
0000oooo0?ooo`0<00000080oooo1@0000020?ooo`P000000P3oool2000000H0oooo1@0000020?oo
o`@000000P3oool@0=7=Z@003P3AcJT2000000/0oooo100000060?ooo`800000103oool7000000@0
oooo0P0000040?ooo`800000103oool7000000@0oooo0P0000060?ooo`@000002`3oool2000000d0
dLfY103oool200000080oooo100000030?ooo`8000000P3oool8000000P0oooo1P0000090?ooo`@0
00000P3oool200000080oooo100000020?ooo`800000103oool3000000@0oooo0P0000020?ooo`@0
00000P3oool=0=7=ZEP0P8203@3AcJT20?ooo`800000103oool400000080oooo1P0000040?ooo`@0
00000P3oool600000080oooo100000070?ooo`@00000203oool200000080oooo100000020?ooo`80
00000P3oool4000000@0oooo100000020?ooo`d0dLfY0P0000020?ooo`8000000P3oool500000080
oooo0P0000040?ooo`8000000P3oool600000080oooo00<000000?ooo`3oool0300000020?ooo`D0
00000P3oool800000080oooo0P0000060?ooo`D000000P3oool400000080oooo403AcJT000h0dLfY
103oool200000080oooo1@0000020?ooo`H000000P3oool4000000@0oooo0`0000040?ooo`@00000
103oool4000000@0oooo0`0000040?ooo`@000000P3oool600000080oooo1@0000020?ooo`800000
103oool=0=7=Z@@0oooo0P0000020?ooo`@000000`3oool200000080oooo200000080?ooo`H00000
2@3oool400000080oooo0P0000020?ooo`@000000P3oool2000000@0oooo0`0000040?ooo`800000
0P3oool400000080oooo3@3AcJUH0820P0d0dLfY0P3oool2000000@0oooo100000020?ooo`H00000
103oool400000080oooo1P0000020?ooo`@000001`3oool4000000P0oooo0P0000020?ooo`@00000
0P3oool200000080oooo100000040?ooo`@000000P3oool=0=7=Z@@000000P3oool2000000D0oooo
0P0000060?ooo`@000000P3oool4000000<0oooo0P0000020?ooo`8000000P3oool6000000H0oooo
00<000000?ooo`3oool0100000020?ooo`8000000P3oool2000000@0oooo2@0000020?ooo`800000
0P3oool@0=7=Z@003P3AcJT40?ooo`8000000P3oool500000080oooo1P0000020?ooo`@00000103o
ool3000000@0oooo100000040?ooo`@00000103oool3000000@0oooo100000020?ooo`H000000P3o
ool500000080oooo0P0000040?ooo`d0dLfY103oool2000000@0oooo0P0000070?ooo`H00000103o
ool200000080oooo1P0000090?ooo`h00000103oool2000000l0oooo100000020?ooo`d0dLfYF020
P80=0=7=Z@8000000P3oool200000080oooo300000080?ooo`800000103oool400000080oooo1000
00020?ooo`030000003oool0oooo00H0oooo100000040?ooo`h000001P3oool200000080oooo0P00
000=0=7=Z@@000000P3oool2000000D0oooo0P0000060?ooo`@000000P3oool4000000<0oooo0P00
00020?ooo`8000000P3oool6000000H0oooo00<000000?ooo`3oool0100000020?ooo`8000000P3o
ool2000000@0oooo2@0000020?ooo`8000000P3oool@0=7=Z@003P3AcJT20?ooo`@000000P3oool;
000000@0oooo0P0000020?ooo`L000000P3oool@00000080oooo1`0000020?ooo`800000103oool;
00000080oooo100000020?ooo`d0dLfY103oool2000000@0oooo0P0000070?ooo`H00000103oool2
00000080oooo1P0000090?ooo`h00000103oool2000000l0oooo100000020?ooo`d0dLfYF020P80=
0=7=Z@8000000P3oool200000080oooo300000080?ooo`800000103oool400000080oooo10000002
0?ooo`030000003oool0oooo00H0oooo100000040?ooo`h000001P3oool200000080oooo0P00000=
0=7=Z@8000000P3oool2000000@0oooo0`0000020?ooo`8000000P3oool400000080oooo0P000004
0?ooo`T000000P3oool2000000@0oooo0P0000020?ooo`80000000<0oooo0000000000000P3oool2
000000@0oooo0P0000020?ooo`800000103oool900000080oooo0P00000@0=7=Z@003P3AcJT20?oo
o`@000000P3oool;000000@0oooo0P0000020?ooo`L000000P3oool@00000080oooo1`0000020?oo
o`800000103oool;00000080oooo100000020?ooo`d0dLfY203oool200000080oooo0`0000020?oo
o`8000000P3oool2000000H0oooo0P0000020?ooo`8000000P3oool200000080oooo1@0000060?oo
o`800000103oool400000080oooo100000040?ooo`<00000203oool200000080oooo0P00000=0=7=
ZEP0P8203@3AcJT20?ooo`X000001P3oool2000000@0oooo100000040?ooo`8000000P3oool20000
0080oooo1P0000030?ooo`800000203oool400000080oooo100000020?ooo`800000203oool20000
0080oooo0P0000020?ooo`d0dLfY0P0000020?ooo`800000103oool300000080oooo0P0000020?oo
o`@000000P3oool2000000@0oooo2@0000020?ooo`800000103oool200000080oooo0P0000000`3o
ool00000000000020?ooo`800000103oool200000080oooo0P0000040?ooo`T000000P3oool20000
0100dLfY000>0=7=Z@80oooo100000020?ooo`/00000103oool200000080oooo1`0000020?oooa00
00000P3oool700000080oooo0P0000040?ooo`/000000P3oool400000080oooo3@3AcJT80?ooo`80
00000P3oool300000080oooo0P0000020?ooo`8000001P3oool200000080oooo0P0000020?ooo`80
00000P3oool5000000H0oooo0P0000040?ooo`@000000P3oool4000000@0oooo0`0000080?ooo`80
00000P3oool2000000d0dLfYF020P80=0=7=Z@80oooo2P0000060?ooo`800000103oool4000000@0
oooo0P0000020?ooo`8000000P3oool6000000<0oooo0P0000080?ooo`@000000P3oool400000080
oooo0P0000080?ooo`8000000P3oool200000080oooo3@3AcJT60?ooo`8000000P3oool300000080
oooo200000020?ooo`@000000P3oool2000000030?ooo`000000000000@000000P3oool600000080
oooo1`0000040?ooo`X00000103oool2000000030?ooo`000000000000H0oooo0P00000@0=7=Z@00
3P3AcJT:000000<0oooo0P0000040?ooo`8000000P3oool200000080oooo0P0000070?ooo`@00000
203oool4000000L0oooo0P0000020?ooo`8000000P3oool2000000@0oooo0P0000030?ooo`X00000
3@3AcJT2000000l0oooo1000000<0?ooo`800000103oool9000000H0oooo0P0000040?ooo`800000
0P3oool200000080oooo100000050?ooo`8000001P3oool4000000d0dLfYF020P80=0=7=Z@80oooo
1P0000040?ooo`8000002P3oool2000000P0oooo2P0000020?ooo`T000000P3oool>00000080oooo
100000040?ooo`8000000P3oool200000080oooo3@3AcJT60?ooo`@000001@3oool2000000@0oooo
0P0000020?ooo`800000103oool2000000030?ooo`0000000000008000000P3oool200000080oooo
100000060?ooo`030000003oool0oooo00@00000103oool2000000@0oooo1P0000000`3oool00000
0000000800000100dLfY000>0=7=Z@X000000`3oool2000000@0oooo0P0000020?ooo`8000000P3o
ool2000000L0oooo100000080?ooo`@000001`3oool200000080oooo0P0000020?ooo`800000103o
ool2000000<0oooo2P00000=0=7=Z@8000003`3oool4000000`0oooo0P0000040?ooo`T000001P3o
ool2000000@0oooo0P0000020?ooo`8000000P3oool4000000D0oooo0P0000060?ooo`@000003@3A
cJUH0820P0d0dLfY0P3oool6000000@0oooo0P00000:0?ooo`800000203oool:00000080oooo2@00
00020?ooo`h000000P3oool4000000@0oooo0P0000020?ooo`8000000P3oool=0=7=Z@H0oooo1000
00050?ooo`800000103oool200000080oooo0P0000040?ooo`80000000<0oooo0000000000000P00
00020?ooo`8000000P3oool4000000H0oooo00<000000?ooo`3oool0100000040?ooo`800000103o
ool6000000030?ooo`000000000000P00000403AcJT000h0dLfY0P3oool4000000@0oooo3`000002
0?ooo`8000000P3oool300000080oooo100000080?ooo`@000000P3oool300000080oooo0P000002
0?ooo`l00000103oool400000080oooo3@3AcJT20?ooo`d000000P3oool4000000@0oooo0P000008
0?ooo`@000000P3oool700000080oooo100000080?ooo`800000103oool4000000<0oooo30000002
0?ooo`d0dLfYF020P80=0=7=Z@H0oooo100000040?ooo`800000203oool2000000P0oooo20000002
0?ooo`D000000P3oool2000000@0oooo3P0000020?ooo`@00000103oool2000000@0oooo0P00000=
0=7=Z@800000103oool500000080oooo0P0000060?ooo`@000000P3oool4000000D0oooo0P000006
0?ooo`8000000P3oool200000080oooo0`0000040?ooo`@000000P3oool400000080oooo0P000002
0?ooo`T000000P3oool200000100dLfY000>0=7=Z@80oooo100000040?ooo`l000000P3oool20000
0080oooo0`0000020?ooo`@00000203oool400000080oooo0`0000020?ooo`8000000P3oool?0000
00@0oooo100000020?ooo`d0dLfY0P3oool=00000080oooo100000040?ooo`800000203oool40000
0080oooo1`0000020?ooo`@00000203oool2000000@0oooo100000030?ooo``000000P3oool=0=7=
ZEP0P8203@3AcJT60?ooo`@00000103oool2000000P0oooo0P0000080?ooo`P000000P3oool50000
0080oooo0P0000040?ooo`h000000P3oool4000000@0oooo0P0000040?ooo`8000003@3AcJT20000
00@0oooo1@0000020?ooo`8000001P3oool400000080oooo100000050?ooo`8000001P3oool20000
0080oooo0P0000020?ooo`<00000103oool400000080oooo100000020?ooo`8000000P3oool90000
0080oooo0P00000@0=7=Z@003P3AcJT4000000H0oooo0`0000040?ooo`800000103oool200000080
oooo1`0000080?ooo`@00000203oool700000080oooo0P0000040?ooo`800000103oool3000000H0
oooo1000000=0=7=Z@H0oooo0P0000090?ooo`8000001P3oool200000080oooo200000060?ooo`<0
00000P3oool200000080oooo3P0000040?ooo`8000001@3oool200000080oooo0P0000020?ooo`80
00000P3oool=0=7=ZEP0P8203@3AcJT400000080oooo0P0000080?ooo`@000000P3ooolD000000T0
oooo100000040?ooo`8000000P3oool400000080oooo1P0000020?ooo``000003@3AcJT20?ooo`@0
00001@3oool200000080oooo0P0000020?ooo`8000001P3oool2000000l0oooo0P0000040?ooo`80
00000`3oool200000080oooo0P0000020?ooo`@00000103oool400000080oooo00<000000?ooo`3o
ool00P3oool600000100dLfY000>0=7=Z@@000001P3oool3000000@0oooo0P0000040?ooo`800000
0P3oool7000000P0oooo100000080?ooo`L000000P3oool2000000@0oooo0P0000040?ooo`<00000
1P3oool4000000d0dLfY1P3oool2000000T0oooo0P0000060?ooo`8000000P3oool8000000H0oooo
0`0000020?ooo`8000000P3oool>000000@0oooo0P0000050?ooo`8000000P3oool200000080oooo
0P0000020?ooo`d0dLfYF020P80=0=7=Z@@000000P3oool2000000P0oooo100000020?oooa@00000
2@3oool4000000@0oooo0P0000020?ooo`@000000P3oool600000080oooo3000000=0=7=Z@80oooo
100000050?ooo`8000000P3oool200000080oooo0P0000060?ooo`8000003`3oool2000000@0oooo
0P0000030?ooo`8000000P3oool200000080oooo100000040?ooo`@000000P3oool00`000000oooo
0?ooo`020?ooo`H00000403AcJT000h0dLfY0P3oool200000080oooo0P0000020?ooo`/000000P3o
ool8000000<0oooo1P0000080?ooo`H000000`3oool800000080oooo2`0000020?ooo`8000000P3o
ool200000080oooo3@3AcJT60?ooo`H000000`3oool200000080oooo0P0000020?ooo`@00000303o
ool200000080oooo3@0000040?ooo`@00000103oool4000000<0oooo100000020?ooo`@000000P3o
ool2000000d0dLfYF020P80=0=7=Z@800000303oool400000080oooo2P0000060?ooo`@000001`3o
ool8000000H0oooo0P00000:0?ooo`8000000P3oool6000000H0oooo3@3AcJT6000000L0oooo0P00
00020?ooo`800000203oool2000000@0oooo00<000000?ooo`3oool00P3oool6000000@0oooo0P00
00020?ooo`L000001P3oool2000000P0oooo0`0000060?ooo`@00000403AcJT000h0dLfY0P3oool2
00000080oooo0P0000020?ooo`/000000P3oool8000000<0oooo1P0000080?ooo`H000000`3oool8
00000080oooo2`0000020?ooo`8000000P3oool200000080oooo3@3AcJT60?ooo`H000000`3oool2
00000080oooo0P0000020?ooo`@00000303oool200000080oooo3@0000040?ooo`@00000103oool4
000000<0oooo100000020?ooo`@000000P3oool2000000d0dLfYF020P80=0=7=Z@800000303oool4
00000080oooo2P0000060?ooo`@000001`3oool8000000H0oooo0P00000:0?ooo`8000000P3oool6
000000H0oooo3@3AcJT6000000L0oooo0P0000020?ooo`800000203oool2000000@0oooo00<00000
0?ooo`3oool00P3oool6000000@0oooo0P0000020?ooo`L000001P3oool2000000P0oooo0`000006
0?ooo`@00000403AcJT000h0dLfY0P0000040?ooo`@000001@3oool200000080oooo200000040?oo
o`<00000103oool<000000@0oooo0`0000040?ooo`P000000P3oool2000000D0oooo100000040?oo
o`8000003@3AcJT4000000@0oooo3`00000<0?ooo`800000103oool2000000<0oooo100000020?oo
o`8000000P3oool200000080oooo0P0000020?ooo`@000000P3oool700000080oooo0P0000060?oo
o`8000003@3AcJUH0820P0d0dLfY0P3oool4000000H0oooo1P00000B0?ooo`@00000103oool20000
00D0oooo0P0000060?ooo`@000000P3oool:000000@0oooo0P0000060?ooo`8000003@3AcJT40000
0080oooo0P0000030?ooo`P000000P3oool2000000@0oooo0P0000040?ooo`<000000P3oool20000
00P0oooo1P0000000`3oool000000000000200000080oooo100000040?ooo`8000000P3oool20000
0080oooo0`0000020?ooo`@000000P3oool@0=7=Z@003P3AcJT2000000@0oooo100000050?ooo`80
00000P3oool8000000@0oooo0`0000040?ooo``00000103oool3000000@0oooo200000020?ooo`80
00001@3oool4000000@0oooo0P00000=0=7=Z@@00000103oool?000000`0oooo0P0000040?ooo`80
00000`3oool400000080oooo0P0000020?ooo`8000000P3oool200000080oooo100000020?ooo`L0
00000P3oool2000000H0oooo0P00000=0=7=ZEP0P8203@3AcJT20?ooo`@000001P3oool600000180
oooo100000040?ooo`8000001@3oool2000000H0oooo100000020?ooo`X00000103oool2000000H0
oooo0P00000=0=7=Z@@000000P3oool2000000<0oooo200000020?ooo`800000103oool2000000@0
oooo0`0000020?ooo`800000203oool6000000030?ooo`0000000000008000000P3oool4000000@0
oooo0P0000020?ooo`8000000P3oool300000080oooo100000020?oooa00dLfY003o0=7=ZOl0dLfY
3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0
dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>
0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3A
cJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT000h0dLfY0P0000030?oooa0000001@3oool50000
0080oooo0`0000040?ooo`<000001`3oool2000000<0oooo2@0000030?ooo`T000000`3oool20000
0080oooo0`0000020?ooo`d0dLfY0P3ooolC000000L0oooo0P0000030?ooo`@000000`3oool50000
0080oooo1@0000020?ooo`L000000P3oool3000000@0oooo0`0000020?ooo`8000000`3oool40000
00D0oooo3@3AcJT5000000@0oooo0P0000030?ooo`8000000P3oool7000000@0oooo0`0000020?oo
o`8000000P3oool3000000@0oooo1@0000020?ooo`@000000`3oool200000080oooo1@0000020?oo
o`8000000P3oool5000000D0oooo0P0000020?ooo`d0dLfY0P0000020?ooo`<000000P3oool20000
0080oooo0`0000020?ooo`@000002@3oool2000000<0oooo1P0000030?ooo`800000103oool50000
0080oooo0P0000020?ooo`D000000P3oool2000000L0oooo0P0000090?ooo`d0dLfY1P0000030?oo
o`@000000P3oool200000140oooo1@0000020?ooo`@000001`3oool400000080oooo1P0000090?oo
o`8000002@3oool200000080oooo403AcJT000h0dLfY0P0000030?oooa0000001@3oool500000080
oooo0`0000040?ooo`<000001`3oool2000000<0oooo2@0000030?ooo`T000000`3oool200000080
oooo0`0000020?ooo`d0dLfY0P3ooolC000000L0oooo0P0000030?ooo`@000000`3oool500000080
oooo1@0000020?ooo`L000000P3oool3000000@0oooo0`0000020?ooo`8000000`3oool4000000D0
oooo3@3AcJT5000000@0oooo0P0000030?ooo`8000000P3oool7000000@0oooo0`0000020?ooo`80
00000P3oool3000000@0oooo1@0000020?ooo`@000000`3oool200000080oooo1@0000020?ooo`80
00000P3oool5000000D0oooo0P0000020?ooo`d0dLfY0P0000020?ooo`<000000P3oool200000080
oooo0`0000020?ooo`@000002@3oool2000000<0oooo1P0000030?ooo`800000103oool500000080
oooo0P0000020?ooo`D000000P3oool2000000L0oooo0P0000090?ooo`d0dLfY1P0000030?ooo`@0
00000P3oool200000140oooo1@0000020?ooo`@000001`3oool400000080oooo1P0000090?ooo`80
00002@3oool200000080oooo403AcJT000h0dLfY0P3oool5000000<0oooo0P0000020?ooo`<00000
1`3oool2000000<0oooo1`0000040?ooo`P000000P3oool5000000`0oooo1000000:0?ooo`800000
0`3oool2000000d0dLfY2@3oool5000000D0oooo2`0000050?ooo`D000000P3oool7000000<0oooo
0P0000050?ooo`800000303oool200000080oooo0`0000020?ooo`D000000P3oool=0=7=Z@D00000
0P3oool900000080oooo2`00000B0?ooo`<000003@3oool2000000T0oooo1`0000030?ooo`@00000
3@3AcJT7000000/0oooo0P0000020?ooo`8000001`3oool5000000@0oooo0P00000;0?ooo`D00000
1`3oool200000080oooo0P0000020?ooo`<00000103oool700000080oooo3@3AcJT200000080oooo
2`0000060?ooo`<000000P3oool200000080oooo0P0000020?ooo`<00000103oool4000000@0oooo
1`0000020?ooo`800000103oool5000000H0oooo2@0000020?ooo`800000403AcJT000h0dLfY0P3o
ool5000000<0oooo0P0000020?ooo`<000001`3oool2000000<0oooo1`0000040?ooo`P000000P3o
ool5000000`0oooo1000000:0?ooo`8000000`3oool2000000d0dLfY2@3oool5000000D0oooo2`00
00050?ooo`D000000P3oool7000000<0oooo0P0000050?ooo`800000303oool200000080oooo0`00
00020?ooo`D000000P3oool=0=7=Z@D000000P3oool900000080oooo2`00000B0?ooo`<000003@3o
ool2000000T0oooo1`0000030?ooo`@000003@3AcJT7000000/0oooo0P0000020?ooo`8000001`3o
ool5000000@0oooo0P00000;0?ooo`D000001`3oool200000080oooo0P0000020?ooo`<00000103o
ool700000080oooo3@3AcJT200000080oooo2`0000060?ooo`<000000P3oool200000080oooo0P00
00020?ooo`<00000103oool4000000@0oooo1`0000020?ooo`800000103oool5000000H0oooo2@00
00020?ooo`800000403AcJT000h0dLfY0P3oool5000000<0oooo0P0000020?ooo`<000001`3oool2
000000<0oooo1`0000040?ooo`P000000P3oool5000000`0oooo1000000:0?ooo`8000000`3oool2
000000d0dLfY2@3oool5000000D0oooo2`0000050?ooo`D000000P3oool7000000<0oooo0P000005
0?ooo`800000303oool200000080oooo0`0000020?ooo`D000000P3oool=0=7=Z@D000000P3oool9
00000080oooo2`00000B0?ooo`<000003@3oool2000000T0oooo1`0000030?ooo`@000003@3AcJT7
0?ooo`@000002`3oool500000080oooo100000030?ooo`8000001`3oool400000080oooo2`000003
0?ooo`P000000`3oool200000080oooo1`0000020?ooo`d0dLfY0P0000020?ooo`T000003@3oool4
00000080oooo1`0000060?ooo`@000000`3oool:00000080oooo1`0000020?ooo`@000001@3oool2
000000@0oooo403AcJT000h0dLfY2P0000090?ooo`X000000P3oool500000080oooo1`0000050?oo
o`8000000`3oool4000000D0oooo1@0000020?ooo`D000000`3oool9000000d0dLfY0P0000030?oo
o`8000001`3oool500000080oooo1@0000070?ooo`@00000303oool300000080oooo300000020?oo
o`D00000103oool300000080oooo1`00000=0=7=Z@D000000P3oool=000000L0oooo0P0000030?oo
o`8000000P3oool5000000@0oooo1`0000090?ooo`8000000P3oool3000000@0oooo1@0000070?oo
o`@000003@3AcJT70?ooo`@000002`3oool500000080oooo100000030?ooo`8000001`3oool40000
0080oooo2`0000030?ooo`P000000`3oool200000080oooo1`0000020?ooo`d0dLfY0P0000020?oo
o`T000003@3oool400000080oooo1`0000060?ooo`@000000`3oool:00000080oooo1`0000020?oo
o`@000001@3oool2000000@0oooo403AcJT000h0dLfY2P0000090?ooo`X000000P3oool500000080
oooo1`0000050?ooo`8000000`3oool4000000D0oooo1@0000020?ooo`D000000`3oool9000000d0
dLfY0P0000030?ooo`8000001`3oool500000080oooo1@0000070?ooo`@00000303oool300000080
oooo300000020?ooo`D00000103oool300000080oooo1`00000=0=7=Z@D000000P3oool=000000L0
oooo0P0000030?ooo`8000000P3oool5000000@0oooo1`0000090?ooo`8000000P3oool3000000@0
oooo1@0000070?ooo`@000003@3AcJT70?ooo`@000002`3oool500000080oooo100000030?ooo`80
00001`3oool400000080oooo2`0000030?ooo`P000000`3oool200000080oooo1`0000020?ooo`d0
dLfY0P0000020?ooo`T000003@3oool400000080oooo1`0000060?ooo`@000000`3oool:00000080
oooo1`0000020?ooo`@000001@3oool2000000@0oooo403AcJT000h0dLfY0P0000030?ooo`D00000
103oool300000080oooo0P0000080?ooo`8000001`3oool2000000D0oooo1@0000020?ooo`<00000
103oool3000000D0oooo0P0000070?ooo`<000000P3oool7000000d0dLfY4000000<0?ooo`800000
1@3oool500000080oooo0`0000040?ooo`<000001`3oool4000000<0oooo0P0000020?ooo`<00000
0P3oool7000000D0oooo0P00000=0=7=Z@D0oooo0P0000020?ooo`8000000`3oool2000000L0oooo
0P0000040?ooo`<000002`3oool2000000h0oooo100000020?ooo`<00000103oool2000000<0oooo
0P0000090?ooo`d0dLfY2@3oool900000080oooo0P0000020?ooo`D000000P3oool2000000T0oooo
1@0000020?ooo`L000001P3oool500000080oooo0P0000020?ooo`<00000103oool700000080oooo
3@3AcJT20?ooo`8000001@3oool400000080oooo2@0000020?ooo`8000000P3oool4000000d0oooo
0P0000030?ooo`@000001P3oool700000080oooo0P0000020?ooo`@000000`3oool400000080oooo
403AcJT000h0dLfY0P0000030?ooo`D00000103oool300000080oooo0P0000080?ooo`8000001`3o
ool2000000D0oooo1@0000020?ooo`<00000103oool3000000D0oooo0P0000070?ooo`<000000P3o
ool7000000d0dLfY4000000<0?ooo`8000001@3oool500000080oooo0`0000040?ooo`<000001`3o
ool4000000<0oooo0P0000020?ooo`<000000P3oool7000000D0oooo0P00000=0=7=Z@D0oooo0P00
00020?ooo`8000000`3oool2000000L0oooo0P0000040?ooo`<000002`3oool2000000h0oooo1000
00020?ooo`<00000103oool2000000<0oooo0P0000090?ooo`d0dLfY2@3oool900000080oooo0P00
00020?ooo`D000000P3oool2000000T0oooo1@0000020?ooo`L000001P3oool500000080oooo0P00
00020?ooo`<00000103oool700000080oooo3@3AcJT20?ooo`8000001@3oool400000080oooo2@00
00020?ooo`8000000P3oool4000000d0oooo0P0000030?ooo`@000001P3oool700000080oooo0P00
00020?ooo`@000000`3oool400000080oooo403AcJT000h0dLfY0P0000030?ooo`D00000103oool3
00000080oooo0P0000080?ooo`8000001`3oool2000000D0oooo1@0000020?ooo`<00000103oool3
000000D0oooo0P0000070?ooo`<000000P3oool7000000d0dLfY1`0000020?ooo`L000002P3oool9
000000D0oooo1@0000020?ooo`h000003P3oool<00000080oooo3@3AcJT2000000D0oooo10000005
0?ooo`8000002`3oool3000000T0oooo0P0000040?ooo`<000000P3oool4000000<0oooo0P000004
0?ooo`<00000103oool2000000<0oooo1`0000020?ooo`8000003@3AcJT4000000`0oooo20000007
0?ooo`D000000P3oool4000000L0oooo2@0000040?ooo`<00000103oool2000000D0oooo10000007
0?ooo`8000003@3AcJT400000080oooo1@0000080?ooo`8000000`3oool200000080oooo1P000005
0?ooo`H00000103oool300000080oooo2P00000=0?ooo`T000000P3oool@0=7=Z@003P3AcJT50000
00D0oooo1`0000070?ooo`8000000`3oool200000080oooo1`0000030?ooo`D000002@3oool20000
00X0oooo1@0000020?ooo`D000001@3oool2000000d0dLfY1`0000020?ooo`L000002P3oool90000
00D0oooo1@0000020?ooo`h000003P3oool<00000080oooo3@3AcJT2000000D0oooo100000050?oo
o`8000002`3oool3000000T0oooo0P0000040?ooo`<000000P3oool4000000<0oooo0P0000040?oo
o`<00000103oool2000000<0oooo1`0000020?ooo`8000003@3AcJT4000000`0oooo200000070?oo
o`D000000P3oool4000000L0oooo2@0000040?ooo`<00000103oool2000000D0oooo100000070?oo
o`8000003@3AcJT400000080oooo1@0000080?ooo`8000000`3oool200000080oooo1P0000050?oo
o`H00000103oool300000080oooo2P00000=0?ooo`T000000P3oool@0=7=Z@003P3AcJT5000000D0
oooo1`0000070?ooo`8000000`3oool200000080oooo1`0000030?ooo`D000002@3oool2000000X0
oooo1@0000020?ooo`D000001@3oool2000000d0dLfY1`0000020?ooo`L000002P3oool9000000D0
oooo1@0000020?ooo`h000003P3oool<00000080oooo3@3AcJT;000000T0oooo2@0000050?ooo`@0
00001@3oool;000000D0oooo100000020?ooo`<000002@3oool900000080oooo3@3AcJT4000000<0
oooo3@0000020?ooo`8000003P3oool4000000L0oooo1`0000040?ooo`8000001@3oool400000080
oooo1`0000020?ooo`<00000103oool=0=7=Z@T00000203oool200000080oooo1`0000020?ooo`80
00001@3oool<000000D0oooo0P0000020?ooo`8000004`3oool700000080oooo403AcJT000h0dLfY
0P0000080?ooo`/000001@3oool5000000D0oooo0P0000070?ooo`X00000103oool300000080oooo
1@0000020?ooo`<000000P3oool7000000<0oooo0P00000=0=7=Z@8000001@3oool500000080oooo
0P0000030?ooo`@000000`3oool9000001X0oooo5@0000050?ooo`8000003@3AcJT;000000T0oooo
2@0000050?ooo`@000001@3oool;000000D0oooo100000020?ooo`<000002@3oool900000080oooo
3@3AcJT4000000<0oooo3@0000020?ooo`8000003P3oool4000000L0oooo1`0000040?ooo`800000
1@3oool400000080oooo1`0000020?ooo`<00000103oool=0=7=Z@T00000203oool200000080oooo
1`0000020?ooo`8000001@3oool<000000D0oooo0P0000020?ooo`8000004`3oool700000080oooo
403AcJT000h0dLfY0P0000080?ooo`/000001@3oool5000000D0oooo0P0000070?ooo`X00000103o
ool300000080oooo1@0000020?ooo`<000000P3oool7000000<0oooo0P00000=0=7=Z@8000001@3o
ool500000080oooo0P0000030?ooo`@000000`3oool9000001X0oooo5@0000050?ooo`8000003@3A
cJT;000000T0oooo2@0000050?ooo`@000001@3oool;000000D0oooo100000020?ooo`<000002@3o
ool900000080oooo3@3AcJT2000000D0oooo1P0000030?ooo`@000000P3oool5000000@0oooo0P00
00050?ooo`8000001@3oool4000000@0oooo0`0000060?ooo`D000000P3oool900000080oooo0P00
00030?ooo`8000000P3oool=0=7=Z@@0oooo0P0000050?ooo`800000103oool700000080oooo0P00
000C0?ooo`8000001`3oool400000080oooo0P0000030?ooo`@00000103oool2000000L0oooo1000
000@0=7=Z@003P3AcJT500000080oooo2P0000070?ooo`8000000`3oool200000080oooo0`000002
0?ooo`h000001@3oool500000080oooo0`0000040?ooo`D000001`3oool300000080oooo3@3AcJT<
0?ooo`T000001@3oool4000000L0oooo0`0000050?ooo`8000000P3oool300000080oooo1`000007
0?ooo`8000000`3oool4000000L0oooo0`0000020?ooo`d0dLfY0P0000090?ooo`<00000103oool5
00000080oooo0P0000070?ooo`8000000P3oool5000000@0oooo1@0000020?ooo`L00000103oool3
000000H0oooo1@0000050?ooo`8000000P3oool=0=7=Z@8000001@3oool6000000<0oooo10000002
0?ooo`D00000103oool2000000D0oooo0P0000050?ooo`@00000103oool3000000H0oooo1@000002
0?ooo`T000000P3oool2000000<0oooo0P0000020?ooo`d0dLfY103oool2000000D0oooo0P000004
0?ooo`L000000P3oool2000001<0oooo0P0000070?ooo`@000000P3oool2000000<0oooo10000004
0?ooo`8000001`3oool400000100dLfY000>0=7=Z@D000000P3oool:000000L0oooo0P0000030?oo
o`8000000P3oool300000080oooo3P0000050?ooo`D000000P3oool3000000@0oooo1@0000070?oo
o`<000000P3oool=0=7=Z@`0oooo2@0000050?ooo`@000001`3oool3000000D0oooo0P0000020?oo
o`<000000P3oool7000000L0oooo0P0000030?ooo`@000001`3oool300000080oooo3@3AcJT20000
00T0oooo0`0000040?ooo`D000000P3oool2000000L0oooo0P0000020?ooo`D00000103oool50000
0080oooo1`0000040?ooo`<000001P3oool5000000D0oooo0P0000020?ooo`d0dLfY0P0000050?oo
o`H000000`3oool400000080oooo1@0000040?ooo`8000001@3oool2000000D0oooo100000040?oo
o`<000001P3oool500000080oooo2@0000020?ooo`8000000`3oool200000080oooo3@3AcJT60000
00D0oooo100000040?ooo`8000001@3oool2000000H0oooo0`0000020?ooo`P000001`3oool20000
00@0oooo0P0000050?ooo`800000103oool4000000D0oooo100000020?oooa00dLfY000>0=7=Z@D0
00000P3oool:000000L0oooo0P0000030?ooo`8000000P3oool300000080oooo3P0000050?ooo`D0
00000P3oool3000000@0oooo1@0000070?ooo`<000000P3oool=0=7=Z@8000001@3oool500000080
oooo2@0000030?ooo`8000001@3oool200000080oooo0`0000020?ooo`D000000P3oool3000000@0
oooo1`0000070?ooo`<000000P3oool2000000<0oooo100000030?ooo`8000003@3AcJT5000000@0
oooo0P0000050?ooo`8000001@3oool4000000D0oooo0P0000020?ooo`8000000`3oool2000000L0
oooo0P0000070?ooo`H000000`3oool4000000T0oooo1@0000020?ooo`d0dLfY0P3oool2000000<0
oooo100000050?ooo`/000000P3oool4000000<0oooo0P0000070?ooo`8000000P3oool200000080
oooo0`0000040?ooo`T000000P3oool5000000H0oooo0`0000040?ooo`d0dLfY1P0000050?ooo`@0
0000103oool2000000D0oooo0P0000060?ooo`<000000P3oool8000000L0oooo0P0000040?ooo`80
00001@3oool2000000@0oooo100000050?ooo`@000000P3oool@0=7=Z@003P3AcJT2000000X0oooo
0P0000030?ooo`8000000P3oool3000000D0oooo0P0000050?ooo`8000001@3oool5000000L0oooo
0P0000020?ooo`P000000P3oool2000000`0oooo0`0000020?ooo`d0dLfY0P0000050?ooo`D00000
0P3oool9000000<0oooo0P0000050?ooo`8000000P3oool300000080oooo1@0000020?ooo`<00000
103oool7000000L0oooo0`0000020?ooo`8000000`3oool4000000<0oooo0P00000=0=7=Z@D00000
103oool2000000D0oooo0P0000050?ooo`@000001@3oool200000080oooo0P0000030?ooo`800000
1`3oool2000000L0oooo1P0000030?ooo`@000002@3oool500000080oooo3@3AcJT20?ooo`800000
0`3oool4000000D0oooo2`0000020?ooo`@000000`3oool2000000L0oooo0P0000020?ooo`800000
0P3oool3000000@0oooo2@0000020?ooo`D000001P3oool3000000@0oooo3@3AcJT40?ooo`800000
1@3oool200000080oooo100000050?ooo`8000000P3oool6000000L0oooo0P0000060?ooo`L00000
1P3oool500000080oooo100000060?ooo`<000001P3oool@0=7=Z@003P3AcJT2000000X0oooo0P00
00030?ooo`8000000P3oool3000000D0oooo0P0000050?ooo`8000001@3oool5000000L0oooo0P00
00020?ooo`P000000P3oool2000000`0oooo0`0000020?ooo`d0dLfY0P0000050?ooo`D000000P3o
ool9000000<0oooo0P0000050?ooo`8000000P3oool300000080oooo1@0000020?ooo`<00000103o
ool7000000L0oooo0`0000020?ooo`8000000`3oool4000000<0oooo0P00000=0=7=Z@80oooo2@00
00090?ooo`L000001`3oool2000000D0oooo100000070?ooo`@000001@3oool4000000D0oooo1000
00030?ooo`@000001@3oool2000000d0dLfY0P3oool2000000D0oooo2@0000060?ooo`L000000P3o
ool3000000@0oooo0P0000050?ooo`800000103oool3000000@0oooo2`0000020?oooa0000003@3A
cJT40?ooo`8000001@3oool200000080oooo100000050?ooo`8000000P3oool6000000L0oooo0P00
00060?ooo`L000001P3oool500000080oooo100000060?ooo`<000001P3oool@0=7=Z@003P3AcJT2
000000<0oooo1@0000020?ooo`8000001@3oool2000000D0oooo0`0000020?ooo`8000001@3oool2
000000<0oooo0P0000030?ooo`@000000`3oool<00000080oooo0P00000:0?ooo`8000000`3oool2
000000d0dLfY1@3oool2000000L0oooo1@0000020?ooo`8000002P3oool2000000L0oooo1@000005
0?ooo`8000000P3oool300000080oooo0P0000050?ooo`8000000`3oool4000000D0oooo0P000005
0?ooo`d0dLfY0P3oool9000000T0oooo1`0000070?ooo`8000001@3oool4000000L0oooo10000005
0?ooo`@000001@3oool4000000<0oooo100000050?ooo`8000003@3AcJT20?ooo`8000001@3oool9
000000H0oooo1`0000020?ooo`<00000103oool2000000D0oooo0P0000040?ooo`<00000103oool;
00000080oooo4000000=0=7=Z@@0oooo0P0000050?ooo`8000000P3oool4000000D0oooo0P000002
0?ooo`H000001`3oool2000000H0oooo1`0000060?ooo`D000000P3oool4000000H0oooo0`000006
0?oooa00dLfY000>0=7=Z@8000000`3oool500000080oooo0P0000050?ooo`8000001@3oool30000
0080oooo0P0000050?ooo`8000000`3oool2000000<0oooo100000030?ooo``000000P3oool20000
00X0oooo0P0000030?ooo`8000003@3AcJT50?ooo`8000001`3oool500000080oooo0P00000:0?oo
o`8000001`3oool5000000D0oooo0P0000020?ooo`<000000P3oool2000000D0oooo0P0000030?oo
o`@000001@3oool2000000D0oooo3@3AcJT20?ooo`T000002@3oool7000000L0oooo0P0000050?oo
o`@000001`3oool4000000D0oooo100000050?ooo`@000000`3oool4000000D0oooo0P00000=0=7=
Z@80oooo2@0000020?ooo`<000000P3oool;000000@0oooo1@0000040?ooo`D000000P3oool20000
00D0oooo4@0000030?ooo`800000103oool3000000@0oooo3@3AcJT40?ooo`8000000`3oool20000
00H0oooo0P0000020?ooo`D00000103oool2000000d0oooo0P0000050?ooo`8000000P3oool20000
0080oooo100000050?ooo`8000003@3oool200000080oooo403AcJT000h0dLfY0P0000030?ooo`D0
00000P3oool2000000D0oooo0P0000050?ooo`<000000P3oool2000000D0oooo0P0000030?ooo`80
00000`3oool4000000<0oooo300000020?ooo`8000002P3oool2000000<0oooo0P00000=0=7=Z@h0
oooo1`0000020?ooo``000000P3oool3000000D0oooo100000050?ooo`T000000`3oool2000000L0
oooo0P0000030?ooo`8000001`3oool=0=7=Z@8000000`3oool400000080oooo1@0000040?ooo`<0
00001P3oool3000000@0oooo1@0000090?ooo`8000000P3oool2000000<0oooo0P0000040?ooo`D0
00000P3oool7000000D0oooo1000000=0=7=Z@80oooo2@0000020?ooo`<000000P3oool;000000@0
oooo1@0000040?ooo`D000000P3oool2000000D0oooo4@0000030?ooo`800000103oool3000000@0
oooo3@3AcJT40?ooo`8000000`3oool2000000H0oooo0P0000020?ooo`D00000103oool2000000d0
oooo0P0000050?ooo`8000000P3oool200000080oooo100000050?ooo`8000003@3oool200000080
oooo403AcJT000h0dLfY1@3oool2000000X0oooo0P0000020?ooo`<000000P3oool5000000D0oooo
0P0000070?ooo`<00000103oool3000000@0oooo3000000:0?ooo`L000003@3AcJT>0?ooo`L00000
0P3oool<00000080oooo0`0000050?ooo`@000001@3oool9000000<0oooo0P0000070?ooo`800000
0`3oool2000000L0oooo3@3AcJT2000000<0oooo100000020?ooo`D00000103oool3000000H0oooo
0`0000040?ooo`D000002@3oool200000080oooo0P0000030?ooo`800000103oool500000080oooo
1`0000050?ooo`@000003@3AcJT4000000<0oooo0P0000020?ooo`8000000`3oool400000080oooo
400000040?ooo`<000000P3oool2000000@0oooo5`0000040?ooo`T000003@3AcJT;00000080oooo
0P0000040?ooo`8000000`3oool400000080oooo0P0000020?ooo`L000000P3oool2000000@0oooo
0`0000040?ooo`P000001@3oool2000000@0oooo1`0000020?ooo`@00000403AcJT000h0dLfY1@3o
ool2000000X0oooo0P0000020?ooo`<000000P3oool5000000D0oooo0P0000070?ooo`<00000103o
ool3000000@0oooo3000000:0?ooo`L000003@3AcJT20?ooo`L000000`3oool4000000D0oooo1@00
00020?ooo`L00000303oool2000000<0oooo100000030?ooo`L000002@3oool2000000D0oooo0P00
00030?ooo`8000003@3AcJT2000000D0oooo0P0000050?ooo`T000000P3oool200000080oooo0`00
00020?ooo`8000001`3oool2000000L0oooo0P00000;0?ooo``000002@3oool2000000d0dLfY1000
00030?ooo`8000000P3oool2000000<0oooo100000020?oooa000000103oool300000080oooo0P00
00040?oooaL00000103oool9000000d0dLfY2`0000020?ooo`800000103oool2000000<0oooo1000
00020?ooo`8000000P3oool700000080oooo0P0000040?ooo`<00000103oool8000000D0oooo0P00
00040?ooo`L000000P3oool400000100dLfY000>0=7=Z@80oooo1@0000030?ooo`8000000P3oool3
000000L0oooo1`0000050?ooo`L000000P3oool<00000080oooo0`0000090?ooo`P000002@3oool=
0=7=Z@80oooo1`0000030?ooo`@000001@3oool500000080oooo1`00000<0?ooo`8000000`3oool4
000000<0oooo1`0000090?ooo`8000001@3oool2000000<0oooo0P00000=0=7=Z@8000001@3oool2
000000D0oooo2@0000020?ooo`8000000P3oool300000080oooo0P0000070?ooo`8000001`3oool2
000000/0oooo300000090?ooo`8000003@3AcJT20?ooo`L000000P3oool500000080oooo0P000002
0?ooo`D000000P3oool2000000T0oooo0P0000050?ooo`8000000P3oool2000000<0oooo10000002
0?ooo`h000000P3oool4000000D0oooo0P00000=0=7=Z@@00000503oool4000000/0oooo0P000002
0?ooo`8000000P3oool2000000<0oooo0P0000020?ooo`@000000P3oool2000000T0oooo10000002
0?ooo`<000000P3oool200000080oooo403AcJT000h0dLfY0P3oool5000000<0oooo0P0000020?oo
o`<000001`3oool7000000D0oooo1`0000020?ooo``000000P3oool3000000T0oooo200000090?oo
o`d0dLfY0P3oool7000000<0oooo100000050?ooo`D000000P3oool7000000`0oooo0P0000030?oo
o`@000000`3oool7000000T0oooo0P0000050?ooo`8000000`3oool2000000d0dLfY1`3oool20000
00L0oooo2@0000040?ooo`D000000P3oool700000080oooo0P0000030?ooo`T000001P3oool90000
00L0oooo1@0000020?ooo`d0dLfY0P3oool700000080oooo1@0000020?ooo`8000000P3oool50000
0080oooo0P0000090?ooo`8000001@3oool200000080oooo0P0000030?ooo`@000000P3oool>0000
0080oooo100000050?ooo`8000003@3AcJT4000001@0oooo1000000;0?ooo`8000000P3oool20000
0080oooo0P0000030?ooo`8000000P3oool400000080oooo0P0000090?ooo`@000000P3oool30000
0080oooo0P0000020?oooa00dLfY000>0=7=Z@8000000`3oool2000000D0oooo0P0000050?ooo``0
00001@3oool2000001<0oooo1`0000030?ooo`8000000P3oool800000080oooo1@0000020?ooo`d0
dLfY0P3oool300000080oooo0P0000030?ooo`@000001@3oool5000000L0oooo1`0000020?ooo`D0
00001@3oool200000080oooo4@0000020?ooo`8000000`3oool4000000D0oooo3@3AcJT70?ooo`80
00001`3oool9000000@0oooo1@0000020?ooo`L000000P3oool2000000<0oooo2@0000060?ooo`T0
00001`3oool500000080oooo3@3AcJT20?ooo`L000000P3oool500000080oooo0P0000020?ooo`D0
00000P3oool2000000T0oooo0P0000050?ooo`8000000P3oool2000000<0oooo100000020?ooo`h0
00000P3oool4000000D0oooo0P00000=0=7=Z@@000000P3oool300000080oooo2000000=0?ooo`80
00002`3oool4000000<0oooo0P0000080?ooo`8000000`3oool6000000@0oooo0P0000090?oooa00
dLfY000>0=7=Z@8000000`3oool2000000D0oooo0P0000050?ooo``000001@3oool2000001<0oooo
1`0000030?ooo`8000000P3oool800000080oooo1@0000020?ooo`d0dLfY0P3oool300000080oooo
0P0000030?ooo`@000001@3oool5000000L0oooo1`0000020?ooo`D000001@3oool200000080oooo
4@0000020?ooo`8000000`3oool4000000D0oooo3@3AcJT2000000L0oooo0P0000050?ooo`@00000
0`3oool200000180oooo100000030?ooo`H000001`3oool700000080oooo0P0000050?ooo`L00000
0P3oool=0=7=Z@80oooo1@0000020?ooo`8000000P3oool3000000@0oooo1`0000020?ooo`800000
0P3oool9000000<0oooo0P0000020?ooo`@000001@3oool4000000<0oooo200000030?ooo`800000
103oool3000000@0oooo3@3AcJT400000080oooo0`0000020?ooo`P000003@3oool2000000/0oooo
100000030?ooo`800000203oool2000000<0oooo1P0000040?ooo`8000002@3oool@0=7=Z@003P3A
cJT2000000<0oooo0P0000050?ooo`8000001@3oool<000000D0oooo0P00000C0?ooo`L000000`3o
ool200000080oooo200000020?ooo`D000000P3oool=0=7=Z@T0oooo1@0000020?ooo`<000001`3o
ool7000000@0oooo0`0000050?ooo`8000001@3oool@00000080oooo1@0000020?ooo``000003@3A
cJT2000000L0oooo0P0000050?ooo`@000000`3oool200000180oooo100000030?ooo`H000001`3o
ool700000080oooo0P0000050?ooo`L000000P3oool=0=7=Z@80oooo1@0000020?ooo`8000000P3o
ool3000000@0oooo1`0000020?ooo`8000000P3oool9000000<0oooo0P0000020?ooo`@000001@3o
ool4000000<0oooo200000030?ooo`800000103oool3000000@0oooo3@3AcJT20?ooo`8000000P3o
ool300000080oooo100000020?ooo`@000000`3oool200000080oooo0P0000040?ooo`T000001P3o
ool700000080oooo0P0000040?ooo`D000002P3oool3000000@0oooo0P00000@0=7=Z@003P3AcJT5
00000080oooo300000020?ooo`X000001`3oool2000000D0oooo0`0000020?ooo`8000001@3oool2
000000P0oooo0P0000070?ooo`D000001`3oool=0=7=Z@T0oooo1@0000020?ooo`<000001`3oool7
000000@0oooo0`0000050?ooo`8000001@3oool@00000080oooo1@0000020?ooo``000003@3AcJT2
000000L0oooo0P0000050?ooo`@000000`3oool200000180oooo100000030?ooo`H000001`3oool7
00000080oooo0P0000050?ooo`L000000P3oool=0=7=Z@@000000`3oool;00000080oooo0P000002
0?ooo`D00000103oool700000080oooo0`0000020?ooo`800000103oool@000000d0oooo0`000002
0?ooo`8000003@3AcJT20?ooo`8000000P3oool300000080oooo100000020?ooo`@000000`3oool2
00000080oooo0P0000040?ooo`T000001P3oool700000080oooo0P0000040?ooo`D000002P3oool3
000000@0oooo0P00000@0=7=Z@003P3AcJT500000080oooo300000020?ooo`X000001`3oool20000
00D0oooo0`0000020?ooo`8000001@3oool2000000P0oooo0P0000070?ooo`D000001`3oool=0=7=
Z@D000000P3oool5000000h0oooo0P00000<0?ooo`D000001`3oool;000000<0oooo2@0000020?oo
o`<000000P3oool2000000<0oooo0P00000=0=7=Z@D0oooo100000020?ooo`D000000P3oool50000
00@0oooo1`0000040?ooo`<000000P3oool4000000<0oooo0P0000020?ooo`L000000P3oool20000
00<0oooo0P0000040?ooo`D000000P3oool300000080oooo0P00000=0=7=Z@@000000`3oool;0000
0080oooo0P0000020?ooo`D00000103oool700000080oooo0`0000020?ooo`800000103oool@0000
00d0oooo0`0000020?ooo`8000003@3AcJT20?ooo`8000000P3oool5000000@0oooo1P0000090?oo
oa4000000P3oool3000000@0oooo0P0000040?ooo`8000000`3oool200000080oooo200000030?oo
o`800000103oool@0=7=Z@003P3AcJT20?ooo`D00000303oool2000000X0oooo1`0000020?ooo`<0
00001`3oool5000000h0oooo1`0000050?ooo`L000003@3AcJT500000080oooo1@00000>0?ooo`80
0000303oool5000000L0oooo2`0000030?ooo`T000000P3oool300000080oooo0P0000030?ooo`80
00003@3AcJT50?ooo`@000000P3oool500000080oooo1@0000040?ooo`L00000103oool300000080
oooo100000030?ooo`8000000P3oool700000080oooo0P0000030?ooo`800000103oool500000080
oooo0`0000020?ooo`8000003@3AcJT40?ooo`<00000103oool2000000<0oooo100000040?ooo`<0
00000P3oool4000000<0oooo0P0000090?ooo`H000000`3oool400000080oooo1`0000090?ooo`80
00000P3oool500000080oooo3@3AcJT20?ooo`8000000P3oool5000000@0oooo1P0000090?oooa40
00000P3oool3000000@0oooo0P0000040?ooo`8000000`3oool200000080oooo200000030?ooo`80
0000103oool@0=7=Z@003P3AcJT20?ooo`D00000303oool2000000X0oooo1`0000020?ooo`<00000
1`3oool5000000h0oooo1`0000050?ooo`L000003@3AcJT500000080oooo1@00000>0?ooo`800000
303oool5000000L0oooo2`0000030?ooo`T000000P3oool300000080oooo0P0000030?ooo`800000
3@3AcJT50?ooo`8000000P3oool500000080oooo1`0000040?ooo`8000001@3oool4000000<0oooo
2@00000F0?ooo`D000002@3oool2000000d0dLfY103oool3000000@0oooo0P0000030?ooo`@00000
103oool300000080oooo100000030?ooo`8000002@3oool6000000<0oooo100000020?ooo`L00000
2@3oool200000080oooo1@0000020?ooo`d0dLfY0P3oool200000080oooo1@0000040?ooo`H00000
2@3ooolA00000080oooo0`0000040?ooo`800000103oool2000000<0oooo0P0000020?ooo`P00000
0`3oool2000000@0oooo403AcJT000h0dLfY0P3oool5000000`0oooo0P00000:0?ooo`L000000P3o
ool3000000L0oooo1@00000>0?ooo`L000001@3oool7000000d0dLfY1@0000040?ooo`D000001@3o
ool2000000L0oooo1`0000050?ooo`T000001@3oool700000080oooo1@0000050?ooo`8000000P3o
ool300000080oooo0P0000030?ooo`8000003@3AcJT50?ooo`8000000P3oool500000080oooo1`00
00040?ooo`8000001@3oool4000000<0oooo2@00000F0?ooo`D000002@3oool2000000d0dLfY1000
00030?ooo`@000000P3oool7000000@0oooo0`0000020?ooo`8000000P3oool<000000P0oooo0`00
00020?ooo`8000001@3oool200000080oooo5000000=0=7=Z@8000001`3oool200000080oooo1000
000;0?ooo`l00000103oool9000000@0oooo0P00000;0?ooo`H000001@3oool200000080oooo403A
cJT000h0dLfY1`0000030?ooo`8000000P3oool3000000h0oooo1@0000020?ooo`L000004@3oool2
000000D0oooo0P0000030?ooo`8000001@3oool7000000d0dLfY1@0000040?ooo`D000001@3oool2
000000L0oooo1`0000050?ooo`T000001@3oool700000080oooo1@0000050?ooo`8000000P3oool3
00000080oooo0P0000030?ooo`8000003@3AcJT2000000<0oooo0P0000040?ooo`<000001P3oool3
000000@0oooo0P0000030?ooo`@000001@3oool400000080oooo0`0000020?ooo`8000001`3oool2
00000080oooo0`0000040?ooo`L000000P3oool300000080oooo0P00000=0=7=Z@@000000`3oool4
00000080oooo1`0000040?ooo`<000000P3oool200000080oooo300000080?ooo`<000000P3oool2
000000D0oooo0P0000020?oooa@000003@3AcJT2000000L0oooo0P0000020?ooo`@000002`3oool?
000000@0oooo2@0000040?ooo`8000002`3oool6000000D0oooo0P0000020?oooa00dLfY000>0=7=
Z@L000000`3oool200000080oooo0`00000>0?ooo`D000000P3oool700000140oooo0P0000050?oo
o`8000000`3oool2000000D0oooo1`00000=0=7=Z@80oooo0`0000020?ooo`L00000303oool70000
00`0oooo2@0000020?ooo`X000000P3oool2000000L0oooo0`0000040?ooo`<000000P3oool=0=7=
Z@8000000`3oool2000000@0oooo0`0000060?ooo`<00000103oool2000000<0oooo100000050?oo
o`@000000P3oool300000080oooo0P0000070?ooo`8000000P3oool3000000@0oooo1`0000020?oo
o`<000000P3oool2000000d0dLfY100000030?ooo`@000000P3oool7000000@0oooo0`0000020?oo
o`8000000P3oool<000000P0oooo0`0000020?ooo`8000001@3oool200000080oooo5000000=0=7=
Z@80oooo100000030?ooo`8000000P3oool6000000/0oooo2@0000020?ooo`8000000P3oool;0000
00@0oooo2@0000040?ooo`8000000P3oool900000080oooo403AcJT000h0dLfY2P3oool4000000<0
oooo0P0000020?ooo`P000000P3oool2000000<0oooo0P0000020?ooo`D000001`3oool5000000D0
oooo0P0000030?ooo`8000001@3oool2000000D0oooo1`00000=0=7=Z@80oooo0`0000020?ooo`L0
0000303oool7000000`0oooo2@0000020?ooo`X000000P3oool2000000L0oooo0`0000040?ooo`<0
00000P3oool=0=7=Z@8000000`3oool2000000@0oooo0`0000060?ooo`<00000103oool2000000<0
oooo100000050?ooo`@000000P3oool300000080oooo0P0000070?ooo`8000000P3oool3000000@0
oooo1`0000020?ooo`<000000P3oool2000000d0dLfY1`0000020?ooo`T000001P3oool500000080
oooo1@0000040?ooo`8000000`3oool200000080oooo100000030?ooo`8000000P3oool5000000/0
oooo2@0000020?ooo`8000003@3AcJT20?ooo`@000000`3oool200000080oooo1P00000;0?ooo`T0
00000P3oool200000080oooo2`0000040?ooo`T00000103oool200000080oooo2@0000020?oooa00
dLfY000>0=7=Z@X0oooo100000030?ooo`8000000P3oool800000080oooo0P0000030?ooo`800000
0P3oool5000000L0oooo1@0000050?ooo`8000000`3oool2000000D0oooo0P0000050?ooo`L00000
3@3AcJT500000080oooo1@0000040?ooo`<00000103oool500000080oooo6000000@0?ooo`D00000
0P3oool7000000<0oooo0P00000=0=7=Z@80oooo1@0000020?ooo`L000002`3oool2000000<0oooo
1P0000030?ooo`800000103oool700000080oooo0`00000?0?ooo`D000000P3oool500000080oooo
3@3AcJT700000080oooo2@0000060?ooo`D000000P3oool5000000@0oooo0P0000030?ooo`800000
0P3oool4000000<0oooo0P0000020?ooo`D000002`3oool900000080oooo0P00000=0=7=Z@H0oooo
1`0000040?ooo`L000000P3oool6000000T0oooo1P0000090?ooo`H000000P3oool5000000X0oooo
2@00000@0=7=Z@003P3AcJT50?ooo`L000000P3oool300000080oooo0P0000030?ooo`8000000`3o
ool200000080oooo0`0000020?ooo`8000001@3oool300000080oooo0P0000030?ooo`L000001@3o
ool4000000<0oooo0P0000070?ooo`<000000P3oool=0=7=Z@D000000P3oool5000000@0oooo0`00
00040?ooo`D000000P3ooolH00000100oooo1@0000020?ooo`L000000`3oool2000000d0dLfY0P3o
ool500000080oooo1`00000;0?ooo`8000000`3oool6000000<0oooo0P0000040?ooo`L000000P3o
ool3000000l0oooo1@0000020?ooo`D000000P3oool=0=7=Z@80oooo0P0000070?ooo`L00000103o
ool@00000080oooo0P0000070?ooo`@000000`3oool200000080oooo0P0000050?ooo`8000000P3o
ool2000000<0oooo1P0000070?ooo`d0dLfY1P3oool7000000@0oooo1`0000020?ooo`H000002@3o
ool6000000T0oooo1P0000020?ooo`D000002P3oool900000100dLfY000>0=7=Z@D0oooo1`000002
0?ooo`<000000P3oool2000000<0oooo0P0000030?ooo`8000000P3oool300000080oooo0P000005
0?ooo`<000000P3oool2000000<0oooo1`0000050?ooo`@000000`3oool2000000L0oooo0`000002
0?ooo`d0dLfY1@0000020?ooo`D00000103oool3000000@0oooo1@0000020?oooaP00000403oool5
00000080oooo1`0000030?ooo`8000003@3AcJT5000000@0oooo0P0000030?ooo`H000000`3oool4
00000080oooo1@0000040?ooo`<00000103oool9000000T0oooo3P0000090?ooo`8000003@3AcJT2
0?ooo`8000001`3oool7000000@0oooo400000020?ooo`8000001`3oool4000000<0oooo0P000002
0?ooo`8000001@3oool200000080oooo0P0000030?ooo`H000001`3oool=0=7=Z@80oooo0P000005
0?ooo`8000000P3oool2000000H0oooo0`0000020?ooo`800000103oool5000000@0oooo0P00000;
0?ooo`H000002`3oool2000000H0oooo1`0000020?oooa00dLfY000>0=7=Z@D0oooo1`0000020?oo
o`<000000P3oool2000000<0oooo0P0000030?ooo`8000000P3oool300000080oooo0P0000050?oo
o`<000000P3oool2000000<0oooo1`0000050?ooo`@000000`3oool2000000L0oooo0`0000020?oo
o`d0dLfY0P0000030?ooo`L000002`3oool300000080oooo0P0000030?ooo`@000000`3oool50000
0080oooo2@0000070?ooo`D000002@3oool3000000@0oooo1@00000=0=7=Z@D00000103oool20000
00<0oooo1P0000030?ooo`@000000P3oool5000000@0oooo0`0000040?ooo`T000002@3oool>0000
00T0oooo0P00000=0=7=Z@@000000`3oool4000000T0oooo0P0000020?ooo`<000000P3oool20000
0080oooo1`0000020?ooo`<000000P3oool2000000L0oooo100000020?ooo`D000000P3oool20000
0080oooo0`0000060?ooo`<00000103oool=0=7=Z@80oooo0P0000050?ooo`8000000P3oool20000
00H0oooo0`0000020?ooo`800000103oool5000000@0oooo0P00000;0?ooo`H000002`3oool20000
00H0oooo1`0000020?oooa00dLfY000>0=7=Z@L000001`3oool3000000L0oooo0P0000050?ooo`L0
00000P3oool5000000D0oooo0P0000030?oooaD000002P3oool2000000d0dLfY0P0000030?ooo`L0
00002`3oool300000080oooo0P0000030?ooo`@000000`3oool500000080oooo2@0000070?ooo`D0
00002@3oool3000000@0oooo1@00000=0=7=Z@D0oooo1000000;0?ooo`<000000P3oool2000000T0
oooo0P0000090?ooo`<000000P3oool200000080oooo1`0000020?oooa0000001@3oool2000000d0
dLfY100000030?ooo`@000002@3oool200000080oooo0`0000020?ooo`8000000P3oool700000080
oooo0`0000020?ooo`8000001`3oool400000080oooo1@0000020?ooo`8000000P3oool3000000H0
oooo0`0000040?ooo`d0dLfY0P3oool2000000D0oooo100000080?ooo`<00000103oool400000080
oooo0`0000040?ooo`P000000`3oool600000080oooo0P0000020?ooo`L00000103oool2000000D0
oooo0P0000020?ooo`800000403AcJT000h0dLfY1`0000070?ooo`<000001`3oool2000000D0oooo
1`0000020?ooo`D000001@3oool2000000<0oooo5@00000:0?ooo`8000003@3AcJT2000000<0oooo
100000030?ooo`8000000P3oool300000080oooo3P0000050?ooo`L000000P3oool7000000<0oooo
100000030?ooo`T000002@3oool300000080oooo3@3AcJT50?ooo`@000002`3oool300000080oooo
0P0000090?ooo`8000002@3oool300000080oooo0P0000020?ooo`L000000P3oool@000000D0oooo
0P00000=0=7=Z@8000001@3oool900000080oooo100000020?ooo`<000002@3oool200000080oooo
0P0000030?ooo`800000103oool2000000L0oooo0P0000050?ooo`8000000P3oool5000000@0oooo
1@0000020?ooo`8000003@3AcJT20?ooo`8000001@3oool4000000P0oooo0`0000040?ooo`@00000
0P3oool3000000@0oooo200000030?ooo`H000000P3oool200000080oooo1`0000040?ooo`800000
1@3oool200000080oooo0P00000@0=7=Z@003P3AcJT20?ooo`D000000`3oool200000080oooo1`00
000<0?ooo`D000000P3ooolC000000<0oooo0P0000030?ooo`8000001@3oool700000080oooo1@00
000=0=7=Z@8000000`3oool4000000<0oooo0P0000020?ooo`<000000P3oool>000000D0oooo1`00
00020?ooo`L000000`3oool4000000<0oooo2@0000090?ooo`<000000P3oool=0=7=ZEP000003@3A
cJT2000000D0oooo2@0000020?ooo`@000000P3oool3000000T0oooo0P0000020?ooo`8000000`3o
ool2000000@0oooo0P0000070?ooo`8000001@3oool200000080oooo1@0000040?ooo`D000000P3o
ool2000000d0dLfYF000000@0=7=Z@003P3AcJT20?ooo`D000000`3oool200000080oooo1`00000<
0?ooo`D000000P3ooolC000000<0oooo0P0000030?ooo`8000001@3oool700000080oooo1@00000=
0=7=Z@8000000`3oool4000000<0oooo0P0000020?ooo`<000000P3oool>000000D0oooo1`000002
0?ooo`L000000`3oool4000000<0oooo2@0000090?ooo`<000000P3oool=0=7=ZEP000003@3AcJT2
000000D0oooo2@0000020?ooo`@000000P3oool3000000T0oooo0P0000020?ooo`8000000`3oool2
000000@0oooo0P0000070?ooo`8000001@3oool200000080oooo1@0000040?ooo`D000000P3oool2
000000d0dLfYF000000@0=7=Z@003P3AcJT20?ooo`D000000`3oool200000080oooo1`00000<0?oo
o`D000000P3ooolC000000<0oooo0P0000030?ooo`8000001@3oool700000080oooo1@00000=0=7=
Z@8000000`3oool4000000L0oooo1@0000070?ooo`8000001@3oool2000000D0oooo2P0000020?oo
o`D000000P3oool2000000D0oooo1@0000040?ooo`D000000P3oool5000000d0dLfYF000000=0=7=
Z@80oooo0P0000030?ooo`@000001@3oool4000000L0oooo0P0000040?ooo`<000000P3oool20000
0080oooo0`0000020?ooo`800000103oool300000080oooo0P0000050?ooo`@000002`3oool20000
00L0oooo3@3AcJUH00000100dLfY000>0=7=Z@80oooo0`0000020?ooo``000000P3oool5000000<0
oooo0P0000070?ooo`8000000`3oool5000000@0oooo1`00000:0?oooa<000003@3AcJT2000000<0
oooo100000070?ooo`D000001`3oool2000000D0oooo0P0000050?ooo`X000000P3oool500000080
oooo0P0000050?ooo`D00000103oool500000080oooo1@00000=0=7=Z@D0oooo1000000;0?ooo`<0
00000P3oool2000000T0oooo0P0000090?ooo`<000000P3oool200000080oooo1`0000020?oooa00
00001@3oool2000000d0dLfY0P3oool2000000<0oooo100000050?ooo`@000001`3oool2000000@0
oooo0`0000020?ooo`8000000P3oool300000080oooo0P0000040?ooo`<000000P3oool2000000D0
oooo1000000;0?ooo`8000001`3oool=0=7=Z@80oooo0P0000050?ooo`@00000203oool3000000@0
oooo100000020?ooo`<00000103oool8000000<0oooo1P0000020?ooo`8000000P3oool7000000@0
oooo0P0000050?ooo`8000000P3oool200000100dLfY000>0=7=Z@80oooo0`0000020?ooo``00000
0P3oool5000000<0oooo0P0000070?ooo`8000000`3oool5000000@0oooo1`00000:0?oooa<00000
3@3AcJT20?ooo`<00000103oool300000080oooo0P0000030?ooo`T000000P3oool<000000<0oooo
1`0000020?ooo`D000004P3oool3000000L0oooo0P00000=0=7=Z@D0oooo1000000;0?ooo`<00000
0P3oool2000000T0oooo0P0000090?ooo`<000000P3oool200000080oooo1`0000020?oooa000000
1@3oool2000000d0dLfY0P0000050?ooo`8000001`3oool4000000T0oooo0P0000070?ooo`@00000
0`3oool200000080oooo1`0000040?ooo`D00000103oool2000000D0oooo100000050?ooo`@00000
3@3AcJT20?ooo`8000001@3oool4000000P0oooo0`0000040?ooo`@000000P3oool3000000@0oooo
200000030?ooo`H000000P3oool200000080oooo1`0000040?ooo`8000001@3oool200000080oooo
0P00000@0=7=Z@003P3AcJT70?ooo`<000000P3oool500000080oooo0P0000030?ooo`8000004@3o
ool2000000<0oooo100000030?ooo`L000000P3oool7000000D0oooo0`0000040?ooo`<000000P3o
ool=0=7=Z@80oooo0`0000040?ooo`<000000P3oool2000000<0oooo2@0000020?ooo``000000`3o
ool700000080oooo1@00000B0?ooo`<000001`3oool2000000d0dLfY1@0000040?ooo`8000000`3o
ool6000000<0oooo100000020?ooo`D00000103oool3000000@0oooo2@0000090?ooo`h000002@3o
ool2000000d0dLfY0P0000050?ooo`8000001`3oool4000000T0oooo0P0000070?ooo`@000000`3o
ool200000080oooo1`0000040?ooo`D00000103oool2000000D0oooo100000050?ooo`@000003@3A
cJT20?ooo`8000001@3oool200000080oooo0P0000060?ooo`<000000P3oool2000000@0oooo1@00
00040?ooo`8000002`3oool6000000/0oooo0P0000060?ooo`L000000P3oool@0=7=Z@003P3AcJT7
0?ooo`<000000P3oool500000080oooo0P0000030?ooo`8000004@3oool2000000<0oooo10000003
0?ooo`L000000P3oool7000000D0oooo0`0000040?ooo`<000000P3oool=0=7=Z@80oooo1@000002
0?ooo`<000000P3oool5000000@0oooo1@0000020?ooo`<000000P3oool7000000L0oooo0`000007
0?ooo`@000000`3oool200000080oooo1@0000050?ooo`8000000P3oool300000080oooo3@3AcJT5
000000@0oooo0P0000030?ooo`H000000`3oool400000080oooo1@0000040?ooo`<00000103oool9
000000T0oooo3P0000090?ooo`8000003@3AcJT4000000<0oooo0P0000020?ooo`/000001@3oool2
00000080oooo0P0000050?ooo`L000000P3oool2000000@0oooo0`0000020?ooo`@000002`3oool7
000000L0oooo0P00000=0=7=Z@80oooo0P0000050?ooo`8000000P3oool2000000H0oooo0`000002
0?ooo`800000103oool5000000@0oooo0P00000;0?ooo`H000002`3oool2000000H0oooo1`000002
0?oooa00dLfY000>0=7=Z@L0oooo0`0000020?ooo`D000000P3oool2000000<0oooo0P00000A0?oo
o`8000000`3oool4000000<0oooo1`0000020?ooo`L000001@3oool3000000@0oooo0`0000020?oo
o`d0dLfY0P3oool500000080oooo0`0000020?ooo`D00000103oool500000080oooo0`0000020?oo
o`L000001`3oool3000000L0oooo100000030?ooo`8000000P3oool5000000D0oooo0P0000020?oo
o`<000000P3oool=0=7=Z@80oooo1@0000020?ooo`L000002`3oool2000000<0oooo1P0000030?oo
o`800000103oool700000080oooo0`00000?0?ooo`D000000P3oool500000080oooo3@3AcJT40000
00<0oooo0P0000020?ooo`/000001@3oool200000080oooo0P0000050?ooo`L000000P3oool20000
00@0oooo0`0000020?ooo`@000002`3oool7000000L0oooo0P00000=0=7=Z@H0oooo1`0000040?oo
o`L000000P3oool6000000T0oooo1P0000090?ooo`H000000P3oool5000000X0oooo2@00000@0=7=
Z@003P3AcJT7000000D0oooo1@0000020?ooo`8000000`3oool2000000<0oooo100000050?ooo`L0
00000`3oool@000000`0oooo1@0000070?ooo`d0dLfY0P3oool500000080oooo0`0000020?ooo`D0
0000103oool500000080oooo0`0000020?ooo`L000001`3oool3000000L0oooo100000030?ooo`80
00000P3oool5000000D0oooo0P0000020?ooo`<000000P3oool=0=7=Z@80oooo1@0000020?ooo`L0
00002`3oool2000000<0oooo1P0000030?ooo`800000103oool700000080oooo0`00000?0?ooo`D0
00000P3oool500000080oooo3@3AcJT20?ooo`/000002`3oool3000000@0oooo1`0000070?ooo`H0
00000P3oool9000000<0oooo100000020?ooo`8000002@3oool300000080oooo0P00000=0=7=Z@H0
oooo1`0000040?ooo`L000000P3oool6000000T0oooo1P0000090?ooo`H000000P3oool5000000X0
oooo2@00000@0=7=Z@003P3AcJT7000000D0oooo1@0000020?ooo`8000000`3oool2000000<0oooo
100000050?ooo`L000000`3oool@000000`0oooo1@0000070?ooo`d0dLfY0P3oool300000080oooo
1@0000020?ooo`800000303oool2000000D0oooo2P0000020?ooo`D000002@3oool200000140oooo
2@00000=0=7=Z@8000000`3oool2000000@0oooo0`0000060?ooo`<00000103oool2000000<0oooo
100000050?ooo`@000000P3oool300000080oooo0P0000070?ooo`8000000P3oool3000000@0oooo
1`0000020?ooo`<000000P3oool2000000d0dLfY0P3oool;000000/0oooo0`0000040?ooo`L00000
1`3oool600000080oooo2@0000030?ooo`@000000P3oool2000000T0oooo0`0000020?ooo`800000
3@3AcJT20?ooo`@000000`3oool200000080oooo1P00000;0?ooo`T000000P3oool200000080oooo
2`0000040?ooo`T00000103oool200000080oooo2@0000020?oooa00dLfY000>0=7=Z@80oooo0`00
00020?ooo`<000000P3oool2000000L0oooo1@0000050?ooo`8000000`3oool2000000D0oooo1@00
00020?ooo`h000000`3oool200000080oooo0`00000>0?ooo`d0dLfY0P3oool300000080oooo1@00
00020?ooo`800000303oool2000000D0oooo2P0000020?ooo`D000002@3oool200000140oooo2@00
000=0=7=Z@8000000`3oool2000000@0oooo0`0000060?ooo`<00000103oool2000000<0oooo1000
00050?ooo`@000000P3oool300000080oooo0P0000070?ooo`8000000P3oool3000000@0oooo1`00
00020?ooo`<000000P3oool2000000d0dLfY0P0000020?ooo`D000001`3oool2000000@0oooo0P00
00050?ooo`8000000P3oool5000000@0oooo0`0000020?ooo`T000000P3oool4000000<0oooo1P00
00070?ooo`8000001@3oool200000080oooo3@3AcJT20?ooo`@000000`3oool200000080oooo1P00
000;0?ooo`T000000P3oool200000080oooo2`0000040?ooo`T00000103oool200000080oooo2@00
00020?oooa00dLfY000>0=7=Z@80oooo0`0000020?ooo`<000000P3oool2000000L0oooo1@000005
0?ooo`8000000`3oool2000000D0oooo1@0000020?ooo`h000000`3oool200000080oooo0`00000>
0?ooo`d0dLfY0P3oool500000080oooo300000070?ooo`L000001@3oool2000000<0oooo1`000002
0?ooo`8000001@3oool<00000080oooo1@0000020?ooo`8000000`3oool2000000d0dLfY0P000003
0?ooo`800000103oool3000000H0oooo0`0000040?ooo`8000000`3oool4000000D0oooo10000002
0?ooo`<000000P3oool2000000L0oooo0P0000020?ooo`<00000103oool700000080oooo0`000002
0?ooo`8000003@3AcJT200000080oooo1@0000070?ooo`800000103oool2000000D0oooo0P000002
0?ooo`D00000103oool300000080oooo2@0000020?ooo`@000000`3oool6000000L0oooo0P000005
0?ooo`8000000P3oool=0=7=Z@8000001`3oool200000080oooo1000000;0?ooo`l00000103oool9
000000@0oooo0P00000;0?ooo`H000001@3oool200000080oooo403AcJT000h0dLfY0P0000030?oo
o`8000002P3oool4000000<0oooo0P00000:0?oooaL000000`3oool2000000<0oooo0P00000:0?oo
o`L000000P3oool=0=7=Z@80oooo1@0000020?ooo``000001`3oool7000000D0oooo0P0000030?oo
o`L000000P3oool2000000D0oooo300000020?ooo`D000000P3oool2000000<0oooo0P00000=0=7=
Z@D0oooo0P0000020?ooo`D000000P3oool7000000@0oooo0P0000050?ooo`@000000`3oool90000
01H0oooo1@0000090?ooo`8000003@3AcJT200000080oooo1@0000070?ooo`800000103oool20000
00D0oooo0P0000020?ooo`D00000103oool300000080oooo2@0000020?ooo`@000000`3oool60000
00L0oooo0P0000050?ooo`8000000P3oool=0=7=Z@8000001`3oool200000080oooo1000000;0?oo
o`l00000103oool9000000@0oooo0P00000;0?ooo`H000001@3oool200000080oooo403AcJT000h0
dLfY0P0000030?ooo`8000002P3oool4000000<0oooo0P00000:0?oooaL000000`3oool2000000<0
oooo0P00000:0?ooo`L000000P3oool=0=7=Z@800000303oool700000080oooo300000020?ooo`D0
00000`3oool200000080oooo1`0000030?ooo`8000000P3oool5000000L0oooo1@0000090?ooo`d0
dLfY1@3oool200000080oooo1@0000020?ooo`L00000103oool2000000D0oooo100000030?ooo`T0
00005P3oool5000000T0oooo0P00000=0=7=Z@L000000P3oool700000080oooo0P0000020?ooo`/0
00000`3oool4000000T0oooo100000030?ooo`8000001`3oool2000000@0oooo1@0000020?ooo`/0
00003@3AcJT20?ooo`8000000P3oool5000000@0oooo1P0000090?oooa4000000P3oool3000000@0
oooo0P0000040?ooo`8000000`3oool200000080oooo200000030?ooo`800000103oool@0=7=Z@00
3P3AcJT2000000<0oooo0P00000:0?ooo`@000000`3oool2000000X0oooo5`0000030?ooo`800000
0`3oool2000000X0oooo1`0000020?ooo`d0dLfY0P00000<0?ooo`L000000P3oool<00000080oooo
1@0000030?ooo`8000000P3oool7000000<0oooo0P0000020?ooo`D000001`3oool5000000T0oooo
3@3AcJT50?ooo`@000000P3oool500000080oooo1@0000040?ooo`L00000103oool300000080oooo
100000030?ooo`8000000P3oool700000080oooo0P0000030?ooo`800000103oool500000080oooo
0`0000020?ooo`8000003@3AcJT700000080oooo1`0000020?ooo`8000000P3oool;000000<0oooo
100000090?ooo`@000000`3oool2000000L0oooo0P0000040?ooo`D000000P3oool;000000d0dLfY
0P3oool200000080oooo1@0000040?ooo`H000002@3ooolA00000080oooo0`0000040?ooo`800000
103oool2000000<0oooo0P0000020?ooo`P000000`3oool2000000@0oooo403AcJT000h0dLfY0P00
00030?ooo`8000000`3oool200000080oooo0`0000020?ooo`8000001@3oool5000000L0oooo6000
00050?ooo`8000000P3oool:000000D0oooo0P00000=0=7=Z@800000303oool700000080oooo3000
00020?ooo`D000000`3oool200000080oooo1`0000030?ooo`8000000P3oool5000000L0oooo1@00
00090?ooo`d0dLfY1@3oool400000080oooo1@0000020?ooo`D00000103oool7000000@0oooo0`00
00020?ooo`@000000`3oool200000080oooo1`0000020?ooo`8000000`3oool2000000@0oooo1@00
00020?ooo`<000000P3oool2000000d0dLfY0P0000050?ooo`8000000P3oool900000080oooo1@00
00020?ooo`L00000103oool2000000D0oooo100000020?ooo`D000000P3oool700000080oooo1000
00090?ooo`<00000103oool=0=7=Z@80oooo0P0000020?ooo`D00000103oool6000000T0oooo4@00
00020?ooo`<00000103oool2000000@0oooo0P0000030?ooo`8000000P3oool8000000<0oooo0P00
00040?oooa00dLfY000>0=7=Z@8000000`3oool2000000<0oooo0P0000020?ooo`<000000P3oool2
000000D0oooo1@0000070?oooaP000001@3oool200000080oooo2P0000050?ooo`8000003@3AcJT5
0?ooo`/000002P3oool;000000D0oooo1`0000030?ooo`@000000`3oool200000080oooo1@000005
0?ooo`T000000P3oool5000000d0dLfY0P0000070?ooo`8000001@3oool4000000<0oooo0P00000B
0?ooo`@000000`3oool6000000L0oooo1`0000020?ooo`8000001@3oool700000080oooo3@3AcJT2
000000D0oooo0P0000020?ooo`T000000P3oool500000080oooo1`0000040?ooo`8000001@3oool4
00000080oooo1@0000020?ooo`L000000P3oool4000000T0oooo0`0000040?ooo`d0dLfY0P3oool2
00000080oooo0`0000020?ooo`@000000P3oool4000000<0oooo0P0000020?ooo`800000103oool9
000000H0oooo1`0000020?ooo`800000103oool5000000X0oooo0`0000040?ooo`800000403AcJT0
00h0dLfY0P0000050?ooo`<000000P3ooolA000000T0oooo1@0000050?ooo`L000000P3oool50000
00L0oooo0P0000030?ooo`T000000`3oool2000000d0dLfY1@3oool;000000X0oooo2`0000050?oo
o`L000000`3oool4000000<0oooo0P0000020?ooo`D000001@3oool900000080oooo1@00000=0=7=
Z@8000001`3oool2000000D0oooo100000030?ooo`8000004P3oool4000000<0oooo1P0000070?oo
o`L000000P3oool2000000D0oooo1`0000020?ooo`d0dLfY100000030?ooo`8000000P3oool90000
0080oooo0P0000030?ooo`8000000P3oool2000000D0oooo0P0000020?ooo`<00000103oool40000
00D0oooo0P0000050?ooo`H000002@3oool2000000L0oooo3@3AcJT20?ooo`8000000P3oool30000
0080oooo100000020?ooo`@000000`3oool200000080oooo0P0000040?ooo`T000001P3oool70000
0080oooo0P0000040?ooo`D000002P3oool3000000@0oooo0P00000@0=7=Z@003P3AcJT2000000D0
oooo0`0000020?oooa4000002@3oool5000000D0oooo1`0000020?ooo`D000001`3oool2000000<0
oooo2@0000030?ooo`8000003@3AcJT70?ooo`L000001@3oool2000000D0oooo1`0000040?ooo`D0
00000`3oool200000080oooo1@0000020?ooo`D000001@3oool200000080oooo2P0000040?ooo`<0
00000P3oool=0=7=Z@8000001`3oool2000000D0oooo100000030?ooo`8000004P3oool4000000<0
oooo1P0000070?ooo`L000000P3oool2000000D0oooo1`0000020?ooo`d0dLfY100000030?ooo`80
00000P3oool900000080oooo0P0000030?ooo`8000000P3oool2000000D0oooo0P0000020?ooo`<0
0000103oool4000000D0oooo0P0000050?ooo`H000002@3oool2000000L0oooo3@3AcJT400000080
oooo0`0000020?ooo`P000003@3oool2000000/0oooo100000030?ooo`800000203oool2000000<0
oooo1P0000040?ooo`8000002@3oool@0=7=Z@003P3AcJT2000000D0oooo0`0000020?oooa400000
2@3oool5000000D0oooo1`0000020?ooo`D000001`3oool2000000<0oooo2@0000030?ooo`800000
3@3AcJT70?ooo`L000001@3oool2000000D0oooo1`0000040?ooo`D000000`3oool200000080oooo
1@0000020?ooo`D000001@3oool200000080oooo2P0000040?ooo`<000000P3oool=0=7=Z@L0oooo
0P0000070?ooo`T00000103oool500000080oooo1`0000020?ooo`8000000`3oool9000000H0oooo
2@0000070?ooo`D000000P3oool=0=7=Z@@0oooo1@00000;0?ooo`8000000P3oool300000080oooo
100000030?ooo`8000001`3ooolO000000@0oooo1@0000040?ooo`d0dLfY100000020?ooo`<00000
0P3oool8000000d0oooo0P00000;0?ooo`@000000`3oool2000000P0oooo0P0000030?ooo`H00000
103oool2000000T0oooo403AcJT000h0dLfY0P00000?0?ooo`L000000P3oool3000000@0oooo1@00
00020?ooo`D000001@3oool7000000D0oooo1@00000@0?ooo`D000003@3AcJT20?ooo`D000002@3o
ool300000080oooo1@0000040?ooo`<00000103oool5000000<0oooo1`0000090?ooo`L000003P3o
ool500000080oooo3@3AcJT70?ooo`8000001`3oool9000000@0oooo1@0000020?ooo`L000000P3o
ool2000000<0oooo2@0000060?ooo`T000001`3oool500000080oooo3@3AcJT40?ooo`D000002`3o
ool200000080oooo0`0000020?ooo`@000000`3oool2000000L0oooo7`0000040?ooo`D00000103o
ool=0=7=Z@@00000503oool4000000/0oooo0P0000020?ooo`8000000P3oool2000000<0oooo0P00
00020?ooo`@000000P3oool2000000T0oooo100000020?ooo`<000000P3oool200000080oooo403A
cJT000h0dLfY0P00000?0?ooo`L000000P3oool3000000@0oooo1@0000020?ooo`D000001@3oool7
000000D0oooo1@00000@0?ooo`D000003@3AcJT20?ooo`D000002@3oool300000080oooo1@000004
0?ooo`<00000103oool5000000<0oooo1`0000090?ooo`L000003P3oool500000080oooo3@3AcJT2
000000D0oooo0P0000050?ooo`T000000P3oool200000080oooo0`0000020?ooo`8000001`3oool2
000000L0oooo0P00000;0?ooo``000002@3oool2000000d0dLfY103oool5000000/0oooo0P000002
0?ooo`<000000P3oool4000000<0oooo0P0000070?oooal00000103oool5000000@0oooo3@3AcJT4
000001@0oooo1000000;0?ooo`8000000P3oool200000080oooo0P0000030?ooo`8000000P3oool4
00000080oooo0P0000090?ooo`@000000P3oool300000080oooo0P0000020?oooa00dLfY000>0=7=
Z@D0oooo0P0000050?ooo``00000403oool3000000D0oooo0P00000<0?ooo`L000001@3oool70000
00D0oooo0P00000=0=7=Z@80oooo1@0000090?ooo`<000000P3oool5000000@0oooo0`0000040?oo
o`D000000`3oool7000000T0oooo1`00000>0?ooo`D000000P3oool=0=7=Z@8000001@3oool20000
00D0oooo2@0000020?ooo`8000000P3oool300000080oooo0P0000070?ooo`8000001`3oool20000
00/0oooo300000090?ooo`8000003@3AcJT7000000H0oooo0`0000020?ooo`8000000P3oool20000
00<0oooo2@00000=0?ooo`8000002@3oool900000080oooo2@0000020?ooo`D000000P3oool=0=7=
Z@/000000P3oool2000000@0oooo0P0000030?ooo`@000000P3oool200000080oooo1`0000020?oo
o`800000103oool3000000@0oooo200000050?ooo`800000103oool700000080oooo1000000@0=7=
Z@003P3AcJT50?ooo`8000001@3oool<00000100oooo0`0000050?ooo`800000303oool7000000D0
oooo1`0000050?ooo`8000003@3AcJT<0?ooo`@000001@3oool5000000h0oooo0P0000030?ooo`80
00003P3oool500000080oooo1@0000020?ooo`8000001@3oool500000080oooo3@3AcJT2000000<0
oooo100000020?ooo`D00000103oool3000000H0oooo0`0000040?ooo`D000002@3oool200000080
oooo0P0000030?ooo`800000103oool500000080oooo1`0000050?ooo`@000003@3AcJT7000000H0
oooo0`0000020?ooo`8000000P3oool2000000<0oooo2@00000=0?ooo`8000002@3oool900000080
oooo2@0000020?ooo`D000000P3oool=0=7=Z@/000000P3oool2000000@0oooo0P0000030?ooo`@0
00000P3oool200000080oooo1`0000020?ooo`800000103oool3000000@0oooo200000050?ooo`80
0000103oool700000080oooo1000000@0=7=Z@003P3AcJT:00000080oooo0P0000070?ooo`<00000
0P3oool5000000D0oooo2@0000030?ooo`8000000P3oool7000000D0oooo2P0000020?ooo`<00000
0P3oool2000000<0oooo0P00000=0=7=Z@`0oooo100000050?ooo`D000003P3oool2000000<0oooo
0P00000>0?ooo`D000000P3oool500000080oooo0P0000050?ooo`D000000P3oool=0=7=Z@800000
0`3oool400000080oooo1@0000040?ooo`<000001P3oool3000000@0oooo1@0000090?ooo`800000
0P3oool2000000<0oooo0P0000040?ooo`D000000P3oool7000000D0oooo1000000=0=7=Z@@00000
1@3oool200000080oooo2@0000020?ooo`<000002`3oool2000000D0oooo100000090?ooo`@00000
1@3oool200000080oooo0P0000050?ooo`@000001@3oool2000000d0dLfY103oool2000000<0oooo
0P0000060?ooo`8000000P3oool5000000@0oooo0P00000=0?ooo`8000001@3oool200000080oooo
0P0000020?ooo`@000001@3oool2000000d0oooo0P0000020?oooa00dLfY000>0=7=Z@X000000P3o
ool2000000L0oooo0`0000020?ooo`D000001@3oool9000000<0oooo0P0000020?ooo`L000001@3o
ool:00000080oooo0`0000020?ooo`8000000`3oool2000000d0dLfY0P3oool300000080oooo3P00
00050?ooo`8000000P3oool5000000D0oooo1@0000090?ooo`8000002P3oool200000080oooo1`00
00070?ooo`D000003@3AcJT20?ooo`T000002@3oool7000000L0oooo0P0000050?ooo`@000001`3o
ool4000000D0oooo100000050?ooo`@000000`3oool4000000D0oooo0P00000=0=7=Z@@000001@3o
ool200000080oooo2@0000020?ooo`<000002`3oool2000000D0oooo100000090?ooo`@000001@3o
ool200000080oooo0P0000050?ooo`@000001@3oool2000000d0dLfY103oool2000000<0oooo0P00
00060?ooo`8000000P3oool5000000@0oooo0P00000=0?ooo`8000001@3oool200000080oooo0P00
00020?ooo`@000001@3oool2000000d0oooo0P0000020?oooa00dLfY000>0=7=Z@X000000P3oool2
000000L0oooo0`0000020?ooo`D000001@3oool9000000<0oooo0P0000020?ooo`L000001@3oool:
00000080oooo0`0000020?ooo`8000000`3oool2000000d0dLfY0P3oool300000080oooo3P000005
0?ooo`8000000P3oool5000000D0oooo1@0000090?ooo`8000002P3oool200000080oooo1`000007
0?ooo`D000003@3AcJT20?ooo`T000002@3oool7000000L0oooo0P0000050?ooo`@000001`3oool4
000000D0oooo100000050?ooo`@000000`3oool4000000D0oooo0P00000=0=7=Z@8000002@3oool2
000000<0oooo200000030?ooo`H000001@3oool9000000H0oooo1@0000040?ooo`L000000P3oool9
000000D0oooo1000000=0=7=Z@@0oooo0P0000050?ooo`8000000P3oool4000000D0oooo0P000002
0?ooo`H000001`3oool2000000H0oooo1`0000060?ooo`D000000P3oool4000000H0oooo0`000006
0?oooa00dLfY000>0=7=Z@D000001@3oool2000000D0oooo1`0000070?ooo`D000000P3oool50000
0080oooo1@0000090?ooo`<000001@3oool4000000X0oooo1@0000020?ooo`d0dLfY0P0000050?oo
o`D000000P3oool700000080oooo0`0000040?ooo`D000000P3oool300000080oooo1@0000020?oo
o`<000001`3oool2000000D0oooo2@0000070?ooo`8000000`3oool2000000d0dLfY0P3oool90000
00T0oooo1`0000070?ooo`8000001@3oool4000000L0oooo100000050?ooo`@000001@3oool40000
00<0oooo100000050?ooo`8000003@3AcJT2000000T0oooo0P0000030?ooo`P000000`3oool60000
00D0oooo2@0000060?ooo`D00000103oool700000080oooo2@0000050?ooo`@000003@3AcJT40?oo
o`8000001@3oool200000080oooo100000050?ooo`8000000P3oool6000000L0oooo0P0000060?oo
o`L000001P3oool500000080oooo100000060?ooo`<000001P3oool@0=7=Z@003P3AcJT5000000D0
oooo0P0000050?ooo`L000001`3oool500000080oooo1@0000020?ooo`D000002@3oool3000000D0
oooo1000000:0?ooo`D000000P3oool=0=7=Z@8000001@3oool500000080oooo1`0000020?ooo`<0
0000103oool500000080oooo0`0000020?ooo`D000000P3oool3000000L0oooo0P0000050?ooo`T0
00001`3oool2000000<0oooo0P00000=0=7=Z@D00000103oool2000000D0oooo0P0000050?ooo`@0
00001@3oool200000080oooo0P0000030?ooo`8000001`3oool2000000L0oooo1P0000030?ooo`@0
00002@3oool500000080oooo3@3AcJT200000080oooo0`0000020?ooo`d000001@3oool400000080
oooo0`0000020?ooo`L00000103oool;000000D0oooo0P0000020?ooo`d000001`3oool=0=7=Z@@0
oooo0P0000050?ooo`8000000P3oool4000000D0oooo0P0000020?ooo`H000001`3oool2000000H0
oooo1`0000060?ooo`D000000P3oool4000000H0oooo0`0000060?oooa00dLfY000>0=7=Z@800000
0`3oool2000000<0oooo1`0000070?ooo`D000000P3oool2000000L0oooo0`0000020?ooo`<00000
103oool300000080oooo0P0000080?ooo`8000000P3oool5000000D0oooo1`00000=0=7=Z@800000
1@3oool500000080oooo1`0000020?ooo`<00000103oool500000080oooo0`0000020?ooo`D00000
0P3oool3000000L0oooo0P0000050?ooo`T000001`3oool2000000<0oooo0P00000=0=7=Z@D00000
103oool2000000D0oooo0P0000050?ooo`@000001@3oool200000080oooo0P0000030?ooo`800000
1`3oool2000000L0oooo1P0000030?ooo`@000002@3oool500000080oooo3@3AcJT200000080oooo
0`0000020?ooo`d000001@3oool400000080oooo0`0000020?ooo`L00000103oool;000000D0oooo
0P0000020?ooo`d000001`3oool=0=7=Z@H000001@3oool4000000@0oooo0P0000050?ooo`800000
1P3oool300000080oooo200000070?ooo`800000103oool2000000D0oooo0P0000040?ooo`@00000
1@3oool400000080oooo403AcJT000h0dLfY0P0000030?ooo`8000000`3oool7000000L0oooo1@00
00020?ooo`8000001`3oool300000080oooo0`0000040?ooo`<000000P3oool2000000P0oooo0P00
00020?ooo`D000001@3oool7000000d0dLfY1@3oool200000080oooo0`0000020?ooo`T000001@3o
ool>000001<0oooo5`0000030?ooo`8000003@3AcJT2000000T0oooo0`0000040?ooo`D000000P3o
ool2000000L0oooo0P0000020?ooo`D00000103oool500000080oooo1`0000040?ooo`<000001P3o
ool5000000D0oooo0P0000020?ooo`d0dLfY3@3oool500000080oooo100000030?ooo`H000001@3o
ool2000000D0oooo0P0000020?ooo`L000000P3oool700000080oooo100000050?ooo`8000000P3o
ool2000000D0oooo0P00000=0=7=Z@H000001@3oool4000000@0oooo0P0000050?ooo`8000001P3o
ool300000080oooo200000070?ooo`800000103oool2000000D0oooo0P0000040?ooo`@000001@3o
ool400000080oooo403AcJT000h0dLfY0P0000030?ooo`8000000`3oool7000000L0oooo1@000002
0?ooo`8000001`3oool300000080oooo0`0000040?ooo`<000000P3oool2000000P0oooo0P000002
0?ooo`D000001@3oool7000000d0dLfY1@3oool200000080oooo0`0000020?ooo`T000001@3oool>
000001<0oooo5`0000030?ooo`8000003@3AcJT2000000T0oooo0`0000040?ooo`D000000P3oool2
000000L0oooo0P0000020?ooo`D00000103oool500000080oooo1`0000040?ooo`<000001P3oool5
000000D0oooo0P0000020?ooo`d0dLfY3@3oool500000080oooo100000030?ooo`H000001@3oool2
000000D0oooo0P0000020?ooo`L000000P3oool700000080oooo100000050?ooo`8000000P3oool2
000000D0oooo0P00000=0=7=Z@@0oooo0P0000050?ooo`800000103oool700000080oooo0P00000C
0?ooo`8000001`3oool400000080oooo0P0000030?ooo`@00000103oool2000000L0oooo1000000@
0=7=Z@003P3AcJT2000000<0oooo0P0000070?ooo`<000001`3oool500000080oooo4@0000090?oo
o`D000000P3oool3000000@0oooo1@00000:0?ooo`8000003@3AcJT2000000<0oooo2@0000050?oo
o`@000000`3oool4000000<0oooo0P00000:0?ooo`8000001@3oool4000000<0oooo1`0000070?oo
o`8000000P3oool500000080oooo1@00000=0=7=Z@/000002@3oool9000000D0oooo100000050?oo
o`/000001@3oool400000080oooo0`0000090?ooo`T000000P3oool=0=7=Z@d0oooo1@0000020?oo
o`@000000`3oool6000000D0oooo0P0000050?ooo`8000000P3oool700000080oooo1`0000020?oo
o`@000001@3oool200000080oooo0P0000050?ooo`8000003@3AcJT40?ooo`8000001@3oool20000
00@0oooo1`0000020?ooo`8000004`3oool2000000L0oooo100000020?ooo`8000000`3oool40000
00@0oooo0P0000070?ooo`@00000403AcJT000h0dLfY0P0000030?ooo`8000001`3oool3000000L0
oooo1@0000020?oooa4000002@3oool500000080oooo0`0000040?ooo`D000002P3oool2000000d0
dLfY0P0000030?ooo`T000001@3oool4000000<0oooo100000030?ooo`8000002P3oool2000000D0
oooo100000030?ooo`L000001`3oool200000080oooo1@0000020?ooo`D000003@3AcJT;000000T0
oooo2@0000050?ooo`@000001@3oool;000000D0oooo100000020?ooo`<000002@3oool900000080
oooo3@3AcJT200000080oooo0`0000040?ooo`8000000`3oool4000000L0oooo1P0000030?ooo`@0
00001@3oool200000080oooo100000030?ooo`@000000P3oool500000080oooo0P0000020?ooo`D0
00000P3oool2000000L0oooo3@3AcJT9000000P0oooo0P0000020?ooo`L000000P3oool2000000D0
oooo300000050?ooo`8000000P3oool2000001<0oooo1`0000020?oooa00dLfY000>0=7=Z@L0oooo
1`00000:0?ooo`L00000303oool9000000D0oooo1@0000020?ooo`D000001`3oool5000000L0oooo
3@3AcJT500000080oooo3P0000050?ooo`@000000`3oool9000000D0oooo3P0000090?ooo`<00000
0P3oool700000080oooo1@00000=0=7=Z@/000002@3oool9000000D0oooo100000050?ooo`/00000
1@3oool400000080oooo0`0000090?ooo`T000000P3oool=0=7=Z@8000000P3oool3000000@0oooo
0P0000030?ooo`@000001`3oool6000000<0oooo100000050?ooo`8000000P3oool4000000<0oooo
100000020?ooo`D000000P3oool200000080oooo1@0000020?ooo`8000001`3oool=0=7=Z@T00000
203oool200000080oooo1`0000020?ooo`8000001@3oool<000000D0oooo0P0000020?ooo`800000
4`3oool700000080oooo403AcJT000h0dLfY1`3oool7000000X0oooo1`00000<0?ooo`T000001@3o
ool500000080oooo1@0000070?ooo`D000001`3oool=0=7=Z@D000000P3oool>000000D0oooo1000
00030?ooo`T000001@3oool>000000T0oooo0`0000020?ooo`L000000P3oool5000000d0dLfY0P00
00050?ooo`@000001@3oool2000000/0oooo0`0000090?ooo`800000103oool300000080oooo1000
00030?ooo`800000103oool3000000@0oooo0P0000030?ooo`L000000P3oool2000000d0dLfY0P3o
ool2000000<0oooo100000050?ooo`8000000P3oool2000000T0oooo0P0000030?ooo`800000103o
ool700000080oooo1@0000020?ooo`@000001@3oool;00000080oooo1@0000020?ooo`8000003@3A
cJT400000080oooo1@0000080?ooo`8000000`3oool200000080oooo1P0000050?ooo`H00000103o
ool300000080oooo2P00000=0?ooo`T000000P3oool@0=7=Z@003P3AcJT2000000<0oooo0P000003
0?ooo`@000003`3oool2000000`0oooo1@0000020?ooo`8000000`3oool700000080oooo0`000009
0?ooo``000003@3AcJT500000080oooo3P0000050?ooo`@000000`3oool9000000D0oooo3P000009
0?ooo`<000000P3oool700000080oooo1@00000=0=7=Z@8000001@3oool4000000D0oooo0P00000;
0?ooo`<000002@3oool2000000@0oooo0`0000020?ooo`@000000`3oool2000000@0oooo0`000004
0?ooo`8000000`3oool700000080oooo0P00000=0=7=Z@80oooo0P0000030?ooo`@000001@3oool2
00000080oooo0P0000090?ooo`8000000`3oool2000000@0oooo1`0000020?ooo`D000000P3oool4
000000D0oooo2`0000020?ooo`D000000P3oool2000000d0dLfY100000020?ooo`D00000203oool2
000000<0oooo0P0000020?ooo`H000001@3oool6000000@0oooo0`0000020?ooo`X000003@3oool9
00000080oooo403AcJT000h0dLfY0P0000030?ooo`8000000`3oool4000000l0oooo0P00000<0?oo
o`D000000P3oool2000000<0oooo1`0000020?ooo`<000002@3oool<000000d0dLfY1@0000020?oo
o`L000000P3oool5000000D0oooo100000050?ooo`8000001@3oool<00000080oooo0`0000020?oo
o`D00000103oool300000080oooo0P0000030?ooo`8000001@3oool2000000d0dLfY1@3oool20000
0080oooo0P0000030?ooo`8000001`3oool2000000@0oooo0`00000;0?ooo`8000003P3oool40000
0080oooo0`0000040?ooo`8000000`3oool2000000T0oooo3@3AcJT200000080oooo1`00000=0?oo
o`L000000P3oool@000000@0oooo0`0000020?ooo`8000000P3oool700000080oooo1`0000040?oo
o`<00000103oool=0=7=Z@80oooo0P0000050?ooo`@000000P3oool900000080oooo0P0000020?oo
o`@000003@3oool2000000<0oooo100000060?ooo`L000000P3oool200000080oooo100000030?oo
o`@000000P3oool@0=7=Z@003P3AcJT2000000<0oooo0P0000030?ooo`@000003`3oool2000000`0
oooo1@0000020?ooo`8000000`3oool700000080oooo0`0000090?ooo``000003@3AcJT500000080
oooo1`0000020?ooo`D000001@3oool4000000D0oooo0P0000050?ooo``000000P3oool300000080
oooo1@0000040?ooo`<000000P3oool2000000<0oooo0P0000050?ooo`8000003@3AcJT50?ooo`80
00000P3oool2000000<0oooo0P0000070?ooo`800000103oool3000000/0oooo0P00000>0?ooo`@0
00000P3oool3000000@0oooo0P0000030?ooo`8000002@3oool=0=7=Z@8000000P3oool7000000d0
oooo1`0000020?oooa000000103oool300000080oooo0P0000020?ooo`L000000P3oool7000000@0
oooo0`0000040?ooo`d0dLfY0P3oool2000000D0oooo100000020?ooo`T000000P3oool200000080
oooo1000000=0?ooo`8000000`3oool4000000H0oooo1`0000020?ooo`8000000P3oool4000000<0
oooo100000020?oooa00dLfY000>0=7=Z@80oooo200000020?ooo`8000001@3oool500000080oooo
0`0000020?ooo`L000001`3oool3000000L0oooo0P0000020?ooo`<000001@3oool7000000D0oooo
100000030?ooo`8000003@3AcJT20?ooo`D000001@3oool4000000L0oooo0`0000020?ooo`800000
0`3oool200000080oooo0`0000020?ooo`L000003P3oool300000080oooo0P0000070?ooo`L00000
0`3oool2000000d0dLfY1@0000020?ooo`d000001`3oool2000000<0oooo0P0000020?ooo`D00000
103oool7000000T0oooo0P0000020?ooo`<00000103oool5000000L0oooo1000000=0=7=Z@80oooo
1`0000020?ooo`8000000`3oool2000000@0oooo1@0000040?ooo`L000003@3oool2000000<0oooo
0P0000020?ooo`D000000P3oool200000100oooo1000000=0=7=Z@8000000P3oool9000000d0oooo
100000020?ooo`L000001P3oool4000000<0oooo2P0000020?ooo`L000000P3oool4000000D0oooo
0P0000040?oooa00dLfY000>0=7=Z@80oooo200000020?ooo`8000001@3oool500000080oooo0`00
00020?ooo`L000001`3oool3000000L0oooo0P0000020?ooo`<000001@3oool7000000D0oooo1000
00030?ooo`8000003@3AcJT20?ooo`D000001@3oool4000000L0oooo0`0000020?ooo`8000000`3o
ool200000080oooo0`0000020?ooo`L000003P3oool300000080oooo0P0000070?ooo`L000000`3o
ool2000000d0dLfY1@0000020?ooo`d000001`3oool2000000<0oooo0P0000020?ooo`D00000103o
ool7000000T0oooo0P0000020?ooo`<00000103oool5000000L0oooo1000000=0=7=Z@80oooo1`00
00020?ooo`8000000`3oool2000000@0oooo1@0000040?ooo`L000003@3oool2000000<0oooo0P00
00020?ooo`D000000P3oool200000100oooo1000000=0=7=Z@8000000P3oool9000000d0oooo1000
00020?ooo`L000001P3oool4000000<0oooo2P0000020?ooo`L000000P3oool4000000D0oooo0P00
00040?oooa00dLfY000>0=7=Z@8000000`3oool5000000@0oooo1@0000020?ooo`<000000P3oool3
00000080oooo2@0000030?ooo`L000001@3oool2000000D0oooo0P0000050?ooo`D000001@3oool2
00000080oooo1@00000=0=7=Z@80oooo2P0000070?ooo`8000000P3oool3000000L0oooo2@000007
0?ooo`X000000P3oool5000000/0oooo1@0000050?ooo`8000003@3AcJT500000080oooo2@000002
0?ooo`/000004P3oool3000000d0oooo0P0000090?ooo`L000000`3oool4000000d0dLfY0P3oool7
00000080oooo0P0000030?ooo`800000103oool5000000@0oooo1`00000=0?ooo`8000000`3oool2
00000080oooo1@0000020?ooo`800000403oool4000000d0dLfY0P0000020?ooo`T000003@3oool4
00000080oooo1`0000060?ooo`@000000`3oool:00000080oooo1`0000020?ooo`@000001@3oool2
000000@0oooo403AcJT000h0dLfY0P0000030?ooo`D00000103oool500000080oooo0`0000020?oo
o`<000000P3oool9000000<0oooo1`0000050?ooo`8000001@3oool2000000D0oooo1@0000050?oo
o`8000000P3oool5000000d0dLfY0P3oool:000000L0oooo0P0000020?ooo`<000001`3oool90000
00L0oooo2P0000020?ooo`D000002`3oool5000000D0oooo0P00000=0=7=Z@D000000P3oool90000
0080oooo2`00000B0?ooo`<000003@3oool2000000T0oooo1`0000030?ooo`@000003@3AcJT20?oo
o`D000000P3oool2000000T0oooo100000030?ooo`8000000P3oool2000000<0oooo100000020?oo
o`<000000P3oool900000080oooo3`0000030?ooo`@000001@3oool200000080oooo3@3AcJT20000
0080oooo2`0000060?ooo`<000000P3oool200000080oooo0P0000020?ooo`<00000103oool40000
00@0oooo1`0000020?ooo`800000103oool5000000H0oooo2@0000020?ooo`800000403AcJT000h0
dLfY0P0000030?ooo`D00000103oool500000080oooo0`0000020?ooo`<000000P3oool9000000<0
oooo1`0000050?ooo`8000001@3oool2000000D0oooo1@0000050?ooo`8000000P3oool5000000d0
dLfY0P3oool:000000L0oooo0P0000020?ooo`<000001`3oool9000000L0oooo2P0000020?ooo`D0
00002`3oool5000000D0oooo0P00000=0=7=Z@D000000P3oool900000080oooo2`00000B0?ooo`<0
00003@3oool2000000T0oooo1`0000030?ooo`@000003@3AcJT20?ooo`D000000P3oool2000000T0
oooo100000030?ooo`8000000P3oool2000000<0oooo100000020?ooo`<000000P3oool900000080
oooo3`0000030?ooo`@000001@3oool200000080oooo3@3AcJT200000080oooo2`0000060?ooo`<0
00000P3oool200000080oooo0P0000020?ooo`<00000103oool4000000@0oooo1`0000020?ooo`80
0000103oool5000000H0oooo2@0000020?ooo`800000403AcJT000h0dLfY0P3oool<000000D0oooo
1@0000070?ooo`L000000P3oool8000000T0oooo300000020?ooo`D000000`3oool700000080oooo
3@3AcJT2000000D0oooo1`0000020?ooo`<000002`3oool3000000T0oooo2P0000020?ooo`D00000
2`3oool300000080oooo2@0000050?ooo`d0dLfY1@0000040?ooo`8000000`3oool200000080oooo
1`0000040?ooo`<000000P3oool200000080oooo0`0000040?ooo`D000000P3oool4000000<0oooo
0P0000020?ooo`D000000P3oool200000080oooo1@0000050?ooo`8000000P3oool=0=7=Z@800000
1@3oool200000080oooo0P0000030?ooo`P000000`3oool900000080oooo100000030?ooo`@00000
0P3oool500000080oooo0P0000050?ooo`8000001P3oool7000000D0oooo1000000=0=7=Z@H00000
0`3oool400000080oooo0P00000A0?ooo`D000000P3oool4000000L0oooo100000020?ooo`H00000
2@3oool2000000T0oooo0P0000020?oooa00dLfY000>0=7=Z@80oooo300000050?ooo`D000001`3o
ool700000080oooo200000090?ooo``000000P3oool5000000<0oooo1`0000020?ooo`d0dLfY0P00
00050?ooo`L000000P3oool3000000/0oooo0`0000090?ooo`X000000P3oool5000000/0oooo0`00
00020?ooo`T000001@3oool=0=7=Z@D00000103oool2000000<0oooo0P0000020?ooo`L00000103o
ool300000080oooo0P0000020?ooo`<00000103oool500000080oooo100000030?ooo`8000000P3o
ool500000080oooo0P0000020?ooo`D000001@3oool200000080oooo3@3AcJT2000000D0oooo0P00
00020?ooo`8000000`3oool8000000<0oooo2@0000020?ooo`@000000`3oool400000080oooo1@00
00020?ooo`8000001@3oool2000000H0oooo1`0000050?ooo`@000003@3AcJT6000000<0oooo1000
00020?ooo`8000004@3oool500000080oooo100000070?ooo`@000000P3oool6000000T0oooo0P00
00090?ooo`8000000P3oool@0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0
dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>
0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3A
cJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0
dLfY000>0=7=Z@P0oooo1P0000050?ooo`<000002`3oool600000080oooo1P0000030?ooo`D00000
2`3oool3000000D0oooo1P0000080?ooo`d0dLfY1@3oool3000000H0oooo600000020?ooo`/00000
0`3oool8000000P0oooo1P0000050?ooo`<000001@3oool=0=7=Z@<0oooo3@0000070?ooo`<00000
0P3oool3000000D0oooo1@0000060?ooo`8000009`3oool=0=7=Z@<000000P3oool300000080oooo
1@0000050?ooo`d000000`3oool2000000<0oooo1`0000030?ooo`8000008@3oool3000000d0dLfY
0P3oool300000080oooo3@0000040?ooo`<00000?@3oool@0=7=Z@003P3AcJT80?ooo`H000001@3o
ool3000000/0oooo1P0000020?ooo`H000000`3oool5000000/0oooo0`0000050?ooo`H00000203o
ool=0=7=Z@D0oooo0`0000060?oooaP000000P3oool;000000<0oooo200000080?ooo`H000001@3o
ool3000000D0oooo3@3AcJT30?ooo`d000001`3oool300000080oooo0`0000050?ooo`D000001P3o
ool2000002L0oooo3@3AcJT300000080oooo0`0000020?ooo`D000001@3oool=000000<0oooo0P00
00030?ooo`L000000`3oool200000240oooo0`00000=0=7=Z@80oooo0`0000020?ooo`d00000103o
ool3000003d0oooo403AcJT000h0dLfY203oool6000000D0oooo0`00000;0?ooo`H000000P3oool6
000000<0oooo1@00000;0?ooo`<000001@3oool6000000P0oooo3@3AcJT50?ooo`<000001P3ooolH
00000080oooo2`0000030?ooo`P00000203oool6000000D0oooo0`0000050?ooo`d0dLfY0`3oool=
000000L0oooo0`0000020?ooo`<000001@3oool5000000H0oooo0P00000W0?ooo`d0dLfY0`000002
0?ooo`<000000P3oool5000000D0oooo3@0000030?ooo`8000000`3oool7000000<0oooo0P00000Q
0?ooo`<000003@3AcJT<000000<0oooo0P0000050?ooo``000004@3oool5000000<0oooo1@000002
0?ooo`8000001@3oool300000080oooo0`0000070?oooa00dLfY000>0=7=Z@<000001@3oool30000
00<0oooo0`0000050?ooo`<000000`3oool2000001`0oooo0`0000020?ooo`<000001P3oool20000
00<0oooo0`0000050?ooo`<000003@3AcJT3000000D0oooo1P0000080?ooo`8000000`3oool80000
00<0oooo3@0000060?ooo`D000001@3oool6000000<0oooo1@0000030?ooo`8000000`3oool=0=7=
Z@D0oooo0`0000050?ooo`<000000P3oool300000080oooo0`0000020?ooo`H000000P3oool30000
0080oooo0`0000030?ooo`L000001P3oool500000080oooo1@0000060?ooo`D000000P3oool30000
00d0dLfY1@0000080?ooo`800000203oool200000100oooo0P0000030?ooo`D000001@3oool30000
01@0oooo0P0000080?ooo`d0dLfY300000030?ooo`8000001@3oool<00000140oooo1@0000030?oo
o`D000000P3oool2000000D0oooo0`0000020?ooo`<000001`3oool@0=7=Z@003P3AcJT3000000D0
oooo0`0000030?ooo`<000001@3oool3000000<0oooo0P00000L0?ooo`<000000P3oool3000000H0
oooo0P0000030?ooo`<000001@3oool3000000d0dLfY0`0000050?ooo`H00000203oool2000000<0
oooo200000030?ooo`d000001P3oool5000000D0oooo1P0000030?ooo`D000000`3oool2000000<0
oooo3@3AcJT50?ooo`<000001@3oool300000080oooo0`0000020?ooo`<000000P3oool600000080
oooo0`0000020?ooo`<000000`3oool7000000H0oooo1@0000020?ooo`D000001P3oool500000080
oooo0`00000=0=7=Z@D00000203oool2000000P0oooo0P00000@0?ooo`8000000`3oool5000000D0
oooo0`00000D0?ooo`800000203oool=0=7=Z@`000000`3oool2000000D0oooo3000000A0?ooo`D0
00000`3oool500000080oooo0P0000050?ooo`<000000P3oool3000000L0oooo403AcJT000h0dLfY
0`0000050?ooo`<000000`3oool3000000D0oooo0`0000030?ooo`800000703oool300000080oooo
0`0000060?ooo`8000000`3oool3000000D0oooo0`00000=0=7=Z@<000001@3oool8000000H0oooo
200000020?ooo`H000000P3oool3000000H0oooo0P0000060?ooo`D000000`3oool5000000/0oooo
0`0000020?ooo`<000003@3AcJT300000080oooo1@0000080?ooo`<000001`3oool8000000D0oooo
1P0000020?ooo`<000001@3oool300000080oooo2000000:0?ooo`<000001@3oool=0=7=Z@<0oooo
0P0000080?ooo`D000000P3oool5000000<0oooo1@0000080?ooo`800000203oool2000000<0oooo
0`0000020?ooo`<000001`3oool300000080oooo0`0000070?ooo`<000003@3AcJT2000000X0oooo
1@0000070?ooo`D000000`3ooolK00000080oooo1@0000020?ooo`<000000P3oool?00000100dLfY
000>0=7=Z@<0oooo0`0000020?ooo`<000001P3oool500000140oooo0P0000060?ooo`<00000403o
ool6000000D0oooo0`0000030?ooo`8000000`3oool=0=7=Z@<000001@3oool8000000H0oooo2000
00020?ooo`H000000P3oool3000000H0oooo0P0000060?ooo`D000000`3oool5000000/0oooo0`00
00020?ooo`<000003@3AcJT300000080oooo1@0000080?ooo`<000001`3oool8000000D0oooo1P00
00020?ooo`<000001@3oool300000080oooo2000000:0?ooo`<000001@3oool=0=7=Z@<0oooo0P00
00080?ooo`D000000P3oool5000000<0oooo1@0000080?ooo`800000203oool2000000<0oooo0`00
00020?ooo`<000001`3oool300000080oooo0`0000070?ooo`<000003@3AcJT2000000X0oooo1@00
00070?ooo`D000000`3ooolK00000080oooo1@0000020?ooo`<000000P3oool?00000100dLfY000>
0=7=Z@<0oooo0`0000020?ooo`<000001P3oool500000140oooo0P0000060?ooo`<00000403oool6
000000D0oooo0`0000030?ooo`8000000`3oool=0=7=Z@<000001@3oool8000000H0oooo20000002
0?ooo`H000000P3oool3000000H0oooo0P0000060?ooo`D000000`3oool5000000/0oooo0`000002
0?ooo`<000003@3AcJT300000080oooo1@0000080?ooo`<000001`3oool8000000D0oooo1P000002
0?ooo`<000001@3oool300000080oooo2000000:0?ooo`<000001@3oool=0=7=Z@<0oooo0P000008
0?ooo`D000000P3oool5000000<0oooo1@0000080?ooo`800000203oool2000000<0oooo0`000002
0?ooo`<000001`3oool300000080oooo0`0000070?ooo`<000003@3AcJT5000000L0oooo0`000009
0?ooo`D000000`3oool5000000L0oooo300000080?ooo`@000000`3oool:00000080oooo0`000002
0?oooa00dLfY000>0=7=Z@H0oooo200000050?ooo`<000001P3oool2000000H0oooo400000060?oo
o`<000001@3oool3000000D0oooo2@0000050?ooo`d0dLfY0`0000020?ooo`h000000`3oool20000
00P0oooo1P0000020?ooo`<000001P3oool2000000<0oooo1@0000030?ooo`<00000203oool80000
00<0oooo0P0000030?ooo`d0dLfY0`3oool=00000080oooo0`0000020?ooo`<000000P3oool30000
00P0oooo200000020?ooo`<000001@3oool3000000D0oooo1@0000020?ooo`H000001`3oool30000
00d0dLfY0`3oool5000000D0oooo0P00000:0?ooo`<00000203oool2000000<0oooo1@0000050?oo
o`8000000`3oool5000000P0oooo2P00000:0?ooo`d0dLfY1@0000070?ooo`<000002@3oool50000
00<0oooo1@0000070?ooo``00000203oool4000000<0oooo2P0000020?ooo`<000000P3oool@0=7=
Z@003P3AcJT60?ooo`P000001@3oool3000000H0oooo0P0000060?oooa0000001P3oool3000000D0
oooo0`0000050?ooo`T000001@3oool=0=7=Z@<000000P3oool>000000<0oooo0P0000080?ooo`H0
00000P3oool3000000H0oooo0P0000030?ooo`D000000`3oool3000000P0oooo200000030?ooo`80
00000`3oool=0=7=Z@<0oooo3@0000020?ooo`<000000P3oool300000080oooo0`0000080?ooo`P0
00000P3oool3000000D0oooo0`0000050?ooo`D000000P3oool6000000L0oooo0`00000=0=7=Z@<0
oooo1@0000050?ooo`8000002P3oool3000000P0oooo0P0000030?ooo`D000001@3oool2000000<0
oooo1@0000080?ooo`X000002P3oool=0=7=Z@D000001`3oool3000000T0oooo1@0000030?ooo`D0
00001`3oool<000000P0oooo100000030?ooo`X000000P3oool300000080oooo403AcJT000h0dLfY
1P3oool8000000D0oooo0`0000060?ooo`8000001P3oool@000000H0oooo0`0000050?ooo`<00000
1@3oool9000000D0oooo3@3AcJT300000080oooo3P0000030?ooo`800000203oool600000080oooo
0`0000060?ooo`8000000`3oool5000000<0oooo0`0000080?ooo`P000000`3oool2000000<0oooo
3@3AcJT50?ooo`D000001P3oool:00000080oooo0`0000030?ooo`8000001@3oool=000000<0oooo
0`0000020?ooo`X000000`3oool800000080oooo0`00000=0=7=Z@<000000P3oool3000000D0oooo
1@00000:0?ooo`D000001@3oool3000000L0oooo0`0000080?ooo`L000000`3oool2000000D0oooo
3@00000=0=7=Z@X000001@3oool700000080oooo3@0000020?ooo`<00000103oool3000000D0oooo
0P00000:0?ooo`D000000P3oool3000000D0oooo1`00000@0=7=Z@003P3AcJT3000000/0oooo1@00
000>0?ooo`H000002`3oool5000000h0oooo1@00000;0?ooo`<000003@3AcJT8000000<0oooo1@00
000;0?ooo`<000000P3oool3000000<0oooo0P0000090?ooo`P00000203oool2000000T0oooo1@00
00030?ooo`8000000`3oool=0=7=Z@D0oooo1@0000060?ooo`X000000P3oool3000000<0oooo0P00
00050?ooo`d000000`3oool300000080oooo2P0000030?ooo`P000000P3oool3000000d0dLfY0`00
00020?ooo`<000001@3oool5000000X0oooo1@0000050?ooo`<000001`3oool3000000P0oooo1`00
00030?ooo`8000001@3oool=000000d0dLfY2P0000050?ooo`L000000P3oool=00000080oooo0`00
00040?ooo`<000001@3oool2000000X0oooo1@0000020?ooo`<000001@3oool700000100dLfY000>
0=7=Z@<000002`3oool5000000h0oooo1P00000;0?ooo`D000003P3oool5000000/0oooo0`00000=
0=7=Z@P000000`3oool5000000/0oooo0`0000020?ooo`<000000`3oool2000000T0oooo20000008
0?ooo`8000002@3oool5000000<0oooo0P0000030?ooo`d0dLfY1@3oool5000000H0oooo2P000002
0?ooo`<000000`3oool2000000D0oooo3@0000030?ooo`<000000P3oool:000000<0oooo20000002
0?ooo`<000003@3AcJT300000080oooo0`0000050?ooo`D000002P3oool5000000D0oooo0`000007
0?ooo`<00000203oool7000000<0oooo0P0000050?ooo`d000003@3AcJT2000000D0oooo1@000003
0?ooo`8000001`3oool300000080oooo4@0000030?ooo`8000000`3oool2000000D0oooo0`000002
0?ooo`D000001@3oool2000000<0oooo1@0000020?oooa00dLfY000>0=7=Z@<000002`3oool50000
00h0oooo1P00000;0?ooo`D000003P3oool5000000/0oooo0`00000=0=7=Z@<0oooo0P00000>0?oo
o`P000001@3oool3000000P0oooo0`0000080?ooo`<000000P3oool6000000P0oooo0`0000020?oo
o`<000001@3oool3000000d0dLfY203oool=00000080oooo0`00000:0?ooo`<000000P3oool80000
00<0oooo3`0000050?ooo`<000000`3oool2000000<0oooo1@00000=0=7=Z@D000000`3oool20000
00P0oooo0P0000030?ooo`X000000`3ooolG00000080oooo0`0000070?ooo`<000000P3oool:0000
00<0oooo3@3AcJT2000000D0oooo1@0000030?ooo`8000001`3oool300000080oooo4@0000030?oo
o`8000000`3oool2000000D0oooo0`0000020?ooo`D000001@3oool2000000<0oooo1@0000020?oo
oa00dLfY000>0=7=Z@<0oooo0`0000020?ooo`<000000`3oool;000000<0oooo1@0000030?ooo`<0
00002`3oool2000000<0oooo1P0000020?ooo`/000000`3oool3000000<0oooo0P0000030?ooo`d0
dLfY0`3oool2000000h0oooo200000050?ooo`<00000203oool3000000P0oooo0`0000020?ooo`H0
0000203oool300000080oooo0`0000050?ooo`<000003@3AcJT80?ooo`d000000P3oool3000000X0
oooo0`0000020?ooo`P000000`3oool?000000D0oooo0`0000030?ooo`8000000`3oool5000000d0
dLfY1@0000030?ooo`800000203oool2000000<0oooo2P0000030?oooaL000000P3oool3000000L0
oooo0`0000020?ooo`X000000`3oool=0=7=Z@8000001@3oool5000000<0oooo0P0000070?ooo`<0
00000P3ooolA000000<0oooo0P0000030?ooo`8000001@3oool300000080oooo1@0000050?ooo`80
00000`3oool500000080oooo403AcJT000h0dLfY0`3oool300000080oooo0`0000030?ooo`/00000
0`3oool5000000<0oooo0`00000;0?ooo`8000000`3oool600000080oooo2`0000030?ooo`<00000
0`3oool2000000<0oooo3@3AcJT30?ooo`8000003P3oool8000000D0oooo0`0000080?ooo`<00000
203oool300000080oooo1P0000080?ooo`<000000P3oool3000000D0oooo0`00000=0=7=Z@P0oooo
3@0000020?ooo`<000002P3oool300000080oooo200000030?ooo`l000001@3oool3000000<0oooo
0P0000030?ooo`D000003@3AcJT=000000D0oooo3`0000030?ooo`8000002P3oool300000080oooo
200000030?ooo`X000001@3oool7000000<0oooo3@3AcJT7000000<0oooo1@0000020?ooo`<00000
103oool3000000L0oooo0`0000020?ooo`<000002@3oool300000080oooo0`0000020?ooo`<00000
2@3oool5000000<0oooo0P0000050?oooa00dLfY000>0=7=Z@<0oooo0`0000020?ooo`<000000`3o
ool;000000<0oooo1@0000030?ooo`<000002`3oool2000000<0oooo1P0000020?ooo`/000000`3o
ool3000000<0oooo0P0000030?ooo`d0dLfY1@3oool;000000P0oooo0`0000050?ooo`H00000203o
ool5000000<0oooo4`00000;0?ooo`D000003@3AcJT5000000/0oooo2P0000020?ooo`P000000`3o
ool2000000H0oooo1@0000020?ooo`<000000`3oool2000000<0oooo2P0000030?ooo`8000001@3o
ool3000000d0dLfY3@0000050?ooo`l000000`3oool2000000X0oooo0`0000020?ooo`P000000`3o
ool:000000D0oooo1`0000030?ooo`d0dLfY1`0000030?ooo`D000000P3oool3000000@0oooo0`00
00070?ooo`<000000P3oool3000000T0oooo0`0000020?ooo`<000000P3oool3000000T0oooo1@00
00030?ooo`8000001@3oool@0=7=Z@003P3AcJT600000080oooo2@0000050?ooo`/000001P3oool2
000000H0oooo0`0000050?ooo`/000001P3oool8000000<0oooo1@00000=0=7=Z@D0oooo2`000008
0?ooo`<000001@3oool6000000P0oooo1@0000030?oooa<000002`3oool5000000d0dLfY1@00000;
0?ooo`X000000P3oool8000000<0oooo0P0000060?ooo`D000000P3oool3000000<0oooo0P000003
0?ooo`X000000`3oool2000000D0oooo0`00000=0=7=Z@d000001@3oool?000000<0oooo0P00000:
0?ooo`<000000P3oool8000000<0oooo2P0000050?ooo`L000000`3oool=0=7=Z@8000000`3oool5
00000080oooo0`0000090?ooo`D000000`3oool2000000<0oooo0P0000030?ooo`8000001`3oool5
000000<0oooo0P0000050?ooo`8000000`3oool2000000<0oooo0P00000:0?oooa00dLfY000>0=7=
Z@H000000P3oool9000000D0oooo2`0000060?ooo`8000001P3oool3000000D0oooo2`0000060?oo
o`P000000`3oool5000000d0dLfY1@3oool;000000P0oooo0`0000050?ooo`H00000203oool50000
00<0oooo4`00000;0?ooo`D000003@3AcJT30?ooo`L000003@3oool300000080oooo2`00000=0?oo
o`8000000`3oool300000080oooo0`0000020?ooo`<000000P3oool600000080oooo0`0000020?oo
o`<000003@3AcJT50?ooo`D000001@3oool300000080oooo200000030?ooo`8000003`3oool30000
00X0oooo1@0000030?ooo`8000000`3oool7000000<0oooo0P0000030?ooo`d0dLfY0P0000030?oo
o`D000000P3oool3000000T0oooo1@0000030?ooo`8000000`3oool2000000<0oooo0P0000070?oo
o`D000000`3oool2000000D0oooo0P0000030?ooo`8000000`3oool2000000X0oooo403AcJT000h0
dLfY0`3oool3000000D0oooo200000060?ooo`P000000`3oool300000080oooo1P0000030?ooo`80
00000`3oool8000000H0oooo200000060?ooo`8000000`3oool=0=7=Z@P0oooo0`00000;0?ooo`D0
0000203oool3000000D0oooo0`0000050?oooaH00000203oool5000000<0oooo3@3AcJT30?ooo`L0
00003@3oool300000080oooo2`00000=0?ooo`8000000`3oool300000080oooo0`0000020?ooo`<0
00000P3oool600000080oooo0`0000020?ooo`<000003@3AcJT50?ooo`D000001@3oool300000080
oooo200000030?ooo`8000003`3oool3000000X0oooo1@0000030?ooo`8000000`3oool7000000<0
oooo0P0000030?ooo`d0dLfY0P0000030?ooo`D000000P3oool3000000T0oooo1@0000030?ooo`80
00000`3oool2000000<0oooo0P0000070?ooo`D000000`3oool2000000D0oooo0P0000030?ooo`80
00000`3oool2000000X0oooo403AcJT000h0dLfY0`3oool3000000D0oooo200000060?ooo`P00000
0`3oool300000080oooo1P0000030?ooo`8000000`3oool8000000H0oooo200000060?ooo`800000
0`3oool=0=7=Z@P0oooo0`00000;0?ooo`D00000203oool3000000D0oooo0`0000050?oooaH00000
203oool5000000<0oooo3@3AcJT30?ooo`L000003@3oool300000080oooo2`00000=0?ooo`800000
0`3oool300000080oooo0`0000020?ooo`<000000P3oool600000080oooo0`0000020?ooo`<00000
3@3AcJT30?ooo`800000203oool5000000D0oooo0P0000030?ooob4000000`3oool2000000P0oooo
1`0000030?ooo`D000003@3AcJT70?ooo`D000001@3oool500000080oooo0`00000:0?ooo`h00000
1@3oool5000000<0oooo0P0000020?ooo`<000001@3oool5000000D0oooo0P00000@0=7=Z@003P3A
cJT30?ooo`<000001@3oool8000000H0oooo200000030?ooo`<000000P3oool6000000<0oooo0P00
00030?ooo`P000001P3oool8000000H0oooo0P0000030?ooo`d0dLfY1@0000060?ooo`D000000`3o
ool5000000<0oooo0`0000020?ooo`<000000`3oool2000000H0oooo0`0000080?ooo`8000001P3o
ool8000000<0oooo0P0000030?ooo`<000001@3oool=0=7=Z@<0oooo1@0000020?ooo`<00000203o
ool500000080oooo200000030?ooo`D000001@3oool3000000D0oooo200000070?ooo`<000001@3o
ool8000000d0dLfY0`3oool2000000P0oooo1@0000050?ooo`8000000`3ooolQ000000<0oooo0P00
00080?ooo`L000000`3oool5000000d0dLfY1`3oool5000000D0oooo1@0000020?ooo`<000002P3o
ool>000000D0oooo1@0000030?ooo`8000000P3oool3000000D0oooo1@0000050?ooo`800000403A
cJT000h0dLfY0`3oool300000080oooo0`0000060?ooo`8000002@3oool;00000080oooo1P000003
0?ooo`/00000203oool3000000D0oooo0`0000030?ooo`8000000`3oool=0=7=Z@D000001P3oool5
000000<0oooo1@0000030?ooo`<000000P3oool3000000<0oooo0P0000060?ooo`<00000203oool2
000000H0oooo200000030?ooo`8000000`3oool3000000D0oooo3@3AcJT30?ooo`D000000P3oool3
000000P0oooo1@0000020?ooo`P000000`3oool5000000D0oooo0`0000050?ooo`P000001`3oool3
000000D0oooo2000000=0=7=Z@<0oooo0P0000080?ooo`D000001@3oool2000000<0oooo8@000003
0?ooo`800000203oool7000000<0oooo1@00000=0=7=Z@8000000`3oool2000000D0oooo20000007
0?ooo`8000001@3oool5000000L0oooo200000020?ooo`<000000P3oool500000080oooo0`000007
0?ooo`<000001`3oool@0=7=Z@003P3AcJT30?ooo`<000000P3oool3000000H0oooo0P0000090?oo
o`/000000P3oool6000000<0oooo2`0000080?ooo`<000001@3oool3000000<0oooo0P0000030?oo
o`d0dLfY1@0000060?ooo`D000000`3oool5000000<0oooo0`0000020?ooo`<000000`3oool20000
00H0oooo0`0000080?ooo`8000001P3oool8000000<0oooo0P0000030?ooo`<000001@3oool=0=7=
Z@<0oooo0P0000050?oooa0000000P3oool3000000<0oooo1@0000050?ooo`D000000`3oool50000
00D0oooo0`0000070?ooo`<000000`3oool2000000<0oooo0P0000030?ooo`d0dLfY2P0000030?oo
o`D000000P3oool300000080oooo3@00000:0?ooo`P000001@3oool=000000D0oooo1@0000020?oo
o`<000003@3AcJT2000000<0oooo0P0000050?ooo`P000001`3oool2000000D0oooo1@0000070?oo
o`P000000P3oool300000080oooo1@0000020?ooo`<000001`3oool3000000L0oooo403AcJT000h0
dLfY0`3oool300000080oooo0`0000060?ooo`8000002@3oool;00000080oooo1P0000030?ooo`/0
0000203oool3000000D0oooo0`0000030?ooo`8000000`3oool=0=7=Z@D000001P3oool3000000D0
oooo1@0000030?ooo`P000001@3oool>000000<0oooo200000020?ooo`T000000P3oool3000000P0
oooo3@3AcJT30?ooo`8000001@3oool@00000080oooo0`0000030?ooo`D000001@3oool5000000<0
oooo1@0000050?ooo`<000001`3oool3000000<0oooo0P0000030?ooo`8000000`3oool=0=7=Z@X0
00000`3oool500000080oooo0`0000020?ooo`d000002P3oool8000000D0oooo3@0000050?ooo`D0
00000P3oool3000000d0dLfY4@3oool3000000@0oooo0`0000050?ooo`800000203oool2000000D0
oooo0P0000050?ooo`P00000103ooolB00000080oooo403AcJT000h0dLfY0`3oool5000000<0oooo
1P0000020?ooo`H000000`3oool5000000<0oooo400000030?ooo`H000000P3oool6000000<0oooo
1@0000030?ooo`D000000`3oool=0=7=Z@D000001P3oool3000000D0oooo1@0000030?ooo`P00000
1@3oool>000000<0oooo200000020?ooo`T000000P3oool3000000P0oooo3@3AcJT30?ooo`800000
1@3oool@00000080oooo0`0000030?ooo`D000001@3oool5000000<0oooo1@0000050?ooo`<00000
1`3oool3000000<0oooo0P0000030?ooo`8000000`3oool=0=7=Z@<0oooo1`0000030?ooo`D00000
0P3oool5000000/0oooo0P0000030?ooo`X000000P3oool600000080oooo0`00000<0?ooo`D00000
203oool=0=7=ZA40oooo0`0000040?ooo`<000001@3oool2000000P0oooo0P0000050?ooo`800000
1@3oool8000000@0oooo4P0000020?oooa00dLfY000>0=7=Z@<0oooo1@0000030?ooo`H000000P3o
ool6000000<0oooo1@0000030?oooa0000000`3oool600000080oooo1P0000030?ooo`D000000`3o
ool5000000<0oooo3@3AcJT5000000H0oooo0`0000050?ooo`D000000`3oool8000000D0oooo3P00
00030?ooo`P000000P3oool900000080oooo0`0000080?ooo`d0dLfY1@3oool300000080oooo0`00
00030?ooo`8000000`3oool7000000P0oooo0`00000=0?ooo`D000000`3oool:00000080oooo2`00
00020?ooo`<000003@3AcJT30?ooo`L000000`3oool500000080oooo1@00000;0?ooo`8000000`3o
ool:00000080oooo1P0000020?ooo`<00000303oool5000000P0oooo3@3AcJTA0?ooo`<00000103o
ool3000000D0oooo0P0000080?ooo`8000001@3oool2000000D0oooo200000040?oooa8000000P3o
ool@0=7=Z@003P3AcJT30?ooo`D000000`3oool600000080oooo1P0000030?ooo`D000000`3oool@
000000<0oooo1P0000020?ooo`H000000`3oool5000000<0oooo1@0000030?ooo`d0dLfY0`000002
0?ooo`<000000`3oool3000000D0oooo200000030?ooo`8000000`3oool300000080oooo1P000003
0?ooo`P000000P3oool600000080oooo2@0000050?ooo`P000003@3AcJT50?ooo`<000000P3oool3
000000<0oooo0P0000030?ooo`L00000203oool3000000d0oooo1@0000030?ooo`X000000P3oool;
00000080oooo0`00000=0=7=Z@<0oooo1`0000030?ooo`D000000P3oool5000000/0oooo0P000003
0?ooo`X000000P3oool600000080oooo0`00000<0?ooo`D00000203oool=0=7=Z@80oooo2P000005
0?ooo`<000001`3oool2000000P0oooo1`00000?0?ooo`8000001@3oool7000000D0oooo20000002
0?oooa00dLfY000>0=7=Z@H0oooo1@0000060?ooo`8000001P3oool3000000/0oooo2`00000;0?oo
o`8000001P3oool3000000D0oooo1P0000050?ooo`d0dLfY0`0000020?ooo`<000000`3oool30000
00D0oooo200000030?ooo`8000000`3oool300000080oooo1P0000030?ooo`P000000P3oool60000
0080oooo2@0000050?ooo`P000003@3AcJT30?ooo`D000003`3oool;00000080oooo1@0000030?oo
o`<000000P3oool5000000P0oooo0`0000050?ooo`D000000`3oool7000000<0oooo3@3AcJT30?oo
o`D000001@3oool2000000D0oooo200000080?ooo`L000000`3oool7000000H0oooo1@0000020?oo
o`d000001@3oool5000000d0dLfY0P3oool:000000D0oooo0`0000070?ooo`800000203oool70000
00l0oooo0P0000050?ooo`L000001@3oool800000080oooo403AcJT000h0dLfY1P3oool5000000H0
oooo0P0000060?ooo`<000002`3oool;000000/0oooo0P0000060?ooo`<000001@3oool6000000D0
oooo3@3AcJT5000000<0oooo200000060?ooo`8000002`3oool8000000<0oooo1@0000060?ooo`80
00000`3oool;000000D0oooo2`00000=0=7=Z@<0oooo1@00000?0?ooo`/000000P3oool5000000<0
oooo0`0000020?ooo`D00000203oool3000000D0oooo1@0000030?ooo`L000000`3oool=0=7=Z@<0
oooo1@0000050?ooo`8000001@3oool8000000P0oooo1`0000030?ooo`L000001P3oool500000080
oooo3@0000050?ooo`D000003@3AcJT20?ooo`<000000P3oool3000000D0oooo1`00000?0?ooo`L0
00001@3oool:00000080oooo0`0000020?ooo`D000000P3oool5000000<0oooo1`00000@0=7=Z@00
3P3AcJT3000000<0oooo1@0000030?ooo`<000000P3oool3000000<0oooo1@0000060?ooo`D00000
1P3oool5000000H0oooo1@0000030?ooo`<000000`3oool2000000<0oooo1P0000020?ooo`<00000
3@3AcJT5000000<0oooo200000060?ooo`8000002`3oool8000000<0oooo1@0000060?ooo`800000
0`3oool;000000D0oooo2`00000=0=7=Z@<0oooo1@00000?0?ooo`/000000P3oool5000000<0oooo
0`0000020?ooo`D00000203oool3000000D0oooo1@0000030?ooo`L000000`3oool=0=7=Z@<00000
2P3oool2000000D0oooo0`00000:0?ooo`X000001@3oool8000000<0oooo0P0000030?ooo`800000
0`3oool5000000D0oooo2P00000=0=7=Z@80oooo0`0000020?ooo`<000001@3oool7000000l0oooo
1`0000050?ooo`X000000P3oool300000080oooo1@0000020?ooo`D000000`3oool700000100dLfY
000>0=7=Z@<000000`3oool5000000<0oooo0`0000020?ooo`<000000`3oool5000000H0oooo1@00
00060?ooo`D000001P3oool5000000<0oooo0`0000030?ooo`8000000`3oool600000080oooo0`00
000=0=7=Z@D000000`3oool8000000H0oooo0P00000;0?ooo`P000000`3oool5000000H0oooo0P00
00030?ooo`/000001@3oool;000000d0dLfY0`0000020?ooo`<000000P3oool3000000P0oooo2P00
00030?ooo`D000001@3oool300000080oooo0`0000020?ooo`<000000`3oool500000080oooo0`00
00020?ooo`<000001@3oool5000000<0oooo3@3AcJT3000000X0oooo0P0000050?ooo`<000002P3o
ool:000000D0oooo200000030?ooo`8000000`3oool2000000<0oooo1@0000050?ooo`X000003@3A
cJT20?ooo`<000000P3oool3000000D0oooo1`00000?0?ooo`L000001@3oool:00000080oooo0`00
00020?ooo`D000000P3oool5000000<0oooo1`00000@0=7=Z@003P3AcJT3000000<0oooo1@000003
0?ooo`<000000P3oool3000000<0oooo1@0000060?ooo`D000001P3oool5000000H0oooo1@000003
0?ooo`<000000`3oool2000000<0oooo1P0000020?ooo`<000003@3AcJT30?ooo`8000001P3oool8
000000<0oooo0P0000030?ooo`<000001@3oool5000000<0oooo0`0000030?ooo`8000000`3oool3
00000080oooo0`0000050?ooo`h000001@3oool3000000d0dLfY0`0000020?ooo`<000000P3oool3
000000P0oooo2P0000030?ooo`D000001@3oool300000080oooo0`0000020?ooo`<000000`3oool5
00000080oooo0`0000020?ooo`<000001@3oool5000000<0oooo3@3AcJT3000000X0oooo0P000005
0?ooo`<000002P3oool:000000D0oooo200000030?ooo`8000000`3oool2000000<0oooo1@000005
0?ooo`X000003@3AcJT2000000<0oooo0P0000030?ooo`800000203oool2000000D0oooo1@000005
0?ooo`8000001@3oool500000080oooo0`0000020?ooo`<000001@3oool4000000<0oooo0P000003
0?ooo`X000000P3oool@0=7=Z@003P3AcJT3000000P0oooo0`0000080?ooo`P000000`3oool80000
00H0oooo200000030?ooo`P00000203oool3000000P0oooo0`00000=0=7=Z@<0oooo0P0000060?oo
o`P000000`3oool2000000<0oooo0`0000050?ooo`D000000`3oool3000000<0oooo0P0000030?oo
o`<000000P3oool3000000D0oooo3P0000050?ooo`<000003@3AcJT300000080oooo0`0000020?oo
o`<00000203oool:000000<0oooo1@0000050?ooo`<000000P3oool300000080oooo0`0000030?oo
o`D000000P3oool300000080oooo0`0000050?ooo`D000000`3oool=0=7=Z@<0oooo0P0000050?oo
o`d000000P3oool6000000L0oooo1@0000030?ooo`8000000`3oool2000000d0oooo0`00000:0?oo
o`L000000`3oool=0=7=Z@8000000`3oool2000000<0oooo0P0000080?ooo`8000001@3oool50000
00D0oooo0P0000050?ooo`D000000P3oool300000080oooo0`0000050?ooo`@000000`3oool20000
00<0oooo2P0000020?oooa00dLfY000>0=7=Z@<00000203oool3000000P0oooo200000030?ooo`P0
00001P3oool8000000<0oooo200000080?ooo`<00000203oool3000000d0dLfY0`3oool2000000H0
oooo200000030?ooo`8000000`3oool3000000D0oooo1@0000030?ooo`<000000`3oool2000000<0
oooo0`0000020?ooo`<000001@3oool>000000D0oooo0`00000=0=7=Z@D000000`3oool2000000H0
oooo1@0000020?ooo`<000000P3oool8000000D0oooo0`0000030?ooo`D000001@3oool5000000<0
oooo0P0000050?ooo`H000002P3oool=0=7=Z@<0oooo0P0000050?ooo`d000000P3oool6000000L0
oooo1@0000030?ooo`8000000`3oool2000000d0oooo0`00000:0?ooo`L000000`3oool=0=7=Z@D0
oooo0P0000050?ooo`X000001@3oool2000000<0oooo1`0000030?ooo`@000000`3oool500000080
oooo0`0000020?ooo`<000000P3oool:00000080oooo1@0000030?ooo`800000403AcJT000h0dLfY
0`0000080?ooo`<00000203oool8000000<0oooo200000060?ooo`P000000`3oool8000000P0oooo
0`0000080?ooo`<000003@3AcJT3000000D0oooo4000000>0?ooo`D000000`3oool300000080oooo
0`0000050?ooo`H000000P3oool3000000H0oooo0P00000;0?ooo`d0dLfY1@0000030?ooo`800000
1P3oool500000080oooo0`0000020?ooo`P000001@3oool3000000<0oooo1@0000050?ooo`D00000
0`3oool2000000D0oooo1P00000:0?ooo`d0dLfY0`3oool:00000080oooo8@0000080?ooo`P00000
1@3oool500000080oooo0`0000020?ooo`D000000`3oool=0=7=Z@D0oooo0P0000050?ooo`X00000
1@3oool2000000<0oooo1`0000030?ooo`@000000`3oool500000080oooo0`0000020?ooo`<00000
0P3oool:00000080oooo1@0000030?ooo`800000403AcJT000h0dLfY0`3oool3000000d0oooo2`00
000L0?ooo`/000003P3oool2000000<0oooo3@3AcJT3000000D0oooo4000000>0?ooo`D000000`3o
ool300000080oooo0`0000050?ooo`H000000P3oool3000000H0oooo0P00000;0?ooo`d0dLfY1@3o
ool5000000<0oooo1@0000050?ooo`D000000`3oool800000080oooo1P00000=0?ooo`8000001@3o
ool3000000P0oooo0P0000030?ooo`8000000`3oool=0=7=Z@<0oooo2P0000020?ooob400000203o
ool8000000D0oooo1@0000020?ooo`<000000P3oool5000000<0oooo3@3AcJT50?ooo`8000001@3o
ool:000000D0oooo0P0000030?ooo`L000000`3oool4000000<0oooo1@0000020?ooo`<000000P3o
ool300000080oooo2P0000020?ooo`D000000`3oool200000100dLfY000>0=7=Z@<0oooo0`00000=
0?ooo`/00000703oool;000000h0oooo0P0000030?ooo`d0dLfY1@3oool900000080oooo2000000;
0?ooo`<000000P3oool;000000<0oooo2`0000050?ooo`<000000`3oool=000000d0dLfY1@3oool5
000000<0oooo1@0000050?ooo`D000000`3oool800000080oooo1P00000=0?ooo`8000001@3oool3
000000P0oooo0P0000030?ooo`8000000`3oool=0=7=Z@<0oooo2P0000020?ooob400000203oool8
000000D0oooo1@0000020?ooo`<000000P3oool5000000<0oooo3@3AcJT500000080oooo20000002
0?ooo`<000002@3oool300000080oooo200000020?ooo`8000000`3oool7000000X0oooo0P000008
0?ooo`8000000`3oool700000100dLfY000>0=7=Z@<0oooo0`00000=0?ooo`/00000703oool;0000
00h0oooo0P0000030?ooo`d0dLfY1@3oool900000080oooo2000000;0?ooo`<000000P3oool;0000
00<0oooo2`0000050?ooo`<000000`3oool=000000d0dLfY1@3oool5000000<0oooo1@0000050?oo
o`D000000`3oool800000080oooo1P00000=0?ooo`8000001@3oool3000000P0oooo0P0000030?oo
o`8000000`3oool=0=7=Z@<000002P3oool2000000<0oooo1@00000=0?ooo`D000000P3oool30000
0080oooo1@00000;0?oooa4000001@3oool3000000d0dLfY1@0000020?ooo`P000000P3oool30000
00T0oooo0`0000020?ooo`P000000P3oool2000000<0oooo1`00000:0?ooo`800000203oool20000
00<0oooo1`00000@0=7=Z@003P3AcJT80?ooo`<000000`3oool8000000h0oooo1@0000060?ooo`D0
00003P3oool8000000<0oooo0`0000080?ooo`d0dLfY1@3oool900000080oooo2000000;0?ooo`<0
00000P3oool;000000<0oooo2`0000050?ooo`<000000`3oool=000000d0dLfY0`3oool2000000<0
oooo0P0000030?ooo`<000000P3oool5000000<0oooo2000000?0?ooo`<000000P3oool600000080
oooo1@0000030?ooo`8000000`3oool5000000P0oooo3@3AcJT3000000X0oooo0P0000030?ooo`D0
00003@3oool500000080oooo0`0000020?ooo`D000002`3ooolA000000D0oooo0`00000=0=7=Z@D0
oooo0P0000050?ooo`P000003P3oool3000000T0oooo0`0000020?ooo`<000000P3oool5000000D0
oooo0P0000030?ooo`8000000`3oool<00000100dLfY000>0=7=Z@P0oooo0`0000030?ooo`P00000
3P3oool5000000H0oooo1@00000>0?ooo`P000000`3oool3000000P0oooo3@3AcJT3000000D0oooo
1P0000050?ooo`<000001@3oool5000000<0oooo4`0000030?ooo`8000000`3oool5000000<0oooo
0`00000;0?ooo`D000003@3AcJT30?ooo`8000000`3oool2000000<0oooo0`0000020?ooo`D00000
0`3oool8000000l0oooo0`0000020?ooo`H000000P3oool5000000<0oooo0P0000030?ooo`D00000
203oool=0=7=Z@<000000P3oool3000000L0oooo0`00000?0?ooo`<000001@3oool:00000080oooo
200000030?ooo`8000000`3oool7000000X0oooo0`00000=0=7=Z@D0oooo0P0000050?ooo`P00000
3P3oool3000000T0oooo0`0000020?ooo`<000000P3oool5000000D0oooo0P0000030?ooo`800000
0`3oool<00000100dLfY000>0=7=Z@<0oooo0`0000020?ooo`T000003@3oool6000000<0oooo2`00
00020?ooo`H000003P3oool8000000<0oooo0P0000030?ooo`d0dLfY0`0000050?ooo`H000001@3o
ool3000000D0oooo1@0000030?oooa<000000`3oool2000000<0oooo1@0000030?ooo`<000002`3o
ool5000000d0dLfY0`0000050?ooo`P00000303oool3000000D0oooo0`00000L0?ooo`<00000203o
ool2000000<0oooo1@00000=0=7=Z@<000000P3oool3000000L0oooo0`00000?0?ooo`<000001@3o
ool:00000080oooo200000030?ooo`8000000`3oool7000000X0oooo0`00000=0=7=Z@D0oooo0P00
00050?ooo`P000003P3oool3000000T0oooo0`0000020?ooo`<000000P3oool5000000D0oooo0P00
00030?ooo`8000000`3oool<00000100dLfY000>0=7=Z@<0oooo0`0000020?ooo`T000003@3oool6
000000<0oooo2`0000020?ooo`H000003P3oool8000000<0oooo0P0000030?ooo`d0dLfY0`000005
0?ooo`H000001@3oool3000000D0oooo1@0000030?oooa<000000`3oool2000000<0oooo1@000003
0?ooo`<000002`3oool5000000d0dLfY0`0000050?ooo`P00000303oool3000000D0oooo0`00000L
0?ooo`<00000203oool2000000<0oooo1@00000=0=7=Z@<000000P3oool3000000L0oooo0`00000?
0?ooo`<000001@3oool:00000080oooo200000030?ooo`8000000`3oool7000000X0oooo0`00000=
0=7=Z@L000000`3oool2000000P0oooo100000050?ooo`P000000P3oool300000080oooo0P000005
0?oooa/000001@3oool500000100dLfY000>0=7=Z@<0oooo0`0000020?ooo`T000003@3oool60000
00<0oooo2`0000020?ooo`H000003P3oool8000000<0oooo0P0000030?ooo`d0dLfY200000030?oo
o`<00000203oool2000000<0oooo0`0000050?ooo`<000001@3oool8000000<0oooo0`0000020?oo
o`H000000P3oool3000000<0oooo0`0000080?ooo`D000003@3AcJT3000000D0oooo2000000<0?oo
o`<000001@3oool3000001`0oooo0`0000080?ooo`8000000`3oool5000000d0dLfY1@0000030?oo
o`X000001`3oool3000000P0oooo0P0000050?ooo`<000001@3oool2000000P0oooo1@0000050?oo
o`X000001@3oool3000000d0dLfY1`0000030?ooo`800000203oool4000000D0oooo200000020?oo
o`<000000P3oool2000000D0oooo6`0000050?ooo`D00000403AcJT000h0dLfY1P3oool2000000<0
oooo1P0000020?ooo`H00000403oool600000100oooo1P0000030?ooo`D000000`3oool3000000D0
oooo3@3AcJT8000000<0oooo0`0000080?ooo`8000000`3oool3000000D0oooo0`0000050?ooo`P0
00000`3oool300000080oooo1P0000020?ooo`<000000`3oool3000000P0oooo1@00000=0=7=Z@P0
oooo0P0000030?ooo`D000000`3oool2000000<0oooo1@0000050?ooo`<000000P3oool6000000d0
oooo0P0000030?ooo`L000000`3oool5000000<0oooo0P0000030?ooo`d0dLfY1@0000030?ooo`X0
00001`3oool3000000P0oooo0P0000050?ooo`<000001@3oool2000000P0oooo1@0000050?ooo`X0
00001@3oool3000000d0dLfY1@3oool2000000D0oooo1@0000030?ooo`8000001@3oool5000000L0
oooo1@00000<0?ooo`D000000`3oool4000000P0oooo0P0000030?ooo`L00000403AcJT000h0dLfY
1P3oool2000000<0oooo1P0000020?ooo`H00000403oool600000100oooo1P0000030?ooo`D00000
0`3oool3000000D0oooo3@3AcJT30?ooo`D000000`3oool5000000/0oooo0`0000020?ooo`<00000
0`3oool5000000<0oooo200000030?ooo`P000003@3oool;000000d0dLfY203oool2000000<0oooo
1@0000030?ooo`8000000`3oool5000000D0oooo0`0000020?ooo`H000003@3oool2000000<0oooo
1`0000030?ooo`D000000`3oool2000000<0oooo3@3AcJT3000000D0oooo0P0000050?ooo`D00000
2`3oool2000000D0oooo2P0000050?ooo`<000000`3oool2000000P0oooo1`0000050?ooo`<00000
0P3oool3000000d0dLfY1@3oool2000000D0oooo1@0000030?ooo`8000001@3oool5000000L0oooo
1@00000<0?ooo`D000000`3oool4000000P0oooo0P0000030?ooo`L00000403AcJT000h0dLfY1P3o
ool2000000<0oooo1P0000020?ooo`H00000403oool600000100oooo1P0000030?ooo`D000000`3o
ool3000000D0oooo3@3AcJT30?ooo`D000000`3oool5000000/0oooo0`0000020?ooo`<000000`3o
ool5000000<0oooo200000030?ooo`P000003@3oool;000000d0dLfY203oool2000000<0oooo1@00
00030?ooo`8000000`3oool5000000D0oooo0`0000020?ooo`H000003@3oool2000000<0oooo1`00
00030?ooo`D000000`3oool2000000<0oooo3@3AcJT3000000D0oooo0P0000050?ooo`D000002`3o
ool2000000D0oooo2P0000050?ooo`<000000`3oool2000000P0oooo1`0000050?ooo`<000000P3o
ool3000000d0dLfY1@0000020?ooo`<000000P3oool8000000L0oooo0P0000050?ooo``00000203o
ool7000000<0oooo100000030?ooo`8000000`3oool500000080oooo1@00000@0=7=Z@003P3AcJT3
0?ooo`D000000`3oool3000000h0oooo200000030?ooo`/000000P3oool9000000d0oooo0`000003
0?ooo`D000000`3oool=0=7=Z@<0oooo1@0000030?ooo`D000002`3oool300000080oooo0`000003
0?ooo`D000000`3oool8000000<0oooo2000000=0?ooo`/000003@3AcJT=0?ooo`<000000P3oool3
000000D0oooo200000050?ooo`8000001P3oool500000080oooo1P0000020?ooo`<000001@3oool2
000000<0oooo0`0000050?ooo`8000000`3oool=0=7=Z@<000001@3oool2000000D0oooo1@00000;
0?ooo`8000001@3oool:000000D0oooo0`0000030?ooo`800000203oool7000000D0oooo0`000002
0?ooo`<000003@3AcJT500000080oooo0`0000020?ooo`P000001`3oool2000000D0oooo30000008
0?ooo`L000000`3oool4000000<0oooo0P0000030?ooo`D000000P3oool500000100dLfY000>0=7=
Z@<0oooo1@0000030?ooo`<000003P3oool8000000<0oooo2`0000020?ooo`T000003@3oool30000
00<0oooo1@0000030?ooo`d0dLfY2`3oool3000000X0oooo0`00000;0?ooo`D000000`3oool30000
0080oooo200000060?ooo`8000002@3oool2000000H0oooo0P0000030?ooo`d0dLfY3@3oool30000
0080oooo0`0000050?ooo`P000001@3oool2000000H0oooo1@0000020?ooo`H000000P3oool30000
00D0oooo0P0000030?ooo`<000001@3oool2000000<0oooo3@3AcJT800000080oooo0`0000020?oo
o`<000000P3oool3000000D0oooo0`0000050?ooo`8000001@3oool3000000X0oooo2P00000=0?oo
o`X000003@3AcJT500000080oooo0`0000020?ooo`P000001`3oool2000000D0oooo300000080?oo
o`L000000`3oool4000000<0oooo0P0000030?ooo`D000000P3oool500000100dLfY000>0=7=Z@<0
oooo1@0000030?ooo`<000003P3oool8000000<0oooo2`0000020?ooo`T000003@3oool3000000<0
oooo1@0000030?ooo`d0dLfY2`3oool3000000X0oooo0`00000;0?ooo`D000000`3oool300000080
oooo200000060?ooo`8000002@3oool2000000H0oooo0P0000030?ooo`d0dLfY0`0000050?ooo`80
0000203oool300000080oooo0`0000020?ooo`<000000`3oool5000000l0oooo1P00000:0?ooo`D0
00000`3oool:000000d0dLfY200000020?ooo`<000000P3oool300000080oooo0`0000050?ooo`<0
00001@3oool2000000D0oooo0`00000:0?ooo`X000003@3oool:000000d0dLfY1@0000050?ooo`80
0000303ooolD00000080oooo1@0000050?ooo`D000000`3oool2000000L0oooo1@0000030?ooo`80
00001@3oool@0=7=Z@003P3AcJT8000000<0oooo200000030?ooo`<000001@3oool6000000<0oooo
0P0000060?ooo`<000000P3oool6000000D0oooo0`0000030?ooo`P000000`3oool8000000d0dLfY
2`3oool3000000X0oooo0`00000;0?ooo`D000000`3oool300000080oooo200000060?ooo`800000
2@3oool2000000H0oooo0P0000030?ooo`d0dLfY0`0000050?ooo`800000203oool300000080oooo
0`0000020?ooo`<000000`3oool5000000l0oooo1P00000:0?ooo`D000000`3oool:000000d0dLfY
203oool2000000<0oooo1@0000020?ooo`<000000P3oool3000000d0oooo1`0000030?ooo`800000
0`3oool3000000l0oooo1`0000080?ooo`d0dLfY1@0000050?ooo`800000303ooolD00000080oooo
1@0000050?ooo`D000000`3oool2000000L0oooo1@0000030?ooo`8000001@3oool@0=7=Z@003P3A
cJT8000000<0oooo200000030?ooo`<000001@3oool6000000<0oooo0P0000060?ooo`<000000P3o
ool6000000D0oooo0`0000030?ooo`P000000`3oool8000000d0dLfY2`0000030?ooo`D000000`3o
ool@000000D0oooo200000030?ooo`P000001@3oool6000000D0oooo1P0000020?ooo`<000003@3A
cJT3000000D0oooo0P0000080?ooo`<000000P3oool300000080oooo0`0000030?ooo`D000003`3o
ool6000000X0oooo1@0000030?ooo`X000003@3AcJT80?ooo`8000000`3oool500000080oooo0`00
00020?ooo`<000003@3oool7000000<0oooo0P0000030?ooo`<000003`3oool7000000P0oooo3@3A
cJT2000000X0oooo3`0000020?ooo`<000000P3oool5000000L0oooo0`0000020?ooo`D000000`3o
ool2000000<0oooo0P0000020?ooo`<000001@3oool5000000L0oooo403AcJT000h0dLfY0`000005
0?ooo`H00000203oool3000000P0oooo0`0000050?ooo`H000001@3oool3000000P0oooo0`000008
0?ooo`H000001@3oool3000000d0dLfY2`0000030?ooo`D000000`3oool@000000D0oooo20000003
0?ooo`P000001@3oool6000000D0oooo1P0000020?ooo`<000003@3AcJT5000000D0oooo0`000003
0?ooo`L000000`3oool2000000<0oooo0`0000020?ooo`<000001@3oool5000000<0oooo0P000008
0?ooo`<000001`3oool3000000<0oooo0P0000080?ooo`d0dLfY203oool2000000<0oooo1@000002
0?ooo`<000000P3oool3000000d0oooo1`0000030?ooo`8000000`3oool3000000l0oooo1`000008
0?ooo`d0dLfY0P00000:0?ooo`l000000P3oool300000080oooo1@0000070?ooo`<000000P3oool5
000000<0oooo0P0000030?ooo`8000000P3oool3000000D0oooo1@0000070?oooa00dLfY000>0=7=
Z@<000001@3oool6000000P0oooo0`0000080?ooo`<000001@3oool6000000D0oooo0`0000080?oo
o`<00000203oool6000000D0oooo0`00000=0=7=Z@<000000P3oool3000000H0oooo1@0000080?oo
o`<000000P3oool600000080oooo0`00000C0?ooo`D000000`3ooolC000000d0dLfY1@0000050?oo
o`<000000`3oool7000000<0oooo0P0000030?ooo`<000000P3oool3000000D0oooo1@0000030?oo
o`800000203oool3000000L0oooo0`0000030?ooo`800000203oool=0=7=Z@<000000P3oool50000
00<0oooo0P0000030?ooo`D000001@3oool8000000X0oooo1@0000020?ooo`H000000P3oool30000
00D0oooo0P0000050?ooo`D000001@3oool3000000d0dLfY0P00000:0?ooo`l000000P3oool30000
0080oooo1@0000070?ooo`<000000P3oool5000000<0oooo0P0000030?ooo`8000000P3oool30000
00D0oooo1@0000070?oooa00dLfY000>0=7=Z@<000001@3oool6000000P0oooo0`0000080?ooo`<0
00001@3oool6000000D0oooo0`0000080?ooo`<00000203oool6000000D0oooo0`00000=0=7=Z@<0
00000P3oool3000000H0oooo1@0000080?ooo`<000000P3oool600000080oooo0`00000C0?ooo`D0
00000`3ooolC000000d0dLfY0`3ooolB00000080oooo1@0000060?ooo`X000000`3oool500000080
oooo3@0000030?ooo`8000001P3oool500000080oooo0`00000=0=7=Z@<000000P3oool5000000<0
oooo0P0000030?ooo`D000001@3oool8000000X0oooo1@0000020?ooo`H000000P3oool3000000D0
oooo0P0000050?ooo`D000001@3oool3000000d0dLfY0P0000050?ooo`D000001@3oool300000080
oooo1@0000020?ooo`<000000P3oool300000080oooo0`0000020?ooo`L000002P3oool7000000<0
oooo0P0000030?ooo`X000000P3oool@0=7=Z@003P3AcJT60?ooo`d000000`3oool300000100oooo
1P00000@0?ooo`<000000`3oool>000000D0oooo3@3AcJT300000080oooo0`0000060?ooo`D00000
203oool300000080oooo1P0000020?ooo`<000004`3oool5000000<0oooo4`00000=0=7=Z@<0oooo
4P0000020?ooo`D000001P3oool:000000<0oooo1@0000020?ooo`d000000`3oool2000000H0oooo
1@0000020?ooo`<000003@3AcJT50?ooo`P000001`3oool300000080oooo1P0000020?ooo`<00000
2P3oool:000000<0oooo1`0000030?oooa4000000`3oool=0=7=Z@8000001@3oool5000000D0oooo
0`0000020?ooo`D000000P3oool300000080oooo0`0000020?ooo`<000000P3oool7000000X0oooo
1`0000030?ooo`8000000`3oool:00000080oooo403AcJT000h0dLfY1P3oool=000000<0oooo0`00
000@0?ooo`H00000403oool3000000<0oooo3P0000050?ooo`d0dLfY0`3oool2000000H0oooo0`00
00080?ooo`8000001P3oool2000000<0oooo0`0000080?ooo`<000002P3oool6000001<0oooo1@00
000=0=7=Z@<0oooo4P0000020?ooo`D000001P3oool:000000<0oooo1@0000020?ooo`d000000`3o
ool2000000H0oooo1@0000020?ooo`<000003@3AcJT50?ooo`P000001`3oool300000080oooo1P00
00020?ooo`<000002P3oool:000000<0oooo1`0000030?oooa4000000`3oool=0=7=Z@D0oooo1`00
000:0?ooo`8000001@3oool800000080oooo0`0000020?ooo`8000000`3oool2000000<0oooo0P00
00030?ooo`D000000P3oool2000000d0oooo1@0000020?oooa00dLfY000>0=7=Z@H0oooo3@000003
0?ooo`<00000403oool600000100oooo0`0000030?ooo`h000001@3oool=0=7=Z@<0oooo0P000006
0?ooo`<00000203oool2000000H0oooo0P0000030?ooo`<00000203oool3000000X0oooo1P00000C
0?ooo`D000003@3AcJT30?ooo`8000001@3oool6000000D0oooo1@0000050?ooo`<000000P3oool3
000000D0oooo2P0000030?ooo`X000000`3oool2000000<0oooo1@0000030?ooo`8000000`3oool=
0=7=Z@D0oooo200000070?ooo`<000000P3oool600000080oooo0`00000:0?ooo`X000000`3oool7
000000<0oooo4@0000030?ooo`d0dLfY1@3oool7000000X0oooo0P0000050?ooo`P000000P3oool3
00000080oooo0P0000030?ooo`8000000`3oool2000000<0oooo1@0000020?ooo`8000003@3oool5
00000080oooo403AcJT000h0dLfY203oool9000000D0oooo0`0000050?ooo`T000000P3oool60000
00<0oooo200000050?ooo`<000001P3oool8000000P0oooo3@3AcJT30?ooo`8000001P3oool30000
00P0oooo0P0000060?ooo`8000000`3oool3000000P0oooo0`00000:0?ooo`H000004`3oool50000
00d0dLfY0`3oool2000000D0oooo1P0000050?ooo`D000001@3oool300000080oooo0`0000050?oo
o`X000000`3oool:000000<0oooo0P0000030?ooo`D000000`3oool2000000<0oooo3@3AcJT50000
00<0oooo1@0000020?ooo`<000001@3oool8000001T0oooo0`0000050?ooo`8000000`3oool50000
0080oooo200000050?ooo`d0dLfY1@3oool7000000X0oooo0P0000050?ooo`P000000P3oool30000
0080oooo0P0000030?ooo`8000000`3oool2000000<0oooo1@0000020?ooo`8000003@3oool50000
0080oooo403AcJT000h0dLfY203oool9000000D0oooo0`0000050?ooo`T000000P3oool6000000<0
oooo200000050?ooo`<000001P3oool8000000P0oooo3@3AcJT;0?ooo`P00000203oool300000080
oooo1P0000020?ooo`T000001@3oool3000000D0oooo1@0000090?ooo`8000000`3oool8000000d0
dLfY0`3oool2000000D0oooo1P0000050?ooo`D000001@3oool300000080oooo0`0000050?ooo`X0
00000`3oool:000000<0oooo0P0000030?ooo`D000000`3oool2000000<0oooo3@3AcJT5000000<0
oooo1@0000020?ooo`<000001@3oool8000001T0oooo0`0000050?ooo`8000000`3oool500000080
oooo200000050?ooo`d0dLfY0P3oool?000000D0oooo0P0000030?ooo`800000203oool2000000l0
oooo1`0000050?ooo`8000000`3oool:000000D0oooo0P00000@0=7=Z@003P3AcJT80?ooo`T00000
1@3oool3000000D0oooo2@0000020?ooo`H000000`3oool8000000D0oooo0`0000060?ooo`P00000
203oool=0=7=Z@/0oooo200000080?ooo`<000000P3oool600000080oooo2@0000050?ooo`<00000
1@3oool5000000T0oooo0P0000030?ooo`P000003@3AcJT30?ooo`L000000`3oool5000000<0oooo
1@0000020?ooo`<000000`3oool5000000l0oooo1P0000020?ooo`P000002P3oool8000000d0dLfY
0`0000020?ooo`<000000P3oool3000000L0oooo0`0000020?ooo`<000003@3oool7000000D0oooo
200000030?ooo`8000001@3oool5000000<0oooo2P00000=0=7=Z@80oooo3`0000050?ooo`800000
0`3oool2000000P0oooo0P00000?0?ooo`L000001@3oool2000000<0oooo2P0000050?ooo`800000
403AcJT000h0dLfY2`3oool8000000<0oooo0`0000080?ooo`<000000`3oool;00000080oooo0`00
00080?ooo`<000000`3oool8000000/0oooo3@3AcJT30?ooo`8000002@3oool2000000H0oooo1@00
00080?ooo`D000004`3oool3000000D0oooo2@0000050?ooo`<000000P3oool3000000d0dLfY0`3o
ool7000000<0oooo1@0000030?ooo`D000000P3oool3000000<0oooo1@00000?0?ooo`H000000P3o
ool8000000X0oooo2000000=0=7=Z@<000000P3oool300000080oooo0`0000070?ooo`<000000P3o
ool3000000d0oooo1`0000050?ooo`P000000`3oool2000000D0oooo1@0000030?ooo`X000003@3A
cJT2000000D0oooo0`0000050?ooo`L000000P3oool5000000<0oooo0P0000080?ooo`@000002P3o
ool300000080oooo1`00000:0?ooo`<000000P3oool500000100dLfY000>0=7=Z@/0oooo20000003
0?ooo`<00000203oool3000000<0oooo2`0000020?ooo`<00000203oool3000000<0oooo2000000;
0?ooo`d0dLfY0`3oool2000000T0oooo0P0000060?ooo`D00000203oool5000001<0oooo0`000005
0?ooo`T000001@3oool300000080oooo0`00000=0=7=Z@D000002`3oool2000000d0oooo1@000008
0?ooo`X000000`3oool3000000D0oooo1@0000050?ooo`D000000`3oool5000000d0dLfY0`000002
0?ooo`<000000P3oool3000000L0oooo0`0000020?ooo`<000003@3oool7000000D0oooo20000003
0?ooo`8000001@3oool5000000<0oooo2P00000=0=7=Z@8000001@3oool3000000D0oooo1`000002
0?ooo`D000000`3oool2000000P0oooo1000000:0?ooo`<000000P3oool7000000X0oooo0`000002
0?ooo`D00000403AcJT000h0dLfY0`3oool8000000<0oooo0`00000@0?ooo`H000002`3oool50000
0140oooo0P0000030?ooo`P000000`3oool=0=7=Z@<0oooo0P0000090?ooo`8000001P3oool50000
00P0oooo1@00000C0?ooo`<000001@3oool9000000D0oooo0`0000020?ooo`<000003@3AcJT50000
00/0oooo0P00000=0?ooo`D00000203oool:000000<0oooo0`0000050?ooo`D000001@3oool50000
00<0oooo1@00000=0=7=Z@P0oooo500000030?ooo`D000001@3oool500000080oooo200000050?oo
o`<000000P3oool:000000D0oooo1@0000030?ooo`d0dLfY0P0000050?ooo`<000001@3oool70000
0080oooo1@0000030?ooo`800000203oool4000000X0oooo0`0000020?ooo`L000002P3oool30000
0080oooo1@00000@0=7=Z@003P3AcJT30?ooo`P000000`3oool300000100oooo1P00000;0?ooo`D0
00004@3oool2000000<0oooo200000030?ooo`d0dLfY0`3oool8000000D0oooo0`0000030?ooo`D0
00000`3oool2000000<0oooo0`0000050?ooo`<000000`3ooolE000000<0oooo0`0000020?ooo`/0
00003@3AcJT5000000/0oooo0P00000=0?ooo`D00000203oool:000000<0oooo0`0000050?ooo`D0
00001@3oool5000000<0oooo1@00000=0=7=Z@P0oooo500000030?ooo`D000001@3oool500000080
oooo200000050?ooo`<000000P3oool:000000D0oooo1@0000030?ooo`d0dLfY1`0000050?ooo`<0
00001`3oool7000000P0oooo1`0000020?ooo`<000001@3oool2000000<0oooo1@0000020?ooo`X0
00000P3oool300000080oooo0`0000020?oooa00dLfY000>0=7=Z@<0oooo200000030?ooo`<00000
403oool6000000/0oooo1@00000A0?ooo`8000000`3oool8000000<0oooo3@3AcJT30?ooo`P00000
1@3oool3000000<0oooo1@0000030?ooo`8000000`3oool3000000D0oooo0`0000030?oooaD00000
0`3oool300000080oooo2`00000=0=7=Z@<0oooo0P0000030?ooo`l000001@3oool6000000X0oooo
2P0000030?ooo`D000001@3oool5000000H0oooo0P0000030?ooo`D000003@3AcJT300000080oooo
0`0000050?ooo`L000000`3oool5000000D0oooo0`0000020?ooo`X000003@3oool5000000<0oooo
0P0000030?ooo`D000000P3oool5000000<0oooo3@3AcJT7000000D0oooo0`0000070?ooo`L00000
203oool700000080oooo0`0000050?ooo`8000000`3oool500000080oooo2P0000020?ooo`<00000
0P3oool300000080oooo403AcJT000h0dLfY200000030?ooo`P000002@3oool2000000T0oooo0P00
00060?ooo`<00000203oool3000000P0oooo200000030?ooo`P000003@3AcJT30?ooo`P000001@3o
ool3000000<0oooo1@0000030?ooo`8000000`3oool3000000D0oooo0`0000030?oooaD000000`3o
ool300000080oooo2`00000=0=7=Z@<0oooo0P0000030?ooo`l000001@3oool6000000X0oooo2P00
00030?ooo`D000001@3oool5000000H0oooo0P0000030?ooo`D000003@3AcJT300000080oooo0`00
00050?ooo`L000000`3oool5000000D0oooo0`0000020?ooo`X000003@3oool5000000<0oooo0P00
00030?ooo`D000000P3oool5000000<0oooo3@3AcJT2000000<0oooo0P0000030?ooo`D000001`3o
ool5000000D0oooo0P0000080?ooo`@000000`3oool5000000D0oooo0P0000030?ooo`@000000`3o
ool2000000<0oooo3000000@0=7=Z@003P3AcJT8000000<0oooo200000090?ooo`8000002@3oool2
000000H0oooo0`0000080?ooo`<00000203oool8000000<0oooo2000000=0=7=Z@D000003P3oool3
000001P0oooo200000050?ooo`P000001P3oool3000000X0oooo0`00000=0=7=Z@<0oooo0P000008
0?ooo`P000000P3oool5000000<0oooo4P0000030?ooo`8000001P3oool5000000D0oooo0P000003
0?ooo`D000001@3oool3000000d0dLfY0`0000020?ooo`<000001@3oool7000000<0oooo1@000005
0?ooo`<000000P3oool:000000d0oooo1@0000030?ooo`8000000`3oool500000080oooo1@000003
0?ooo`d0dLfY0P0000030?ooo`8000000`3oool5000000L0oooo1@0000050?ooo`800000203oool4
000000<0oooo1@0000050?ooo`8000000`3oool4000000<0oooo0P0000030?ooo``00000403AcJT0
00h0dLfY200000030?ooo`P000002@3oool2000000T0oooo0P0000060?ooo`<00000203oool30000
00P0oooo200000030?ooo`P000003@3AcJT5000000h0oooo0`00000H0?ooo`P000001@3oool80000
00H0oooo0`00000:0?ooo`<000003@3AcJT30?ooo`800000203oool800000080oooo1@0000030?oo
oa8000000`3oool2000000H0oooo1@0000050?ooo`8000000`3oool5000000D0oooo0`00000=0=7=
Z@<0oooo300000030?ooo`X000000`3oool5000000X0oooo1@00000:0?ooo`<000001`3oool30000
0080oooo1@0000080?ooo`d0dLfY1`3oool3000000`0oooo0P0000050?ooo`<000000P3oool30000
0080oooo2P0000050?ooo`D000001`3oool2000000<0oooo0P0000030?ooo`D000001@3oool20000
0100dLfY000>0=7=Z@<0oooo3P00000C0?ooo`<000002`3oool2000001@0oooo3@0000030?ooo`d0
dLfY200000030?ooo`<000000P3oool3000000<0oooo0P0000030?ooo`<000000P3oool6000000/0
oooo2000000E0?ooo`<000001@3oool3000000d0dLfY0`3oool2000000P0oooo200000020?ooo`D0
00000`3ooolB000000<0oooo0P0000060?ooo`D000001@3oool2000000<0oooo1@0000050?ooo`<0
00003@3AcJT30?ooo``000000`3oool:000000<0oooo1@00000:0?ooo`D000002P3oool3000000L0
oooo0`0000020?ooo`D00000203oool=0=7=Z@L0oooo0`00000<0?ooo`8000001@3oool300000080
oooo0`0000020?ooo`X000001@3oool5000000L0oooo0P0000030?ooo`8000000`3oool5000000D0
oooo0P00000@0=7=Z@003P3AcJT30?ooo`h000004`3oool3000000/0oooo0P00000D0?ooo`d00000
0`3oool=0=7=Z@P000000`3oool300000080oooo0`0000030?ooo`8000000`3oool300000080oooo
1P00000;0?ooo`P000005@3oool3000000D0oooo0`00000=0=7=Z@<0oooo3`0000030?ooo`800000
1@3oool8000000d0oooo0`0000020?ooo`<000000`3oool7000000<0oooo0P0000030?ooo`<00000
0P3oool3000000D0oooo3@3AcJT3000000X0oooo1`0000030?ooo`8000000`3oool300000140oooo
0`00000:0?ooo`D000000`3oool2000000<0oooo1@0000020?ooo`D000000`3oool=0=7=Z@L0oooo
0`00000<0?ooo`8000001@3oool300000080oooo0`0000020?ooo`X000001@3oool5000000L0oooo
0P0000030?ooo`8000000`3oool5000000D0oooo0P00000@0=7=Z@003P3AcJT30?ooo`h000004`3o
ool3000000/0oooo0P00000D0?ooo`d000000`3oool=0=7=Z@P000000`3oool300000080oooo0`00
00030?ooo`8000000`3oool300000080oooo1P00000;0?ooo`P000005@3oool3000000D0oooo0`00
000=0=7=Z@<0oooo3`0000030?ooo`8000001@3oool8000000d0oooo0`0000020?ooo`<000000`3o
ool7000000<0oooo0P0000030?ooo`<000000P3oool3000000D0oooo3@3AcJT3000000X0oooo1`00
00030?ooo`8000000`3oool300000140oooo0`00000:0?ooo`D000000`3oool2000000<0oooo1@00
00020?ooo`D000000`3oool=0=7=Z@X000000P3oool300000080oooo0`0000040?ooo`<000000P3o
ool8000000T0oooo0`0000050?ooo`X000000P3oool2000000D0oooo0`00000<0?oooa00dLfY000>
0=7=Z@P000000`3oool;000000P0oooo0`0000060?ooo`8000001P3oool3000000D0oooo0`000008
0?ooo`/000000`3oool8000000d0dLfY0`3oool8000000<0oooo0P0000080?ooo`H000000P3oool6
00000080oooo0`0000080?ooo`P000001P3oool2000000<0oooo0`0000030?ooo`P000000P3oool3
000000d0dLfY2P0000030?ooo`<000000P3oool5000000P0oooo1@00000;0?ooo`D000001@3oool5
000000P0oooo3@0000050?ooo`d0dLfY0`00000:0?ooo`L000000`3oool2000000<0oooo0`00000A
0?ooo`<000002P3oool5000000<0oooo0P0000030?ooo`D000000P3oool5000000<0oooo3@3AcJT:
00000080oooo0`0000020?ooo`<00000103oool300000080oooo200000090?ooo`<000001@3oool:
00000080oooo0P0000050?ooo`<00000303oool@0=7=Z@003P3AcJT8000000<0oooo2`0000080?oo
o`<000001P3oool2000000H0oooo0`0000050?ooo`<00000203oool;000000<0oooo2000000=0=7=
Z@<0oooo200000030?ooo`800000203oool600000080oooo1P0000020?ooo`<00000203oool80000
00H0oooo0P0000030?ooo`<000000`3oool800000080oooo0`00000=0=7=Z@X000000`3oool30000
0080oooo1@0000080?ooo`D000002`3oool5000000D0oooo1@0000080?ooo`d000001@3oool=0=7=
Z@<000000P3oool5000000P0oooo0P0000050?ooo`/000001`3oool3000000X0oooo0`0000020?oo
o`<000001`3oool300000080oooo1@0000030?ooo`8000000`3oool=0=7=Z@80oooo1@0000030?oo
o`8000001@3oool300000080oooo0P0000030?ooo`L000000`3oool9000000<0oooo0P0000030?oo
o`X00000103oool5000000X0oooo0`0000020?oooa00dLfY000>0=7=Z@H0oooo0P0000090?ooo`80
00002@3oool8000000<0oooo0P0000060?ooo`<000000P3oool9000000P0oooo0`0000080?ooo`<0
00001@3oool=0=7=Z@<0oooo200000030?ooo`800000203oool600000080oooo1P0000020?ooo`<0
0000203oool8000000H0oooo0P0000030?ooo`<000000`3oool800000080oooo0`00000=0=7=Z@X0
00000`3oool300000080oooo1@0000080?ooo`D000002`3oool5000000D0oooo1@0000080?ooo`d0
00001@3oool=0=7=Z@<000000P3oool5000000P0oooo0P0000050?ooo`/000001`3oool3000000X0
oooo0`0000020?ooo`<000001`3oool300000080oooo1@0000030?ooo`8000000`3oool=0=7=Z@80
oooo1@0000030?ooo`8000001@3oool300000080oooo0P0000030?ooo`L000000`3oool9000000<0
oooo0P0000030?ooo`X00000103oool5000000X0oooo0`0000020?oooa00dLfY000>0=7=Z@H0oooo
0P0000090?ooo`8000002@3oool8000000<0oooo0P0000060?ooo`<000000P3oool9000000P0oooo
0`0000080?ooo`<000001@3oool=0=7=Z@<0oooo0P0000060?ooo`<000000P3oool3000000P0oooo
1@0000060?oooad000000`3oool3000000<0oooo2P0000030?ooo`d0dLfY200000080?ooo`L00000
0`3oool800000080oooo0`0000020?ooo`P000001@3oool8000000<0oooo1`0000030?ooo`<00000
0P3oool5000000<0oooo3@3AcJT50?ooo`X000000`3oool500000080oooo3@00000?0?ooo`<00000
2P3oool8000000D0oooo0P0000080?ooo`d0dLfY0P3oool5000000<0oooo0P0000050?ooo`<00000
0P3oool2000000<0oooo1`0000030?ooo`T000000`3oool2000000<0oooo2P0000040?ooo`D00000
2P3oool300000080oooo403AcJT000h0dLfY1P3oool2000000T0oooo0P0000090?ooo`P000000`3o
ool2000000H0oooo0`0000020?ooo`T00000203oool3000000P0oooo0`0000050?ooo`d0dLfY0`3o
ool2000000H0oooo0`0000020?ooo`<00000203oool5000000H0oooo7@0000030?ooo`<000000`3o
ool:000000<0oooo3@3AcJT8000000P0oooo1`0000030?ooo`P000000P3oool300000080oooo2000
00050?ooo`P000000`3oool7000000<0oooo0`0000020?ooo`D000000`3oool=0=7=Z@D0oooo2P00
00030?ooo`D000000P3oool=000000l0oooo0`00000:0?ooo`P000001@3oool2000000P0oooo3@3A
cJT7000000D0oooo1@0000030?ooo`8000000P3oool5000000<0oooo0P0000080?ooo`8000002P3o
ool:00000080oooo0P0000050?ooo`<000000P3oool3000000L0oooo403AcJT000h0dLfY1P000002
0?ooo`T000000P3oool3000000H0oooo0P0000030?ooo`H000002`3oool5000000<0oooo0`000005
0?ooo`<000000`3oool8000000<0oooo1@00000=0=7=Z@<0oooo0P0000030?ooo`<000000`3oool2
000000H0oooo0P00000;0?ooo`<00000203oool8000000<0oooo0P0000080?ooo`H000001@3oool8
000000<0oooo3@3AcJT8000000P0oooo1`0000030?ooo`P000000P3oool300000080oooo20000005
0?ooo`P000000`3oool7000000<0oooo0`0000020?ooo`D000000`3oool=0=7=Z@D0oooo2P000003
0?ooo`D000000P3oool=000000l0oooo0`00000:0?ooo`P000001@3oool2000000P0oooo3@3AcJT7
000000D0oooo1@0000030?ooo`8000000P3oool5000000<0oooo0P0000080?ooo`8000002P3oool:
00000080oooo0P0000050?ooo`<000000P3oool3000000L0oooo403AcJT000h0dLfY1P0000020?oo
o`T000000P3oool3000000H0oooo0P0000030?ooo`H000002`3oool5000000<0oooo0`0000050?oo
o`<000000`3oool8000000<0oooo1@00000=0=7=Z@<0oooo0P0000030?ooo`<000000`3oool20000
00H0oooo0P00000;0?ooo`<00000203oool8000000<0oooo0P0000080?ooo`H000001@3oool80000
00<0oooo3@3AcJT3000000D0oooo200000020?ooo`<000001@3oool2000000<0oooo2P00000;0?oo
o`D000000`3oool:00000080oooo1P0000020?ooo`D000000`3oool=0=7=Z@D000000`3oool20000
00D0oooo200000050?ooo`<000001@3oool?00000080oooo0`0000080?ooo`8000003@3oool50000
0080oooo0`00000=0=7=Z@8000001@3oool800000080oooo0`0000090?ooo`D000000`3oool70000
0080oooo1@0000050?ooo`D000000`3oool2000001H0oooo403AcJT000h0dLfY1P0000020?ooo`T0
00000P3oool3000000H0oooo0P0000030?ooo`H000002`3oool5000000<0oooo0`0000050?ooo`<0
00000`3oool8000000<0oooo1@00000=0=7=Z@<0oooo0P0000030?ooo`<000000`3oool2000000H0
oooo0P00000;0?ooo`<00000203oool8000000<0oooo0P0000080?ooo`H000001@3oool8000000<0
oooo3@3AcJT3000000D0oooo200000020?ooo`<000001@3oool2000000<0oooo2P00000;0?ooo`D0
00000`3oool:00000080oooo1P0000020?ooo`D000000`3oool=0=7=Z@D000000`3oool2000000D0
oooo200000050?ooo`<000001@3oool?00000080oooo0`0000080?ooo`8000003@3oool500000080
oooo0`00000=0=7=Z@8000001@3oool800000080oooo0`0000090?ooo`D000000`3oool700000080
oooo1@0000050?ooo`D000000`3oool2000001H0oooo403AcJT000h0dLfY0`0000080?ooo`H00000
1@3oool8000000H0oooo0`0000020?ooo`H000000`3oool2000000H0oooo200000060?ooo`D00000
203oool3000000d0dLfY1@3oool3000000H0oooo1@0000030?ooo`800000203oool600000080oooo
1P0000030?ooo`800000203oool3000000P0oooo0`0000030?ooo`D000001@3oool3000000d0dLfY
0`3oool500000080oooo0`0000050?ooo`<000002P3oool3000000D0oooo3`0000080?ooo`P00000
1@3oool=000000d0dLfY1@0000030?ooo`D000001`3oool3000000P0oooo1@0000020?ooo`<00000
1@3oool:000000<0oooo0P00000:0?ooo`X000000`3oool2000000<0oooo3@3AcJT2000000D0oooo
200000020?ooo`<000002@3oool5000000<0oooo1`0000020?ooo`D000001@3oool5000000<0oooo
0P00000F0?oooa00dLfY000>0=7=Z@<00000203oool6000000D0oooo200000060?ooo`<000000P3o
ool6000000<0oooo0P0000060?ooo`P000001P3oool5000000P0oooo0`00000=0=7=Z@D0oooo0`00
00060?ooo`D000000`3oool2000000P0oooo1P0000020?ooo`H000000`3oool2000000P0oooo0`00
00080?ooo`<000000`3oool5000000D0oooo0`00000=0=7=Z@<0oooo1@0000020?ooo`<000001@3o
ool3000000X0oooo0`0000050?ooo`l00000203oool8000000D0oooo3@00000=0=7=Z@D000000`3o
ool5000000L0oooo0`0000080?ooo`D000000P3oool3000000D0oooo2P0000030?ooo`8000002P3o
ool:000000<0oooo0P0000030?ooo`d0dLfY1@3oool:00000080oooo1@0000070?ooo`<00000303o
ool2000000P0oooo1@0000020?ooo`X000000P3oool5000000D0oooo0`0000020?oooa00dLfY000>
0=7=Z@<00000203oool6000000D0oooo200000060?ooo`<000000P3oool6000000<0oooo0P000006
0?ooo`P000001P3oool5000000P0oooo0`00000=0=7=Z@D0oooo0`0000060?ooo`D000000`3oool2
000000P0oooo1P0000020?ooo`H000000`3oool2000000P0oooo0`0000080?ooo`<000000`3oool5
000000D0oooo0`00000=0=7=Z@<0oooo1@0000020?ooo`<000001@3oool3000000X0oooo0`000005
0?ooo`l00000203oool8000000D0oooo3@00000=0=7=Z@D000000`3oool5000000L0oooo0`000008
0?ooo`D000000P3oool3000000D0oooo2P0000030?ooo`8000002P3oool:000000<0oooo0P000003
0?ooo`d0dLfY1@3oool:00000080oooo1@0000070?ooo`<00000303oool2000000P0oooo1@000002
0?ooo`X000000P3oool5000000D0oooo0`0000020?oooa00dLfY000>0=7=Z@H0oooo0P0000060?oo
o`<000001@3oool8000000T0oooo2`0000080?ooo`P000001P3oool2000000H0oooo0`0000050?oo
o`d0dLfY0`3oool2000000<0oooo4`0000030?ooo`8000000`3oool300000080oooo1P0000080?oo
o`D000000`3oool5000000H0oooo1@00000;0?ooo`d0dLfY0`3oool2000000D0oooo200000080?oo
o`P000001@3oool2000000<0oooo0`0000050?ooo`8000005@3oool5000000<0oooo1@00000=0=7=
Z@P000001@3oool2000000D0oooo0`0000020?ooo`<000000`3oool7000000<0oooo3`0000030?oo
o`L000001@3oool:000000P0oooo3@3AcJT50?ooo`8000001@3oool5000000<0oooo100000030?oo
o`D000000P3oool3000000D0oooo0P0000020?ooo`D000001@3oool3000000L0oooo0P0000050?oo
o`<000001`3oool500000100dLfY000>0=7=Z@H0oooo0P0000060?ooo`<000001@3oool8000000T0
oooo2`0000080?ooo`P000001P3oool2000000H0oooo0`0000050?ooo`d0dLfY0`3oool2000000<0
oooo4`0000030?ooo`8000000`3oool300000080oooo1P0000080?ooo`D000000`3oool5000000H0
oooo1@00000;0?ooo`d0dLfY0`3oool2000000D0oooo200000080?ooo`P000001@3oool2000000<0
oooo0`0000050?ooo`8000005@3oool5000000<0oooo1@00000=0=7=Z@P000001@3oool2000000D0
oooo0`0000020?ooo`<000000`3oool7000000<0oooo3`0000030?ooo`L000001@3oool:000000P0
oooo3@3AcJT50?ooo`8000001@3oool5000000<0oooo100000030?ooo`D000000P3oool3000000D0
oooo0P0000020?ooo`D000001@3oool3000000L0oooo0P0000050?ooo`<000001`3oool500000100
dLfY000>0=7=Z@P000001P3oool5000000/0oooo1P0000050?ooo`H000001@3oool6000000/0oooo
1@0000060?ooo`P000003@3AcJT3000000d0oooo1P00000:0?ooo`H000001@3oool600000080oooo
0`0000030?ooo`X000002@3oool:000000<0oooo3@3AcJT30?ooo`8000000`3oool5000000<0oooo
0P0000030?ooo`D000000P3oool3000000<0oooo0P00000=0?ooo`D000002`3oool2000000<0oooo
1@0000050?ooo`<000001@3oool=0=7=Z@D000000`3oool:000000D0oooo1@0000030?ooo`L00000
0`3oool7000000<0oooo1@0000030?ooo`8000001@3oool300000080oooo0`0000050?ooo`X00000
3@3AcJT50?ooo`8000001@3oool5000000<0oooo100000030?ooo`D000000P3oool3000000D0oooo
0P0000020?ooo`D000001@3oool3000000L0oooo0P0000050?ooo`<000001`3oool500000100dLfY
000>0=7=Z@P000001P3oool5000000/0oooo1P0000050?ooo`H000001@3oool6000000/0oooo1@00
00060?ooo`P000003@3AcJT3000000d0oooo1P00000:0?ooo`H000001@3oool600000080oooo0`00
00030?ooo`X000002@3oool:000000<0oooo3@3AcJT30?ooo`8000000`3oool5000000<0oooo0P00
00030?ooo`D000000P3oool3000000<0oooo0P00000=0?ooo`D000002`3oool2000000<0oooo1@00
00050?ooo`<000001@3oool=0=7=Z@D000000`3oool:000000D0oooo1@0000030?ooo`L000000`3o
ool7000000<0oooo1@0000030?ooo`8000001@3oool300000080oooo0`0000050?ooo`X000003@3A
cJT50?ooo`D000001@3oool2000000D0oooo1@0000020?ooo`D00000203oool200000080oooo1@00
00030?ooo`8000000`3oool2000000<0oooo1`00000:0?ooo`D000000P3oool@0=7=Z@003P3AcJT8
000000H0oooo1@00000;0?ooo`H000001@3oool6000000D0oooo1P00000;0?ooo`D000001P3oool8
000000d0dLfY0`00000=0?ooo`H000002P3oool6000000D0oooo1P0000020?ooo`<000000`3oool:
000000T0oooo2P0000030?ooo`d0dLfY0`3oool2000000<0oooo1@0000030?ooo`8000000`3oool5
00000080oooo0`0000030?ooo`8000003@3oool5000000/0oooo0P0000030?ooo`D000001@3oool3
000000D0oooo3@3AcJT5000000<0oooo2P0000050?ooo`D000000`3oool7000000<0oooo1`000003
0?ooo`D000000`3oool2000000D0oooo0`0000020?ooo`<000001@3oool:000000d0dLfY1@3oool5
000000D0oooo0P0000050?ooo`D000000P3oool5000000P0oooo0P0000020?ooo`D000000`3oool2
000000<0oooo0P0000030?ooo`L000002P3oool500000080oooo403AcJT00?l0dLfYo`3AcJT>0=7=
Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo
0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY
003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0
dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@003P3AcJT:000000?ooooo1`00000:ooooo`<000000ooo
ool:000000Oooooo1P00000Nooooo``0dLfY1oooool3000000Wooooo1`000006ooooo`<000001?oo
ool9000000Oooooo3000000Gooooo``0dLfY1P000006ooooo`T000000oooool3000000Cooooo0`00
0003ooooo`<000000oooool3000000Wooooo1P000004ooooo`<000004_ooool3000000`0dLfY3`3o
ool6000000H0oooo1P0000090?ooo`D000000`3oool600000240oooo3@3AcJT60?ooo`P000005`3o
ool8000000T0oooo1P0000050?ooo`H000000`3oool3000000/0oooo403AcJT000h0dLfY2P000003
ooooo`L000002_ooool3000000?ooooo2P000007ooooo`H000007_ooool<0=7=Z@Oooooo0`000009
ooooo`L000001_ooool3000000Cooooo2@000007ooooo``000005oooool<0=7=Z@H000001_ooool9
000000?ooooo0`000004ooooo`<000000oooool3000000?ooooo0`000009ooooo`H000001?ooool3
000001;ooooo0`00000<0=7=Z@l0oooo1P0000060?ooo`H000002@3oool5000000<0oooo1P00000Q
0?ooo`d0dLfY1P3oool8000001L0oooo200000090?ooo`H000001@3oool6000000<0oooo0`00000;
0?oooa00dLfY000>0=7=Z@X000000oooool7000000[ooooo0`000003ooooo`X000001oooool60000
01kooooo303AcJT7ooooo`<000002Oooool7000000Kooooo0`000004ooooo`T000001oooool<0000
01Oooooo303AcJT6000000Kooooo2@000003ooooo`<000001?ooool3000000?ooooo0`000003oooo
o`<000002Oooool6000000Cooooo0`00000Booooo`<00000303AcJT?0?ooo`H000001P3oool60000
00T0oooo1@0000030?ooo`H000008@3oool=0=7=Z@H0oooo2000000G0?ooo`P000002@3oool60000
00D0oooo1P0000030?ooo`<000002`3oool@0=7=Z@003P3AcJT6ooooo`@000002_oooolJ000000Co
oooo0`000003ooooo`<000001?ooool6000000Cooooo3@000003ooooo``0dLfY1`000003ooooo`H0
00001oooool3000000?ooooo1P000007ooooo`<000000oooool3000000Cooooo0`000006ooooo`L0
00002Oooool3000000Cooooo0`00000<0=7=Z@?ooooo0`000009ooooo`<000001_ooool:000000?o
oooo3`000003ooooo`<000000oooool7000001Gooooo303AcJT30?ooo`H000000`3oool6000000<0
oooo0`0000030?ooo``000006P3oool6000000<0oooo0`0000030?ooo`H000000`3oool=0=7=Z@<0
oooo1P0000080?ooo`<00000203oool3000000T0oooo1@0000060?ooo`/00000303oool3000000D0
oooo1P00000@0=7=Z@003P3AcJT6ooooo`@000002_oooolJ000000Cooooo0`000003ooooo`<00000
1?ooool6000000Cooooo3@000003ooooo``0dLfY1`000003ooooo`H000001oooool3000000?ooooo
1P000007ooooo`<000000oooool3000000Cooooo0`000006ooooo`L000002Oooool3000000Cooooo
0`00000<0=7=Z@?ooooo0`000009ooooo`<000001_ooool:000000?ooooo3`000003ooooo`<00000
0oooool7000001Gooooo303AcJT30?ooo`H000000`3oool6000000<0oooo0`0000030?ooo``00000
6P3oool6000000<0oooo0`0000030?ooo`H000000`3oool=0=7=Z@<0oooo1P0000080?ooo`<00000
203oool3000000T0oooo1@0000060?ooo`/00000303oool3000000D0oooo1P00000@0=7=Z@003P3A
cJT6ooooo`@000002_oooolJ000000Cooooo0`000003ooooo`<000001?ooool6000000Cooooo3@00
0003ooooo``0dLfY1`000003ooooo`H000001oooool3000000?ooooo1P000007ooooo`<000000ooo
ool3000000Cooooo0`000006ooooo`L000002Oooool3000000Cooooo0`00000<0=7=Z@?ooooo0`00
0009ooooo`<000001_ooool:000000?ooooo3`000003ooooo`<000000oooool7000001Gooooo303A
cJT30?ooo`H000000`3oool6000000<0oooo0`0000030?ooo``000006P3oool6000000<0oooo0`00
00030?ooo`H000000`3oool=0=7=Z@<0oooo1P0000080?ooo`<00000203oool3000000T0oooo1@00
00060?ooo`/00000303oool3000000D0oooo1P00000@0=7=Z@003P3AcJT6ooooo`@000002_oooolJ
000000Cooooo0`000003ooooo`<000001?ooool6000000Cooooo3@000003ooooo``0dLfY1oooool3
000000Wooooo10000006ooooo`X000002Oooool7000000?ooooo1P000007ooooo`T000000oooool7
000000`0dLfY0`000009ooooo`H000000oooool:000000oooooo1P000009ooooo`@000000ooooolE
000000`0dLfY0`00000<0?ooo`<000001P3oool3000000<0oooo0`0000060?ooo`<000000`3oool;
000000<0oooo0`0000030?ooo`<000001P3oool3000000<0oooo1P0000030?ooo`d0dLfY2`000006
0?ooo`<000000`3ooolA000000D0oooo1P0000060?ooo`<000000P3oool6000000H0oooo0`000003
0?ooo`P00000403AcJT000h0dLfY0`000003ooooo`L000000oooool7000000?ooooo2P000004oooo
o`X000003Oooool6000000Cooooo3@000003ooooo``0dLfY1oooool3000000Wooooo10000006oooo
o`X000002Oooool7000000?ooooo1P000007ooooo`T000000oooool7000000`0dLfY0`000009oooo
o`H000000oooool:000000oooooo1P000009ooooo`@000000ooooolE000000`0dLfY0`00000<0?oo
o`<000001P3oool3000000<0oooo0`0000060?ooo`<000000`3oool;000000<0oooo0`0000030?oo
o`<000001P3oool3000000<0oooo1P0000030?ooo`d0dLfY2`0000060?ooo`<000000`3ooolA0000
00D0oooo1P0000060?ooo`<000000P3oool6000000H0oooo0`0000030?ooo`P00000403AcJT000h0
dLfY0`000003ooooo`L000000oooool7000000?ooooo2P000004ooooo`X000003Oooool6000000Co
oooo3@000003ooooo``0dLfY1oooool3000000Wooooo10000006ooooo`X000002Oooool7000000?o
oooo1P000007ooooo`T000000oooool7000000`0dLfY0`000009ooooo`H000000oooool:000000oo
oooo1P000009ooooo`@000000ooooolE000000`0dLfY0`00000<0?ooo`<000001P3oool3000000<0
oooo0`0000060?ooo`<000000`3oool;000000<0oooo0`0000030?ooo`<000001P3oool3000000<0
oooo1P0000030?ooo`d0dLfY2`0000060?ooo`<000000`3ooolA000000D0oooo1P0000060?ooo`<0
00000P3oool6000000H0oooo0`0000030?ooo`P00000403AcJT000h0dLfY0`000003ooooo`L00000
0oooool7000000?ooooo2P000004ooooo`X000003Oooool6000000Cooooo3@000003ooooo``0dLfY
1oooool3000000Wooooo10000006ooooo`X000002Oooool7000000?ooooo1P000007ooooo`T00000
0oooool7000000`0dLfY1_ooool3000000Wooooo0`000003ooooo`L000000oooool3000000?ooooo
2@000003ooooo`<000000oooool7000000?ooooo0`000009ooooo`<000001_ooool<0=7=Z@T0oooo
3`0000030?ooo`<000001P3oool6000000<0oooo2000000E0?ooo`<000001P3oool6000000d0dLfY
0`0000030?ooo`P000001P3oool3000000P0oooo0`0000090?ooo`8000001P3oool3000000P0oooo
1P00000<0?ooo`D000000`3oool@0=7=Z@003P3AcJT6ooooo`@000002_ooool6000000Cooooo0`00
0003ooooo`@000003Oooool3000000Oooooo0`000007ooooo`X000000oooool3000000`0dLfY4`00
0004ooooo`<000004oooool=000000?ooooo3@000009ooooo`@000000oooool<0=7=Z@Kooooo0`00
0009ooooo`<000000oooool7000000?ooooo0`000003ooooo`T000000oooool3000000?ooooo1`00
0003ooooo`<000002Oooool3000000Kooooo303AcJT90?ooo`l000000`3oool3000000H0oooo1P00
00030?ooo`P000005@3oool3000000H0oooo1P00000=0=7=Z@<000000`3oool8000000H0oooo0`00
00080?ooo`<000002@3oool2000000H0oooo0`0000080?ooo`H00000303oool5000000<0oooo403A
cJT000h0dLfY1_ooool4000000[ooooo1P000004ooooo`<000000oooool4000000gooooo0`000007
ooooo`<000001oooool:000000?ooooo0`00000<0=7=ZA<000001?ooool3000001?ooooo3@000003
ooooo`d000002Oooool4000000?ooooo303AcJT6ooooo`<000002Oooool3000000?ooooo1`000003
ooooo`<000000oooool9000000?ooooo0`000003ooooo`L000000oooool3000000Wooooo0`000006
ooooo``0dLfY2@3oool?000000<0oooo0`0000060?ooo`H000000`3oool8000001D0oooo0`000006
0?ooo`H000003@3AcJT3000000H0oooo1@0000030?ooo`H000000`3oool2000000<0oooo0`000009
0?ooo`8000000`3oool6000001L0oooo0`0000020?ooo`H00000403AcJT000h0dLfY1_ooool40000
00[ooooo1P000004ooooo`<000000oooool4000000gooooo0`000007ooooo`<000001oooool:0000
00?ooooo0`00000<0=7=ZA<000001?ooool3000001?ooooo3@000003ooooo`d000002Oooool40000
00?ooooo303AcJT3000000?ooooo0`000003ooooo``000000oooool:000000?ooooo0`000009oooo
o`H000000oooool4000000?ooooo1P000003ooooo`<000000oooool6000000`0dLfY0`3oool60000
00<0oooo0`0000030?ooo`<000000`3oool6000000H0oooo0`0000060?ooo`h00000303oool30000
00<0oooo1P0000030?ooo`<000003@3AcJT3000000H0oooo1@0000030?ooo`H000000`3oool20000
00<0oooo0`0000090?ooo`8000000`3oool6000001L0oooo0`0000020?ooo`H00000403AcJT000h0
dLfY0`000003ooooo`h000000ooooolA000000[ooooo0`000003ooooo`X000000oooool7000000Oo
oooo0`000003ooooo``0dLfY1oooool3000000gooooo0`000006ooooo`<000001?ooool3000000Ko
oooo0`000004ooooo`H000000oooool7000000?ooooo4000000<0=7=Z@<000000oooool3000000?o
oooo30000003ooooo`X000000oooool3000000Wooooo1P000003ooooo`@000000oooool6000000?o
oooo0`000003ooooo`H00000303AcJT30?ooo`H000000`3oool3000000<0oooo0`0000030?ooo`H0
00001P3oool3000000H0oooo3P00000<0?ooo`<000000`3oool6000000<0oooo0`00000=0=7=Z@<0
00001P3oool5000000<0oooo1P0000030?ooo`8000000`3oool3000000T0oooo0P0000030?ooo`H0
00005`3oool300000080oooo1P00000@0=7=Z@003P3AcJT3000000?ooooo3P000003oooooa400000
2_ooool3000000?ooooo2P000003ooooo`L000001oooool3000000?ooooo303AcJT7ooooo`<00000
3Oooool3000000Kooooo0`000004ooooo`<000001_ooool3000000Cooooo1P000003ooooo`L00000
0oooool@000000`0dLfY0`000003ooooo`<000000oooool<000000?ooooo2P000003ooooo`<00000
2Oooool6000000?ooooo10000003ooooo`H000000oooool3000000?ooooo1P00000<0=7=Z@<0oooo
1P0000030?ooo`<000000`3oool3000000<0oooo1P0000060?ooo`<000001P3oool>000000`0oooo
0`0000030?ooo`H000000`3oool3000000d0dLfY3P3oool6000000P0oooo300000030?ooo`800000
1P3oool6000000D0oooo0`0000030?oooa@00000403AcJT000h0dLfY0`000003ooooo`h000000ooo
oolA000000[ooooo0`000003ooooo`X000000oooool7000000Oooooo0`000003ooooo``0dLfY1ooo
ool3000000gooooo0`000006ooooo`<000001?ooool3000000Kooooo0`000004ooooo`H000000ooo
ool7000000?ooooo4000000<0=7=Z@?ooooo1P000009ooooo`<000000oooool7000000Kooooo2@00
0003ooooo`H000000oooool@000000?ooooo1P000006ooooo``0dLfY1P0000030?ooo`<000001P3o
ool9000000T0oooo0`0000080?ooo`<000002@3oool3000000T0oooo2@0000030?ooo`H000003@3A
cJT>0?ooo`H00000203oool<000000<0oooo0P0000060?ooo`H000001@3oool3000000<0oooo5000
000@0=7=Z@003P3AcJT3ooooo`<000003_ooool3000000?ooooo10000003ooooo`<000004Oooool3
000000?ooooo10000006ooooo`@000001_ooool4000000Kooooo303AcJT3ooooo`X000000oooool3
000000Cooooo3000000@ooooo`@000002Oooool3000000Cooooo0`000006ooooo`X00000303AcJT3
ooooo`H000002Oooool3000000?ooooo1`000006ooooo`T000000oooool6000000?ooooo40000003
ooooo`H000001_ooool<0=7=Z@H000000`3oool3000000H0oooo2@0000090?ooo`<00000203oool3
000000T0oooo0`0000090?ooo`T000000`3oool6000000d0dLfY3P3oool6000000P0oooo30000003
0?ooo`8000001P3oool6000000D0oooo0`0000030?oooa@00000403AcJT000h0dLfY0oooool30000
00kooooo0`000003ooooo`@000000oooool30000017ooooo0`000003ooooo`@000001_ooool40000
00Kooooo10000006ooooo``0dLfY0oooool:000000?ooooo0`000004ooooo``000004?ooool40000
00Wooooo0`000004ooooo`<000001_ooool:000000`0dLfY0oooool6000000Wooooo0`000003oooo
o`L000001_ooool9000000?ooooo1P000003oooooa0000000oooool6000000Kooooo303AcJT60000
00<0oooo0`0000060?ooo`T000002@3oool3000000P0oooo0`0000090?ooo`<000002@3oool90000
00<0oooo1P00000=0=7=Z@<0oooo1P0000020?ooo`T00000203oool3000000`0oooo0P0000030?oo
o`<000002@3oool5000000H0oooo0`0000030?ooo`/00000403AcJT000h0dLfY0oooool3000000ko
oooo0`000003ooooo`@000000oooool30000017ooooo0`000003ooooo`@000001_ooool4000000Ko
oooo10000006ooooo``0dLfY0oooool:000000?ooooo0`000004ooooo``000004?ooool4000000Wo
oooo0`000004ooooo`<000001_ooool:000000`0dLfY0`000003ooooo`<000001_ooool90000013o
oooo0`000003ooooo`<000000oooool3000000Kooooo10000003ooooo`T000001_ooool6000000`0
dLfY0`3oool9000000H0oooo5@0000030?ooo`D000000`3oool9000000H0oooo300000060?ooo`<0
00000`3oool=0=7=Z@<0oooo1P0000020?ooo`T00000203oool3000000`0oooo0P0000030?ooo`<0
00002@3oool5000000H0oooo0`0000030?ooo`/00000403AcJT000h0dLfY0oooool3000000kooooo
0`000003ooooo`@000000oooool30000017ooooo0`000003ooooo`@000001_ooool4000000Kooooo
10000006ooooo``0dLfY0`00000=ooooo`<000002_ooool3000000Oooooo40000003ooooo`T00000
1?ooool3000000?ooooo1P000004ooooo`<00000303AcJT3000000?ooooo0`000006ooooo`T00000
4?ooool3000000?ooooo0`000003ooooo`<000001_ooool4000000?ooooo2@000006ooooo`H00000
303AcJT30?ooo`T000001P3ooolE000000<0oooo1@0000030?ooo`T000001P3oool<000000H0oooo
0`0000030?ooo`d0dLfY0`3oool600000080oooo2@0000080?ooo`<00000303oool2000000<0oooo
0`0000090?ooo`D000001P3oool3000000<0oooo2`00000@0=7=Z@003P3AcJT:000000?ooooo2P00
000Aooooo`d000000oooool7000000?ooooo0`000004ooooo`X000000oooool3000000`0dLfY0`00
000=ooooo`<000002_ooool3000000Oooooo40000003ooooo`T000001?ooool3000000?ooooo1P00
0004ooooo`<00000303AcJT3000000?ooooo0`000006ooooo`T000004?ooool3000000?ooooo0`00
0003ooooo`<000001_ooool4000000?ooooo2@000006ooooo`H00000303AcJT30?ooo`T000001P3o
oolE000000<0oooo1@0000030?ooo`T000001P3oool<000000H0oooo0`0000030?ooo`d0dLfY2@3o
ool5000000H0oooo1P0000050?ooo`T000000`3oool2000000l0oooo0P00000?0?ooo`<00000203o
ool@0=7=Z@003P3AcJT:000000?ooooo2P00000Aooooo`d000000oooool7000000?ooooo0`000004
ooooo`X000000oooool3000000`0dLfY0`00000=ooooo`<000002_ooool3000000Oooooo40000003
ooooo`T000001?ooool3000000?ooooo1P000004ooooo`<00000303AcJT3000000Kooooo0`000009
ooooo`<000000oooool4000000Wooooo30000006ooooo`d000000oooool6000000Kooooo0`00000<
0=7=Z@<000000`3oool6000000H0oooo1P0000060?ooo`<000000`3oool6000000<0oooo0P000009
0?ooo`H000000`3oool9000000<0oooo0`0000030?ooo`<000000`3oool=0=7=Z@T0oooo1@000006
0?ooo`H000001@3oool9000000<0oooo0P00000?0?ooo`8000003`3oool3000000P0oooo403AcJT0
00h0dLfY2P000003ooooo`X000004Oooool=000000?ooooo1`000003ooooo`<000001?ooool:0000
00?ooooo0`00000<0=7=Z@[ooooo3@000003ooooo`<000002_ooool9000000Oooooo30000007oooo
o`H000000oooool7000000`0dLfY0`000006ooooo`<000002Oooool3000000?ooooo10000009oooo
o``000001_ooool=000000?ooooo1P000006ooooo`<00000303AcJT3000000<0oooo1P0000060?oo
o`H000001P3oool3000000<0oooo1P0000030?ooo`8000002@3oool6000000<0oooo2@0000030?oo
o`<000000`3oool3000000<0oooo3@3AcJT90?ooo`D000001P3oool6000000D0oooo2@0000030?oo
o`8000003`3oool2000000l0oooo0`0000080?oooa00dLfY000>0=7=Z@H000001oooool3000000Co
oooo0`00000:ooooo`<000004Oooool6000000Cooooo0`000003ooooo`X000001?ooool3000000?o
oooo303AcJT:ooooo`d000000oooool3000000[ooooo2@000007ooooo``000001oooool6000000?o
oooo1`00000<0=7=Z@<000001_ooool3000000Wooooo0`000003ooooo`@000002Oooool<000000Ko
oooo3@000003ooooo`H000001_ooool3000000`0dLfY0`0000030?ooo`H000001P3oool6000000H0
oooo0`0000030?ooo`H000000`3oool2000000T0oooo1P0000030?ooo`T000000`3oool3000000<0
oooo0`0000030?ooo`d0dLfY1P3oool3000000/0oooo1P0000020?ooo`H000001P3oool300000080
oooo0`0000030?ooo`<000001P3oool5000000H0oooo0`0000030?ooo`<000000P3oool600000100
dLfY000>0=7=Z@H000001oooool3000000Cooooo0`00000:ooooo`<000004Oooool6000000Cooooo
0`000003ooooo`X000001?ooool3000000?ooooo303AcJT:ooooo`d000000oooool3000000[ooooo
2@000007ooooo``000001oooool6000000?ooooo1`00000<0=7=Z@?ooooo1P000003ooooo`<00000
0oooool6000000?ooooo1`000003ooooo`H000001_ooool3000000?ooooo0`000003ooooo`@00000
0oooool3000000Kooooo0`000009ooooo``0dLfY2@3oool9000000`0oooo0`0000030?ooo`H00000
0`3oool2000000T0oooo1P00000<0?ooo`l000003@3AcJT60?ooo`<000002`3oool600000080oooo
1P0000060?ooo`<000000P3oool3000000<0oooo0`0000060?ooo`D000001P3oool3000000<0oooo
0`0000020?ooo`H00000403AcJT000h0dLfY1P000007ooooo`<000001?ooool3000000[ooooo0`00
000Aooooo`H000001?ooool3000000?ooooo2P000004ooooo`<000000oooool<0=7=Z@d000001_oo
oolD000000?ooooo1P000003ooooo`@000002Oooool:000000Kooooo2P00000<0=7=Z@?ooooo1P00
0003ooooo`<000000oooool6000000?ooooo1`000003ooooo`H000001_ooool3000000?ooooo0`00
0003ooooo`@000000oooool3000000Kooooo0`000009ooooo``0dLfY2@3oool9000000`0oooo0`00
00030?ooo`H000000`3oool2000000T0oooo1P00000<0?ooo`l000003@3AcJT60?ooo`<000002`3o
ool600000080oooo1P0000060?ooo`<000000P3oool3000000<0oooo0`0000060?ooo`D000001P3o
ool3000000<0oooo0`0000020?ooo`H00000403AcJT000h0dLfY2_ooool:000000?ooooo0`000007
ooooo`<000001?ooool:0000013ooooo0`000004ooooo`<000000oooool4000000Kooooo303AcJT=
000000Kooooo50000003ooooo`H000000oooool4000000Wooooo2P000006ooooo`X00000303AcJT3
ooooo`H000000oooool3000000?ooooo1P000003ooooo`L000000oooool6000000Kooooo0`000003
ooooo`<000000oooool4000000?ooooo0`000006ooooo`<000002Oooool<0=7=Z@T0oooo2@00000<
0?ooo`<000000`3oool6000000<0oooo0P0000090?ooo`H00000303oool?000000d0dLfY1P3oool3
00000080oooo0`00000<0?ooo`8000002@3oool8000000<0oooo1P0000060?ooo`D000002@3oool3
000000<0oooo1@0000030?oooa00dLfY000>0=7=Z@[ooooo2P000003ooooo`<000001oooool30000
00Cooooo2P00000@ooooo`<000001?ooool3000000?ooooo10000006ooooo``0dLfY3@000006oooo
oa@000000oooool6000000?ooooo10000009ooooo`X000001_ooool:000000`0dLfY1P000003oooo
o`H000000oooool3000000?ooooo1`000006ooooo`H000001_ooool3000000gooooo1P000009oooo
o`<000000oooool3000000`0dLfY1P00000<0?ooo`T000000`3oool9000000<0oooo1@00000B0?oo
o`<000001P3oool?000000d0dLfY1P3oool300000080oooo0`00000<0?ooo`8000002@3oool80000
00<0oooo1P0000060?ooo`D000002@3oool3000000<0oooo1@0000030?oooa00dLfY000>0=7=Z@[o
oooo2P000003ooooo`<000001oooool3000000Cooooo2P00000@ooooo`<000001?ooool3000000?o
oooo10000006ooooo``0dLfY0oooool7000000gooooo2@000003ooooo`@000002Oooool3000000Co
oooo30000004ooooo`<000000oooool3000000?ooooo1`00000<0=7=Z@H000000oooool6000000?o
oooo0`000003ooooo`L000001_ooool6000000Kooooo0`00000=ooooo`H000002Oooool3000000?o
oooo0`00000<0=7=Z@H00000303oool9000000<0oooo2@0000030?ooo`D000004P3oool3000000H0
oooo3`00000=0=7=Z@H0oooo0`0000020?ooo`<00000303oool2000000T0oooo200000030?ooo`H0
00001P3oool5000000T0oooo0`0000030?ooo`D000000`3oool@0=7=Z@003P3AcJT3000000?ooooo
5000000Hooooo`H000001oooool3000000Oooooo1P000004ooooo`H00000303AcJT3ooooo`L00000
3Oooool9000000?ooooo10000009ooooo`<000001?ooool<000000Cooooo0`000003ooooo`<00000
0oooool7000000`0dLfY1P000003ooooo`H000000oooool3000000?ooooo1`000006ooooo`H00000
1_ooool3000000gooooo1P000009ooooo`<000000oooool3000000`0dLfY1P00000<0?ooo`T00000
0`3oool9000000<0oooo1@00000B0?ooo`<000001P3oool?000000d0dLfY0`3oool6000000D0oooo
1P0000030?ooo`<000000P3oool3000000<0oooo0`0000030?ooo`<000000P3oool3000000H0oooo
0`0000030?ooo`D000000`3oool3000000h0oooo0`00000@0=7=Z@003P3AcJT3000000?ooooo5000
000Hooooo`H000001oooool3000000Oooooo1P000004ooooo`H00000303AcJT3ooooo`L000003Ooo
ool9000000?ooooo10000009ooooo`<000001?ooool<000000Cooooo0`000003ooooo`<000000ooo
ool7000000`0dLfY2Oooool9000000?ooooo1P00000:ooooo`<000002Oooool6000000?ooooo0`00
0004ooooo`<000002Oooool6000000Kooooo303AcJT9000000<0oooo0`0000030?ooo`H000002@3o
ool3000000<0oooo3P0000030?ooo`H000000`3oool3000000<0oooo1P0000030?ooo`T000003@3A
cJT30?ooo`H000001@3oool6000000<0oooo0`0000020?ooo`<000000`3oool3000000<0oooo0`00
00020?ooo`<000001P3oool3000000<0oooo1@0000030?ooo`<000003P3oool300000100dLfY000>
0=7=Z@<000000ooooolD000001Sooooo1P000007ooooo`<000001oooool6000000Cooooo1P00000<
0=7=Z@?ooooo1`00000=ooooo`T000000oooool4000000Wooooo0`000004ooooo``000001?ooool3
000000?ooooo0`000003ooooo`L00000303AcJT9ooooo`T000000oooool6000000[ooooo0`000009
ooooo`H000000oooool3000000Cooooo0`000009ooooo`H000001_ooool<0=7=Z@T000000`3oool3
000000<0oooo1P0000090?ooo`<000000`3oool>000000<0oooo1P0000030?ooo`<000000`3oool6
000000<0oooo2@00000=0=7=Z@<0oooo1P0000050?ooo`H000000`3oool300000080oooo0`000003
0?ooo`<000000`3oool300000080oooo0`0000060?ooo`<000000`3oool5000000<0oooo0`00000>
0?ooo`<00000403AcJT000h0dLfY0`000003oooooa@000006?ooool6000000Oooooo0`000007oooo
o`H000001?ooool6000000`0dLfY2P000003ooooo`<000005oooool9000000?ooooo10000003oooo
o`<000002_ooool3000000Kooooo0`000004ooooo`<00000303AcJT9ooooo`T000000oooool60000
00[ooooo0`000009ooooo`H000000oooool3000000Cooooo0`000009ooooo`H000001_ooool<0=7=
Z@T000000`3oool3000000<0oooo1P0000090?ooo`<000000`3oool>000000<0oooo1P0000030?oo
o`<000000`3oool6000000<0oooo2@00000=0=7=Z@H0oooo2`0000030?ooo`H000001@3oool30000
00T0oooo0P0000060?ooo`<000001P3oool;000000<0oooo0`0000050?ooo`H00000403AcJT000h0
dLfY1_ooool4000000?ooooo0`000004ooooo`<000000oooool4000000?ooooo0`000004ooooo`<0
00002_ooool6000000Cooooo2P00000=ooooo`<00000303AcJT:000000?ooooo0`00000Gooooo`T0
00000oooool4000000?ooooo0`00000:ooooo`<000001_ooool3000000Cooooo0`00000<0=7=Z@oo
oooo0`000003ooooo`d000002Oooool6000000?ooooo1P000003ooooo`L000000oooool3000000?o
oooo0`000009ooooo``0dLfY0`0000060?ooo`<000000`3oool3000000T0oooo0`0000090?ooo`P0
00001P3oool6000000H0oooo0`00000<0?ooo`<000000`3oool3000000d0dLfY1P3oool;000000<0
oooo1P0000050?ooo`<000002@3oool2000000H0oooo0`0000060?ooo`/000000`3oool3000000D0
oooo1P00000@0=7=Z@003P3AcJT6ooooo`@000000oooool3000000Cooooo0`000003ooooo`@00000
0oooool3000000Cooooo0`00000:ooooo`H000001?ooool:000000gooooo0`00000<0=7=Z@X00000
0oooool3000001Oooooo2@000003ooooo`@000000oooool3000000[ooooo0`000006ooooo`<00000
1?ooool3000000`0dLfY3oooool3000000?ooooo3@000009ooooo`H000000oooool6000000?ooooo
1`000003ooooo`<000000oooool3000000Wooooo303AcJT3000000H0oooo0`0000030?ooo`<00000
2@3oool3000000T0oooo200000060?ooo`H000001P3oool3000000`0oooo0`0000030?ooo`<00000
3@3AcJT60?ooo`<000001@3oool3000000<0oooo0`0000050?ooo`<000000`3oool3000000P0oooo
1P00000D0?ooo`<000001P3oool2000000<0oooo0`00000@0=7=Z@003P3AcJT6ooooo`@000000ooo
ool3000000Cooooo0`000003ooooo`@000000oooool3000000Cooooo0`00000:ooooo`H000001?oo
ool:000000gooooo0`00000<0=7=Z@<000004?ooool4000000Wooooo2P000003ooooo`H000001ooo
ool6000000?ooooo10000003ooooo`T000001oooool<0=7=Z@oooooo0`000003ooooo`d000002Ooo
ool6000000?ooooo1P000003ooooo`L000000oooool3000000?ooooo0`000009ooooo``0dLfY0`00
00060?ooo`<000000`3oool3000000T0oooo0`0000090?ooo`P000001P3oool6000000H0oooo0`00
000<0?ooo`<000000`3oool3000000d0dLfY1P3oool3000000D0oooo0`0000030?ooo`<000001@3o
ool3000000<0oooo0`0000080?ooo`H00000503oool3000000H0oooo0P0000030?ooo`<00000403A
cJT000h0dLfY0oooool30000017ooooo0`000004ooooo`X000000oooool:000000?ooooo4@00000:
ooooo`<000000oooool<0=7=Z@<000004?ooool4000000Wooooo2P000003ooooo`H000001oooool6
000000?ooooo10000003ooooo`T000001oooool<0=7=Z@?ooooo0`000003ooooo`<000002Oooool3
000000?ooooo1`000003ooooo`H000000oooool3000000?ooooo1P000007ooooo`T000000oooool9
000000?ooooo303AcJT3000000H0oooo0`00000?0?ooo`<000002@3oool3000000D0oooo0`000009
0?ooo`<000003`3oool3000000H0oooo0`00000=0=7=Z@H0oooo0`0000050?ooo`<000000`3oool3
000000D0oooo0`0000030?ooo`<00000203oool6000001@0oooo0`0000060?ooo`8000000`3oool3
00000100dLfY000>0=7=Z@?ooooo0`00000Aooooo`<000001?ooool:000000?ooooo2P000003oooo
oa4000002_ooool3000000?ooooo303AcJT30000013ooooo10000009ooooo`X000000oooool60000
00Oooooo1P000003ooooo`@000000oooool9000000Oooooo303AcJT3ooooo`<000000oooool30000
00Wooooo0`000003ooooo`L000000oooool6000000?ooooo0`000003ooooo`H000001oooool90000
00?ooooo2@000003ooooo``0dLfY0`0000060?ooo`<000003`3oool3000000T0oooo0`0000050?oo
o`<000002@3oool3000000l0oooo0`0000060?ooo`<000003@3AcJT3000000<0oooo0`0000050?oo
o`<000000`3oool3000000<0oooo0P0000090?ooo`<000002`3oool900000080oooo0`0000060?oo
o`<000000`3oool300000080oooo1P00000@0=7=Z@003P3AcJT3ooooo`<000004Oooool3000000Co
oooo2P000003ooooo`X000000ooooolA000000[ooooo0`000003ooooo``0dLfY1oooool6000000Ko
oooo2P000003ooooo`L000000oooool=000000?ooooo2@000004ooooo`<000000oooool3000000[o
oooo303AcJT3ooooo`<000000oooool3000000Wooooo0`000003ooooo`L000000oooool6000000?o
oooo0`000003ooooo`H000001oooool9000000?ooooo2@000003ooooo``0dLfY0`0000060?ooo`<0
00003`3oool3000000T0oooo0`0000050?ooo`<000002@3oool3000000l0oooo0`0000060?ooo`<0
00003@3AcJT3000000<0oooo0`0000050?ooo`<000000`3oool3000000<0oooo0P0000090?ooo`<0
00002`3oool900000080oooo0`0000060?ooo`<000000`3oool300000080oooo1P00000@0=7=Z@00
3P3AcJT6ooooo`h000001_ooool7000000?ooooo1`000003oooooa4000002_ooool3000000?ooooo
2P00000<0=7=Z@Oooooo1P000006ooooo`X000000oooool7000000?ooooo3@000003ooooo`T00000
1?ooool3000000?ooooo0`00000:ooooo``0dLfY0oooool3000000?ooooo0`000003ooooo`<00000
3Oooool3000000?ooooo1P000003ooooo`<000000oooool6000000Oooooo2@000003ooooo`H00000
1_ooool<0=7=Z@H000001P3oool6000000T0oooo0`0000030?ooo`<000002@3oool2000000H0oooo
0`0000090?ooo`H000000`3oool6000000T0oooo3@3AcJT3000000<0oooo0`0000050?ooo`<00000
0`3oool3000000<0oooo0P0000090?ooo`<000002`3oool900000080oooo0`0000060?ooo`<00000
0`3oool300000080oooo1P00000@0=7=Z@003P3AcJT6ooooo`h000001_ooool7000000?ooooo1`00
0003oooooa4000002_ooool3000000?ooooo2P00000<0=7=Z@Oooooo1P000006ooooo`X000000ooo
ool7000000?ooooo3@000003ooooo`T000001?ooool3000000?ooooo0`00000:ooooo``0dLfY0ooo
ool3000000?ooooo0`000003ooooo`<000003Oooool3000000?ooooo1P000003ooooo`<000000ooo
ool6000000Oooooo2@000003ooooo`H000001_ooool<0=7=Z@H000001P3oool6000000T0oooo0`00
00030?ooo`<000002@3oool2000000H0oooo0`0000090?ooo`H000000`3oool6000000T0oooo3@3A
cJT600000140oooo200000090?ooo`/000002@3oool2000000<0oooo2@0000030?ooo`<00000203o
ool@0=7=Z@003P3AcJT6ooooo`h000001_ooool7000000?ooooo1`000003oooooa4000002_ooool3
000000?ooooo2P00000<0=7=Z@?ooooo10000003ooooo`T000002_ooool3000000?ooooo10000003
ooooo`d000000oooool=000000Kooooo0`00000:ooooo``0dLfY0oooool3000000?ooooo0`000003
ooooo`<000003Oooool3000000?ooooo1P000003ooooo`<000000oooool6000000Oooooo2@000003
ooooo`H000001_ooool<0=7=Z@H000001P3oool6000000T0oooo0`0000030?ooo`<000002@3oool2
000000H0oooo0`0000090?ooo`H000000`3oool6000000T0oooo3@3AcJT600000140oooo20000009
0?ooo`/000002@3oool2000000<0oooo2@0000030?ooo`<00000203oool@0=7=Z@003P3AcJT60000
00Cooooo0`000003ooooo`@000001_ooool4000000[ooooo2P000009ooooo`@000001_ooool40000
00?ooooo0`000004ooooo`H00000303AcJT3ooooo`@000000oooool9000000[ooooo0`000003oooo
o`@000000oooool=000000?ooooo3@000006ooooo`<000002_ooool<0=7=Z@?ooooo0`000003oooo
o`<000000oooool3000000gooooo0`000003ooooo`H000000oooool3000000?ooooo1P000007oooo
o`T000000oooool6000000Kooooo303AcJT3000000H0oooo1P0000030?ooo``000000`3oool30000
00<0oooo0`0000080?ooo`H000000`3oool6000000T0oooo0`0000030?ooo`<000000`3oool30000
00d0dLfY1P00000A0?ooo`P000002@3oool;000000T0oooo0P0000030?ooo`T000000`3oool30000
00P0oooo403AcJT000h0dLfY1P000004ooooo`<000000oooool4000000Kooooo1000000:ooooo`X0
00002Oooool4000000Kooooo10000003ooooo`<000001?ooool6000000`0dLfY0oooool4000000?o
oooo2@00000:ooooo`<000000oooool4000000?ooooo3@000003ooooo`d000001_ooool3000000[o
oooo303AcJT3000000cooooo0`000003ooooo`<000000oooool4000000?ooooo0`000006ooooo`<0
00000oooool6000000Kooooo10000003ooooo`<000000oooool3000000Kooooo1P00000<0=7=Z@<0
00001P3oool6000000<0oooo300000030?ooo`<000000`3oool3000000P0oooo1P0000030?ooo`H0
00002@3oool3000000<0oooo0`0000030?ooo`<000003@3AcJT6000000<0oooo3P0000030?ooo`80
00000`3oool3000000H0oooo1@0000060?ooo`<000000`3oool5000000l0oooo1@0000060?oooa00
dLfY000>0=7=Z@H000001?ooool3000000?ooooo10000006ooooo`@000002_ooool:000000Wooooo
10000006ooooo`@000000oooool3000000Cooooo1P00000<0=7=Z@?ooooo1000000<ooooo`d00000
1oooool9000000[ooooo0`00000:ooooo`H000003Oooool<0=7=Z@<000003?ooool3000000?ooooo
0`000003ooooo`@000000oooool3000000Kooooo0`000003ooooo`H000001_ooool4000000?ooooo
0`000003ooooo`<000001_ooool6000000`0dLfY0`0000060?ooo`H000000`3oool<000000<0oooo
0`0000030?ooo`<00000203oool6000000<0oooo1P0000090?ooo`<000000`3oool3000000<0oooo
0`00000=0=7=Z@H000000`3oool>000000<0oooo0P0000030?ooo`<000001P3oool5000000H0oooo
0`0000030?ooo`D000003`3oool5000000H0oooo403AcJT000h0dLfY1P000004ooooo`<000000ooo
ool4000000Kooooo1000000:ooooo`X000002Oooool4000000Kooooo10000003ooooo`<000001?oo
ool6000000`0dLfY0oooool4000000cooooo3@000007ooooo`T000002_ooool3000000[ooooo1P00
000=ooooo``0dLfY0`00000<ooooo`<000000oooool3000000?ooooo10000003ooooo`<000001_oo
ool3000000?ooooo1P000006ooooo`@000000oooool3000000?ooooo0`000006ooooo`H00000303A
cJT3000000H0oooo1P0000090?ooo`T000000`3oool3000000/0oooo0`0000030?ooo`<00000303o
ool3000000H0oooo0`0000030?ooo`<000003@3AcJT6000000<0oooo3P0000030?ooo`8000000`3o
ool3000000H0oooo1@0000060?ooo`<000000`3oool5000000l0oooo1@0000060?oooa00dLfY000>
0=7=Z@[ooooo4000000:ooooo`L000000oooool:000000Oooooo1P000004ooooo`<000001oooool6
000000`0dLfY0oooool4000000cooooo3@000007ooooo`T000002_ooool3000000[ooooo1P00000=
ooooo``0dLfY4_ooool6000000?ooooo10000003ooooo`T000000oooool3000000Wooooo0`00000C
ooooo`H000000oooool<0=7=Z@<000001P3oool6000000T0oooo2@0000030?ooo`<000002`3oool3
000000<0oooo0`00000<0?ooo`<000001P3oool3000000<0oooo0`00000=0=7=Z@H0oooo0`00000>
0?ooo`<000000P3oool3000000<0oooo0`0000030?ooo`<000000P3oool3000000h0oooo3`000008
0?ooo`<00000403AcJT000h0dLfY2_ooool@000000[ooooo1`000003ooooo`X000001oooool60000
00Cooooo0`000007ooooo`H00000303AcJT:000000Kooooo0`000007ooooo`<000000oooool70000
00Wooooo1`000003ooooo`H000000oooool4000000cooooo1`00000<0=7=ZA;ooooo1P000003oooo
o`@000000oooool9000000?ooooo0`000009ooooo`<000004oooool6000000?ooooo303AcJT?0000
00<0oooo1P0000030?ooo``000000`3oool5000000<0oooo2@0000030?ooo``000002@3oool60000
00d0dLfY1P3oool3000000h0oooo0`0000020?ooo`<000000`3oool3000000<0oooo0`0000020?oo
o`<000003P3oool?000000P0oooo0`00000@0=7=Z@003P3AcJT:oooooa0000002_ooool7000000?o
oooo2P000007ooooo`H000001?ooool3000000Oooooo1P00000<0=7=Z@X000001_ooool3000000Oo
oooo0`000003ooooo`L000002Oooool7000000?ooooo1P000003ooooo`@000003?ooool7000000`0
dLfY4_ooool6000000?ooooo10000003ooooo`T000000oooool3000000Wooooo0`00000Cooooo`H0
00000oooool<0=7=Z@l000000`3oool6000000<0oooo300000030?ooo`D000000`3oool9000000<0
oooo300000090?ooo`H000003@3AcJT60?ooo`<000003P3oool300000080oooo0`0000030?ooo`<0
00000`3oool300000080oooo0`00000>0?ooo`l00000203oool300000100dLfY000>0=7=ZA3ooooo
1`000003ooooo`L000000oooool:000000Cooooo2@00000Nooooo``0dLfY2P000006ooooo`<00000
1oooool3000000?ooooo1`000009ooooo`L000000oooool6000000?ooooo1000000<ooooo`L00000
303AcJT3000000?ooooo1P00000?ooooo`X000001_ooool3000000?ooooo40000003ooooo`<00000
0oooool9000000?ooooo0`00000<0=7=Z@l000000`3oool6000000<0oooo300000030?ooo`D00000
0`3oool9000000<0oooo300000090?ooo`H000003@3AcJT60?ooo`<000000P3oool3000000<0oooo
0`0000060?ooo`8000001P3oool3000000<0oooo0`0000050?ooo`H000002`3oool<000000<0oooo
0P0000030?ooo`<00000403AcJT000h0dLfY4?ooool7000000?ooooo1`000003ooooo`X000001?oo
ool9000001kooooo303AcJT7ooooo`<000000oooool6000000Oooooo0`000003ooooo`d000000ooo
ool3000000Oooooo0`00000:ooooo`<000000oooool3000000Oooooo0`00000<0=7=Z@<000000ooo
ool6000000oooooo2P000006ooooo`<000000oooool@000000?ooooo0`000003ooooo`T000000ooo
ool3000000`0dLfY0`0000030?ooo`<000000`3oool3000000<0oooo1P0000030?ooo`<000000`3o
ool3000000T0oooo0P0000060?ooo`<000003`3oool?000000<0oooo3@3AcJT60?ooo`<000000P3o
ool3000000<0oooo0`0000060?ooo`8000001P3oool3000000<0oooo0`0000050?ooo`H000002`3o
ool<000000<0oooo0P0000030?ooo`<00000403AcJT000h0dLfY4?ooool7000000?ooooo1`000003
ooooo`X000001?ooool9000001kooooo303AcJT7ooooo`<000000oooool6000000Oooooo0`000003
ooooo`d000000oooool3000000Oooooo0`00000:ooooo`<000000oooool3000000Oooooo0`00000<
0=7=Z@<000000oooool6000000oooooo2P000006ooooo`<000000oooool@000000?ooooo0`000003
ooooo`T000000oooool3000000`0dLfY0`0000030?ooo`<000000`3oool3000000<0oooo1P000003
0?ooo`<000000`3oool3000000T0oooo0P0000060?ooo`<000003`3oool?000000<0oooo3@3AcJT6
0?ooo`<000000P3oool3000000<0oooo0`0000060?ooo`8000001P3oool3000000<0oooo0`000005
0?ooo`H000002`3oool<000000<0oooo0P0000030?ooo`<00000403AcJT000h0dLfY2P000006oooo
o`@000002_ooool6000000Cooooo0`00000:ooooo`<000000oooool7000000Oooooo0`000007oooo
o`<000000oooool<0=7=Z@Oooooo0`000003ooooo`H000001oooool3000000?ooooo3@000003oooo
o`<000001oooool3000000[ooooo0`000003ooooo`<000001oooool3000000`0dLfY0oooool30000
00cooooo1P000003ooooo`@000003?ooool<000000?ooooo1`000006ooooo`T000002Oooool<0=7=
Z@<000000`3oool3000000<0oooo0`0000030?ooo`H000000`3oool3000000<0oooo0`0000090?oo
o`8000001P3oool3000000l0oooo3`0000030?ooo`d0dLfY0`3oool3000000<0oooo200000060?oo
o`D000000`3oool3000000<0oooo0`0000030?ooo`8000000`3oool6000000h0oooo1P00000;0?oo
o`<00000403AcJT000h0dLfY2P000006ooooo`@000002_ooool6000000Cooooo0`00000:ooooo`<0
00000oooool7000000Oooooo0`000007ooooo`<000000oooool<0=7=Z@<000001oooool3000000[o
oooo1P00000:ooooo`T000000oooool4000000?ooooo2@000004ooooo`T000000oooool7000000`0
dLfY0oooool3000000cooooo1P000003ooooo`@000003?ooool<000000?ooooo1`000006ooooo`T0
00002Oooool<0=7=Z@<000001P3oool6000000`0oooo300000080?ooo`H000001P3oool9000000T0
oooo0`0000060?ooo`<000003@3AcJT30?ooo`<000000`3oool8000000H0oooo1@0000030?ooo`<0
00000`3oool3000000<0oooo0P0000030?ooo`H000003P3oool6000000/0oooo0`00000@0=7=Z@00
3P3AcJT:000000Kooooo1000000:ooooo`H000001?ooool3000000[ooooo0`000003ooooo`L00000
1oooool3000000Oooooo0`000003ooooo``0dLfY0`000007ooooo`<000002_ooool6000000[ooooo
2@000003ooooo`@000000oooool9000000Cooooo2@000003ooooo`L00000303AcJT3ooooo`<00000
3?ooool6000000?ooooo1000000<ooooo``000000oooool7000000Kooooo2@000009ooooo``0dLfY
0`0000060?ooo`H00000303oool<000000P0oooo1P0000060?ooo`T000002@3oool3000000H0oooo
0`00000=0=7=Z@<0oooo0`0000030?ooo`P000001P3oool5000000<0oooo0`0000030?ooo`<00000
0`3oool2000000<0oooo1P00000>0?ooo`H000002`3oool300000100dLfY000>0=7=Z@<000000ooo
ool:000000Cooooo0`00000:ooooo`X000000oooool4000001?ooooo2P000004ooooo`H00000303A
cJT3000000Oooooo0`00000:ooooo`H000002_ooool9000000?ooooo10000003ooooo`T000001?oo
ool9000000?ooooo1`00000<0=7=Z@?ooooo0`000003ooooo`T000001_ooool7000000Kooooo1P00
0003ooooo`T000005_ooool9000000?ooooo303AcJT3000000H0oooo1P00000<0?ooo``00000203o
ool6000000H0oooo2@0000090?ooo`<000001P3oool3000000d0dLfY1P0000080?ooo`<000002`3o
ool3000000H0oooo0`00000>0?ooo`<000000`3oool>000000h0oooo403AcJT000h0dLfY0`000003
ooooo`X000001?ooool3000000[ooooo2P000003ooooo`@000004oooool:000000Cooooo1P00000<
0=7=Z@<000001oooool3000000[ooooo1P00000:ooooo`T000000oooool4000000?ooooo2@000004
ooooo`T000000oooool7000000`0dLfY0oooool3000000?ooooo2@000006ooooo`L000001_ooool6
000000?ooooo2@00000Fooooo`T000000oooool<0=7=Z@T000001P3oool9000000H0oooo0`000003
0?ooo`<000003P3oool3000000H0oooo1P0000030?ooo`T000000`3oool6000000d0dLfY1P000008
0?ooo`<000002`3oool3000000H0oooo0`00000>0?ooo`<000000`3oool>000000h0oooo403AcJT0
00h0dLfY0`000003ooooo`X000001?ooool3000000[ooooo2P000003ooooo`@000004oooool:0000
00Cooooo1P00000<0=7=Z@[ooooo1P00000=ooooo`<000000oooool4000000Wooooo0`000004oooo
o`H000002_ooool6000000?ooooo0`000004ooooo`<00000303AcJT3ooooo`<000000oooool90000
00Kooooo1`000006ooooo`H000000oooool9000001Kooooo2@000003ooooo``0dLfY2@0000060?oo
o`T000001P3oool3000000<0oooo0`00000>0?ooo`<000001P3oool6000000<0oooo2@0000030?oo
o`H000003@3AcJT9000001`0oooo0`0000030?ooo`800000303oool5000000<0oooo0`0000030?oo
o`<00000203oool600000100dLfY000>0=7=Z@<000000oooool:000000Cooooo0`00000:ooooo`X0
00000oooool4000001?ooooo2P000004ooooo`H00000303AcJT:ooooo`H000003Oooool3000000?o
oooo10000009ooooo`<000001?ooool6000000[ooooo1P000003ooooo`<000001?ooool3000000`0
dLfY0`000006ooooo``000000oooool3000000Oooooo1P000003ooooo`H000002Oooool3000000[o
oooo0`00000<ooooo`<00000303AcJT9000000H0oooo2@0000060?ooo`<000000`3oool3000000h0
oooo0`0000060?ooo`H000000`3oool9000000<0oooo1P00000=0=7=Z@T00000703oool3000000<0
oooo0P00000<0?ooo`D000000`3oool3000000<0oooo0`0000080?ooo`H00000403AcJT000h0dLfY
0oooool3000000Oooooo0`000007ooooo`<000004Oooool3000000Oooooo0`00000:oooooa@00000
0oooool<0=7=Z@[ooooo1P00000=ooooo`<000000oooool4000000Wooooo0`000004ooooo`H00000
2_ooool6000000?ooooo0`000004ooooo`<00000303AcJT3000000Kooooo30000003ooooo`<00000
1oooool6000000?ooooo1P000009ooooo`<000002_ooool3000000cooooo0`00000<0=7=Z@l0oooo
1P0000030?ooo`<000000`3oool6000000<0oooo1P0000020?ooo`<000000`3oool6000000H0oooo
0`0000030?ooo`H000000`3oool9000000d0dLfY2@00000L0?ooo`<000000`3oool2000000`0oooo
1@0000030?ooo`<000000`3oool3000000P0oooo1P00000@0=7=Z@003P3AcJT3ooooo`<000001ooo
ool3000000Oooooo0`00000Aooooo`<000001oooool3000000[ooooo50000003ooooo``0dLfY0ooo
ool4000000?ooooo0`00000:ooooo`H000006_ooool6000000?ooooo0`000004ooooo`<000002Ooo
ool4000000?ooooo303AcJT3000000Kooooo30000003ooooo`<000001oooool6000000?ooooo1P00
0009ooooo`<000002_ooool3000000cooooo0`00000<0=7=Z@l0oooo1P0000030?ooo`<000000`3o
ool6000000<0oooo1P0000020?ooo`<000000`3oool6000000H0oooo0`0000030?ooo`H000000`3o
ool9000000d0dLfY0`3oool3000000/0oooo4@0000060?ooo`D000002@3oool8000000`0oooo2000
00030?ooo`<00000403AcJT000h0dLfY0oooool3000000Oooooo0`000007ooooo`<000004Oooool3
000000Oooooo0`00000:oooooa@000000oooool<0=7=Z@?ooooo10000003ooooo`<000002_ooool6
000001[ooooo1P000003ooooo`<000001?ooool3000000Wooooo10000003ooooo``0dLfY0`000003
ooooo`<000001_ooool3000000Kooooo1`000006ooooo`T000001_ooool3000000gooooo3`000003
ooooo`<00000303AcJT?0?ooo`H000000`3oool3000000<0oooo1P0000030?ooo`H000000P3oool3
000000<0oooo1P0000060?ooo`<000000`3oool6000000<0oooo2@00000=0=7=Z@<0oooo0`00000;
0?oooa4000001P3oool5000000T0oooo2000000<0?ooo`P000000`3oool300000100dLfY000>0=7=
Z@H000001?ooool:000000?ooooo1`000006ooooo`L000000oooool7000000?ooooo1`000003oooo
o`<000001?ooool3000000Oooooo0`000003ooooo``0dLfY0oooool4000000?ooooo0`00000:oooo
o`H000006_ooool6000000?ooooo0`000004ooooo`<000002Oooool4000000?ooooo303AcJT30000
00?ooooo0`000006ooooo`<000001_ooool7000000Kooooo2@000006ooooo`<000003Oooool?0000
00?ooooo0`00000<0=7=Z@H000000`3oool3000000<0oooo1P0000090?ooo`<000002@3oool50000
00<0oooo1P0000030?ooo`<000003`3oool3000000<0oooo1P00000=0=7=Z@<0oooo0`00000;0?oo
oa4000001P3oool5000000T0oooo2000000<0?ooo`P000000`3oool300000100dLfY000>0=7=Z@H0
00001?ooool:000000?ooooo1`000006ooooo`L000000oooool7000000?ooooo1`000003ooooo`<0
00001?ooool3000000Oooooo0`000003ooooo``0dLfY1`000003ooooo`H000000oooool4000000?o
oooo2@00000=ooooo`<000002_ooool6000000Cooooo2@00000:ooooo``0dLfY0`000003ooooo`<0
00001_ooool3000000Kooooo1`000006ooooo`T000001_ooool3000000gooooo3`000003ooooo`<0
0000303AcJT6000000<0oooo0`0000030?ooo`H000002@3oool3000000T0oooo1@0000030?ooo`H0
00000`3oool3000000l0oooo0`0000030?ooo`H000003@3AcJT60?ooo`D000000`3oool6000000<0
oooo2`0000030?ooo`<000001@3oool3000000H0oooo0`0000050?ooo``000000`3oool3000000D0
oooo0`00000@0=7=Z@003P3AcJT6000000Cooooo2P000003ooooo`L000001_ooool7000000?ooooo
1`000003ooooo`L000000oooool3000000Cooooo0`000007ooooo`<000000oooool<0=7=Z@L00000
0oooool6000000?ooooo10000003ooooo`T000003Oooool3000000[ooooo1P000004ooooo`T00000
2_ooool<0=7=Z@?ooooo2@00000Cooooo`<000000oooool6000000?ooooo0`000003ooooo`T00000
1oooool6000000?ooooo0`000003ooooo`<000000oooool<0=7=Z@H000000`3oool3000000<0oooo
1P0000090?ooo`<000002@3oool5000000<0oooo1P0000030?ooo`<000003`3oool3000000<0oooo
1P00000=0=7=Z@H0oooo1@0000030?ooo`H000000`3oool;000000<0oooo0`0000050?ooo`<00000
1P3oool3000000D0oooo300000030?ooo`<000001@3oool300000100dLfY000>0=7=Z@Kooooo1000
0003ooooo`X000002_ooool7000000?ooooo0`000007ooooo`X000000oooool3000000Cooooo3@00
0003ooooo``0dLfY1`000003ooooo`H000000oooool4000000?ooooo2@00000=ooooo`<000002_oo
ool6000000Cooooo2@00000:ooooo``0dLfY0oooool9000001?ooooo0`000003ooooo`H000000ooo
ool3000000?ooooo2@000007ooooo`H000000oooool3000000?ooooo0`000003ooooo``0dLfY0`00
000<0?ooo`T000001P3oool9000000<0oooo1@0000030?ooo`T000001P3oool9000000`0oooo0`00
000=0=7=Z@H0oooo1@0000030?ooo`H000000`3oool;000000<0oooo0`0000050?ooo`<000001P3o
ool3000000D0oooo300000030?ooo`<000001@3oool300000100dLfY000>0=7=Z@Kooooo10000003
ooooo`X000002_ooool7000000?ooooo0`000007ooooo`X000000oooool3000000Cooooo3@000003
ooooo``0dLfY0oooool4000000Kooooo1P000007ooooo`H000000oooool4000001?ooooo0`000003
ooooo`<000001?ooool@000000?ooooo303AcJT3ooooo`T000004oooool3000000?ooooo1P000003
ooooo`<000000oooool9000000Oooooo1P000003ooooo`<000000oooool3000000?ooooo303AcJT3
000000`0oooo2@0000060?ooo`T000000`3oool5000000<0oooo2@0000060?ooo`T00000303oool3
000000d0dLfY0`0000030?ooo`D00000503oool3000000H0oooo0`0000020?ooo`H000000`3oool6
00000080oooo300000030?ooo`P000000`3oool@0=7=Z@003P3AcJT6ooooo`@000000oooool:0000
00[ooooo1`000003ooooo`<000001oooool:000000?ooooo0`000004ooooo`d000000oooool<0=7=
Z@?ooooo10000006ooooo`H000001oooool6000000?ooooo1000000Cooooo`<000000oooool30000
00Cooooo40000003ooooo``0dLfY0oooool3000000?ooooo0`000006ooooo`<000001_ooool40000
00Kooooo3`00000=ooooo`T000000oooool3000000Wooooo303AcJT3000000`0oooo2@0000060?oo
o`T000000`3oool5000000<0oooo2@0000060?ooo`T00000303oool3000000d0dLfY0`0000030?oo
o`D00000503oool3000000H0oooo0`0000020?ooo`H000000`3oool600000080oooo300000030?oo
o`P000000`3oool@0=7=Z@003P3AcJT@ooooo`L000000oooool4000000?ooooo0`000004ooooo`<0
00000oooool4000000?ooooo0`000003ooooo`@000004?ooool7000000?ooooo303AcJT3ooooo`@0
00001_ooool6000000Oooooo1P000003ooooo`@000004oooool3000000?ooooo0`000004oooooa00
00000oooool<0=7=Z@?ooooo0`000003ooooo`<000001_ooool3000000Kooooo10000006ooooo`l0
00003Oooool9000000?ooooo0`000009ooooo``0dLfY0`3oool3000000H0oooo0`0000030?ooo``0
00000`3oool3000000H0oooo0`0000020?ooo`T000001P3oool?000000<0oooo0`0000030?ooo`<0
00003@3AcJT3000000<0oooo1@00000D0?ooo`<000001P3oool300000080oooo1P0000030?ooo`H0
00000P3oool<000000<0oooo200000030?oooa00dLfY000>0=7=ZA3ooooo1`000003ooooo`@00000
0oooool3000000Cooooo0`000003ooooo`@000000oooool3000000?ooooo1000000@ooooo`L00000
0oooool<0=7=Z@L000002Oooool3000000Oooooo6@00000Dooooo`<000000oooool3000000?ooooo
10000003ooooo``0dLfY0oooool3000000?ooooo0`000006ooooo`<000001_ooool4000000Kooooo
3`00000=ooooo`T000000oooool3000000Wooooo303AcJT30?ooo`<000001P3oool3000000<0oooo
300000030?ooo`<000001P3oool300000080oooo2@0000060?ooo`l000000`3oool3000000<0oooo
0`00000=0=7=Z@<000002`3oool3000000/0oooo1P0000060?ooo`<000000P3oool<000000D0oooo
3000000;0?ooo`<00000403AcJT000h0dLfY4?ooool7000000?ooooo10000003ooooo`<000001?oo
ool3000000?ooooo10000003ooooo`<000000oooool40000013ooooo1`000003ooooo``0dLfY1`00
0009ooooo`<000001ooooolI000001Cooooo0`000003ooooo`<000000oooool4000000?ooooo303A
cJT6000000?ooooo1P000003oooooaH000001_ooool3000000?ooooo40000003ooooo`H000000ooo
ool9000000`0dLfY0`3oool3000000H0oooo0`0000030?ooo``000000`3oool3000000H0oooo0`00
00020?ooo`T000001P3oool?000000<0oooo0`0000030?ooo`<000003@3AcJT3000000/0oooo0`00
000;0?ooo`H000001P3oool300000080oooo300000050?ooo``000002`3oool300000100dLfY000>
0=7=ZA3ooooo1`000003ooooo`@000000oooool3000000Cooooo0`000003ooooo`@000000oooool3
000000?ooooo1000000@ooooo`L000000oooool<0=7=Z@L000002Oooool3000000Oooooo6@00000D
ooooo`<000000oooool3000000?ooooo10000003ooooo``0dLfY1P000003ooooo`H000000ooooolF
000000Kooooo0`000003oooooa0000000oooool6000000?ooooo2@00000<0=7=Z@T0oooo0`000003
0?ooo`H000000`3oool3000000`0oooo0`0000030?ooo`8000001P3oool9000000`0oooo0`000006
0?ooo`H000003@3AcJT3000000/0oooo0`00000;0?ooo`H000001P3oool300000080oooo30000005
0?ooo``000002`3oool300000100dLfY000>0=7=Z@?ooooo0`000007ooooo`L000000oooool:0000
00?ooooo1000000:oooooa0000000oooool>000000?ooooo0`00000<0=7=Z@<000004?ooool70000
00?ooooo0`000003oooooa@000002Oooool3000000Oooooo1P000003ooooo`@000000oooool<0=7=
Z@H000000oooool6000000?ooooo5P000006ooooo`<000000oooool@000000?ooooo1P000003oooo
o`T00000303AcJT90?ooo`<000000`3oool6000000<0oooo0`00000<0?ooo`<000000`3oool20000
00H0oooo2@00000<0?ooo`<000001P3oool6000000d0dLfY3P3oool6000000<0oooo0`0000080?oo
o`T000000P3oool?00000080oooo500000030?ooo`<00000403AcJT000h0dLfY0oooool3000000Oo
oooo1`000003ooooo`X000000oooool4000000[ooooo40000003ooooo`h000000oooool3000000`0
dLfY0`00000@ooooo`L000000oooool3000000?ooooo50000009ooooo`<000001oooool6000000?o
oooo10000003ooooo``0dLfY1_ooool6000000?ooooo0`000006ooooo`L000002Oooool6000000?o
oooo1P00000=ooooo`T000000oooool3000000Kooooo303AcJT90?ooo`<000000`3oool6000000<0
oooo0`00000<0?ooo`<000000`3oool2000000H0oooo2@00000<0?ooo`<000001P3oool6000000d0
dLfY3P3oool6000000<0oooo0`0000080?ooo`T000000P3oool?00000080oooo500000030?ooo`<0
0000403AcJT000h0dLfY0oooool3000000Oooooo1`000003ooooo`X000000oooool4000000[ooooo
40000003ooooo`h000000oooool3000000`0dLfY0`00000@ooooo`L000000oooool3000000?ooooo
50000009ooooo`<000001oooool6000000?ooooo10000003ooooo``0dLfY1_ooool6000000?ooooo
0`000006ooooo`L000002Oooool6000000?ooooo1P00000=ooooo`T000000oooool3000000Kooooo
303AcJT3000000<0oooo0`00000?0?ooo`H000002@3oool;000001D0oooo2@0000060?ooo`<00000
3@3AcJT>0?ooo`H000000`3oool3000000P0oooo2@0000020?ooo`l000000P3ooolD000000<0oooo
0`00000@0=7=Z@003P3AcJT3000000Oooooo1P000004ooooo`H000001oooool3000000Cooooo0`00
0003ooooo`L000000oooool3000000Cooooo0`00000Gooooo``0dLfY1oooool9000000Oooooo0`00
0003ooooo`H000001?ooool6000000Kooooo10000003ooooo`d000004?ooool3000000`0dLfY1_oo
ool6000000?ooooo0`000006ooooo`L000002Oooool6000000?ooooo1P00000=ooooo`T000000ooo
ool3000000Kooooo303AcJT3000000<0oooo0`00000?0?ooo`H000002@3oool;000001D0oooo2@00
00060?ooo`<000003@3AcJT9000000D0oooo0`0000090?ooo`8000000`3oool3000000/0oooo1P00
00090?ooo`8000002@3oool6000000<0oooo0P0000060?oooa00dLfY000>0=7=Z@<000001oooool6
000000Cooooo1P000007ooooo`<000001?ooool3000000?ooooo1`000003ooooo`<000001?ooool3
000001Oooooo303AcJT7ooooo`T000001oooool3000000?ooooo1P000004ooooo`H000001_ooool4
000000?ooooo3@00000@ooooo`<00000303AcJT6000000Kooooo1P000006ooooo`L000000oooool3
000000Kooooo0`000006ooooo`<000000oooool7000000Kooooo1P000006ooooo`H00000303AcJT3
000000<0oooo0`00000?0?ooo`H000002@3oool;000001D0oooo2@0000060?ooo`<000003@3AcJT9
000000D0oooo0`0000090?ooo`8000000`3oool3000000/0oooo1P0000090?ooo`8000002@3oool6
000000<0oooo0P0000060?oooa00dLfY000>0=7=Z@<000001oooool6000000Cooooo1P000007oooo
o`<000001?ooool3000000?ooooo1`000003ooooo`<000001?ooool3000001Oooooo303AcJT7oooo
o`T000001oooool3000000?ooooo1P000004ooooo`H000001_ooool4000000?ooooo3@00000@oooo
o`<00000303AcJT6000000Kooooo1P000006ooooo`L000000oooool3000000Kooooo0`000006oooo
o`<000000oooool7000000Kooooo1P000006ooooo`H00000303AcJT9000000`0oooo0`0000030?oo
o`<000000`3oool3000000<0oooo0`0000030?ooo`P000000`3oool6000000l0oooo1P0000060?oo
o`d0dLfY2@0000050?ooo`<000002@3oool2000000<0oooo0`00000;0?ooo`H000002@3oool20000
00T0oooo1P0000030?ooo`8000001P3oool@0=7=Z@003P3AcJT:000000?ooooo5`000007ooooo`<0
00005?ooool3000000[ooooo10000006ooooo``0dLfY1oooool3000000?ooooo2P000003ooooo`<0
00004oooool3000000Cooooo0`00000Cooooo`<000000oooool7000000`0dLfY1P000006ooooo`H0
00001_ooool7000000?ooooo0`000006ooooo`<000001_ooool3000000?ooooo1`000006ooooo`H0
00001_ooool6000000`0dLfY2@00000<0?ooo`<000000`3oool3000000<0oooo0`0000030?ooo`<0
00000`3oool8000000<0oooo1P00000?0?ooo`H000001P3oool=0=7=Z@/0oooo3`00000;0?ooo`P0
00003`3oool8000000<0oooo0`0000030?ooo`/00000403AcJT000h0dLfY2P000003oooooaL00000
1oooool3000001Cooooo0`00000:ooooo`@000001_ooool<0=7=Z@Oooooo0`000003ooooo`X00000
0oooool3000001?ooooo0`000004ooooo`<000004oooool3000000?ooooo1`00000<0=7=Z@`00000
1_ooool6000000Oooooo30000006ooooo`T000000oooool@000000Kooooo1P00000<0=7=Z@T00000
303oool3000000<0oooo0`0000030?ooo`<000000`3oool3000000<0oooo200000030?ooo`H00000
3`3oool6000000H0oooo3@3AcJT;0?ooo`l000002`3oool8000000l0oooo200000030?ooo`<00000
0`3oool;00000100dLfY000>0=7=Z@X000000ooooolG000000Oooooo0`00000Dooooo`<000002_oo
ool4000000Kooooo303AcJT7ooooo`<000000oooool:000000?ooooo0`00000Cooooo`<000001?oo
ool3000001?ooooo0`000003ooooo`L00000303AcJT<000000Kooooo1P000007ooooo``000001_oo
ool9000000?ooooo40000006ooooo`H00000303AcJT30?ooo``000001P3oool600000180oooo2000
00060?ooo`T000000`3oool9000000H0oooo0`00000=0=7=Z@H0oooo1@0000030?ooo`H000001P3o
ool2000000H0oooo0`0000060?ooo`8000000`3oool3000000T0oooo0P0000030?ooo`<000000`3o
ool;000000<0oooo0`00000@0=7=Z@003P3AcJT@000000Cooooo2P000003ooooo`<000001?ooool6
0000017ooooo1P00000:ooooo`@000000oooool3000000`0dLfY1oooool3000000?ooooo2P000003
ooooo`<000004oooool3000000Cooooo0`00000Cooooo`<000000oooool7000000`0dLfY30000006
ooooo`H000001oooool<000000Kooooo2@000003oooooa0000001_ooool6000000`0dLfY0`3oool<
000000H0oooo1P00000B0?ooo`P000001P3oool9000000<0oooo2@0000060?ooo`<000003@3AcJT6
0?ooo`D000000`3oool6000000H0oooo0P0000060?ooo`<000001P3oool2000000<0oooo0`000009
0?ooo`8000000`3oool3000000<0oooo2`0000030?ooo`<00000403AcJT000h0dLfY40000004oooo
o`X000000oooool3000000Cooooo1P00000Aooooo`H000002_ooool4000000?ooooo0`00000<0=7=
Z@L000001_ooool3000000?ooooo1000000@ooooo`H000003Oooool30000013ooooo1P000004oooo
o`<00000303AcJT3ooooo`<000000oooool3000000?ooooo1P00000=ooooo`T000000oooool60000
00Wooooo5P000006ooooo``0dLfY0`3oool<000000H0oooo1P00000B0?ooo`P000001P3oool90000
00<0oooo2@0000060?ooo`<000003@3AcJT60?ooo`D000000`3oool6000000H0oooo0P0000060?oo
o`<000001P3oool2000000<0oooo0`0000090?ooo`8000000`3oool3000000<0oooo2`0000030?oo
o`<00000403AcJT000h0dLfY40000004ooooo`X000000oooool3000000Cooooo1P00000Aooooo`H0
00002_ooool4000000?ooooo0`00000<0=7=Z@L000001_ooool3000000?ooooo1000000@ooooo`H0
00003Oooool30000013ooooo1P000004ooooo`<00000303AcJT3ooooo`<000000oooool3000000?o
oooo1P00000=ooooo`T000000oooool6000000Wooooo5P000006ooooo``0dLfY0`3oool6000000<0
oooo2@0000060?ooo`<000002@3oool3000000/0oooo5@0000060?ooo`H000000`3oool=0=7=Z@<0
oooo4@0000030?ooo`D000000`3oool3000000<0oooo0`00000A0?ooo`<000001@3oool3000000T0
oooo0`0000020?ooo`<000000`3oool@0=7=Z@003P3AcJT@000000Cooooo2P000003ooooo`<00000
1?ooool60000017ooooo1P00000:ooooo`@000000oooool3000000`0dLfY1`000006ooooo`<00000
0oooool40000013ooooo1P00000=ooooo`<000004?ooool6000000Cooooo0`00000<0=7=Z@?ooooo
0`000003ooooo`<000000oooool6000000gooooo2@000003ooooo`H000002OoooolF000000Kooooo
303AcJT30?ooo`H000000`3oool9000000H0oooo0`0000090?ooo`<000002`3ooolE000000H0oooo
1P0000030?ooo`d0dLfY0`3ooolA000000<0oooo1@0000030?ooo`<000000`3oool300000140oooo
0`0000050?ooo`<000002@3oool300000080oooo0`0000030?oooa00dLfY000>0=7=Z@?ooooo1`00
000:ooooo`H000001?ooool6000000Cooooo1P000004ooooo`<000000oooool3000000Cooooo3@00
000:ooooo`<00000303AcJT7ooooo``000001oooool3000000?ooooo1`000003oooooa<000001_oo
ool=000000[ooooo303AcJT3000000Kooooo30000003ooooo`X000000oooool3000000?ooooo0`00
0009ooooo`<000001oooool3000000Wooooo0`000003ooooo`H00000303AcJT30?ooo`H000000`3o
ool9000000H0oooo0`0000090?ooo`<000002`3ooolE000000H0oooo1P0000030?ooo`d0dLfY0`3o
oolA000000<0oooo1@0000030?ooo`<000000`3oool300000140oooo0`0000050?ooo`<000002@3o
ool300000080oooo0`0000030?oooa00dLfY000>0=7=Z@?ooooo1`00000:ooooo`H000001?ooool6
000000Cooooo1P000004ooooo`<000000oooool3000000Cooooo3@00000:ooooo`<00000303AcJT7
ooooo``000001oooool3000000?ooooo1`000003oooooa<000001_ooool=000000[ooooo303AcJT3
000000Kooooo30000003ooooo`X000000oooool3000000?ooooo0`000009ooooo`<000001oooool3
000000Wooooo0`000003ooooo`H00000303AcJT?0?ooo`<000000`3oool3000000<0oooo0`000003
0?ooo`h000000`3oool3000000<0oooo2@0000060?ooo`H00000303oool=0=7=Z@<0oooo1P000002
0?ooo`T000000`3oool300000080oooo300000050?ooo`T000000`3oool8000000<0oooo1P000003
0?ooo`D000000`3oool300000100dLfY000>0=7=Z@?ooooo1`00000:ooooo`H000001?ooool60000
00Cooooo1P000004ooooo`<000000oooool3000000Cooooo3@00000:ooooo`<00000303AcJT7oooo
o``000001oooool3000000?ooooo1`000003oooooa<000001_ooool=000000[ooooo303AcJT30000
00Kooooo30000003ooooo`X000000oooool3000000?ooooo0`000009ooooo`<000001oooool30000
00Wooooo0`000003ooooo`H00000303AcJT?0?ooo`<000000`3oool3000000<0oooo0`0000030?oo
o`h000000`3oool3000000<0oooo2@0000060?ooo`H00000303oool=0=7=Z@<0oooo1P0000020?oo
o`T000000`3oool300000080oooo300000050?ooo`T000000`3oool8000000<0oooo1P0000030?oo
o`D000000`3oool300000100dLfY003o0=7=ZCl0dLfY3`3oool3000000<0oooo0`0000030?ooo`<0
00000`3oool>000000<0oooo0`0000030?ooo`T000001P3oool6000000`0oooo3@3AcJT30?ooo`H0
00000P3oool9000000<0oooo0`0000020?ooo``000001@3oool9000000<0oooo200000030?ooo`H0
00000`3oool5000000<0oooo0`00000@0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3A
cJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfY
o`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=
Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo
0=7=Z@h0dLfY000>0=7=Z@@000001?ooool4000000Sooooo10000008ooooo`@000001?ooool50000
00Sooooo10000008ooooo`@000003?ooool4000000Cooooo303AcJT4000000Sooooo3`000008oooo
o`@000001?oooolD000000Oooooo10000004ooooo`@000002?ooool<0=7=Z@Oooooo2`00000eoooo
o`/000001oooool<0=7=Z@Cooooo0`00000;ooooo`@000004_ooool7000000Oooooo0`00000Qoooo
o``0dLfYF@20P80?0=7=Z@003P3AcJT4000000Cooooo10000008ooooo`@000002?ooool4000000Co
oooo1@000008ooooo`@000002?ooool4000000cooooo10000004ooooo``0dLfY10000008ooooo`l0
00002?ooool4000000Cooooo50000007ooooo`@000001?ooool4000000Sooooo303AcJT7ooooo`/0
0000=Oooool;000000Oooooo303AcJT4ooooo`<000002oooool4000001;ooooo1`000007ooooo`<0
00008Oooool<0=7=ZET0P8203`3AcJT000h0dLfY10000004ooooo`@000002?ooool4000000Sooooo
10000004ooooo`D000002?ooool4000000Sooooo1000000<ooooo`@000001?ooool<0=7=Z@@00000
2?ooool?000000Sooooo10000004oooooa@000001oooool4000000Cooooo10000008ooooo``0dLfY
1oooool;000003Gooooo2`000007ooooo``0dLfY1?ooool3000000_ooooo1000000Booooo`L00000
1oooool30000027ooooo303AcJUI0820P0l0dLfY000>0=7=Z@@000001?ooool4000000Sooooo1000
0008ooooo`@000001?ooool5000000Sooooo10000008ooooo`@000003?ooool4000000Cooooo303A
cJT8000000Cooooo10000008ooooo`<000001?ooool@000000cooooo10000003ooooo`P000002?oo
ool8000000`0dLfY0`000008ooooo`@000000oooool?000000Sooooo1`000008ooooo`l000000ooo
ool4000000Sooooo0`00000<0=7=Z@@000000oooool7000000Cooooo2`00000Booooo`<000001ooo
ool4000000Oooooo2`00000;ooooo``0dLfYF@20P80?0=7=Z@003P3AcJT4ooooo`@000002?ooool4
000000Cooooo10000004ooooo`@000002Oooool4000000Cooooo4000000<ooooo`P00000303AcJT8
000000Cooooo10000008ooooo`<000001?ooool@000000cooooo10000003ooooo`P000002?ooool8
000000`0dLfY0`000008ooooo`@000000oooool?000000Sooooo1`000008ooooo`l000000oooool4
000000Sooooo0`00000<0=7=Z@@000000oooool7000000Cooooo2`00000Booooo`<000001oooool4
000000Oooooo2`00000;ooooo``0dLfYF@20P80?0=7=Z@003P3AcJT4ooooo`@000002?ooool40000
00Cooooo10000004ooooo`@000002Oooool4000000Cooooo4000000<ooooo`P00000303AcJT80000
00Cooooo10000008ooooo`<000001?ooool@000000cooooo10000003ooooo`P000002?ooool80000
00`0dLfY0`000008ooooo`@000000oooool?000000Sooooo1`000008ooooo`l000000oooool40000
00Sooooo0`00000<0=7=Z@@000000oooool7000000Cooooo2`00000Booooo`<000001oooool40000
00Oooooo2`00000;ooooo``0dLfYF@20P80?0=7=Z@003P3AcJT4ooooo`@000002?ooool4000000Co
oooo10000004ooooo`@000002Oooool4000000Cooooo4000000<ooooo`P00000303AcJT8000000Co
oooo10000008ooooo`<000001?ooool@000000cooooo10000003ooooo`P000002?ooool8000000`0
dLfY0`000008ooooo`@000000oooool?000000Sooooo1`000008ooooo`l000000oooool4000000So
oooo0`00000<0=7=Z@@000000oooool7000000Cooooo2`00000Booooo`<000001oooool4000000Oo
oooo2`00000;ooooo``0dLfYF@20P80?0=7=Z@003P3AcJT4ooooo`@000002?ooool4000000Cooooo
10000004ooooo`@000002Oooool4000000Cooooo4000000<ooooo`P00000303AcJT8000000Sooooo
10000004ooooo`L000003?ooool4000000Cooooo10000008ooooo`/000002?ooool4000000Cooooo
303AcJT3oooooaL000001oooool8000000Oooooo20000007oooooaL000000oooool<0=7=Z@Cooooo
1`000003ooooo`@000001?ooool3000000_ooooo2`000003ooooo`@000002oooool:000000Cooooo
10000007ooooo``0dLfYF@20P80?0=7=Z@003P3AcJT4ooooo`@000001?ooool4000000Cooooo1000
0008ooooo`@000001?ooool5000000Cooooo10000004ooooo`@000001?ooool8000000Sooooo2000
000<0=7=Z@P000002?ooool4000000Cooooo1`00000<ooooo`@000001?ooool4000000Sooooo2`00
0008ooooo`@000001?ooool<0=7=Z@?ooooo5`000007ooooo`P000001oooool8000000Oooooo5`00
0003ooooo``0dLfY1?ooool7000000?ooooo10000004ooooo`<000002oooool;000000?ooooo1000
000;ooooo`X000001?ooool4000000Oooooo303AcJUI0820P0l0dLfY000>0=7=Z@Cooooo10000004
ooooo`@000001?ooool4000000Sooooo10000004ooooo`D000001?ooool4000000Cooooo10000004
ooooo`P000002?ooool8000000`0dLfY20000008ooooo`@000001?ooool7000000cooooo10000004
ooooo`@000002?ooool;000000Sooooo10000004ooooo``0dLfY0ooooolG000000Oooooo20000007
ooooo`P000001ooooolG000000?ooooo303AcJT4ooooo`L000000oooool4000000Cooooo0`00000;
ooooo`/000000oooool4000000_ooooo2P000004ooooo`@000001oooool<0=7=ZET0P8203`3AcJT0
00h0dLfY1?ooool4000000Cooooo10000004ooooo`@000002?ooool4000000Cooooo1@000004oooo
o`@000001?ooool4000000Cooooo20000008ooooo`P00000303AcJT8000000Sooooo10000004oooo
o`L000003?ooool4000000Cooooo10000008ooooo`/000002?ooool4000000Cooooo303AcJT3oooo
oaL000001oooool8000000Oooooo20000007oooooaL000000oooool<0=7=Z@L000001?oooolB0000
00Oooooo10000003ooooo`@000000oooool4000000Oooooo4P000004ooooo`L00000303AcJUI0820
P0l0dLfY000>0=7=Z@Cooooo10000004ooooo`@000001?ooool4000000Sooooo10000004ooooo`D0
00001?ooool4000000Cooooo10000004ooooo`P000002?ooool8000000`0dLfY10000004ooooo`@0
00002?ooool7000000Cooooo2000000Dooooo`@000003oooool8000000Cooooo303AcJT3ooooo`@0
00002oooool4000000Cooooo2`00000?ooooo`/000001?ooool4000000_ooooo10000003ooooo``0
dLfY1`000004oooooa8000001oooool4000000?ooooo10000003ooooo`@000001ooooolB000000Co
oooo1`00000<0=7=ZET0P8203`3AcJT000h0dLfY1?ooool4000000Cooooo40000004ooooo`@00000
4Oooool4000000Cooooo20000004ooooo``000001?ooool<0=7=Z@@000001?ooool4000000Sooooo
1`000004ooooo`P000005?ooool4000000oooooo20000004ooooo``0dLfY0oooool4000000_ooooo
10000004ooooo`/000003oooool;000000Cooooo1000000;ooooo`@000000oooool<0=7=Z@L00000
1?oooolB000000Oooooo10000003ooooo`@000000oooool4000000Oooooo4P000004ooooo`L00000
303AcJUI0820P0l0dLfY000>0=7=Z@Cooooo10000004oooooa0000001?ooool40000017ooooo1000
0004ooooo`P000001?ooool<000000Cooooo303AcJT4000000Cooooo10000008ooooo`L000001?oo
ool8000001Cooooo1000000?ooooo`P000001?ooool<0=7=Z@?ooooo1000000;ooooo`@000001?oo
ool;000000oooooo2`000004ooooo`@000002oooool4000000?ooooo303AcJT7000000Cooooo4P00
0007ooooo`@000000oooool4000000?ooooo10000007oooooa8000001?ooool7000000`0dLfYF@20
P80?0=7=Z@003P3AcJT4ooooo`@000001?ooool@000000Cooooo1000000Aooooo`@000001?ooool8
000000Cooooo30000004ooooo``0dLfY10000004ooooo`@000002?ooool7000000Cooooo2000000D
ooooo`@000003oooool8000000Cooooo303AcJT7ooooo`@000006_ooool?000001[ooooo10000007
ooooo``0dLfY1`000004ooooo`<000001?ooool;000000?ooooo3`000003ooooo`L000001?ooool7
000000Oooooo10000007ooooo`@00000303AcJUI0820P0l0dLfY000>0=7=Z@Cooooo10000004oooo
oa0000001?ooool40000017ooooo10000004ooooo`P000001?ooool<000000Cooooo303AcJT8oooo
o`@000001?ooool;000000Cooooo3000000<ooooo`P000000oooool8000000Cooooo20000004oooo
o``0dLfY1oooool4000001[ooooo3`00000Jooooo`@000001oooool<0=7=Z@L000001?ooool30000
00Cooooo2`000003ooooo`l000000oooool7000000Cooooo1`000007ooooo`@000001oooool40000
00`0dLfYF@20P80?0=7=Z@003P3AcJT<000000Cooooo1000000<ooooo`@000001?ooool5000000Co
oooo10000004oooooa@000002?ooool4000000`0dLfY2?ooool4000000Cooooo2`000004ooooo``0
00003?ooool8000000?ooooo20000004ooooo`P000001?ooool<0=7=Z@Oooooo1000000Jooooo`l0
00006_ooool4000000Oooooo303AcJT7000000Cooooo0`000004ooooo`/000000oooool?000000?o
oooo1`000004ooooo`L000001oooool4000000Oooooo1000000<0=7=ZET0P8203`3AcJT000h0dLfY
30000004ooooo`@000003?ooool4000000Cooooo1@000004ooooo`@000001?oooolD000000Sooooo
1000000<0=7=Z@Sooooo10000004ooooo`/000001?ooool<000000cooooo20000003ooooo`P00000
1?ooool8000000Cooooo303AcJT7ooooo`@000006_ooool?000001[ooooo10000007ooooo``0dLfY
1?ooool3000000Cooooo0`000008ooooo`L000000oooool4000000Cooooo0`00000;ooooo`L00000
2ooooolB000000`0dLfYF@20P80?0=7=Z@003P3AcJT<000000Cooooo1000000<ooooo`@000001?oo
ool5000000Cooooo10000004oooooa@000002?ooool4000000`0dLfY2?ooool4000000Cooooo2`00
0004ooooo``000003?ooool8000000?ooooo20000004ooooo`P000001?ooool<0=7=Z@_ooooo7P00
0007oooooah000002oooool<0=7=Z@Cooooo0`000004ooooo`<000002?ooool7000000?ooooo1000
0004ooooo`<000002oooool7000000_ooooo4P00000<0=7=ZET0P8203`3AcJT000h0dLfY30000004
ooooo`@000003?ooool4000000Cooooo1@000004ooooo`@000001?oooolD000000Sooooo1000000<
0=7=Z@cooooo20000004ooooo`L000001?ooool4000000Cooooo10000004ooooo`P000002oooool4
000000Cooooo3000000<0=7=Z@_ooooo7P000007oooooah000002oooool<0=7=Z@Cooooo0`000004
ooooo`<000002?ooool7000000?ooooo10000004ooooo`<000002oooool7000000_ooooo4P00000<
0=7=ZET0P8203`3AcJT000h0dLfY20000004ooooo`@000002?oooolI000000cooooo10000004oooo
o`P000002?ooool4000000`0dLfY3?ooool8000000Cooooo1`000004ooooo`@000001?ooool40000
00Cooooo2000000;ooooo`@000001?ooool<000000`0dLfY2ooooolN000000Oooooo7P00000;oooo
o``0dLfY1?ooool3000000Cooooo0`000008ooooo`L000000oooool4000000Cooooo0`00000;oooo
o`L000002ooooolB000000`0dLfYF@20P80?0=7=Z@003P3AcJT8000000Cooooo10000008oooooaT0
00003?ooool4000000Cooooo20000008ooooo`@00000303AcJT<ooooo`P000001?ooool7000000Co
oooo10000004ooooo`@000001?ooool8000000_ooooo10000004ooooo``00000303AcJT;oooooah0
00001ooooolN000000_ooooo303AcJT4000000[ooooo2`00000Booooo`L000001?ooool3000000So
oooo0`000004ooooo`<000002?ooool7000000`0dLfYF@20P80?0=7=Z@003P3AcJT8000000Cooooo
10000008oooooaT000003?ooool4000000Cooooo20000008ooooo`@00000303AcJT4ooooo`@00000
2?ooool;000000Sooooo10000004ooooo`@000001?ooool8000000Cooooo0`000008ooooo`@00000
2?ooool4000000`0dLfY1ooooolC000000Cooooo0`000004ooooo`l000001?ooool3000000Cooooo
4`000007ooooo``0dLfY1000000:ooooo`/000004_ooool7000000Cooooo0`000008ooooo`<00000
1?ooool3000000Sooooo1`00000<0=7=ZET0P8203`3AcJT000h0dLfY20000004ooooo`@000002?oo
oolI000000cooooo10000004ooooo`P000002?ooool4000000`0dLfY1?ooool4000000Sooooo2`00
0008ooooo`@000001?ooool4000000Cooooo20000004ooooo`<000002?ooool4000000Sooooo1000
000<0=7=Z@Oooooo4`000004ooooo`<000001?ooool?000000Cooooo0`000004oooooa<000001ooo
ool<0=7=Z@@000002_ooool;000001;ooooo1`000004ooooo`<000002?ooool3000000Cooooo0`00
0008ooooo`L00000303AcJUI0820P0l0dLfY000>0=7=Z@Cooooo60000004ooooo`P000001Oooool8
000000Cooooo30000004ooooo``000001?ooool<0=7=Z@Cooooo10000008ooooo`/000002?ooool4
000000Cooooo10000004ooooo`P000001?ooool3000000Sooooo10000008ooooo`@00000303AcJT7
oooooa<000001?ooool3000000Cooooo3`000004ooooo`<000001?oooolC000000Oooooo303AcJT4
000000?ooooo10000003ooooo`P000002_ooool8000000?ooooo2`00000Booooo`<000001?ooool;
000000`0dLfYF@20P80?0=7=Z@003P3AcJT4oooooaP000001?ooool8000000Gooooo20000004oooo
o``000001?ooool<000000Cooooo303AcJT4ooooo`@000002?ooool;000000Sooooo10000004oooo
o`@000001?ooool8000000Cooooo0`000008ooooo`@000002?ooool4000000`0dLfY2`00000;oooo
o`@000001?ooool7000000Cooooo1`000004ooooo`L000001?ooool4000000_ooooo2`00000<0=7=
Z@@000000oooool4000000?ooooo2000000:ooooo`P000000oooool;000001;ooooo0`000004oooo
o`/00000303AcJUI0820P0l0dLfY000>0=7=Z@Cooooo60000004ooooo`P000001Oooool8000000Co
oooo30000004ooooo``000001?ooool<0=7=Z@`000001?ooool4000000Cooooo0`000004ooooo``0
00005?ooool7000000Cooooo1000000<ooooo``0dLfY2`00000;ooooo`@000001?ooool7000000Co
oooo1`000004ooooo`L000001?ooool4000000_ooooo2`00000<0=7=Z@@000000oooool4000000?o
oooo2000000:ooooo`P000000oooool;000001;ooooo0`000004ooooo`/00000303AcJUI0820P0l0
dLfY000>0=7=Z@Cooooo60000004ooooo`P000001Oooool8000000Cooooo30000004ooooo``00000
1?ooool<0=7=Z@`000001?ooool4000000Cooooo0`000004ooooo``000005?ooool7000000Cooooo
1000000<ooooo``0dLfY2`00000;ooooo`@000001?ooool7000000Cooooo1`000004ooooo`L00000
1?ooool4000000_ooooo2`00000<0=7=Z@@000000oooool4000000?ooooo2000000:ooooo`P00000
0oooool;000001;ooooo0`000004ooooo`/00000303AcJUI0820P0l0dLfY000>0=7=ZAcooooo1000
0004ooooo`@000001Oooool8000000Cooooo40000004ooooo`P000001?ooool<0=7=Z@`000001?oo
ool4000000Cooooo0`000004ooooo``000005?ooool7000000Cooooo1000000<ooooo``0dLfY2`00
000;ooooo`@000001?ooool7000000Cooooo1`000004ooooo`L000001?ooool4000000_ooooo2`00
000<0=7=Z@@000001oooool;000000Oooooo4P000003ooooo`@000000oooool4000000_ooooo1`00
0004ooooo`L00000303AcJUI0820P0l0dLfY000>0=7=ZAcooooo10000004ooooo`@000001Oooool8
000000Cooooo40000004ooooo`P000001?ooool<0=7=Z@`000001?ooool4000000Cooooo0`000004
ooooo``000005?ooool7000000Cooooo1000000<ooooo``0dLfY0oooool4000000Cooooo1`000004
ooooo`/000001?ooool4000000Oooooo10000004ooooo`/000001?ooool7000000Cooooo10000003
ooooo``0dLfY10000007ooooo`/000001ooooolB000000?ooooo10000003ooooo`@000002oooool7
000000Cooooo1`00000<0=7=ZET0P8203`3AcJT000h0dLfY7?ooool4000000Cooooo10000005oooo
o`P000001?ooool@000000Cooooo20000004ooooo``0dLfY2?ooool4000000Cooooo10000004oooo
o`<000002?ooool4000000cooooo10000004ooooo`@000000ooooolH000000`0dLfY0oooool40000
00Cooooo1`000004ooooo`/000001?ooool4000000Oooooo10000004ooooo`/000001?ooool70000
00Cooooo10000003ooooo``0dLfY10000007ooooo`/000001ooooolB000000?ooooo10000003oooo
o`@000002oooool7000000Cooooo1`00000<0=7=ZET0P8203`3AcJT000h0dLfY7?ooool4000000Co
oooo10000005ooooo`P000001?ooool@000000Cooooo20000004ooooo``0dLfY2?ooool4000000Co
oooo10000004ooooo`<000002?ooool4000000cooooo10000004ooooo`@000000ooooolH000000`0
dLfY0oooool4000000Cooooo1`000004ooooo`/000001?ooool4000000Oooooo10000004ooooo`/0
00001?ooool7000000Cooooo10000003ooooo``0dLfY1?ooool3000000Cooooo3P000007ooooo`P0
00001oooool3000000Cooooo2`000003ooooo`/000001?ooool7000000`0dLfYF@20P80?0=7=Z@00
3P3AcJT@000000cooooo10000004ooooo`@000004OoooolD000000Cooooo2000000<0=7=Z@Sooooo
10000004ooooo`@000001?ooool3000000Sooooo1000000<ooooo`@000001?ooool4000000?ooooo
6000000<0=7=Z@?ooooo10000004ooooo`L000001?ooool;000000Cooooo10000007ooooo`@00000
1?ooool;000000Cooooo1`000004ooooo`@000000oooool<0=7=Z@Cooooo0`000004ooooo`h00000
1oooool8000000Oooooo0`000004ooooo`/000000oooool;000000Cooooo1`00000<0=7=ZET0P820
3`3AcJT000h0dLfY4000000<ooooo`@000001?ooool40000017ooooo50000004ooooo`P00000303A
cJT8ooooo`@000001?ooool4000000Cooooo0`000008ooooo`@000003?ooool4000000Cooooo1000
0003oooooaP00000303AcJT3000000Cooooo8P000007ooooob8000001?ooool3000000`0dLfY1?oo
ool3000000Cooooo3P000007ooooo`P000001oooool3000000Cooooo2`000003ooooo`/000001?oo
ool7000000`0dLfYF@20P80?0=7=Z@003P3AcJT@000000cooooo10000004ooooo`@000004OoooolD
000000Cooooo2000000<0=7=Z@`000001?ooool4000000Oooooo30000004oooooa0000003oooool4
000000Sooooo1000000<0=7=Z@<000001?oooolR000000Oooooo8P000004ooooo`<00000303AcJT4
ooooo`<000001?ooool>000000Oooooo20000007ooooo`<000001?ooool;000000?ooooo2`000004
ooooo`L00000303AcJUI0820P0l0dLfY000>0=7=Z@Sooooo3000000<ooooo`@000001?ooool90000
013ooooo10000004ooooo`@000003?ooool<0=7=Z@`000001?ooool4000000Oooooo30000004oooo
oa0000003oooool4000000Sooooo1000000<0=7=Z@<000001?oooolR000000Oooooo8P000004oooo
o`<00000303AcJT7ooooo`@000000oooool8000000?ooooo1000000;ooooo`X000001?ooool30000
00Cooooo10000003ooooo`L000001?ooool4000000Oooooo303AcJUI0820P0l0dLfY000>0=7=Z@So
oooo3000000<ooooo`@000001?ooool90000013ooooo10000004ooooo`@000003?ooool<0=7=Z@`0
00001?ooool4000000Oooooo30000004oooooa0000003oooool4000000Sooooo1000000<0=7=Z@<0
00001?ooool?000000Cooooo1`00000Gooooo`L000001?ooool?000000Cooooo0`00000<0=7=Z@Oo
oooo10000003ooooo`P000000oooool4000000_ooooo2P000004ooooo`<000001?ooool4000000?o
oooo1`000004ooooo`@000001oooool<0=7=ZET0P8203`3AcJT000h0dLfY2?ooool<000000cooooo
10000004ooooo`T000004?ooool4000000Cooooo1000000<ooooo``0dLfY30000004ooooo`@00000
1oooool<000000Cooooo4000000?ooooo`@000002?ooool4000000`0dLfY0`000004ooooo`l00000
1?ooool7000001Oooooo1`000004ooooo`l000001?ooool3000000`0dLfY1oooool4000000?ooooo
20000003ooooo`@000002oooool:000000Cooooo0`000004ooooo`@000000oooool7000000Cooooo
10000007ooooo``0dLfYF@20P80?0=7=Z@003P3AcJT8ooooo``000003?ooool4000000Cooooo2@00
000@ooooo`@000001?ooool4000000cooooo303AcJT4ooooo`@000004oooool4000000Cooooo1000
0004ooooo`@000005oooool4000000cooooo1000000<0=7=Z@<000001?ooool?000000Cooooo1`00
000Gooooo`L000001?ooool?000000Cooooo0`00000<0=7=Z@Cooooo0`000004ooooo`<000001?oo
ool>000000Cooooo1000000:ooooo`L000003oooool;000000?ooooo1000000<0=7=ZET0P8203`3A
cJT000h0dLfY10000004oooooa0000001?ooool8000000Cooooo2@000004ooooo`@000001?ooool8
000000Cooooo10000004ooooo`@000001?ooool<0=7=Z@Cooooo1000000Cooooo`@000001?ooool4
000000Cooooo1000000Gooooo`@000003?ooool4000000`0dLfY0`000004ooooo`l000001?ooool7
000001Oooooo1`000004ooooo`l000001?ooool3000000`0dLfY1?ooool3000000Cooooo0`000004
ooooo`h000001?ooool4000000[ooooo1`00000?ooooo`/000000oooool4000000`0dLfYF@20P80?
0=7=Z@003P3AcJT4000000Cooooo40000004ooooo`P000001?ooool9000000Cooooo10000004oooo
o`P000001?ooool4000000Cooooo10000004ooooo``0dLfY1?ooool4000001?ooooo10000004oooo
o`@000001?ooool4000001Oooooo1000000<ooooo`@00000303AcJT?ooooo`<000003?ooool70000
00Cooooo1`000004ooooo`L000003?ooool3000000oooooo303AcJT4ooooo`<000001?ooool30000
00Cooooo3P000004ooooo`@000002_ooool7000000oooooo2`000003ooooo`@00000303AcJUI0820
P0l0dLfY000>0=7=Z@@000001?ooool@000000Cooooo20000004ooooo`T000001?ooool4000000Co
oooo20000004ooooo`@000001?ooool4000000Cooooo303AcJT4ooooo`@000004oooool4000000Co
oooo10000004ooooo`@000005oooool4000000cooooo1000000<0=7=Z@oooooo0`00000<ooooo`L0
00001?ooool7000000Cooooo1`00000<ooooo`<000003oooool<0=7=Z@Cooooo0`000004ooooo`<0
00001?ooool>000000Cooooo1000000:ooooo`L000003oooool;000000?ooooo1000000<0=7=ZET0
P8203`3AcJT000h0dLfY10000004oooooa0000001?ooool8000000Cooooo2@000004ooooo`@00000
1?ooool8000000Cooooo10000004ooooo`@000001?ooool<0=7=ZEX00000303AcJT?ooooo`<00000
3?ooool7000000Cooooo1`000004ooooo`L000003?ooool3000000oooooo303AcJUJ000000`0dLfY
F@20P80?0=7=Z@003P3AcJT4000000Cooooo40000004ooooo`P000001?ooool9000000Cooooo1000
0004ooooo`P000001?ooool4000000Cooooo10000004ooooo``0dLfYFP00000<0=7=Z@<000002?oo
ool4000000oooooo1`000004ooooo`L000001?ooool7000000oooooo10000008ooooo`<00000303A
cJUJ000000`0dLfYF@20P80?0=7=Z@003P3AcJT4000000Cooooo40000004ooooo`P000001?ooool9
000000Cooooo10000004ooooo`P000001?ooool4000000Cooooo10000004ooooo``0dLfYFP00000<
0=7=Z@<000002?ooool4000000oooooo1`000004ooooo`L000001?ooool7000000oooooo10000008
ooooo`<00000303AcJUJ000000`0dLfYF@20P80?0=7=Z@003P3AcJT4000000Cooooo40000004oooo
o`P000001?ooool9000000Cooooo10000004ooooo`P000001?ooool4000000Cooooo10000004oooo
o``0dLfY1?ooool4000001?ooooo10000004ooooo`@000001?ooool4000001Oooooo1000000<oooo
o`@00000303AcJT3000000Sooooo1000000?ooooo`L000001?ooool7000000Cooooo1`00000?oooo
o`@000002?ooool3000000`0dLfY1?ooool3000000Cooooo0`000004ooooo`h000001?ooool40000
00[ooooo1`00000?ooooo`/000000oooool4000000`0dLfYF@20P80?0=7=Z@003P3AcJT4000000Co
oooo40000004ooooo`P000001?ooool9000000Cooooo10000004ooooo`P000001?ooool4000000Co
oooo10000004ooooo``0dLfY1?ooool4000001?ooooo10000004ooooo`@000001?ooool4000001Oo
oooo1000000<ooooo`@00000303AcJT3000000Sooooo1000000?ooooo`L000001?ooool7000000Co
oooo1`00000?ooooo`@000002?ooool3000000`0dLfY1?ooool3000000Cooooo0`000004ooooo`h0
00001?ooool4000000[ooooo1`00000?ooooo`/000000oooool4000000`0dLfYF@20P80?0=7=Z@00
3P3AcJT8ooooo``000003?ooool4000000Cooooo2@00000@ooooo`@000001?ooool4000000cooooo
303AcJT4ooooo`@000004oooool4000000Cooooo10000004ooooo`@000005oooool4000000cooooo
1000000<0=7=Z@?ooooo20000004ooooo`l000000oooool4000000oooooo10000003ooooo`l00000
1?ooool8000000?ooooo303AcJT4ooooo`<000001?ooool3000000Cooooo3P000004ooooo`@00000
2_ooool7000000oooooo2`000003ooooo`@00000303AcJUI0820P0l0dLfY000>0=7=Z@Sooooo3000
000<ooooo`@000001?ooool90000013ooooo10000004ooooo`@000003?ooool<0=7=Z@Cooooo1000
000Cooooo`@000001?ooool4000000Cooooo1000000Gooooo`@000003?ooool4000000`0dLfY0ooo
ool8000000Cooooo3`000003ooooo`@000003oooool4000000?ooooo3`000004ooooo`P000000ooo
ool<0=7=Z@Cooooo0`000004ooooo`<000001?ooool>000000Cooooo1000000:ooooo`L000003ooo
ool;000000?ooooo1000000<0=7=ZET0P8203`3AcJT000h0dLfY2?ooool<000000cooooo10000004
ooooo`T000004?ooool4000000Cooooo1000000<ooooo``0dLfY30000004ooooo`@000001oooool<
000000Cooooo4000000?ooooo`@000002?ooool4000000`0dLfY0oooool8000000Cooooo3`000003
ooooo`@000003oooool4000000?ooooo3`000004ooooo`P000000oooool<0=7=Z@Oooooo10000003
ooooo`P000000oooool4000000_ooooo2P000004ooooo`<000001?ooool4000000?ooooo1`000004
ooooo`@000001oooool<0=7=ZET0P8203`3AcJT000h0dLfY2?ooool<000000cooooo10000004oooo
o`T000004?ooool4000000Cooooo1000000<ooooo``0dLfY30000004ooooo`@000001oooool<0000
00Cooooo4000000?ooooo`@000002?ooool4000000`0dLfY0oooool8000000Cooooo3`000003oooo
o`@000003oooool4000000?ooooo3`000004ooooo`P000000oooool<0=7=Z@Oooooo10000003oooo
o`P000000oooool4000000_ooooo2P000004ooooo`<000001?ooool4000000?ooooo1`000004oooo
o`@000001oooool<0=7=ZET0P8203`3AcJT000h0dLfY4000000<ooooo`@000001?ooool40000017o
oooo50000004ooooo`P00000303AcJT<000000Cooooo10000007ooooo``000001?ooool@000000oo
oooo10000008ooooo`@00000303AcJT7ooooo`@000001?ooool7000000Cooooo2`00000?ooooo`/0
00001?ooool7000000Cooooo10000007ooooo``0dLfY1oooool4000000?ooooo20000003ooooo`@0
00002oooool:000000Cooooo0`000004ooooo`@000000oooool7000000Cooooo10000007ooooo``0
dLfYF@20P80?0=7=Z@003P3AcJT@000000cooooo10000004ooooo`@000004OoooolD000000Cooooo
2000000<0=7=Z@`000001?ooool4000000Oooooo30000004oooooa0000003oooool4000000Sooooo
1000000<0=7=Z@Oooooo10000004ooooo`L000001?ooool;000000oooooo2`000004ooooo`L00000
1?ooool4000000Oooooo303AcJT4ooooo`<000001?ooool>000000Oooooo20000007ooooo`<00000
1?ooool;000000?ooooo2`000004ooooo`L00000303AcJUI0820P0l0dLfY000>0=7=ZA0000003?oo
ool4000000Cooooo1000000Aoooooa@000001?ooool8000000`0dLfY2?ooool4000000Cooooo1000
0004ooooo`<000002?ooool4000000cooooo10000004ooooo`@000000ooooolH000000`0dLfY1ooo
ool4000000Cooooo1`000004ooooo`/000003oooool;000000Cooooo1`000004ooooo`@000001ooo
ool<0=7=Z@Cooooo0`000004ooooo`h000001oooool8000000Oooooo0`000004ooooo`/000000ooo
ool;000000Cooooo1`00000<0=7=ZET0P8203`3AcJT000h0dLfY4000000<ooooo`@000001?ooool4
0000017ooooo50000004ooooo`P00000303AcJT8ooooo`@000001?ooool4000000Cooooo0`000008
ooooo`@000003?ooool4000000Cooooo10000003oooooaP00000303AcJT3000000Cooooo10000007
ooooo`P000001?ooool3000001Oooooo0`000004ooooo`P000001oooool4000000Cooooo0`00000<
0=7=Z@Cooooo0`000004ooooo`h000001oooool8000000Oooooo0`000004ooooo`/000000oooool;
000000Cooooo1`00000<0=7=ZET0P8203`3AcJT000h0dLfY7?ooool4000000Cooooo10000005oooo
o`P000001?ooool@000000Cooooo20000004ooooo``0dLfY2?ooool4000000Cooooo10000004oooo
o`<000002?ooool4000000cooooo10000004ooooo`@000000ooooolH000000`0dLfY0`000004oooo
o`@000001oooool8000000Cooooo0`00000Gooooo`<000001?ooool8000000Oooooo10000004oooo
o`<00000303AcJT4ooooo`<000001?ooool>000000Oooooo20000007ooooo`<000001?ooool;0000
00?ooooo2`000004ooooo`L00000303AcJUI0820P0l0dLfY000>0=7=ZAcooooo10000004ooooo`@0
00001Oooool8000000Cooooo40000004ooooo`P000001?ooool<0=7=Z@Sooooo10000004ooooo`@0
00001?ooool3000000Sooooo1000000<ooooo`@000001?ooool4000000?ooooo6000000<0=7=Z@<0
00001?ooool4000000Oooooo20000004ooooo`<000005oooool3000000Cooooo20000007ooooo`@0
00001?ooool3000000`0dLfY10000007ooooo`/000001ooooolB000000?ooooo10000003ooooo`@0
00002oooool7000000Cooooo1`00000<0=7=ZET0P8203`3AcJT000h0dLfY7?ooool4000000Cooooo
10000005ooooo`P000001?ooool@000000Cooooo20000004ooooo``0dLfY30000004ooooo`@00000
1?ooool3000000Cooooo3000000Dooooo`L000001?ooool4000000cooooo303AcJT3000000Cooooo
10000007ooooo`P000001?ooool3000001Oooooo0`000004ooooo`P000001oooool4000000Cooooo
0`00000<0=7=Z@@000001oooool;000000Oooooo4P000003ooooo`@000000oooool4000000_ooooo
1`000004ooooo`L00000303AcJUI0820P0l0dLfY000>0=7=ZAcooooo10000004ooooo`@000001Ooo
ool8000000Cooooo40000004ooooo`P000001?ooool<0=7=Z@`000001?ooool4000000Cooooo0`00
0004ooooo``000005?ooool7000000Cooooo1000000<ooooo``0dLfY0oooool8000000Cooooo1`00
000;ooooo`@000001?ooool7000000Cooooo1000000;ooooo`L000001?ooool8000000?ooooo303A
cJT4000000Oooooo2`000007oooooa8000000oooool4000000?ooooo1000000;ooooo`L000001?oo
ool7000000`0dLfYF@20P80?0=7=Z@003P3AcJT4oooooaP000001?ooool8000000Gooooo20000004
ooooo``000001?ooool<000000Cooooo303AcJT<000000Cooooo10000004ooooo`<000001?ooool<
000001Cooooo1`000004ooooo`@000003?ooool<0=7=Z@?ooooo20000004ooooo`L000002oooool4
000000Cooooo1`000004ooooo`@000002oooool7000000Cooooo20000003ooooo``0dLfY10000003
ooooo`@000000oooool8000000[ooooo20000003ooooo`/000004_ooool3000000Cooooo2`00000<
0=7=ZET0P8203`3AcJT000h0dLfY1?oooolH000000Cooooo20000005ooooo`P000001?ooool<0000
00Cooooo30000004ooooo``0dLfY30000004ooooo`@000001?ooool3000000Cooooo3000000Doooo
o`L000001?ooool4000000cooooo303AcJT3ooooo`P000001?ooool7000000_ooooo10000004oooo
o`L000001?ooool4000000_ooooo1`000004ooooo`P000000oooool<0=7=Z@@000000oooool40000
00?ooooo2000000:ooooo`P000000oooool;000001;ooooo0`000004ooooo`/00000303AcJUI0820
P0l0dLfY000>0=7=Z@Cooooo60000004ooooo`P000001Oooool8000000Cooooo30000004ooooo``0
00001?ooool<0=7=Z@Cooooo10000008ooooo`/000002?ooool4000000Cooooo10000004ooooo`P0
00001?ooool3000000Sooooo10000008ooooo`@00000303AcJT3ooooo`P000001?ooool7000000_o
oooo10000004ooooo`L000001?ooool4000000_ooooo1`000004ooooo`P000000oooool<0=7=Z@@0
00000oooool4000000?ooooo2000000:ooooo`P000000oooool;000001;ooooo0`000004ooooo`/0
0000303AcJUI0820P0l0dLfY000>0=7=Z@Cooooo60000004ooooo`P000001Oooool8000000Cooooo
30000004ooooo``000001?ooool<0=7=Z@Cooooo10000008ooooo`/000002?ooool4000000Cooooo
10000004ooooo`P000001?ooool3000000Sooooo10000008ooooo`@00000303AcJT3ooooo`@00000
3oooool?000000Cooooo1`000004ooooo`l000003oooool4000000?ooooo303AcJT4000000?ooooo
10000003ooooo`P000002_ooool8000000?ooooo2`00000Booooo`<000001?ooool;000000`0dLfY
F@20P80?0=7=Z@003P3AcJT8000000Cooooo10000008oooooaT000003?ooool4000000Cooooo2000
0008ooooo`@00000303AcJT4ooooo`@000002?ooool;000000Sooooo10000004ooooo`@000001?oo
ool8000000Cooooo0`000008ooooo`@000002?ooool4000000`0dLfY0oooool4000000oooooo3`00
0004ooooo`L000001?ooool?000000oooooo10000003ooooo``0dLfY1000000:ooooo`/000004_oo
ool7000000Cooooo0`000008ooooo`<000001?ooool3000000Sooooo1`00000<0=7=ZET0P8203`3A
cJT000h0dLfY20000004ooooo`@000002?oooolI000000cooooo10000004ooooo`P000002?ooool4
000000`0dLfY3?ooool8000000Cooooo1`000004ooooo`@000001?ooool4000000Cooooo2000000;
ooooo`@000001?ooool<000000`0dLfY0oooool4000000oooooo3`000004ooooo`L000001?ooool?
000000oooooo10000003ooooo``0dLfY1000000:ooooo`/000004_ooool7000000Cooooo0`000008
ooooo`<000001?ooool3000000Sooooo1`00000<0=7=ZET0P8203`3AcJT000h0dLfY20000004oooo
o`@000002?oooolI000000cooooo10000004ooooo`P000002?ooool4000000`0dLfY3?ooool80000
00Cooooo1`000004ooooo`@000001?ooool4000000Cooooo2000000;ooooo`@000001?ooool<0000
00`0dLfY0`000004ooooo`P000000oooool4000000_ooooo20000007ooooo`P000002oooool40000
00?ooooo20000004ooooo`<00000303AcJT4000000[ooooo2`00000Booooo`L000001?ooool30000
00Sooooo0`000004ooooo`<000002?ooool7000000`0dLfYF@20P80?0=7=Z@003P3AcJT8000000Co
oooo10000008oooooaT000003?ooool4000000Cooooo20000008ooooo`@00000303AcJT<ooooo`P0
00001?ooool7000000Cooooo10000004ooooo`@000001?ooool8000000_ooooo10000004ooooo``0
0000303AcJT3000000Cooooo20000003ooooo`@000002oooool8000000Oooooo2000000;ooooo`@0
00000oooool8000000Cooooo0`00000<0=7=Z@Cooooo0`000004ooooo`<000002?ooool7000000?o
oooo10000004ooooo`<000002oooool7000000_ooooo4P00000<0=7=ZET0P8203`3AcJT000h0dLfY
30000004ooooo`@000003?ooool4000000Cooooo1@000004ooooo`@000001?oooolD000000Sooooo
1000000<0=7=Z@cooooo20000004ooooo`L000001?ooool4000000Cooooo10000004ooooo`P00000
2oooool4000000Cooooo3000000<0=7=Z@<000001?ooool8000000?ooooo1000000;ooooo`P00000
1oooool8000000_ooooo10000003ooooo`P000001?ooool3000000`0dLfY1?ooool3000000Cooooo
0`000008ooooo`L000000oooool4000000Cooooo0`00000;ooooo`L000002ooooolB000000`0dLfY
F@20P80?0=7=Z@003P3AcJT<000000Cooooo1000000<ooooo`@000001?ooool5000000Cooooo1000
0004oooooa@000002?ooool4000000`0dLfY2?ooool4000000Cooooo2`000004ooooo``000003?oo
ool8000000?ooooo20000004ooooo`P000001?ooool<0=7=Z@<000001?ooool8000000?ooooo1000
000;ooooo`P000001oooool8000000_ooooo10000003ooooo`P000001?ooool3000000`0dLfY1?oo
ool3000000Cooooo0`000008ooooo`L000000oooool4000000Cooooo0`00000;ooooo`L000002ooo
oolB000000`0dLfYF@20P80?0=7=Z@003P3AcJT<000000Cooooo1000000<ooooo`@000001?ooool5
000000Cooooo10000004oooooa@000002?ooool4000000`0dLfY2?ooool4000000Cooooo2`000004
ooooo``000003?ooool8000000?ooooo20000004ooooo`P000001?ooool<0=7=Z@<000001?ooool8
000000?ooooo3`000004ooooo`@000001oooool4000000Cooooo3`000003ooooo`P000001?ooool3
000000`0dLfY1?ooool3000000Cooooo0`000008ooooo`L000000oooool4000000Cooooo0`00000;
ooooo`L000002ooooolB000000`0dLfYF@20P80?0=7=Z@003P3AcJT<000000Cooooo1000000<oooo
o`@000001?ooool5000000Cooooo10000004oooooa@000002?ooool4000000`0dLfY2?ooool40000
00Cooooo2`000004ooooo``000003?ooool8000000?ooooo20000004ooooo`P000001?ooool<0=7=
Z@<000001?ooool8000000?ooooo3`000004ooooo`@000001oooool4000000Cooooo3`000003oooo
o`P000001?ooool3000000`0dLfY1`000004ooooo`<000001?ooool;000000?ooooo3`000003oooo
o`L000001?ooool7000000Oooooo10000007ooooo`@00000303AcJUI0820P0l0dLfY000>0=7=Z@Co
oooo10000004oooooa0000001?ooool40000017ooooo10000004ooooo`P000001?ooool<000000Co
oooo303AcJT8ooooo`@000001?ooool;000000Cooooo3000000<ooooo`P000000oooool8000000Co
oooo20000004ooooo``0dLfY0`000004ooooo`P000000oooool?000000Cooooo10000007ooooo`@0
00001?ooool?000000?ooooo20000004ooooo`<00000303AcJT7000000Cooooo0`000004ooooo`/0
00000oooool?000000?ooooo1`000004ooooo`L000001oooool4000000Oooooo1000000<0=7=ZET0
P8203`3AcJT000h0dLfY1?ooool4000000Cooooo40000004ooooo`@000004Oooool4000000Cooooo
20000004ooooo``000001?ooool<0=7=Z@@000001?ooool4000000Sooooo1`000004ooooo`P00000
5?ooool4000000oooooo20000004ooooo``0dLfY0`000004ooooo`P000000oooool?000000Cooooo
10000007ooooo`@000001?ooool?000000?ooooo20000004ooooo`<00000303AcJT7000000Cooooo
0`000004ooooo`/000000oooool?000000?ooooo1`000004ooooo`L000001oooool4000000Oooooo
1000000<0=7=ZET0P8203`3AcJT000h0dLfY1?ooool4000000Cooooo40000004ooooo`@000004Ooo
ool4000000Cooooo20000004ooooo``000001?ooool<0=7=Z@@000001?ooool4000000Sooooo1`00
0004ooooo`P000005?ooool4000000oooooo20000004ooooo``0dLfY0`000004ooooo`@000001?oo
ool?000000Oooooo3`000007ooooo`l000001?ooool4000000Cooooo0`00000<0=7=Z@L000001?oo
oolB000000Oooooo10000003ooooo`@000000oooool4000000Oooooo4P000004ooooo`L00000303A
cJUI0820P0l0dLfY000>0=7=Z@Cooooo10000004oooooa0000001?ooool40000017ooooo10000004
ooooo`P000001?ooool<000000Cooooo303AcJT4000000Cooooo10000008ooooo`L000001?ooool8
000001Cooooo1000000?ooooo`P000001?ooool<0=7=Z@<000001?ooool4000000Cooooo3`000007
ooooo`l000001oooool?000000Cooooo10000004ooooo`<00000303AcJT7000000Cooooo4P000007
ooooo`@000000oooool4000000?ooooo10000007oooooa8000001?ooool7000000`0dLfYF@20P80?
0=7=Z@003P3AcJT4ooooo`@000001?ooool4000000Cooooo10000008ooooo`@000001?ooool50000
00Cooooo10000004ooooo`@000001?ooool8000000Sooooo2000000<0=7=Z@@000001?ooool40000
00Sooooo1`000004ooooo`P000005?ooool4000000oooooo20000004ooooo``0dLfY0`000004oooo
o`@000001?ooool?000000Oooooo3`000007ooooo`l000001?ooool4000000Cooooo0`00000<0=7=
Z@L000001?oooolB000000Oooooo10000003ooooo`@000000oooool4000000Oooooo4P000004oooo
o`L00000303AcJUI0820P0l0dLfY000>0=7=Z@Cooooo10000004ooooo`@000001?ooool4000000So
oooo10000004ooooo`D000001?ooool4000000Cooooo10000004ooooo`P000002?ooool8000000`0
dLfY20000008ooooo`@000001?ooool7000000cooooo10000004ooooo`@000002?ooool;000000So
oooo10000004ooooo``0dLfY0`000004ooooo`@000001?ooool3000000cooooo2`000007ooooo`/0
00003?ooool3000000Cooooo10000004ooooo`<00000303AcJT7000000Cooooo4P000007ooooo`@0
00000oooool4000000?ooooo10000007oooooa8000001?ooool7000000`0dLfYF@20P80?0=7=Z@00
3P3AcJT4ooooo`@000001?ooool4000000Cooooo10000008ooooo`@000001?ooool5000000Cooooo
10000004ooooo`@000001?ooool8000000Sooooo2000000<0=7=Z@P000002?ooool4000000Cooooo
1`00000<ooooo`@000001?ooool4000000Sooooo2`000008ooooo`@000001?ooool<0=7=Z@<00000
1?ooool4000000Cooooo0`00000<ooooo`/000001oooool;000000cooooo0`000004ooooo`@00000
1?ooool3000000`0dLfY1?ooool7000000?ooooo10000004ooooo`<000002oooool;000000?ooooo
1000000;ooooo`X000001?ooool4000000Oooooo303AcJUI0820P0l0dLfY000>0=7=Z@Cooooo1000
0004ooooo`@000001?ooool4000000Sooooo10000004ooooo`D000001?ooool4000000Cooooo1000
0004ooooo`P000002?ooool8000000`0dLfY20000008ooooo`@000001?ooool7000000cooooo1000
0004ooooo`@000002?ooool;000000Sooooo10000004ooooo``0dLfY0`000004ooooo`@000001?oo
ool3000000cooooo2`000007ooooo`/000003?ooool3000000Cooooo10000004ooooo`<00000303A
cJT4ooooo`L000000oooool4000000Cooooo0`00000;ooooo`/000000oooool4000000_ooooo2P00
0004ooooo`@000001oooool<0=7=ZET0P8203`3AcJT000h0dLfY1?ooool4000000Sooooo10000004
ooooo`@000001?ooool4000000Wooooo10000004oooooa0000003?ooool8000000`0dLfY20000008
ooooo`@000001?ooool7000000cooooo10000004ooooo`@000002?ooool;000000Sooooo10000004
ooooo``0dLfY0`000004ooooo`@000001?ooool3000000cooooo2`000007ooooo`/000003?ooool3
000000Cooooo10000004ooooo`<00000303AcJT4ooooo`L000000oooool4000000Cooooo0`00000;
ooooo`/000000oooool4000000_ooooo2P000004ooooo`@000001oooool<0=7=ZET0P8203`3AcJT0
00h0dLfY1?ooool4000000Sooooo10000004ooooo`@000001?ooool4000000Wooooo10000004oooo
oa0000003?ooool8000000`0dLfY20000004ooooo`@000002?ooool3000000Cooooo4000000<oooo
o`@000000oooool8000000Sooooo2000000<0=7=Z@<000001?ooool4000000Oooooo10000004oooo
o`@000001oooool?000000Oooooo10000004ooooo`@000001oooool4000000Cooooo0`00000<0=7=
Z@@000000oooool7000000Cooooo2`00000Booooo`<000001oooool4000000Oooooo2`00000;oooo
o``0dLfYF@20P80?0=7=Z@003P3AcJT4ooooo`@000002?ooool4000000Cooooo10000004ooooo`@0
00002Oooool4000000Cooooo4000000<ooooo`P00000303AcJT8000000Cooooo10000008ooooo`<0
00001?ooool@000000cooooo10000003ooooo`P000002?ooool8000000`0dLfY0`000004ooooo`@0
00001oooool4000000Cooooo10000007ooooo`l000001oooool4000000Cooooo10000007ooooo`@0
00001?ooool3000000`0dLfY10000003ooooo`L000001?ooool;000001;ooooo0`000007ooooo`@0
00001oooool;000000_ooooo303AcJUI0820P0l0dLfY000>0=7=Z@Cooooo10000008ooooo`@00000
1?ooool4000000Cooooo10000009ooooo`@000001?ooool@000000cooooo2000000<0=7=Z@P00000
1?ooool4000000Sooooo0`000004oooooa0000003?ooool4000000?ooooo20000008ooooo`P00000
303AcJT3000000Cooooo10000007ooooo`@000001?ooool4000000Oooooo3`000007ooooo`@00000
1?ooool4000000Oooooo10000004ooooo`<00000303AcJT4000000?ooooo1`000004ooooo`/00000
4_ooool3000000Oooooo10000007ooooo`/000002oooool<0=7=ZET0P8203`3AcJT000h0dLfY1000
0004ooooo`@000002?ooool4000000Sooooo10000004ooooo`D000002?ooool4000000Sooooo1000
000<ooooo`@000001?ooool<0=7=Z@@000002?ooool?000000Sooooo10000004oooooa@000001ooo
ool4000000Cooooo10000008ooooo``0dLfY0`000004ooooo`@000001oooool4000000Cooooo1000
0007ooooo`l000001oooool4000000Cooooo10000007ooooo`@000001?ooool3000000`0dLfY1000
0003ooooo`L000001?ooool;000001;ooooo0`000007ooooo`@000001oooool;000000_ooooo303A
cJUI0820P0l0dLfY000>0=7=Z@@000001?ooool4000000Sooooo10000008ooooo`@000001?ooool5
000000Sooooo10000008ooooo`@000003?ooool4000000Cooooo303AcJT4000000Sooooo3`000008
ooooo`@000001?oooolD000000Oooooo10000004ooooo`@000002?ooool<0=7=Z@<000003oooool4
000000Cooooo9@000004ooooo`@000003oooool3000000`0dLfY1?ooool3000000_ooooo1000000B
ooooo`L000001oooool30000027ooooo303AcJUI0820P0l0dLfY000>0=7=Z@@000001?ooool40000
00Sooooo10000008ooooo`@000001?ooool5000000Sooooo10000008ooooo`@000003?ooool40000
00Cooooo303AcJT4000000Sooooo3`000008ooooo`@000001?oooolD000000Oooooo10000004oooo
o`@000002?ooool<0=7=Z@<000003oooool4000000Cooooo9@000004ooooo`@000003oooool30000
00`0dLfY1?ooool3000000_ooooo1000000Booooo`L000001oooool30000027ooooo303AcJUI0820
P0l0dLfY000>0=7=Z@@000001?ooool4000000Sooooo10000008ooooo`@000001?ooool5000000So
oooo10000008ooooo`@000003?ooool4000000Cooooo303AcJT4000000Sooooo3`000008ooooo`@0
00001?oooolD000000Oooooo10000004ooooo`@000002?ooool<0=7=Z@<000003oooool4000000Co
oooo9@000004ooooo`@000003oooool3000000`0dLfY1?ooool3000000_ooooo1000000Booooo`L0
00001oooool30000027ooooo303AcJUI0820P0l0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3A
cJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00
o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=
Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o
0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@003P3AcJT:000001Gooooo1P000005ooooo`D0
00001Oooool6000001[ooooo1@00000<0=7=Z@Gooooo1@00001@ooooo``0dLfY3_oooolC000000Wo
oooo1@000009oooooa<000003_ooool<0=7=Z@Wooooo1@000008ooooo`h000001?ooool9000000Go
oooo3@000009ooooo`D000002Oooool<0=7=Z@@000001?ooool9000000Cooooo10000004ooooo`D0
00003?ooool5000000Cooooo2@000004ooooo`@000002Oooool4000000Cooooo3`3AcJT000h0dLfY
2P00000Eooooo`H000001Oooool5000000Gooooo1P00000Jooooo`D00000303AcJT5ooooo`D00000
D?ooool<0=7=Z@kooooo4`000009ooooo`D000002OoooolC000000kooooo303AcJT9ooooo`D00000
2?ooool>000000Cooooo2@000005ooooo`d000002Oooool5000000Wooooo303AcJT4000000Cooooo
2@000004ooooo`@000001?ooool5000000cooooo1@000004ooooo`T000001?ooool4000000Wooooo
10000004ooooo`l0dLfY000>0=7=Z@X000005Oooool6000000Gooooo1@000005ooooo`H000006_oo
ool5000000`0dLfY1Oooool50000053ooooo303AcJT>oooooa<000002Oooool5000000Wooooo4`00
000>ooooo``0dLfY2Oooool5000000Sooooo3P000004ooooo`T000001Oooool=000000Wooooo1@00
0009ooooo``0dLfY10000004ooooo`T000001?ooool4000000Cooooo1@00000<ooooo`D000001?oo
ool9000000Cooooo10000009ooooo`@000001?ooool?0=7=Z@003P3AcJT:000001Gooooo1P000005
ooooo`D000001Oooool6000001[ooooo1@00000<0=7=Z@Gooooo1@00001@ooooo``0dLfY3_oooolC
000000Wooooo1@000009oooooa<000003_ooool<0=7=Z@Wooooo1@000008ooooo`h000001?ooool9
000000Gooooo3@000009ooooo`D000002Oooool<0=7=Z@@000001?ooool9000000Cooooo10000004
ooooo`D000003?ooool5000000Cooooo2@000004ooooo`@000002Oooool4000000Cooooo3`3AcJT0
00h0dLfY2P00000Eooooo`H000001Oooool5000000Gooooo1P00000Jooooo`D00000303AcJT5oooo
o`D00000D?ooool<0=7=Z@kooooo4`000009ooooo`D000002OoooolC000000kooooo303AcJT9oooo
o`D000002?ooool>000000Cooooo2@000005ooooo`d000002Oooool5000000Wooooo303AcJT4oooo
o`@000001?ooool=000000Cooooo1@000004ooooo`@000001?ooool5000000Cooooo10000009oooo
o`P000001Oooool8000000l0dLfY000>0=7=Z@X000001_ooool?000002Gooooo1P00000?ooooo``0
dLfY1@000005ooooo`D000003oooool5000002gooooo2P00000<0=7=Z@h000002Oooool>000000Go
oooo1@000005ooooo`h000002Oooool>000000`0dLfY2@000009ooooo`d000002Oooool9000000Wo
oooo3P000009ooooo`T00000303AcJT4ooooo`@000001?ooool=000000Cooooo1@000004ooooo`@0
00001?ooool5000000Cooooo10000009ooooo`P000001Oooool8000000l0dLfY000>0=7=Z@X00000
1_ooool?000002Gooooo1P00000?ooooo``0dLfY1@000005ooooo`D000003oooool5000002gooooo
2P00000<0=7=Z@h000002Oooool>000000Gooooo1@000005ooooo`h000002Oooool>000000`0dLfY
2@000009ooooo`d000002Oooool9000000Wooooo3P000009ooooo`T00000303AcJT4ooooo`@00000
1?ooool=000000Cooooo1@000004ooooo`@000001?ooool5000000Cooooo10000009ooooo`P00000
1Oooool8000000l0dLfY000>0=7=Z@X000001_ooool?000002Gooooo1P00000?ooooo``0dLfY1@00
0005ooooo`D000003oooool5000002gooooo2P00000<0=7=Z@h000002Oooool>000000Gooooo1@00
0005ooooo`h000002Oooool>000000`0dLfY2@000009ooooo`d000002Oooool9000000Wooooo3P00
0009ooooo`T00000303AcJT4ooooo`@000001?ooool=000000Cooooo1@000004ooooo`@000001?oo
ool5000000Cooooo10000009ooooo`P000001Oooool8000000l0dLfY000>0=7=Z@X000001_ooool?
000002Gooooo1P00000?ooooo``0dLfY1@000005ooooo`D000003oooool5000002gooooo2P00000<
0=7=Z@h000002Oooool>000000Gooooo1@000005ooooo`h000002Oooool>000000`0dLfY2@000009
ooooo`d000002Oooool9000000Wooooo3P000009ooooo`T00000303AcJT4000000Cooooo3@000004
ooooo`@000006_ooool4000000Wooooo10000004ooooo`D000002?ooool?0=7=Z@003P3AcJT:0000
00Kooooo3`00000Uooooo`H000003oooool<0=7=Z@D000001Oooool5000000oooooo1@00000]oooo
o`X00000303AcJT4000000Gooooo4`00000>ooooo`D000003_oooolC000000Gooooo1000000<0=7=
Z@Wooooo5P000005ooooo`@000002Oooool5000000Cooooo5`000009ooooo``0dLfY10000004oooo
o`d000001?ooool4000001[ooooo10000009ooooo`@000001?ooool5000000Sooooo3`3AcJT000h0
dLfY2P00000Eooooo`H000001Oooool5000000_ooooo40000005ooooo`X00000303AcJT5ooooo`D0
00001OoooolD000001Wooooo1@00000:ooooo`X000001Oooool<0=7=Z@@000001OoooolC000000ko
oooo1@00000>oooooa<000001Oooool4000000`0dLfY2OoooolF000000Gooooo10000009ooooo`D0
00001?oooolG000000Wooooo303AcJT4000000Cooooo3@000004ooooo`@000006_ooool4000000Wo
oooo10000004ooooo`D000002?ooool?0=7=Z@003P3AcJT:000001Gooooo1P000005ooooo`D00000
2oooool@000000Gooooo2P00000<0=7=Z@Gooooo1@000005oooooa@000006Oooool5000000[ooooo
2P000005ooooo``0dLfY10000005oooooa<000003_ooool5000000kooooo4`000005ooooo`@00000
303AcJT9oooooaH000001Oooool4000000Wooooo1@000004oooooaL000002Oooool<0=7=Z@@00000
1?ooool=000000Cooooo1000000Jooooo`@000002Oooool4000000Cooooo1@000008ooooo`l0dLfY
000>0=7=Z@X000005Oooool6000000Gooooo1@00000;oooooa0000001Oooool:000000`0dLfY1Ooo
ool5000000Gooooo5000000Iooooo`D000002_ooool:000000Gooooo303AcJT4000000Gooooo4`00
000>ooooo`D000003_oooolC000000Gooooo1000000<0=7=Z@Wooooo5P000005ooooo`@000002Ooo
ool5000000Cooooo5`000009ooooo``0dLfY10000004ooooo`d000001?ooool4000001[ooooo1000
0009ooooo`@000001?ooool5000000Sooooo3`3AcJT000h0dLfY2P00000Eooooo`H000001Oooool5
000000_ooooo40000005ooooo`X00000303AcJT5ooooo`D000001OoooolD000001Wooooo1@00000:
ooooo`X000001Oooool<0=7=Z@@000001OoooolC000000kooooo1@00000>oooooa<000001Oooool4
000000`0dLfY4_ooool9000000Cooooo2@000009ooooo`T000001Oooool9000001;ooooo303AcJTA
000000Sooooo10000009ooooo`@000002Oooool8000000Wooooo10000009ooooo`P000003`3AcJT0
00h0dLfY2P00000Eooooo`H000001Oooool5000000_ooooo40000005ooooo`X00000303AcJT5oooo
o`D000001OoooolD000001Wooooo1@00000:ooooo`X000001Oooool<0=7=Z@@000003_ooool50000
01?ooooo1@00000Cooooo`@000003oooool4000000`0dLfY4_ooool9000000Cooooo2@000009oooo
o`T000001Oooool9000001;ooooo303AcJTA000000Sooooo10000009ooooo`@000002Oooool80000
00Wooooo10000009ooooo`P000003`3AcJT000h0dLfY2P00000Eooooo`H000001Oooool5000000_o
oooo40000005ooooo`X00000303AcJT:000000Gooooo1@00000?ooooo`D000001Oooool:000001Wo
oooo1@000005ooooo``0dLfY1000000>ooooo`D000004oooool5000001?ooooo1000000?ooooo`@0
0000303AcJTBooooo`T000001?ooool9000000Wooooo2@000005ooooo`T000004_ooool<0=7=ZA40
00002?ooool4000000Wooooo10000009ooooo`P000002Oooool4000000Wooooo2000000?0=7=Z@00
3P3AcJT5000001[ooooo2`000005ooooo`D000001_oooolJ000000Gooooo303AcJT:000000Gooooo
1@00000?ooooo`D000001Oooool:000001Wooooo1@000005ooooo``0dLfY1000000>ooooo`D00000
4oooool5000001?ooooo1000000?ooooo`@00000303AcJTBooooo`T000001?ooool9000000Wooooo
2@000005ooooo`T000004_ooool<0=7=ZA4000002?ooool4000000Wooooo10000009ooooo`P00000
2Oooool4000000Wooooo2000000?0=7=Z@003P3AcJT5000001[ooooo2`000005ooooo`D000001_oo
oolJ000000Gooooo303AcJT:000000Gooooo1@00000?ooooo`D000001Oooool:000001Wooooo1@00
0005ooooo``0dLfY1000000>ooooo`D000004oooool5000001?ooooo1000000?ooooo`@00000303A
cJTBooooo`T000001?ooool9000000Wooooo2@000005ooooo`T000004_ooool<0=7=Z@Cooooo2000
0005ooooo`@000001?ooool=000000Sooooo2@000004oooooaH000002?ooool?0=7=Z@003P3AcJT5
000001[ooooo2`000005ooooo`D000001_oooolJ000000Gooooo303AcJT:000000Gooooo1@00000?
ooooo`D000001Oooool:000001Wooooo1@000005ooooo``0dLfY1000000>ooooo`D000004oooool5
000001?ooooo1000000?ooooo`@00000303AcJT9000001Kooooo6`00000Gooooo`T00000303AcJT4
ooooo`P000001Oooool4000000Cooooo3@000008ooooo`T000001?oooolF000000Sooooo3`3AcJT0
00h0dLfY1@00000Jooooo`/000001Oooool5000000Kooooo6P000005ooooo``0dLfY2P000005oooo
o`D000003oooool5000000Gooooo2P00000Iooooo`D000001Oooool<0=7=Z@Cooooo3P000005oooo
o`X000002Oooool5000000Wooooo2P000004ooooo`l000001?ooool<0=7=Z@T000005_oooolK0000
01Oooooo2@00000<0=7=Z@Cooooo20000005ooooo`@000001?ooool=000000Sooooo2@000004oooo
oaH000002?ooool?0=7=Z@003P3AcJT5000001[ooooo2`000005ooooo`D000001_oooolJ000000Go
oooo303AcJTD000000Gooooo1@000005ooooo`D000003oooool5000000[ooooo2P000005ooooo`D0
0000303AcJT4ooooo`h000001Oooool:000000Wooooo1@000009ooooo`X000001?ooool?000000Co
oooo303AcJT9000001Kooooo6`00000Gooooo`T00000303AcJT4ooooo`P000001Oooool4000000Co
oooo3@000008ooooo`T000001?oooolF000000Sooooo3`3AcJT000h0dLfY4?oooolE000000[ooooo
5@000006ooooo`D000002_ooool<0=7=ZA@000001Oooool5000000Gooooo1@00000?ooooo`D00000
2_ooool:000000Gooooo1@00000<0=7=Z@Cooooo3P000005ooooo`X000002Oooool5000000Wooooo
2P000004ooooo`l000001?ooool<0=7=Z@T000005_oooolK000001Oooooo2@00000<0=7=Z@P00000
3Oooool4000000Wooooo30000005ooooo`d000001?ooool4000000Wooooo2000000?0=7=Z@003P3A
cJT@oooooaD000002_oooolE000000Kooooo1@00000:ooooo``0dLfY50000005ooooo`D000001Ooo
ool5000000oooooo1@00000:ooooo`X000001Oooool5000000`0dLfY1?ooool>000000Gooooo2P00
0009ooooo`D000002Oooool:000000Cooooo3`000004ooooo``0dLfY1Oooool4000000Gooooo1000
000=ooooo`T000002Oooool9000000kooooo10000005ooooo`@000001Oooool<0=7=Z@P000003Ooo
ool4000000Wooooo30000005ooooo`d000001?ooool4000000Wooooo2000000?0=7=Z@003P3AcJT@
oooooaD000002_oooolE000000Kooooo1@00000:ooooo``0dLfY50000005ooooo`D000001Oooool5
000000oooooo1@00000:ooooo`X000001Oooool5000000`0dLfY1?ooool5000000Gooooo?@000005
ooooo`D000001?ooool<0=7=Z@Gooooo10000005ooooo`@000003Oooool9000000Wooooo2@00000>
ooooo`@000001Oooool4000000Gooooo303AcJT8000000gooooo10000009ooooo``000001Oooool=
000000Cooooo10000009ooooo`P000003`3AcJT000h0dLfY4?oooolE000000[ooooo5@000006oooo
o`D000002_ooool<0=7=Z@[ooooo2P00000:ooooo`D000005?oooolD000000[ooooo1@00000<0=7=
Z@Cooooo1@000005ooooocd000001Oooool5000000Cooooo303AcJT5ooooo`@000001Oooool40000
00gooooo2@000009ooooo`T000003_ooool4000000Gooooo10000005ooooo``0dLfY2000000=oooo
o`@000002Oooool<000000Gooooo3@000004ooooo`@000002Oooool8000000l0dLfY000>0=7=ZA3o
oooo5@00000:oooooaD000001_ooool5000000[ooooo303AcJT:ooooo`X000002_ooool5000001Co
oooo5000000:ooooo`D00000303AcJT4ooooo`D000001Ooooolm000000Gooooo1@000004ooooo``0
dLfY1Oooool4000000Gooooo1000000=ooooo`T000002Oooool9000000kooooo10000005ooooo`@0
00001Oooool<0=7=Z@Sooooo3@000004oooooa4000001?ooool5000000Sooooo2@00000Eooooo`l0
dLfY000>0=7=ZA0000001Oooool:000002Gooooo5@00000<0=7=Z@[ooooo2P00000:ooooo`D00000
5?oooolD000000[ooooo1@00000<0=7=Z@Cooooo1@000005ooooocd000001Oooool5000000Cooooo
303AcJT>000000Sooooo1@000009ooooo`@000002Oooool5000000Wooooo10000009ooooo`h00000
303AcJT8ooooo`d000001?oooolA000000Cooooo1@000008ooooo`T000005Oooool?0=7=Z@003P3A
cJT@000000Gooooo2P00000UoooooaD00000303AcJT:ooooo`X000002_ooool5000001Cooooo5000
000:ooooo`D00000303AcJT4ooooo`D000001Ooooolm000000Gooooo1@000004ooooo``0dLfY3P00
0008ooooo`D000002Oooool4000000Wooooo1@000009ooooo`@000002Oooool>000000`0dLfY2?oo
ool=000000Cooooo4@000004ooooo`D000002?ooool9000001Gooooo3`3AcJT000h0dLfY40000005
ooooo`X000009OoooolE000000`0dLfY2_ooool:000000[ooooo1@00000Doooooa@000002_ooool5
000000`0dLfY1?ooool5000000Gooooo10000005ooooob/000001?ooool5000000Gooooo1@000004
ooooo``0dLfY3P000008ooooo`D000002Oooool4000000Wooooo1@000009ooooo`@000002Oooool>
000000`0dLfY2?ooool=000000Cooooo4@000004ooooo`D000002?ooool9000001Gooooo3`3AcJT0
00h0dLfY40000005ooooo`X000009OoooolE000000`0dLfY1@00000:ooooo`D000002_ooool50000
00Gooooo2P000005ooooo`X000002_ooool?000000`0dLfY1?ooool5000000Gooooo10000005oooo
ob/000001?ooool5000000Gooooo1@000004ooooo``0dLfY3P000008ooooo`D000002Oooool40000
00Wooooo1@000009ooooo`@000002Oooool>000000`0dLfY20000009ooooo`@000001?ooool90000
017ooooo20000009ooooo`d000001?ooool4000000l0dLfY000>0=7=ZA0000001Oooool:000002Go
oooo5@00000<0=7=Z@D000002_ooool5000000[ooooo1@000005ooooo`X000001Oooool:000000[o
oooo3`00000<0=7=Z@Cooooo1@000005ooooo`@000001Oooool[000000Cooooo1@000005ooooo`D0
00001?ooool<0=7=Z@h000002?ooool5000000Wooooo10000009ooooo`D000002Oooool4000000Wo
oooo3P00000<0=7=Z@P000002Oooool4000000Cooooo2@00000Aooooo`P000002Oooool=000000Co
oooo1000000?0=7=Z@003P3AcJT5ooooo`/000001Oooool5000000Gooooo2`000005oooooa/00000
1Oooool5000000Gooooo303AcJT5000000[ooooo1@00000:ooooo`D000001Oooool:000000Gooooo
2P00000:ooooo`l00000303AcJT4ooooo`D000001Oooool4000000Gooooo:`000004ooooo`D00000
1Oooool5000000Cooooo303AcJT>ooooo`@000002Oooool9000000Cooooo2@000005ooooo`T00000
2Oooool4000000kooooo303AcJT8000000Wooooo10000004ooooo`T000004Oooool8000000Wooooo
3@000004ooooo`@000003`3AcJT000h0dLfY1Oooool;000000Gooooo1@000005ooooo`/000001Ooo
oolK000000Gooooo1@000005ooooo``0dLfY1@00000:ooooo`D000002_ooool5000000Gooooo2P00
0005ooooo`X000002_ooool?000000`0dLfY1000000:ooooo`T000001OoooolQ000000Gooooo2@00
000:ooooo`@00000303AcJT>ooooo`@000002Oooool9000000Cooooo2@000005ooooo`T000002Ooo
ool4000000kooooo303AcJT8000000Wooooo10000004ooooo`T000004Oooool8000000Wooooo3@00
0004ooooo`@000003`3AcJT000h0dLfY1Oooool;000000Gooooo1@000005ooooo`/000001OoooolK
000000Gooooo1@000005ooooo``0dLfY1@00000:ooooo`D000002_ooool5000000Gooooo2P000005
ooooo`X000002_ooool?000000`0dLfY1000000:ooooo`T000001OoooolQ000000Gooooo2@00000:
ooooo`@00000303AcJT>ooooo`@000002Oooool9000000Cooooo2@000005ooooo`T000002Oooool4
000000kooooo303AcJT8000000Wooooo10000004ooooo`T000004Oooool8000000Wooooo3@000004
ooooo`@000003`3AcJT000h0dLfY1Oooool;000000Gooooo1@000005ooooo`/000001OoooolK0000
00Gooooo1@000005ooooo``0dLfY:0000005oooooa@000001Oooool5000000Gooooo1@000005oooo
o``0dLfY1000000:ooooo`T000001OoooolQ000000Gooooo2@00000:ooooo`@00000303AcJT>oooo
o`@000002Oooool9000000Cooooo2@000005ooooo`T000002Oooool4000000kooooo303AcJTAoooo
o``000001Oooool<000000Gooooo10000009ooooo`P000001?ooool5000000Sooooo3`3AcJT000h0
dLfY1Oooool;000000Gooooo1@000005ooooo`/000001OoooolK000000Gooooo1@000005ooooo``0
dLfY:0000005oooooa@000001Oooool5000000Gooooo1@000005ooooo``0dLfY1000000:ooooo`T0
00001OoooolQ000000Gooooo2@00000:ooooo`@00000303AcJT9000001Kooooo6`00000Gooooo`T0
0000303AcJTAooooo``000001Oooool<000000Gooooo10000009ooooo`P000001?ooool5000000So
oooo3`3AcJT000h0dLfY5@00000:ooooo`H000002_ooool5000000_ooooo1@00000Eooooo``0dLfY
:0000005oooooa@000001Oooool5000000Gooooo1@000005ooooo``0dLfY1000000:ooooo`T00000
1OoooolQ000000Gooooo2@00000:ooooo`@00000303AcJT9000001Kooooo6`00000Gooooo`T00000
303AcJTAooooo``000001Oooool<000000Gooooo10000009ooooo`P000001?ooool5000000Sooooo
3`3AcJT000h0dLfY5@00000:ooooo`H000002_ooool5000000_ooooo1@00000Eooooo``0dLfY:000
0005oooooa@000001Oooool5000000Gooooo1@000005ooooo``0dLfY10000005ooooo`D000002Ooo
ool:000000Cooooo3`000004ooooo`X000002Oooool5000000Gooooo1000000<0=7=Z@T000005_oo
oolK000001Oooooo2@00000<0=7=ZA7ooooo30000005ooooo``000001Oooool4000000Wooooo2000
0004ooooo`D000002?ooool?0=7=Z@003P3AcJTE000000[ooooo1P00000:ooooo`D000002oooool5
000001Gooooo303AcJTX000000Gooooo50000005ooooo`D000001Oooool5000000Gooooo303AcJT4
000000Gooooo1@000009ooooo`X000001?ooool?000000Cooooo2P000009ooooo`D000001Oooool4
000000`0dLfY2@00000Foooooa/000005oooool9000000`0dLfY1?ooool4000000Cooooo1@000004
ooooo`P000001Oooool8000000Wooooo20000005ooooo``000001Oooool4000000Cooooo3`3AcJT0
00h0dLfY5@00000:ooooo`H000002_ooool5000000_ooooo1@00000Eooooo``0dLfY3`00000:oooo
o`D000002_ooool5000001kooooo2P000005ooooo``0dLfY10000005ooooo`D000002Oooool:0000
00Cooooo3`000004ooooo`X000002Oooool5000000Gooooo1000000<0=7=Z@T000005_oooolK0000
01Oooooo2@00000<0=7=Z@Cooooo10000004ooooo`D000001?ooool8000000Gooooo20000009oooo
o`P000001Oooool<000000Gooooo10000004ooooo`l0dLfY000>0=7=ZAD000002_ooool6000000[o
oooo1@00000;ooooo`D000005Oooool<0=7=Z@l000002_ooool5000000[ooooo1@00000Nooooo`X0
00001Oooool<0=7=Z@@000001Oooool5000000Wooooo2P000004ooooo`l000001?ooool:000000Wo
oooo1@000005ooooo`@00000303AcJT5ooooo`T000002?ooool5000000Wooooo4P000009ooooo`@0
00002Oooool9000000Gooooo303AcJT4ooooo`@000001?ooool5000000Cooooo20000005ooooo`P0
00002Oooool8000000Gooooo30000005ooooo`@000001?ooool?0=7=Z@003P3AcJTE000001Gooooo
2P00000Fooooo`l00000303AcJT?000000[ooooo1@00000:ooooo`D000007_ooool:000000Gooooo
303AcJT4000000Gooooo1@000009ooooo`X000001?ooool?000000Cooooo2P000009ooooo`D00000
1Oooool4000000`0dLfY1Oooool9000000Sooooo1@000009oooooa8000002Oooool4000000Wooooo
2@000005ooooo``0dLfY1?ooool4000000Cooooo1@000004ooooo`P000001Oooool8000000Wooooo
20000005ooooo``000001Oooool4000000Cooooo3`3AcJT000h0dLfY5@00000Eooooo`X000005_oo
ool?000000`0dLfY3`00000:ooooo`D000002_ooool5000001kooooo2P000005ooooo``0dLfY1000
000Cooooob/000004oooool4000000`0dLfY1Oooool9000000Sooooo1@000009oooooa8000002Ooo
ool4000000Wooooo2@000005ooooo``0dLfY5Oooool4000000Wooooo10000004ooooo`d000003Ooo
ool4000000Wooooo10000004ooooo`l0dLfY000>0=7=ZAD000005Oooool:000001Kooooo3`00000<
0=7=Z@l000002_ooool5000000[ooooo1@00000Nooooo`X000001Oooool<0=7=Z@@000004oooool[
000001?ooooo1000000<0=7=Z@Gooooo2@000008ooooo`D000002OoooolB000000Wooooo10000009
ooooo`T000001Oooool<0=7=ZAGooooo10000009ooooo`@000001?ooool=000000gooooo10000009
ooooo`@000001?ooool?0=7=Z@003P3AcJTE000001Gooooo2P00000Fooooo`l00000303AcJT:0000
00[ooooo50000005ooooob<000002_ooool<0=7=Z@@000004oooool[000001?ooooo1000000<0=7=
Z@Gooooo5P00000=ooooo`T000003_oooolF000000Gooooo303AcJTEooooo`@000002Oooool40000
00Cooooo3@00000=ooooo`@000002Oooool4000000Cooooo3`3AcJT000h0dLfY5@00000Eooooo`X0
00005_ooool?000000`0dLfY2P00000:oooooa@000001OoooolS000000[ooooo303AcJT4000001?o
oooo:`00000Cooooo`@00000303AcJT5oooooaH000003Oooool9000000kooooo5P000005ooooo``0
dLfY5Oooool4000000Wooooo10000004ooooo`d000003Oooool4000000Wooooo10000004ooooo`l0
dLfY000>0=7=ZAD000005Oooool:000001Kooooo3`00000<0=7=Z@X000002_oooolD000000Gooooo
8`00000:ooooo``0dLfY10000005ooooo`h000001OoooolQ000000Gooooo3P000005ooooo`@00000
303AcJT5oooooaH000003Oooool9000000kooooo5P000005ooooo``0dLfY20000009ooooo`@00000
1?ooool4000000gooooo2@000008ooooo`D000006Oooool?0=7=Z@003P3AcJT@ooooo`D000004?oo
ool:000000Gooooo4000000;ooooo`X00000303AcJT:000000[ooooo50000005ooooob<000002_oo
ool<0=7=Z@@000001Oooool>000000Gooooo8@000005ooooo`h000001Oooool4000000`0dLfY1Ooo
oolF000000gooooo2@00000>oooooaH000001Oooool<0=7=Z@P000002Oooool4000000Cooooo1000
000=ooooo`T000002?ooool5000001Wooooo3`3AcJT000h0dLfY4?ooool50000013ooooo2P000005
oooooa0000002oooool:000000`0dLfY2P00000:oooooa@000001OoooolS000000[ooooo303AcJT4
000000Gooooo3P000005ooooob4000001Oooool>000000Gooooo1000000<0=7=Z@D000001?ooool=
000000kooooo10000009ooooo`D000003Oooool>000000Cooooo1@00000<0=7=Z@P000002Oooool4
000000Cooooo1000000=ooooo`T000002?ooool5000001Wooooo3`3AcJT000h0dLfY4?ooool50000
013ooooo2P000005oooooa0000002oooool:000000`0dLfY3`00000:ooooo`D000002_ooool?0000
00oooooo5000000<0=7=Z@@000001Oooool>000000Gooooo8@000005ooooo`h000001Oooool40000
00`0dLfY1@000004ooooo`d000003_ooool4000000Wooooo1@00000=ooooo`h000001?ooool50000
00`0dLfY20000009ooooo`@000001?ooool4000000gooooo2@000008ooooo`D000006Oooool?0=7=
Z@003P3AcJT@ooooo`D000004?ooool:000000Gooooo4000000;ooooo`X00000303AcJT?000000[o
oooo1@00000:ooooo`l000003ooooolD000000`0dLfY10000005ooooo`h000001OoooolQ000000Go
oooo3P000005ooooo`@00000303AcJT5000000Cooooo3@00000>ooooo`@000002Oooool5000000go
oooo3P000004ooooo`D00000303AcJT<ooooo`d000001?oooolA000000Gooooo10000004ooooo`D0
00001?ooool4000000gooooo1000000?0=7=Z@003P3AcJT@ooooo`D000004?ooool:000000Gooooo
4000000;ooooo`X00000303AcJT?000000[ooooo1@00000:ooooo`l000003ooooolD000000`0dLfY
1000000:oooooaL000001Oooool5000000Gooooo5`00000:ooooo`@00000303AcJT5000000Cooooo
3@00000>ooooo`@000002Oooool5000000gooooo3P000004ooooo`D00000303AcJT<ooooo`d00000
1?oooolA000000Gooooo10000004ooooo`D000001?ooool4000000gooooo1000000?0=7=Z@003P3A
cJT5ooooo`D000001_ooool:000000Gooooo2`000005ooooob0000002_ooool<0=7=Z@l000002_oo
ool5000000[ooooo3`00000?oooooa@00000303AcJT4000000[ooooo5`000005ooooo`D000001Ooo
oolG000000[ooooo1000000<0=7=Z@D000001?ooool=000000kooooo10000009ooooo`D000003Ooo
ool>000000Cooooo1@00000<0=7=Z@cooooo3@000004oooooa4000001Oooool4000000Cooooo1@00
0004ooooo`@000003Oooool4000000l0dLfY000>0=7=Z@Gooooo1@000006ooooo`X000001Oooool;
000000Gooooo8000000:ooooo``0dLfY3`00000:ooooo`D000002_ooool?000000oooooo5000000<
0=7=Z@@000002_oooolG000000Gooooo1@000005oooooaL000002_ooool4000000`0dLfY2@00000B
ooooob@000004_ooool9000000`0dLfY3?ooool=000000Cooooo4@000005ooooo`@000001?ooool5
000000Cooooo1000000=ooooo`@000003`3AcJT000h0dLfY1Oooool5000000Kooooo2P000005oooo
o`/000001OoooolP000000[ooooo303AcJT:ooooo`X000001Oooool5000000Gooooo1@000005oooo
o`l000005?ooool5000000Gooooo303AcJT4000000[ooooo5`000005ooooo`D000001OoooolG0000
00[ooooo1000000<0=7=Z@T000004_oooolT000001;ooooo2@00000<0=7=ZA4000001?ooool40000
00Cooooo1@000004ooooo`@000003OoooolE000000Gooooo2000000?0=7=Z@003P3AcJT5ooooo`D0
00001_ooool:000000Gooooo2`000005ooooob0000002_ooool<0=7=Z@[ooooo2P000005ooooo`D0
00001Oooool5000000Gooooo3`00000Dooooo`D000001Oooool<0=7=Z@@000001Oooool9000000[o
oooo8@000009ooooo`X000001Oooool4000000`0dLfY2@00000Booooob@000004_ooool9000000`0
dLfY4@000004ooooo`@000001?ooool5000000Cooooo1000000=oooooaD000001Oooool8000000l0
dLfY000>0=7=Z@Gooooo1@000006ooooo`X000001Oooool;000000Gooooo8000000:ooooo``0dLfY
2_ooool:000000Gooooo1@000005ooooo`D000001Oooool?000001Cooooo1@000005ooooo``0dLfY
10000005ooooo`T000002_oooolQ000000Wooooo2P000005ooooo`@00000303AcJT9000001;ooooo
9000000Booooo`T00000303AcJTA000000Cooooo10000004ooooo`D000001?ooool4000000gooooo
5@000005ooooo`P000003`3AcJT000h0dLfY4000000?ooooo`/000002_ooool@000000Kooooo3`00
000<0=7=Z@[ooooo2P000005ooooo`D000001Oooool5000000Gooooo3`00000Dooooo`D000001Ooo
ool<0=7=Z@@000001Oooool9000000[ooooo8@000009ooooo`X000001Oooool4000000`0dLfY1@00
0004ooooo`d000003_ooool4000000Wooooo1@00000=ooooo`h000001?ooool5000000`0dLfY4@00
0004ooooo`@000001?ooool5000000Cooooo1000000=oooooaD000001Oooool8000000l0dLfY000>
0=7=ZA0000003oooool;000000[ooooo40000006ooooo`l00000303AcJT:ooooo`X000001Oooool5
000000Gooooo1@000005ooooo`l000005?ooool5000000Gooooo303AcJT4000000Gooooo2@00000:
ooooob4000002Oooool:000000Gooooo1000000<0=7=Z@D000001?ooool=000000kooooo10000009
ooooo`D000003Oooool>000000Cooooo1@00000<0=7=ZA4000001?ooool4000000Cooooo1@000004
ooooo`@000003OoooolE000000Gooooo2000000?0=7=Z@003P3AcJT@000000oooooo2`00000:oooo
oa0000001_ooool?000000`0dLfY2P00000:ooooo`D000002_ooool5000000[ooooo6@000005oooo
o`X00000303AcJT4000000Gooooo2@00000:ooooob4000002Oooool:000000Gooooo1000000<0=7=
Z@D000001?ooool=000000kooooo10000009ooooo`D000003Oooool>000000Cooooo1@00000<0=7=
Z@@000003Oooool<0000017ooooo4P000004ooooo`@000001?ooool5000000Cooooo1000000?0=7=
Z@003P3AcJT@000000oooooo2`00000:oooooa0000001_ooool?000000`0dLfY2P00000:ooooo`D0
00002_ooool5000000[ooooo6@000005ooooo`X00000303AcJT4000000Gooooo1@000004ooooo`X0
00003_ooool5000000kooooo2@000005ooooo`D000001Oooool4000000`0dLfY1@000004ooooo`d0
00003_ooool4000000Wooooo1@00000=ooooo`h000001?ooool5000000`0dLfY1000000=ooooo``0
00004OoooolB000000Cooooo10000004ooooo`D000001?ooool4000000l0dLfY000>0=7=ZA000000
3oooool;000000[ooooo40000006ooooo`l00000303AcJT:000000[ooooo1@00000:ooooo`D00000
2_oooolI000000Gooooo2P00000<0=7=Z@@000001Oooool5000000Cooooo2P00000>ooooo`D00000
3_ooool9000000Gooooo1@000005ooooo`@00000303AcJT5000000Wooooo20000005ooooo`d00000
2Oooool>000000Cooooo2@000009ooooo`D00000303AcJT4000000gooooo3000000Aoooooa800000
1?ooool4000000Cooooo1@000004ooooo`@000003`3AcJT000h0dLfY2_ooool6000000Gooooo4000
000:oooooaD000002oooool5000000Gooooo303AcJT:000000[ooooo1@00000:ooooo`D000002_oo
oolI000000Gooooo2P00000<0=7=Z@@000001Oooool5000000Cooooo2P00000>ooooo`D000003_oo
ool9000000Gooooo1@000005ooooo`@00000303AcJT5000000Wooooo20000005ooooo`d000002Ooo
ool>000000Cooooo2@000009ooooo`D00000303AcJT4000000gooooo3000000Aoooooa8000001?oo
ool4000000Cooooo1@000004ooooo`@000003`3AcJT000h0dLfY2_ooool6000000Gooooo4000000:
oooooaD000002oooool5000000Gooooo303AcJTI000000[ooooo2P00000Dooooo`l000002_ooool<
0=7=Z@@000001Oooool5000000Cooooo2P00000>ooooo`D000003_ooool9000000Gooooo1@000005
ooooo`@00000303AcJT5000000Wooooo20000005ooooo`d000002Oooool>000000Cooooo2@000009
ooooo`D00000303AcJTAooooo`@000001?ooool4000000Gooooo2000000=ooooo`@000001Oooool4
000000gooooo2000000?0=7=Z@003P3AcJT:ooooo`H000001Oooool@000000[ooooo5@00000;oooo
o`D000001Oooool<0=7=ZAT000002_ooool:000001Cooooo3`00000:ooooo``0dLfY10000005oooo
o`D000001?ooool:000000kooooo1@00000>ooooo`T000001Oooool5000000Gooooo1000000<0=7=
Z@D000002Oooool8000000Gooooo3@000009ooooo`h000001?ooool9000000Wooooo1@00000<0=7=
ZA7ooooo10000004ooooo`@000001Oooool8000000gooooo10000005ooooo`@000003Oooool80000
00l0dLfY000>0=7=Z@[ooooo1P000005oooooa0000002_oooolE000000_ooooo1@000005ooooo``0
dLfY6@00000:ooooo`X000005?ooool?000000[ooooo303AcJT>ooooo`@000001Oooool:000000Co
oooo3`000004ooooo`X000001?ooool5000000kooooo303AcJT5000000Wooooo20000005ooooo`d0
00002Oooool>000000Cooooo2@000009ooooo`D00000303AcJTAooooo`@000001?ooool4000000Go
oooo2000000=ooooo`@000001Oooool4000000gooooo2000000?0=7=Z@003P3AcJT:ooooo`H00000
1Oooool@000000[ooooo5@00000;ooooo`D000001Oooool<0=7=ZAT000002_ooool:000001Cooooo
3`00000:ooooo``0dLfY3_ooool4000000Gooooo2P000004ooooo`l000001?ooool:000000Cooooo
1@00000>ooooo``0dLfY1@000004ooooo`D000002?ooool>000001;ooooo3@000009ooooo`D00000
1?ooool5000000`0dLfY4Oooool4000000Cooooo10000005ooooo`P000003Oooool4000000Gooooo
1000000=ooooo`P000003`3AcJT000h0dLfY1Oooool;000000[ooooo2`000005ooooo`D000001Ooo
ool;000000Gooooo2`000005ooooo`D00000303AcJTI000000[ooooo2P00000Dooooo`l000002_oo
ool<0=7=Z@kooooo10000005ooooo`X000001?ooool?000000Cooooo2P000004ooooo`D000003_oo
ool<0=7=Z@D000001?ooool5000000Sooooo3P00000Booooo`d000002Oooool5000000Cooooo1@00
000<0=7=ZAT000001?oooolA000000Gooooo3@000004ooooo`d000001?ooool4000000l0dLfY000>
0=7=Z@Gooooo2`00000:ooooo`/000001Oooool5000000Gooooo2`000005ooooo`/000001Oooool5
000000`0dLfY6@00000?oooooa@000001OoooolI000000`0dLfY3_ooool4000000Gooooo2P000004
ooooo`l000001?ooool:000000Cooooo1@00000>ooooo``0dLfY1@000004ooooo`D000002?ooool>
000001;ooooo3@000009ooooo`D000001?ooool5000000`0dLfY6@000004oooooa4000001Oooool=
000000Cooooo3@000004ooooo`@000003`3AcJT000h0dLfY1Oooool;000000[ooooo2`000005oooo
o`D000001Oooool;000000Gooooo2`000005ooooo`D00000303AcJTI000000oooooo50000005oooo
oaT00000303AcJT4000000kooooo2P000009ooooo`l000002Oooool9000000oooooo1000000<0=7=
Z@D000001?ooool5000000Sooooo3P00000Booooo`d000002Oooool5000000Cooooo1@00000<0=7=
ZAT000001?oooolA000000Gooooo3@000004ooooo`d000001?ooool4000000l0dLfY000>0=7=Z@Go
oooo2`00000:ooooo`/000001Oooool5000000Gooooo2`000005ooooo`/000001Oooool5000000`0
dLfY6@00000?oooooa@000001OoooolI000000`0dLfY1000000>ooooo`X000002Oooool?000000Wo
oooo2@00000?ooooo`@00000303AcJT9000000Wooooo3@000009ooooo`T000002Oooool>000000Wo
oooo2@00000<0=7=ZAT000001?oooolA000000Gooooo3@000004ooooo`d000001?ooool4000000l0
dLfY000>0=7=Z@Gooooo2`00000:ooooo`/000001Oooool5000000Gooooo2`000005ooooo`/00000
1Oooool5000000`0dLfY6@00000?oooooa@000001OoooolI000000`0dLfY1000000>ooooo`X00000
2Oooool?000000Wooooo2@00000?ooooo`@00000303AcJT9000000Wooooo3@000009ooooo`T00000
2Oooool>000000Wooooo2@00000<0=7=Z@Cooooo10000009ooooo`@000002?ooool5000000Cooooo
1000000=ooooo`@000002Oooool=000000Cooooo1000000?0=7=Z@003P3AcJT:000000_ooooo2P00
0006ooooo`X000001Oooool6000001Gooooo2P00000<0=7=ZAT000003ooooolD000000Gooooo6@00
000<0=7=Z@@000003_ooool:000000Wooooo3`000009ooooo`T000003oooool4000000`0dLfY2@00
0009ooooo`d000002Oooool9000000Wooooo3P000009ooooo`T00000303AcJT4ooooo`@000002Ooo
ool4000000Sooooo1@000004ooooo`@000003Oooool4000000Wooooo3@000004ooooo`@000003`3A
cJT000h0dLfY2P00000;ooooo`X000001_ooool:000000Gooooo1P00000Eooooo`X00000303AcJT?
ooooo`X000003oooool5000000[ooooo3`00000:ooooo`X00000303AcJT4000000kooooo2P000009
ooooo`l000002Oooool9000000oooooo1000000<0=7=Z@T000002Oooool=000000Wooooo2@000009
ooooo`h000002Oooool9000000`0dLfY1?ooool4000000Wooooo10000008ooooo`D000001?ooool4
000000gooooo10000009ooooo`d000001?ooool4000000l0dLfY000>0=7=Z@X000002oooool:0000
00Kooooo2P000005ooooo`H000005Oooool:000000`0dLfY3oooool:000000oooooo1@00000:oooo
o`l000002_ooool:000000`0dLfY1?ooool>000000[ooooo1@000009ooooo`D000002Oooool50000
00Wooooo3`000004ooooo``0dLfY2@000009ooooo`d000002Oooool9000000Wooooo3P000009oooo
o`T00000303AcJT4ooooo`@000002Oooool4000000Sooooo1@000004ooooo`@000003Oooool40000
00Wooooo3@000004ooooo`@000003`3AcJT000h0dLfY2P00000;ooooo`X000001_ooool:000000Go
oooo1P00000Eooooo`X00000303AcJT?ooooo`X000003oooool5000000[ooooo3`00000:ooooo`X0
0000303AcJT4ooooo`h000002_ooool5000000Wooooo1@000009ooooo`D000002Oooool?000000Co
oooo303AcJT5000000Cooooo2@000004ooooo`T000006oooool9000000Gooooo2@000004ooooo`D0
0000303AcJT8ooooo`@000001Oooool4000000Sooooo2@00000Eooooo`D000001?ooool=000000Co
oooo1000000?0=7=Z@003P3AcJT:000000_ooooo2P000006ooooo`X000001Oooool6000001Gooooo
2P00000<0=7=Z@oooooo2P00000?ooooo`D000002_ooool?000000[ooooo2P00000<0=7=Z@Cooooo
3P00000:ooooo`D000002Oooool5000000Wooooo1@000009ooooo`l000001?ooool<0=7=Z@D00000
1?ooool9000000Cooooo2@00000Kooooo`T000001Oooool9000000Cooooo1@00000<0=7=Z@Sooooo
10000005ooooo`@000002?ooool9000001Gooooo1@000004ooooo`d000001?ooool4000000l0dLfY
000>0=7=Z@X000001_ooool:000000Gooooo1P00000Eoooooa0000003oooool<0=7=Z@oooooo2P00
000?ooooo`D000002_ooool?000000[ooooo2P00000<0=7=Z@Cooooo3P00000:ooooo`D000002Ooo
ool5000000Wooooo1@000009ooooo`l000001?ooool<0=7=Z@D000001?ooool9000000Cooooo2@00
000Kooooo`T000001Oooool9000000Cooooo1@00000<0=7=Z@Sooooo10000005ooooo`@000002?oo
ool9000001Gooooo1@000004ooooo`d000001?ooool4000000l0dLfY000>0=7=Z@X000001_ooool:
000000Gooooo1P00000Eoooooa0000003oooool<0=7=Z@Gooooo1@000005ooooo`D000002_ooool5
000000[ooooo7P00000:ooooo`D00000303AcJT4ooooo`h000002_ooool5000000Wooooo1@000009
ooooo`D000002Oooool?000000Cooooo303AcJT5000000Cooooo2@000004ooooo`T000006oooool9
000000Gooooo2@000004ooooo`D00000303AcJT8ooooo`@000001Oooool4000000Sooooo2@00000E
ooooo`D000001?ooool=000000Cooooo1000000?0=7=Z@003P3AcJT:000000Kooooo2P000005oooo
o`H000005Oooool@000000oooooo303AcJT5ooooo`D000001Oooool5000000[ooooo1@00000:oooo
oah000002_ooool5000000`0dLfY2@000009ooooo`D000002_ooool4000000Gooooo1@000005oooo
o`@000002_ooool4000000[ooooo2@00000<0=7=Z@Gooooo10000005ooooo`@000003OoooolK0000
00kooooo10000005ooooo`@000001Oooool<0=7=Z@P000001?ooool5000000Cooooo1000000=oooo
o`P000002Oooool4000000Gooooo1000000=ooooo`P000003`3AcJT000h0dLfY2P000006ooooo`X0
00001Oooool6000001Gooooo4000000?ooooo``0dLfY1Oooool5000000Gooooo1@00000:ooooo`D0
00002_oooolN000000[ooooo1@00000<0=7=Z@T000002Oooool5000000[ooooo10000005ooooo`D0
00001Oooool4000000[ooooo1000000:ooooo`T00000303AcJT5ooooo`@000001Oooool4000000go
oooo6`00000>ooooo`@000001Oooool4000000Gooooo303AcJT8000000Cooooo1@000004ooooo`@0
00003Oooool8000000Wooooo10000005ooooo`@000003Oooool8000000l0dLfY000>0=7=Z@X00000
1_ooool:000000Gooooo1P00000Eoooooa0000003oooool<0=7=Z@Gooooo1@000005ooooo`D00000
2_ooool5000000[ooooo7P00000:ooooo`D00000303AcJT9000000Wooooo1@00000:ooooo`@00000
1Oooool5000000Gooooo1000000:ooooo`@000002_ooool9000000`0dLfY1Oooool4000000Gooooo
1000000=oooooa/000003_ooool4000000Gooooo10000005ooooo``0dLfY20000004ooooo`D00000
1?ooool4000000gooooo20000009ooooo`@000001Oooool4000000gooooo2000000?0=7=Z@003P3A
cJT:000000Kooooo2P000005ooooo`H000005Oooool@000000oooooo303AcJT5ooooo`D000001Ooo
ool5000000[ooooo1@00000:oooooah000002_ooool5000000`0dLfY2@000009ooooo`D000002_oo
ool4000000Gooooo1@000005ooooo`@000002_ooool4000000[ooooo2@00000<0=7=Z@Gooooo1000
0005ooooo`@000003OoooolK000000kooooo10000005ooooo`@000001Oooool<0=7=Z@P000001?oo
ool5000000Cooooo1000000=ooooo`P000002Oooool4000000Gooooo1000000=ooooo`P000003`3A
cJT000h0dLfY2P00000Eooooo`H000001Oooool5000000Gooooo1P00000Jooooo`D00000303AcJT5
ooooo`X000001OoooolS000000Gooooo3`000005ooooo`D000001Oooool<0=7=Z@@000001Oooool>
000001?ooooo1@00000Cooooo`h000001Oooool4000000`0dLfY2@000005ooooo`@000002Oooool4
000000Wooooo2@000009ooooo`D000002Oooool4000000Gooooo2@00000<0=7=Z@P000001?ooool5
000000Cooooo1000000=ooooo`P000002Oooool4000000Gooooo1000000=ooooo`P000003`3AcJT0
00h0dLfY2P00000Eooooo`H000001Oooool5000000Gooooo1P00000Jooooo`D00000303AcJT5oooo
o`X000001OoooolS000000Gooooo3`000005ooooo`D000001Oooool<0=7=Z@@000001Oooool>0000
01?ooooo1@00000Cooooo`h000001Oooool4000000`0dLfY2@000005ooooo`@000002Oooool40000
00Wooooo2@000009ooooo`D000002Oooool4000000Gooooo2@00000<0=7=Z@Cooooo10000004oooo
o`D000001?ooool4000000Cooooo1@00000Aooooob8000001?ooool?0=7=Z@003P3AcJT:000001Go
oooo1P000005ooooo`D000001Oooool6000001[ooooo1@00000<0=7=Z@Gooooo2P000005ooooob<0
00001Oooool?000000Gooooo1@000005ooooo``0dLfY10000005ooooo`h000004oooool5000001?o
oooo3P000005ooooo`@00000303AcJT9000000Gooooo10000009ooooo`@000002Oooool9000000Wo
oooo1@000009ooooo`@000001Oooool9000000`0dLfY1?ooool4000000Cooooo1@000004ooooo`@0
00001?ooool50000017ooooo8P000004ooooo`l0dLfY000>0=7=Z@X000005Oooool6000000Gooooo
1@000005ooooo`H000006_ooool5000000`0dLfY1Oooool:000000Gooooo8`000005ooooo`l00000
1Oooool5000000Gooooo303AcJT4000000Gooooo3P00000Cooooo`D000004oooool>000000Gooooo
1000000<0=7=Z@T000001Oooool4000000Wooooo10000009ooooo`T000002Oooool5000000Wooooo
10000005ooooo`T00000303AcJT4ooooo`@000001?ooool5000000Cooooo10000004ooooo`D00000
4OoooolR000000Cooooo3`3AcJT000h0dLfY2P00000Eooooo`H000001Oooool5000000Gooooo1P00
000Jooooo`D00000303AcJT5ooooo`X000001OoooolS000000Gooooo3`000005ooooo`D000001Ooo
ool<0=7=Z@@000001Oooool>000001?ooooo1@00000Cooooo`h000001Oooool4000000`0dLfY2@00
0005ooooo`@000002Oooool4000000Wooooo2@000009ooooo`D000002Oooool4000000Gooooo2@00
000<0=7=Z@Cooooo10000004ooooo`D000001?ooool4000000Cooooo1@00000Aooooob8000001?oo
ool?0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00
o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=
Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o
0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY
3P3AcJT000h0dLfY9Oooool?000002Gooooo303AcJTLooooo`L00000=oooool<0=7=Z@H000004ooo
oolW000001?ooooo1P00000<0=7=Z@H000001_ooool6000000Kooooo7P00000Tooooo``0dLfY2ooo
oolL0000027ooooo1P00000;ooooo`l0dLfY000>0=7=ZBGooooo3`00000Uooooo``0dLfY7?ooool7
000003Oooooo303AcJT6000001?ooooo9`00000Cooooo`H00000303AcJT6000000Kooooo1P000006
oooooah000009?ooool<0=7=Z@_ooooo7000000Qooooo`H000002oooool?0=7=Z@003P3AcJTUoooo
o`l000009Oooool<0=7=ZAcooooo1`00000gooooo``0dLfY1P00000CooooobL000004oooool60000
00`0dLfY1P000006ooooo`H000001_oooolN000002Cooooo303AcJT;oooooa`000008Oooool60000
00_ooooo3`3AcJT000h0dLfY9Oooool?000002Gooooo303AcJTLooooo`L00000=oooool<0=7=Z@H0
00004ooooolW000001?ooooo1P00000<0=7=Z@H000001_ooool6000000Kooooo7P00000Tooooo``0
dLfY2ooooolL0000027ooooo1P00000;ooooo`l0dLfY000>0=7=ZBGooooo3`00000Uooooo``0dLfY
7?ooool7000003Oooooo303AcJT6000001?ooooo9`00000Cooooo`H00000303AcJT6000000Kooooo
1P000006oooooah000009?ooool<0=7=Z@_ooooo7000000Qooooo`H000002oooool?0=7=Z@003P3A
cJTUooooo`l000009Oooool<0=7=ZAcooooo1`00000gooooo``0dLfY1P00000CooooobL000004ooo
ool6000000`0dLfY30000006ooooo`H000001_ooool<000000cooooo1P00000<ooooo`H000003?oo
ool<0=7=Z@D000001_ooool;000000Kooooo2`00000Aooooo`D000002oooool6000000Kooooo1@00
000?0=7=Z@003P3AcJTUooooo`l000009Oooool<0=7=ZAGooooo3P000007ooooo`d000001oooool>
000000kooooo303AcJT6ooooo`H000001oooool6000000gooooo3@00000=ooooo`H000001_ooool7
000000Kooooo303AcJT<000000Kooooo1P000006ooooo``000003?ooool6000000cooooo1P00000<
ooooo``0dLfY1@000006ooooo`/000001_ooool;0000017ooooo1@00000;ooooo`H000001_ooool5
000000l0dLfY000>0=7=Z@Oooooo5`000007ooooo`l000001ooooolG000000Oooooo303AcJTEoooo
o`h000001oooool=000000Oooooo3P00000>ooooo``0dLfY1_ooool6000000Oooooo1P00000=oooo
o`d000003Oooool6000000Kooooo1`000006ooooo``0dLfY30000006ooooo`H000001_ooool<0000
00cooooo1P00000<ooooo`H000003?ooool<0=7=Z@D000001_ooool;000000Kooooo2`00000Aoooo
o`D000002oooool6000000Kooooo1@00000?0=7=Z@003P3AcJT7oooooaL000001oooool?000000Oo
oooo5`000007ooooo``0dLfY5Oooool>000000Oooooo3@000007ooooo`h000003_ooool<0=7=Z@Ko
oooo1P000007ooooo`H000003Oooool=000000gooooo1P000006ooooo`L000001_ooool<0=7=Z@`0
00001_ooool6000000Kooooo3000000<ooooo`H000003?ooool6000000cooooo303AcJT5000000Ko
oooo2`000006ooooo`/000004Oooool5000000_ooooo1P000006ooooo`D000003`3AcJT000h0dLfY
1ooooolG000000Oooooo3`000007oooooaL000001oooool<0=7=ZAGooooo3P000007ooooo`d00000
1oooool>000000kooooo303AcJT6ooooo`H000001oooool6000000gooooo3@00000=ooooo`H00000
1_ooool7000000Kooooo303AcJT<000000Kooooo1P000006ooooo``000003?ooool6000000cooooo
1P00000<ooooo``0dLfY1@000006ooooo`/000001_ooool;0000017ooooo1@00000;ooooo`H00000
1_ooool5000000l0dLfY000>0=7=Z@Oooooo5`000007ooooo`l000001ooooolG000000Oooooo303A
cJTEooooo`h000001oooool=000000Oooooo3P00000>ooooo``0dLfY1_ooool6000000Oooooo1P00
000=ooooo`d000003Oooool6000000Kooooo1`000006ooooo``0dLfY30000006ooooo`H000001_oo
ool<000000cooooo1P00000<ooooo`H000003?ooool<0=7=Z@D000001_ooool;000000Kooooo2`00
000Aooooo`D000002oooool6000000Kooooo1@00000?0=7=Z@003P3AcJT7oooooaL000001oooool?
000000Oooooo5`000007ooooo``0dLfY5Oooool>000000Oooooo3@000007ooooo`h000003_ooool<
0=7=Z@Kooooo1P000007ooooo`H000003Oooool=000000gooooo1P000006ooooo`L000001_ooool<
0=7=ZASooooo30000006ooooo``000001_ooool6000001;ooooo1P00000<0=7=Z@_ooooo2`00000A
ooooo`/000001_oooolF000000_ooooo3`3AcJT000h0dLfY1ooooolG000000Oooooo3`000007oooo
oaL000001oooool<0=7=ZAGooooo3P000007ooooo`d000001oooool>000000kooooo303AcJT6oooo
o`H000005?oooolI000001?ooooo1`000006ooooo``0dLfY6?ooool<000000Kooooo30000006oooo
o`H000004_ooool6000000`0dLfY2oooool;0000017ooooo2`000006oooooaH000002oooool?0=7=
Z@003P3AcJT7oooooaL000001oooool?000000Oooooo5`000007ooooo``0dLfY1oooool7000000Oo
oooo3P00000=ooooo`h000007?ooool<0=7=Z@Kooooo1P00000DoooooaT000004oooool7000000Ko
oooo303AcJTHooooo``000001_ooool<000000Kooooo1P00000Booooo`H00000303AcJT;ooooo`/0
00004Oooool;000000Kooooo5P00000;ooooo`l0dLfY000>0=7=ZAKooooo2000000Mooooo`P00000
5_ooool<0=7=Z@Oooooo1`000007ooooo`h000003Oooool>000001cooooo303AcJT6ooooo`H00000
5?oooolI000001?ooooo1`000006ooooo``0dLfY6?ooool<000000Kooooo30000006ooooo`H00000
4_ooool6000000`0dLfY2oooool;0000017ooooo2`000006oooooaH000002oooool?0=7=Z@003P3A
cJTFooooo`P000007Oooool8000001Kooooo303AcJT7ooooo`L000001oooool>000000gooooo3P00
000Looooo``0dLfY1_ooool6000001Cooooo6@00000Cooooo`L000001_ooool<0=7=ZASooooo3000
0006ooooo``000001_ooool6000001;ooooo1P00000<0=7=Z@_ooooo2`00000Aooooo`/000001_oo
oolF000000_ooooo3`3AcJT000h0dLfY5_ooool8000001gooooo2000000Fooooo``0dLfY1oooool7
000000Oooooo3P00000=ooooo`h000007?ooool<0=7=Z@Kooooo1P00000DoooooaT000004oooool7
000000Kooooo303AcJTHooooo``000001_ooool<000000Kooooo1P00000Booooo`H00000303AcJT5
000000Kooooo1@00000<oooooa0000007?ooool<000000Gooooo3`3AcJT000h0dLfY5_ooool80000
01gooooo2000000Fooooo``0dLfY1oooool7000000Oooooo3P00000=ooooo`h000007?ooool<0=7=
Z@Kooooo1P00000DoooooaT000004oooool7000000Kooooo303AcJT6000000Kooooo1P000006oooo
oaP000001_oooolB000000Kooooo3000000<0=7=Z@D000001_ooool5000000cooooo4000000Loooo
o``000001Oooool?0=7=Z@003P3AcJTFooooo`P000007Oooool8000001Kooooo303AcJT7ooooo`L0
00001oooool>000000gooooo3P00000Looooo``0dLfY1_ooool6000001[ooooo3@00000Iooooo`L0
00001_ooool<0=7=Z@H000001_ooool6000000Kooooo60000006oooooa8000001_ooool<000000`0
dLfY1@000006ooooo`D000003?ooool@000001cooooo30000005ooooo`l0dLfY000>0=7=ZAKooooo
2000000Mooooo`P000005_ooool<0=7=Z@Oooooo1`000007ooooo`h000003Oooool>000001cooooo
303AcJT6ooooo`H000006_ooool=000001Wooooo1`000006ooooo``0dLfY1P000006ooooo`H00000
1_oooolH000000Kooooo4P000006ooooo``00000303AcJT5000000Kooooo1@00000<oooooa000000
7?ooool<000000Gooooo3`3AcJT000h0dLfY5_ooool8000001gooooo2000000Fooooo``0dLfY1ooo
ool7000000kooooo1`00000=ooooo`h000001oooool>000000Oooooo303AcJT6ooooo`H000006_oo
ool=000001Wooooo1`000006ooooo``0dLfY1P000006ooooo`H000001_oooolH000000Kooooo4P00
0006ooooo``00000303AcJT5000000Kooooo1@00000<oooooa0000007?ooool<000000Gooooo3`3A
cJT000h0dLfY3`00000Fooooo`l000005_ooool?000000`0dLfY1oooool7000000kooooo1`00000=
ooooo`h000001oooool>000000Oooooo303AcJT6ooooo`H000006_ooool=000001Wooooo1`000006
ooooo``0dLfY1P000006ooooo`H000001_oooolH000000Kooooo4P000006ooooo``00000303AcJT5
000000Kooooo4@00000@oooooa`000004Oooool?0=7=Z@003P3AcJT?000001Kooooo3`00000Foooo
o`l00000303AcJT7ooooo`L000003_ooool7000000gooooo3P000007ooooo`h000001oooool<0=7=
Z@Kooooo1P00000Jooooo`d000006Oooool7000000Kooooo303AcJT6000000Kooooo1P000006oooo
oaP000001_oooolB000000Kooooo3000000<0=7=Z@D000001_oooolA0000013ooooo7000000Aoooo
o`l0dLfY000>0=7=Z@l000005_ooool?000001Kooooo3`00000<0=7=Z@Oooooo1`00000>ooooo`L0
00003Oooool>000000Oooooo3P000007ooooo``0dLfY1_ooool6000001[ooooo3@00000Iooooo`L0
00001_ooool<0=7=Z@cooooo1P000006ooooo`H000001_ooool6000000Kooooo1P000006oooooa80
00001_ooool6000000`0dLfY1@000006oooooa4000004?oooolL0000017ooooo3`3AcJT000h0dLfY
3`00000Fooooo`l000005_ooool?000000`0dLfY1oooool7000000kooooo1`00000=ooooo`h00000
1oooool>000000Oooooo303AcJT6ooooo`H000006_ooool=000001Wooooo1`000006ooooo``0dLfY
3?ooool6000000Kooooo1P000006ooooo`H000001_ooool6000000Kooooo4P000006ooooo`H00000
303AcJT5000000Kooooo4@00000@oooooa`000004Oooool?0=7=Z@003P3AcJT?000001Kooooo3`00
000Fooooo`l00000303AcJT7ooooo`L000003_ooool7000000gooooo3P000007ooooo`h000001ooo
ool<0=7=ZA<000001_ooool7000001Wooooo1`000006oooooa<00000303AcJT<ooooo`H000001_oo
ool6000000Kooooo1P000006ooooo`H000001_oooolB000000Kooooo1P00000<0=7=Z@D000001_oo
oolA0000013ooooo7000000Aooooo`l0dLfY000>0=7=Z@l000005_ooool?000001Kooooo3`00000<
0=7=Z@Oooooo1`00000>ooooo`L000003Oooool>000000Oooooo3P000007ooooo``0dLfY4`000006
ooooo`L000006Oooool7000000Kooooo4`00000<0=7=Z@cooooo1P000006ooooo`H000001_ooool6
000000Kooooo1P000006oooooa8000001_ooool6000000`0dLfY1@000006oooooa4000004?oooolL
0000017ooooo3`3AcJT000h0dLfY3`00000Fooooo`l000005_ooool?000000`0dLfY3_oooolE0000
01Cooooo8`00000<0=7=ZA<000001_ooool7000001Wooooo1`000006oooooa<00000303AcJT<oooo
o`H000001_ooool6000000Kooooo1P000006ooooo`H000001_oooolB000000Kooooo1P00000<0=7=
Z@/000004Oooool5000000Kooooo1@00000<oooooa`000001Oooool?0=7=Z@003P3AcJT?000001Ko
oooo3`00000Fooooo`l00000303AcJT>oooooaD000005?oooolS000000`0dLfY4`000006ooooo`L0
00006Oooool7000000Kooooo4`00000<0=7=Z@cooooo1P000006ooooo`H000001_ooool6000000Ko
oooo1P000006oooooa8000001_ooool6000000`0dLfY2`00000Aooooo`D000001_ooool5000000co
oooo70000005ooooo`l0dLfY000>0=7=Z@L000007_ooool?000001kooooo1`00000<0=7=Z@kooooo
5@00000Dooooob<00000303AcJTC000000Kooooo1`00000Iooooo`L000001_oooolC000000`0dLfY
1_ooool6000000Kooooo1P000006ooooo`H000004_ooool6000000Kooooo30000006ooooo`H00000
303AcJT;0000017ooooo1@000006ooooo`D000003?oooolL000000Gooooo3`3AcJT000h0dLfY1`00
000Nooooo`l000007_ooool7000000`0dLfY3_oooolE000001Cooooo8`00000<0=7=ZA<000001_oo
ool7000001Wooooo1`000006oooooa<00000303AcJT6ooooo`H000001_ooool6000000Kooooo1P00
000Booooo`H000001_ooool<000000Kooooo1P00000<0=7=Z@/000004Oooool5000000Kooooo1@00
000<oooooa`000001Oooool?0=7=Z@003P3AcJT7000001kooooo3`00000Nooooo`L00000303AcJT>
oooooaD000005?oooolS000000`0dLfY3000000Jooooo`d000006Oooool=000000`0dLfY1_ooool6
000000Kooooo1P000006ooooo`H000004_ooool6000000Kooooo30000006ooooo`H00000303AcJT;
0000017ooooo1@000006ooooo`D000003?oooolL000000Gooooo3`3AcJT000h0dLfY1`00000Noooo
o`l000007_ooool7000000`0dLfY3_oooolE000001Cooooo8`00000<0=7=Z@`000006_ooool=0000
01Wooooo3@00000<0=7=Z@Kooooo1P000006ooooo`H000001_ooool6000001;ooooo1P000006oooo
o``000001_ooool6000000`0dLfY40000006ooooo`/000001_ooool5000000cooooo1@000006oooo
o`/000002oooool?0=7=Z@003P3AcJT7000001kooooo3`00000Nooooo`L00000303AcJT7oooooaD0
00001oooool7000000Kooooo1`00000Sooooo``0dLfY3000000Jooooo`d000006Oooool=000000`0
dLfY1_ooool6000000Kooooo1P000006ooooo`H000004_ooool6000000Kooooo30000006ooooo`H0
0000303AcJT@000000Kooooo2`000006ooooo`D000003?ooool5000000Kooooo2`00000;ooooo`l0
dLfY000>0=7=Z@L000007_ooool?000001kooooo1`00000<0=7=Z@Oooooo5@000007ooooo`L00000
1_ooool7000002?ooooo303AcJT<000001[ooooo3@00000Iooooo`d00000303AcJT6ooooo`H00000
1_ooool6000000Kooooo1P00000Booooo`H000001_ooool<000000Kooooo1P00000<0=7=ZA000000
1_ooool;000000Kooooo1@00000<ooooo`D000001_ooool;000000_ooooo3`3AcJT000h0dLfY1`00
000Nooooo`l000007_ooool7000000`0dLfY1ooooolE000000Oooooo1`000006ooooo`L000008ooo
ool<0=7=Z@`000006_ooool=000001Wooooo3@00000<0=7=Z@Kooooo1P000006ooooo``000001_oo
oolB000000Kooooo4P00000<ooooo``0dLfY40000006ooooo`/000001_ooool5000000cooooo1@00
0006ooooo`/000002oooool?0=7=Z@003P3AcJT?000000Oooooo;@000007ooooo`l00000303AcJT7
oooooaD000001oooool7000000Kooooo1`00000Sooooo``0dLfY3000000Jooooo`d000006Oooool=
000000`0dLfY1_ooool6000000Kooooo30000006oooooa8000001_oooolB000000cooooo303AcJT@
000000Kooooo2`000006ooooo`D000003?ooool5000000Kooooo2`00000;ooooo`l0dLfY000>0=7=
Z@l000001oooool]000000Oooooo3`00000<0=7=Z@Oooooo5@000007ooooo`L000001_ooool70000
02?ooooo303AcJT<000000Oooooo3@000006ooooo`d000001_ooool=000000Kooooo3@00000<0=7=
Z@Kooooo1P000006ooooo``000001_oooolB000000Kooooo4P00000<ooooo``0dLfY40000006oooo
o`/000001_ooool5000000cooooo1@000006ooooo`/000002oooool?0=7=Z@003P3AcJT?000000Oo
oooo;@000007ooooo`l00000303AcJT7oooooaD000001oooool7000000Kooooo1`00000Sooooo``0
dLfY30000007ooooo`d000001_ooool=000000Kooooo3@000006ooooo`d00000303AcJT6ooooo`H0
00001_ooool<000000Kooooo4P000006oooooa8000003?ooool<0=7=Z@_ooooo5P000006oooooa40
00004?ooool6000000_ooooo3`3AcJT000h0dLfY3`000007ooooobd000001oooool?000000`0dLfY
1ooooolE000000Oooooo1`000006ooooo`L000008oooool<0=7=Z@`000001oooool=000000Kooooo
3@000006ooooo`d000001_ooool=000000`0dLfY1_ooool6000000Kooooo30000006oooooa800000
1_oooolB000000cooooo303AcJT;oooooaH000001_oooolA0000013ooooo1P00000;ooooo`l0dLfY
000>0=7=Z@l000001oooool]000000Oooooo3`00000<0=7=Z@Oooooo1`00000Looooo`H000007?oo
ool7000000Oooooo303AcJT<000000Oooooo3@000006ooooo`d000001_ooool=000000Kooooo3@00
000<0=7=ZA;ooooo30000006oooooa8000001_ooool<000001;ooooo303AcJT;oooooaH000001_oo
oolA0000013ooooo1P00000;ooooo`l0dLfY000>0=7=Z@l000001oooool]000000Oooooo3`00000<
0=7=Z@Oooooo1`00000Looooo`H000007?ooool7000000Oooooo303AcJT<000000Oooooo3@000006
ooooo`d000001_ooool=000000Kooooo3@00000<0=7=ZA;ooooo30000006oooooa8000001_ooool<
000001;ooooo303AcJT;oooooaH000001_oooolA0000013ooooo1P00000;ooooo`l0dLfY000>0=7=
Z@l000001oooool]000000Oooooo3`00000<0=7=Z@Oooooo1`00000Looooo`H000007?ooool70000
00Oooooo303AcJT<000000Oooooo3@000006ooooo`d000001_ooool=000000Kooooo3@00000<0=7=
ZA;ooooo30000006oooooa8000001_ooool<000001;ooooo303AcJT;oooooaH000001_oooolA0000
013ooooo1P00000;ooooo`l0dLfY000>0=7=ZAKooooo;@00000Fooooo``0dLfY1oooool7000001co
oooo1P00000Looooo`L000001oooool<0=7=Z@`000001oooool=000000Kooooo3@000006ooooo`d0
00001_ooool=000000`0dLfY4_ooool<000000Kooooo4P000006ooooo``000004_ooool<0=7=Z@Go
oooo2`000006ooooo`H000001OoooolA000000Kooooo1@000006oooooa4000001Oooool?0=7=Z@00
3P3AcJTFooooobd000005_ooool<0=7=Z@Oooooo1`00000Looooo`H000007?ooool7000000Oooooo
303AcJT<000000Oooooo3@000006ooooo`d000001_ooool=000000Kooooo3@00000<0=7=ZA;ooooo
30000006oooooa8000001_ooool<000001;ooooo303AcJT5ooooo`/000001_ooool6000000Gooooo
4@000006ooooo`D000001_oooolA000000Gooooo3`3AcJT000h0dLfY5_ooool]000001Kooooo303A
cJT7ooooo`L000007?ooool6000001cooooo1`000007ooooo``0dLfY30000007ooooo`d000001_oo
ool=000000Kooooo3@000006ooooo`d00000303AcJTBooooo``000001_oooolB000000Kooooo3000
000Booooo``0dLfY1Oooool;000000Kooooo1P000005oooooa4000001_ooool5000000Kooooo4@00
0005ooooo`l0dLfY000>0=7=ZAKooooo;@00000Fooooo``0dLfY1oooool7000001cooooo1P00000L
ooooo`L000001oooool<0=7=Z@`000001oooool=000000Kooooo3@000006ooooo`d000001_ooool=
000000`0dLfY1P000006ooooo`H000001_oooolZ000000cooooo3000000<0=7=Z@Gooooo2`000006
ooooo`H000001OoooolA000000Kooooo1@000006oooooa4000001Oooool?0=7=Z@003P3AcJTFoooo
obd000005_ooool<0=7=ZB?ooooo1`000006ooooo`L000001ooooolE000000Oooooo303AcJT<0000
00Oooooo3@000006ooooo`d000001_ooool=000000Kooooo3@00000<0=7=Z@H000001_ooool60000
00Kooooo:P00000<ooooo``00000303AcJT5ooooo`/000001_ooool6000000Gooooo4@000006oooo
o`D000001_oooolA000000Gooooo3`3AcJT000h0dLfY5_ooool]000001Kooooo303AcJTSooooo`L0
00001_ooool7000000Oooooo5@000007ooooo``0dLfY30000007ooooo`d000001_ooool=000000Ko
oooo3@000006ooooo`d00000303AcJT6000000Kooooo1P000006ooooobX000003?ooool<000000`0
dLfY1Oooool;000000Kooooo1P000005oooooa4000001_ooool5000000Kooooo4@000005ooooo`l0
dLfY000>0=7=ZAKooooo;@00000Fooooo``0dLfY8oooool7000000Kooooo1`000007oooooaD00000
1oooool<0=7=Z@`000001oooool=000000Kooooo3@000006ooooo`d000001_ooool=000000`0dLfY
1P000006ooooo`H000001_oooolZ000000cooooo3000000<0=7=Z@Gooooo1P000005oooooa`00000
1_ooool;000001Oooooo1@00000?0=7=Z@003P3AcJTFooooobd000005_ooool<0=7=ZB?ooooo1`00
0006ooooo`L000001ooooolE000000Oooooo303AcJT<000001[ooooo3@00000Iooooo`d00000303A
cJT6000000Kooooo1P000006ooooobX000003?ooool<000000`0dLfY1Oooool6000000Gooooo7000
0006ooooo`/000005oooool5000000l0dLfY000>0=7=Z@L000007_ooool?000001kooooo1`00000<
0=7=ZB?ooooo1`000006ooooo`L000001ooooolE000000Oooooo303AcJT<000001[ooooo3@00000I
ooooo`d00000303AcJT6000000Kooooo1P000006ooooobX000003?ooool<000000`0dLfY1Oooool6
000000Gooooo70000006ooooo`/000005oooool5000000l0dLfY000>0=7=Z@L000007_ooool?0000
01kooooo1`00000<0=7=ZB?ooooo1`000006ooooo`L000001ooooolE000000Oooooo303AcJT<0000
01[ooooo3@00000Iooooo`d00000303AcJT<ooooo`H000001_oooolB000000Kooooo4P00000<oooo
o``00000303AcJT5ooooo`H000001OoooolL000000Kooooo2`00000Gooooo`D000003`3AcJT000h0
dLfY1`00000Nooooo`l000007_ooool7000000`0dLfY8oooool7000000Kooooo1`000007oooooaD0
00001oooool<0=7=Z@`000006_ooool=000001Wooooo3@00000<0=7=Z@cooooo1P000006oooooa80
00001_oooolB000000cooooo3000000<0=7=Z@Gooooo1P000005oooooa`000001_ooool;000001Oo
oooo1@00000?0=7=Z@003P3AcJT7000001kooooo3`00000Nooooo`L00000303AcJTS000001Cooooo
5@00000>ooooo``0dLfY3000000Jooooo`d000006Oooool=000000`0dLfY3?ooool6000000Kooooo
4P000006oooooa8000003?ooool<000000`0dLfY1@00000;ooooo`H000004Oooool50000017ooooo
1P000005ooooo`H000002oooool?0=7=Z@003P3AcJT7000001kooooo3`00000Nooooo`L00000303A
cJTS000001Cooooo5@00000>ooooo``0dLfY3000000Jooooo`d000006Oooool=000000`0dLfY3?oo
ool6000000Kooooo4P000006oooooa8000003?ooool<000000`0dLfY1@00000;ooooo`H000004Ooo
ool50000017ooooo1P000005ooooo`H000002oooool?0=7=Z@003P3AcJT7000001kooooo3`00000N
ooooo`L00000303AcJTS000001Cooooo5@00000>ooooo``0dLfY4`000006ooooo`L000006Oooool7
000000Kooooo4`00000<0=7=Z@cooooo1P000006oooooa8000001_oooolB000000cooooo3000000<
0=7=Z@D000002oooool60000017ooooo1@00000Aooooo`H000001Oooool6000000_ooooo3`3AcJT0
00h0dLfY1`00000Nooooo`l000007_ooool7000000`0dLfY8`00000DoooooaD000003_ooool<0=7=
ZA<000001_ooool7000001Wooooo1`000006oooooa<00000303AcJT<ooooo`H000001_oooolB0000
00Kooooo4P00000<ooooo``00000303AcJT5000000_ooooo1P00000Aooooo`D000004Oooool60000
00Gooooo1P00000;ooooo`l0dLfY000>0=7=Z@oooooo1`00000?ooooo`l000003oooool7000000oo
oooo303AcJTS000001Cooooo5@00000>ooooo``0dLfY4`000006ooooo`L000006Oooool7000000Ko
oooo4`00000<0=7=Z@`000001_oooolH000000Kooooo4P00000<ooooo`H000001_ooool<0=7=Z@D0
00002oooool60000017ooooo1@00000Aooooo`H000001Oooool6000000_ooooo3`3AcJT000h0dLfY
3oooool7000000oooooo3`00000?ooooo`L000003oooool<0=7=ZB<000005?oooolE000000kooooo
303AcJTC000000Kooooo1`00000Iooooo`L000001_oooolC000000`0dLfY30000006oooooaP00000
1_oooolB000000cooooo1P000006ooooo``0dLfY1@00000;ooooo`H000004Oooool50000017ooooo
1P000005ooooo`H000002oooool?0=7=Z@003P3AcJT?ooooo`L000003oooool?000000oooooo1`00
000?ooooo``0dLfY1oooool>000000Oooooo3P00000=ooooo`L000003_ooool7000000Oooooo303A
cJTC000000Kooooo1`00000Iooooo`L000001_oooolC000000`0dLfY30000006oooooaP000001_oo
oolB000000cooooo1P000006ooooo``0dLfY1Oooool6000000Gooooo7000000Aoooooa`000003`3A
cJT000h0dLfY3oooool7000000oooooo3`00000?ooooo`L000003oooool<0=7=Z@Oooooo3P000007
ooooo`h000003Oooool7000000kooooo1`000007ooooo``0dLfY4`000006ooooo`L000006Oooool7
000000Kooooo4`00000<0=7=Z@`000001_oooolH000000Kooooo4P00000<ooooo`H000001_ooool<
0=7=Z@Gooooo1P000005oooooa`000004OoooolL000000l0dLfY000>0=7=Z@oooooo1`00000?oooo
o`l000003oooool7000000oooooo303AcJT7ooooo`h000001oooool>000000gooooo1`00000>oooo
o`L000001oooool<0=7=Z@Kooooo1P00000Jooooo`d000006Oooool7000000Kooooo303AcJT<0000
00Kooooo60000006oooooa8000003?ooool6000000Kooooo303AcJT5ooooo`H000001OoooolL0000
017ooooo7000000?0=7=Z@003P3AcJT?ooooo`L000003oooool?000000oooooo1`00000?ooooo``0
dLfY1oooool>000000Oooooo3P00000=ooooo`L000003_ooool7000000Oooooo303AcJT6ooooo`H0
00006_ooool=000001Wooooo1`000006ooooo``0dLfY30000006oooooaP000001_oooolB000000co
oooo1P000006ooooo``0dLfY1Oooool6000000Gooooo7000000Aoooooa`000003`3AcJT000h0dLfY
3oooool7000000oooooo3`00000?ooooo`L000003oooool<0=7=Z@Oooooo3P000007ooooo`h00000
3Oooool7000000kooooo1`000007ooooo``0dLfY1_ooool6000001[ooooo3@00000Iooooo`L00000
1_ooool<0=7=Z@Kooooo3000000Hooooo``000003?ooool6000001;ooooo303AcJT5ooooo`H00000
1OoooolL0000017ooooo7000000?0=7=Z@003P3AcJT7000004_ooooo1`00000<0=7=Z@Oooooo3P00
0007ooooo`h000003Oooool7000000kooooo1`000007ooooo``0dLfY1_ooool6000001[ooooo3@00
000Iooooo`L000001_ooool<0=7=Z@Kooooo3000000Hooooo``000003?ooool6000001;ooooo303A
cJTLoooooa0000008_ooool;000000l0dLfY000>0=7=Z@L00000Boooool7000000`0dLfY1oooool>
000000Oooooo3P00000=ooooo`L000003_ooool7000000Oooooo303AcJT6ooooo`H000006_ooool=
000001Wooooo1`000006ooooo``0dLfY1_ooool<000001Sooooo3000000<ooooo`H000004_ooool<
0=7=ZAcooooo4000000Rooooo`/000003`3AcJT000h0dLfY1`00001;ooooo`L00000303AcJTLoooo
o`h000003Oooool>000000Oooooo1`000007ooooo``0dLfY1_ooool6000001[ooooo3@00000Ioooo
o`L000001_ooool<0=7=Z@Kooooo3000000Hooooo``000003?ooool6000001;ooooo303AcJTLoooo
oa0000008_ooool;000000l0dLfY000>0=7=Z@L00000Boooool7000000`0dLfY7?ooool>000000go
oooo3P000007ooooo`L000001oooool<0=7=Z@Kooooo1P00000DoooooaT000004oooool7000000Ko
oooo303AcJT6ooooo``000006?ooool<000000cooooo1P00000Booooo``0dLfY7?ooool@000002;o
oooo2`00000?0=7=Z@003P3AcJT7000004_ooooo1`00000<0=7=ZAcooooo3P00000=ooooo`h00000
1oooool7000000Oooooo303AcJT6ooooo`H000005?oooolI000001?ooooo1`000006ooooo``0dLfY
1_ooool<000001Sooooo3000000<ooooo`H000004_ooool<0=7=ZAcooooo4000000Rooooo`/00000
3`3AcJT000h0dLfY1`00001;ooooo`L00000303AcJTLooooo`h000003Oooool>000000Oooooo1`00
0007ooooo``0dLfY1_ooool6000001Cooooo6@00000Cooooo`L000001_ooool<0=7=Z@H000007_oo
ool<000000Kooooo1P00000Nooooo``0dLfY7?ooool@000002;ooooo2`00000?0=7=Z@003P3AcJT7
000004_ooooo1`00000<0=7=ZAcooooo3P00000=ooooo`h000001oooool7000000Oooooo303AcJT6
ooooo`H000005?oooolI000001?ooooo1`000006ooooo``0dLfY1P00000Nooooo``000001_ooool6
000001kooooo303AcJTLoooooa`000001Oooool6000001Kooooo3`3AcJT000h0dLfY1`00001;oooo
o`L00000303AcJTLooooo`h000003Oooool>000000Oooooo1`000007ooooo``0dLfY1_ooool60000
01Cooooo6@00000Cooooo`L000001_ooool<0=7=Z@H000007_ooool<000000Kooooo1P00000Noooo
o``0dLfY7?oooolL000000Gooooo1P00000Fooooo`l0dLfY000>0=7=Z@Oooooo3`00000]ooooo`l0
00001oooool<0=7=ZAcooooo3P00000=ooooo`h000001oooool7000000Oooooo303AcJT6ooooo`H0
00005?oooolI000001?ooooo1`000006ooooo``0dLfY1P00000Nooooo``000001_ooool6000001ko
oooo303AcJTLoooooa`000001Oooool6000001Kooooo3`3AcJT000h0dLfY1oooool?000002gooooo
3`000007ooooo``0dLfY3_ooool>000000Oooooo3@000007ooooo`h000005Oooool<0=7=Z@Kooooo
1P00000DoooooaT000004oooool7000000Kooooo303AcJT6000001kooooo30000006ooooo`H00000
7_ooool<0=7=ZAcooooo70000005ooooo`H000005_ooool?0=7=Z@003P3AcJT7ooooo`l00000;Ooo
ool?000000Oooooo303AcJT>ooooo`h000001oooool=000000Oooooo3P00000Eooooo``0dLfY1_oo
ool6000000Oooooo1P00000=ooooo`d000003Oooool6000000Kooooo1`000006ooooo``0dLfY1P00
000Nooooo``000001_ooool6000001kooooo303AcJTLoooooa`000001Oooool6000001Kooooo3`3A
cJT000h0dLfY1oooool?000002gooooo3`000007ooooo``0dLfY3_ooool>000000Oooooo3@000007
ooooo`h000005Oooool<0=7=Z@Kooooo1P000007ooooo`H000003Oooool=000000gooooo1P000006
ooooo`L000001_ooool<0=7=Z@Kooooo1P00000<ooooo`H000004_ooool6000000Kooooo4P000006
ooooo`H00000303AcJT@000000Kooooo1P00000;oooooa4000001OoooolL000000l0dLfY000>0=7=
Z@Oooooo3`00000]ooooo`l000001oooool<0=7=Z@kooooo3P000007ooooo`d000001oooool>0000
01Gooooo303AcJT6ooooo`H000001oooool6000000gooooo3@00000=ooooo`H000001_ooool70000
00Kooooo303AcJT6ooooo`H000003?ooool6000001;ooooo1P000006oooooa8000001_ooool60000
00`0dLfY40000006ooooo`H000002ooooolA000000Gooooo7000000?0=7=Z@003P3AcJT7ooooo`l0
0000;Oooool?000000Oooooo303AcJT>ooooo`h000001oooool=000000Oooooo3P00000Eooooo``0
dLfY1_ooool6000000Oooooo1P00000=ooooo`d000003Oooool6000000Kooooo1`000006ooooo``0
dLfY1_ooool6000000cooooo1P00000Booooo`H000001_oooolB000000Kooooo1P00000<0=7=ZA00
00001_ooool6000000_ooooo4@000005oooooa`000003`3AcJT000h0dLfY1oooool?000002gooooo
3`000007ooooo``0dLfY3_ooool>000000Oooooo3@000007ooooo`h000005Oooool<0=7=Z@Kooooo
1P000007ooooo`H000003Oooool=000000gooooo1P000006ooooo`L000001_ooool<0=7=Z@Kooooo
1P00000<ooooo`H000004_ooool6000000Kooooo4P000006ooooo`H00000303AcJT@000000Kooooo
1P00000;oooooa4000001OoooolL000000l0dLfY000>0=7=Z@L000002?ooool?000001gooooo3`00
0008ooooo`L00000303AcJT>ooooo`h000001oooool=000000Oooooo3P00000Eooooo``0dLfY1_oo
ool6000000Oooooo1P00000=ooooo`d000003Oooool6000000Kooooo1`000006ooooo``0dLfY1_oo
ool6000000cooooo1P00000Booooo`H000001_oooolB000000Kooooo1P00000<0=7=ZA0000001_oo
ool6000000_ooooo4@000005oooooa`000003`3AcJT000h0dLfY1`000008ooooo`l000007Oooool?
000000Sooooo1`00000<0=7=ZCOooooo1`00000Looooo``0dLfY1P00000CooooobL000004oooool6
000000`0dLfY30000006ooooo`H000001_ooool6000000Kooooo1P00000<oooooaP000001_ooool<
0=7=ZA0000001_ooool6000000_ooooo4@000005oooooa`000003`3AcJT000h0dLfY1`000008oooo
o`l000007Oooool?000000Sooooo1`00000<0=7=ZCOooooo1`00000Looooo``0dLfY1P00000Coooo
obL000004oooool6000000`0dLfY30000006ooooo`H000001_ooool6000000Kooooo1P00000<oooo
oaP000001_ooool<0=7=Z@_ooooo4@000005ooooo`H000004Oooool5000000_ooooo1P00000;oooo
o`l0dLfY000>0=7=Z@L000002?ooool?000001gooooo3`000008ooooo`L00000303AcJTgooooo`L0
00007?ooool<0=7=Z@H000004ooooolW000001?ooooo1P00000<0=7=Z@`000001_ooool6000000Ko
oooo1P000006ooooo`H000003?oooolH000000Kooooo303AcJT;oooooa4000001Oooool60000017o
oooo1@00000;ooooo`H000002oooool?0=7=Z@003P3AcJT7000000Sooooo3`00000Mooooo`l00000
2?ooool7000000`0dLfY=oooool7000001cooooo303AcJT6000001?ooooo9`00000Cooooo`H00000
303AcJT<000000Kooooo1P000006ooooo`H000001_ooool6000000cooooo60000006ooooo``0dLfY
2ooooolA000000Gooooo1P00000Aooooo`D000002oooool6000000_ooooo3`3AcJT000h0dLfY1`00
0008ooooo`l000007Oooool?000000Sooooo1`00000<0=7=ZCOooooo1`00000Looooo``0dLfY1P00
000CooooobL000004oooool6000000`0dLfY30000006ooooo`H000001_ooool6000000Kooooo1P00
000<oooooaP000001_ooool<0=7=Z@_ooooo4@000005ooooo`H000004Oooool5000000_ooooo1P00
000;ooooo`l0dLfY000>0=7=Z@L000002?ooool?000001gooooo3`000008ooooo`L00000303AcJTg
ooooo`L000007?ooool<0=7=Z@H000004ooooolW000001?ooooo1P00000<0=7=Z@`000001_ooool6
000000Kooooo1P000006ooooo`H000003?oooolH000000Kooooo303AcJT;oooooa4000001Oooool6
0000017ooooo1@00000;ooooo`H000002oooool?0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0
dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT0
0?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3A
cJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00
o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT000h0dLfY3Oooool<0000043ooooo303AcJT;
000001Oooooo2`00000]ooooo``0dLfYFOooool<0=7=Z@T000006oooool9000002gooooo303AcJT8
0000013ooooo6000000Aooooo`P000004?ooool?0=7=Z@003P3AcJT=ooooo``00000@?ooool<0=7=
Z@/000005oooool;000002gooooo303AcJUIooooo``0dLfY2@00000Kooooo`T00000;Oooool<0=7=
Z@P000004?oooolH0000017ooooo2000000@ooooo`l0dLfY000>0=7=Z@gooooo30000010ooooo``0
dLfY2`00000Gooooo`/00000;Oooool<0=7=ZEWooooo303AcJT9000001_ooooo2@00000]ooooo``0
dLfY2000000@oooooaP000004Oooool80000013ooooo3`3AcJT000h0dLfY3Oooool<0000043ooooo
303AcJT;000001Oooooo2`00000]ooooo``0dLfYFOooool<0=7=Z@T000006oooool9000002gooooo
303AcJT80000013ooooo6000000Aooooo`P000004?ooool?0=7=Z@003P3AcJT=ooooo``00000@?oo
ool<0=7=Z@/000005oooool;000002gooooo303AcJUIooooo``0dLfY2@00000Kooooo`T00000;Ooo
ool<0=7=Z@P000004?oooolH0000017ooooo2000000@ooooo`l0dLfY000>0=7=Z@gooooo30000010
ooooo``0dLfY2`00000Gooooo`/00000;Oooool<0=7=ZEWooooo303AcJT9000001_ooooo2@00000]
ooooo``0dLfY2000000@oooooaP000004Oooool80000013ooooo3`3AcJT000h0dLfY3Oooool<0000
043ooooo303AcJT;000001Oooooo2`00000]ooooo``0dLfYFOooool<0=7=Z@T000006oooool90000
02gooooo303AcJT80000013ooooo6000000Aooooo`P000004?ooool?0=7=Z@003P3AcJT=ooooo``0
0000@?ooool<0=7=Z@/000005oooool;000002gooooo303AcJUIooooo``0dLfY2@00000Kooooo`T0
0000;Oooool<0=7=Z@P000004?oooolH0000017ooooo2000000@ooooo`l0dLfY000>0=7=Z@gooooo
30000010ooooo``0dLfY2`00000Gooooo`/00000;Oooool<0=7=ZEWooooo303AcJT9000001_ooooo
2@00000]ooooo``0dLfY60000008ooooo`P000002?oooolY000000l0dLfY000>0=7=Z@gooooo3000
0010ooooo``0dLfY2`00000Gooooo`/00000;Oooool<0=7=ZEWooooo303AcJT9ooooo`T000002Ooo
ool9000000Wooooo2@000009ooooo`T000002Oooool9000000`0dLfY60000008ooooo`P000002?oo
oolY000000l0dLfY000>0=7=Z@gooooo30000010ooooo``0dLfY2`00000Gooooo`/00000;Oooool<
0=7=ZBL000002_ooool:000001kooooo303AcJT9ooooo`T000002Oooool9000000Wooooo2@000009
ooooo`T000002Oooool9000000`0dLfY60000008ooooo`P000002?oooolY000000l0dLfY000>0=7=
Z@gooooo30000010ooooo``0dLfY2ooooolR000001Kooooo3000000;ooooo``0dLfY9`00000:oooo
o`X000007_ooool<0=7=Z@Wooooo2@000009ooooo`T000002Oooool9000000Wooooo2@000009oooo
o`T00000303AcJTH000000Sooooo20000008ooooobT000003`3AcJT000h0dLfY3Oooool<0000043o
oooo303AcJT;ooooob8000005_ooool<000000_ooooo303AcJTW000000[ooooo2P00000Nooooo``0
dLfY2Oooool9000000Wooooo2@000009ooooo`T000002Oooool9000000Wooooo2@00000<0=7=ZAP0
00002?ooool8000000Sooooo:@00000?0=7=Z@003P3AcJTIoooooaX000006_ooool<000000`0dLfY
2ooooolR000001Kooooo3000000;ooooo``0dLfY9`00000:ooooo`X000007_ooool<0=7=Z@Wooooo
2@000009ooooo`T000002Oooool9000000Wooooo2@000009ooooo`T00000303AcJTH000000Sooooo
20000008ooooobT000003`3AcJT000h0dLfY6OoooolJ000001[ooooo3000000<0=7=Z@_ooooo8P00
000Fooooo``000002oooool<0=7=ZBL000002_ooool:000001kooooo303AcJT9ooooo`T000002Ooo
ool9000000Wooooo2@000009ooooo`T000002Oooool9000000`0dLfY60000008ooooo`P000002?oo
oolY000000l0dLfY000>0=7=ZAWooooo6P00000Jooooo``00000303AcJT;ooooob8000005_ooool<
000000_ooooo303AcJTW000000[ooooo2P00000Nooooo``0dLfY2Oooool9000000Wooooo2@000009
ooooo`T000002Oooool9000000Wooooo2@00000<0=7=ZAP000002?ooool8000000Sooooo:@00000?
0=7=Z@003P3AcJTIoooooaX000006_ooool<000000`0dLfY2ooooolR000001Kooooo3000000;oooo
o``0dLfY9`00000:ooooo`X000007_ooool<0=7=Z@Wooooo2@000009ooooo`T000002Oooool90000
00Wooooo2@000009ooooo`T00000303AcJT8ooooo`P000002?oooolH000000Wooooo20000008oooo
oa0000003`3AcJT000h0dLfY6OoooolJ000001[ooooo3000000<0=7=Z@_ooooo8P00000Fooooo``0
00002oooool<0=7=ZBL000002_ooool:000001kooooo303AcJT9ooooo`T000002Oooool9000000Wo
oooo2@000009ooooo`T000002Oooool9000000`0dLfY2?ooool8000000Sooooo60000009ooooo`P0
00002?ooool@000000l0dLfY000>0=7=ZAWooooo6P00000Jooooo``00000303AcJT;ooooob800000
5_ooool<000000_ooooo303AcJTW000000[ooooo2P00000Nooooo``0dLfY2OoooolK000000Wooooo
2@00000Kooooo`T00000303AcJT8ooooo`P000002?oooolH000000Wooooo20000008oooooa000000
3`3AcJT000h0dLfY6OoooolJ000001[ooooo3000000<0=7=Z@_ooooo8P00000Fooooo``000002ooo
ool<0=7=Z@X000002_ooool:000000Wooooo5000000:ooooo`X000002_ooool<0=7=Z@Wooooo6`00
0009ooooo`T000006oooool9000000`0dLfY2?ooool8000000Sooooo60000009ooooo`P000002?oo
ool@000000l0dLfY000>0=7=ZAWooooo6P00000Jooooo``00000303AcJT;ooooob8000005_ooool<
000000_ooooo303AcJT:000000[ooooo2P000009oooooa@000002_ooool:000000[ooooo303AcJT9
oooooa/000002Oooool9000001_ooooo2@00000<0=7=Z@Sooooo20000008oooooaP000002Oooool8
000000Sooooo4000000?0=7=Z@003P3AcJTIoooooaX000006_ooool<000000`0dLfY2ooooolR0000
01Kooooo3000000;ooooo``0dLfY2P00000:ooooo`X000002OoooolD000000[ooooo2P00000:oooo
o``0dLfY2OoooolK000000Wooooo2@00000Kooooo`T00000303AcJT8ooooo`P000002?oooolH0000
00Wooooo20000008oooooa0000003`3AcJT000h0dLfY6OoooolJ000001[ooooo3000000<0=7=Z@_o
oooo3000000Fooooo`/000008_ooool<0=7=Z@X000002_ooool:000000Wooooo5000000:ooooo`X0
00002_ooool<0=7=Z@Wooooo6`000009ooooo`T000006oooool9000000`0dLfY2?ooool8000000So
oooo60000009ooooo`P000002?ooool@000000l0dLfY000>0=7=ZAWooooo6P00000Jooooo``00000
303AcJT;ooooo``000005_ooool;000002;ooooo303AcJT:000000[ooooo2P000009oooooa@00000
2_ooool:000000[ooooo303AcJT9oooooa/000002Oooool9000001_ooooo2@00000<0=7=Z@Sooooo
20000008oooooaP000002Oooool8000000Sooooo4000000?0=7=Z@003P3AcJTIoooooaX000006_oo
ool<000000`0dLfY2oooool<000001Kooooo2`00000Rooooo``0dLfY2P00000:ooooo`X000002Ooo
oolD000000[ooooo2P00000:ooooo``0dLfY2OoooolK000000Wooooo2@00000Kooooo`T00000303A
cJTPooooo`P000008Oooool@000000l0dLfY000>0=7=Z@d000003?oooom0000000`0dLfY2oooool<
000001Kooooo2`00000Rooooo``0dLfY2P00000:ooooo`X000002OoooolD000000[ooooo2P00000:
ooooo``0dLfY2OoooolK000000Wooooo2@00000Kooooo`T00000303AcJTPooooo`P000008Oooool@
000000l0dLfY000>0=7=Z@d000003?oooom0000000`0dLfY2oooool<000001Kooooo2`00000Roooo
o``0dLfY2P00000:ooooo`X000002OoooolD000000[ooooo2P00000:ooooo``0dLfY6`00000Boooo
ob@000002Oooool<0=7=ZB3ooooo2000000Qoooooa0000003`3AcJT000h0dLfY3@00000<oooood00
0000303AcJT;ooooo``000005_ooool;000002;ooooo303AcJT:000000[ooooo2P000009oooooa@0
00002_ooool:000000[ooooo303AcJTK000001;ooooo90000009ooooo``0dLfY8?ooool80000027o
oooo4000000?0=7=Z@003P3AcJT=000000cooooo@000000<0=7=Z@_ooooo3000000Fooooo`/00000
8_ooool<0=7=Z@X000002_ooool:000000Wooooo5000000:ooooo`X000002_ooool<0=7=ZA/00000
4_oooolT000000Wooooo303AcJTPooooo`P000008Oooool@000000l0dLfY000>0=7=Z@d000003?oo
oom0000000`0dLfY2oooool<000001Kooooo2`00000Rooooo``0dLfY5000000Cooooo`X000002_oo
ool:000001Cooooo303AcJTK000001;ooooo90000009ooooo``0dLfY8?ooool80000027ooooo4000
000?0=7=Z@003P3AcJT=000000cooooo@000000<0=7=Z@_ooooo3000000Fooooo`/000008_ooool<
0=7=ZA@000004oooool:000000[ooooo2P00000Dooooo``0dLfY6`00000Booooob@000002Oooool<
0=7=ZB3ooooo2000000Qoooooa0000003`3AcJT000h0dLfY3@00000<oooood000000303AcJT;oooo
o``000005_ooool;000002;ooooo303AcJTD000001?ooooo2P00000:ooooo`X000005?ooool<0=7=
ZA/000004_oooolT000000Wooooo303AcJTPooooo`P000008Oooool@000000l0dLfY000>0=7=Z@d0
00003?oooom0000000`0dLfY2oooool<000001Kooooo2`00000Rooooo``0dLfY5000000Cooooo`X0
00002_ooool:000001Cooooo303AcJTK000001;ooooo90000009ooooo``0dLfY2?ooool@000000So
oooo20000008oooooa4000002?ooool@000000l0dLfY000>0=7=Z@d000003?oooom0000000`0dLfY
8_oooolh000000`0dLfY5000000Cooooo`X000002_ooool:000001Cooooo303AcJTK000001;ooooo
90000009ooooo``0dLfY2?ooool@000000Sooooo20000008oooooa4000002?ooool@000000l0dLfY
000>0=7=Z@d000003?oooom0000000`0dLfY8_oooolh000000`0dLfY5000000Cooooo`X000002_oo
ool:000001Cooooo303AcJTK000001;ooooo90000009ooooo``0dLfY2?ooool@000000Sooooo2000
0008oooooa4000002?ooool@000000l0dLfY000>0=7=Z@d000003?oooom0000000`0dLfY8_oooolh
000000`0dLfY5000000Cooooo`X000002_ooool:000001Cooooo303AcJT9000001;ooooo4P000009
ooooo`T000002OoooolB000000`0dLfY2?ooool@000000Sooooo20000008oooooa4000002?ooool@
000000l0dLfY000>0=7=Z@d000003?oooom0000000`0dLfY8_oooolh000000`0dLfY5000000Coooo
o`X000002_ooool:000001Cooooo303AcJT9000001;ooooo4P000009ooooo`T000002OoooolB0000
00`0dLfY2?ooool@000000Sooooo20000008oooooa4000002?ooool@000000l0dLfY000>0=7=Z@d0
00003?oooom0000000`0dLfY8_oooolh000000`0dLfY5000000Cooooo`X000002_ooool:000001Co
oooo303AcJT9000001;ooooo4P000009ooooo`T000002OoooolB000000`0dLfY2?ooool@000000So
oooo20000008oooooa4000002?ooool@000000l0dLfY000>0=7=Z@gooooo@000000<ooooo``0dLfY
8_oooolh000000`0dLfY5000000Cooooo`X000002_ooool:000001Cooooo303AcJT9000001;ooooo
4P000009ooooo`T000002OoooolB000000`0dLfY2?ooool@000000Sooooo20000008oooooa400000
2?ooool@000000l0dLfY000>0=7=Z@gooooo@000000<ooooo``0dLfY8_oooolh000000`0dLfY2P00
000:ooooobL000002_oooolD000000`0dLfY2@00000Boooooa8000002Oooool9000000Wooooo4P00
000<0=7=Z@Sooooo40000008ooooo`P000002?oooolA000000Sooooo4000000?0=7=Z@003P3AcJT=
oooood0000003?ooool<0=7=ZB;ooooo>000000<0=7=Z@X000002_oooolW000000[ooooo5000000<
0=7=Z@T000004_oooolB000000Wooooo2@000009oooooa800000303AcJUI000000l0dLfY000>0=7=
Z@gooooo@000000<ooooo``0dLfY8_oooolh000000`0dLfY2P00000:ooooobL000002_oooolD0000
00`0dLfY2@00000Boooooa8000002Oooool9000000Wooooo4P00000<0=7=ZET000003`3AcJT000h0
dLfY3Ooooom0000000cooooo303AcJTRooooocP00000303AcJT:000000[ooooo9`00000:oooooa@0
0000303AcJT9000001;ooooo4P000009ooooo`T000002OoooolB000000`0dLfYF@00000?0=7=Z@00
3P3AcJT=oooood0000003?ooool<0=7=ZB;ooooo>000000<0=7=Z@X000002_oooolW000000[ooooo
5000000<0=7=Z@T000004_oooolB000000Wooooo2@000009oooooa800000303AcJUI000000l0dLfY
000>0=7=Z@gooooo@000000<ooooo``0dLfY8_oooolh000000`0dLfY2P00000:ooooobL000002_oo
oolD000000`0dLfY2Oooool9000000Wooooo4P000009ooooo`T000006oooool<0=7=ZET000003`3A
cJT000h0dLfY3Ooooom0000000cooooo303AcJTRooooocP00000303AcJT:000000[ooooo9`00000:
oooooa@00000303AcJT9ooooo`T000002OoooolB000000Wooooo2@00000Kooooo``0dLfYF@00000?
0=7=Z@003P3AcJT=oooood0000003?ooool<0=7=ZB;ooooo>000000<0=7=Z@X000002_oooolW0000
00[ooooo5000000<0=7=Z@Wooooo2@000009oooooa8000002Oooool9000001_ooooo303AcJUI0000
00l0dLfY000>0=7=Z@gooooo@000000<ooooo``0dLfY8_oooolh000000`0dLfY2P00000:ooooobL0
00002_oooolD000000`0dLfY2Oooool9000000Wooooo4P000009ooooo`T000006oooool<0=7=ZET0
00003`3AcJT000h0dLfY3Ooooom0000000cooooo303AcJTRooooocP00000303AcJT:000000[ooooo
9`00000:oooooa@00000303AcJT9ooooo`T000002OoooolB000000Wooooo2@00000Kooooo``0dLfY
2?ooool@000000Sooooo20000008oooooa4000002?ooool@000000l0dLfY000>0=7=Z@gooooo@000
000<ooooo``0dLfY8_oooolh000000`0dLfY2P00000:oooooc/000002_ooool<0=7=Z@Wooooo2@00
0009oooooa8000002Oooool9000001_ooooo303AcJT8oooooa0000002?ooool8000000Sooooo4@00
0008oooooa0000003`3AcJT000h0dLfY@000000=ooooo``00000303AcJTRooooocP00000303AcJT:
000000[ooooo>`00000:ooooo``0dLfY2Oooool9000000Wooooo4P000009ooooo`T000006oooool<
0=7=Z@Sooooo40000008ooooo`P000002?oooolA000000Sooooo4000000?0=7=Z@003P3AcJU00000
00gooooo3000000<0=7=ZB;ooooo>000000<0=7=Z@X000002_oooolk000000[ooooo303AcJT9oooo
o`T000002OoooolB000000Wooooo2@00000Kooooo``0dLfY2?ooool@000000Sooooo20000008oooo
oa4000002?ooool@000000l0dLfY000>0=7=ZD0000003Oooool<000000`0dLfY8_oooolh000000`0
dLfY2P00000:oooooc/000002_ooool<0=7=Z@Wooooo2@000009oooooa8000002Oooool9000001_o
oooo303AcJT8oooooa0000002?ooool8000000Sooooo4@000008oooooa0000003`3AcJT000h0dLfY
@000000=ooooo``00000303AcJTRooooocP00000303AcJT:000000[ooooo>`00000:ooooo``0dLfY
4P00000Koooooa8000002Oooool9000000Wooooo303AcJT8oooooa0000002?ooool8000000Sooooo
4@000008oooooa0000003`3AcJT000h0dLfY@000000=ooooo``00000303AcJTRooooocP00000303A
cJT:000000[ooooo>`00000:ooooo``0dLfY4P00000Koooooa8000002Oooool9000000Wooooo303A
cJT8oooooa0000002?ooool8000000Sooooo4@000008oooooa0000003`3AcJT000h0dLfY@000000=
ooooo``00000303AcJT;ooooo``000005_ooool;000002;ooooo303AcJT:000000[ooooo>`00000:
ooooo``0dLfY4P00000Koooooa8000002Oooool9000000Wooooo303AcJT8oooooa0000002?ooool8
000000Sooooo4@000008oooooa0000003`3AcJT000h0dLfY@000000=ooooo``00000303AcJT;oooo
o``000005_ooool;000002;ooooo303AcJT:000000[ooooo>`00000:ooooo``0dLfY4P00000Koooo
oa8000002Oooool9000000Wooooo303AcJTPooooo`P000008Oooool@000000l0dLfY000>0=7=ZD00
00003Oooool<000000`0dLfY2oooool<000001Kooooo2`00000Rooooo``0dLfY2P00000:oooooc/0
00002_ooool<0=7=ZA8000006ooooolB000000Wooooo2@000009ooooo``0dLfY8?ooool80000027o
oooo4000000?0=7=Z@003P3AcJU0000000gooooo3000000<0=7=Z@_ooooo3000000Fooooo`/00000
8_ooool<0=7=Z@[ooooo2P00000:ooooo`T000002_oooolD000001Cooooo303AcJTB000001_ooooo
4P000009ooooo`T000002Oooool<0=7=ZB3ooooo2000000Qoooooa0000003`3AcJT000h0dLfY@000
000=ooooo``00000303AcJT;ooooo``000005_ooool;000002;ooooo303AcJT:ooooo`X000002_oo
ool9000000[ooooo5000000Dooooo``0dLfY4P00000Koooooa8000002Oooool9000000Wooooo303A
cJTPooooo`P000008Oooool@000000l0dLfY000>0=7=ZD0000003Oooool<000000`0dLfY2oooool<
000001Kooooo2`00000Rooooo``0dLfY2_ooool:000000[ooooo2@00000:oooooa@000005?ooool<
0=7=ZA8000006ooooolB000000Wooooo2@000009ooooo``0dLfY8?ooool80000027ooooo4000000?
0=7=Z@003P3AcJU0000000gooooo3000000<0=7=Z@_ooooo3000000Fooooo`/000008_ooool<0=7=
Z@[ooooo2P00000:ooooo`T000002_oooolD000001Cooooo303AcJTK000001;ooooo4P00000Koooo
o``0dLfY8?ooool80000027ooooo4000000?0=7=Z@003P3AcJU0000000gooooo3000000<0=7=Z@_o
oooo3000000Fooooo`/000008_ooool<0=7=Z@[ooooo2P00000:ooooo`T000002_oooolD000001Co
oooo303AcJTK000001;ooooo4P00000Kooooo``0dLfY8?ooool80000027ooooo4000000?0=7=Z@00
3P3AcJT=000001Wooooo6P00000Iooooo``0dLfY2oooool<000001Kooooo2`00000Rooooo``0dLfY
2_ooool:000000[ooooo2@00000:oooooa@000005?ooool<0=7=ZA/000004_oooolB000001_ooooo
303AcJTPooooo`P000008Oooool@000000l0dLfY000>0=7=Z@d000006OoooolJ000001Wooooo303A
cJT;ooooo``000005_ooool;000002;ooooo303AcJT:ooooo`X000002_ooool9000000[ooooo5000
000Dooooo``0dLfY6`00000Boooooa8000006oooool<0=7=Z@Sooooo20000008oooooaP000002Ooo
ool8000000Sooooo4000000?0=7=Z@003P3AcJT=000001Wooooo6P00000Iooooo``0dLfY2oooool<
000001Kooooo2`00000Rooooo``0dLfY2_ooool:000000[ooooo2@00000:oooooa@000005?ooool<
0=7=ZA/000004_oooolB000001_ooooo303AcJT8ooooo`P000002?oooolH000000Wooooo20000008
oooooa0000003`3AcJT000h0dLfY3@00000IoooooaX000006Oooool<0=7=Z@_ooooo8P00000Foooo
o``000002oooool<0=7=Z@[ooooo2P00000:ooooo`T000002_oooolD000001Cooooo303AcJTK0000
01;ooooo4P00000Kooooo``0dLfY2?ooool8000000Sooooo60000009ooooo`P000002?ooool@0000
00l0dLfY000>0=7=Z@d000006OoooolJ000001Wooooo303AcJT;ooooob8000005_ooool<000000_o
oooo303AcJT:ooooo`X000002_ooool9000000[ooooo5000000Dooooo``0dLfY6`00000Boooooa80
00006oooool<0=7=Z@Sooooo20000008oooooaP000002Oooool8000000Sooooo4000000?0=7=Z@00
3P3AcJT=000001Wooooo6P00000Iooooo``0dLfY2ooooolR000001Kooooo3000000;ooooo``0dLfY
2_oooolD000000Wooooo2P00000Xooooo``0dLfY6`00000Boooooa8000006oooool<0=7=Z@Sooooo
20000008oooooaP000002Oooool8000000Sooooo4000000?0=7=Z@003P3AcJT=000001Wooooo6P00
000Iooooo``0dLfY2ooooolR000001Kooooo3000000;ooooo``0dLfY2_oooolD000000Wooooo2P00
000Xooooo``0dLfY6`00000Boooooa8000006oooool<0=7=Z@Sooooo20000008oooooaP000002Ooo
ool8000000Sooooo4000000?0=7=Z@003P3AcJT=000001Wooooo6P00000Iooooo``0dLfY2ooooolR
000001Kooooo3000000;ooooo``0dLfY2_oooolD000000Wooooo2P00000Xooooo``0dLfY2Oooool9
000000Wooooo4P00000Booooo`T000002Oooool9000000`0dLfY2?ooool8000000Sooooo60000009
ooooo`P000002?ooool@000000l0dLfY000>0=7=Z@d000006OoooolJ000001Wooooo303AcJT;oooo
ob8000005_ooool<000000_ooooo303AcJT:oooooa@000002Oooool:000002Sooooo303AcJT9oooo
o`T000002OoooolB000001;ooooo2@000009ooooo`T00000303AcJT8ooooo`P000002?oooolH0000
00Wooooo20000008oooooa0000003`3AcJT000h0dLfY3@00000IoooooaX000006Oooool<0=7=Z@_o
oooo8P00000Fooooo``000002oooool<0=7=Z@[ooooo50000009ooooo`X00000:?ooool<0=7=Z@Wo
oooo2@000009oooooa8000004_ooool9000000Wooooo2@00000<0=7=ZAP000002?ooool8000000So
oooo:@00000?0=7=Z@003P3AcJT=000001Wooooo6P00000Iooooo``0dLfY2ooooolR000001Kooooo
3000000;ooooo``0dLfY2_oooolD000000Wooooo2P00000Xooooo``0dLfY2Oooool9000000Wooooo
4P00000Booooo`T000002Oooool9000000`0dLfY60000008ooooo`P000002?oooolY000000l0dLfY
000>0=7=Z@d000006OoooolJ000001Wooooo303AcJT;ooooob8000005_ooool<000000_ooooo303A
cJT:oooooa@000002Oooool:000002Sooooo303AcJT9ooooo`T000002OoooolB000001;ooooo2@00
0009ooooo`T00000303AcJTH000000Sooooo20000008ooooobT000003`3AcJT000h0dLfY@?ooool=
000000cooooo303AcJT;ooooob8000005_ooool<000000_ooooo303AcJT:oooooa@000002Oooool:
000002Sooooo303AcJT9ooooo`T000002OoooolB000001;ooooo2@000009ooooo`T00000303AcJTH
000000Sooooo20000008ooooobT000003`3AcJT000h0dLfY@?ooool=000000cooooo303AcJT;oooo
ob8000005_ooool<000000_ooooo303AcJT:oooooa@000002Oooool:000002Sooooo303AcJT9oooo
o`T000002OoooolB000001;ooooo2@000009ooooo`T00000303AcJTH000000Sooooo20000008oooo
obT000003`3AcJT000h0dLfY@?ooool=000000cooooo303AcJT;000001Oooooo2`00000]ooooo``0
dLfY2_oooolD000000Wooooo2P00000Xooooo``0dLfY2Oooool9000000Wooooo4P00000Booooo`T0
00002Oooool9000000`0dLfY60000008ooooo`P000002?oooolY000000l0dLfY000>0=7=ZD3ooooo
3@00000<ooooo``0dLfY2`00000Gooooo`/00000;Oooool<0=7=ZA@000009oooool:000000[ooooo
2P00000<0=7=Z@Wooooo2@000009oooooa8000004_ooool9000000Wooooo2@00000<0=7=ZAP00000
2?ooool8000000Sooooo:@00000?0=7=Z@003P3AcJU0ooooo`d000003?ooool<0=7=Z@/000005ooo
ool;000002gooooo303AcJTD000002Oooooo2P00000:ooooo`X00000303AcJT9000000Wooooo2@00
000Booooo`T000002Oooool9000001;ooooo303AcJTH000000Sooooo20000008ooooobT000003`3A
cJT000h0dLfY@?ooool=000000cooooo303AcJT;000001Oooooo2`00000]ooooo``0dLfY5000000W
ooooo`X000002_ooool:000000`0dLfY2@000009ooooo`T000004_ooool9000000Wooooo2@00000B
ooooo``0dLfY2000000@oooooaP000004Oooool80000013ooooo3`3AcJT000h0dLfY@?ooool=0000
00cooooo303AcJT;000001Oooooo2`00000]ooooo``0dLfY5000000Wooooo`X000002_ooool:0000
00`0dLfY2@000009ooooo`T000004_ooool9000000Wooooo2@00000Booooo``0dLfY2000000@oooo
oaP000004Oooool80000013ooooo3`3AcJT000h0dLfY@?ooool=000000cooooo303AcJT;000001Oo
oooo2`00000]ooooo``0dLfY5000000Wooooo`X000002_ooool:000000`0dLfY2@000009ooooo`T0
00004_ooool9000000Wooooo2@00000Booooo``0dLfY2000000@oooooaP000004Oooool80000013o
oooo3`3AcJT000h0dLfY@?ooool=000000cooooo303AcJT;000001Oooooo2`00000]ooooo``0dLfY
5000000Wooooo`X000002_ooool:000000`0dLfY2@000009ooooo`T000004_ooool9000000Wooooo
2@00000Booooo``0dLfY2000000@oooooaP000004Oooool80000013ooooo3`3AcJT000h0dLfY@?oo
ool=000000cooooo303AcJT;000001Oooooo2`00000]ooooo``0dLfY5000000Wooooo`X000002_oo
ool:000000`0dLfY2@000009ooooo`T000004_ooool9000000Wooooo2@00000Booooo``0dLfY2000
000@oooooaP000004Oooool80000013ooooo3`3AcJT000h0dLfY@?ooool=000000cooooo303AcJT;
000001Oooooo2`00000]ooooo``0dLfY5000000Wooooo`X000002_ooool:000000`0dLfY2@000009
ooooo`T000004_ooool9000000Wooooo2@00000Booooo``0dLfY2000000@oooooaP000004Oooool8
0000013ooooo3`3AcJT000h0dLfY@?ooool=000000cooooo303AcJT;000001Oooooo2`00000]oooo
o``0dLfY5000000Wooooo`X000002_ooool:000000`0dLfY2@000009ooooo`T000004_ooool90000
00Wooooo2@00000Booooo``0dLfY2000000@oooooaP000004Oooool80000013ooooo3`3AcJT000h0
dLfY@?ooool=000000cooooo303AcJT;000001Oooooo2`00000]ooooo``0dLfY5000000Wooooo`X0
00002_ooool:000000`0dLfY2@000009ooooo`T000004_ooool9000000Wooooo2@00000Booooo``0
dLfY2000000@oooooaP000004Oooool80000013ooooo3`3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3A
cJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0
dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=
ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3A
cJT00?l0dLfYo`3AcJT>0=7=Z@003P3AcJUIooooo``0dLfY7P00000looooo``0dLfYFOooool<0=7=
ZA8000004_oooolB000002Cooooo303AcJT>ooooo`l000003oooool?000001kooooo3`3AcJT000h0
dLfYFOooool<0=7=ZAh00000??ooool<0=7=ZEWooooo303AcJTB000001;ooooo4P00000Tooooo``0
dLfY3_ooool?000000oooooo3`00000Nooooo`l0dLfY000>0=7=ZEWooooo303AcJTN000003cooooo
303AcJUIooooo``0dLfY4P00000Boooooa8000009?ooool<0=7=Z@kooooo3`00000?ooooo`l00000
7_ooool?0=7=Z@003P3AcJUIooooo``0dLfY7P00000looooo``0dLfYFOooool<0=7=ZA8000004_oo
oolB000002Cooooo303AcJT>ooooo`l000003oooool?000001kooooo3`3AcJT000h0dLfYFOooool<
0=7=ZAh00000??ooool<0=7=ZEWooooo303AcJTB000001;ooooo4P00000Tooooo``0dLfY3_ooool?
000000oooooo3`00000Nooooo`l0dLfY000>0=7=ZEWooooo303AcJTN000003cooooo303AcJUIoooo
o``0dLfY4P00000Boooooa8000009?ooool<0=7=Z@kooooo3`00000?ooooo`l000007_ooool?0=7=
Z@003P3AcJUIooooo``0dLfY7P00000looooo``0dLfYFOooool<0=7=ZA8000004_oooolB000002Co
oooo303AcJT>ooooo`l000003oooool?000001kooooo3`3AcJT000h0dLfYFOooool<0=7=ZAh00000
??ooool<0=7=ZEWooooo303AcJTB000001;ooooo4P00000Tooooo``0dLfY3_ooool?000000oooooo
3`00000Nooooo`l0dLfY000>0=7=ZEWooooo303AcJTN000003cooooo303AcJUIooooo``0dLfY4P00
000Boooooa8000009?ooool<0=7=Z@kooooo3`00000?ooooo`l000007_ooool?0=7=Z@003P3AcJUI
ooooo``0dLfY7P00000looooo``0dLfYFOooool<0=7=ZA8000004_oooolB000002Cooooo303AcJT>
ooooo`l000003oooool?000001kooooo3`3AcJT000h0dLfYFOooool<0=7=ZAh00000??ooool<0=7=
ZEWooooo303AcJTB000001;ooooo4P00000Tooooo``0dLfY3_ooool?000000oooooo3`00000Noooo
o`l0dLfY000>0=7=ZEWooooo303AcJTN000003cooooo303AcJUIooooo``0dLfY4P00000Boooooa80
00009?ooool<0=7=Z@kooooo3`00000?ooooo`l000007_ooool?0=7=Z@003P3AcJUIooooo``0dLfY
7P00000looooo``0dLfYFOooool<0=7=ZA8000004_oooolB000002Cooooo303AcJT>ooooo`l00000
3oooool?000001kooooo3`3AcJT000h0dLfYFOooool<0=7=ZAh00000??ooool<0=7=ZEWooooo303A
cJTB000001;ooooo4P00000Tooooo``0dLfY3_ooool?000000oooooo3`00000Nooooo`l0dLfY000>
0=7=ZEWooooo303AcJTN000003cooooo303AcJUIooooo``0dLfY4P00000Boooooa8000009?ooool<
0=7=Z@kooooo3`00000?ooooo`l000007_ooool?0=7=Z@003P3AcJUIooooo``0dLfY7P00000loooo
o``0dLfYFOooool<0=7=ZA8000004_oooolB000002Cooooo303AcJTk000000oooooo3`00000?0=7=
Z@003P3AcJUIooooo``0dLfY7P00000looooo``0dLfYFOooool<0=7=ZA8000004_oooolB000002Co
oooo303AcJTk000000oooooo3`00000?0=7=Z@003P3AcJUIooooo``0dLfY7P00000looooo``0dLfY
FOooool<0=7=ZA8000004_oooolB000002Cooooo303AcJTk000000oooooo3`00000?0=7=Z@003P3A
cJUIooooo``0dLfY7P00000looooo``0dLfYFOooool<0=7=ZDP000004_ooool<0=7=ZC/000003ooo
ool?000000l0dLfY000>0=7=ZEWooooo303AcJTN000003cooooo303AcJUIooooo``0dLfYB000000B
ooooo``0dLfY>`00000?ooooo`l000003`3AcJT000h0dLfYFOooool<0=7=ZAh00000??ooool<0=7=
ZEWooooo303AcJU8000001;ooooo303AcJTk000000oooooo3`00000?0=7=Z@003P3AcJUIooooo``0
dLfY7P00000looooo``0dLfYFOooool<0=7=ZDP000004_ooool<0=7=ZC/000003oooool?000000l0
dLfY000>0=7=ZEWooooo303AcJTN000003cooooo303AcJTFooooobd000005_ooool<0=7=ZDP00000
4_ooool<0=7=ZC/000003oooool?000000l0dLfY000>0=7=ZEWooooo303AcJTN000003cooooo303A
cJTFooooobd000005_ooool<0=7=ZDP000004_ooool<0=7=ZC/000003oooool?000000l0dLfY000>
0=7=ZEWooooo303AcJTN000003cooooo303AcJTFooooobd000005_ooool<0=7=ZDP000004_ooool<
0=7=ZC/000003oooool?000000l0dLfY000>0=7=ZEWooooo303AcJTN000003cooooo303AcJTFoooo
obd000005_ooool<0=7=ZDP000004_ooool<0=7=ZC/000003oooool?000000l0dLfY000>0=7=ZEWo
oooo303AcJTN000003cooooo303AcJTFooooobd000005_ooool<0=7=ZDP000004_ooool<0=7=ZC/0
00003oooool?000000l0dLfY000>0=7=ZEWooooo303AcJTN000003cooooo303AcJTFooooobd00000
5_ooool<0=7=ZDP000004_ooool<0=7=ZC/000003oooool?000000l0dLfY000>0=7=ZEWooooo303A
cJTN000003cooooo303AcJTFooooobd000005_ooool<0=7=ZDP000004_ooool<0=7=ZC/000003ooo
ool?000000l0dLfY000>0=7=ZEWooooo303AcJTN000003cooooo303AcJTFooooobd000005_ooool<
0=7=ZDP000004_ooool<0=7=ZC/000003oooool?000000l0dLfY000>0=7=ZEWooooo303AcJTN0000
03cooooo303AcJTFooooobd000005_ooool<0=7=ZDP000004_ooool<0=7=Z@kooooo7P00000?oooo
o`l000003oooool?0=7=Z@003P3AcJUIooooo``0dLfY7P00000looooo``0dLfY5_ooool]000001Ko
oooo303AcJU8000001;ooooo303AcJT>oooooah000003oooool?000000oooooo3`3AcJT000h0dLfY
FOooool<0=7=ZAh00000??ooool<0=7=ZAKooooo;@00000Fooooo``0dLfYB000000Booooo``0dLfY
3_oooolN000000oooooo3`00000?ooooo`l0dLfY000>0=7=ZEWooooo303AcJTN000003cooooo303A
cJTFooooobd000005_ooool<0=7=ZDP000004_ooool<0=7=Z@kooooo7P00000?ooooo`l000003ooo
ool?0=7=Z@003P3AcJUIooooo``0dLfY7P00000looooo``0dLfY5_ooool]000001Kooooo303AcJU8
000001;ooooo303AcJT>oooooah000003oooool?000000oooooo3`3AcJT000h0dLfYFOooool<0=7=
ZAh00000??ooool<0=7=ZAKooooo;@00000Fooooo``0dLfYB000000Booooo``0dLfY3_oooolN0000
00oooooo3`00000?ooooo`l0dLfY000>0=7=ZEWooooo303AcJTN000003cooooo303AcJTFooooobd0
00005_ooool<0=7=ZBCooooo=P00000<0=7=Z@kooooo7P00000?ooooo`l000003oooool?0=7=Z@00
3P3AcJUIooooo``0dLfY7P00000looooo``0dLfY5_ooool]000001Kooooo303AcJTTooooocH00000
303AcJT>oooooah000003oooool?000000oooooo3`3AcJT000h0dLfYFOooool<0=7=ZAh00000??oo
ool<0=7=ZAKooooo;@00000Fooooo``0dLfY9?oooolf000000`0dLfY3_oooolN000000oooooo3`00
000?ooooo`l0dLfY000>0=7=ZEWooooo303AcJTN000003cooooo303AcJTFooooobd000005_ooool<
0=7=ZBCooooo=P00000<0=7=Z@kooooo7P00000?ooooo`l000003oooool?0=7=Z@003P3AcJUIoooo
o``0dLfY7P00000looooo``0dLfY5_ooool]000001Kooooo303AcJTTooooocH00000303AcJT>oooo
oah000003oooool?000000oooooo3`3AcJT000h0dLfYFOooool<0=7=ZAh00000??ooool<0=7=ZAKo
oooo;@00000Fooooo``0dLfY9?oooolf000000`0dLfY3_oooolN000000oooooo3`00000?ooooo`l0
dLfY000>0=7=ZEWooooo303AcJTN000003cooooo303AcJTFooooobd000005_ooool<0=7=ZBCooooo
=P00000<0=7=Z@kooooo7P00000?ooooo`l000003oooool?0=7=Z@003P3AcJUIooooo``0dLfY7P00
000looooo``0dLfY5_ooool]000001Kooooo303AcJTTooooocH00000303AcJT>oooooah000003ooo
ool?000000oooooo3`3AcJT000h0dLfY;@00000/ooooo``0dLfY7P00000looooo``0dLfYF@00000<
0=7=ZBCooooo=P00000<0=7=ZAd000003oooool?000001kooooo3`3AcJT000h0dLfY;@00000/oooo
o``0dLfY7P00000looooo``0dLfYF@00000<0=7=ZBCooooo=P00000<0=7=ZAd000003oooool?0000
01kooooo3`3AcJT000h0dLfY;@00000/ooooo``0dLfY7P00000looooo``0dLfYF@00000<0=7=ZBCo
oooo=P00000<0=7=ZAd000003oooool?000001kooooo3`3AcJT000h0dLfY;@00000/ooooo``0dLfY
7P00000looooo``0dLfYF@00000<0=7=ZBCooooo=P00000<0=7=ZAd000003oooool?000001kooooo
3`3AcJT000h0dLfY;@00000/ooooo``0dLfY7P00000looooo``0dLfYF@00000<0=7=ZBCooooo=P00
000<0=7=ZAd000003oooool?000001kooooo3`3AcJT000h0dLfY;@00000/ooooo``0dLfY7P00000l
ooooo``0dLfYF@00000<0=7=ZBCooooo=P00000<0=7=ZAd000003oooool?000001kooooo3`3AcJT0
00h0dLfY;@00000/ooooo``0dLfY7P00000looooo``0dLfYF@00000<0=7=ZBCooooo=P00000<0=7=
ZAd000003oooool?000001kooooo3`3AcJT000h0dLfY;@00000/ooooo``0dLfY7P00000looooo``0
dLfYF@00000<0=7=ZBCooooo=P00000<0=7=ZAd000003oooool?000001kooooo3`3AcJT000h0dLfY
;@00000/ooooo``0dLfY7P00000looooo``0dLfYF@00000<0=7=ZBCooooo=P00000<0=7=ZAd00000
3oooool?000001kooooo3`3AcJT000h0dLfY;@00000/ooooo``0dLfY7P00000looooo``0dLfYF@00
000<0=7=ZB@000004_oooolB000001;ooooo303AcJTM000000oooooo3`00000Nooooo`l0dLfY000>
0=7=ZBd00000;?ooool<0=7=ZAh00000??ooool<0=7=ZET00000303AcJTT000001;ooooo4P00000B
ooooo``0dLfY7@00000?ooooo`l000007_ooool?0=7=Z@003P3AcJT]000002cooooo303AcJTN0000
03cooooo303AcJUI000000`0dLfY9000000Boooooa8000004_ooool<0=7=ZAd000003oooool?0000
01kooooo3`3AcJT000h0dLfY;@00000/ooooo``0dLfY7P00000looooo``0dLfYF@00000<0=7=ZB@0
00004_oooolB000001;ooooo303AcJTM000000oooooo3`00000Nooooo`l0dLfY000>0=7=ZBd00000
;?ooool<0=7=ZAh00000??ooool<0=7=ZET00000303AcJTT000001;ooooo4P00000Booooo``0dLfY
7@00000?ooooo`l000007_ooool?0=7=Z@003P3AcJT]000002cooooo303AcJTN000003cooooo303A
cJUI000000`0dLfY9000000Boooooa8000004_ooool<0=7=ZAd000003oooool?000001kooooo3`3A
cJT000h0dLfY;@00000/ooooo``0dLfYFP00000<0=7=ZET00000303AcJTT000001;ooooo4P00000B
ooooo``0dLfY7Oooool?000000oooooo3`00000?ooooo`l0dLfY000>0=7=ZBd00000;?ooool<0=7=
ZEX00000303AcJUI000000`0dLfY9000000Boooooa8000004_ooool<0=7=ZAgooooo3`00000?oooo
o`l000003oooool?0=7=Z@003P3AcJT]000002cooooo303AcJUJ000000`0dLfYF@00000<0=7=ZB@0
00004_oooolB000001;ooooo303AcJTMooooo`l000003oooool?000000oooooo3`3AcJT000h0dLfY
;@00000/ooooo``0dLfYFP00000<0=7=ZET00000303AcJTT000001;ooooo4P00000Booooo``0dLfY
7Oooool?000000oooooo3`00000?ooooo`l0dLfY000>0=7=ZBd00000;?ooool<0=7=ZEX00000303A
cJUI000000`0dLfY9000000Boooooa8000004_ooool<0=7=ZAgooooo3`00000?ooooo`l000003ooo
ool?0=7=Z@003P3AcJT]000002cooooo303AcJUJ000000`0dLfYF@00000<0=7=ZB@000004_oooolB
000001;ooooo303AcJTMooooo`l000003oooool?000000oooooo3`3AcJT000h0dLfY;@00000/oooo
o``0dLfYFP00000<0=7=ZET00000303AcJTT000001;ooooo4P00000Booooo``0dLfY7Oooool?0000
00oooooo3`00000?ooooo`l0dLfY000>0=7=ZBd00000;?ooool<0=7=ZEX00000303AcJTFooooobd0
00005_ooool<0=7=ZB@000004_oooolB000001;ooooo303AcJTMooooo`l000003oooool?000000oo
oooo3`3AcJT000h0dLfY;@00000/ooooo``0dLfYFP00000<0=7=ZAKooooo;@00000Fooooo``0dLfY
9000000Boooooa8000004_ooool<0=7=ZAgooooo3`00000?ooooo`l000003oooool?0=7=Z@003P3A
cJT]000002cooooo303AcJUJ000000`0dLfY5_ooool]000001Kooooo303AcJTT000001;ooooo4P00
000Booooo``0dLfY7Oooool?000000oooooo3`00000?ooooo`l0dLfY000>0=7=ZBd00000;?ooool<
0=7=ZEX00000303AcJTFooooobd000005_ooool<0=7=ZB@000004_oooolB000001;ooooo303AcJTM
ooooo`l000003oooool?000000oooooo3`3AcJT000h0dLfY;@00000/ooooo``0dLfYFP00000<0=7=
ZAKooooo;@00000Fooooo``0dLfY9000000Boooooa8000004_ooool<0=7=ZAgooooo3`00000?oooo
o`l000003oooool?0=7=Z@003P3AcJT]000002cooooo303AcJUJ000000`0dLfY5_ooool]000001Ko
oooo303AcJTT000001;ooooo9000000<0=7=ZAgooooo3`00000?ooooo`l000003oooool?0=7=Z@00
3P3AcJT]000002cooooo303AcJUJ000000`0dLfY5_ooool]000001Kooooo303AcJTT000001;ooooo
9000000<0=7=ZAgooooo3`00000?ooooo`l000003oooool?0=7=Z@003P3AcJT]000002cooooo303A
cJUJ000000`0dLfY5_ooool]000001Kooooo303AcJTT000001;ooooo9000000<0=7=ZAgooooo3`00
000?ooooo`l000003oooool?0=7=Z@003P3AcJT]000002cooooo303AcJUJ000000`0dLfY5_ooool]
000001Kooooo303AcJTT000001;ooooo9000000<0=7=Z@kooooo3`00000]ooooo`l000003`3AcJT0
00h0dLfY;@00000/ooooo``0dLfYFP00000<0=7=ZAKooooo;@00000Fooooo``0dLfY9000000Boooo
ob@00000303AcJT>ooooo`l00000;Oooool?000000l0dLfY000>0=7=ZBd00000;?ooool<0=7=ZEX0
0000303AcJTFooooobd000005_ooool<0=7=ZB@000004_oooolT000000`0dLfY3_ooool?000002go
oooo3`00000?0=7=Z@003P3AcJT]000002cooooo303AcJUJ000000`0dLfY5_ooool]000001Kooooo
303AcJTT000001;ooooo9000000<0=7=Z@kooooo3`00000]ooooo`l000003`3AcJT000h0dLfY;@00
000/ooooo``0dLfYFP00000<0=7=ZAKooooo;@00000Fooooo``0dLfY9000000Booooob@00000303A
cJT>ooooo`l00000;Oooool?000000l0dLfY000>0=7=ZBd00000;?ooool<0=7=ZEX00000303AcJTF
ooooobd000005_ooool<0=7=ZB@000004_oooolT000000`0dLfY3_ooool?000002gooooo3`00000?
0=7=Z@003P3AcJT]000002cooooo303AcJUJ000000`0dLfY5_ooool]000001Kooooo303AcJTT0000
01;ooooo9000000<0=7=Z@kooooo3`00000]ooooo`l000003`3AcJT000h0dLfY;@00000/ooooo``0
dLfYFP00000<0=7=ZAKooooo;@00000Fooooo``0dLfY9000000Booooob@00000303AcJT>ooooo`l0
0000;Oooool?000000l0dLfY000>0=7=ZBd00000;?ooool<0=7=ZEX00000303AcJTFooooobd00000
5_ooool<0=7=ZB@000004_oooolT000000`0dLfY3_ooool?000002gooooo3`00000?0=7=Z@003P3A
cJT]000002cooooo303AcJUJ000000`0dLfY5_ooool]000001Kooooo303AcJTT000001;ooooo9000
000<0=7=Z@kooooo3`00000]ooooo`l000003`3AcJT000h0dLfY;@00000/ooooo``0dLfYFP00000<
0=7=ZAKooooo;@00000Fooooo``0dLfY9000000Booooob@00000303AcJT>ooooo`l00000;Oooool?
000000l0dLfY000>0=7=ZBd00000;?ooool<0=7=ZEX00000303AcJTFooooobd000005_ooool<0=7=
ZB@000004_oooolT000000`0dLfY3_ooool?000002gooooo3`00000?0=7=Z@003P3AcJT]000002co
oooo303AcJUJ000000`0dLfY5_ooool]000001Kooooo303AcJTT000001;ooooo9000000<0=7=Z@ko
oooo3`00000]ooooo`l000003`3AcJT000h0dLfY;@00000/ooooo``0dLfYFP00000<0=7=ZAKooooo
;@00000Fooooo``0dLfY9000000Booooob@00000303AcJT>ooooo`l00000;Oooool?000000l0dLfY
003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0
dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT0
0?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3A
cJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00
o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=
Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o
0=7=ZOl0dLfY3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY
3P3AcJT00?l0dLfYo`3AcJT>0=7=Z@00o`3AcJWo0=7=Z@h0dLfY003o0=7=ZOl0dLfY3P3AcJT00001
\
\>"],
  ImageRangeCache->{{{0, 523}, {1056.63, 0}} -> {-0.125026, -0.257081, \
0.0100384, 0.0100384}, {{12.4375, 104.688}, {1031, 938.75}} -> {-7.53049, \
-14.5181, 0.529869, 0.529869}, {{113.875, 206.125}, {1031, 938.75}} -> \
{-62.5828, -14.827, 0.541142, 0.541142}, {{215.375, 307.563}, {1031, 938.75}} -> \
{-120.038, -15.1629, 0.552793, 0.552793}, {{316.813, 409.063}, {1031, \
938.75}} -> {-179.584, -15.4448, 0.56369, 0.56369}, {{418.25, 510.5}, {1031, \
938.75}} -> {-241.499, -15.7537, 0.574965, 0.574965}, {{12.4375, 104.688}, \
{929.5, 837.313}} -> {-6.74818, -61.0747, 0.473821, 0.473821}, {{113.875, \
206.125}, {929.5, 837.313}} -> {-56.1164, -62.5289, 0.485102, 0.485102}, \
{{215.375, 307.563}, {929.5, 837.313}} -> {-107.789, -63.9833, 0.496386, \
0.496386}, {{316.813, 409.063}, {929.5, 837.313}} -> {-161.751, -65.4374, \
0.507667, 0.507667}, {{418.25, 510.5}, {929.5, 837.313}} -> {-217.986, \
-66.8915, 0.518948, 0.518948}, {{12.4375, 104.688}, {828.063, 735.813}} -> \
{-5.92827, -96.0809, 0.417132, 0.417132}, {{113.875, 206.125}, {828.063, \
735.813}} -> {-49.5449, -98.6778, 0.428406, 0.428406}, {{215.375, 307.563}, \
{828.063, 735.813}} -> {-95.5404, -101.356, 0.439978, 0.439978}, {{316.813, \
409.063}, {828.063, 735.813}} -> {-143.668, -103.871, 0.450952, 0.450952}, \
{{418.25, 510.5}, {828.063, 735.813}} -> {-194.146, -106.468, 0.462226, \
0.462226}, {{12.4375, 104.688}, {726.625, 634.375}} -> {-5.12715, -119.692, \
0.360762, 0.360762}, {{113.875, 206.125}, {726.625, 634.375}} -> {-43.0258, \
-123.432, 0.372037, 0.372037}, {{215.375, 307.563}, {726.625, 634.375}} -> \
{-83.2917, -127.27, 0.383571, 0.383571}, {{316.813, 409.063}, {726.625, \
634.375}} -> {-125.709, -130.913, 0.394584, 0.394584}, {{418.25, 510.5}, \
{726.625, 634.375}} -> {-170.47, -134.653, 0.405858, 0.405858}, {{12.4375, \
104.688}, {625.125, 532.875}} -> {-4.32604, -131.886, 0.304394, 0.304394}, \
{{113.875, 206.125}, {625.125, 532.875}} -> {-36.5067, -136.77, 0.315667, \
0.315667}, {{215.375, 307.563}, {625.125, 532.875}} -> {-71.0428, -141.761, \
0.327163, 0.327163}, {{316.813, 409.063}, {625.125, 532.875}} -> {-107.751, \
-146.54, 0.338215, 0.338215}, {{418.25, 510.5}, {625.125, 532.875}} -> \
{-146.794, -151.424, 0.349488, 0.349488}, {{12.4375, 104.688}, {523.688, \
431.438}} -> {-3.52491, -132.621, 0.248024, 0.248024}, {{113.875, 206.125}, \
{523.688, 431.438}} -> {-29.9877, -138.65, 0.259298, 0.259298}, {{215.375, \
307.563}, {523.688, 431.438}} -> {-58.794, -144.784, 0.270755, 0.270755}, \
{{316.813, 409.063}, {523.688, 431.438}} -> {-89.7924, -150.706, 0.281846, \
0.281846}, {{418.25, 510.5}, {523.688, 431.438}} -> {-123.118, -156.735, \
0.29312, 0.29312}, {{12.4375, 104.688}, {422.188, 330}} -> {-2.73141, \
-122.016, 0.191785, 0.191785}, {{113.875, 206.125}, {422.188, 330}} -> \
{-23.4906, -129.193, 0.203066, 0.203066}, {{215.375, 307.563}, {422.188, \
330}} -> {-46.5453, -136.37, 0.214348, 0.214348}, {{316.813, 409.063}, \
{422.188, 330}} -> {-71.8894, -143.548, 0.225629, 0.225629}, {{418.25, \
510.5}, {422.188, 330}} -> {-99.5156, -150.725, 0.236911, 0.236911}, \
{{12.4375, 104.688}, {320.75, 228.5}} -> {-1.92268, -99.7936, 0.135286, \
0.135286}, {{113.875, 206.125}, {320.75, 228.5}} -> {-16.9496, -108.11, \
0.14656, 0.14656}, {{215.375, 307.563}, {320.75, 228.5}} -> {-34.2965, \
-116.51, 0.157941, 0.157941}, {{316.813, 409.063}, {320.75, 228.5}} -> \
{-53.8754, -124.742, 0.169107, 0.169107}, {{418.25, 510.5}, {320.75, 228.5}} -> \
{-75.7645, -133.058, 0.180381, 0.180381}, {{12.4375, 104.688}, {219.313, \
127.063}} -> {-1.12156, -66.2179, 0.0789166, 0.0789166}, {{113.875, 206.125}, \
{219.313, 127.063}} -> {-10.4305, -75.678, 0.0901908, 0.0901908}, {{215.375, \
307.563}, {219.313, 127.063}} -> {-22.0477, -85.1979, 0.101533, 0.101533}, \
{{316.813, 409.063}, {219.313, 127.063}} -> {-35.917, -94.5972, 0.112738, \
0.112738}, {{418.25, 510.5}, {219.313, 127.063}} -> {-52.0881, -104.057, \
0.124012, 0.124012}, {{12.4375, 104.688}, {117.813, 25.5625}} -> {-0.320447, \
-21.208, 0.0225477, 0.0225477}, {{113.875, 206.125}, {117.813, 25.5625}} -> \
{-3.91143, -31.812, 0.0338215, 0.0338215}, {{215.375, 307.563}, {117.813, \
25.5625}} -> {-9.79899, -42.4461, 0.0451258, 0.0451258}, {{316.813, 409.063}, \
{117.813, 25.5625}} -> {-17.9584, -53.02, 0.056369, 0.056369}, {{418.25, \
510.5}, {117.813, 25.5625}} -> {-28.4118, -63.6242, 0.0676431, 0.0676431}}],

Cell["\<\
We include the data above in file allOnes6. Note that the cases n=26 and n=44 \
have no solution.

Problem: what if we have more than one state , that is, if the first time we \
press a button it changes color cyclically to one of n available ones?.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["POWERS OF INTEGERS", "Section"],

Cell[TextData[{
  "The behavior displayed by a CA also occurs in the representation of the \
powers of an integer in several bases. This is illustrated below by function \
",
  StyleBox["pow[n, m, gen]", "InlineInput"],
  " which displays a density  plot of the first gen powers of n written in \
base m (More fascinating information on the behaviour can be consulted at \
[5])"
}], "Text"],

Cell[BoxData[
    \(pow[n_, m_, gen_] := 
      Module[{i, t, 
          l = Length[IntegerDigits[n\^gen, m]]}, \[IndentingNewLine]t = 
          Table[IntegerDigits[n\^i, m, l], {i, 
              gen}]; \[IndentingNewLine]ListDensityPlot[Reverse[\(-t\)]\ , 
          FrameTicks \[Rule] None, Frame \[Rule] False, Mesh \[Rule] False, 
          AspectRatio \[Rule] Automatic]]\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(pow[3, 2, 50];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0120192 0.0120192 0.0120192 [
[ 0 0 0 0 ]
[ 1 .625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .625 L
0 .625 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01202 translate
.96154 .60096 scale
80 string
80 50 8 [80 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FFFF0000FFFFFFFFFFFFFFFF00FF00FF00FF00FFFF000000000000FFFFFFFF0000FF00
00FF0000FFFF00FF000000000000FF00FFFFFFFF00FFFF000000FF00000000FFFFFF0000
0000FFFF00FFFF00
FFFF0000FFFF00FF00FF00FF0000FFFFFF000000FFFFFF00FF00FF00FFFFFFFFFF00FFFF
00FFFF00FFFFFFFF0000000000000000FFFFFFFFFFFF0000FF00FFFF00FF00FFFFFFFF00
FF00FFFFFFFF0000
FFFFFF00FFFFFFFF000000FFFF00FFFFFFFF00FFFF00FF000000FFFFFF00FF00FF0000FF
0000FF0000FF00FF000000000000000000FF00FF00FF00000000FFFFFFFF0000FF00FF00
0000FFFFFFFFFF00
FFFFFFFFFF00FF0000FF00FFFFFFFF00FF0000FFFFFFFF00000000FF0000FFFFFF000000
00FFFF00000000FFFF00FF00FF00FF00FFFF000000FFFF00FF00FFFFFFFFFF00FFFFFF00
000000FF00FF0000
FFFFFFFFFFFFFF00000000FFFFFFFFFFFF000000FF00FF000000000000FFFF00FF000000
0000FF0000000000FF000000FFFFFF0000FF00000000FF000000FFFFFFFFFFFFFF00FF00
0000000000FFFF00
FFFFFFFFFFFFFFFF00FF00FFFFFFFFFFFFFF00FFFF000000FF00FF00FFFF0000FFFF00FF
00FFFF00000000000000FF00FFFFFFFF00FFFF00FF00FFFF00FFFF00FF00FF00FF000000
FF00FF00FFFF0000
FFFFFFFFFFFFFFFFFFFF0000FF00FF00FF0000FFFFFF00FFFF000000FFFFFF00FFFFFFFF
0000FF000000000000000000FFFFFFFFFFFF0000FFFFFF0000FFFFFFFF000000FFFF00FF
FF000000FFFFFF00
FFFFFFFFFFFFFFFFFFFFFF00FFFFFF000000FFFF00FF0000FF00000000FF0000FFFFFFFF
FF00FFFF00FF00FF00FF00FFFF00FF00FF0000FFFF00FF000000FF00FF00000000FF0000
FF00000000FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFF00FF00000000FF000000FFFF000000000000FFFF00FF00
FF0000FF000000FFFFFF0000FF000000FFFF00FFFFFFFF0000000000FFFF00FF00FFFF00
FFFF00FF00FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF00FFFFFF00FF00FF00FFFFFFFF00
0000FFFF00000000FF0000FFFF00000000FF0000FF00FF000000000000FF000000FFFFFF
FF0000FFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFFFF00FF000000FFFFFF00FF0000
FF00FFFFFF00FF00FFFF00FFFFFF00FF00FFFF00FFFFFF0000000000000000FF00FFFFFF
FFFF00FFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF00000000FF0000FFFF00
FFFFFF00FF000000FFFFFFFF00FF000000FFFFFFFF00FF00000000000000000000FFFFFF
FFFFFFFF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FF00FF000000000000FFFF0000
FFFFFFFFFF00000000FF00FF000000FF00FFFFFFFFFFFF0000000000000000000000FF00
FF00FF0000FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF00000000000000FF0000
00FF00FF0000FF00FFFF000000FF00FFFFFF00FF00FF0000FF00FF00FF00FF00FF00FFFF
FF000000FFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF00FF00FF00FFFF0000
000000FFFF00FFFFFF0000FF00FFFFFF00FF000000FFFF00FFFFFF000000FFFFFF0000FF
0000FF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000FFFFFF0000FF0000
00000000FF0000FF0000FFFF0000FF0000FFFF00FFFF0000FFFFFFFF00FFFF00FF000000
00FFFF0000FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF0000FFFF0000
000000000000FFFF000000FF00000000FFFF0000FFFFFF00FFFFFFFFFFFF0000FFFF00FF
00FFFFFF00FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF000000FF0000
00000000000000FF0000000000FF00FFFF0000FFFF00FF0000FF00FF00FF000000FF0000
00FFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00FFFF00
FF00FF00FF00FFFF00000000000000FFFFFF00FFFFFFFF00000000FFFFFF0000000000FF
00FFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF0000
FFFFFF000000FFFFFF00FF00FF00FFFF00FF0000FF00FF0000000000FF0000FF00FF00FF
FFFF00FF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF0000
00FF0000FF00FFFFFFFFFF000000FFFFFFFF00000000FFFF00FF00FFFF00000000FFFFFF
00FF000000FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFF0000FF00FF0000FF00FFFFFFFFFF00FF00FFFFFFFF0000FF0000000000FF00
00FFFF00FFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FF00FFFF0000FFFF000000FFFF0000FF00FF0000FFFFFF00FF0000FFFF00000000000000
FFFF0000FFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF000000FF00000000FF00000000FFFF00FFFFFFFFFF000000FF00000000000000
00FF000000FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFF00FFFF000000000000FF00FFFF0000FFFFFFFFFFFF00FFFF00000000000000
000000FF00FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFF00FF00FF00FFFFFF0000FFFF00FF00FF0000FFFFFF00FF00FF00FF
00FF00FFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFF000000FFFFFFFF00FFFFFFFF000000FFFF00FF000000FFFFFF
000000FFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FF00FF00000000FF00FF0000FF00FF00000000FF000000FF00FFFFFF
FF00FFFF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF00FFFF000000FFFF000000FF00FFFF0000000000FFFFFF
FFFFFF0000FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFF0000FF00000000FF0000000000FFFFFF00FF00FFFF00FF
00FF0000FFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF000000000000FF00FF00FFFFFFFFFF0000FF0000
00FFFF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FF00FF00FFFFFF0000FF00FF0000FFFF0000
0000FF0000FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF000000FFFFFF00FF00000000FFFF00FFFFFF00
FF00FFFF00FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF0000FFFF00FF00FFFFFFFF00FF00
0000FFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FFFF00FFFFFFFF0000FF00FF000000
FF00FFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF00FF00000000FFFF00FF
FF0000FF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF00FFFFFF0000000000FF0000
FF00000000FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF00FF00FFFF0000
0000FF00FFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF0000FF0000
00000000FFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF00FF0000FFFF0000
0000000000FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF0000FF
00FF00FF00FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF0000FFFF
000000FFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00
00FF00FFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
00FFFFFF00FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF
0000FF0000FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FF00FFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{184.313, 115.188},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002h0000Lb000`400?l00000o`00003o^03AcJT0
0;P0dLfY002h0=7=Z@000`3AcJT2000000D0oooo1000000B0?ooo`8000000P3oool200000080oooo
0`0000020?ooo`800000103oool>000000P0oooo1@0000020?ooo`@000000`3oool4000000@0oooo
0`0000020?ooo`d000000P3oool2000000T0oooo0P0000050?ooo`H000000`3oool8000000L0oooo
2@0000040?ooo`8000001@3oool2000000D0dLfY00030=7=Z@8000001@3oool400000180oooo0P00
00020?ooo`8000000P3oool300000080oooo0P0000040?ooo`h00000203oool500000080oooo1000
00030?ooo`@00000103oool300000080oooo3@0000020?ooo`8000002@3oool2000000D0oooo1P00
00030?ooo`P000001`3oool9000000@0oooo0P0000050?ooo`8000001@3AcJT000<0dLfY103oool5
000000@0oooo0P0000030?ooo`8000000P3oool200000080oooo1@0000060?ooo`L000001`3oool2
00000080oooo0P0000020?ooo`<000002`3oool2000000@0oooo0P0000050?ooo`8000002@3ooolA
000000h0oooo100000020?ooo`8000001@3oool200000080oooo0P0000090?ooo`8000000`3oool2
000000T0oooo100000050=7=Z@000`3AcJT40?ooo`D00000103oool2000000<0oooo0P0000020?oo
o`8000000P3oool5000000H0oooo1`0000070?ooo`8000000P3oool200000080oooo0`00000;0?oo
o`800000103oool2000000D0oooo0P0000090?oooa4000003P3oool400000080oooo0P0000050?oo
o`8000000P3oool2000000T0oooo0P0000030?ooo`8000002@3oool4000000D0dLfY00030=7=Z@L0
oooo0P0000090?ooo`H000001@3oool2000000T0oooo0P0000040?ooo`8000000`3oool6000000L0
oooo0P0000020?ooo`8000000`3oool400000080oooo1@0000020?ooo`@000000P3oool300000080
oooo500000020?ooo`8000000P3oool2000000<0oooo200000090?ooo`D000000P3oool200000080
oooo1`00000;0?ooo`8000001@3AcJT000<0dLfY1`3oool2000000T0oooo1P0000050?ooo`800000
2@3oool2000000@0oooo0P0000030?ooo`H000001`3oool200000080oooo0P0000030?ooo`@00000
0P3oool500000080oooo100000020?ooo`<000000P3ooolD00000080oooo0P0000020?ooo`800000
0`3oool8000000T0oooo1@0000020?ooo`8000000P3oool7000000/0oooo0P0000050=7=Z@000`3A
cJT70?ooo`8000002@3oool6000000D0oooo0P0000090?ooo`800000103oool2000000<0oooo1P00
00070?ooo`8000000P3oool2000000<0oooo100000020?ooo`D000000P3oool400000080oooo0`00
00020?oooa@000000P3oool200000080oooo0P0000030?ooo`P000002@3oool500000080oooo0P00
00020?ooo`L000002`3oool2000000D0dLfY00030=7=Z@/0oooo0P0000020?ooo`D000000P3oool2
000000T0oooo0P0000020?ooo`D000002@3oool8000000<0oooo100000070?ooo`P000001@3oool9
000000@0oooo0P0000020?ooo`<000000P3oool200000080oooo0P0000050?ooo`H000001@3oool2
00000080oooo0P00000;0?ooo`<000001P3oool900000080oooo0P0000030?ooo`@000001@3AcJT0
00<0dLfY2`3oool200000080oooo1@0000020?ooo`8000002@3oool200000080oooo1@0000090?oo
o`P000000`3oool4000000L0oooo200000050?ooo`T00000103oool200000080oooo0`0000020?oo
o`8000000P3oool2000000D0oooo1P0000050?ooo`8000000P3oool2000000/0oooo0`0000060?oo
o`T000000P3oool2000000<0oooo100000050=7=Z@000`3AcJT?0?ooo`T000003@3oool700000080
oooo0P0000030?ooo`d00000103oool2000000<0oooo2`0000020?ooo`/000000P3oool7000000H0
oooo1@0000020?ooo`T000000P3oool600000100oooo0P0000020?ooo`d000001@3oool2000000D0
dLfY00030=7=Z@l0oooo2@00000=0?ooo`L000000P3oool2000000<0oooo3@0000040?ooo`800000
0`3oool;00000080oooo2`0000020?ooo`L000001P3oool500000080oooo2@0000020?ooo`H00000
403oool200000080oooo3@0000050?ooo`8000001@3AcJT000<0dLfY4P3oool200000080oooo0P00
000@0?ooo`800000103oool700000080oooo0P0000020?ooo`<00000103oool4000000D0oooo0P00
00020?ooo`8000001@3oool?00000080oooo0`0000080?ooo`<00000103oool200000080oooo0`00
00040?ooo`8000001@3oool200000080oooo0P0000020?ooo`<000000P3oool6000000<0oooo0P00
00020?ooo`8000001@3oool4000000D0dLfY00030=7=ZA80oooo0P0000020?ooo`800000403oool2
000000@0oooo1`0000020?ooo`8000000P3oool3000000@0oooo100000050?ooo`8000000P3oool2
000000D0oooo3`0000020?ooo`<00000203oool3000000@0oooo0P0000020?ooo`<00000103oool2
000000D0oooo0P0000020?ooo`8000000P3oool300000080oooo1P0000030?ooo`8000000P3oool2
000000D0oooo100000050=7=Z@000`3AcJTF0?ooo`@000000`3oool200000080oooo0P0000020?oo
o`D000001P3oool3000000@0oooo1`0000060?ooo`8000002@3oool500000080oooo5000000=0?oo
o`@000001`3oool4000000T0oooo1`0000040?ooo`8000001@3oool6000000L0oooo0P0000050=7=
Z@000`3AcJTF0?ooo`@000000`3oool200000080oooo0P0000020?ooo`D000001P3oool3000000@0
oooo1`0000060?ooo`8000002@3oool500000080oooo5000000=0?ooo`@000001`3oool4000000T0
oooo1`0000040?ooo`8000001@3oool6000000L0oooo0P0000050=7=Z@000`3AcJTH0?ooo`800000
1`3oool7000000@0oooo0P0000020?ooo`D000000P3oool900000080oooo1000000;0?ooo`<00000
103oool200000080oooo0`0000020?ooo`8000000P3oool2000000D0oooo0P0000020?ooo`800000
0`3oool4000000@0oooo0`0000020?ooo`H000000`3oool200000080oooo2@0000020?ooo`@00000
0`3oool8000000<0oooo100000050=7=Z@000`3AcJTH0?ooo`8000001`3oool7000000@0oooo0P00
00020?ooo`D000000P3oool900000080oooo1000000;0?ooo`<00000103oool200000080oooo0`00
00020?ooo`8000000P3oool2000000D0oooo0P0000020?ooo`8000000`3oool4000000@0oooo0`00
00020?ooo`H000000`3oool200000080oooo2@0000020?ooo`@000000`3oool8000000<0oooo1000
00050=7=Z@000`3AcJTH0?ooo`8000001`3oool7000000@0oooo0P0000020?ooo`D000000P3oool9
00000080oooo1000000;0?ooo`<00000103oool200000080oooo0`0000020?ooo`8000000P3oool2
000000D0oooo0P0000020?ooo`8000000`3oool4000000@0oooo0`0000020?ooo`H000000`3oool2
00000080oooo2@0000020?ooo`@000000`3oool8000000<0oooo100000050=7=Z@000`3AcJTM0?oo
o`8000000P3oool900000080oooo1`0000040?ooo`d000001@3oool200000080oooo0P0000020?oo
o`D000000P3oool7000000H0oooo1@0000020?ooo`H000001@3oool2000000T0oooo2`0000040?oo
o`8000000`3oool2000000@0oooo0P0000050?ooo`8000000P3oool2000000D0oooo0P0000050=7=
Z@000`3AcJTM0?ooo`8000000P3oool900000080oooo1`0000040?ooo`d000001@3oool200000080
oooo0P0000020?ooo`D000000P3oool7000000H0oooo1@0000020?ooo`H000001@3oool2000000T0
oooo2`0000040?ooo`8000000`3oool2000000@0oooo0P0000050?ooo`8000000P3oool2000000D0
oooo0P0000050=7=Z@000`3AcJTQ0?ooo`d000000P3oool3000000H0oooo0P0000030?ooo`800000
0P3oool2000000T0oooo1`0000040?ooo`T000000P3oool4000000D0oooo2@0000020?ooo`@00000
0P3oool300000080oooo3@0000020?ooo`L000002@3oool4000000L0oooo100000050=7=Z@000`3A
cJTQ0?ooo`d000000P3oool3000000H0oooo0P0000030?ooo`8000000P3oool2000000T0oooo1`00
00040?ooo`T000000P3oool4000000D0oooo2@0000020?ooo`@000000P3oool300000080oooo3@00
00020?ooo`L000002@3oool4000000L0oooo100000050=7=Z@000`3AcJTS0?ooo`8000000`3oool2
00000080oooo0P0000070?ooo`8000000P3oool7000000H0oooo0`0000020?ooo`@000000P3oool3
000000H0oooo0P0000030?ooo`800000103oool2000000L0oooo0P0000020?ooo`<00000103oool2
000000L0oooo4@0000030?ooo`8000002`3oool2000000T0oooo0P0000050=7=Z@000`3AcJTS0?oo
o`8000000`3oool200000080oooo0P0000070?ooo`8000000P3oool7000000H0oooo0`0000020?oo
o`@000000P3oool3000000H0oooo0P0000030?ooo`800000103oool2000000L0oooo0P0000020?oo
o`<00000103oool2000000L0oooo4@0000030?ooo`8000002`3oool2000000T0oooo0P0000050=7=
Z@000`3AcJTX0?ooo`H000002`3oool900000080oooo1@0000040?ooo`8000001`3oool200000080
oooo1`0000090?ooo`8000000P3oool7000000P0oooo0`0000020?oooaH000003`3oool2000000<0
oooo100000050=7=Z@000`3AcJTX0?ooo`H000002`3oool900000080oooo1@0000040?ooo`800000
1`3oool200000080oooo1`0000090?ooo`8000000P3oool7000000P0oooo0`0000020?oooaH00000
3`3oool2000000<0oooo100000050=7=Z@000`3AcJTZ0?ooo`800000103oool300000080oooo0P00
00020?ooo`d000001@3oool4000000/0oooo2@0000020?ooo`8000000`3oool600000080oooo0`00
000=0?oooaP000000P3oool2000000<0oooo0P0000020?ooo`@000001@3oool2000000D0dLfY0003
0=7=ZBX0oooo0P0000040?ooo`<000000P3oool200000080oooo3@0000050?ooo`@000002`3oool9
00000080oooo0P0000030?ooo`H000000P3oool3000000d0oooo600000020?ooo`8000000`3oool2
00000080oooo100000050?ooo`8000001@3AcJT000<0dLfY:P3oool2000000@0oooo0`0000020?oo
o`8000000P3oool=000000D0oooo1000000;0?ooo`T000000P3oool2000000<0oooo1P0000020?oo
o`<000003@3ooolH00000080oooo0P0000030?ooo`8000000P3oool4000000D0oooo0P0000050=7=
Z@000`3AcJT^0?ooo`D000001P3oool@00000080oooo1P0000030?ooo`8000000P3oool4000000<0
oooo0P0000040?ooo`L000000P3oool2000000L0oooo0P0000020?ooo`8000000`3oool400000080
oooo0P0000030?ooo`8000000P3oool200000080oooo0`0000020?ooo`8000001`3oool6000000D0
oooo100000050=7=Z@000`3AcJT^0?ooo`D000001P3oool@00000080oooo1P0000030?ooo`800000
0P3oool4000000<0oooo0P0000040?ooo`L000000P3oool2000000L0oooo0P0000020?ooo`800000
0`3oool400000080oooo0P0000030?ooo`8000000P3oool200000080oooo0`0000020?ooo`800000
1`3oool6000000D0oooo100000050=7=Z@000`3AcJT`0?ooo`<00000203oool300000080oooo0P00
00020?ooo`8000001@3oool;000000@0oooo0P0000070?ooo`@000000`3oool2000000H0oooo0`00
00020?ooo`H000001@3oool2000000L0oooo1P0000070?ooo`@000000P3oool500000080oooo0P00
00070?ooo`8000001@3AcJT000<0dLfY<03oool3000000P0oooo0`0000020?ooo`8000000P3oool2
000000D0oooo2`0000040?ooo`8000001`3oool4000000<0oooo0P0000060?ooo`<000000P3oool6
000000D0oooo0P0000070?ooo`H000001`3oool400000080oooo1@0000020?ooo`8000001`3oool2
000000D0dLfY00030=7=ZCD0oooo0P0000020?ooo`D000001P3oool500000080oooo3@0000020?oo
o`D000000P3oool4000000D0oooo100000020?ooo`D00000103oool2000000D0oooo100000090?oo
o`800000103oool300000080oooo2@0000040?ooo`@000000`3oool4000000D0dLfY00030=7=ZCD0
oooo0P0000020?ooo`D000001P3oool500000080oooo3@0000020?ooo`D000000P3oool4000000D0
oooo100000020?ooo`D00000103oool2000000D0oooo100000090?ooo`800000103oool300000080
oooo2@0000040?ooo`@000000`3oool4000000D0dLfY00030=7=ZCT0oooo1`0000020?ooo`@00000
1@3ooolA000000D0oooo1P0000030?ooo`P000001@3oool4000000L0oooo0P00000=0?ooo`D00000
103oool200000080oooo0`0000060?ooo`8000001@3oool2000000D0dLfY00030=7=ZCT0oooo1`00
00020?ooo`@000001@3ooolA000000D0oooo1P0000030?ooo`P000001@3oool4000000L0oooo0P00
000=0?ooo`D00000103oool200000080oooo0`0000060?ooo`8000001@3oool2000000D0dLfY0003
0=7=ZC/0oooo0`0000040?ooo`L000000P3ooolD00000080oooo2`0000020?ooo`8000001@3oool4
000000@0oooo0`0000020?ooo`@000000P3oool300000080oooo0P0000020?ooo`L000000P3oool7
000000/0oooo100000050=7=Z@000`3AcJTk0?ooo`<00000103oool700000080oooo500000020?oo
o`/000000P3oool2000000D0oooo100000040?ooo`<000000P3oool400000080oooo0`0000020?oo
o`8000000P3oool700000080oooo1`00000;0?ooo`@000001@3AcJT000<0dLfY>`3oool3000000@0
oooo1`0000020?oooa@000000P3oool;00000080oooo0P0000050?ooo`@00000103oool300000080
oooo100000020?ooo`<000000P3oool200000080oooo1`0000020?ooo`L000002`3oool4000000D0
dLfY00030=7=ZD00oooo100000020?ooo`<00000103oool200000080oooo0`0000020?ooo`800000
0P3oool2000000D0oooo3`0000070?ooo`8000002@3oool9000000H0oooo2`0000020?ooo`<00000
3@3oool2000000D0dLfY00030=7=ZD00oooo100000020?ooo`<00000103oool200000080oooo0`00
00020?ooo`8000000P3oool2000000D0oooo3`0000070?ooo`8000002@3oool9000000H0oooo2`00
00020?ooo`<000003@3oool2000000D0dLfY00030=7=ZD80oooo0P0000070?ooo`@000001`3oool6
000000L0oooo0P0000020?ooo`<000000P3oool2000000@0oooo0`0000020?ooo`@000000P3oool3
00000080oooo2`0000020?ooo`@000000`3oool200000080oooo0P0000070?ooo`8000000P3oool2
000000<0oooo100000050=7=Z@000`3AcJU20?ooo`8000001`3oool4000000L0oooo1P0000070?oo
o`8000000P3oool300000080oooo0P0000040?ooo`<000000P3oool400000080oooo0`0000020?oo
o`/000000P3oool4000000<0oooo0P0000020?ooo`8000001`3oool200000080oooo0P0000030?oo
o`@000001@3AcJT000<0dLfYAP3oool300000080oooo1P0000030?ooo`@000000P3oool2000000/0
oooo1`0000090?ooo`T00000103oool200000080oooo0`0000040?ooo`T000001P3oool300000080
oooo1P0000050?ooo`8000001@3AcJT000<0dLfYAP3oool300000080oooo1P0000030?ooo`@00000
0P3oool2000000/0oooo1`0000090?ooo`T00000103oool200000080oooo0`0000040?ooo`T00000
1P3oool300000080oooo1P0000050?ooo`8000001@3AcJT000<0dLfYB`3oool;000000@0oooo1@00
00020?ooo`8000000P3oool500000080oooo0P00000;0?ooo`8000000P3oool3000000P0oooo1@00
00020?ooo`/000000P3oool5000000@0oooo0P0000050?ooo`@000001@3AcJT000<0dLfYB`3oool;
000000@0oooo1@0000020?ooo`8000000P3oool500000080oooo0P00000;0?ooo`8000000P3oool3
000000P0oooo1@0000020?ooo`/000000P3oool5000000@0oooo0P0000050?ooo`@000001@3AcJT0
00<0dLfYC@3oool200000080oooo0`0000040?ooo`@000001@3oool6000000D0oooo100000020?oo
o`<000000P3oool4000000L0oooo0P0000020?ooo`D00000103oool?000000D0oooo100000070?oo
o`8000001@3AcJT000<0dLfYC@3oool200000080oooo0`0000040?ooo`@000001@3oool6000000D0
oooo100000020?ooo`<000000P3oool4000000L0oooo0P0000020?ooo`D00000103oool?000000D0
oooo100000070?ooo`8000001@3AcJT000<0dLfYC@3oool200000080oooo0`0000040?ooo`@00000
1@3oool6000000D0oooo100000020?ooo`<000000P3oool4000000L0oooo0P0000020?ooo`D00000
103oool?000000D0oooo100000070?ooo`8000001@3AcJT000<0dLfYD@3oool500000080oooo1`00
00020?ooo`T000000P3oool9000000@0oooo0P00000;0?ooo`L000000P3ooolB00000080oooo1P00
00030?ooo`@000001@3AcJT000<0dLfYD@3oool500000080oooo1`0000020?ooo`T000000P3oool9
000000@0oooo0P00000;0?ooo`L000000P3ooolB00000080oooo1P0000030?ooo`@000001@3AcJT0
00<0dLfYE03oool2000000@0oooo0P0000050?ooo`d000000P3oool2000000D0oooo1000000=0?oo
o`<00000103ooolF00000080oooo0P0000050?ooo`8000001@3AcJT000<0dLfYE03oool2000000@0
oooo0P0000050?ooo`d000000P3oool2000000D0oooo1000000=0?ooo`<00000103ooolF00000080
oooo0P0000050?ooo`8000001@3AcJT000<0dLfYF03oool4000000L0oooo0P0000020?ooo`<00000
0P3oool2000000L0oooo100000040?ooo`<000000P3oool200000080oooo1@0000060?ooo`800000
0`3oool200000080oooo0P0000020?ooo`<000000P3oool2000000L0oooo100000050=7=Z@000`3A
cJUH0?ooo`@000001`3oool200000080oooo0`0000020?ooo`8000001`3oool4000000@0oooo0`00
00020?ooo`8000000P3oool5000000H0oooo0P0000030?ooo`8000000P3oool200000080oooo0`00
00020?ooo`8000001`3oool4000000D0dLfY00030=7=ZEX0oooo0P00000;0?ooo`L000002@3oool2
000000T0oooo1P0000050?ooo`8000000P3oool7000000H0oooo1`0000090?ooo`8000001@3AcJT0
00<0dLfYFP3oool2000000/0oooo1`0000090?ooo`8000002@3oool6000000D0oooo0P0000020?oo
o`L000001P3oool7000000T0oooo0P0000050=7=Z@000`3AcJUO0?ooo`8000000P3oool200000080
oooo2@0000020?ooo`<000000P3oool400000080oooo0`0000020?ooo`T000000P3oool6000000<0
oooo0P0000090?ooo`800000103oool2000000<0oooo100000050=7=Z@000`3AcJUO0?ooo`800000
0P3oool200000080oooo2@0000020?ooo`<000000P3oool400000080oooo0`0000020?ooo`T00000
0P3oool6000000<0oooo0P0000090?ooo`800000103oool2000000<0oooo100000050=7=Z@000`3A
cJUO0?ooo`8000000P3oool200000080oooo2@0000020?ooo`<000000P3oool400000080oooo0`00
00020?ooo`T000000P3oool6000000<0oooo0P0000090?ooo`800000103oool2000000<0oooo1000
00050=7=Z@000`3AcJUS0?ooo`L000000P3oool2000000@0oooo1`0000040?ooo`L000000P3oool2
000000D0oooo2`00000=0?ooo`@000001@3oool2000000D0dLfY00030=7=ZF<0oooo1`0000020?oo
o`800000103oool7000000@0oooo1`0000020?ooo`8000001@3oool;000000d0oooo100000050?oo
o`8000001@3AcJT000<0dLfYI@3oool2000000D0oooo100000020?ooo`T000000P3oool;000000L0
oooo0P0000020?ooo`<00000103oool200000080oooo0`0000020?ooo`@000001@3oool4000000D0
dLfY00030=7=ZFD0oooo0P0000050?ooo`@000000P3oool900000080oooo2`0000070?ooo`800000
0P3oool3000000@0oooo0P0000020?ooo`<000000P3oool4000000D0oooo100000050=7=Z@000`3A
cJUZ0?ooo`@00000103oool>00000080oooo0P0000020?ooo`8000002`3oool500000080oooo1`00
00040?ooo`8000001`3oool2000000D0dLfY00030=7=ZFX0oooo100000040?ooo`h000000P3oool2
00000080oooo0P00000;0?ooo`D000000P3oool7000000@0oooo0P0000070?ooo`8000001@3AcJT0
00<0dLfYK03oool2000000L0oooo0P0000020?ooo`8000000P3oool3000000H0oooo1@0000020?oo
o`8000000P3oool5000000@0oooo2@0000020?ooo`@000000`3oool4000000D0dLfY00030=7=ZF`0
oooo0P0000070?ooo`8000000P3oool200000080oooo0`0000060?ooo`D000000P3oool200000080
oooo1@0000040?ooo`T000000P3oool4000000<0oooo100000050=7=Z@000`3AcJU`0?ooo`800000
0`3oool6000000L0oooo0P0000020?ooo`T00000103oool3000000H0oooo0P0000030?ooo`800000
103oool2000000D0oooo0P0000050=7=Z@000`3AcJU`0?ooo`8000000`3oool6000000L0oooo0P00
00020?ooo`T00000103oool3000000H0oooo0P0000030?ooo`800000103oool2000000D0oooo0P00
00050=7=Z@000`3AcJU`0?ooo`8000000`3oool6000000L0oooo0P0000020?ooo`T00000103oool3
000000H0oooo0P0000030?ooo`800000103oool2000000D0oooo0P0000050=7=Z@000`3AcJUe0?oo
o`P000000`3oool4000000@0oooo0`0000020?ooo`8000002@3oool200000080oooo1`0000090?oo
o`@000001@3AcJT000<0dLfYM@3oool8000000<0oooo100000040?ooo`<000000P3oool2000000T0
oooo0P0000020?ooo`L000002@3oool4000000D0dLfY00030=7=ZGL0oooo0P0000020?ooo`800000
1@3oool2000000T0oooo100000020?ooo`<000000P3oool6000000<0oooo0P00000;0?ooo`800000
1@3AcJT000<0dLfYM`3oool200000080oooo0P0000050?ooo`8000002@3oool400000080oooo0`00
00020?ooo`H000000`3oool2000000/0oooo0P0000050=7=Z@000`3AcJUk0?ooo`D000000P3oool4
00000080oooo0`0000020?ooo`T00000103oool2000000D0oooo100000020?ooo`8000000`3oool4
000000D0dLfY00030=7=ZG/0oooo1@0000020?ooo`@000000P3oool300000080oooo2@0000040?oo
o`8000001@3oool400000080oooo0P0000030?ooo`@000001@3AcJT000<0dLfYO@3oool3000000@0
oooo0P0000070?ooo`/000000P3oool4000000<0oooo200000050?ooo`8000001@3AcJT000<0dLfY
O@3oool3000000@0oooo0P0000070?ooo`/000000P3oool4000000<0oooo200000050?ooo`800000
1@3AcJT000<0dLfYPP3oool4000000T0oooo0P0000020?ooo`<00000103oool900000080oooo0P00
00050?ooo`@000001@3AcJT000<0dLfYPP3oool4000000T0oooo0P0000020?ooo`<00000103oool9
00000080oooo0P0000050?ooo`@000001@3AcJT000<0dLfYPP3oool4000000T0oooo0P0000020?oo
o`<00000103oool900000080oooo0P0000050?ooo`@000001@3AcJT000<0dLfYQ03oool2000000d0
oooo1@0000020?ooo`d000001`3oool2000000D0dLfY00030=7=ZH@0oooo0P00000=0?ooo`D00000
0P3oool=000000L0oooo0P0000050=7=Z@000`3AcJV80?ooo`<000000P3oool200000080oooo1@00
00040?ooo`l000000`3oool4000000D0dLfY00030=7=ZHP0oooo0`0000020?ooo`8000000P3oool5
000000@0oooo3`0000030?ooo`@000001@3AcJT000<0dLfYS@3oool6000000D0oooo100000020?oo
o`<000000P3oool200000080oooo0P0000050?ooo`8000001@3AcJT000<0dLfYS@3oool6000000D0
oooo100000020?ooo`<000000P3oool200000080oooo0P0000050?ooo`8000001@3AcJT000<0dLfY
S`3oool2000000D0oooo100000040?ooo`L000001`3oool4000000D0dLfY00030=7=ZHl0oooo0P00
00050?ooo`@00000103oool7000000L0oooo100000050=7=Z@000`3AcJVC0?ooo`D00000103oool5
00000080oooo0P0000090?ooo`8000001@3AcJT000<0dLfYT`3oool5000000@0oooo1@0000020?oo
o`8000002@3oool2000000D0dLfY00030=7=ZI<0oooo1@0000040?ooo`D000000P3oool2000000T0
oooo0P0000050=7=Z@000`3AcJVF0?ooo`8000001P3oool3000000H0oooo0P0000030?ooo`@00000
1@3AcJT000<0dLfYUP3oool2000000H0oooo0`0000060?ooo`8000000`3oool4000000D0dLfY0003
0=7=ZIX0oooo0P0000020?ooo`D000000P3oool4000000D0oooo0P0000050=7=Z@000`3AcJVJ0?oo
o`8000000P3oool500000080oooo100000050?ooo`8000001@3AcJT000<0dLfYWP3oool9000000D0
oooo100000050=7=Z@000`3AcJVN0?ooo`T000001@3oool4000000D0dLfY00030=7=ZJ40oooo0P00
00020?ooo`8000001`3oool2000000D0dLfY00030=7=ZJ40oooo0P0000020?ooo`8000001`3oool2
000000D0dLfY00030=7=ZJD0oooo100000030?ooo`@000001@3AcJT000<0dLfYY@3oool4000000<0
oooo100000050=7=Z@000`3AcJVU0?ooo`@000000`3oool4000000D0dLfY00030=7=ZJL0oooo0P00
00050?ooo`8000001@3AcJT000<0dLfYY`3oool2000000D0oooo0P0000050=7=Z@000`3AcJV/0?oo
o`@000001@3AcJT000<0dLfY[03oool4000000D0dLfY002h0=7=Z@00^03AcJT00001\
\>"],
  ImageRangeCache->{{{0, 183.313}, {114.188, 0}} -> {-1.73989, -1.00026, \
0.455397, 0.455397}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(pow[2, 3, 50];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0300481 0.0300481 0.0300481 [
[ 0 0 0 0 ]
[ 1 1.5625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.5625 L
0 1.5625 L
closepath
clip
newpath
% Start of gray image
p
.01923 .03005 translate
.96154 1.5024 scale
32 string
32 50 8 [32 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage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P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{184.313, 287.938},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002h00017b000`400?l00000o`00003o^03AcJT0
0;P0dLfY002h0=7=Z@00^03AcJT00;P0dLfY002h0=7=Z@000`3AcJT60820P0D000002`20P806oooo
o`D0P8202`00000;0820P0Kooooo4@00000;0820P0Gooooo1P20P80;ooooo`/0P8201@0000060820
P0/000002`20P80;000000/0P820103AcJT000<0dLfY1P20P805000000/0P8201_ooool50820P0/0
00002`20P806oooooa4000002`20P805ooooo`H0P8202oooool;0820P0D000001P20P80;000000/0
P8202`00000;0820P0@0dLfY00030=7=Z@H0P8201@00000;0820P0Kooooo1@20P80;000000/0P820
1_oooolA000000/0P8201Oooool60820P0_ooooo2`20P805000000H0P8202`00000;0820P0/00000
2`20P8040=7=Z@000`3AcJT60820P0D000002`20P806ooooo`D0P8202`00000;0820P0Kooooo4@00
000;0820P0Gooooo1P20P80;ooooo`/0P8201@0000060820P0/000002`20P80;000000/0P820103A
cJT000<0dLfY1P20P805000000/0P8201_ooool50820P0/000002`20P806oooooa4000002`20P805
ooooo`H0P8202oooool;0820P0D000001P20P80;000000/0P8202`00000;0820P0@0dLfY00030=7=
Z@H0P8201@00000;0820P0Kooooo1@20P80;000000/0P8201_oooolA000000/0P8201Oooool60820
P0_ooooo2`20P805000000H0P8202`00000;0820P0/000002`20P8040=7=Z@000`3AcJT6ooooo`/0
00001Oooool60820P0D000002`20P806ooooo`D000001_oooolA0820P0Gooooo1P00000;ooooo`/0
P8201@000006ooooo`/000002`20P806ooooo`D000002`20P806ooooo`D00000103AcJT000<0dLfY
1_ooool;000000Gooooo1P20P805000000/0P8201_ooool5000000Kooooo4@20P805ooooo`H00000
2oooool;0820P0D000001_ooool;000000/0P8201_ooool5000000/0P8201_ooool5000000@0dLfY
00030=7=Z@Kooooo2`000005ooooo`H0P8201@00000;0820P0Kooooo1@000006oooooa40P8201Ooo
ool6000000_ooooo2`20P805000000Kooooo2`00000;0820P0Kooooo1@00000;0820P0Kooooo1@00
00040=7=Z@000`3AcJT6ooooo`/000001Oooool60820P0D000002`20P806ooooo`D000001_oooolA
0820P0Gooooo1P00000;ooooo`/0P8201@000006ooooo`/000002`20P806ooooo`D000002`20P806
ooooo`D00000103AcJT000<0dLfY1_ooool;000000Gooooo1P20P805000000/0P8201_ooool50000
00Kooooo4@20P805ooooo`H000002oooool;0820P0D000001_ooool;000000/0P8201_ooool50000
00/0P8201_ooool5000000@0dLfY00030=7=Z@Kooooo2`20P80;ooooo`/000001Oooool60820P0D0
00001P20P805000000Kooooo1P000005ooooo`H0P8204?ooool6000000D0P8201_ooool;0820P0Go
oooo1P000006ooooo`D0P8201_ooool5000000Kooooo1@20P8040=7=Z@000`3AcJT6ooooo`/0P820
2oooool;000000Gooooo1P20P805000000H0P8201@000006ooooo`H000001Oooool60820P13ooooo
1P0000050820P0Kooooo2`20P805ooooo`H000001_ooool50820P0Kooooo1@000006ooooo`D0P820
103AcJT000<0dLfY1_ooool;0820P0_ooooo2`000005ooooo`H0P8201@0000060820P0D000001_oo
ool6000000Gooooo1P20P80@ooooo`H000001@20P806ooooo`/0P8201Oooool6000000Kooooo1@20
P806ooooo`D000001_ooool50820P0@0dLfY00030=7=Z@Kooooo2`20P80;ooooo`/000001Oooool6
0820P0D000001P20P805000000Kooooo1P000005ooooo`H0P8204?ooool6000000D0P8201_ooool;
0820P0Gooooo1P000006ooooo`D0P8201_ooool5000000Kooooo1@20P8040=7=Z@000`3AcJT6oooo
o`/0P8202oooool;000000Gooooo1P20P805000000H0P8201@000006ooooo`H000001Oooool60820
P13ooooo1P0000050820P0Kooooo2`20P805ooooo`H000001_ooool50820P0Kooooo1@000006oooo
o`D0P820103AcJT000<0dLfY1_ooool;0820P0_ooooo2`000005ooooo`H0P8201@0000060820P0D0
00001_ooool6000000Gooooo1P20P80@ooooo`H000001@20P806ooooo`/0P8201Oooool6000000Ko
oooo1@20P806ooooo`D000001_ooool50820P0@0dLfY00030=7=Z@_ooooo1P00000;ooooo`/0P820
2oooool;000000D0P8201_ooool60820P0_ooooo4020P80;000000_ooooo1P000005ooooo`H0P820
2oooool60820P0D000001P20P805000000@0dLfY00030=7=Z@_ooooo1P00000;ooooo`/0P8202ooo
ool;000000D0P8201_ooool60820P0_ooooo4020P80;000000_ooooo1P000005ooooo`H0P8202ooo
ool60820P0D000001P20P805000000@0dLfY00030=7=Z@_ooooo1P00000;ooooo`/0P8202oooool;
000000D0P8201_ooool60820P0_ooooo4020P80;000000_ooooo1P000005ooooo`H0P8202oooool6
0820P0D000001P20P805000000@0dLfY00030=7=Z@_ooooo1P00000;ooooo`/0P8202oooool;0000
00D0P8201_ooool60820P0_ooooo4020P80;000000_ooooo1P000005ooooo`H0P8202oooool60820
P0D000001P20P805000000@0dLfY00030=7=Z@_ooooo1P00000;ooooo`/0P8202oooool;000000D0
P8201_ooool60820P0_ooooo4020P80;000000_ooooo1P000005ooooo`H0P8202oooool60820P0D0
00001P20P805000000@0dLfY00030=7=Z@_ooooo1P20P80@ooooo`H000002oooool;0820P0Gooooo
1P20P8060000013ooooo1P000005ooooo`/000002`20P806000000D0P8201P00000Aooooo`/00000
1@20P8040=7=Z@000`3AcJT;ooooo`H0P8204?ooool6000000_ooooo2`20P805ooooo`H0P8201P00
000@ooooo`H000001Oooool;000000/0P8201P0000050820P0H000004Oooool;000000D0P820103A
cJT000<0dLfY2oooool60820P13ooooo1P00000;ooooo`/0P8201Oooool60820P0H000004?ooool6
000000Gooooo2`00000;0820P0H000001@20P8060000017ooooo2`0000050820P0@0dLfY00030=7=
Z@_ooooo1P20P80@ooooo`H000002oooool;0820P0Gooooo1P20P8060000013ooooo1P000005oooo
o`/000002`20P806000000D0P8201P00000Aooooo`/000001@20P8040=7=Z@000`3AcJT;ooooo`H0
P8204?ooool6000000_ooooo2`20P805ooooo`H0P8201P00000@ooooo`H000001Oooool;000000/0
P8201P0000050820P0H000004Oooool;000000D0P820103AcJT000<0dLfY2oooool60820P13ooooo
1P00000;ooooo`/0P8201Oooool60820P0H000004?ooool6000000Gooooo2`00000;0820P0H00000
1@20P8060000017ooooo2`0000050820P0@0dLfY00030=7=ZA7ooooo4020P806000000/0P8201@00
0006ooooo`D0P8201P0000060820P13ooooo1P20P805ooooo`/0P8201_ooool5000000H0P8201Ooo
ool600000140P820400000040=7=Z@000`3AcJTAoooooa00P8201P00000;0820P0D000001_ooool5
0820P0H000001P20P80@ooooo`H0P8201Oooool;0820P0Kooooo1@0000060820P0Gooooo1P00000A
0820P1000000103AcJT000<0dLfY4Oooool@0820P0H000002`20P805000000Kooooo1@20P8060000
00H0P8204?ooool60820P0Gooooo2`20P806ooooo`D000001P20P805ooooo`H000004@20P80@0000
00@0dLfY00030=7=ZA7ooooo4020P806000000/0P8201@000006ooooo`D0P8201P0000060820P13o
oooo1P20P805ooooo`/0P8201_ooool5000000H0P8201Oooool600000140P820400000040=7=Z@00
0`3AcJTAoooooa00P8201P00000;0820P0D000001_ooool50820P0H000001P20P80@ooooo`H0P820
1Oooool;0820P0Kooooo1@0000060820P0Gooooo1P00000A0820P1000000103AcJT000<0dLfY5_oo
ool6000000Gooooo2`000006ooooo`D000001P20P805000000H0P8201_ooool@0820P0H000002ooo
ool5000000Kooooo1@20P806ooooo`D0P82030000005ooooo`H000004020P8040=7=Z@000`3AcJTF
ooooo`H000001Oooool;000000Kooooo1@0000060820P0D000001P20P806oooooa00P8201P00000;
ooooo`D000001_ooool50820P0Kooooo1@20P80<000000Gooooo1P00000@0820P0@0dLfY00030=7=
ZAKooooo1P000005ooooo`/000001_ooool5000000H0P8201@0000060820P0Kooooo4020P8060000
00_ooooo1@000006ooooo`D0P8201_ooool50820P0`000001Oooool600000100P820103AcJT000<0
dLfY5_ooool6000000Gooooo2`000006ooooo`D000001P20P805000000H0P8201_ooool@0820P0H0
00002oooool5000000Kooooo1@20P806ooooo`D0P82030000005ooooo`H000004020P8040=7=Z@00
0`3AcJTFooooo`H000001Oooool;000000Kooooo1@0000060820P0D000001P20P806oooooa00P820
1P00000;ooooo`D000001_ooool50820P0Kooooo1@20P80<000000Gooooo1P00000@0820P0@0dLfY
00030=7=ZAKooooo1P000005ooooo`/000001_ooool5000000H0P8201@0000060820P0Kooooo4020
P806000000_ooooo1@000006ooooo`D0P8201_ooool50820P0`000001Oooool600000100P820103A
cJT000<0dLfY5_ooool60820P0Gooooo2`20P806ooooo`D0P8201_ooool;000000_ooooo1P000005
ooooo`H000002`20P805000000H0P8201@00000;ooooo``000001@20P80;000000Kooooo1@000004
0=7=Z@000`3AcJTFooooo`H0P8201Oooool;0820P0Kooooo1@20P806ooooo`/000002oooool60000
00Gooooo1P00000;0820P0D000001P20P805000000_ooooo300000050820P0/000001_ooool50000
00@0dLfY00030=7=ZAKooooo1P20P805ooooo`/0P8201_ooool50820P0Kooooo2`00000;ooooo`H0
00001Oooool6000000/0P8201@0000060820P0D000002oooool<000000D0P8202`000006ooooo`D0
0000103AcJT000<0dLfY5_ooool60820P0Gooooo2`20P806ooooo`D0P8201_ooool;000000_ooooo
1P000005ooooo`H000002`20P805000000H0P8201@00000;ooooo``000001@20P80;000000Kooooo
1@0000040=7=Z@000`3AcJTFooooo`H0P8201Oooool;0820P0Kooooo1@20P806ooooo`/000002ooo
ool6000000Gooooo1P00000;0820P0D000001P20P805000000_ooooo300000050820P0/000001_oo
ool5000000@0dLfY00030=7=ZAcooooo1@20P806000000Gooooo1P20P805000000Kooooo2`20P80;
ooooo`H0P8201Oooool60820P0Gooooo1P0000050820P0Kooooo1@00000;0820P14000002`20P806
ooooo`D0P820103AcJT000<0dLfY7?ooool50820P0H000001Oooool60820P0D000001_ooool;0820
P0_ooooo1P20P805ooooo`H0P8201Oooool6000000D0P8201_ooool5000000/0P8204@00000;0820
P0Kooooo1@20P8040=7=Z@000`3AcJTLooooo`D0P8201P000005ooooo`H0P8201@000006ooooo`/0
P8202oooool60820P0Gooooo1P20P805ooooo`H000001@20P806ooooo`D000002`20P80A000000/0
P8201_ooool50820P0@0dLfY00030=7=ZAcooooo1@20P806000000Gooooo1P20P805000000Kooooo
2`20P80;ooooo`H0P8201Oooool60820P0Gooooo1P0000050820P0Kooooo1@00000;0820P1400000
2`20P806ooooo`D0P820103AcJT000<0dLfY7?ooool50820P0H000001Oooool60820P0D000001_oo
ool;0820P0_ooooo1P20P805ooooo`H0P8201Oooool6000000D0P8201_ooool5000000/0P8204@00
000;0820P0Kooooo1@20P8040=7=Z@000`3AcJTLooooo`D0P8201P000005ooooo`H0P8201@000006
ooooo`/0P8202oooool60820P0Gooooo1P20P805ooooo`H000001@20P806ooooo`D000002`20P80A
000000/0P8201_ooool50820P0@0dLfY00030=7=ZB7ooooo1P0000050820P0H000001@20P80;oooo
o`H000004Oooool50820P0H000001Oooool60820P0Gooooo1P20P80;000000Gooooo5`000005oooo
o`H0P8201@0000040=7=Z@000`3AcJTQooooo`H000001@20P806000000D0P8202oooool60000017o
oooo1@20P806000000Gooooo1P20P805ooooo`H0P8202`000005oooooaL000001Oooool60820P0D0
0000103AcJT000<0dLfY8Oooool6000000D0P8201P0000050820P0_ooooo1P00000Aooooo`D0P820
1P000005ooooo`H0P8201Oooool60820P0/000001OoooolG000000Gooooo1P20P805000000@0dLfY
00030=7=ZB7ooooo1P0000050820P0H000001@20P80;ooooo`H000004Oooool50820P0H000001Ooo
ool60820P0Gooooo1P20P80;000000Gooooo5`000005ooooo`H0P8201@0000040=7=Z@000`3AcJTQ
ooooo`H000001@20P806000000D0P8202oooool60000017ooooo1@20P806000000Gooooo1P20P805
ooooo`H0P8202`000005oooooaL000001Oooool60820P0D00000103AcJT000<0dLfY8Oooool60820
P0Gooooo2`00000;ooooo`H0P8205_ooool6000000D0P8201P00000;ooooo`/000001@20P80G0000
00D0P8201P0000050820P0@0dLfY00030=7=ZB7ooooo1P20P805ooooo`/000002oooool60820P1Ko
oooo1P0000050820P0H000002oooool;000000D0P8205`0000050820P0H000001@20P8040=7=Z@00
0`3AcJTQooooo`H0P8201Oooool;000000_ooooo1P20P80Fooooo`H000001@20P806000000_ooooo
2`0000050820P1L000001@20P806000000D0P820103AcJT000<0dLfY8Oooool60820P0Gooooo2`00
000;ooooo`H0P8205_ooool6000000D0P8201P00000;ooooo`/000001@20P80G000000D0P8201P00
00050820P0@0dLfY00030=7=ZB7ooooo1P20P805ooooo`/000002oooool60820P1Kooooo1P000005
0820P0H000002oooool;000000D0P8205`0000050820P0H000001@20P8040=7=Z@000`3AcJTQoooo
o`H0P8201Oooool;000000_ooooo1P20P80Fooooo`H000001@20P806000000_ooooo2`0000050820
P1L000001@20P806000000D0P820103AcJT000<0dLfY9oooool50820P0/000002`20P806000001Ko
oooo1P20P805ooooo`H000002`20P80@000001L0P8201Oooool;000000@0dLfY00030=7=ZBOooooo
1@20P80;000000/0P8201P00000Fooooo`H0P8201Oooool6000000/0P8204000000G0820P0Gooooo
2`0000040=7=Z@000`3AcJTWooooo`D0P8202`00000;0820P0H000005_ooool60820P0Gooooo1P00
000;0820P10000005`20P805ooooo`/00000103AcJT000<0dLfY9oooool50820P0/000002`20P806
000001Kooooo1P20P805ooooo`H000002`20P80@000001L0P8201Oooool;000000@0dLfY00030=7=
ZBOooooo1@20P80;000000/0P8201P00000Fooooo`H0P8201Oooool6000000/0P8204000000G0820
P0Gooooo2`0000040=7=Z@000`3AcJT/oooooa4000001Oooool6000001H0P8201P000005ooooo`H0
P8201Oooool600000100P8201_ooool6000000Gooooo1P000005ooooo`/0P820103AcJT000<0dLfY
;?oooolA000000Gooooo1P00000F0820P0H000001Oooool60820P0Gooooo1P00000@0820P0Kooooo
1P000005ooooo`H000001Oooool;0820P0@0dLfY00030=7=ZBcooooo4@000005ooooo`H000005P20
P806000000Gooooo1P20P805ooooo`H000004020P806ooooo`H000001Oooool6000000Gooooo2`20
P8040=7=Z@000`3AcJT/oooooa4000001Oooool6000001H0P8201P000005ooooo`H0P8201Oooool6
00000100P8201_ooool6000000Gooooo1P000005ooooo`/0P820103AcJT000<0dLfY;?oooolA0000
00Gooooo1P00000F0820P0H000001Oooool60820P0Gooooo1P00000@0820P0Kooooo1P000005oooo
o`H000001Oooool;0820P0@0dLfY00030=7=ZBcooooo4@000005ooooo`H000005P20P806000000Go
oooo1P20P805ooooo`H000004020P806ooooo`H000001Oooool6000000Gooooo2`20P8040=7=Z@00
0`3AcJT/oooooa40P8201Oooool60820P0Kooooo1@000006ooooo`D000001P20P80;ooooo`D0P820
2`000006ooooo`D000001_ooool60820P0Gooooo1P20P80;ooooo`D00000103AcJT000<0dLfY;?oo
oolA0820P0Gooooo1P20P806ooooo`D000001_ooool5000000H0P8202oooool50820P0/000001_oo
ool5000000Kooooo1P20P805ooooo`H0P8202oooool5000000@0dLfY00030=7=ZBcooooo4@20P805
ooooo`H0P8201_ooool5000000Kooooo1@0000060820P0_ooooo1@20P80;000000Kooooo1@000006
ooooo`H0P8201Oooool60820P0_ooooo1@0000040=7=Z@000`3AcJT/oooooa40P8201Oooool60820
P0Kooooo1@000006ooooo`D000001P20P80;ooooo`D0P8202`000006ooooo`D000001_ooool60820
P0Gooooo1P20P80;ooooo`D00000103AcJT000<0dLfY;?oooolA0820P0Gooooo1P20P806ooooo`D0
00001_ooool5000000H0P8202oooool50820P0/000001_ooool5000000Kooooo1P20P805ooooo`H0
P8202oooool5000000@0dLfY00030=7=ZC;ooooo1@000006ooooo`D0P8201P000006ooooo`D0P820
1_ooool50820P0Kooooo2`20P805000000/0P8201_ooool50820P0cooooo1@20P806000000_ooooo
1@20P8040=7=Z@000`3AcJTbooooo`D000001_ooool50820P0H000001_ooool50820P0Kooooo1@20
P806ooooo`/0P8201@00000;0820P0Kooooo1@20P80<ooooo`D0P8201P00000;ooooo`D0P820103A
cJT000<0dLfY<_ooool5000000Kooooo1@20P806000000Kooooo1@20P806ooooo`D0P8201_ooool;
0820P0D000002`20P806ooooo`D0P8203?ooool50820P0H000002oooool50820P0@0dLfY00030=7=
ZC;ooooo1@000006ooooo`D0P8201P000006ooooo`D0P8201_ooool50820P0Kooooo2`20P8050000
00/0P8201_ooool50820P0cooooo1@20P806000000_ooooo1@20P8040=7=Z@000`3AcJTbooooo`D0
00001_ooool50820P0H000001_ooool50820P0Kooooo1@20P806ooooo`/0P8201@00000;0820P0Ko
oooo1@20P80<ooooo`D0P8201P00000;ooooo`D0P820103AcJT000<0dLfY<_ooool5000000Kooooo
1@20P806000000Kooooo1@20P806ooooo`D0P8201_ooool;0820P0D000002`20P806ooooo`D0P820
3?ooool50820P0H000002oooool50820P0@0dLfY00030=7=ZC;ooooo1@20P80;ooooo`H000001P20
P805000000_ooooo1P20P805000000Kooooo2`000005ooooo`H0P8201@00000Aooooo`H000002`20
P805000000@0dLfY00030=7=ZC;ooooo1@20P80;ooooo`H000001P20P805000000_ooooo1P20P805
000000Kooooo2`000005ooooo`H0P8201@00000Aooooo`H000002`20P805000000@0dLfY00030=7=
ZC;ooooo1@20P80;ooooo`H000001P20P805000000_ooooo1P20P805000000Kooooo2`000005oooo
o`H0P8201@00000Aooooo`H000002`20P805000000@0dLfY00030=7=ZC;ooooo1@20P80;ooooo`H0
00001P20P805000000_ooooo1P20P805000000Kooooo2`000005ooooo`H0P8201@00000Aooooo`H0
00002`20P805000000@0dLfY00030=7=ZC;ooooo1@20P80;ooooo`H000001P20P805000000_ooooo
1P20P805000000Kooooo2`000005ooooo`H0P8201@00000Aooooo`H000002`20P805000000@0dLfY
00030=7=ZCOooooo2`20P80<000000D0P8204Oooool5000000H0P8202`0000050820P0H000001@20
P80Aooooo`H0P8201Oooool6000000D0P820103AcJT000<0dLfY=oooool;0820P0`000001@20P80A
ooooo`D000001P20P80;000000D0P8201P0000050820P17ooooo1P20P805ooooo`H000001@20P804
0=7=Z@000`3AcJTgooooo`/0P820300000050820P17ooooo1@0000060820P0/000001@20P8060000
00D0P8204Oooool60820P0Gooooo1P0000050820P0@0dLfY00030=7=ZCOooooo2`20P80<000000D0
P8204Oooool5000000H0P8202`0000050820P0H000001@20P80Aooooo`H0P8201Oooool6000000D0
P820103AcJT000<0dLfY=oooool;0820P0`000001@20P80Aooooo`D000001P20P80;000000D0P820
1P0000050820P17ooooo1P20P805ooooo`H000001@20P8040=7=Z@000`3AcJTgooooo`/0P8203000
00050820P17ooooo1@0000060820P0/000001@20P806000000D0P8204Oooool60820P0Gooooo1P00
00050820P0@0dLfY00030=7=ZCgooooo1@00000<0820P0Gooooo4@20P80;000000/0P8201Oooool;
000001Oooooo1@20P80;000000@0dLfY00030=7=ZCgooooo1@00000<0820P0Gooooo4@20P80;0000
00/0P8201Oooool;000001Oooooo1@20P80;000000@0dLfY00030=7=ZCgooooo1@00000<0820P0Go
oooo4@20P80;000000/0P8201Oooool;000001Oooooo1@20P80;000000@0dLfY00030=7=ZCgooooo
1@00000<0820P0Gooooo4@20P80;000000/0P8201Oooool;000001Oooooo1@20P80;000000@0dLfY
00030=7=ZCgooooo1@00000<0820P0Gooooo4@20P80;000000/0P8201Oooool;000001Oooooo1@20
P80;000000@0dLfY00030=7=ZCgooooo1@20P806ooooo`H000002oooool5000000Kooooo40000006
ooooo`D0P8202`00000G0820P0D000002`20P8040=7=Z@000`3AcJTmooooo`D0P8201_ooool60000
00_ooooo1@000006oooooa0000001_ooool50820P0/000005`20P805000000/0P820103AcJT000<0
dLfY?Oooool50820P0Kooooo1P00000;ooooo`D000001_ooool@000000Kooooo1@20P80;000001L0
P8201@00000;0820P0@0dLfY00030=7=ZCgooooo1@20P806ooooo`H000002oooool5000000Kooooo
40000006ooooo`D0P8202`00000G0820P0D000002`20P8040=7=Z@000`3AcJTmooooo`D0P8201_oo
ool6000000_ooooo1@000006oooooa0000001_ooool50820P0/000005`20P805000000/0P820103A
cJT000<0dLfY?Oooool50820P0Kooooo1P00000;ooooo`D000001_ooool@000000Kooooo1@20P80;
000001L0P8201@00000;0820P0@0dLfY00030=7=ZD;ooooo1P20P806000000/0P8201@0000060820
P10000001P20P805000000/0P8201_ooool6000000Gooooo1P0000050820P0Kooooo1@0000040=7=
Z@000`3AcJU2ooooo`H0P8201P00000;0820P0D000001P20P80@000000H0P8201@00000;0820P0Ko
oooo1P000005ooooo`H000001@20P806ooooo`D00000103AcJT000<0dLfY@_ooool60820P0H00000
2`20P805000000H0P820400000060820P0D000002`20P806ooooo`H000001Oooool6000000D0P820
1_ooool5000000@0dLfY00030=7=ZD;ooooo1P20P806000000/0P8201@0000060820P10000001P20
P805000000/0P8201_ooool6000000Gooooo1P0000050820P0Kooooo1@0000040=7=Z@000`3AcJU2
ooooo`H0P8201P00000;0820P0D000001P20P80@000000H0P8201@00000;0820P0Kooooo1P000005
ooooo`H000001@20P806ooooo`D00000103AcJT000<0dLfYB?ooool;000000Kooooo2`00000@0820
P0Kooooo2`000005ooooo`H0P8201P0000050820P0/000001_ooool50820P0@0dLfY00030=7=ZDSo
oooo2`000006ooooo`/000004020P806ooooo`/000001Oooool60820P0H000001@20P80;000000Ko
oooo1@20P8040=7=Z@000`3AcJU8ooooo`/000001_ooool;00000100P8201_ooool;000000Gooooo
1P20P806000000D0P8202`000006ooooo`D0P820103AcJT000<0dLfYB?ooool;000000Kooooo2`00
000@0820P0Kooooo2`000005ooooo`H0P8201P0000050820P0/000001_ooool50820P0@0dLfY0003
0=7=ZDSooooo2`000006ooooo`/000004020P806ooooo`/000001Oooool60820P0H000001@20P80;
000000Kooooo1@20P8040=7=Z@000`3AcJU8ooooo`/000001_ooool;00000100P8201_ooool;0000
00Gooooo1P20P806000000D0P8202`000006ooooo`D0P820103AcJT000<0dLfYB?ooool;0820P0Ko
oooo2`20P805ooooo`H000001Oooool60820P0/000001@20P806000000H0P8201Oooool;000000H0
P8201@0000040=7=Z@000`3AcJU8ooooo`/0P8201_ooool;0820P0Gooooo1P000005ooooo`H0P820
2`0000050820P0H000001P20P805ooooo`/000001P20P805000000@0dLfY00030=7=ZDSooooo2`20
P806ooooo`/0P8201Oooool6000000Gooooo1P20P80;000000D0P8201P0000060820P0Gooooo2`00
00060820P0D00000103AcJT000<0dLfYB?ooool;0820P0Kooooo2`20P805ooooo`H000001Oooool6
0820P0/000001@20P806000000H0P8201Oooool;000000H0P8201@0000040=7=Z@000`3AcJU8oooo
o`/0P8201_ooool;0820P0Gooooo1P000005ooooo`H0P8202`0000050820P0H000001P20P805oooo
o`/000001P20P805000000@0dLfY00030=7=ZDkooooo1@00000;ooooo`H000001Oooool60820P0_o
oooo400000060820P0Kooooo1@20P80A000000D0P820103AcJT000<0dLfYC_ooool5000000_ooooo
1P000005ooooo`H0P8202oooool@000000H0P8201_ooool50820P14000001@20P8040=7=Z@000`3A
cJU>ooooo`D000002oooool6000000Gooooo1P20P80;oooooa0000001P20P806ooooo`D0P8204@00
00050820P0@0dLfY00030=7=ZDkooooo1@00000;ooooo`H000001Oooool60820P0_ooooo40000006
0820P0Kooooo1@20P80A000000D0P820103AcJT000<0dLfYC_ooool5000000_ooooo1P000005oooo
o`H0P8202oooool@000000H0P8201_ooool50820P14000001@20P8040=7=Z@000`3AcJU>ooooo`D0
00002oooool6000000Gooooo1P20P80;oooooa0000001P20P806ooooo`D0P8204@0000050820P0@0
dLfY00030=7=ZDkooooo1@20P80;ooooo`H0P8202oooool;0820P1H000002ooooolF000000@0dLfY
00030=7=ZDkooooo1@20P80;ooooo`H0P8202oooool;0820P1H000002ooooolF000000@0dLfY0003
0=7=ZDkooooo1@20P80;ooooo`H0P8202oooool;0820P1H000002ooooolF000000@0dLfY00030=7=
ZDkooooo1@20P80;ooooo`H0P8202oooool;0820P1H000002ooooolF000000@0dLfY00030=7=ZDko
oooo1@20P80;ooooo`H0P8202oooool;0820P1H000002ooooolF000000@0dLfY00030=7=ZE?ooooo
2`20P8060000013ooooo1P00000F0820P0_ooooo5P20P8040=7=Z@000`3AcJUCooooo`/0P8201P00
000@ooooo`H000005P20P80;oooooaH0P820103AcJT000<0dLfYDoooool;0820P0H000004?ooool6
000001H0P8202ooooolF0820P0@0dLfY00030=7=ZE?ooooo2`20P8060000013ooooo1P00000F0820
P0_ooooo5P20P8040=7=Z@000`3AcJUCooooo`/0P8201P00000@ooooo`H000005P20P80;oooooaH0
P820103AcJT000<0dLfYDoooool;0820P0H000004?ooool6000001H0P8202ooooolF0820P0@0dLfY
00030=7=ZEWooooo1@0000060820P13ooooo1P20P805ooooo`H000001Oooool60000017ooooo1@00
0006ooooo`D00000103AcJT000<0dLfYFOooool5000000H0P8204?ooool60820P0Gooooo1P000005
ooooo`H000004Oooool5000000Kooooo1@0000040=7=Z@000`3AcJUIooooo`D000001P20P80@oooo
o`H0P8201Oooool6000000Gooooo1P00000Aooooo`D000001_ooool5000000@0dLfY00030=7=ZEWo
oooo1@0000060820P13ooooo1P20P805ooooo`H000001Oooool60000017ooooo1@000006ooooo`D0
0000103AcJT000<0dLfYFOooool5000000H0P8204?ooool60820P0Gooooo1P000005ooooo`H00000
4Oooool5000000Kooooo1@0000040=7=Z@000`3AcJUIooooo`D0P8201_ooool@0820P0H000001Ooo
ool60820P0Gooooo1P20P80Aooooo`D0P8201_ooool50820P0@0dLfY00030=7=ZEWooooo1@20P806
oooooa00P8201P000005ooooo`H0P8201Oooool60820P17ooooo1@20P806ooooo`D0P820103AcJT0
00<0dLfYFOooool50820P0Kooooo4020P806000000Gooooo1P20P805ooooo`H0P8204Oooool50820
P0Kooooo1@20P8040=7=Z@000`3AcJUIooooo`D0P8201_ooool@0820P0H000001Oooool60820P0Go
oooo1P20P80Aooooo`D0P8201_ooool50820P0@0dLfY00030=7=ZEWooooo1@20P806oooooa00P820
1P000005ooooo`H0P8201Oooool60820P17ooooo1@20P806ooooo`D0P820103AcJT000<0dLfYFOoo
ool50820P0Kooooo4020P806000000Gooooo1P20P805ooooo`H0P8204Oooool50820P0Kooooo1@20
P8040=7=Z@000`3AcJUNooooo`H0P8201@000006ooooo`D000001P20P80;ooooo`D0P8201P00000F
ooooo`H0P8201@0000040=7=Z@000`3AcJUNooooo`H0P8201@000006ooooo`D000001P20P80;oooo
o`D0P8201P00000Fooooo`H0P8201@0000040=7=Z@000`3AcJUNooooo`H0P8201@000006ooooo`D0
00001P20P80;ooooo`D0P8201P00000Fooooo`H0P8201@0000040=7=Z@000`3AcJUNooooo`H0P820
1@000006ooooo`D000001P20P80;ooooo`D0P8201P00000Fooooo`H0P8201@0000040=7=Z@000`3A
cJUNooooo`H0P8201@000006ooooo`D000001P20P80;ooooo`D0P8201P00000Fooooo`H0P8201@00
00040=7=Z@000`3AcJUTooooo`D000001P20P80;0000013ooooo1P00000F0820P0H000001@20P804
0=7=Z@000`3AcJUTooooo`D000001P20P80;0000013ooooo1P00000F0820P0H000001@20P8040=7=
Z@000`3AcJUTooooo`D000001P20P80;0000013ooooo1P00000F0820P0H000001@20P8040=7=Z@00
0`3AcJUTooooo`D000001P20P80;0000013ooooo1P00000F0820P0H000001@20P8040=7=Z@000`3A
cJUTooooo`D000001P20P80;0000013ooooo1P00000F0820P0H000001@20P8040=7=Z@000`3AcJUT
ooooo`D000001P20P80;0000013ooooo1P00000F0820P0H000001@20P8040=7=Z@000`3AcJUToooo
o`D0P8201_ooool;00000100P82030000005ooooo`H000001Oooool;000000@0dLfY00030=7=ZFCo
oooo1@20P806ooooo`/000004020P80<000000Gooooo1P000005ooooo`/00000103AcJT000<0dLfY
I?ooool50820P0Kooooo2`00000@0820P0`000001Oooool6000000Gooooo2`0000040=7=Z@000`3A
cJUTooooo`D0P8201_ooool;00000100P82030000005ooooo`H000001Oooool;000000@0dLfY0003
0=7=ZFCooooo1@20P806ooooo`/000004020P80<000000Gooooo1P000005ooooo`/00000103AcJT0
00<0dLfYJOooool60820P10000001_ooool5000000`0P8201Oooool60820P0Gooooo2`20P8040=7=
Z@000`3AcJUYooooo`H0P82040000006ooooo`D000003020P805ooooo`H0P8201Oooool;0820P0@0
dLfY00030=7=ZFWooooo1P20P80@000000Kooooo1@00000<0820P0Gooooo1P20P805ooooo`/0P820
103AcJT000<0dLfYJOooool60820P10000001_ooool5000000`0P8201Oooool60820P0Gooooo2`20
P8040=7=Z@000`3AcJUYooooo`H0P82040000006ooooo`D000003020P805ooooo`H0P8201Oooool;
0820P0@0dLfY00030=7=ZFoooooo400000060820P0/000001_ooool50820P0H000002oooool50000
00@0dLfY00030=7=ZFoooooo400000060820P0/000001_ooool50820P0H000002oooool5000000@0
dLfY00030=7=ZFoooooo400000060820P0/000001_ooool50820P0H000002oooool5000000@0dLfY
00030=7=ZFoooooo400000060820P0/000001_ooool50820P0H000002oooool5000000@0dLfY0003
0=7=ZFoooooo400000060820P0/000001_ooool50820P0H000002oooool5000000@0dLfY00030=7=
ZFoooooo400000060820P0/000001_ooool50820P0H000002oooool5000000@0dLfY00030=7=ZFoo
oooo4020P806ooooo`/000001P20P805000000H0P8202oooool50820P0@0dLfY00030=7=ZFoooooo
4020P806ooooo`/000001P20P805000000H0P8202oooool50820P0@0dLfY00030=7=ZFoooooo4020
P806ooooo`/000001P20P805000000H0P8202oooool50820P0@0dLfY00030=7=ZFoooooo4020P806
ooooo`/000001P20P805000000H0P8202oooool50820P0@0dLfY00030=7=ZFoooooo4020P806oooo
o`/000001P20P805000000H0P8202oooool50820P0@0dLfY00030=7=ZGCooooo1P000005ooooo`H0
P8204@0000050820P0Kooooo2`20P805000000@0dLfY00030=7=ZGCooooo1P000005ooooo`H0P820
4@0000050820P0Kooooo2`20P805000000@0dLfY00030=7=ZGCooooo1P000005ooooo`H0P8204@00
00050820P0Kooooo2`20P805000000@0dLfY00030=7=ZGCooooo1P000005ooooo`H0P8204@000005
0820P0Kooooo2`20P805000000@0dLfY00030=7=ZGCooooo1P000005ooooo`H0P8204@0000050820
P0Kooooo2`20P805000000@0dLfY00030=7=ZGCooooo1P000005ooooo`H0P8204@0000050820P0Ko
oooo2`20P805000000@0dLfY00030=7=ZGCooooo1P20P80;oooooaH000002oooool6000000D0P820
103AcJT000<0dLfYM?ooool60820P0_ooooo5P00000;ooooo`H000001@20P8040=7=Z@000`3AcJUd
ooooo`H0P8202ooooolF000000_ooooo1P0000050820P0@0dLfY00030=7=ZGCooooo1P20P80;oooo
oaH000002oooool6000000D0P820103AcJT000<0dLfYM?ooool60820P0_ooooo5P00000;ooooo`H0
00001@20P8040=7=Z@000`3AcJUjooooo`/0P8205P00000;0820P0/00000103AcJT000<0dLfYN_oo
ool;0820P1H000002`20P80;000000@0dLfY00030=7=ZG[ooooo2`20P80F000000/0P8202`000004
0=7=Z@000`3AcJUjooooo`/0P8205P00000;0820P0/00000103AcJT000<0dLfYN_ooool;0820P1H0
00002`20P80;000000@0dLfY00030=7=ZG[ooooo2`20P80F000000/0P8202`0000040=7=Z@000`3A
cJUoooooo`H000005P20P806ooooo`D000002`20P8040=7=Z@000`3AcJUoooooo`H000005P20P806
ooooo`D000002`20P8040=7=Z@000`3AcJUoooooo`H000005P20P806ooooo`D000002`20P8040=7=
Z@000`3AcJUoooooo`H000005P20P806ooooo`D000002`20P8040=7=Z@000`3AcJUoooooo`H00000
5P20P806ooooo`D000002`20P8040=7=Z@000`3AcJUoooooo`H0P8201Oooool6000000Kooooo1@00
0006ooooo`D0P8201_ooool5000000@0dLfY00030=7=ZGoooooo1P20P805ooooo`H000001_ooool5
000000Kooooo1@20P806ooooo`D00000103AcJT000<0dLfYOoooool60820P0Gooooo1P000006oooo
o`D000001_ooool50820P0Kooooo1@0000040=7=Z@000`3AcJUoooooo`H0P8201Oooool6000000Ko
oooo1@000006ooooo`D0P8201_ooool5000000@0dLfY00030=7=ZGoooooo1P20P805ooooo`H00000
1_ooool5000000Kooooo1@20P806ooooo`D00000103AcJT000<0dLfYOoooool60820P0Gooooo1P00
0006ooooo`D000001_ooool50820P0Kooooo1@0000040=7=Z@000`3AcJV5ooooo`D0P8201P000006
0820P0D000001P20P805000000Kooooo1@20P8040=7=Z@000`3AcJV5ooooo`D0P8201P0000060820
P0D000001P20P805000000Kooooo1@20P8040=7=Z@000`3AcJV5ooooo`D0P8201P0000060820P0D0
00001P20P805000000Kooooo1@20P8040=7=Z@000`3AcJV5ooooo`D0P8201P0000060820P0D00000
1P20P805000000Kooooo1@20P8040=7=Z@000`3AcJV5ooooo`D0P8201P0000060820P0D000001P20
P805000000Kooooo1@20P8040=7=Z@000`3AcJV:ooooo``000001@20P806ooooo`D000001P20P805
000000@0dLfY00030=7=ZH[ooooo300000050820P0Kooooo1@0000060820P0D00000103AcJT000<0
dLfYR_ooool<000000D0P8201_ooool5000000H0P8201@0000040=7=Z@000`3AcJV:ooooo``00000
1@20P806ooooo`D000001P20P805000000@0dLfY00030=7=ZH[ooooo300000050820P0Kooooo1@00
00060820P0D00000103AcJT000<0dLfYR_ooool<000000D0P8201_ooool5000000H0P8201@000004
0=7=Z@000`3AcJV:ooooo``0P8201Oooool60820P0/000001@20P8040=7=Z@000`3AcJV:ooooo``0
P8201Oooool60820P0/000001@20P8040=7=Z@000`3AcJV:ooooo``0P8201Oooool60820P0/00000
1@20P8040=7=Z@000`3AcJV:ooooo``0P8201Oooool60820P0/000001@20P8040=7=Z@000`3AcJV:
ooooo``0P8201Oooool60820P0/000001@20P8040=7=Z@000`3AcJV@ooooo`H000002oooool@0000
00@0dLfY00030=7=ZI3ooooo1P00000;oooooa000000103AcJT000<0dLfYT?ooool6000000_ooooo
400000040=7=Z@000`3AcJV@ooooo`H000002oooool@000000@0dLfY00030=7=ZI3ooooo1P00000;
oooooa000000103AcJT000<0dLfYT?ooool6000000_ooooo400000040=7=Z@000`3AcJV@ooooo`H0
P8202oooool@0820P0@0dLfY00030=7=ZI3ooooo1P20P80;oooooa00P820103AcJT000<0dLfYT?oo
ool60820P0_ooooo4020P8040=7=Z@000`3AcJV@ooooo`H0P8202oooool@0820P0@0dLfY00030=7=
ZI3ooooo1P20P80;oooooa00P820103AcJT000<0dLfYU_ooool;0820P0D000001_ooool5000000@0
dLfY00030=7=ZIKooooo2`20P805000000Kooooo1@0000040=7=Z@000`3AcJVFooooo`/0P8201@00
0006ooooo`D00000103AcJT000<0dLfYU_ooool;0820P0D000001_ooool5000000@0dLfY00030=7=
ZIKooooo2`20P805000000Kooooo1@0000040=7=Z@000`3AcJVFooooo`/0P8201@000006ooooo`D0
0000103AcJT000<0dLfYVoooool6000000D0P8201_ooool50820P0@0dLfY00030=7=ZI_ooooo1P00
00050820P0Kooooo1@20P8040=7=Z@000`3AcJVKooooo`H000001@20P806ooooo`D0P820103AcJT0
00<0dLfYVoooool6000000D0P8201_ooool50820P0@0dLfY00030=7=ZI_ooooo1P0000050820P0Ko
oooo1@20P8040=7=Z@000`3AcJVKooooo`H0P8201Oooool60820P0D00000103AcJT000<0dLfYVooo
ool60820P0Gooooo1P20P805000000@0dLfY00030=7=ZI_ooooo1P20P805ooooo`H0P8201@000004
0=7=Z@000`3AcJVKooooo`H0P8201Oooool60820P0D00000103AcJT000<0dLfYVoooool60820P0Go
oooo1P20P805000000@0dLfY00030=7=ZI_ooooo1P20P805ooooo`H0P8201@0000040=7=Z@000`3A
cJVQooooo`D0P8201P0000050820P0@0dLfY00030=7=ZJ7ooooo1@20P806000000D0P820103AcJT0
00<0dLfYXOooool50820P0H000001@20P8040=7=Z@000`3AcJVQooooo`D0P8201P0000050820P0@0
dLfY00030=7=ZJ7ooooo1@20P806000000D0P820103AcJT000<0dLfYY_ooool;000000@0dLfY0003
0=7=ZJKooooo2`0000040=7=Z@000`3AcJVVooooo`/00000103AcJT000<0dLfYY_ooool;000000@0
dLfY00030=7=ZJKooooo2`0000040=7=Z@000`3AcJVVooooo`/00000103AcJT000<0dLfYY_ooool;
0820P0@0dLfY00030=7=ZJKooooo2`20P8040=7=Z@000`3AcJVVooooo`/0P820103AcJT000<0dLfY
Y_ooool;0820P0@0dLfY00030=7=ZJKooooo2`20P8040=7=Z@000`3AcJV/ooooo`D00000103AcJT0
00<0dLfY[?ooool5000000@0dLfY00030=7=ZJcooooo1@0000040=7=Z@000`3AcJV/ooooo`D00000
103AcJT000<0dLfY[?ooool5000000@0dLfY00030=7=ZJcooooo1@0000040=7=Z@00^03AcJT00;P0
dLfY002h0=7=Z@00^03AcJT00;P0dLfY002h0=7=Z@00\
\>"],
  ImageRangeCache->{{{0, 183.313}, {286.938, 0}} -> {-0.640167, -1.04671, \
0.18155, 0.18155}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(pow[10, 7, 50];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .83333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0160256 0.0160256 0.0160256 [
[ 0 0 0 0 ]
[ 1 .83333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .83333 L
0 .83333 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01603 translate
.96154 .80128 scale
60 string
60 50 8 [60 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
D5AA558055AAD52A8055D58055D5802A80005500D555FF2AAA00AA2AD5D5D580AA2A00AA
00808000AAD580AAAA2A002A2A55AA00FF000080AA80AAAA
FFFF002AD52A2A2A80D5FF2A002AFFAA5555D5D5AAD52A552AD5AAAA55AAD5802A00D5AA
AA2AD52A802AFFAAAAAA5500D5D52A00D5808080FF005580
FFFFFF552AFF55FF802A550000D500AAAA8000AA0080552AAA55AAAAAA802AFFAA552A2A
FF002A2A80D5D580FFD555552A2AFF55FF2A00558055D5D5
FFFFFFFF80AAD5FF2AD5002A55FF00D55580D5AAAA2AD500FF002AFF008000FF2AD5D5D5
00AA2A80AAAA0080FF2AFF80D5002A5555D500002AD52A2A
FFFFFFFFFFAAAAD580AAAAFF8000AA2AFF80FF2A2A00FF00D58080AAD5AA80AA00FF2A2A
FF5580AA80FFAAFFAAD5D580FF00D5002AAAAAFF552AFF55
FFFFFFFFFFFFD555AA80FFD580D5AAAA55D5550000D5AAD5AAD52AD555AAAA80FF55D500
2A5555802AD580FFFFD580558055FF00D5008055002AAA00
FFFFFFFFFFFFFFD5FF0055D5802A2AFF002AFF8080AA008055AA002A2AAAAAAAAA00FFD5
AA55555555FFD5FFFFFFD5FF80D5FF2A80552A002A55FFAA
FFFFFFFFFFFFFFFFFF2A800080D5D500AA2AAA2A00558080D5FF000000FF00802AD5AAFF
2A00FF80D52A55AAFF5500AA2A00AA00D5FF80AA2A80D580
FFFFFFFFFFFFFFFFFFFF8000D52AFFD5AAAA5580AA2AAA80FF2A5500AAFFFF5555FFFF00
AA552A5580552AAAAAD5D5AAAA552A00D580802A00D5FFD5
FFFFFFFFFFFFFFFFFFFFFFAA2AFF80805580FF80FF002A2A00AA55552A2A55D500FFFFFF
5580D5002AD500FF008055AAAAAA55FF55AA80D5AAFFFF2A
FFFFFFFFFFFFFFFFFFFFFFFFD500AA80D5D5FFFFAAD5AA552A802AAA55FF800080AA2A55
D52A008080AAAAFFFF558000802AD5FF2AAAAAAA00808055
FFFFFFFFFFFFFFFFFFFFFFFFFFD5AAAAAA00AA2A55AA0080002A002A00FFFFAA2AD5552A
AAD5000055802AFF55002AAAFFAA55AAD5D55580FF558000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00802A802A80D5552A000000D50000AAFF002A2AAA
55AA0000002AD500AA55D5D555D55555AA0080D555002AAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5555FFAA558055552A55D5AAAAFF55AA00D5002A
00FFAAFF5500FF00D55555AAD52A2AAA802A802A2AAA2A80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80D580FF80D5D5D5D52A2AFF00AA802A805500
D5AAFF00AA55FF2A80555555AA0000FF00552AD5002A00D5
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAD5550055AAD580552AAA00D55555FFAA55
FF2A2A552A00FFFF8000FF80D55500D58080D5008080AA2A
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD58000002AFF2A002A80FF55AA8000AAAA
8055FF800000D5AA2A0000AAAA002A8055802A2A802A0055
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD5FF5500FF2A8080AAAA00FFD52A802A
D5FFAA2A00000080FF55D5AAAAAA2A80D5D5FF55FFAA5500
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2AAA55002A005580FF55D555FFAA
55AAFF0000AAFF5580800080FFD5552AD58055D52A5580AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF802AAA2A8080D555002AFFAA2A
00FFD5808080FFFF80D5FF55808055552AFFAA80552AAA80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA5580AA80FF00FF55550055
FF55D5802A0055D580FF2A55558000FF80AAFF0055552AD5
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD52A00802A552A55555500
FFFFAA00552A800080FF2A80D52A0000AA80FFFF5555552A
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD5AAFFAA55552AAA8000
00AAFF00002A80D5AAAA00D5FFD5AAFF5580FF55002AAA55
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00AAAA80002A2A00
00008055D5AA55805580FF55AAFF2A2A5555808000002A00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5580FFAA2A80AA
2A55D5FFAA00800055558080008055FF80002AD52A55D5AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FF2AD5D52A
D5D52A550055D5FF5555558000D52AAAD5FF552AFF800080
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAD5D58055
2AFFD5D500D52A55002AAA8000D555FFD58080002A5555D5
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD5805580
002A55AAAAFFD5D500D5008000D58000AAD52AAAFF80002A
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD5FF80
D5AA555580FFFFFF00D555D5FF55AA8080FFD5D555D52A55
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2A
D5802AAA802A55D580AA002AFFFF80FFAAAA2A2AFFAA0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
805555FFD52A80D5802A00D500AAD5FFFFD5552AAA2A00AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFAA8000AAD50055AA80AA2AFF55AA00AAFF00FF802A8080
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFD52A802AFF555580FF002A55558080FFFF55D52A80D5
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFD5D52AAA00FF80FF2A55FF80D52AD5AA00FFD5D52A
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF0000AAAA00D5FF2AD555FFFF0000AAD555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF55AAFF5580FF55AAD5D58000AAD5AA2AFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF80FFFF80FF2AAAAAD58000D555AAAA55AA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAAFF2AD580AAAAAAD52A80555580FF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFD580AAD52AFF0080552AD500FFAAD5
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFD5FFD555FFFF5580002A2A80802A
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF2AFFAA2A555555D5D5005555
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF80802A80D500FFFF00D500
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFAA80AAAA0000AAD5AAAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD52AFF000000805580
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD5D580808080D5D5
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2A0055802A2A
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF55D5D5FF55
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA00AA00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAAFFAA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD580
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 239.938},
  ImageMargins->{{30, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000kb000`400?l00000o`00003oo`3AcJTQ
0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@001@3AcJT5
0=GEe@@0ZZZZ1@1EEED50820P0@0EEEE1@2ZZZX40=GEe@D0:RXZ1@20P80405EEE@D0eMGE1020P805
05EEE@D0eMGE1020P80502XZ:PD0P8201000000505EEE@@000001@3EeMD505EEE@Cooooo1@0Z:RX4
0:ZZZPD000001@2ZZZX402XZ:Ph0eMGE1@20P8040:ZZZPD0:RXZ1@0000040:ZZZPD000002@20P805
000000@0ZZZZ1@3EeMD40820P0X0ZZZZ100Z:RX5000000T0:RXZ1@1EEED40:ZZZPD000001Oooool9
000000@0P8201@2ZZZX50820P0T0ZZZZ1P3AcJT000D0dLfY1@3EeMD40:ZZZPD0EEEE1@20P80405EE
E@D0ZZZZ103EeMD502XZ:PD0P820101EEED50=GEe@@0P8201@1EEED50=GEe@@0P8201@0Z:RX50820
P0@000001@1EEED4000000D0eMGE1@1EEED4ooooo`D0:RXZ102ZZZX5000000D0ZZZZ100Z:RX>0=GE
e@D0P820102ZZZX502XZ:PD00000102ZZZX5000000T0P8201@0000040:ZZZPD0eMGE1020P80:0:ZZ
ZP@0:RXZ1@00000902XZ:PD0EEEE102ZZZX5000000Gooooo2@0000040820P0D0ZZZZ1@20P8090:ZZ
ZPH0dLfY00050=7=Z@D0eMGE102ZZZX505EEE@D0P820101EEED50:ZZZP@0eMGE1@0Z:RX50820P0@0
EEEE1@3EeMD40820P0D0EEEE1@3EeMD40820P0D0:RXZ1@20P804000000D0EEEE100000050=GEe@D0
EEEE1?ooool502XZ:P@0ZZZZ1@0000050:ZZZP@0:RXZ3P3EeMD50820P0@0ZZZZ1@0Z:RX5000000@0
ZZZZ1@0000090820P0D00000102ZZZX50=GEe@@0P8202P2ZZZX402XZ:PD000002@0Z:RX505EEE@@0
ZZZZ1@000005ooooo`T000001020P8050:ZZZPD0P8202@2ZZZX60=7=Z@001@3AcJT50=GEe@@0ZZZZ
1@1EEED50820P0@0EEEE1@2ZZZX40=GEe@D0:RXZ1@20P80405EEE@D0eMGE1020P80505EEE@D0eMGE
1020P80502XZ:PD0P8201000000505EEE@@000001@3EeMD505EEE@Cooooo1@0Z:RX40:ZZZPD00000
1@2ZZZX402XZ:Ph0eMGE1@20P8040:ZZZPD0:RXZ1@0000040:ZZZPD000002@20P805000000@0ZZZZ
1@3EeMD40820P0X0ZZZZ100Z:RX5000000T0:RXZ1@1EEED40:ZZZPD000001Oooool9000000@0P820
1@2ZZZX50820P0T0ZZZZ1P3AcJT000D0dLfY1@3EeMD40:ZZZPD0EEEE1@20P80405EEE@D0ZZZZ103E
eMD502XZ:PD0P820101EEED50=GEe@@0P8201@1EEED50=GEe@@0P8201@0Z:RX50820P0@000001@1E
EED4000000D0eMGE1@1EEED4ooooo`D0:RXZ102ZZZX5000000D0ZZZZ100Z:RX>0=GEe@D0P820102Z
ZZX502XZ:PD00000102ZZZX5000000T0P8201@0000040:ZZZPD0eMGE1020P80:0:ZZZP@0:RXZ1@00
000902XZ:PD0EEEE102ZZZX5000000Gooooo2@0000040820P0D0ZZZZ1@20P8090:ZZZPH0dLfY0005
0=7=Z@Wooooo1@00000502XZ:P@0eMGE3P0Z:RX50820P0@0eMGE1Oooool402XZ:PD000001@0Z:RX4
ooooo`D0ZZZZ2@1EEED90=GEe@D0ZZZZ1@3EeMD402XZ:PD0EEEE100Z:RX50=GEe@T0ZZZZ1@1EEED4
0:ZZZPD0eMGE1@20P80402XZ:PD000001@3EeMD90:ZZZP@0:RXZ1@3EeMD502XZ:P@0P8201@0Z:RX4
ooooo`h0ZZZZ1@1EEED4000000X0eMGE100Z:RX5000000D0eMGE3@20P805ooooo`D00000101EEED5
0820P0H0dLfY00050=7=Z@Wooooo1@00000502XZ:P@0eMGE3P0Z:RX50820P0@0eMGE1Oooool402XZ
:PD000001@0Z:RX4ooooo`D0ZZZZ2@1EEED90=GEe@D0ZZZZ1@3EeMD402XZ:PD0EEEE100Z:RX50=GE
e@T0ZZZZ1@1EEED40:ZZZPD0eMGE1@20P80402XZ:PD000001@3EeMD90:ZZZP@0:RXZ1@3EeMD502XZ
:P@0P8201@0Z:RX4ooooo`h0ZZZZ1@1EEED4000000X0eMGE100Z:RX5000000D0eMGE3@20P805oooo
o`D00000101EEED50820P0H0dLfY00050=7=Z@Wooooo1@00000502XZ:P@0eMGE3P0Z:RX50820P0@0
eMGE1Oooool402XZ:PD000001@0Z:RX4ooooo`D0ZZZZ2@1EEED90=GEe@D0ZZZZ1@3EeMD402XZ:PD0
EEEE100Z:RX50=GEe@T0ZZZZ1@1EEED40:ZZZPD0eMGE1@20P80402XZ:PD000001@3EeMD90:ZZZP@0
:RXZ1@3EeMD502XZ:P@0P8201@0Z:RX4ooooo`h0ZZZZ1@1EEED4000000X0eMGE100Z:RX5000000D0
eMGE3@20P805ooooo`D00000101EEED50820P0H0dLfY00050=7=Z@Wooooo1@00000502XZ:P@0eMGE
3P0Z:RX50820P0@0eMGE1Oooool402XZ:PD000001@0Z:RX4ooooo`D0ZZZZ2@1EEED90=GEe@D0ZZZZ
1@3EeMD402XZ:PD0EEEE100Z:RX50=GEe@T0ZZZZ1@1EEED40:ZZZPD0eMGE1@20P80402XZ:PD00000
1@3EeMD90:ZZZP@0:RXZ1@3EeMD502XZ:P@0P8201@0Z:RX4ooooo`h0ZZZZ1@1EEED4000000X0eMGE
100Z:RX5000000D0eMGE3@20P805ooooo`D00000101EEED50820P0H0dLfY00050=7=Z@kooooo1@1E
EED402XZ:PGooooo101EEED5ooooo`D0P820100Z:RX505EEE@T000001@3EeMD4000000X0ZZZZ1020
P805000000@0ZZZZ1@0000050820P0@0EEEE1@0Z:RX40:ZZZPD0EEEE3P2ZZZX40820P0D0:RXZ1Ooo
ool40:ZZZPD0EEEE2@0Z:RX5ooooo`@000002P0Z:RX40820P0T0eMGE1@20P805ooooo`@0eMGE2@1E
EED:02XZ:PCooooo1@1EEED5ooooo`@0:RXZ1@00000405EEE@D0P8201@1EEED90=GEe@H0dLfY0005
0=7=Z@kooooo1@1EEED402XZ:PGooooo101EEED5ooooo`D0P820100Z:RX505EEE@T000001@3EeMD4
000000X0ZZZZ1020P805000000@0ZZZZ1@0000050820P0@0EEEE1@0Z:RX40:ZZZPD0EEEE3P2ZZZX4
0820P0D0:RXZ1Oooool40:ZZZPD0EEEE2@0Z:RX5ooooo`@000002P0Z:RX40820P0T0eMGE1@20P805
ooooo`@0eMGE2@1EEED:02XZ:PCooooo1@1EEED5ooooo`@0:RXZ1@00000405EEE@D0P8201@1EEED9
0=GEe@H0dLfY00050=7=Z@kooooo1@1EEED402XZ:PGooooo101EEED5ooooo`D0P820100Z:RX505EE
E@T000001@3EeMD4000000X0ZZZZ1020P805000000@0ZZZZ1@0000050820P0@0EEEE1@0Z:RX40:ZZ
ZPD0EEEE3P2ZZZX40820P0D0:RXZ1Oooool40:ZZZPD0EEEE2@0Z:RX5ooooo`@000002P0Z:RX40820
P0T0eMGE1@20P805ooooo`@0eMGE2@1EEED:02XZ:PCooooo1@1EEED5ooooo`@0:RXZ1@00000405EE
E@D0P8201@1EEED90=GEe@H0dLfY00050=7=Z@kooooo1@1EEED402XZ:PGooooo101EEED5ooooo`D0
P820100Z:RX505EEE@T000001@3EeMD4000000X0ZZZZ1020P805000000@0ZZZZ1@0000050820P0@0
EEEE1@0Z:RX40:ZZZPD0EEEE3P2ZZZX40820P0D0:RXZ1Oooool40:ZZZPD0EEEE2@0Z:RX5ooooo`@0
00002P0Z:RX40820P0T0eMGE1@20P805ooooo`@0eMGE2@1EEED:02XZ:PCooooo1@1EEED5ooooo`@0
:RXZ1@00000405EEE@D0P8201@1EEED90=GEe@H0dLfY00050=7=Z@kooooo1@1EEED402XZ:PGooooo
101EEED5ooooo`D0P820100Z:RX505EEE@T000001@3EeMD4000000X0ZZZZ1020P805000000@0ZZZZ
1@0000050820P0@0EEEE1@0Z:RX40:ZZZPD0EEEE3P2ZZZX40820P0D0:RXZ1Oooool40:ZZZPD0EEEE
2@0Z:RX5ooooo`@000002P0Z:RX40820P0T0eMGE1@20P805ooooo`@0eMGE2@1EEED:02XZ:PCooooo
1@1EEED5ooooo`@0:RXZ1@00000405EEE@D0P8201@1EEED90=GEe@H0dLfY00050=7=ZA?ooooo1020
P8050:ZZZP@0eMGE1Oooool502XZ:P@0eMGE1@00000402XZ:PD0EEEE1Oooool4000000D0eMGE1@1E
EED40820P0D0eMGE2@2ZZZX502XZ:P@0eMGE1@000004ooooo`D000001@0Z:RX4ooooo`D000001020
P805000000Gooooo100Z:RX>0=GEe@D00000102ZZZX502XZ:PD0P8202@2ZZZX4000000D0P8201Ooo
ool402XZ:PGooooo1020P8050=GEe@D00000100Z:RX:05EEE@@0eMGE2@00000502XZ:PD0eMGE2@0Z
:RX60=7=Z@001@3AcJTCooooo`@0P8201@2ZZZX40=GEe@Gooooo1@0Z:RX40=GEe@D00000100Z:RX5
05EEE@Gooooo100000050=GEe@D0EEEE1020P8050=GEe@T0ZZZZ1@0Z:RX40=GEe@D000001?ooool5
000000D0:RXZ1?ooool5000000@0P8201@000005ooooo`@0:RXZ3P3EeMD5000000@0ZZZZ1@0Z:RX5
0820P0T0ZZZZ100000050820P0Gooooo100Z:RX5ooooo`@0P8201@3EeMD5000000@0:RXZ2P1EEED4
0=GEe@T000001@0Z:RX50=GEe@T0:RXZ1P3AcJT000D0dLfY4oooool40820P0D0ZZZZ103EeMD5oooo
o`D0:RXZ103EeMD5000000@0:RXZ1@1EEED5ooooo`@000001@3EeMD505EEE@@0P8201@3EeMD90:ZZ
ZPD0:RXZ103EeMD5000000Cooooo1@00000502XZ:PCooooo1@0000040820P0D000001Oooool402XZ
:Ph0eMGE1@0000040:ZZZPD0:RXZ1@20P8090:ZZZP@000001@20P805ooooo`@0:RXZ1Oooool40820
P0D0eMGE1@00000402XZ:PX0EEEE103EeMD9000000D0:RXZ1@3EeMD902XZ:PH0dLfY00050=7=ZA?o
oooo1020P8050:ZZZP@0eMGE1Oooool502XZ:P@0eMGE1@00000402XZ:PD0EEEE1Oooool4000000D0
eMGE1@1EEED40820P0D0eMGE2@2ZZZX502XZ:P@0eMGE1@000004ooooo`D000001@0Z:RX4ooooo`D0
00001020P805000000Gooooo100Z:RX>0=GEe@D00000102ZZZX502XZ:PD0P8202@2ZZZX4000000D0
P8201Oooool402XZ:PGooooo1020P8050=GEe@D00000100Z:RX:05EEE@@0eMGE2@00000502XZ:PD0
eMGE2@0Z:RX60=7=Z@001@3AcJTGooooo`T0ZZZZ1@3EeMD50820P0T0ZZZZ1?ooool50820P0D00000
102ZZZX502XZ:PGooooo1020P805ooooo`T0:RXZ1@000004ooooo`D00000103EeMD:0820P0@0ZZZZ
1@3EeMD40:ZZZPD0P8201@2ZZZX4000000Gooooo2@0Z:RX5ooooo`@0EEEE1@20P8050:ZZZP@0P820
1Oooool40:ZZZPGooooo1@2ZZZX90=GEe@@0P8201Oooool5000000@0eMGE1@00000502XZ:PT0ZZZZ
1?ooool505EEE@D0:RXZ1?ooool505EEE@H0dLfY00050=7=ZAOooooo2@2ZZZX50=GEe@D0P8202@2Z
ZZX4ooooo`D0P8201@0000040:ZZZPD0:RXZ1Oooool40820P0Gooooo2@0Z:RX5000000Cooooo1@00
00040=GEe@X0P820102ZZZX50=GEe@@0ZZZZ1@20P8050:ZZZP@000001Oooool902XZ:PGooooo101E
EED50820P0D0ZZZZ1020P805ooooo`@0ZZZZ1Oooool50:ZZZPT0eMGE1020P805ooooo`D00000103E
eMD5000000D0:RXZ2@2ZZZX4ooooo`D0EEEE1@0Z:RX4ooooo`D0EEEE1P3AcJT000D0dLfY5oooool9
0:ZZZPD0eMGE1@20P8090:ZZZPCooooo1@20P805000000@0ZZZZ1@0Z:RX5ooooo`@0P8201Oooool9
02XZ:PD000001?ooool5000000@0eMGE2P20P8040:ZZZPD0eMGE102ZZZX50820P0D0ZZZZ10000005
ooooo`T0:RXZ1Oooool405EEE@D0P8201@2ZZZX40820P0Gooooo102ZZZX5ooooo`D0ZZZZ2@3EeMD4
0820P0Gooooo1@0000040=GEe@D000001@0Z:RX90:ZZZPCooooo1@1EEED502XZ:PCooooo1@1EEED6
0=7=Z@001@3AcJTGooooo`T0ZZZZ1@3EeMD50820P0T0ZZZZ1?ooool50820P0D00000102ZZZX502XZ
:PGooooo1020P805ooooo`T0:RXZ1@000004ooooo`D00000103EeMD:0820P0@0ZZZZ1@3EeMD40:ZZ
ZPD0P8201@2ZZZX4000000Gooooo2@0Z:RX5ooooo`@0EEEE1@20P8050:ZZZP@0P8201Oooool40:ZZ
ZPGooooo1@2ZZZX90=GEe@@0P8201Oooool5000000@0eMGE1@00000502XZ:PT0ZZZZ1?ooool505EE
E@D0:RXZ1?ooool505EEE@H0dLfY00050=7=ZAOooooo2@2ZZZX50=GEe@D0P8202@2ZZZX4ooooo`D0
P8201@0000040:ZZZPD0:RXZ1Oooool40820P0Gooooo2@0Z:RX5000000Cooooo1@0000040=GEe@X0
P820102ZZZX50=GEe@@0ZZZZ1@20P8050:ZZZP@000001Oooool902XZ:PGooooo101EEED50820P0D0
ZZZZ1020P805ooooo`@0ZZZZ1Oooool50:ZZZPT0eMGE1020P805ooooo`D00000103EeMD5000000D0
:RXZ2@2ZZZX4ooooo`D0EEEE1@0Z:RX4ooooo`D0EEEE1P3AcJT000D0dLfY7?ooool40=GEe@D0EEEE
1@2ZZZX40820P0Gooooo103EeMD50820P0D0eMGE2@2ZZZX505EEE@@0eMGE1@1EEED9000000D0eMGE
102ZZZX50=GEe@@0ZZZZ1@3EeMD502XZ:P@0eMGE1@1EEED90:ZZZPD0P8201?ooool505EEE@D0eMGE
1000000502XZ:PT0EEEE1@20P80402XZ:PD0eMGE1020P80:ooooo`@0eMGE1@20P80405EEE@D0P820
1@1EEED4ooooo`D000001@3EeMD4000000D0P820101EEED5000000D0:RXZ102ZZZX5000000H0dLfY
00050=7=ZAcooooo103EeMD505EEE@D0ZZZZ1020P805ooooo`@0eMGE1@20P8050=GEe@T0ZZZZ1@1E
EED40=GEe@D0EEEE2@0000050=GEe@@0ZZZZ1@3EeMD40:ZZZPD0eMGE1@0Z:RX40=GEe@D0EEEE2@2Z
ZZX50820P0Cooooo1@1EEED50=GEe@@000001@0Z:RX905EEE@D0P820100Z:RX50=GEe@@0P8202_oo
ool40=GEe@D0P820101EEED50820P0D0EEEE1?ooool5000000D0eMGE100000050820P0@0EEEE1@00
000502XZ:P@0ZZZZ1@0000060=7=Z@001@3AcJTLooooo`@0eMGE1@1EEED50:ZZZP@0P8201Oooool4
0=GEe@D0P8201@3EeMD90:ZZZPD0EEEE103EeMD505EEE@T000001@3EeMD40:ZZZPD0eMGE102ZZZX5
0=GEe@D0:RXZ103EeMD505EEE@T0ZZZZ1@20P804ooooo`D0EEEE1@3EeMD4000000D0:RXZ2@1EEED5
0820P0@0:RXZ1@3EeMD40820P0[ooooo103EeMD50820P0@0EEEE1@20P80505EEE@Cooooo1@000005
0=GEe@@000001@20P80405EEE@D000001@0Z:RX40:ZZZPD000001P3AcJT000D0dLfY7?ooool40=GE
e@D0EEEE1@2ZZZX40820P0Gooooo103EeMD50820P0D0eMGE2@2ZZZX505EEE@@0eMGE1@1EEED90000
00D0eMGE102ZZZX50=GEe@@0ZZZZ1@3EeMD502XZ:P@0eMGE1@1EEED90:ZZZPD0P8201?ooool505EE
E@D0eMGE1000000502XZ:PT0EEEE1@20P80402XZ:PD0eMGE1020P80:ooooo`@0eMGE1@20P80405EE
E@D0P8201@1EEED4ooooo`D000001@3EeMD4000000D0P820101EEED5000000D0:RXZ102ZZZX50000
00H0dLfY00050=7=ZAcooooo103EeMD505EEE@D0ZZZZ1020P805ooooo`@0eMGE1@20P8050=GEe@T0
ZZZZ1@1EEED40=GEe@D0EEEE2@0000050=GEe@@0ZZZZ1@3EeMD40:ZZZPD0eMGE1@0Z:RX40=GEe@D0
EEEE2@2ZZZX50820P0Cooooo1@1EEED50=GEe@@000001@0Z:RX905EEE@D0P820100Z:RX50=GEe@@0
P8202_ooool40=GEe@D0P820101EEED50820P0D0EEEE1?ooool5000000D0eMGE100000050820P0@0
EEEE1@00000502XZ:P@0ZZZZ1@0000060=7=Z@001@3AcJTPooooo`D0eMGE1Oooool4000000D0EEEE
103EeMD50820P0T0:RXZ1Oooool5000000@0:RXZ1Oooool90820P0D0ZZZZ100000050820P0@0EEEE
1@2ZZZX5000000T0:RXZ4P2ZZZX5000000Gooooo103EeMD50:ZZZQ80EEEE1Oooool40=GEe@kooooo
1@3EeMD4ooooo`D0P8201@3EeMD4ooooo`D0:RXZ1@20P80405EEE@D0:RXZ1000000502XZ:PD0EEEE
1?ooool50:ZZZPH0dLfY00050=7=ZB3ooooo1@3EeMD5ooooo`@000001@1EEED40=GEe@D0P8202@0Z
:RX5ooooo`D00000100Z:RX5ooooo`T0P8201@2ZZZX4000000D0P820101EEED50:ZZZPD000002@0Z
:RXB0:ZZZPD000001Oooool40=GEe@D0ZZZZ4P1EEED5ooooo`@0eMGE3_ooool50=GEe@Cooooo1@20
P8050=GEe@Cooooo1@0Z:RX50820P0@0EEEE1@0Z:RX4000000D0:RXZ1@1EEED4ooooo`D0ZZZZ1P3A
cJT000D0dLfY8?ooool50=GEe@Gooooo1000000505EEE@@0eMGE1@20P80902XZ:PGooooo1@000004
02XZ:PGooooo2@20P8050:ZZZP@000001@20P80405EEE@D0ZZZZ1@00000902XZ:Q80ZZZZ1@000005
ooooo`@0eMGE1@2ZZZXB05EEE@Gooooo103EeMD>ooooo`D0eMGE1?ooool50820P0D0eMGE1?ooool5
02XZ:PD0P820101EEED502XZ:P@000001@0Z:RX505EEE@Cooooo1@2ZZZX60=7=Z@001@3AcJTPoooo
o`D0eMGE1Oooool4000000D0EEEE103EeMD50820P0T0:RXZ1Oooool5000000@0:RXZ1Oooool90820
P0D0ZZZZ100000050820P0@0EEEE1@2ZZZX5000000T0:RXZ4P2ZZZX5000000Gooooo103EeMD50:ZZ
ZQ80EEEE1Oooool40=GEe@kooooo1@3EeMD4ooooo`D0P8201@3EeMD4ooooo`D0:RXZ1@20P80405EE
E@D0:RXZ1000000502XZ:PD0EEEE1?ooool50:ZZZPH0dLfY00050=7=ZB[ooooo100Z:RX50820P0@0
00001@20P8090=GEe@D000001@2ZZZX402XZ:PD0ZZZZ100Z:RX5000000D0EEEE2@20P8040=GEe@Go
oooo3P000004ooooo`D000001@20P80402XZ:PD0eMGE1@2ZZZX4ooooo`D0:RXZ10000005ooooo`D0
P820103EeMD502XZ:P@0EEEE1@2ZZZX5ooooo`@0EEEE1@0000040:ZZZPD0:RXZ1@0000040:ZZZPD0
00001@3EeMD4ooooo`D0P820102ZZZX502XZ:PD0P820103EeMD50820P0H0dLfY00050=7=ZB[ooooo
100Z:RX50820P0@000001@20P8090=GEe@D000001@2ZZZX402XZ:PD0ZZZZ100Z:RX5000000D0EEEE
2@20P8040=GEe@Gooooo3P000004ooooo`D000001@20P80402XZ:PD0eMGE1@2ZZZX4ooooo`D0:RXZ
10000005ooooo`D0P820103EeMD502XZ:P@0EEEE1@2ZZZX5ooooo`@0EEEE1@0000040:ZZZPD0:RXZ
1@0000040:ZZZPD000001@3EeMD4ooooo`D0P820102ZZZX502XZ:PD0P820103EeMD50820P0H0dLfY
00050=7=ZB[ooooo100Z:RX50820P0@000001@20P8090=GEe@D000001@2ZZZX402XZ:PD0ZZZZ100Z
:RX5000000D0EEEE2@20P8040=GEe@Gooooo3P000004ooooo`D000001@20P80402XZ:PD0eMGE1@2Z
ZZX4ooooo`D0:RXZ10000005ooooo`D0P820103EeMD502XZ:P@0EEEE1@2ZZZX5ooooo`@0EEEE1@00
00040:ZZZPD0:RXZ1@0000040:ZZZPD000001@3EeMD4ooooo`D0P820102ZZZX502XZ:PD0P820103E
eMD50820P0H0dLfY00050=7=ZB[ooooo100Z:RX50820P0@000001@20P8090=GEe@D000001@2ZZZX4
02XZ:PD0ZZZZ100Z:RX5000000D0EEEE2@20P8040=GEe@Gooooo3P000004ooooo`D000001@20P804
02XZ:PD0eMGE1@2ZZZX4ooooo`D0:RXZ10000005ooooo`D0P820103EeMD502XZ:P@0EEEE1@2ZZZX5
ooooo`@0EEEE1@0000040:ZZZPD0:RXZ1@0000040:ZZZPD000001@3EeMD4ooooo`D0P820102ZZZX5
02XZ:PD0P820103EeMD50820P0H0dLfY00050=7=ZB[ooooo100Z:RX50820P0@000001@20P8090=GE
e@D000001@2ZZZX402XZ:PD0ZZZZ100Z:RX5000000D0EEEE2@20P8040=GEe@Gooooo3P000004oooo
o`D000001@20P80402XZ:PD0eMGE1@2ZZZX4ooooo`D0:RXZ10000005ooooo`D0P820103EeMD502XZ
:P@0EEEE1@2ZZZX5ooooo`@0EEEE1@0000040:ZZZPD0:RXZ1@0000040:ZZZPD000001@3EeMD4oooo
o`D0P820102ZZZX502XZ:PD0P820103EeMD50820P0H0dLfY00050=7=ZBkooooo1@20P804000000D0
eMGE1@0Z:RX4ooooo`D0eMGE2@2ZZZX505EEE@@0P8201@2ZZZX502XZ:P@0ZZZZ1@20P804ooooo`D0
:RXZ1@1EEED4000000D0ZZZZ2Oooool905EEE@[ooooo100000050:ZZZP@0EEEE1@0Z:RX505EEE@@0
P8201@1EEED402XZ:PX0ZZZZ2@3EeMD90:ZZZPD0EEEE100Z:RX5000000D0eMGE2@20P80402XZ:PD0
00001@3EeMD4ooooo`D0eMGE1P3AcJT000D0dLfY;_ooool50820P0@000001@3EeMD502XZ:PCooooo
1@3EeMD90:ZZZPD0EEEE1020P8050:ZZZPD0:RXZ102ZZZX50820P0Cooooo1@0Z:RX505EEE@@00000
1@2ZZZX9ooooo`T0EEEE2_ooool4000000D0ZZZZ101EEED502XZ:PD0EEEE1020P80505EEE@@0:RXZ
2P2ZZZX90=GEe@T0ZZZZ1@1EEED402XZ:PD000001@3EeMD90820P0@0:RXZ1@0000050=GEe@Cooooo
1@3EeMD60=7=Z@001@3AcJT^ooooo`D0P820100000050=GEe@D0:RXZ1?ooool50=GEe@T0ZZZZ1@1E
EED40820P0D0ZZZZ1@0Z:RX40:ZZZPD0P8201?ooool502XZ:PD0EEEE100000050:ZZZPWooooo2@1E
EED:ooooo`@000001@2ZZZX405EEE@D0:RXZ1@1EEED40820P0D0EEEE100Z:RX:0:ZZZPT0eMGE2@2Z
ZZX505EEE@@0:RXZ1@0000050=GEe@T0P820100Z:RX5000000D0eMGE1?ooool50=GEe@H0dLfY0005
0=7=ZBkooooo1@20P804000000D0eMGE1@0Z:RX4ooooo`D0eMGE2@2ZZZX505EEE@@0P8201@2ZZZX5
02XZ:P@0ZZZZ1@20P804ooooo`D0:RXZ1@1EEED4000000D0ZZZZ2Oooool905EEE@[ooooo10000005
0:ZZZP@0EEEE1@0Z:RX505EEE@@0P8201@1EEED402XZ:PX0ZZZZ2@3EeMD90:ZZZPD0EEEE100Z:RX5
000000D0eMGE2@20P80402XZ:PD000001@3EeMD4ooooo`D0eMGE1P3AcJT000D0dLfY<oooool40:ZZ
ZPD0:RXZ1Oooool90820P0D0EEEE1020P805ooooo`@0P8201Oooool5000000T0:RXZ100000050:ZZ
ZPT0EEEE2@0Z:RX505EEE@D0eMGE1000000>ooooo`D0EEEE1020P8050=GEe@D00000100Z:RX50=GE
e@@000001Oooool5000000@0P8201@1EEED>0:ZZZP@0EEEE1Oooool505EEE@@0ZZZZ1@20P8040=GE
e@D0ZZZZ2Oooool502XZ:PH0dLfY00050=7=ZC?ooooo102ZZZX502XZ:PGooooo2@20P80505EEE@@0
P8201Oooool40820P0Gooooo1@00000902XZ:P@000001@2ZZZX905EEE@T0:RXZ1@1EEED50=GEe@@0
00003_ooool505EEE@@0P8201@3EeMD5000000@0:RXZ1@3EeMD4000000Gooooo1@0000040820P0D0
EEEE3P2ZZZX405EEE@Gooooo1@1EEED40:ZZZPD0P820103EeMD50:ZZZPWooooo1@0Z:RX60=7=Z@00
1@3AcJTcooooo`@0ZZZZ1@0Z:RX5ooooo`T0P8201@1EEED40820P0Gooooo1020P805ooooo`D00000
2@0Z:RX4000000D0ZZZZ2@1EEED902XZ:PD0EEEE1@3EeMD4000000kooooo1@1EEED40820P0D0eMGE
1@00000402XZ:PD0eMGE10000005ooooo`D000001020P80505EEE@h0ZZZZ101EEED5ooooo`D0EEEE
102ZZZX50820P0@0eMGE1@2ZZZX9ooooo`D0:RXZ1P3AcJT000D0dLfY<oooool40:ZZZPD0:RXZ1Ooo
ool90820P0D0EEEE1020P805ooooo`@0P8201Oooool5000000T0:RXZ100000050:ZZZPT0EEEE2@0Z
:RX505EEE@D0eMGE1000000>ooooo`D0EEEE1020P8050=GEe@D00000100Z:RX50=GEe@@000001Ooo
ool5000000@0P8201@1EEED>0:ZZZP@0EEEE1Oooool505EEE@@0ZZZZ1@20P8040=GEe@D0ZZZZ2Ooo
ool502XZ:PH0dLfY00050=7=ZC?ooooo102ZZZX502XZ:PGooooo2@20P80505EEE@@0P8201Oooool4
0820P0Gooooo1@00000902XZ:P@000001@2ZZZX905EEE@T0:RXZ1@1EEED50=GEe@@000003_ooool5
05EEE@@0P8201@3EeMD5000000@0:RXZ1@3EeMD4000000Gooooo1@0000040820P0D0EEEE3P2ZZZX4
05EEE@Gooooo1@1EEED40:ZZZPD0P820103EeMD50:ZZZPWooooo1@0Z:RX60=7=Z@001@3AcJTgoooo
o`D0eMGE1@0000040:ZZZPD0P8202@3EeMD9ooooo`D0ZZZZ1@3EeMD40:ZZZPD0EEEE100Z:RX50820
P0D0:RXZ102ZZZX505EEE@Cooooo1@20P805000000@0P8201@2ZZZX502XZ:P@0EEEE1@3EeMD402XZ
:PD000002@20P8090:ZZZP[ooooo101EEED50820P0@000001@20P80502XZ:P@0eMGE1Oooool502XZ
:Pd0ZZZZ1@0000090820P0D0EEEE1P3AcJT000D0dLfY=oooool50=GEe@D00000102ZZZX50820P0T0
eMGE2Oooool50:ZZZPD0eMGE102ZZZX505EEE@@0:RXZ1@20P80502XZ:P@0ZZZZ1@1EEED4ooooo`D0
P8201@0000040820P0D0ZZZZ1@0Z:RX405EEE@D0eMGE100Z:RX5000000T0P8202@2ZZZX:ooooo`@0
EEEE1@20P804000000D0P8201@0Z:RX40=GEe@Gooooo1@0Z:RX=0:ZZZPD000002@20P80505EEE@H0
dLfY00050=7=ZCOooooo1@3EeMD5000000@0ZZZZ1@20P8090=GEe@Wooooo1@2ZZZX50=GEe@@0ZZZZ
1@1EEED402XZ:PD0P8201@0Z:RX40:ZZZPD0EEEE1?ooool50820P0D000001020P8050:ZZZPD0:RXZ
101EEED50=GEe@@0:RXZ1@0000090820P0T0ZZZZ2_ooool405EEE@D0P820100000050820P0D0:RXZ
103EeMD5ooooo`D0:RXZ3@2ZZZX5000000T0P8201@1EEED60=7=Z@001@3AcJTgooooo`D0eMGE1@00
00040:ZZZPD0P8202@3EeMD9ooooo`D0ZZZZ1@3EeMD40:ZZZPD0EEEE100Z:RX50820P0D0:RXZ102Z
ZZX505EEE@Cooooo1@20P805000000@0P8201@2ZZZX502XZ:P@0EEEE1@3EeMD402XZ:PD000002@20
P8090:ZZZP[ooooo101EEED50820P0@000001@20P80502XZ:P@0eMGE1Oooool502XZ:Pd0ZZZZ1@00
00090820P0D0EEEE1P3AcJT000D0dLfY=oooool50=GEe@D00000102ZZZX50820P0T0eMGE2Oooool5
0:ZZZPD0eMGE102ZZZX505EEE@@0:RXZ1@20P80502XZ:P@0ZZZZ1@1EEED4ooooo`D0P8201@000004
0820P0D0ZZZZ1@0Z:RX405EEE@D0eMGE100Z:RX5000000T0P8202@2ZZZX:ooooo`@0EEEE1@20P804
000000D0P8201@0Z:RX40=GEe@Gooooo1@0Z:RX=0:ZZZPD000002@20P80505EEE@H0dLfY00050=7=
ZCcooooo1@3EeMD>0:ZZZP@000001@2ZZZX402XZ:PD0EEEE1@2ZZZX4000000D0P8201000000502XZ
:PD00000100Z:RX5000000Wooooo1@2ZZZX402XZ:PD0eMGE1@1EEED402XZ:PD0ZZZZ103EeMD:0000
00@0EEEE1@20P80402XZ:PGooooo1@1EEED4000000D0:RXZ102ZZZX5ooooo`D0ZZZZ101EEED50:ZZ
ZPT0eMGE1@1EEED40820P0Gooooo1@1EEED40820P0D000001P3AcJT000D0dLfY??ooool50=GEe@h0
ZZZZ100000050:ZZZP@0:RXZ1@1EEED50:ZZZP@000001@20P804000000D0:RXZ1@00000402XZ:PD0
00002Oooool50:ZZZP@0:RXZ1@3EeMD505EEE@@0:RXZ1@2ZZZX40=GEe@X00000101EEED50820P0@0
:RXZ1Oooool505EEE@@000001@0Z:RX40:ZZZPGooooo1@2ZZZX405EEE@D0ZZZZ2@3EeMD505EEE@@0
P8201Oooool505EEE@@0P8201@0000060=7=Z@001@3AcJTlooooo`D0eMGE3P2ZZZX4000000D0ZZZZ
100Z:RX505EEE@D0ZZZZ100000050820P0@000001@0Z:RX5000000@0:RXZ1@000009ooooo`D0ZZZZ
100Z:RX50=GEe@D0EEEE100Z:RX50:ZZZP@0eMGE2P00000405EEE@D0P820100Z:RX5ooooo`D0EEEE
1000000502XZ:P@0ZZZZ1Oooool50:ZZZP@0EEEE1@2ZZZX90=GEe@D0EEEE1020P805ooooo`D0EEEE
1020P805000000H0dLfY00050=7=ZCcooooo1@3EeMD>0:ZZZP@000001@2ZZZX402XZ:PD0EEEE1@2Z
ZZX4000000D0P8201000000502XZ:PD00000100Z:RX5000000Wooooo1@2ZZZX402XZ:PD0eMGE1@1E
EED402XZ:PD0ZZZZ103EeMD:000000@0EEEE1@20P80402XZ:PGooooo1@1EEED4000000D0:RXZ102Z
ZZX5ooooo`D0ZZZZ101EEED50:ZZZPT0eMGE1@1EEED40820P0Gooooo1@1EEED40820P0D000001P3A
cJT000D0dLfYAOooool5000000D0P820100Z:RX50820P0@0:RXZ1@20P8050=GEe@@0EEEE1@0Z:RX>
000000@0eMGE2@0000050:ZZZPGooooo1000000:02XZ:P@0ZZZZ1@1EEED40:ZZZPh000001@0Z:RX4
0=GEe@D000001@2ZZZX405EEE@T0eMGE1@1EEED50=GEe@T0EEEE1@2ZZZX4000000D0P820103EeMD5
05EEE@D00000100Z:RX50:ZZZPH0dLfY00050=7=ZDGooooo1@0000050820P0@0:RXZ1@20P80402XZ
:PD0P8201@3EeMD405EEE@D0:RXZ3P0000040=GEe@T000001@2ZZZX5ooooo`@000002P0Z:RX40:ZZ
ZPD0EEEE102ZZZX>000000D0:RXZ103EeMD5000000D0ZZZZ101EEED90=GEe@D0EEEE1@3EeMD905EE
E@D0ZZZZ100000050820P0@0eMGE1@1EEED5000000@0:RXZ1@2ZZZX60=7=Z@001@3AcJU5ooooo`D0
00001@20P80402XZ:PD0P820100Z:RX50820P0D0eMGE101EEED502XZ:Ph00000103EeMD9000000D0
ZZZZ1Oooool4000000X0:RXZ102ZZZX505EEE@@0ZZZZ3P00000502XZ:P@0eMGE1@0000050:ZZZP@0
EEEE2@3EeMD505EEE@D0eMGE2@1EEED50:ZZZP@000001@20P8040=GEe@D0EEEE1@00000402XZ:PD0
ZZZZ1P3AcJT000D0dLfYAOooool5000000D0P820100Z:RX50820P0@0:RXZ1@20P8050=GEe@@0EEEE
1@0Z:RX>000000@0eMGE2@0000050:ZZZPGooooo1000000:02XZ:P@0ZZZZ1@1EEED40:ZZZPh00000
1@0Z:RX40=GEe@D000001@2ZZZX405EEE@T0eMGE1@1EEED50=GEe@T0EEEE1@2ZZZX4000000D0P820
103EeMD505EEE@D00000100Z:RX50:ZZZPH0dLfY00050=7=ZDGooooo1@0000050820P0@0:RXZ1@20
P80402XZ:PD0P8201@3EeMD405EEE@D0:RXZ3P0000040=GEe@T000001@2ZZZX5ooooo`@000002P0Z
:RX40:ZZZPD0EEEE102ZZZX>000000D0:RXZ103EeMD5000000D0ZZZZ101EEED90=GEe@D0EEEE1@3E
eMD905EEE@D0ZZZZ100000050820P0@0eMGE1@1EEED5000000@0:RXZ1@2ZZZX60=7=Z@001@3AcJU:
ooooo`T0EEEE1Oooool40:ZZZPD0EEEE1@20P80905EEE@@0:RXZ1@1EEED50=GEe@T0ZZZZ1?ooool5
05EEE@D0ZZZZ100000050=GEe@D00000100Z:RX5000000Cooooo1@2ZZZX5ooooo`@0EEEE1@000004
ooooo`D000001@3EeMD905EEE@@0ZZZZ1@3EeMD902XZ:PD0ZZZZ1@20P80402XZ:PD0P8202@0Z:RX5
0:ZZZP@0:RXZ1@20P8060=7=Z@001@3AcJU:ooooo`T0EEEE1Oooool40:ZZZPD0EEEE1@20P80905EE
E@@0:RXZ1@1EEED50=GEe@T0ZZZZ1?ooool505EEE@D0ZZZZ100000050=GEe@D00000100Z:RX50000
00Cooooo1@2ZZZX5ooooo`@0EEEE1@000004ooooo`D000001@3EeMD905EEE@@0ZZZZ1@3EeMD902XZ
:PD0ZZZZ1@20P80402XZ:PD0P8202@0Z:RX50:ZZZP@0:RXZ1@20P8060=7=Z@001@3AcJU:ooooo`T0
EEEE1Oooool40:ZZZPD0EEEE1@20P80905EEE@@0:RXZ1@1EEED50=GEe@T0ZZZZ1?ooool505EEE@D0
ZZZZ100000050=GEe@D00000100Z:RX5000000Cooooo1@2ZZZX5ooooo`@0EEEE1@000004ooooo`D0
00001@3EeMD905EEE@@0ZZZZ1@3EeMD902XZ:PD0ZZZZ1@20P80402XZ:PD0P8202@0Z:RX50:ZZZP@0
:RXZ1@20P8060=7=Z@001@3AcJU:ooooo`T0EEEE1Oooool40:ZZZPD0EEEE1@20P80905EEE@@0:RXZ
1@1EEED50=GEe@T0ZZZZ1?ooool505EEE@D0ZZZZ100000050=GEe@D00000100Z:RX5000000Cooooo
1@2ZZZX5ooooo`@0EEEE1@000004ooooo`D000001@3EeMD905EEE@@0ZZZZ1@3EeMD902XZ:PD0ZZZZ
1@20P80402XZ:PD0P8202@0Z:RX50:ZZZP@0:RXZ1@20P8060=7=Z@001@3AcJU?ooooo`@0P8201@3E
eMD40820P0Gooooo1@20P80B0=GEe@T0:RXZ1Oooool4000000D0ZZZZ1@20P80402XZ:PD0P8201@1E
EED4000000D0eMGE102ZZZX5ooooo`D00000102ZZZX505EEE@Cooooo1@0Z:RX50820P0d0EEEE1@2Z
ZZX9000000Gooooo1@00000405EEE@D0:RXZ103EeMD5000000D0:RXZ100000050=GEe@H0dLfY0005
0=7=ZDoooooo1020P8050=GEe@@0P8201Oooool50820P180eMGE2@0Z:RX5ooooo`@000001@2ZZZX5
0820P0@0:RXZ1@20P80505EEE@@000001@3EeMD40:ZZZPGooooo1@0000040:ZZZPD0EEEE1?ooool5
02XZ:PD0P8203@1EEED50:ZZZPT000001Oooool5000000@0EEEE1@0Z:RX40=GEe@D000001@0Z:RX4
000000D0eMGE1P3AcJT000D0dLfYCoooool40820P0D0eMGE1020P805ooooo`D0P8204P3EeMD902XZ
:PGooooo100000050:ZZZPD0P820100Z:RX50820P0D0EEEE100000050=GEe@@0ZZZZ1Oooool50000
00@0ZZZZ1@1EEED4ooooo`D0:RXZ1@20P80=05EEE@D0ZZZZ2@000005ooooo`D00000101EEED502XZ
:P@0eMGE1@00000502XZ:P@000001@3EeMD60=7=Z@001@3AcJU?ooooo`@0P8201@3EeMD40820P0Go
oooo1@20P80B0=GEe@T0:RXZ1Oooool4000000D0ZZZZ1@20P80402XZ:PD0P8201@1EEED4000000D0
eMGE102ZZZX5ooooo`D00000102ZZZX505EEE@Cooooo1@0Z:RX50820P0d0EEEE1@2ZZZX9000000Go
oooo1@00000405EEE@D0:RXZ103EeMD5000000D0:RXZ100000050=GEe@H0dLfY00050=7=ZDoooooo
1020P8050=GEe@@0P8201Oooool50820P180eMGE2@0Z:RX5ooooo`@000001@2ZZZX50820P0@0:RXZ
1@20P80505EEE@@000001@3EeMD40:ZZZPGooooo1@0000040:ZZZPD0EEEE1?ooool502XZ:PD0P820
3@1EEED50:ZZZPT000001Oooool5000000@0EEEE1@0Z:RX40=GEe@D000001@0Z:RX4000000D0eMGE
1P3AcJT000D0dLfYDoooool50:ZZZP@0eMGE1@1EEED5000000@0EEEE1@2ZZZX40=GEe@D0P8201@1E
EED402XZ:PD0ZZZZ100000050=GEe@T0EEEE1Oooool50:ZZZP@0EEEE1Oooool902XZ:PD0EEEE100Z
:RX5000000Wooooo1@20P804000000Gooooo1020P8050=GEe@D0EEEE100000050=GEe@T0P8201@3E
eMD4000000X0P820102ZZZX502XZ:PH0dLfY00050=7=ZE?ooooo1@2ZZZX40=GEe@D0EEEE1@000004
05EEE@D0ZZZZ103EeMD50820P0D0EEEE100Z:RX50:ZZZP@000001@3EeMD905EEE@Gooooo1@2ZZZX4
05EEE@Gooooo2@0Z:RX505EEE@@0:RXZ1@000009ooooo`D0P82010000005ooooo`@0P8201@3EeMD5
05EEE@@000001@3EeMD90820P0D0eMGE1000000:0820P0@0ZZZZ1@0Z:RX60=7=Z@001@3AcJUCoooo
o`D0ZZZZ103EeMD505EEE@D00000101EEED50:ZZZP@0eMGE1@20P80505EEE@@0:RXZ1@2ZZZX40000
00D0eMGE2@1EEED5ooooo`D0ZZZZ101EEED5ooooo`T0:RXZ1@1EEED402XZ:PD000002Oooool50820
P0@000001Oooool40820P0D0eMGE1@1EEED4000000D0eMGE2@20P8050=GEe@@000002P20P8040:ZZ
ZPD0:RXZ1P3AcJT000D0dLfYDoooool50:ZZZP@0eMGE1@1EEED5000000@0EEEE1@2ZZZX40=GEe@D0
P8201@1EEED402XZ:PD0ZZZZ100000050=GEe@T0EEEE1Oooool50:ZZZP@0EEEE1Oooool902XZ:PD0
EEEE100Z:RX5000000Wooooo1@20P804000000Gooooo1020P8050=GEe@D0EEEE100000050=GEe@T0
P8201@3EeMD4000000X0P820102ZZZX502XZ:PH0dLfY00050=7=ZESooooo103EeMD50820P0T00000
1@0Z:RX4ooooo`D0:RXZ1@00000402XZ:PD0P8201?ooool505EEE@D0ZZZZ1020P805000000T0ZZZZ
1@20P80405EEE@Gooooo1@20P809000000@0eMGE1@2ZZZX502XZ:PT000002@2ZZZX5000000@0:RXZ
1@20P80505EEE@@0P8202@0Z:RX50820P0D0:RXZ1000000505EEE@H0dLfY00050=7=ZESooooo103E
eMD50820P0T000001@0Z:RX4ooooo`D0:RXZ1@00000402XZ:PD0P8201?ooool505EEE@D0ZZZZ1020
P805000000T0ZZZZ1@20P80405EEE@Gooooo1@20P809000000@0eMGE1@2ZZZX502XZ:PT000002@2Z
ZZX5000000@0:RXZ1@20P80505EEE@@0P8202@0Z:RX50820P0D0:RXZ1000000505EEE@H0dLfY0005
0=7=ZESooooo103EeMD50820P0T000001@0Z:RX4ooooo`D0:RXZ1@00000402XZ:PD0P8201?ooool5
05EEE@D0ZZZZ1020P805000000T0ZZZZ1@20P80405EEE@Gooooo1@20P809000000@0eMGE1@2ZZZX5
02XZ:PT000002@2ZZZX5000000@0:RXZ1@20P80505EEE@@0P8202@0Z:RX50820P0D0:RXZ10000005
05EEE@H0dLfY00050=7=ZESooooo103EeMD50820P0T000001@0Z:RX4ooooo`D0:RXZ1@00000402XZ
:PD0P8201?ooool505EEE@D0ZZZZ1020P805000000T0ZZZZ1@20P80405EEE@Gooooo1@20P8090000
00@0eMGE1@2ZZZX502XZ:PT000002@2ZZZX5000000@0:RXZ1@20P80505EEE@@0P8202@0Z:RX50820
P0D0:RXZ1000000505EEE@H0dLfY00050=7=ZESooooo103EeMD50820P0T000001@0Z:RX4ooooo`D0
:RXZ1@00000402XZ:PD0P8201?ooool505EEE@D0ZZZZ1020P805000000T0ZZZZ1@20P80405EEE@Go
oooo1@20P809000000@0eMGE1@2ZZZX502XZ:PT000002@2ZZZX5000000@0:RXZ1@20P80505EEE@@0
P8202@0Z:RX50820P0D0:RXZ1000000505EEE@H0dLfY00050=7=ZEcooooo1@3EeMD5ooooo`@0EEEE
1@000004ooooo`D0:RXZ2@20P8090:ZZZPD000001Oooool40=GEe@D0:RXZ1@20P80402XZ:PD0eMGE
1?ooool50:ZZZPD0:RXZ3@0000050820P0Gooooo101EEED50=GEe@h0ZZZZ100Z:RX50820P0T0eMGE
1Oooool405EEE@Gooooo1@2ZZZX405EEE@D000001P3AcJT000D0dLfYG?ooool50=GEe@Gooooo101E
EED5000000Cooooo1@0Z:RX90820P0T0ZZZZ1@000005ooooo`@0eMGE1@0Z:RX50820P0@0:RXZ1@3E
eMD4ooooo`D0ZZZZ1@0Z:RX=000000D0P8201Oooool405EEE@D0eMGE3P2ZZZX402XZ:PD0P8202@3E
eMD5ooooo`@0EEEE1Oooool50:ZZZP@0EEEE1@0000060=7=Z@001@3AcJULooooo`D0eMGE1Oooool4
05EEE@D000001?ooool502XZ:PT0P8202@2ZZZX5000000Gooooo103EeMD502XZ:PD0P820100Z:RX5
0=GEe@Cooooo1@2ZZZX502XZ:Pd000001@20P805ooooo`@0EEEE1@3EeMD>0:ZZZP@0:RXZ1@20P809
0=GEe@Gooooo101EEED5ooooo`D0ZZZZ101EEED5000000H0dLfY00050=7=ZEcooooo1@3EeMD5oooo
o`@0EEEE1@000004ooooo`D0:RXZ2@20P8090:ZZZPD000001Oooool40=GEe@D0:RXZ1@20P80402XZ
:PD0eMGE1?ooool50:ZZZPD0:RXZ3@0000050820P0Gooooo101EEED50=GEe@h0ZZZZ100Z:RX50820
P0T0eMGE1Oooool405EEE@Gooooo1@2ZZZX405EEE@D000001P3AcJT000D0dLfYG?ooool50=GEe@Go
oooo101EEED5000000Cooooo1@0Z:RX90820P0T0ZZZZ1@000005ooooo`@0eMGE1@0Z:RX50820P0@0
:RXZ1@3EeMD4ooooo`D0ZZZZ1@0Z:RX=000000D0P8201Oooool405EEE@D0eMGE3P2ZZZX402XZ:PD0
P8202@3EeMD5ooooo`@0EEEE1Oooool50:ZZZP@0EEEE1@0000060=7=Z@001@3AcJUVooooo`@0:RXZ
1@2ZZZX405EEE@D000001@0Z:RX4000000D0EEEE1020P805ooooo`D0EEEE103EeMD505EEE@Gooooo
102ZZZX505EEE@@0ZZZZ1Oooool9000000D0ZZZZ1?ooool505EEE@T0P8201@0000040820P0Gooooo
1@3EeMD405EEE@D0:RXZ1@3EeMD40820P0D0EEEE103EeMD502XZ:PD0EEEE1020P8050:ZZZPH0dLfY
00050=7=ZFKooooo100Z:RX50:ZZZP@0EEEE1@00000502XZ:P@000001@1EEED40820P0Gooooo1@1E
EED40=GEe@D0EEEE1Oooool40:ZZZPD0EEEE102ZZZX5ooooo`T000001@2ZZZX4ooooo`D0EEEE2@20
P805000000@0P8201Oooool50=GEe@@0EEEE1@0Z:RX50=GEe@@0P8201@1EEED40=GEe@D0:RXZ1@1E
EED40820P0D0ZZZZ1P3AcJT000D0dLfYI_ooool402XZ:PD0ZZZZ101EEED5000000D0:RXZ10000005
05EEE@@0P8201Oooool505EEE@@0eMGE1@1EEED5ooooo`@0ZZZZ1@1EEED40:ZZZPGooooo2@000005
0:ZZZPCooooo1@1EEED90820P0D000001020P805ooooo`D0eMGE101EEED502XZ:PD0eMGE1020P805
05EEE@@0eMGE1@0Z:RX505EEE@@0P8201@2ZZZX60=7=Z@001@3AcJUVooooo`@0:RXZ1@2ZZZX405EE
E@D000001@0Z:RX4000000D0EEEE1020P805ooooo`D0EEEE103EeMD505EEE@Gooooo102ZZZX505EE
E@@0ZZZZ1Oooool9000000D0ZZZZ1?ooool505EEE@T0P8201@0000040820P0Gooooo1@3EeMD405EE
E@D0:RXZ1@3EeMD40820P0D0EEEE103EeMD502XZ:PD0EEEE1020P8050:ZZZPH0dLfY00050=7=ZF[o
oooo1@20P80402XZ:PD0ZZZZ1@0Z:RX90820P0@0eMGE1@1EEED5000000@0:RXZ1Oooool50:ZZZP@0
:RXZ1@000004ooooo`D0eMGE3P20P809ooooo`D0P820103EeMD5ooooo`@0EEEE2P20P80905EEE@D0
:RXZ1?ooool50:ZZZP@0P8201@1EEED502XZ:P@0ZZZZ1@20P8060=7=Z@001@3AcJUZooooo`D0P820
100Z:RX50:ZZZPD0:RXZ2@20P8040=GEe@D0EEEE1@00000402XZ:PGooooo1@2ZZZX402XZ:PD00000
1?ooool50=GEe@h0P8202Oooool50820P0@0eMGE1Oooool405EEE@X0P8202@1EEED502XZ:PCooooo
1@2ZZZX40820P0D0EEEE1@0Z:RX40:ZZZPD0P8201P3AcJT000D0dLfYJ_ooool50820P0@0:RXZ1@2Z
ZZX502XZ:PT0P820103EeMD505EEE@D00000100Z:RX5ooooo`D0ZZZZ100Z:RX5000000Cooooo1@3E
eMD>0820P0Wooooo1@20P8040=GEe@Gooooo101EEED:0820P0T0EEEE1@0Z:RX4ooooo`D0ZZZZ1020
P80505EEE@D0:RXZ102ZZZX50820P0H0dLfY00050=7=ZF[ooooo1@20P80402XZ:PD0ZZZZ1@0Z:RX9
0820P0@0eMGE1@1EEED5000000@0:RXZ1Oooool50:ZZZP@0:RXZ1@000004ooooo`D0eMGE3P20P809
ooooo`D0P820103EeMD5ooooo`@0EEEE2P20P80905EEE@D0:RXZ1?ooool50:ZZZP@0P8201@1EEED5
02XZ:P@0ZZZZ1@20P8060=7=Z@001@3AcJUZooooo`D0P820100Z:RX50:ZZZPD0:RXZ2@20P8040=GE
e@D0EEEE1@00000402XZ:PGooooo1@2ZZZX402XZ:PD000001?ooool50=GEe@h0P8202Oooool50820
P0@0eMGE1Oooool405EEE@X0P8202@1EEED502XZ:PCooooo1@2ZZZX40820P0D0EEEE1@0Z:RX40:ZZ
ZPD0P8201P3AcJT000D0dLfYKoooool40:ZZZPD0EEEE1@20P8040:ZZZPD0P8201?ooool5000000Go
oooo2@1EEED5000000@0EEEE1Oooool405EEE@D0eMGE1@20P80402XZ:PD00000101EEED50=GEe@D0
P8201?ooool502XZ:PT0EEEE1@20P804000000Gooooo1@20P8040:ZZZPGooooo1000000:05EEE@@0
:RXZ1@3EeMD60=7=Z@001@3AcJU_ooooo`@0ZZZZ1@1EEED50820P0@0ZZZZ1@20P804ooooo`D00000
1Oooool905EEE@D00000101EEED5ooooo`@0EEEE1@3EeMD50820P0@0:RXZ1@00000405EEE@D0eMGE
1@20P804ooooo`D0:RXZ2@1EEED50820P0@000001Oooool50820P0@0ZZZZ1Oooool4000000X0EEEE
100Z:RX50=GEe@H0dLfY00050=7=ZFoooooo102ZZZX505EEE@D0P820102ZZZX50820P0Cooooo1@00
0005ooooo`T0EEEE1@00000405EEE@Gooooo101EEED50=GEe@D0P820100Z:RX5000000@0EEEE1@3E
eMD50820P0Cooooo1@0Z:RX905EEE@D0P82010000005ooooo`D0P820102ZZZX5ooooo`@000002P1E
EED402XZ:PD0eMGE1P3AcJT000D0dLfYKoooool40:ZZZPD0EEEE1@20P8040:ZZZPD0P8201?ooool5
000000Gooooo2@1EEED5000000@0EEEE1Oooool405EEE@D0eMGE1@20P80402XZ:PD00000101EEED5
0=GEe@D0P8201?ooool502XZ:PT0EEEE1@20P804000000Gooooo1@20P8040:ZZZPGooooo1000000:
05EEE@@0:RXZ1@3EeMD60=7=Z@001@3AcJUcooooo`D0eMGE1@0Z:RX4000000D0P820100Z:RX505EE
E@D0:RXZ3P1EEED4000000Wooooo1@2ZZZX5000000@0EEEE1@0Z:RX40820P0D000001@20P804oooo
o`D0:RXZ1020P8050=GEe@D0:RXZ2@0000050:ZZZP@0P8202Oooool>05EEE@D0:RXZ1P3AcJT000D0
dLfYLoooool50=GEe@D0:RXZ100000050820P0@0:RXZ1@1EEED502XZ:Ph0EEEE10000009ooooo`D0
ZZZZ1@00000405EEE@D0:RXZ1020P805000000D0P8201?ooool502XZ:P@0P8201@3EeMD502XZ:PT0
00001@2ZZZX40820P0Wooooo3P1EEED502XZ:PH0dLfY00050=7=ZG?ooooo1@3EeMD502XZ:P@00000
1@20P80402XZ:PD0EEEE1@0Z:RX>05EEE@@000002Oooool50:ZZZPD00000101EEED502XZ:P@0P820
1@0000050820P0Cooooo1@0Z:RX40820P0D0eMGE1@0Z:RX9000000D0ZZZZ1020P809ooooo`h0EEEE
1@0Z:RX60=7=Z@001@3AcJUcooooo`D0eMGE1@0Z:RX4000000D0P820100Z:RX505EEE@D0:RXZ3P1E
EED4000000Wooooo1@2ZZZX5000000@0EEEE1@0Z:RX40820P0D000001@20P804ooooo`D0:RXZ1020
P8050=GEe@D0:RXZ2@0000050:ZZZP@0P8202Oooool>05EEE@D0:RXZ1P3AcJT000D0dLfYLoooool5
0=GEe@D0:RXZ100000050820P0@0:RXZ1@1EEED502XZ:Ph0EEEE10000009ooooo`D0ZZZZ1@000004
05EEE@D0:RXZ1020P805000000D0P8201?ooool502XZ:P@0P8201@3EeMD502XZ:PT000001@2ZZZX4
0820P0Wooooo3P1EEED502XZ:PH0dLfY00050=7=ZGSooooo1@3EeMD40:ZZZPGooooo102ZZZX:05EE
E@@0:RXZ1@2ZZZX50820P0T00000102ZZZX5ooooo`T000001@0Z:RX40820P0D0eMGE2@2ZZZX50000
00@0eMGE1Oooool50=GEe@@0ZZZZ1Oooool505EEE@@0P8201Oooool405EEE@D000001@0Z:RX40:ZZ
ZPD0EEEE1P3AcJT000D0dLfYN?ooool50=GEe@@0ZZZZ1Oooool40:ZZZPX0EEEE100Z:RX50:ZZZPD0
P8202@0000040:ZZZPGooooo2@00000502XZ:P@0P8201@3EeMD90:ZZZPD00000103EeMD5ooooo`D0
eMGE102ZZZX5ooooo`D0EEEE1020P805ooooo`@0EEEE1@00000502XZ:P@0ZZZZ1@1EEED60=7=Z@00
1@3AcJUhooooo`D0eMGE102ZZZX5ooooo`@0ZZZZ2P1EEED402XZ:PD0ZZZZ1@20P809000000@0ZZZZ
1Oooool9000000D0:RXZ1020P8050=GEe@T0ZZZZ1@0000040=GEe@Gooooo1@3EeMD40:ZZZPGooooo
1@1EEED40820P0Gooooo101EEED5000000D0:RXZ102ZZZX505EEE@H0dLfY00050=7=ZGSooooo1@3E
eMD40:ZZZPGooooo102ZZZX:05EEE@@0:RXZ1@2ZZZX50820P0T00000102ZZZX5ooooo`T000001@0Z
:RX40820P0D0eMGE2@2ZZZX5000000@0eMGE1Oooool50=GEe@@0ZZZZ1Oooool505EEE@@0P8201Ooo
ool405EEE@D000001@0Z:RX40:ZZZPD0EEEE1P3AcJT000D0dLfYPOooool5000000T0ZZZZ1@20P804
000000X0:RXZ3@0000050820P0D0EEEE103EeMD50:ZZZP@0EEEE1@20P80505EEE@@0P8201Oooool4
05EEE@D0ZZZZ1Oooool902XZ:PT0EEEE2@20P80:000000@0:RXZ1@0000060=7=Z@001@3AcJV1oooo
o`D000002@2ZZZX50820P0@000002P0Z:RX=000000D0P8201@1EEED40=GEe@D0ZZZZ101EEED50820
P0D0EEEE1020P805ooooo`@0EEEE1@2ZZZX5ooooo`T0:RXZ2@1EEED90820P0X00000100Z:RX50000
00H0dLfY00050=7=ZH7ooooo1@0000090:ZZZPD0P8201000000:02XZ:Pd000001@20P80505EEE@@0
eMGE1@2ZZZX405EEE@D0P8201@1EEED40820P0Gooooo101EEED50:ZZZPGooooo2@0Z:RX905EEE@T0
P8202P00000402XZ:PD000001P3AcJT000D0dLfYPOooool5000000T0ZZZZ1@20P804000000X0:RXZ
3@0000050820P0D0EEEE103EeMD50:ZZZP@0EEEE1@20P80505EEE@@0P8201Oooool405EEE@D0ZZZZ
1Oooool902XZ:PT0EEEE2@20P80:000000@0:RXZ1@0000060=7=Z@001@3AcJV1ooooo`D000002@2Z
ZZX50820P0@000002P0Z:RX=000000D0P8201@1EEED40=GEe@D0ZZZZ101EEED50820P0D0EEEE1020
P805ooooo`@0EEEE1@2ZZZX5ooooo`T0:RXZ2@1EEED90820P0X00000100Z:RX5000000H0dLfY0005
0=7=ZHKooooo101EEED50820P0Gooooo102ZZZX502XZ:PD0P820102ZZZX502XZ:P@0EEEE1@3EeMD5
ooooo`@0ZZZZ1@0000040820P0D000002@1EEED90820P0D000001@20P80405EEE@Gooooo1@20P804
000000D0:RXZ103EeMD502XZ:PD0EEEE103EeMD50:ZZZPH0dLfY00050=7=ZHKooooo101EEED50820
P0Gooooo102ZZZX502XZ:PD0P820102ZZZX502XZ:P@0EEEE1@3EeMD5ooooo`@0ZZZZ1@0000040820
P0D000002@1EEED90820P0D000001@20P80405EEE@Gooooo1@20P804000000D0:RXZ103EeMD502XZ
:PD0EEEE103EeMD50:ZZZPH0dLfY00050=7=ZHKooooo101EEED50820P0Gooooo102ZZZX502XZ:PD0
P820102ZZZX502XZ:P@0EEEE1@3EeMD5ooooo`@0ZZZZ1@0000040820P0D000002@1EEED90820P0D0
00001@20P80405EEE@Gooooo1@20P804000000D0:RXZ103EeMD502XZ:PD0EEEE103EeMD50:ZZZPH0
dLfY00050=7=ZHKooooo101EEED50820P0Gooooo102ZZZX502XZ:PD0P820102ZZZX502XZ:P@0EEEE
1@3EeMD5ooooo`@0ZZZZ1@0000040820P0D000002@1EEED90820P0D000001@20P80405EEE@Gooooo
1@20P804000000D0:RXZ103EeMD502XZ:PD0EEEE103EeMD50:ZZZPH0dLfY00050=7=ZHKooooo101E
EED50820P0Gooooo102ZZZX502XZ:PD0P820102ZZZX502XZ:P@0EEEE1@3EeMD5ooooo`@0ZZZZ1@00
00040820P0D000002@1EEED90820P0D000001@20P80405EEE@Gooooo1@20P804000000D0:RXZ103E
eMD502XZ:PD0EEEE103EeMD50:ZZZPH0dLfY00050=7=ZH[ooooo1@20P805ooooo`@0:RXZ2P3EeMD4
02XZ:PT0eMGE1@0Z:RX505EEE@@000001@1EEED40=GEe@Gooooo3P1EEED40820P0D000001@3EeMD4
02XZ:PD0ZZZZ1@3EeMD4ooooo`D0EEEE100Z:RX5ooooo`D0P820100000050820P0H0dLfY00050=7=
ZH[ooooo1@20P805ooooo`@0:RXZ2P3EeMD402XZ:PT0eMGE1@0Z:RX505EEE@@000001@1EEED40=GE
e@Gooooo3P1EEED40820P0D000001@3EeMD402XZ:PD0ZZZZ1@3EeMD4ooooo`D0EEEE100Z:RX5oooo
o`D0P820100000050820P0H0dLfY00050=7=ZH[ooooo1@20P805ooooo`@0:RXZ2P3EeMD402XZ:PT0
eMGE1@0Z:RX505EEE@@000001@1EEED40=GEe@Gooooo3P1EEED40820P0D000001@3EeMD402XZ:PD0
ZZZZ1@3EeMD4ooooo`D0EEEE100Z:RX5ooooo`D0P820100000050820P0H0dLfY00050=7=ZH[ooooo
1@20P805ooooo`@0:RXZ2P3EeMD402XZ:PT0eMGE1@0Z:RX505EEE@@000001@1EEED40=GEe@Gooooo
3P1EEED40820P0D000001@3EeMD402XZ:PD0ZZZZ1@3EeMD4ooooo`D0EEEE100Z:RX5ooooo`D0P820
100000050820P0H0dLfY00050=7=ZHoooooo1@2ZZZX90=GEe@D0P820101EEED502XZ:PCooooo2P3E
eMD4000000D0eMGE100Z:RX505EEE@D00000100Z:RX50:ZZZP@0P8201@0000050=GEe@@0EEEE1Ooo
ool50=GEe@T0P8201000000502XZ:PT0EEEE1@3EeMD60=7=Z@001@3AcJV?ooooo`D0ZZZZ2@3EeMD5
0820P0@0EEEE1@0Z:RX4ooooo`X0eMGE100000050=GEe@@0:RXZ1@1EEED5000000@0:RXZ1@2ZZZX4
0820P0D000001@3EeMD405EEE@Gooooo1@3EeMD90820P0@000001@0Z:RX905EEE@D0eMGE1P3AcJT0
00D0dLfYSoooool50:ZZZPT0eMGE1@20P80405EEE@D0:RXZ1?ooool:0=GEe@@000001@3EeMD402XZ
:PD0EEEE1@00000402XZ:PD0ZZZZ1020P805000000D0eMGE101EEED5ooooo`D0eMGE2@20P8040000
00D0:RXZ2@1EEED50=GEe@H0dLfY00050=7=ZHoooooo1@2ZZZX90=GEe@D0P820101EEED502XZ:PCo
oooo2P3EeMD4000000D0eMGE100Z:RX505EEE@D00000100Z:RX50:ZZZP@0P8201@0000050=GEe@@0
EEEE1Oooool50=GEe@T0P8201000000502XZ:PT0EEEE1@3EeMD60=7=Z@001@3AcJV?ooooo`D0ZZZZ
2@3EeMD50820P0@0EEEE1@0Z:RX4ooooo`X0eMGE100000050=GEe@@0:RXZ1@1EEED5000000@0:RXZ
1@2ZZZX40820P0D000001@3EeMD405EEE@Gooooo1@3EeMD90820P0@000001@0Z:RX905EEE@D0eMGE
1P3AcJT000D0dLfYU?ooool40=GEe@D0P8201@1EEED40820P0D00000100Z:RX505EEE@T0ZZZZ1Ooo
ool90=GEe@D00000103EeMD5000000@0P8201@0000050=GEe@@0P8201@0000050:ZZZP@0eMGE1@0Z
:RX40:ZZZPGooooo1@20P804000000D0:RXZ1P3AcJT000D0dLfYU?ooool40=GEe@D0P8201@1EEED4
0820P0D00000100Z:RX505EEE@T0ZZZZ1Oooool90=GEe@D00000103EeMD5000000@0P8201@000005
0=GEe@@0P8201@0000050:ZZZP@0eMGE1@0Z:RX40:ZZZPGooooo1@20P804000000D0:RXZ1P3AcJT0
00D0dLfYU?ooool40=GEe@D0P8201@1EEED40820P0D00000100Z:RX505EEE@T0ZZZZ1Oooool90=GE
e@D00000103EeMD5000000@0P8201@0000050=GEe@@0P8201@0000050:ZZZP@0eMGE1@0Z:RX40:ZZ
ZPGooooo1@20P804000000D0:RXZ1P3AcJT000D0dLfYU?ooool40=GEe@D0P8201@1EEED40820P0D0
0000100Z:RX505EEE@T0ZZZZ1Oooool90=GEe@D00000103EeMD5000000@0P8201@0000050=GEe@@0
P8201@0000050:ZZZP@0eMGE1@0Z:RX40:ZZZPGooooo1@20P804000000D0:RXZ1P3AcJT000D0dLfY
V?ooool50=GEe@Gooooo1020P8050=GEe@@0ZZZZ2P1EEED40820P0kooooo1@0000040=GEe@D0EEEE
103EeMD5ooooo`D0EEEE102ZZZX:0820P0Cooooo2@3EeMD505EEE@D0eMGE100Z:RX505EEE@H0dLfY
00050=7=ZISooooo1@3EeMD5ooooo`@0P8201@3EeMD40:ZZZPX0EEEE1020P80>ooooo`D00000103E
eMD505EEE@@0eMGE1Oooool505EEE@@0ZZZZ2P20P804ooooo`T0eMGE1@1EEED50=GEe@@0:RXZ1@1E
EED60=7=Z@001@3AcJVHooooo`D0eMGE1Oooool40820P0D0eMGE102ZZZX:05EEE@@0P8203_ooool5
000000@0eMGE1@1EEED40=GEe@Gooooo1@1EEED40:ZZZPX0P8201?ooool90=GEe@D0EEEE1@3EeMD4
02XZ:PD0EEEE1P3AcJT000D0dLfYV?ooool50=GEe@Gooooo1020P8050=GEe@@0ZZZZ2P1EEED40820
P0kooooo1@0000040=GEe@D0EEEE103EeMD5ooooo`D0EEEE102ZZZX:0820P0Cooooo2@3EeMD505EE
E@D0eMGE100Z:RX505EEE@H0dLfY00050=7=ZISooooo1@3EeMD5ooooo`@0P8201@3EeMD40:ZZZPX0
EEEE1020P80>ooooo`D00000103EeMD505EEE@@0eMGE1Oooool505EEE@@0ZZZZ2P20P804ooooo`T0
eMGE1@1EEED50=GEe@@0:RXZ1@1EEED60=7=Z@001@3AcJVRooooo`@0:RXZ1@3EeMD40820P0D0:RXZ
1@2ZZZX40820P0D0:RXZ101EEED50=GEe@D0P820102ZZZX5000000@0:RXZ2_ooool40820P0Gooooo
2@2ZZZX902XZ:PGooooo1@2ZZZX9000000H0dLfY00050=7=ZJ;ooooo100Z:RX50=GEe@@0P8201@0Z
:RX50:ZZZP@0P8201@0Z:RX405EEE@D0eMGE1@20P8040:ZZZPD00000100Z:RX:ooooo`@0P8201Ooo
ool90:ZZZPT0:RXZ1Oooool50:ZZZPT000001P3AcJT000D0dLfYX_ooool402XZ:PD0eMGE1020P805
02XZ:PD0ZZZZ1020P80502XZ:P@0EEEE1@3EeMD50820P0@0ZZZZ1@00000402XZ:P[ooooo1020P805
ooooo`T0ZZZZ2@0Z:RX5ooooo`D0ZZZZ2@0000060=7=Z@001@3AcJVRooooo`@0:RXZ1@3EeMD40820
P0D0:RXZ1@2ZZZX40820P0D0:RXZ101EEED50=GEe@D0P820102ZZZX5000000@0:RXZ2_ooool40820
P0Gooooo2@2ZZZX902XZ:PGooooo1@2ZZZX9000000H0dLfY00050=7=ZJKooooo1@20P80905EEE@Go
oooo103EeMD502XZ:P@0P8201@3EeMD50820P0@0:RXZ1@0000040=GEe@D000001@2ZZZX40=GEe@[o
oooo103EeMD505EEE@@0:RXZ1@2ZZZX502XZ:P@000001@2ZZZX60=7=Z@001@3AcJVVooooo`D0P820
2@1EEED5ooooo`@0eMGE1@0Z:RX40820P0D0eMGE1@20P80402XZ:PD00000103EeMD5000000D0ZZZZ
103EeMD:ooooo`@0eMGE1@1EEED402XZ:PD0ZZZZ1@0Z:RX4000000D0ZZZZ1P3AcJT000D0dLfYY_oo
ool50820P0T0EEEE1Oooool40=GEe@D0:RXZ1020P8050=GEe@D0P820100Z:RX5000000@0eMGE1@00
00050:ZZZP@0eMGE2_ooool40=GEe@D0EEEE100Z:RX50:ZZZPD0:RXZ100000050:ZZZPH0dLfY0005
0=7=ZJKooooo1@20P80905EEE@Gooooo103EeMD502XZ:P@0P8201@3EeMD50820P0@0:RXZ1@000004
0=GEe@D000001@2ZZZX40=GEe@[ooooo103EeMD505EEE@@0:RXZ1@2ZZZX502XZ:P@000001@2ZZZX6
0=7=Z@001@3AcJVVooooo`D0P8202@1EEED5ooooo`@0eMGE1@0Z:RX40820P0D0eMGE1@20P80402XZ
:PD00000103EeMD5000000D0ZZZZ103EeMD:ooooo`@0eMGE1@1EEED402XZ:PD0ZZZZ1@0Z:RX40000
00D0ZZZZ1P3AcJT000D0dLfYZoooool40:ZZZPD0P8201@0000040:ZZZPD0eMGE1000000505EEE@D0
ZZZZ1020P8050:ZZZP@0:RXZ1Oooool505EEE@@0ZZZZ1@0000050:ZZZPCooooo1@000004ooooo`D0
P8201@0Z:RX90820P0H0dLfY00050=7=ZJ_ooooo102ZZZX50820P0D00000102ZZZX50=GEe@@00000
1@1EEED50:ZZZP@0P8201@2ZZZX402XZ:PGooooo1@1EEED40:ZZZPD000001@2ZZZX4ooooo`D00000
1?ooool50820P0D0:RXZ2@20P8060=7=Z@001@3AcJV[ooooo`@0ZZZZ1@20P805000000@0ZZZZ1@3E
eMD4000000D0EEEE1@2ZZZX40820P0D0ZZZZ100Z:RX5ooooo`D0EEEE102ZZZX5000000D0ZZZZ1?oo
ool5000000Cooooo1@20P80502XZ:PT0P8201P3AcJT000D0dLfYZoooool40:ZZZPD0P8201@000004
0:ZZZPD0eMGE1000000505EEE@D0ZZZZ1020P8050:ZZZP@0:RXZ1Oooool505EEE@@0ZZZZ1@000005
0:ZZZPCooooo1@000004ooooo`D0P8201@0Z:RX90820P0H0dLfY00050=7=ZJ_ooooo102ZZZX50820
P0D00000102ZZZX50=GEe@@000001@1EEED50:ZZZP@0P8201@2ZZZX402XZ:PGooooo1@1EEED40:ZZ
ZPD000001@2ZZZX4ooooo`D000001?ooool50820P0D0:RXZ2@20P8060=7=Z@001@3AcJV_ooooo`D0
eMGE1@0Z:RX40820P0D0:RXZ1?ooool:05EEE@@0P8201Oooool4000000D0:RXZ2@1EEED:0820P0Wo
oooo101EEED50=GEe@D0:RXZ1020P8050=GEe@H0dLfY00050=7=ZJoooooo1@3EeMD502XZ:P@0P820
1@0Z:RX4ooooo`X0EEEE1020P805ooooo`@000001@0Z:RX905EEE@X0P8202Oooool405EEE@D0eMGE
1@0Z:RX40820P0D0eMGE1P3AcJT000D0dLfY[oooool50=GEe@D0:RXZ1020P80502XZ:PCooooo2P1E
EED40820P0Gooooo1000000502XZ:PT0EEEE2P20P809ooooo`@0EEEE1@3EeMD502XZ:P@0P8201@3E
eMD60=7=Z@001@3AcJV_ooooo`D0eMGE1@0Z:RX40820P0D0:RXZ1?ooool:05EEE@@0P8201Oooool4
000000D0:RXZ2@1EEED:0820P0Wooooo101EEED50=GEe@D0:RXZ1020P8050=GEe@H0dLfY00050=7=
ZKCooooo2@3EeMD502XZ:P@0ZZZZ1@000005ooooo`@0P8201Oooool402XZ:PD0EEEE1Oooool40820
P0D0eMGE1@0Z:RX40=GEe@D0ZZZZ10000005ooooo`T0eMGE1@0Z:RX60=7=Z@001@3AcJVdooooo`T0
eMGE1@0Z:RX40:ZZZPD000001Oooool40820P0Gooooo100Z:RX505EEE@Gooooo1020P8050=GEe@D0
:RXZ103EeMD50:ZZZP@000001Oooool90=GEe@D0:RXZ1P3AcJT000D0dLfY]?ooool90=GEe@D0:RXZ
102ZZZX5000000Gooooo1020P805ooooo`@0:RXZ1@1EEED5ooooo`@0P8201@3EeMD502XZ:P@0eMGE
1@2ZZZX4000000Gooooo2@3EeMD502XZ:PH0dLfY00050=7=ZKCooooo2@3EeMD502XZ:P@0ZZZZ1@00
0005ooooo`@0P8201Oooool402XZ:PD0EEEE1Oooool40820P0D0eMGE1@0Z:RX40=GEe@D0ZZZZ1000
0005ooooo`T0eMGE1@0Z:RX60=7=Z@001@3AcJVdooooo`T0eMGE1@0Z:RX40:ZZZPD000001Oooool4
0820P0Gooooo100Z:RX505EEE@Gooooo1020P8050=GEe@D0:RXZ103EeMD50:ZZZP@000001Oooool9
0=GEe@D0:RXZ1P3AcJT000D0dLfY_Oooool5000000Cooooo2P0000090:ZZZP@000001@3EeMD5oooo
o`@0:RXZ1@3EeMD505EEE@Wooooo2@0000050:ZZZP@0eMGE1@1EEED60=7=Z@001@3AcJVmooooo`D0
00001?ooool:000000T0ZZZZ100000050=GEe@Gooooo100Z:RX50=GEe@D0EEEE2Oooool9000000D0
ZZZZ103EeMD505EEE@H0dLfY00050=7=ZKgooooo1@000004ooooo`X000002@2ZZZX4000000D0eMGE
1Oooool402XZ:PD0eMGE1@1EEED9ooooo`T000001@2ZZZX40=GEe@D0EEEE1P3AcJT000D0dLfY_Ooo
ool5000000Cooooo2P0000090:ZZZP@000001@3EeMD5ooooo`@0:RXZ1@3EeMD505EEE@Wooooo2@00
00050:ZZZP@0eMGE1@1EEED60=7=Z@001@3AcJW2ooooo`@0EEEE1@2ZZZX5ooooo`@0EEEE1@20P804
ooooo`D0EEEE1@2ZZZX90=GEe@D0P820100000050:ZZZP@0eMGE1@2ZZZX502XZ:PCooooo1@000006
0=7=Z@001@3AcJW2ooooo`@0EEEE1@2ZZZX5ooooo`@0EEEE1@20P804ooooo`D0EEEE1@2ZZZX90=GE
e@D0P820100000050:ZZZP@0eMGE1@2ZZZX502XZ:PCooooo1@0000060=7=Z@001@3AcJW2ooooo`@0
EEEE1@2ZZZX5ooooo`@0EEEE1@20P804ooooo`D0EEEE1@2ZZZX90=GEe@D0P820100000050:ZZZP@0
eMGE1@2ZZZX502XZ:PCooooo1@0000060=7=Z@001@3AcJW2ooooo`@0EEEE1@2ZZZX5ooooo`@0EEEE
1@20P804ooooo`D0EEEE1@2ZZZX90=GEe@D0P820100000050:ZZZP@0eMGE1@2ZZZX502XZ:PCooooo
1@0000060=7=Z@001@3AcJW2ooooo`@0EEEE1@2ZZZX5ooooo`@0EEEE1@20P804ooooo`D0EEEE1@2Z
ZZX90=GEe@D0P820100000050:ZZZP@0eMGE1@2ZZZX502XZ:PCooooo1@0000060=7=Z@001@3AcJW6
ooooo`D0P8202Oooool50820P0Cooooo1@0Z:RX90:ZZZPD0eMGE1@20P804000000D0eMGE101EEED:
0:ZZZP@0EEEE1@2ZZZX60=7=Z@001@3AcJW6ooooo`D0P8202Oooool50820P0Cooooo1@0Z:RX90:ZZ
ZPD0eMGE1@20P804000000D0eMGE101EEED:0:ZZZP@0EEEE1@2ZZZX60=7=Z@001@3AcJW6ooooo`D0
P8202Oooool50820P0Cooooo1@0Z:RX90:ZZZPD0eMGE1@20P804000000D0eMGE101EEED:0:ZZZP@0
EEEE1@2ZZZX60=7=Z@001@3AcJW6ooooo`D0P8202Oooool50820P0Cooooo1@0Z:RX90:ZZZPD0eMGE
1@20P804000000D0eMGE101EEED:0:ZZZP@0EEEE1@2ZZZX60=7=Z@001@3AcJW;ooooo`D0ZZZZ1?oo
ool502XZ:P@0eMGE1@20P80>0:ZZZPD0eMGE100Z:RX50820P0T0EEEE1@20P804ooooo`D0P8201P3A
cJT000D0dLfYboooool50:ZZZPCooooo1@0Z:RX40=GEe@D0P8203P2ZZZX50=GEe@@0:RXZ1@20P809
05EEE@D0P8201?ooool50820P0H0dLfY00050=7=ZL_ooooo1@2ZZZX4ooooo`D0:RXZ103EeMD50820
P0h0ZZZZ1@3EeMD402XZ:PD0P8202@1EEED50820P0Cooooo1@20P8060=7=Z@001@3AcJW;ooooo`D0
ZZZZ1?ooool502XZ:P@0eMGE1@20P80>0:ZZZPD0eMGE100Z:RX50820P0T0EEEE1@20P804ooooo`D0
P8201P3AcJT000D0dLfYboooool50:ZZZPCooooo1@0Z:RX40=GEe@D0P8203P2ZZZX50=GEe@@0:RXZ
1@20P80905EEE@D0P8201?ooool50820P0H0dLfY00050=7=ZM3ooooo103EeMD50820P0@0ZZZZ1@3E
eMD502XZ:PCooooo1@0000050820P0@0EEEE1@0Z:RX40=GEe@D000001Oooool40:ZZZPD0eMGE1P3A
cJT000D0dLfYd?ooool40=GEe@D0P820102ZZZX50=GEe@D0:RXZ1?ooool5000000D0P820101EEED5
02XZ:P@0eMGE1@000005ooooo`@0ZZZZ1@3EeMD60=7=Z@001@3AcJW@ooooo`@0eMGE1@20P8040:ZZ
ZPD0eMGE1@0Z:RX4ooooo`D000001@20P80405EEE@D0:RXZ103EeMD5000000Gooooo102ZZZX50=GE
e@H0dLfY00050=7=ZM3ooooo103EeMD50820P0@0ZZZZ1@3EeMD502XZ:PCooooo1@0000050820P0@0
EEEE1@0Z:RX40=GEe@D000001Oooool40:ZZZPD0eMGE1P3AcJT000D0dLfYd?ooool40=GEe@D0P820
102ZZZX50=GEe@D0:RXZ1?ooool5000000D0P820101EEED502XZ:P@0eMGE1@000005ooooo`@0ZZZZ
1@3EeMD60=7=Z@001@3AcJWDooooo`D0eMGE1?ooool50=GEe@D0EEEE2Oooool505EEE@@0P8201@00
000902XZ:PT0P8201@0Z:RX60=7=Z@001@3AcJWDooooo`D0eMGE1?ooool50=GEe@D0EEEE2Oooool5
05EEE@@0P8201@00000902XZ:PT0P8201@0Z:RX60=7=Z@001@3AcJWDooooo`D0eMGE1?ooool50=GE
e@D0EEEE2Oooool505EEE@@0P8201@00000902XZ:PT0P8201@0Z:RX60=7=Z@001@3AcJWDooooo`D0
eMGE1?ooool50=GEe@D0EEEE2Oooool505EEE@@0P8201@00000902XZ:PT0P8201@0Z:RX60=7=Z@00
1@3AcJWMooooo`D0:RXZ1Oooool40:ZZZPD0:RXZ3P1EEED90=GEe@D000002@1EEED60=7=Z@001@3A
cJWMooooo`D0:RXZ1Oooool40:ZZZPD0:RXZ3P1EEED90=GEe@D000002@1EEED60=7=Z@001@3AcJWM
ooooo`D0:RXZ1Oooool40:ZZZPD0:RXZ3P1EEED90=GEe@D000002@1EEED60=7=Z@001@3AcJWMoooo
o`D0:RXZ1Oooool40:ZZZPD0:RXZ3P1EEED90=GEe@D000002@1EEED60=7=Z@001@3AcJWMooooo`D0
:RXZ1Oooool40:ZZZPD0:RXZ3P1EEED90=GEe@D000002@1EEED60=7=Z@001@3AcJWRooooo`T0P820
1@0Z:RX50820P0@0eMGE1@000009ooooo`D00000103EeMD5000000H0dLfY00050=7=ZN;ooooo2@20
P80502XZ:PD0P820103EeMD5000000Wooooo1@0000040=GEe@D000001P3AcJT000D0dLfYh_ooool9
0820P0D0:RXZ1@20P8040=GEe@D000002Oooool5000000@0eMGE1@0000060=7=Z@001@3AcJWRoooo
o`T0P8201@0Z:RX50820P0@0eMGE1@000009ooooo`D00000103EeMD5000000H0dLfY00050=7=ZNOo
oooo102ZZZX50820P0T0ZZZZ2@0000050:ZZZPD0eMGE2@2ZZZX60=7=Z@001@3AcJWWooooo`@0ZZZZ
1@20P8090:ZZZPT000001@2ZZZX50=GEe@T0ZZZZ1P3AcJT000D0dLfYioooool40:ZZZPD0P8202@2Z
ZZX9000000D0ZZZZ1@3EeMD90:ZZZPH0dLfY00050=7=ZNOooooo102ZZZX50820P0T0ZZZZ2@000005
0:ZZZPD0eMGE2@2ZZZX60=7=Z@001@3AcJWWooooo`@0ZZZZ1@20P8090:ZZZPT000001@2ZZZX50=GE
e@T0ZZZZ1P3AcJT000D0dLfYjoooool50=GEe@D0:RXZ1?ooool>000000D0P820101EEED50820P0H0
dLfY00050=7=ZN_ooooo1@3EeMD502XZ:PCooooo3P0000050820P0@0EEEE1@20P8060=7=Z@001@3A
cJW[ooooo`D0eMGE1@0Z:RX4ooooo`h000001@20P80405EEE@D0P8201P3AcJT000D0dLfYjoooool5
0=GEe@D0:RXZ1?ooool>000000D0P820101EEED50820P0H0dLfY00050=7=ZO3ooooo2@3EeMDC0820
P0T0eMGE1P3AcJT000D0dLfYl?ooool90=GEeA<0P8202@3EeMD60=7=Z@001@3AcJW`ooooo`T0eMGE
4`20P8090=GEe@H0dLfY00050=7=ZO3ooooo2@3EeMDC0820P0T0eMGE1P3AcJT000D0dLfYl?ooool9
0=GEeA<0P8202@3EeMD60=7=Z@001@3AcJWiooooo`D0:RXZ1000000505EEE@D0P8202@0Z:RX60=7=
Z@001@3AcJWiooooo`D0:RXZ1000000505EEE@D0P8202@0Z:RX60=7=Z@001@3AcJWiooooo`D0:RXZ
1000000505EEE@D0P8202@0Z:RX60=7=Z@001@3AcJWiooooo`D0:RXZ1000000505EEE@D0P8202@0Z
:RX60=7=Z@001@3AcJWiooooo`D0:RXZ1000000505EEE@D0P8202@0Z:RX60=7=Z@001@3AcJWnoooo
o`@0EEEE2P3EeMD4ooooo`D0EEEE1P3AcJT000D0dLfYo_ooool405EEE@X0eMGE1?ooool505EEE@H0
dLfY00050=7=ZOkooooo101EEED:0=GEe@Cooooo1@1EEED60=7=Z@001@3AcJWnooooo`@0EEEE2P3E
eMD4ooooo`D0EEEE1P3AcJT000D0dLfYooooool3ooooo`D0ZZZZ1@0000040:ZZZPD000001P3AcJT0
00D0dLfYooooool3ooooo`D0ZZZZ1@0000040:ZZZPD000001P3AcJT000D0dLfYooooool3ooooo`D0
ZZZZ1@0000040:ZZZPD000001P3AcJT000D0dLfYooooool3ooooo`D0ZZZZ1@0000040:ZZZPD00000
1P3AcJT000D0dLfYooooool3ooooo`D0ZZZZ1@0000040:ZZZPD000001P3AcJT000D0dLfYooooool8
ooooo`D0ZZZZ1?ooool50:ZZZPH0dLfY00050=7=ZOoooooo2?ooool50:ZZZPCooooo1@2ZZZX60=7=
Z@001@3AcJWoooooo`Sooooo1@2ZZZX4ooooo`D0ZZZZ1P3AcJT000D0dLfYooooool8ooooo`D0ZZZZ
1?ooool50:ZZZPH0dLfY00050=7=ZOoooooo3Oooool40=GEe@D0P8201P3AcJT000D0dLfYooooool=
ooooo`@0eMGE1@20P8060=7=Z@001@3AcJWoooooo`gooooo103EeMD50820P0H0dLfY00050=7=ZOoo
oooo3Oooool40=GEe@D0P8201P3AcJT000D0dLfYooooool=ooooo`@0eMGE1@20P8060=7=Z@00o`3A
cJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00\
\>"],
  ImageRangeCache->{{{0, 287}, {238.938, 0}} -> {-1.23012, -1.00026, \
0.217632, 0.217632}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(pow[20, 11, 100];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00769231 0.0153846 0.00769231 [
[ 0 0 0 0 ]
[ 1 .8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .8 L
0 .8 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01538 translate
.96154 .76924 scale
125 string
125 100 8 [125 0 0 100 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19B333FF99CC1966CC4CFFB3004C80E64C6680E6FF196666B3804CE6B3006680E6B3FF66
FF4CB399198033E6CC991900CCFFFFFF00E680999999E699FF19FF99333333008019E633
19CC19B300804C66CCB3FF0033664C003300B31919B3994C004C80FFE633FF6633CCB333
4C66FF33FFFFCC1980CCFF1900196680E6
FF80E680804C19B3FF4C80804C4C8033B34C80CCCC3333FFB380CC66E6B3B3FF33198080
3319E619FF80CC664CCC00009980808066FFFF19FFCC9980E64C666619CC4CFF80334C33
4C6633E619B366994C3300808099CCFF8000996680006619CCCCFFCC33B34C33FF99804C
66994C33E6E6E6CC4C998080000000CC80
FFFFCC19FF19CCE6CC336619660019FF0066004C3300B34C4C196633FFFF4C1999B3CC80
CC4CFF4CFF66B39933FF4C4C4C99E699E699999919B3004C9980B36600B3003319FF0019
CC6699CC19CC00CC99334C4C994CB30080CC4C00CC8080B3CCB399998000FF00B3B38033
6600E680B319008066004C994C4C4C4CB3
FFFFFFE666E6FFE6E6334C809933CC4CCCE6000019CC4C1933E6FFB34C4C33E6FFCCB300
4C19E64C808033004C66FF00B3E6B399FF6619FFCC4CB319E61966336666CC33E666E6E6
FFE6996633E6333399FF0019E6194C19196633E6FF4C994CB39966CC0033CCCC4C198033
4C8080FFCC009999E69900CC0019CCFF99
FFFFFFFFFF19999980FF99338033E6CC66E633CC33E6334CFF0080804C801933B3B39966
669919993380334C4C803319B380FFE61999CCE6E6CC66CC4CCC4C8099E6006680FFB3B3
1919004C80B300B34C19009919991933CCE699331999CC9933996600FF8000FFE680994C
66994C999966FFCC9980CCE633334C3319
FFFFFFFFFFFF80E619666619CC80B300FFB399CC1933B333FF6666B366994C4CFFE619FF
B36619CC00194CFF99CC8099B380CCCCB3CC998066E6CC80660066994CB300994C0080E6
B3CC4C4C80339900FF009999E6FFCC4C66E64C00B33380FF334C99CCE64C991919004C00
B3FF336619FFB3B399661980FF9919CCE6
FFFFFFFFFFFFFFCC19B3FF193300E619B3B380E63333E6B3E64C80CC00CC993366664C66
663366804CE6669999664C004CB366E63399804C0033B3994C8080CC003300004C66FFCC
33006699338000E6664CE6B38066FF4C80331933CC99B3FFFF993380FF66004C4CE6FF00
9966FF00334C4C198033FF80CCCC991980
FFFFFFFFFFFFFFFFE666CCCC4C6666E666CC99E6CCFF00804CCC66B39900FFCC6600CC66
99CCFF1966008019FFCC8019194C194CCC6619FF009933004C8033804CE666FF80194CE6
334C4C80CCFF19B399CCFFFF4C0033B3E699B3CC664C00FF66FF334C999933CC66999900
004C9900001933E6FFB3E64C99806619B3
FFFFFFFFFFFFFFFFFFFF1980FF00CC8066B3004CCCB3B319FF00FFB380CCE64CB3E6FF4C
80E633B3CC66FFB3CCCCB366800019B3E6CC80008080CCE6FF00CCFF19E633FFFFB3CC66
E680194C0066E6FFE619990080B319CCB300E6CC194C66FFFFB3B333FF3380B3003380CC
CCCCFFCC33CC4C66E6E6CC19E619660099
FFFFFFFFFFFFFFFFFFFFFF80CCCC4C19FF1966FFB30066334C33CCCC99E6CCB3E6CC3319
E619001980661900FF4CCC00CC80809966E6CC8080CC80FF664CE6CCCC4CCC6666663399
E64C0000B3B3FF66664C6619B366CC4CCC009980E6FF99E64CE633001999B3FFCCCCFF33
00FFE6E6CC6633FF199980E6FFE6FFB319
FFFFFFFFFFFFFFFFFFFFFFFFCC1980B333B3CC80804C4C8099CC664C19FFFF4CB3B30019
331919B3338019B3CC336633CCB366B380331980CC80FF3319E680FFE6CC66E600336680
E633E6E6FF4C1999E60019E666CC8066006666B3FFFF66CC19E633E64CFF33999980664C
FF808066E6CC80190099FF3319B31900E6
FFFFFFFFFFFFFFFFFFFFFFFFFFE666B38099FFE699E680B366CC194C8000990033004CE6
668099198000CCE6CC19336680FF33FFE600B33380661999B3CCB3FFFFFF4C80FF8000CC
80FF9980FFFF99B38066668066B30033FF8019E6CC33B3FF4C664C66E699001966B3FFB3
4CE600E60080661919B380800099FF8080
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1980339900804C33804C80E6FF99E66619B333CC66
E6994C99B36666E64C19B3E6004C33E6E6CCE619CC80B3CC9966E633333319E61900CCE6
3380804C0099004CB36699E600CC9999CC338000804CFFE64C8019E6008033CC4C80E6E6
B3E6CCE633CC80B3CC4CB366B319FFFFB3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80CC6619B3669919FF00E64C4C1900334C193399
E64C00CC006600CCB3E666CCB3B3E68066E6CCB3CCB366CCB3803319334C66806666FFE6
CCFF19FF00994CE680E699664C4CCC004CB3E600994C808066994C664C4C993300B3FFFF
6633B39980B3004C1980B380CC00B31999
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC194C663366B3CCCC4C336600009919CCE680
4C334CE6CC33FF806633B3664C198066B3664CCC00FFE60066CC8099B333FF196600CCCC
CC1999B3B319FFB300E64C00CC669966FF99FFE6FF3366196600E680B3E680CCE6FF4C4C
33FF9966B3FFCCCCFF80CC99E6CC4C1919
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6669933E69966E6334CFFB319B3800066E6
99CC6600804CFFFFB3FF006600B3CC80CC00CC66CCE64CCC33FFE699FF33E6E66699B300
66CCE6B380E666FF33CCB3E66633FFCC80804C4C33B3E60000CC4C33804CCC80FF666600
19CCCC994C19B30066FF3300E6E6334CE6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF196680FFCC806680B3B3809966B319E6
E61980B3B3FFB31999FFFF8019B380FF330099803319003300B3B399FF6680FFFF1966CC
33FFE6E619FF661900B39966E699333300E600B3E6804CCC33CCB34C66B34CB3FFFFB34C
E666E63380B3339900CCCC4CE6E633E680
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80B3FFFFE699E600FF4C004C80E666
E6CCE699FFE64CB333990080CC4CB366FF00004C9919B3B3CCE633004CE6004C4C33E600
6699008066808019B3CC00E69980CCFF000066FFE64C003300B39966994C194C19B31980
19994C334C996680CCE63399CCCC19CCB3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC191919004CCC4C33E6FF00E633
FFFF4CCC999980B38099E6FF3300CC00CCCC33CC66B3CC99FFE6CCE6FF19000019CCFF4C
E6994CE699E600CCE6CC19199966199900000033CC19CCCCE6FF4C00CC993333E6FFCCE6
99B38019336619E6B3008000E6CCB33399
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6668000003300B3E64C33CCB3
E64CCCFFE6B38033994CB31900B3330099804CFFE69966E619B300FFFF6666FF800066FF
19004C8066CC19B39980E6FF80E60000E64CE64CFFE666E633B3B34C4CCC001933B3B399
80E619E6FF9933E64C19194CE6E6339919
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF194CE64CFF804CCC6680FF
4C33664C4C33994C66B3E6B3CC4C19333380CC66FF6619E6CCE6B3CC33B3FF1999E66619
009999CC80CC1933004C9999004C333333B34CCC66FF66190019804C8019808099330066
19FF4CFF666619CCB3E6668019998099E6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80B399CCCC80B3994C00
80B333FF99CC6619E600664CB3993333E6803399E64C809980FF663399CC190099FF6600
9999FF3399E6CC4C6666996619B34C668099FFB30033B3E6FF800033FF19B3FFCC001919
4C66660080B3E6FFE6CC19E699B3803380
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC00E6CCB366CC9933
33804C66FF3399CCE6CCE60033004C6680FFB3E6199933804C0080B3E619809900E6E699
00E6B3B34C1900669933FFCC8000660033804C4C19193399990033CC664CFF4C4C19B333
33FF194C4C9966E6E6E6334C3380E699B3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6664CCC00CCB380
00B366994C33E6B39980FF4CE666FF99E61900FF4CFF334C993333804CCC4C994CE6E64C
009980E6B3E6666699FF0080FF19B34CE6803366000099CC004C4C66E6003319CCFF80E6
80190099CC66B3FF664CCC660019664C99
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF194C19B39966
B333003380B34C3399661999CCB3FF66CC19B3CC33664CFF99FF00196600669966008066
9900E6B300FF6600CC999900E64C6633664C9919E64CE6B39900B3E699808099B399994C
CC809900E6CC804CE6003300CC33E60019
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80B3339966
00FF00001966334CFFCC80004CCC1900CCB333998000CC66FF33B3B3CC66FFB38019B366
99E6FF663333B3E6FF4C99E6FF6600334C80B3800080199966B3CC19004C994C99FFCC99
3399E6B3331980CC66E64CFF804CFFE6E6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC00B380
19B3B319B3336680B3B3994C4C804CE6FF4CB34C00CCE63366FF00663399E64CB366804C
80E64C33FF99330080801966E6E69900B34C9966B319E6FFCC804CB3CC33FF3366333300
E6804C339919B3FFE69980B3B366999980
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE66633
800066334C193366B380E6B34C8033664CCCFFCCFF80664C66B319194C66CC19E619E699
CC80FF99CC33809999E699B3664CCC9900FF00E699668066FF4C993399801900B34CFF99
190033FF004C6633CC19FFCC00FF1966B3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF19
3366FFB333E6FF994C19664CB34C9919E680FF66E64C9933FF19800000B3FF4C664C664C
B3004C4C00FF994C99FF66330033664C00999919004C80CC8080196680E6009999FFB319
6666FF999900B3FF006680804CE6E66699
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
8099E64CB34C33CC0019B3FF00FF00E666E6B3194CCC66B3E64C661919198080194C8019
E619B34C66FFFFCC66CC3366808099CCFF804C009999CC80FF19E6FFB366E66619FFFFCC
E6994C4C00E66633B3B3FF19FF19008019
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFCC0080198019339999B39900008080FFB399FF80B3994C19993366800000E60099CC80
99809966994C4C4C19E6CC6600E600E6CCCC80B319FFCCB366E6FFFF66CC806699B3B3B3
9980CCFF99B300CC663399991999B319E6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE6661919E6FF996633004C4C4C994CE619FFFFCC00E680994CFFB3666666E6663300
E6196619E6B34C8019331980B3CC19B3B30066B3809999804C80FFFFFFB3994C80E63300
6619FF4CE61966FFE69919FFCC4C99FF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF1919CC3319FFB333CC66993380B399B3B3B39919004C00CC339933FFB399CCE6
FF4CFF19331980194CFF0000E6330099FFCCE600661966B3FF99E6E6E6E6CC0019FF4CFF
8019CC33664C661919004C666633FF33B3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF80998000B3198000FFB38000E619FFE633004C4CE68080FF004C66FF4C00FF
FF66999919334C0000CC333333B333CC999980666699B36633CC008066E6E633334C33FF
66B33399B3FF00CC4C4CE680B3FF008099
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCC0033CC99B36666FF4C0000800080FF9900B3E6E600E64C4C803319CCE6
4CE6004C99B333E6E6FF4C668099FF99804C00E6003380E6993300994C80FFFF001933E6
E6996680E63319B39933664C9966E6FF19
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE64CFFE6B380B3FF669900994C4C99994CE6CC33191999336619334C33
194C33336633001999990019E699FF66B3FF99B3009919FF6619CC4C00B3FFFFFF800019
9980E6004C334C66338099CCFFCC8066E6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF1919006619808019FF8033FF00E6B34CCCB333CCE6B333FF8099CC
4CFF00B333FF990099FF33334C33990033999966333380999933E6334CE6CC33CC3366FF
80E619000019CC6699B3FFCCB3B3994C80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF809900CC4C994C66661933B3CC33003300FF0066E6B3E64C9966
33FF6666CC666619B3808000B34C66B3B3E6196699B3E600E6B34C334C8066CCFF4C66B3
19664C4CE64CFF4C80E6333300FF4C00B3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFCC00006699660033668000FF4C66668099000033B380FF99FF
1933B3FF1980B3E6FFE600CCE619E6006633B33366CC190000804C8000B3FFB399993366
CC4C80B34CCC66FF00E633E666FFFF9999
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE64CE69966009919E699B31933FFB366B3B3B3E619FF66CC
3333E6CC334C00664CE633CCB399B39999CCFF33E6998000000033FF19B399006619FF99
4C19E600FF00FFB3B3331933B366666619
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF19004C8080CCE6E61980001999FFB380E6CC19CC3366
CCFF00804CFF9999CCFFFF0066CC9966CC0066FF00804C000000001999B380CCE6001900
E680998099000080E6B3CCE6804C80B3E6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080B366B39980FF80CC33E61999FFCC3300B30019
4CCC3333801999FF33B3199999E63380CC19194CCCE600B3B3B3B3B3CC9966B399808099
19004C00E6191919664CB39980CC66B380
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB3FFE6006619FF66B399331919FFFFE666FFCCCC
E680FF00194CFF33B3E619CC004CCC66198099194C331919804CB380E6CC994C1966B366
B3CC33E6FF4CE6FF80B3E6CC004C19E6B3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE64CCC33FF990033994CFF8099999980CC33B3
008033B3B3CC66FF00664C6633CC66E60000E61919CCE6FF80CC66CC80FFE6B34C6600FF
19804CFFFF669999004C199966FF99B399
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FF99994CE68033FF66B3804C00E6334C
B319FF00663399E64C4C80B34CFFE699808080FF80998066FF3300CCB366FF6633660099
9919660099003380CCCCFF80E60080E619
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80804C00CC19FF0080CC00CCFF806680
B380999900CC66331933FF330033331966B366B3B366B3FFB3B333CCB380CC336680B3CC
004C6600994CE68033B30080CCB3B3FFE6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB3FF99B3001900994CB3CC1999E699
4CB366CC00006699B3CC664CFF8000B33366CC804CB36633CC00FF0066CC80FF0033804C
B3B3E69900E680FFB3E619B366E6330080
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE64C99FF8000004C804CB3CC9980
CCFFE60066666699FF4C19E6990033CC99B3FF4C99339933E6CC4C33CC8066199999B3FF
99FFE64C009980CCCCB30099FFB399B3B3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00E6E6999999CC80B380FF33
8066664C4C80B3FF33B3E666E6B319CCB3804CCCFFCC6619CCCC1933E6CC80B3CC996633
CC0080FF9999FF3300FFCCE61999FFCC99
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8066E6B3804C19FF4C0080
99E69933FF00E63319CCB300CCCC00B30066194C333300CC4CCC1919CCCC19663399FF19
339999E6E6B380800099998066804C4C19
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB3FF663380193319CCE6
00E6E61933B3CC19CC4CCC0099804CE6B3B3E6FF99B3CCE6336633CCE6CCB3336680E64C
4CFFCC9980FFE600CCE61966B3661933E6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE64C8099E666809980
6666E6CCE6804CB3CCB34CB3CC0033FF66339999004CB3998099CCFF4CCCB38099E61900
19E64CCC004C4C3333B30099E619E66680
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00E619994C004C
9933FFFF4CCC80B380FF33FF4C19B34C33FF996619B34CB3803380FF6699804C99664C4C
E666E680E6FF00B3CCFF33CC99809980B3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80668033E6FF
00E68080801980CC99E6E6808019330019CCCC9933E619E619FF004C33FFCC80B38019CC
FFFF19994CCCCC4C1999001980E600E699
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB3FF19CCCC
3333B366B366803399FF664C994C4CFF800066E61933B333B333B3B3E68080661980334C
333319CC003300FF99B366FF80CCB3CC19
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE64C664C
19CC663366CC80334CB3194C8033FF1900CCE6008000198000FF006633B366B34CFF19CC
668099B39900B33319FFE60080CCB380E6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00CC
66806600B3664C00194C1919E600B3B33333B300994C4C6619199999CCFF33FFCCFFFF80
FF196633004C4CB333E64CCC4C0066CC80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
6600E600006600B3B3CC66800066FFE619CC66333380B34C80991966CC1999CC33B31999
E6E66699B3B3E680E68066998019194CB3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
B3E6FF4CE666009966CCB36619194CE633E633668099E6B3E699E6FFB3991966CCFF33E6
199980CC006633B366E699E6194CE6FF99
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFE64C33FF6600996600FFE6000099CCB3E633E6994CB300FF66331999FFCC4C80FF6680
FF80E600FF8019CC99E64C190000CC3319
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00B3B34CE6B34CE6E6CCCCE61980E6CCFF6619E619B3B34CFF80E64CB3E6B3194C
99994CCC4C4C0000FFCCB3E6666666CCE6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF804CB34CCC99CCCC3300FFE6FFCC331900CC4CCC4CB380B3B366E680E6E619B3
E6B3801980B34C4C4CE6339980B3FF1980
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFB3E6B3E6CC99804CFF808066FF4C6666FFE680FF00FF33006619004C33B333
9980E699B366CC669933B34C00E63319B3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE64C1999804C003319FF19E6E680B3FF66E6B3191999B3B3E6FF80193399
19FFCC19FFE6006699FF00660000800099
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0099FF19CCCCE6FFFF80FFFF330080CC33000099FF4C1999994C4CFF
CC4CE6334C4C333366CC3333666666B319
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF804C33E633B3191900E64CCCE6FF3300B319B380801919FFCC6699
9980199919CCFF9919E6CC4CFFB36600E6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFB3E6806680E66666FFFF00FFFF668080E666CC80CC4C666633FF
CC994C6619CC1999E6FFFF4C80804C8080
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFE64C0033806699E64CCCE64CE6004C00803300E6336600CC66
664C00B3E6FFE666CC333319E600CCFFB3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF009919FF1966E680FF660066FF9999E666FFFF00333399
E60019B380FFFFFF198099B3CCB3CC1999
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF8033E64C6619004C33FF803319FFCCB3FF66E6FF0019
66E64CFF4C00990080994C99FFE6CC1919
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB3E633FF1919B34C66FF19CC4CE63399994C33B3B3
CC8066999933338080CC99339900804CE6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE633E6E666804C803319CC194C334C99FF00B380
E6CC80CC004C6680CC80FF334C9999E680
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00806699E680CC4CFF4C6600194C19009966
B3B3004C19B34C80CCB366FF0019FFCCB3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803366CC19FF4C8080194C4C6600009966
00FF33CC66804C803399FFB3B319CC3399
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB3E60066808019661919CCFFB319B380
19B3B34C19E699CC8099FF66CC99B39919
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE633CC803380003333E633CC0099FF
B3CC99FF99B399FF4C99666600FFCC99E6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0066B34C00001933B34C19B380
804CCC0080E619FFFF99FF194C4CE63380
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80330019B319B3E619CCE6B3
FFB3E6CC4C00800099004CCCE680B399B3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB3CCCCE6B3CCB300B30080
4CE6331980B319E6FF3333664C33804C99
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE633B300FF4CB3330000
33FF4CFF80CC99B3B319334C80B34C0019
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF004CE6E680E666FF
801900CC33806633004CFF0019FF33E6E6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80199980CCB3FF
66B3333399B3FFB333CC66E6E6FFFF9980
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB3CC994CCC19
00CC99B3E61980804C66E6008066FF66B3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE63380B399
191980E6331919FF19E60066FFB3FF6699
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF004C19
6680004C334C4CFF66806666B319808019
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8019
19E69999CC66003319E699E6004CFF19E6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB3
CC4CCC996633FF8000B300E6CCCCFFFF80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E633664C00CC6666191966FFFF4CCC33B3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00334CE6CC8019B3CC808080198099
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF8000CC3300CCE6CC1966194CFF19
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFB3CC193333B300FF80B3CC66E6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE63333E6804C4CE600FF4C80
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0019994C8019991900B3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF80004C80334C009999
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFB3B3E699B3E66619
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE6331966CCB3E6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000CCB380
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF66FFE6B3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFB3B399
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE619
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{353.813, 283.063},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q00016b000`400?l00000o`00003oo`3AcJUR
0=7=Z@00o`3AcJUR0=7=Z@00o`3AcJUR0=7=Z@00o`3AcJUR0=7=Z@00o`3AcJUR0=7=Z@00o`3AcJUR
0=7=Z@00o`3AcJUR0=7=Z@001P3AcJT301TI6@80/k>c0`0c<c<30?ooo`<0VIVI0P3<c<`301TI6@<0
IVIV0P3<c<`304a<C0<0oooo0`2c/k<2000000<0C4a<0`20P8020>KViP<0C4a<0`1VIVH30820P080
i^KV0`3oool301TI6@D0IVIV0`2c/k<30820P080C4a<0`3Vi^H30;>c/`8000000`1VIVH30820P0<0
i^KV0P2c/k<30?ooo`<0IVIV0P3oool304a<C0<0/k>c0P2IVIT301TI6@<0P8200`0c<c<20>KViP<0
c<c<0`2IVIT201TI6@<000000`3<c<`80?ooo`<000000P3Vi^H30820P0P0VIVI0`3Vi^H309VIV@80
oooo0`0I6AT30?ooo`<0VIVI200c<c<2000000<0P8200`0I6AT30>KViP80<c<c0`0I6AT30<c<c080
6ATI0`2c/k<3000000<0P8200P1<C4`306IVIP<0c<c<0P2c/k<30?ooo`<000000`0c<c<206IVIP<0
C4a<0`00000203<c<`<000000`2c/k<501TI6@<0/k>c0`2IVIT204a<C0<000000`1<C4`20820P0<0
oooo0`3Vi^H303<c<`80oooo0`1VIVH303<c<`80c<c<0`2c/k<303<c<`<0C4a<0P1VIVH30?ooo`<0
<c<c1@3oool30<c<c0<06ATI0P20P8030<c<c0<0oooo0P0I6AT3000000<06ATI0`1VIVH20820P0<0
i^KV203AcJT000H0dLfY0`0I6AT20;>c/`<0<c<c0`3oool309VIV@80c<c<0`0I6AT306IVIP80c<c<
0`1<C4`30?ooo`<0/k>c0P00000304a<C0<0P8200P3Vi^H304a<C0<0IVIV0`20P8020>KViP<0oooo
0`0I6AT506IVIP<0/k>c0`20P80204a<C0<0i^KV0`2c/k<2000000<0IVIV0`20P8030>KViP80/k>c
0`3oool306IVIP80oooo0`1<C4`30;>c/`80VIVI0`0I6AT30820P0<0<c<c0P3Vi^H30<c<c0<0VIVI
0P0I6AT3000000<0c<c<203oool300000080i^KV0`20P80809VIV@<0i^KV0`2IVIT20?ooo`<06ATI
0`3oool309VIV@P0<c<c0P0000030820P0<06ATI0`3Vi^H203<c<`<06ATI0`3<c<`201TI6@<0/k>c
0`0000030820P080C4a<0`1VIVH30<c<c080/k>c0`3oool3000000<0<c<c0P1VIVH304a<C0<00000
0P0c<c<3000000<0/k>c1@0I6AT30;>c/`<0VIVI0P1<C4`3000000<0C4a<0P20P8030?ooo`<0i^KV
0`0c<c<20?ooo`<0IVIV0`0c<c<20<c<c0<0/k>c0`0c<c<304a<C080IVIV0`3oool303<c<`D0oooo
0`3<c<`301TI6@80P8200`3<c<`30?ooo`806ATI0`00000301TI6@<0IVIV0P20P8030>KViPP0dLfY
00060=7=Z@<06ATI0P2c/k<303<c<`<0oooo0`2IVIT20<c<c0<06ATI0`1VIVH20<c<c0<0C4a<0`3o
ool30;>c/`8000000`1<C4`30820P080i^KV0`1<C4`306IVIP<0P8200P3Vi^H30?ooo`<06ATI1@1V
IVH30;>c/`<0P8200P1<C4`30>KViP<0/k>c0P00000306IVIP<0P8200`3Vi^H20;>c/`<0oooo0`1V
IVH20?ooo`<0C4a<0`2c/k<209VIV@<06ATI0`20P80303<c<`80i^KV0`3<c<`309VIV@806ATI0`00
00030<c<c0P0oooo0`0000020>KViP<0P820202IVIT30>KViP<0VIVI0P3oool301TI6@<0oooo0`2I
VIT803<c<`8000000`20P80301TI6@<0i^KV0P0c<c<301TI6@<0c<c<0P0I6AT30;>c/`<000000`20
P80204a<C0<0IVIV0`3<c<`20;>c/`<0oooo0`00000303<c<`80IVIV0`1<C4`300000080<c<c0`00
00030;>c/`D06ATI0`2c/k<309VIV@80C4a<0`00000304a<C080P8200`3oool30>KViP<0<c<c0P3o
ool306IVIP<0<c<c0P3<c<`30;>c/`<0<c<c0`1<C4`206IVIP<0oooo0`0c<c<50?ooo`<0c<c<0`0I
6AT20820P0<0c<c<0`3oool201TI6@<000000`0I6AT306IVIP80P8200`3Vi^H80=7=Z@001P3AcJT3
0?ooo`80P8200`3Vi^H60820P080C4a<0`0I6AT30;>c/`80oooo0`1<C4`60820P0D0C4a<0`20P802
03<c<`<0/k>c0`1<C4`30820P0D0c<c<1@0c<c<30?ooo`<0/k>c0`20P8020<c<c0<0IVIV0`3Vi^H5
0;>c/`<0oooo0`0c<c<201TI6@H0P8200P0c<c<301TI6@<0i^KV0P0I6AT30?ooo`<0P8200`3<c<`2
06IVIP<0C4a<0`3<c<`5000000<0VIVI2020P80306IVIPD0oooo0`0I6AT30?ooo`80c<c<0`2IVIT3
0820P080i^KV0`1<C4`606IVIP806ATI0`3<c<`304a<C080oooo0`20P80303<c<`<0C4a<0P0c<c<3
04a<C0<0IVIV0P0c<c<30>KViP<06ATI0`2c/k<206IVIP<0VIVI0`1<C4`203<c<`<000001P20P802
09VIV@<0c<c<0`3oool20820P0<000000`2IVIT306IVIP80P8200`00000306IVIP806ATI1P3<c<`2
0?ooo`<0c<c<0`0c<c<30;>c/`80C4a<0`0c<c<30?ooo`80VIVI0`20P80304a<C0<0IVIV0P2IVIT3
04a<C0<0<c<c203Vi^H30<c<c080C4a<0`2IVIT50820P0T000000P3<c<`30820P0P0dLfY00060=7=
Z@<0oooo0P20P8030>KViPH0P8200P1<C4`301TI6@<0/k>c0P3oool304a<C0H0P8201@1<C4`30820
P080<c<c0`2c/k<304a<C0<0P8201@3<c<`503<c<`<0oooo0`2c/k<30820P080c<c<0`1VIVH30>KV
iPD0/k>c0`3oool303<c<`806ATI1P20P80203<c<`<06ATI0`3Vi^H201TI6@<0oooo0`20P8030<c<
c080IVIV0`1<C4`30<c<c0D000000`2IVIT80820P0<0IVIV1@3oool301TI6@<0oooo0P3<c<`309VI
V@<0P8200P3Vi^H304a<C0H0IVIV0P0I6AT30<c<c0<0C4a<0P3oool30820P0<0<c<c0`1<C4`203<c
<`<0C4a<0`1VIVH203<c<`<0i^KV0`0I6AT30;>c/`80IVIV0`2IVIT304a<C080<c<c0`0000060820
P080VIVI0`3<c<`30?ooo`80P8200`00000309VIV@<0IVIV0P20P803000000<0IVIV0P0I6AT60<c<
c080oooo0`3<c<`303<c<`<0/k>c0P1<C4`303<c<`<0oooo0P2IVIT30820P0<0C4a<0`1VIVH209VI
V@<0C4a<0`0c<c<80>KViP<0c<c<0P1<C4`309VIV@D0P8202@0000020<c<c0<0P820203AcJT000H0
dLfY1@3oool30<c<c0<06ATI0`3oool201TI6@<0c<c<0`3Vi^H20<c<c0<0<c<c0`1VIVH301TI6@80
IVIV0`00000301TI6@80oooo0`00000306IVIP<000000P1<C4`303<c<`<000000P2c/k<604a<C0<0
6ATI0P1VIVH303<c<`D0oooo0`1<C4`301TI6@<0VIVI0P2c/k<30<c<c0<0P8200P3<c<`304a<C0<0
oooo0P1<C4`30?ooo`<0IVIV0`2c/k<209VIV@<0<c<c0`3oool804a<C0<0VIVI0P3Vi^H309VIV@<0
i^KV202IVIT301TI6@80/k>c0`00000304a<C080VIVI0`20P8030;>c/`<0IVIV0P0000030;>c/`<0
00000P0c<c<301TI6@<0oooo0`00000201TI6@<0c<c<0`1VIVH209VIV@<0c<c<0`0I6AT30<c<c080
00000`3<c<`309VIV@80<c<c1P1<C4`309VIV@80C4a<0`2c/k<300000080P8200`3<c<`304a<C0<0
00000P3<c<`60820P080/k>c0`3<c<`30;>c/`D0VIVI0`20P80300000080oooo0`0000050;>c/`<0
P8200`0c<c<306IVIP8000000`3Vi^H30820P080/k>c0`0I6AT3000000<0P8200P1VIVH3000000<0
C4a<0P2IVIT;04a<C0<0/k>c203AcJT000H0dLfY1@3oool30<c<c0<06ATI0`3oool201TI6@<0c<c<
0`3Vi^H20<c<c0<0<c<c0`1VIVH301TI6@80IVIV0`00000301TI6@80oooo0`00000306IVIP<00000
0P1<C4`303<c<`<000000P2c/k<604a<C0<06ATI0P1VIVH303<c<`D0oooo0`1<C4`301TI6@<0VIVI
0P2c/k<30<c<c0<0P8200P3<c<`304a<C0<0oooo0P1<C4`30?ooo`<0IVIV0`2c/k<209VIV@<0<c<c
0`3oool804a<C0<0VIVI0P3Vi^H309VIV@<0i^KV202IVIT301TI6@80/k>c0`00000304a<C080VIVI
0`20P8030;>c/`<0IVIV0P0000030;>c/`<000000P0c<c<301TI6@<0oooo0`00000201TI6@<0c<c<
0`1VIVH209VIV@<0c<c<0`0I6AT30<c<c08000000`3<c<`309VIV@80<c<c1P1<C4`309VIV@80C4a<
0`2c/k<300000080P8200`3<c<`304a<C0<000000P3<c<`60820P080/k>c0`3<c<`30;>c/`D0VIVI
0`20P80300000080oooo0`0000050;>c/`<0P8200`0c<c<306IVIP8000000`3Vi^H30820P080/k>c
0`0I6AT3000000<0P8200P1VIVH3000000<0C4a<0P2IVIT;04a<C0<0/k>c203AcJT000H0dLfY1@3o
ool30<c<c0<06ATI0`3oool201TI6@<0c<c<0`3Vi^H20<c<c0<0<c<c0`1VIVH301TI6@80IVIV0`00
000301TI6@80oooo0`00000306IVIP<000000P1<C4`303<c<`<000000P2c/k<604a<C0<06ATI0P1V
IVH303<c<`D0oooo0`1<C4`301TI6@<0VIVI0P2c/k<30<c<c0<0P8200P3<c<`304a<C0<0oooo0P1<
C4`30?ooo`<0IVIV0`2c/k<209VIV@<0<c<c0`3oool804a<C0<0VIVI0P3Vi^H309VIV@<0i^KV202I
VIT301TI6@80/k>c0`00000304a<C080VIVI0`20P8030;>c/`<0IVIV0P0000030;>c/`<000000P0c
<c<301TI6@<0oooo0`00000201TI6@<0c<c<0`1VIVH209VIV@<0c<c<0`0I6AT30<c<c08000000`3<
c<`309VIV@80<c<c1P1<C4`309VIV@80C4a<0`2c/k<300000080P8200`3<c<`304a<C0<000000P3<
c<`60820P080/k>c0`3<c<`30;>c/`D0VIVI0`20P80300000080oooo0`0000050;>c/`<0P8200`0c
<c<306IVIP8000000`3Vi^H30820P080/k>c0`0I6AT3000000<0P8200P1VIVH3000000<0C4a<0P2I
VIT;04a<C0<0/k>c203AcJT000H0dLfY203oool30>KViP<0IVIV0P3Vi^H30?ooo`D0i^KV0`0c<c<3
04a<C0<0P8200P2IVIT303<c<`<0c<c<0P1<C4`30<c<c0<0i^KV1@00000301TI6@<0c<c<0P1<C4`3
01TI6@<0<c<c0`3Vi^H20?ooo`<0/k>c1@1<C4`303<c<`<0i^KV0`3oool20<c<c0<0/k>c0`000002
04a<C0<06ATI0`3Vi^H204a<C0H0P8200`0c<c<2000000<0C4a<0`1VIVH20?ooo`<000000`2c/k<3
0>KViP80/k>c0`2IVIT30?ooo`80IVIV0`0I6AT30?ooo`<0c<c<0P1<C4`30;>c/`<06ATI0P3Vi^H3
01TI6@<0IVIV0`0c<c<506IVIP<0c<c<0P0c<c<30>KViP<0IVIV1@3Vi^H30?ooo`<0i^KV0P2IVIT3
06IVIP<0<c<c0`3Vi^H503<c<`<0VIVI0P3oool3000000<06ATI0`3Vi^H201TI6@<0C4a<1@0I6AT3
06IVIP<0<c<c0`3Vi^H20?ooo`<0C4a<0`2IVIT204a<C0<0/k>c0`2IVIT206IVIP<0c<c<0`000003
03<c<`D0c<c<0`1<C4`201TI6@<0P8200`0c<c<304a<C0D0P8200`3oool20<c<c0<000001P2IVIT2
0>KViP<0VIVI0`0000020<c<c0<000000`0I6AT30<c<c080oooo0`2IVIT80=7=Z@001P3AcJT80?oo
o`<0i^KV0`1VIVH20>KViP<0oooo1@3Vi^H303<c<`<0C4a<0`20P80209VIV@<0<c<c0`3<c<`204a<
C0<0c<c<0`3Vi^H5000000<06ATI0`3<c<`204a<C0<06ATI0`0c<c<30>KViP80oooo0`2c/k<504a<
C0<0<c<c0`3Vi^H30?ooo`80c<c<0`2c/k<300000080C4a<0`0I6AT30>KViP80C4a<1P20P80303<c
<`8000000`1<C4`306IVIP80oooo0`0000030;>c/`<0i^KV0P2c/k<309VIV@<0oooo0P1VIVH301TI
6@<0oooo0`3<c<`204a<C0<0/k>c0`0I6AT20>KViP<06ATI0`1VIVH303<c<`D0IVIV0`3<c<`203<c
<`<0i^KV0`1VIVH50>KViP<0oooo0`3Vi^H209VIV@<0IVIV0`0c<c<30>KViPD0<c<c0`2IVIT20?oo
o`<000000`0I6AT30>KViP806ATI0`1<C4`501TI6@<0IVIV0`0c<c<30>KViP80oooo0`1<C4`309VI
V@80C4a<0`2c/k<309VIV@80IVIV0`3<c<`3000000<0<c<c1@3<c<`304a<C0806ATI0`20P80303<c
<`<0C4a<1@20P8030?ooo`80c<c<0`00000609VIV@80i^KV0`2IVIT300000080c<c<0`00000301TI
6@<0c<c<0P3oool309VIV@P0dLfY00060=7=Z@P0oooo0`3Vi^H306IVIP80i^KV0`3oool50>KViP<0
<c<c0`1<C4`30820P080VIVI0`0c<c<30<c<c080C4a<0`3<c<`30>KViPD000000`0I6AT30<c<c080
C4a<0`0I6AT303<c<`<0i^KV0P3oool30;>c/`D0C4a<0`0c<c<30>KViP<0oooo0P3<c<`30;>c/`<0
00000P1<C4`301TI6@<0i^KV0P1<C4`60820P0<0<c<c0P00000304a<C0<0IVIV0P3oool3000000<0
/k>c0`3Vi^H20;>c/`<0VIVI0`3oool206IVIP<06ATI0`3oool30<c<c080C4a<0`2c/k<301TI6@80
i^KV0`0I6AT306IVIP<0<c<c1@1VIVH30<c<c080<c<c0`3Vi^H306IVIPD0i^KV0`3oool30>KViP80
VIVI0`1VIVH303<c<`<0i^KV1@0c<c<309VIV@80oooo0`00000301TI6@<0i^KV0P0I6AT304a<C0D0
6ATI0`1VIVH303<c<`<0i^KV0P3oool304a<C0<0VIVI0P1<C4`30;>c/`<0VIVI0P1VIVH30<c<c0<0
00000`0c<c<50<c<c0<0C4a<0P0I6AT30820P0<0<c<c0`1<C4`50820P0<0oooo0P3<c<`3000000H0
VIVI0P3Vi^H309VIV@<000000P3<c<`3000000<06ATI0`3<c<`20?ooo`<0VIVI203AcJT000H0dLfY
3P3oool201TI6@H0VIVI0P20P8030?ooo`<0VIVI0`0c<c<20820P0<0<c<c0`3Vi^H20<c<c0<0IVIV
0`3Vi^H303<c<`80c<c<0`0c<c<30>KViP80<c<c0`1<C4`30?ooo`<000001@20P80304a<C080P820
0`0I6AT303<c<`D0/k>c0`2IVIT506IVIP<0VIVI0`0I6AT209VIV@<0<c<c0`20P80303<c<`D0C4a<
0`20P80203<c<`<06ATI0`2c/k<30820P080oooo0`3Vi^H301TI6@80VIVI0`3<c<`60>KViP80c<c<
0`1VIVH30<c<c080C4a<0`3<c<`304a<C0<0P8200P2IVIT30>KViP<000000P1VIVH30820P0<0oooo
1@2c/k<601TI6@8000000`1<C4`30820P0<0/k>c0P0000030;>c/`<0C4a<0P0I6AT3000000<0VIVI
0`0I6AT209VIV@<06ATI0`0c<c<20<c<c0<0i^KV0`2IVIT303<c<`806ATI0`2IVIT30<c<c080VIVI
0`0c<c<309VIV@80IVIV0`0000030?ooo`<0P8200P0000030?ooo`<0i^KV0P20P80309VIV@<0C4a<
0`1VIVH209VIV@<0C4a<1@2IVIT306IVIP<0oooo0`3<c<`209VIV@<0P8200`3<c<`20>KViPH0<c<c
0`1<C4`203<c<`<06ATI203AcJT000H0dLfY3P3oool201TI6@H0VIVI0P20P8030?ooo`<0VIVI0`0c
<c<20820P0<0<c<c0`3Vi^H20<c<c0<0IVIV0`3Vi^H303<c<`80c<c<0`0c<c<30>KViP80<c<c0`1<
C4`30?ooo`<000001@20P80304a<C080P8200`0I6AT303<c<`D0/k>c0`2IVIT506IVIP<0VIVI0`0I
6AT209VIV@<0<c<c0`20P80303<c<`D0C4a<0`20P80203<c<`<06ATI0`2c/k<30820P080oooo0`3V
i^H301TI6@80VIVI0`3<c<`60>KViP80c<c<0`1VIVH30<c<c080C4a<0`3<c<`304a<C0<0P8200P2I
VIT30>KViP<000000P1VIVH30820P0<0oooo1@2c/k<601TI6@8000000`1<C4`30820P0<0/k>c0P00
00030;>c/`<0C4a<0P0I6AT3000000<0VIVI0`0I6AT209VIV@<06ATI0`0c<c<20<c<c0<0i^KV0`2I
VIT303<c<`806ATI0`2IVIT30<c<c080VIVI0`0c<c<309VIV@80IVIV0`0000030?ooo`<0P8200P00
00030?ooo`<0i^KV0P20P80309VIV@<0C4a<0`1VIVH209VIV@<0C4a<1@2IVIT306IVIP<0oooo0`3<
c<`209VIV@<0P8200`3<c<`20>KViPH0<c<c0`1<C4`203<c<`<06ATI203AcJT000H0dLfY3P3oool2
01TI6@H0VIVI0P20P8030?ooo`<0VIVI0`0c<c<20820P0<0<c<c0`3Vi^H20<c<c0<0IVIV0`3Vi^H3
03<c<`80c<c<0`0c<c<30>KViP80<c<c0`1<C4`30?ooo`<000001@20P80304a<C080P8200`0I6AT3
03<c<`D0/k>c0`2IVIT506IVIP<0VIVI0`0I6AT209VIV@<0<c<c0`20P80303<c<`D0C4a<0`20P802
03<c<`<06ATI0`2c/k<30820P080oooo0`3Vi^H301TI6@80VIVI0`3<c<`60>KViP80c<c<0`1VIVH3
0<c<c080C4a<0`3<c<`304a<C0<0P8200P2IVIT30>KViP<000000P1VIVH30820P0<0oooo1@2c/k<6
01TI6@8000000`1<C4`30820P0<0/k>c0P0000030;>c/`<0C4a<0P0I6AT3000000<0VIVI0`0I6AT2
09VIV@<06ATI0`0c<c<20<c<c0<0i^KV0`2IVIT303<c<`806ATI0`2IVIT30<c<c080VIVI0`0c<c<3
09VIV@80IVIV0`0000030?ooo`<0P8200P0000030?ooo`<0i^KV0P20P80309VIV@<0C4a<0`1VIVH2
09VIV@<0C4a<1@2IVIT306IVIP<0oooo0`3<c<`209VIV@<0P8200`3<c<`20>KViPH0<c<c0`1<C4`2
03<c<`<06ATI203AcJT000H0dLfY403oool30820P0<0i^KV0P0I6AT606IVIP<06ATI0P3<c<`30820
P0<0/k>c0P0000030?ooo`<0/k>c0`2IVIT20<c<c0<06ATI0`0c<c<20;>c/`<0<c<c0`3oool506IV
IP<0/k>c0`1VIVH209VIV@H0C4a<0`3oool20>KViP<06ATI0`3oool20;>c/`<0IVIV0`0I6AT20<c<
c0<000000`0I6AT304a<C080oooo0`2IVIT30<c<c080P8200`2IVIT30;>c/`<0P8201@3<c<`30;>c
/`80c<c<0`2IVIT30820P0<0IVIV0P3Vi^H30<c<c0<0P8200P1VIVH3000000<0IVIV0`2IVIT204a<
C0<0/k>c0`00000209VIV@<0C4a<0`0000030820P080i^KV0`2c/k<30<c<c0D0C4a<0`20P80303<c
<`80VIVI0`0000030?ooo`8000001P2IVIT30>KViP80oooo0`3<c<`304a<C080IVIV0`3Vi^H304a<
C0<000000P2c/k<303<c<`<0P8200P3oool303<c<`<0C4a<0P2IVIT30<c<c0<0i^KV0`1<C4`209VI
V@H06ATI0P00000304a<C0<000000`2c/k<20?ooo`<0<c<c0`1VIVH201TI6@<0oooo1P2c/k<209VI
V@<0IVIV0`0I6AT20820P0<0oooo0`2IVIT301TI6@80c<c<0`3Vi^H80=7=Z@001P3AcJT@0?ooo`<0
P8200`3Vi^H201TI6@H0IVIV0`0I6AT20<c<c0<0P8200`2c/k<2000000<0oooo0`2c/k<309VIV@80
c<c<0`0I6AT303<c<`80/k>c0`0c<c<30?ooo`D0IVIV0`2c/k<306IVIP80VIVI1P1<C4`30?ooo`80
i^KV0`0I6AT30?ooo`80/k>c0`1VIVH301TI6@80c<c<0`00000301TI6@<0C4a<0P3oool309VIV@<0
c<c<0P20P80309VIV@<0/k>c0`20P8050<c<c0<0/k>c0P3<c<`309VIV@<0P8200`1VIVH20>KViP<0
c<c<0`20P80206IVIP<000000`1VIVH309VIV@80C4a<0`2c/k<300000080VIVI0`1<C4`3000000<0
P8200P3Vi^H30;>c/`<0c<c<1@1<C4`30820P0<0<c<c0P2IVIT3000000<0oooo0P00000609VIV@<0
i^KV0P3oool30<c<c0<0C4a<0P1VIVH30>KViP<0C4a<0`0000020;>c/`<0<c<c0`20P8020?ooo`<0
<c<c0`1<C4`209VIV@<0c<c<0`3Vi^H304a<C080VIVI1P0I6AT2000000<0C4a<0`0000030;>c/`80
oooo0`0c<c<306IVIP806ATI0`3oool60;>c/`80VIVI0`1VIVH301TI6@80P8200`3oool309VIV@<0
6ATI0P3<c<`30>KViPP0dLfY00060=7=ZA<0oooo0`3<c<`201TI6@<0/k>c0`3oool301TI6@80<c<c
0`0000030>KViP806ATI1P2c/k<30820P080i^KV1P0c<c<20>KViP<0/k>c0`3Vi^H304a<C080P820
0`3<c<`300000080c<c<0`2IVIT303<c<`D0IVIV0`1<C4`506IVIP<0<c<c0`1VIVH20820P0<0C4a<
0`3Vi^H306IVIPD0VIVI0`1VIVH204a<C0<000000`1<C4`30;>c/`80IVIV0`3Vi^H303<c<`80VIVI
0`20P80304a<C0<000000P0c<c<30;>c/`<0VIVI0P1<C4`60820P0<0c<c<0P00000303<c<`D00000
0`1<C4`306IVIP<0oooo0P3<c<`303<c<`<000000P1VIVH309VIV@<0<c<c0`20P802000000<0i^KV
0`1VIVH204a<C0<0i^KV0`2c/k<30820P080IVIV0`3oool304a<C080P8200`0c<c<301TI6@<0<c<c
0P3<c<`309VIV@<0/k>c1@3oool309VIV@80<c<c0`20P8030?ooo`<0IVIV0P00000604a<C080i^KV
0`3oool3000000<0VIVI0P1VIVH30?ooo`<000000P0c<c<604a<C0<06ATI0P20P80303<c<`<0oooo
0P20P8060<c<c0<0VIVI0P0I6AT30820P0P0dLfY00060=7=ZA<0oooo0`3<c<`201TI6@<0/k>c0`3o
ool301TI6@80<c<c0`0000030>KViP806ATI1P2c/k<30820P080i^KV1P0c<c<20>KViP<0/k>c0`3V
i^H304a<C080P8200`3<c<`300000080c<c<0`2IVIT303<c<`D0IVIV0`1<C4`506IVIP<0<c<c0`1V
IVH20820P0<0C4a<0`3Vi^H306IVIPD0VIVI0`1VIVH204a<C0<000000`1<C4`30;>c/`80IVIV0`3V
i^H303<c<`80VIVI0`20P80304a<C0<000000P0c<c<30;>c/`<0VIVI0P1<C4`60820P0<0c<c<0P00
000303<c<`D000000`1<C4`306IVIP<0oooo0P3<c<`303<c<`<000000P1VIVH309VIV@<0<c<c0`20
P802000000<0i^KV0`1VIVH204a<C0<0i^KV0`2c/k<30820P080IVIV0`3oool304a<C080P8200`0c
<c<301TI6@<0<c<c0P3<c<`309VIV@<0/k>c1@3oool309VIV@80<c<c0`20P8030?ooo`<0IVIV0P00
000604a<C080i^KV0`3oool3000000<0VIVI0P1VIVH30?ooo`<000000P0c<c<604a<C0<06ATI0P20
P80303<c<`<0oooo0P20P8060<c<c0<0VIVI0P0I6AT30820P0P0dLfY00060=7=ZA<0oooo0`3<c<`2
01TI6@<0/k>c0`3oool301TI6@80<c<c0`0000030>KViP806ATI1P2c/k<30820P080i^KV1P0c<c<2
0>KViP<0/k>c0`3Vi^H304a<C080P8200`3<c<`300000080c<c<0`2IVIT303<c<`D0IVIV0`1<C4`5
06IVIP<0<c<c0`1VIVH20820P0<0C4a<0`3Vi^H306IVIPD0VIVI0`1VIVH204a<C0<000000`1<C4`3
0;>c/`80IVIV0`3Vi^H303<c<`80VIVI0`20P80304a<C0<000000P0c<c<30;>c/`<0VIVI0P1<C4`6
0820P0<0c<c<0P00000303<c<`D000000`1<C4`306IVIP<0oooo0P3<c<`303<c<`<000000P1VIVH3
09VIV@<0<c<c0`20P802000000<0i^KV0`1VIVH204a<C0<0i^KV0`2c/k<30820P080IVIV0`3oool3
04a<C080P8200`0c<c<301TI6@<0<c<c0P3<c<`309VIV@<0/k>c1@3oool309VIV@80<c<c0`20P803
0?ooo`<0IVIV0P00000604a<C080i^KV0`3oool3000000<0VIVI0P1VIVH30?ooo`<000000P0c<c<6
04a<C0<06ATI0P20P80303<c<`<0oooo0P20P8060<c<c0<0VIVI0P0I6AT30820P0P0dLfY00060=7=
ZAH0oooo0P3Vi^H306IVIPH0c<c<0P1<C4`606IVIP80i^KV0`1VIVH30<c<c0<0VIVI0P3Vi^H30<c<
c0<0oooo0P0000030820P0<0C4a<0`3<c<`206IVIP<0/k>c0`2IVIT2000000<0oooo0`3<c<`306IV
IP8000000`3<c<`306IVIP80VIVI0`3<c<`30?ooo`806ATI0`1VIVH3000000<0P8200P0I6AT30?oo
o`<0c<c<0P20P80601TI6@<0C4a<0P0I6AT304a<C0<0c<c<0P1VIVH301TI6@<0oooo0`00000209VI
V@<0<c<c0`00000204a<C0<0P8200`0c<c<30820P080C4a<0`3Vi^H306IVIP80oooo0`20P80301TI
6@<0C4a<0P3Vi^H303<c<`D0C4a<0`20P8030<c<c0<0oooo0P0I6AT30;>c/`<0VIVI0P3<c<`60?oo
o`<0C4a<0P00000303<c<`<0/k>c0P3Vi^H309VIV@<0/k>c0`3<c<`206IVIP<0C4a<0`0000020?oo
o`<0IVIV0`3oool203<c<`<0C4a<1P2IVIT203<c<`<0c<c<0`1VIVH509VIV@H000000P1<C4`309VI
V@D000000`0I6AT303<c<`<0i^KV0P3oool30;>c/`<0i^KV0P1<C4`309VIV@<0P8200`1VIVH201TI
6@<0/k>c203AcJT000H0dLfY5P3oool20>KViP<0IVIV1P3<c<`204a<C0H0IVIV0P3Vi^H306IVIP<0
c<c<0`2IVIT20>KViP<0c<c<0`3oool2000000<0P8200`1<C4`30<c<c080IVIV0`2c/k<309VIV@80
00000`3oool30<c<c0<0IVIV0P0000030<c<c0<0IVIV0P2IVIT30<c<c0<0oooo0P0I6AT306IVIP<0
00000`20P80201TI6@<0oooo0`3<c<`20820P0H06ATI0`1<C4`201TI6@<0C4a<0`3<c<`206IVIP<0
6ATI0`3oool300000080VIVI0`0c<c<300000080C4a<0`20P80303<c<`<0P8200P1<C4`30>KViP<0
IVIV0P3oool30820P0<06ATI0`1<C4`20>KViP<0<c<c1@1<C4`30820P0<0c<c<0`3oool201TI6@<0
/k>c0`2IVIT20<c<c0H0oooo0`1<C4`2000000<0<c<c0`2c/k<20>KViP<0VIVI0`2c/k<30<c<c080
IVIV0`1<C4`300000080oooo0`1VIVH30?ooo`80<c<c0`1<C4`609VIV@80<c<c0`3<c<`306IVIPD0
VIVI1P00000204a<C0<0VIVI1@00000301TI6@<0<c<c0`3Vi^H20?ooo`<0/k>c0`3Vi^H204a<C0<0
VIVI0`20P80306IVIP806ATI0`2c/k<80=7=Z@001P3AcJTF0?ooo`80i^KV0`1VIVH60<c<c080C4a<
1P1VIVH20>KViP<0IVIV0`3<c<`309VIV@80i^KV0`3<c<`30?ooo`8000000`20P80304a<C0<0c<c<
0P1VIVH30;>c/`<0VIVI0P0000030?ooo`<0c<c<0`1VIVH2000000<0c<c<0`1VIVH209VIV@<0c<c<
0`3oool201TI6@<0IVIV0`0000030820P0806ATI0`3oool30<c<c080P8201P0I6AT304a<C0806ATI
0`1<C4`30<c<c080IVIV0`0I6AT30?ooo`<000000P2IVIT303<c<`<000000P1<C4`30820P0<0<c<c
0`20P80204a<C0<0i^KV0`1VIVH20?ooo`<0P8200`0I6AT304a<C080i^KV0`0c<c<504a<C0<0P820
0`3<c<`30?ooo`806ATI0`2c/k<309VIV@80c<c<1P3oool304a<C08000000`0c<c<30;>c/`80i^KV
0`2IVIT30;>c/`<0c<c<0P1VIVH304a<C0<000000P3oool306IVIP<0oooo0P0c<c<304a<C0H0VIVI
0P0c<c<30<c<c0<0IVIV1@2IVIT600000080C4a<0`2IVIT5000000<06ATI0`0c<c<30>KViP80oooo
0`2c/k<30>KViP80C4a<0`2IVIT30820P0<0IVIV0P0I6AT30;>c/`P0dLfY00060=7=ZA/0oooo0`0I
6AT30820P080oooo0`0000030<c<c080P8200`1VIVH30;>c/`<000000P1<C4`30<c<c0D0/k>c0`0I
6AT30?ooo`<000000P3oool30;>c/`<0P8200P3<c<`30>KViP<0C4a<0`2c/k<20>KViP<0oooo0`1<
C4`20820P0<0i^KV0`0c<c<20;>c/`<0c<c<0`1VIVH30?ooo`80/k>c1P3<c<`20;>c/`<0IVIV0`20
P803000000806ATI0`2c/k<30>KViP80c<c<0`20P803000000D0P8200`3<c<`30>KViP80oooo0`00
00030<c<c0<0oooo0P0I6AT30>KViP<0<c<c1@3oool30;>c/`<0c<c<0P1VIVH30>KViP<0P8200P0I
6AT304a<C0<000000`1VIVH20>KViP<0oooo0`3Vi^H201TI6@<0VIVI0`0000030820P080/k>c0`0I
6AT30<c<c080/k>c0`0000030>KViP<0c<c<0P0I6AT304a<C0<0IVIV1@3oool50;>c/`<0<c<c0`3o
ool303<c<`80P8200`2c/k<300000080<c<c0`20P8080<c<c0<0oooo0`3<c<`203<c<`<0c<c<0`1<
C4`306IVIPD0i^KV0`3<c<`201TI6@<0i^KV0`0I6AT306IVIP8000000`2IVIT80=7=Z@001P3AcJTK
0?ooo`<06ATI0`20P8020?ooo`<000000`3<c<`20820P0<0IVIV0`2c/k<300000080C4a<0`3<c<`5
0;>c/`<06ATI0`3oool300000080oooo0`2c/k<30820P080c<c<0`3Vi^H304a<C0<0/k>c0P3Vi^H3
0?ooo`<0C4a<0P20P8030>KViP<0<c<c0P2c/k<30<c<c0<0IVIV0`3oool20;>c/`H0c<c<0P2c/k<3
06IVIP<0P8200`00000201TI6@<0/k>c0`3Vi^H20<c<c0<0P8200`0000050820P0<0c<c<0`3Vi^H2
0?ooo`<000000`3<c<`30?ooo`806ATI0`3Vi^H303<c<`D0oooo0`2c/k<30<c<c080IVIV0`3Vi^H3
0820P0806ATI0`1<C4`3000000<0IVIV0P3Vi^H30?ooo`<0i^KV0P0I6AT309VIV@<000000`20P802
0;>c/`<06ATI0`3<c<`20;>c/`<000000`3Vi^H30<c<c0806ATI0`1<C4`306IVIPD0oooo1@2c/k<3
03<c<`<0oooo0`0c<c<20820P0<0/k>c0`00000203<c<`<0P820203<c<`30?ooo`<0c<c<0P0c<c<3
0<c<c0<0C4a<0`1VIVH50>KViP<0c<c<0P0I6AT30>KViP<06ATI0`1VIVH2000000<0VIVI203AcJT0
00H0dLfY7P3oool30820P0D0c<c<0`1<C4`201TI6@<0oooo0`0I6AT306IVIP80oooo0`2c/k<30000
0080IVIV0`0c<c<304a<C0<0<c<c1@3<c<`309VIV@80i^KV0`3<c<`30;>c/`<0i^KV0P3<c<`303<c
<`<06ATI0P3Vi^H301TI6@<000000P0I6AT30820P0<0IVIV0`0I6AT2000000<0oooo0`1<C4`20<c<
c0<000000`3<c<`50820P0<0VIVI0`1VIVH20>KViP<0c<c<1P20P8020<c<c0<0P8200`3oool206IV
IP<0C4a<0`3Vi^H50<c<c0<0C4a<0`3<c<`806IVIP<0<c<c0P2IVIT30>KViP<0C4a<1@0000060;>c
/`80oooo1P1VIVH204a<C0<0IVIV0`0I6AT30;>c/`80IVIV0`3<c<`304a<C080c<c<0`00000309VI
V@<0P8200P3Vi^H30?ooo`<0VIVI0P3Vi^H304a<C0<0i^KV0P0c<c<3000000<06ATI0`2IVIT20;>c
/`<0oooo1@3<c<`30?ooo`<0<c<c0`0000020?ooo`H0i^KV0P3<c<`306IVIP<0<c<c0`3oool201TI
6@<0VIVI0`20P8020>KViP<0oooo0`3Vi^H30?ooo`80/k>c0`0I6AT80=7=Z@001P3AcJTN0?ooo`<0
P8201@3<c<`304a<C0806ATI0`3oool301TI6@<0IVIV0P3oool30;>c/`<000000P1VIVH303<c<`<0
C4a<0`0c<c<50<c<c0<0VIVI0P3Vi^H30<c<c0<0/k>c0`3Vi^H20<c<c0<0<c<c0`0I6AT20>KViP<0
6ATI0`00000201TI6@<0P8200`1VIVH301TI6@8000000`3oool304a<C080c<c<0`0000030<c<c0D0
P8200`2IVIT306IVIP80i^KV0`3<c<`60820P080c<c<0`20P8030?ooo`80IVIV0`1<C4`30>KViPD0
c<c<0`1<C4`30<c<c0P0IVIV0`0c<c<209VIV@<0i^KV0`1<C4`5000000H0/k>c0P3oool606IVIP80
C4a<0`1VIVH301TI6@<0/k>c0P1VIVH30<c<c0<0C4a<0P3<c<`3000000<0VIVI0`20P8020>KViP<0
oooo0`2IVIT20>KViP<0C4a<0`3Vi^H203<c<`<000000`0I6AT309VIV@80/k>c0`3oool50<c<c0<0
oooo0`0c<c<300000080oooo1P3Vi^H20<c<c0<0IVIV0`0c<c<30?ooo`806ATI0`2IVIT30820P080
i^KV0`3oool30>KViP<0oooo0P2c/k<301TI6@P0dLfY00060=7=ZAh0oooo0`20P8050<c<c0<0C4a<
0P0I6AT30?ooo`<06ATI0`1VIVH20?ooo`<0/k>c0`00000206IVIP<0<c<c0`1<C4`303<c<`D0c<c<
0`2IVIT20>KViP<0c<c<0`2c/k<30>KViP80c<c<0`0c<c<301TI6@80i^KV0`0I6AT3000000806ATI
0`20P80306IVIP<06ATI0P0000030?ooo`<0C4a<0P3<c<`3000000<0c<c<1@20P80309VIV@<0IVIV
0P3Vi^H30<c<c0H0P8200P3<c<`30820P0<0oooo0P1VIVH304a<C0<0i^KV1@3<c<`304a<C0<0c<c<
201VIVH303<c<`80VIVI0`3Vi^H304a<C0D000001P2c/k<20?ooo`H0IVIV0P1<C4`306IVIP<06ATI
0`2c/k<206IVIP<0c<c<0`1<C4`20<c<c0<000000`2IVIT30820P080i^KV0`3oool309VIV@80i^KV
0`1<C4`30>KViP80<c<c0`00000301TI6@<0VIVI0P2c/k<30?ooo`D0c<c<0`3oool303<c<`<00000
0P3oool60>KViP80c<c<0`1VIVH303<c<`<0oooo0P0I6AT309VIV@<0P8200P3Vi^H30?ooo`<0i^KV
0`3oool20;>c/`<06ATI203AcJT000H0dLfY8@3oool20<c<c0<06ATI0`20P8020;>c/`<0<c<c0`2c
/k<30<c<c0D0P8201@1<C4`30820P0<0VIVI0`3<c<`206IVIP<0C4a<0`0I6AT50?ooo`<0C4a<1@2c
/k<3000000<06ATI0P0c<c<601TI6@80/k>c0`0c<c<30820P0<06ATI0P2c/k<30<c<c0<0<c<c0P1V
IVH303<c<`<0c<c<0`2c/k<206IVIP<0/k>c0`20P80203<c<`<06ATI0`20P8030<c<c080P8200`3o
ool303<c<`806ATI0`3Vi^H30820P0<0oooo0P3Vi^H30<c<c0<0IVIV0P3Vi^H3000000<0<c<c0`1V
IVH20820P0<0i^KV0`0c<c<50>KViP<0oooo0`1<C4`201TI6@<0VIVI0`3Vi^H2000000<06ATI0`3V
i^H306IVIP80c<c<0`20P80306IVIP8000001P1VIVH30;>c/`D0oooo0`1VIVH20<c<c0<06ATI0`3V
i^H203<c<`<0i^KV0`1<C4`30?ooo`80<c<c1P2IVIT20820P0<0IVIV0`1<C4`30?ooo`D0P8200`1V
IVH20>KViP<0c<c<0`20P80301TI6@8000000`2IVIT30?ooo`80<c<c0`0I6AT30;>c/`<06ATI0P00
00030>KViPP0dLfY00060=7=ZB40oooo0P3<c<`301TI6@<0P8200P2c/k<303<c<`<0/k>c0`3<c<`5
0820P0D0C4a<0`20P80309VIV@<0c<c<0P1VIVH304a<C0<06ATI1@3oool304a<C0D0/k>c0`000003
01TI6@80<c<c1P0I6AT20;>c/`<0<c<c0`20P80301TI6@80/k>c0`3<c<`303<c<`80IVIV0`0c<c<3
0<c<c0<0/k>c0P1VIVH30;>c/`<0P8200P0c<c<301TI6@<0P8200`3<c<`20820P0<0oooo0`0c<c<2
01TI6@<0i^KV0`20P8030?ooo`80i^KV0`3<c<`306IVIP80i^KV0`00000303<c<`<0IVIV0P20P803
0>KViP<0<c<c1@3Vi^H30?ooo`<0C4a<0P0I6AT309VIV@<0i^KV0P00000301TI6@<0i^KV0`1VIVH2
0<c<c0<0P8200`1VIVH2000000H0IVIV0`2c/k<50?ooo`<0IVIV0P3<c<`301TI6@<0i^KV0P0c<c<3
0>KViP<0C4a<0`3oool203<c<`H0VIVI0P20P80306IVIP<0C4a<0`3oool50820P0<0IVIV0P3Vi^H3
0<c<c0<0P8200`0I6AT2000000<0VIVI0`3oool203<c<`<06ATI0`2c/k<301TI6@8000000`3Vi^H8
0=7=Z@001P3AcJTQ0?ooo`80c<c<0`0I6AT30820P080/k>c0`0c<c<30;>c/`<0c<c<1@20P80504a<
C0<0P8200`2IVIT30<c<c080IVIV0`1<C4`301TI6@D0oooo0`1<C4`50;>c/`<000000`0I6AT203<c
<`H06ATI0P2c/k<303<c<`<0P8200`0I6AT20;>c/`<0c<c<0`0c<c<206IVIP<0<c<c0`3<c<`30;>c
/`80IVIV0`2c/k<30820P080<c<c0`0I6AT30820P0<0c<c<0P20P8030?ooo`<0<c<c0P0I6AT30>KV
iP<0P8200`3oool20>KViP<0c<c<0`1VIVH20>KViP<000000`0c<c<306IVIP80P8200`3Vi^H303<c
<`D0i^KV0`3oool304a<C0806ATI0`2IVIT30>KViP8000000`0I6AT30>KViP<0IVIV0P3<c<`30820
P0<0IVIV0P00000606IVIP<0/k>c1@3oool306IVIP80c<c<0`0I6AT30>KViP80<c<c0`3Vi^H304a<
C0<0oooo0P0c<c<609VIV@80P8200`1VIVH304a<C0<0oooo1@20P80306IVIP80i^KV0`3<c<`30820
P0<06ATI0P00000309VIV@<0oooo0P0c<c<301TI6@<0/k>c0`0I6AT2000000<0i^KV203AcJT000H0
dLfY8`3oool30>KViP<0IVIV0P2c/k<30820P0<0VIVI0`3oool20>KViP<0VIVI0`3Vi^H20820P0<0
/k>c0`1VIVH30<c<c0806ATI0`1<C4`30820P08000000`2IVIT3000000<0<c<c0P00000304a<C0<0
i^KV0P1VIVH30820P0<0VIVI0P0I6AT30820P0<000000`3<c<`20>KViP<0c<c<0`0I6AT203<c<`<0
IVIV0`20P8030?ooo`80<c<c0`3oool30>KViP8000000`2c/k<303<c<`<0P8200P1VIVH301TI6@<0
VIVI0P2c/k<30<c<c0<0/k>c203oool304a<C080P8200`3oool30820P0<000000P3<c<`30820P0<0
oooo0P2IVIT30820P0H0oooo0P2IVIT30;>c/`<0P8201@1VIVH30820P0<0IVIV0P2c/k<3000000<0
<c<c0P3oool30820P0<06ATI0`3Vi^H20<c<c0<0<c<c0`2c/k<20?ooo`<0C4a<0`1VIVH204a<C0<0
IVIV0`3Vi^H309VIV@8000000`0I6AT306IVIP80/k>c0`3oool30;>c/`<0C4a<0P3Vi^H3000000<0
i^KV0P0000030820P0<0IVIV1@0I6AT30;>c/`D0P8200`00000309VIV@<0oooo1@20P8080=7=Z@00
1P3AcJTS0?ooo`<0i^KV0`1VIVH20;>c/`<0P8200`2IVIT30?ooo`80i^KV0`2IVIT30>KViP80P820
0`2c/k<306IVIP<0c<c<0P0I6AT304a<C0<0P8200P00000309VIV@<000000`0c<c<2000000<0C4a<
0`3Vi^H206IVIP<0P8200`2IVIT201TI6@<0P8200`0000030<c<c080i^KV0`3<c<`301TI6@80<c<c
0`1VIVH30820P0<0oooo0P0c<c<30?ooo`<0i^KV0P0000030;>c/`<0<c<c0`20P80206IVIP<06ATI
0`2IVIT20;>c/`<0c<c<0`2c/k<80?ooo`<0C4a<0P20P8030?ooo`<0P8200`0000020<c<c0<0P820
0`3oool209VIV@<0P8201P3oool209VIV@<0/k>c0`20P80506IVIP<0P8200`1VIVH20;>c/`<00000
0`0c<c<20?ooo`<0P8200`0I6AT30>KViP80c<c<0`0c<c<30;>c/`80oooo0`1<C4`306IVIP80C4a<
0`1VIVH30>KViP<0VIVI0P00000301TI6@<0IVIV0P2c/k<30?ooo`<0/k>c0`1<C4`20>KViP<00000
0`3Vi^H2000000<0P8200`1VIVH501TI6@<0/k>c1@20P803000000<0VIVI0`3oool50820P0P0dLfY
00060=7=ZB<0oooo0`3Vi^H306IVIP80/k>c0`20P80309VIV@<0oooo0P3Vi^H309VIV@<0i^KV0P20
P8030;>c/`<0IVIV0`3<c<`201TI6@<0C4a<0`20P802000000<0VIVI0`00000303<c<`8000000`1<
C4`30>KViP80IVIV0`20P80309VIV@806ATI0`20P803000000<0c<c<0P3Vi^H30<c<c0<06ATI0P0c
<c<306IVIP<0P8200`3oool203<c<`<0oooo0`3Vi^H2000000<0/k>c0`0c<c<30820P080IVIV0`0I
6AT309VIV@80/k>c0`3<c<`30;>c/`P0oooo0`1<C4`20820P0<0oooo0`20P80300000080c<c<0`20
P8030?ooo`80VIVI0`20P8060?ooo`80VIVI0`2c/k<30820P0D0IVIV0`20P80306IVIP80/k>c0`00
000303<c<`80oooo0`20P80301TI6@<0i^KV0P3<c<`303<c<`<0/k>c0P3oool304a<C0<0IVIV0P1<
C4`306IVIP<0i^KV0`2IVIT2000000<06ATI0`1VIVH20;>c/`<0oooo0`2c/k<304a<C080i^KV0`00
00030>KViP8000000`20P80306IVIPD06ATI0`2c/k<50820P0<000000`2IVIT30?ooo`D0P820203A
cJT000H0dLfY:@3oool201TI6@<0P8200`0c<c<309VIV@8000000`20P80304a<C080<c<c0`20P803
04a<C0<0P8200P3Vi^H30?ooo`<0VIVI0P3Vi^H306IVIP<06ATI0`2c/k<203<c<`<0c<c<0`1VIVH2
0>KViP<0VIVI0`1<C4`209VIV@<0/k>c1P1VIVH20>KViP<0C4a<0`0I6AT20;>c/`<0i^KV0`000003
04a<C080<c<c1P3Vi^H20<c<c0<0i^KV0`0I6AT30<c<c080P8200`2c/k<30<c<c080VIVI0`1VIVH3
0>KViPP0<c<c0`0I6AT20>KViP<06ATI0`0000030<c<c080i^KV0`0c<c<50820P0<0C4a<0`000003
09VIV@8000000`1<C4`30;>c/`80IVIV0`2IVIT30>KViP<000000P3<c<`609VIV@80c<c<0`0c<c<3
0820P0<000000P20P80304a<C0<0oooo0P3Vi^H304a<C0<0P8200P0I6AT30>KViP<000000`20P802
03<c<`<0c<c<0`1<C4`20820P0H0i^KV0`2c/k<20>KViP<0c<c<0`3Vi^H203<c<`<0c<c<0`20P803
0;>c/`80c<c<0`1<C4`30;>c/`80IVIV0`2c/k<301TI6@D0oooo0`2c/k<80=7=Z@001P3AcJTY0?oo
o`806ATI0`20P80303<c<`<0VIVI0P0000030820P0<0C4a<0P0c<c<30820P0<0C4a<0`20P8020>KV
iP<0oooo0`2IVIT20>KViP<0IVIV0`0I6AT30;>c/`80<c<c0`3<c<`306IVIP80i^KV0`2IVIT304a<
C080VIVI0`2c/k<606IVIP80i^KV0`1<C4`301TI6@80/k>c0`3Vi^H3000000<0C4a<0P0c<c<60>KV
iP80c<c<0`3Vi^H301TI6@<0c<c<0P20P8030;>c/`<0c<c<0P2IVIT306IVIP<0i^KV200c<c<301TI
6@80i^KV0`0I6AT3000000<0c<c<0P3Vi^H303<c<`D0P8200`1<C4`3000000<0VIVI0P00000304a<
C0<0/k>c0P1VIVH309VIV@<0i^KV0`0000020<c<c0H0VIVI0P3<c<`303<c<`<0P8200`0000020820
P0<0C4a<0`3oool20>KViP<0C4a<0`20P80201TI6@<0i^KV0`0000030820P080<c<c0`3<c<`304a<
C080P8201P3Vi^H30;>c/`80i^KV0`3<c<`30>KViP80<c<c0`3<c<`30820P0<0/k>c0P3<c<`304a<
C0<0/k>c0P1VIVH30;>c/`<06ATI1@3oool30;>c/`P0dLfY00060=7=ZB/0oooo0`20P8030<c<c0<0
IVIV0P0I6AT30;>c/`<0IVIV0P2IVIT301TI6@<0oooo0`0000020>KViPH0C4a<0P0I6AT3000000<0
<c<c0`1<C4`201TI6@<0<c<c0`2IVIT20>KViP<0C4a<0`0000020<c<c0<000000`1VIVH300000080
c<c<0`2c/k<30>KViP80IVIV0`3<c<`60;>c/`80i^KV0`20P80306IVIP80i^KV0`3<c<`30;>c/`<0
c<c<0P2c/k<306IVIP<0c<c<0P2c/k<30820P0<0<c<c0`0I6AT203<c<`<0C4a<0`1VIVH20820P0H0
IVIV0`3oool20>KViP<0c<c<0`3oool201TI6@<0oooo0`00000309VIV@80C4a<0`3Vi^H30820P080
i^KV0`2IVIT306IVIPD0C4a<0`3<c<`300000080C4a<0`2c/k<30>KViP<000000P2IVIT304a<C0D0
P8200`1VIVH309VIV@80C4a<0`1VIVH604a<C080VIVI0`0c<c<300000080/k>c1P3oool306IVIP80
<c<c0`2c/k<309VIV@80P8200`2c/k<3000000<0C4a<0P0I6AT30820P0<0/k>c0P20P8030<c<c0<0
00000`2c/k<201TI6@<0VIVI203AcJT000H0dLfY:`3oool30820P0<0c<c<0`1VIVH201TI6@<0/k>c
0`1VIVH209VIV@<06ATI0`3oool300000080i^KV1P1<C4`201TI6@<000000`0c<c<304a<C0806ATI
0`0c<c<309VIV@80i^KV0`1<C4`300000080c<c<0`00000306IVIP<000000P3<c<`30;>c/`<0i^KV
0P1VIVH30<c<c0H0/k>c0P3Vi^H30820P0<0IVIV0P3Vi^H30<c<c0<0/k>c0`3<c<`20;>c/`<0IVIV
0`3<c<`20;>c/`<0P8200`0c<c<301TI6@80<c<c0`1<C4`306IVIP80P8201P1VIVH30?ooo`80i^KV
0`3<c<`30?ooo`806ATI0`3oool3000000<0VIVI0P1<C4`30>KViP<0P8200P3Vi^H309VIV@<0IVIV
1@1<C4`30<c<c0<000000P1<C4`30;>c/`<0i^KV0`00000209VIV@<0C4a<1@20P80306IVIP<0VIVI
0P1<C4`306IVIPH0C4a<0P2IVIT303<c<`<000000P2c/k<60?ooo`<0IVIV0P0c<c<30;>c/`<0VIVI
0P20P8030;>c/`<000000`1<C4`201TI6@<0P8200`2c/k<20820P0<0c<c<0`0000030;>c/`806ATI
0`2IVIT80=7=Z@001P3AcJT[0?ooo`<0P8200`3<c<`306IVIP806ATI0`2c/k<306IVIP80VIVI0`0I
6AT30?ooo`<000000P3Vi^H604a<C0806ATI0`00000303<c<`<0C4a<0P0I6AT303<c<`<0VIVI0P3V
i^H304a<C0<000000P3<c<`3000000<0IVIV0`0000020<c<c0<0/k>c0`3Vi^H206IVIP<0c<c<1P2c
/k<20>KViP<0P8200`1VIVH20>KViP<0c<c<0`2c/k<30<c<c080/k>c0`1VIVH30<c<c080/k>c0`20
P80303<c<`<06ATI0P0c<c<304a<C0<0IVIV0P20P80606IVIP<0oooo0P3Vi^H30<c<c0<0oooo0P0I
6AT30?ooo`<000000`2IVIT204a<C0<0i^KV0`20P8020>KViP<0VIVI0`1VIVH504a<C0<0c<c<0`00
000204a<C0<0/k>c0`3Vi^H300000080VIVI0`1<C4`50820P0<0IVIV0`2IVIT204a<C0<0IVIV1P1<
C4`209VIV@<0<c<c0`0000020;>c/`H0oooo0`1VIVH203<c<`<0/k>c0`2IVIT20820P0<0/k>c0`00
000304a<C0806ATI0`20P8030;>c/`80P8200`3<c<`3000000<0/k>c0P0I6AT309VIV@P0dLfY0006
0=7=ZBh0oooo0`3<c<`301TI6@80C4a<0`1VIVH303<c<`80IVIV0`2c/k<60<c<c080C4a<0`0c<c<3
06IVIPD000000`2IVIT301TI6@80c<c<0`3Vi^H30820P080C4a<0`0c<c<304a<C080i^KV0`3<c<`3
03<c<`<0oooo0P20P80306IVIP<0<c<c0P2c/k<306IVIP<0C4a<0`0I6AT20820P0<0IVIV0`2c/k<2
06IVIP<0C4a<0`3<c<`300000080oooo0`3Vi^H300000080IVIV0`3<c<`30820P0<0VIVI0P2c/k<3
03<c<`<0oooo0P0I6AT306IVIP<00000203<c<`301TI6@80VIVI1P2c/k<301TI6@80oooo0`2c/k<3
00000080i^KV0`1<C4`3000000<0c<c<0P1VIVH309VIV@<0IVIV0P3oool309VIV@<0oooo0`3Vi^H2
0?ooo`<0<c<c0`1VIVH201TI6@<0IVIV0`0000020>KViP<0P8200`2c/k<30>KViP80P8200`3<c<`3
0>KViP80oooo1P1<C4`303<c<`80oooo0`2IVIT306IVIP80/k>c0`3oool60<c<c080oooo0`20P803
0<c<c080VIVI0`3Vi^H30<c<c0<0C4a<1@0I6AT80=7=Z@001P3AcJT^0?ooo`<0c<c<0`0I6AT204a<
C0<0IVIV0`0c<c<206IVIP<0/k>c1P3<c<`204a<C0<0<c<c0`1VIVH5000000<0VIVI0`0I6AT20<c<
c0<0i^KV0`20P80204a<C0<0<c<c0`1<C4`20>KViP<0c<c<0`0c<c<30?ooo`80P8200`1VIVH303<c
<`80/k>c0`1VIVH304a<C0<06ATI0P20P80306IVIP<0/k>c0P1VIVH304a<C0<0c<c<0`0000020?oo
o`<0i^KV0`00000206IVIP<0c<c<0`20P80309VIV@80/k>c0`0c<c<30?ooo`806ATI0`1VIVH30000
00P0c<c<0`0I6AT209VIV@H0/k>c0`0I6AT20?ooo`<0/k>c0`0000020>KViP<0C4a<0`0000030<c<
c080IVIV0`2IVIT306IVIP80oooo0`2IVIT30?ooo`<0i^KV0P3oool303<c<`<0IVIV0P0I6AT306IV
IP<000000P3Vi^H30820P0<0/k>c0`3Vi^H20820P0<0c<c<0`3Vi^H20?ooo`H0C4a<0`0c<c<20?oo
o`<0VIVI0`1VIVH20;>c/`<0oooo1P3<c<`20?ooo`<0P8200`3<c<`209VIV@<0i^KV0`3<c<`304a<
C0D06ATI203AcJT000H0dLfY;P3oool30<c<c0<06ATI0P1<C4`306IVIP<0<c<c0P1VIVH30;>c/`H0
c<c<0P1<C4`303<c<`<0IVIV1@00000309VIV@<06ATI0P3<c<`30>KViP<0P8200P1<C4`303<c<`<0
C4a<0P3Vi^H30<c<c0<0<c<c0`3oool20820P0<0IVIV0`0c<c<20;>c/`<0IVIV0`1<C4`301TI6@80
P8200`1VIVH30;>c/`80IVIV0`1<C4`30<c<c0<000000P3oool30>KViP<000000P1VIVH30<c<c0<0
P8200`2IVIT20;>c/`<0<c<c0`3oool201TI6@<0IVIV0`0000080<c<c0<06ATI0P2IVIT60;>c/`<0
6ATI0P3oool30;>c/`<000000P3Vi^H304a<C0<000000`3<c<`206IVIP<0VIVI0`1VIVH20?ooo`<0
VIVI0`3oool30>KViP80oooo0`0c<c<306IVIP806ATI0`1VIVH300000080i^KV0`20P8030;>c/`<0
i^KV0P20P8030<c<c0<0i^KV0P3oool604a<C0<0<c<c0P3oool309VIV@<0IVIV0P2c/k<30?ooo`H0
c<c<0P3oool30820P0<0c<c<0P2IVIT30>KViP<0c<c<0`1<C4`501TI6@P0dLfY00060=7=ZC40oooo
0`3Vi^H206IVIP<0VIVI0`0c<c<20>KViP<0VIVI0`1VIVH30>KViP80<c<c0`1<C4`30?ooo`80/k>c
0`0I6AT30;>c/`<0P8200P00000306IVIP<0i^KV0P2IVIT30<c<c0<0IVIV0P0000030820P0<0C4a<
1@3oool30;>c/`<0oooo0P00000306IVIP<000000`2c/k<20<c<c0<0P8200`3<c<`2000000<0c<c<
0`1VIVH30<c<c080i^KV0`1<C4`30<c<c080<c<c0`3oool30>KViP<0VIVI0P3oool303<c<`D0i^KV
0`1VIVH309VIV@<0/k>c0P00000306IVIP<0c<c<0P3Vi^H30;>c/`<0P8200`3Vi^H206IVIP<0oooo
0`0c<c<20<c<c0<0/k>c0`3Vi^H306IVIP80<c<c0`3oool30<c<c0D0P8201P1<C4`203<c<`<0/k>c
0`3Vi^H5000000<0c<c<0P1<C4`303<c<`<0P8200`1<C4`20<c<c0<0P8200`3oool506IVIP<00000
0`0I6AT50<c<c0<0VIVI0P1<C4`301TI6@<0/k>c0`00000206IVIP<0oooo0`0c<c<2000000H0i^KV
0`0c<c<204a<C0<0i^KV203AcJT000H0dLfY<@3oool30>KViP80IVIV0`2IVIT303<c<`80i^KV0`2I
VIT306IVIP<0i^KV0P0c<c<304a<C0<0oooo0P2c/k<301TI6@<0/k>c0`20P802000000<0IVIV0`3V
i^H209VIV@<0c<c<0`1VIVH2000000<0P8200`1<C4`50?ooo`<0/k>c0`3oool2000000<0IVIV0`00
00030;>c/`80c<c<0`20P8030<c<c08000000`3<c<`306IVIP<0c<c<0P3Vi^H304a<C0<0c<c<0P0c
<c<30?ooo`<0i^KV0`2IVIT20?ooo`<0<c<c1@3Vi^H306IVIP<0VIVI0`2c/k<2000000<0IVIV0`3<
c<`20>KViP<0/k>c0`20P8030>KViP80IVIV0`3oool303<c<`80c<c<0`2c/k<30>KViP<0IVIV0P0c
<c<30?ooo`<0c<c<1@20P80604a<C080<c<c0`2c/k<30>KViPD000000`3<c<`204a<C0<0<c<c0`20
P80304a<C080c<c<0`20P8030?ooo`D0IVIV0`00000301TI6@D0c<c<0`2IVIT204a<C0<06ATI0`2c
/k<300000080IVIV0`3oool303<c<`8000001P3Vi^H303<c<`80C4a<0`3Vi^H80=7=Z@001P3AcJTf
0?ooo`<06ATI0`1VIVH20820P0<0oooo0`3<c<`30820P080IVIV0`20P8050;>c/`<0P8200`2IVIT3
06IVIP80/k>c0`0I6AT50>KViP<06ATI0`20P8050;>c/`<0oooo0`2c/k<201TI6@<0VIVI1@3oool3
0820P0<06ATI0`2c/k<20820P0<0oooo0`0c<c<2000000<0VIVI0`20P80303<c<`806ATI0`000003
03<c<`8000001P2c/k<309VIV@80oooo0`1VIVH30820P0D0oooo0`0I6AT306IVIP80c<c<0`0c<c<3
0?ooo`D0i^KV0`0I6AT30?ooo`80IVIV0`0I6AT300000080/k>c0`2IVIT306IVIP<0i^KV0P2IVIT6
03<c<`8000000`3Vi^H3000000<0/k>c0P3Vi^H30820P0<0C4a<0P3<c<`303<c<`<0c<c<0P2c/k<3
04a<C0<0IVIV0`2c/k<204a<C0<0/k>c1@3oool30;>c/`<0C4a<0`3Vi^H206IVIP<0i^KV0`0c<c<2
0820P0<0/k>c0`0c<c<309VIV@8000001P3<c<`204a<C0H0i^KV0`0c<c<20>KViP<0P820203AcJT0
00H0dLfY=P3oool301TI6@<0IVIV0P20P8030?ooo`<0c<c<0`20P80206IVIP<0P8201@2c/k<30820
P0<0VIVI0`1VIVH20;>c/`<06ATI1@3Vi^H301TI6@<0P8201@2c/k<30?ooo`<0/k>c0P0I6AT309VI
V@D0oooo0`20P80301TI6@<0/k>c0P20P8030?ooo`<0<c<c0P00000309VIV@<0P8200`0c<c<201TI
6@<000000`0c<c<2000000H0/k>c0`2IVIT20?ooo`<0IVIV0`20P8050?ooo`<06ATI0`1VIVH20<c<
c0<0<c<c0`3oool50>KViP<06ATI0`3oool206IVIP<06ATI0`0000020;>c/`<0VIVI0`1VIVH30>KV
iP80VIVI1P0c<c<2000000<0i^KV0`0000030;>c/`80i^KV0`20P80304a<C080c<c<0`0c<c<30<c<
c080/k>c0`1<C4`306IVIP<0/k>c0P1<C4`30;>c/`D0oooo0`2c/k<304a<C0<0i^KV0P1VIVH30>KV
iP<0<c<c0P20P8030;>c/`<0<c<c0`2IVIT2000000H0c<c<0P1<C4`60>KViP<0<c<c0P3Vi^H30820
P0P0dLfY00060=7=ZCH0oooo0`0I6AT306IVIP80P8200`3oool30<c<c0<0P8200P1VIVH30820P0D0
/k>c0`20P80309VIV@<0IVIV0P2c/k<301TI6@D0i^KV0`0I6AT30820P0D0/k>c0`3oool30;>c/`80
6ATI0`2IVIT50?ooo`<0P8200`0I6AT30;>c/`80P8200`3oool303<c<`8000000`2IVIT30820P0<0
<c<c0P0I6AT3000000<0<c<c0P0000060;>c/`<0VIVI0P3oool306IVIP<0P8201@3oool301TI6@<0
IVIV0P3<c<`303<c<`<0oooo1@3Vi^H301TI6@<0oooo0P1VIVH301TI6@<000000P2c/k<309VIV@<0
IVIV0`3Vi^H209VIV@H0<c<c0P0000030>KViP<000000`2c/k<20>KViP<0P8200`1<C4`20<c<c0<0
<c<c0`3<c<`20;>c/`<0C4a<0`1VIVH30;>c/`80C4a<0`2c/k<50?ooo`<0/k>c0`1<C4`30>KViP80
IVIV0`3Vi^H303<c<`80P8200`2c/k<303<c<`<0VIVI0P0000060<c<c080C4a<1P3Vi^H303<c<`80
i^KV0`20P8080=7=Z@001P3AcJTi0?ooo`<0P8200P2c/k<60?ooo`<0i^KV0P2IVIT30>KViP<00000
0P3oool304a<C0<000000`1<C4`20820P0<0i^KV0`1VIVH20>KViP<0c<c<0`3Vi^H209VIV@<0oooo
0`3Vi^H304a<C080/k>c0`0c<c<309VIV@8000000`20P8030<c<c0<0C4a<0P2c/k<306IVIP<0oooo
1@00000304a<C0<0VIVI0P0I6AT60;>c/`80c<c<0`3Vi^H303<c<`<000000P1<C4`30>KViP<00000
1@1<C4`303<c<`<0i^KV0P00000306IVIP<0VIVI0P0000030820P0<0IVIV1@20P80301TI6@<0/k>c
0P3<c<`3000000<0i^KV0`2IVIT20820P0<0c<c<0`3oool5000000<0IVIV0`3oool20>KViP<0C4a<
0`00000203<c<`<000000`2c/k<209VIV@<0IVIV0`2IVIT304a<C0806ATI0`1<C4`301TI6@80/k>c
0`0I6AT30820P0<06ATI0P2IVIT304a<C0<0<c<c0P1<C4`309VIV@<0IVIV0`20P8020<c<c0<0i^KV
0`0c<c<209VIV@H0c<c<0`0I6AT20<c<c0<0/k>c203AcJT000H0dLfY>@3oool30820P080/k>c1P3o
ool30>KViP80VIVI0`3Vi^H300000080oooo0`1<C4`3000000<0C4a<0P20P8030>KViP<0IVIV0P3V
i^H30<c<c0<0i^KV0P2IVIT30?ooo`<0i^KV0`1<C4`20;>c/`<0<c<c0`2IVIT2000000<0P8200`3<
c<`304a<C080/k>c0`1VIVH30?ooo`D000000`1<C4`309VIV@806ATI1P2c/k<20<c<c0<0i^KV0`0c
<c<300000080C4a<0`3Vi^H3000000D0C4a<0`0c<c<30>KViP8000000`1VIVH309VIV@8000000`20
P80306IVIPD0P8200`0I6AT30;>c/`80c<c<0`0000030>KViP<0VIVI0P20P8030<c<c0<0oooo1@00
000306IVIP<0oooo0P3Vi^H304a<C0<000000P0c<c<3000000<0/k>c0P2IVIT306IVIP<0VIVI0`1<
C4`201TI6@<0C4a<0`0I6AT20;>c/`<06ATI0`20P80301TI6@80VIVI0`1<C4`303<c<`80C4a<0`2I
VIT306IVIP<0P8200P3<c<`30>KViP<0<c<c0P2IVIT60<c<c0<06ATI0P3<c<`30;>c/`P0dLfY0006
0=7=ZCT0oooo0`20P8020;>c/`H0oooo0`3Vi^H209VIV@<0i^KV0`0000020?ooo`<0C4a<0`000003
04a<C080P8200`3Vi^H306IVIP80i^KV0`3<c<`30>KViP80VIVI0`3oool30>KViP<0C4a<0P2c/k<3
03<c<`<0VIVI0P0000030820P0<0c<c<0`1<C4`20;>c/`<0IVIV0`3oool5000000<0C4a<0`2IVIT2
01TI6@H0/k>c0P3<c<`30>KViP<0<c<c0`00000204a<C0<0i^KV0`00000504a<C0<0<c<c0`3Vi^H2
000000<0IVIV0`2IVIT2000000<0P8200`1VIVH50820P0<06ATI0`2c/k<20<c<c0<000000`3Vi^H3
09VIV@80P8200`3<c<`30?ooo`D000000`1VIVH30?ooo`80i^KV0`1<C4`300000080<c<c0`000003
0;>c/`80VIVI0`1VIVH309VIV@<0C4a<0P0I6AT304a<C0<06ATI0P2c/k<301TI6@<0P8200`0I6AT2
09VIV@<0C4a<0`0c<c<204a<C0<0VIVI0`1VIVH30820P080c<c<0`3Vi^H303<c<`80VIVI1P3<c<`3
01TI6@80c<c<0`2c/k<80=7=Z@001P3AcJTl0?ooo`80c<c<2@0I6AT2000000<0C4a<0`3<c<`204a<
C0<0<c<c0`3Vi^H30?ooo`8000000`3Vi^H303<c<`D0oooo0`1<C4`20<c<c0H0VIVI0`20P8020;>c
/`<0P8200`2IVIT20>KViP<0oooo0`0c<c<300000080c<c<0`0000050<c<c0<0<c<c0`3<c<`306IV
IP80/k>c0`3<c<`309VIV@80oooo0`3Vi^H30<c<c0<0i^KV0P3oool301TI6@D000000`0I6AT30<c<
c0<0oooo0P1<C4`30>KViP<0VIVI0P1<C4`30>KViP<0VIVI0`3Vi^H2000000<0c<c<0`3Vi^H20<c<
c0H06ATI0`2IVIT206IVIP<06ATI0`2IVIT8000000<0<c<c0P3<c<`301TI6@D0c<c<0`3Vi^H30?oo
o`80C4a<0`0000030<c<c0<0VIVI1@0c<c<30>KViP80oooo0`3<c<`30>KViP<0VIVI0P2c/k<30820
P0<06ATI0P0c<c<306IVIP<06ATI0`3Vi^H20;>c/`<000000`20P802000000<0i^KV0`3<c<`30;>c
/`80<c<c0`2IVIT80=7=Z@001P3AcJTl0?ooo`80c<c<2@0I6AT2000000<0C4a<0`3<c<`204a<C0<0
<c<c0`3Vi^H30?ooo`8000000`3Vi^H303<c<`D0oooo0`1<C4`20<c<c0H0VIVI0`20P8020;>c/`<0
P8200`2IVIT20>KViP<0oooo0`0c<c<300000080c<c<0`0000050<c<c0<0<c<c0`3<c<`306IVIP80
/k>c0`3<c<`309VIV@80oooo0`3Vi^H30<c<c0<0i^KV0P3oool301TI6@D000000`0I6AT30<c<c0<0
oooo0P1<C4`30>KViP<0VIVI0P1<C4`30>KViP<0VIVI0`3Vi^H2000000<0c<c<0`3Vi^H20<c<c0H0
6ATI0`2IVIT206IVIP<06ATI0`2IVIT8000000<0<c<c0P3<c<`301TI6@D0c<c<0`3Vi^H30?ooo`80
C4a<0`0000030<c<c0<0VIVI1@0c<c<30>KViP80oooo0`3<c<`30>KViP<0VIVI0P2c/k<30820P0<0
6ATI0P0c<c<306IVIP<06ATI0`3Vi^H20;>c/`<000000`20P802000000<0i^KV0`3<c<`30;>c/`80
<c<c0`2IVIT80=7=Z@001P3AcJTn0?ooo`<0i^KV0`1VIVH30820P0D000000`0c<c<2000000<0/k>c
0`3Vi^H304a<C080<c<c0`3<c<`30;>c/`80i^KV0`1<C4`30<c<c080oooo0`3Vi^H30;>c/`<0P820
0P0c<c<309VIV@<0C4a<0P2c/k<301TI6@<000000`2c/k<203<c<`<000000`2IVIT20820P0<0C4a<
0`3oool30>KViP80VIVI0`1VIVH30>KViP806ATI0`2c/k<3000000D0oooo1P1VIVH20?ooo`<0P820
0`00000306IVIP80oooo0`0I6AT300000080C4a<0`20P80306IVIP<0c<c<0P0I6AT30;>c/`<0VIVI
0P20P8030>KViP<0oooo0`20P8020>KViPH000000P3Vi^H304a<C0<0i^KV0`1<C4`20?ooo`<0i^KV
0`1VIVH20>KViP<0<c<c1@2c/k<604a<C0<0c<c<0P00000301TI6@<0<c<c1@2c/k<309VIV@<0P820
0P3Vi^H301TI6@<0i^KV0P3oool309VIV@<0<c<c0`3Vi^H204a<C0H06ATI0P1<C4`60>KViP<0<c<c
0P2IVIT301TI6@P0dLfY00060=7=ZCh0oooo0`3Vi^H306IVIP<0P8201@00000303<c<`8000000`2c
/k<30>KViP<0C4a<0P0c<c<30<c<c0<0/k>c0P3Vi^H304a<C0<0c<c<0P3oool30>KViP<0/k>c0`20
P80203<c<`<0VIVI0`1<C4`20;>c/`<06ATI0`0000030;>c/`80<c<c0`00000309VIV@80P8200`1<
C4`30?ooo`<0i^KV0P2IVIT306IVIP<0i^KV0P0I6AT30;>c/`<000001@3oool606IVIP80oooo0`20
P803000000<0IVIV0P3oool301TI6@<000000P1<C4`30820P0<0IVIV0`3<c<`201TI6@<0/k>c0`2I
VIT20820P0<0i^KV0`3oool30820P080i^KV1P0000020>KViP<0C4a<0`3Vi^H304a<C080oooo0`3V
i^H306IVIP80i^KV0`0c<c<50;>c/`H0C4a<0`3<c<`2000000<06ATI0`0c<c<50;>c/`<0VIVI0`20
P8020>KViP<06ATI0`3Vi^H20?ooo`<0VIVI0`0c<c<30>KViP80C4a<1P0I6AT204a<C0H0i^KV0`0c
<c<209VIV@<06ATI203AcJT000H0dLfY?P3oool30>KViP<0IVIV0`20P805000000<0<c<c0P000003
0;>c/`<0i^KV0`1<C4`203<c<`<0c<c<0`2c/k<20>KViP<0C4a<0`3<c<`20?ooo`<0i^KV0`2c/k<3
0820P080<c<c0`2IVIT304a<C080/k>c0`0I6AT3000000<0/k>c0P0c<c<3000000<0VIVI0P20P803
04a<C0<0oooo0`3Vi^H209VIV@<0IVIV0`3Vi^H201TI6@<0/k>c0`0000050?ooo`H0IVIV0P3oool3
0820P0<000000`1VIVH20?ooo`<06ATI0`00000204a<C0<0P8200`1VIVH30<c<c0806ATI0`2c/k<3
09VIV@80P8200`3Vi^H30?ooo`<0P8200P3Vi^H600000080i^KV0`1<C4`30>KViP<0C4a<0P3oool3
0>KViP<0IVIV0P3Vi^H303<c<`D0/k>c1P1<C4`30<c<c08000000`0I6AT303<c<`D0/k>c0`2IVIT3
0820P080i^KV0`0I6AT30>KViP80oooo0`2IVIT303<c<`<0i^KV0P1<C4`601TI6@80C4a<1P3Vi^H3
03<c<`80VIVI0`0I6AT80=7=Z@001P3AcJU40?ooo`<06ATI0P1<C4`30>KViP<0C4a<0P3oool30820
P0<0C4a<0`3<c<`206IVIP<0P8200`3oool204a<C0<0<c<c0`1VIVH504a<C0<0<c<c0`2IVIT204a<
C0<0IVIV0`2c/k<20>KViP<0/k>c0`3<c<`304a<C0806ATI1P0c<c<20820P0<0c<c<0`1VIVH30?oo
o`80IVIV0`0I6AT30>KViP80c<c<0`3Vi^H30;>c/`<0c<c<0P0c<c<30;>c/`<0oooo0P0I6AT309VI
V@<0i^KV0`1VIVH201TI6@<000001@2IVIT30<c<c0<0P8200`3<c<`201TI6@<0<c<c0`00000204a<
C0H0VIVI0`00000204a<C0P0<c<c0`2c/k<304a<C0<0c<c<0P1VIVH30?ooo`<0IVIV0P0I6AT30000
00<06ATI0P20P80304a<C0<0P8200`0I6AT50820P0<0VIVI0P0c<c<3000000<0IVIV0`0I6AT20?oo
o`<0C4a<0`3oool506IVIP<06ATI0`3<c<`20;>c/`<0i^KV0`1VIVH20820P0<06ATI0`2IVIT30820
P080VIVI0`3Vi^H80=7=Z@001P3AcJU40?ooo`<06ATI0P1<C4`30>KViP<0C4a<0P3oool30820P0<0
C4a<0`3<c<`206IVIP<0P8200`3oool204a<C0<0<c<c0`1VIVH504a<C0<0<c<c0`2IVIT204a<C0<0
IVIV0`2c/k<20>KViP<0/k>c0`3<c<`304a<C0806ATI1P0c<c<20820P0<0c<c<0`1VIVH30?ooo`80
IVIV0`0I6AT30>KViP80c<c<0`3Vi^H30;>c/`<0c<c<0P0c<c<30;>c/`<0oooo0P0I6AT309VIV@<0
i^KV0`1VIVH201TI6@<000001@2IVIT30<c<c0<0P8200`3<c<`201TI6@<0<c<c0`00000204a<C0H0
VIVI0`00000204a<C0P0<c<c0`2c/k<304a<C0<0c<c<0P1VIVH30?ooo`<0IVIV0P0I6AT3000000<0
6ATI0P20P80304a<C0<0P8200`0I6AT50820P0<0VIVI0P0c<c<3000000<0IVIV0`0I6AT20?ooo`<0
C4a<0`3oool506IVIP<06ATI0`3<c<`20;>c/`<0i^KV0`1VIVH20820P0<06ATI0`2IVIT30820P080
VIVI0`3Vi^H80=7=Z@001P3AcJU40?ooo`<06ATI0P1<C4`30>KViP<0C4a<0P3oool30820P0<0C4a<
0`3<c<`206IVIP<0P8200`3oool204a<C0<0<c<c0`1VIVH504a<C0<0<c<c0`2IVIT204a<C0<0IVIV
0`2c/k<20>KViP<0/k>c0`3<c<`304a<C0806ATI1P0c<c<20820P0<0c<c<0`1VIVH30?ooo`80IVIV
0`0I6AT30>KViP80c<c<0`3Vi^H30;>c/`<0c<c<0P0c<c<30;>c/`<0oooo0P0I6AT309VIV@<0i^KV
0`1VIVH201TI6@<000001@2IVIT30<c<c0<0P8200`3<c<`201TI6@<0<c<c0`00000204a<C0H0VIVI
0`00000204a<C0P0<c<c0`2c/k<304a<C0<0c<c<0P1VIVH30?ooo`<0IVIV0P0I6AT3000000<06ATI
0P20P80304a<C0<0P8200`0I6AT50820P0<0VIVI0P0c<c<3000000<0IVIV0`0I6AT20?ooo`<0C4a<
0`3oool506IVIP<06ATI0`3<c<`20;>c/`<0i^KV0`1VIVH20820P0<06ATI0`2IVIT30820P080VIVI
0`3Vi^H80=7=Z@001P3AcJU70?ooo`80P8200`2c/k<309VIV@D0c<c<0`20P8030;>c/`80VIVI0`1<
C4`300000080P8200`2c/k<303<c<`80oooo0`2IVIT30<c<c0<0IVIV0P0I6AT30>KViP<000000P1V
IVH304a<C0<0/k>c0`2IVIT503<c<`<0i^KV0P20P80303<c<`<0VIVI0`3Vi^H204a<C0<0P8200`2I
VIT20820P0<0oooo0`1VIVH303<c<`80VIVI0`3<c<`301TI6@8000000`2IVIT30?ooo`<0IVIV0P00
000609VIV@80oooo0`0c<c<309VIV@<0i^KV0P3<c<`304a<C0D0IVIV0`2IVIT306IVIP<06ATI0P2c
/k<304a<C0<0IVIV0P20P80309VIV@<0oooo0`2c/k<2000000<0<c<c0`2c/k<20>KViP<0oooo0`20
P802000000<0<c<c0`3oool301TI6@80/k>c0`3oool30<c<c08000001P0I6AT304a<C0D0IVIV0`00
00020820P0<0/k>c0`3Vi^H30?ooo`80i^KV0`3<c<`301TI6@80i^KV0`2IVIT30;>c/`<0P8200P0c
<c<30820P0P0dLfY00060=7=ZDL0oooo0P20P8030;>c/`<0VIVI1@3<c<`30820P0<0/k>c0P2IVIT3
04a<C0<000000P20P8030;>c/`<0<c<c0P3oool309VIV@<0c<c<0`1VIVH201TI6@<0i^KV0`000002
06IVIP<0C4a<0`2c/k<309VIV@D0<c<c0`3Vi^H20820P0<0<c<c0`2IVIT30>KViP80C4a<0`20P803
09VIV@80P8200`3oool306IVIP<0<c<c0P2IVIT30<c<c0<06ATI0P00000309VIV@<0oooo0`1VIVH2
000000H0VIVI0P3oool303<c<`<0VIVI0`3Vi^H20<c<c0<0C4a<1@1VIVH309VIV@<0IVIV0`0I6AT2
0;>c/`<0C4a<0`1VIVH20820P0<0VIVI0`3oool30;>c/`8000000`0c<c<30;>c/`80i^KV0`3oool3
0820P08000000`0c<c<30?ooo`<06ATI0P2c/k<30?ooo`<0c<c<0P00000601TI6@<0C4a<1@1VIVH3
00000080P8200`2c/k<30>KViP<0oooo0P3Vi^H30<c<c0<06ATI0P3Vi^H309VIV@<0/k>c0`20P802
03<c<`<0P820203AcJT000H0dLfYA`3oool20820P0<0/k>c0`2IVIT50<c<c0<0P8200`2c/k<209VI
V@<0C4a<0`0000020820P0<0/k>c0`0c<c<20?ooo`<0VIVI0`3<c<`306IVIP806ATI0`3Vi^H30000
0080IVIV0`1<C4`30;>c/`<0VIVI1@0c<c<30>KViP80P8200`0c<c<309VIV@<0i^KV0P1<C4`30820
P0<0VIVI0P20P8030?ooo`<0IVIV0`0c<c<209VIV@<0c<c<0`0I6AT2000000<0VIVI0`3oool306IV
IP8000001P2IVIT20?ooo`<0<c<c0`2IVIT30>KViP80c<c<0`1<C4`506IVIP<0VIVI0`1VIVH301TI
6@80/k>c0`1<C4`306IVIP80P8200`2IVIT30?ooo`<0/k>c0P00000303<c<`<0/k>c0P3Vi^H30?oo
o`<0P8200P00000303<c<`<0oooo0`0I6AT20;>c/`<0oooo0`3<c<`2000000H06ATI0`1<C4`506IV
IP<000000P20P8030;>c/`<0i^KV0`3oool20>KViP<0c<c<0`0I6AT20>KViP<0VIVI0`2c/k<30820
P080<c<c0`20P8080=7=Z@001P3AcJU90?ooo`<0c<c<0`0000020>KViP<0c<c<0`2c/k<306IVIP80
c<c<0`2IVIT503<c<`<0P8200`1<C4`206IVIP<0oooo0`0c<c<309VIV@80c<c<0`3Vi^H30<c<c080
i^KV0`00000303<c<`<000000P1<C4`306IVIP<0P8200P3oool30;>c/`<0i^KV0`0I6AT209VIV@<0
<c<c0`20P80204a<C0<000000`20P8030;>c/`80i^KV0`0I6AT30820P080VIVI0`0000060>KViP80
VIVI0`0000030>KViPD0/k>c0`1<C4`301TI6@8000000`1VIVH309VIV@80<c<c0`3oool30<c<c0<0
P8200P00000306IVIP<000000P0c<c<30820P0H0C4a<1@0I6AT303<c<`D0VIVI0`00000203<c<`<0
c<c<0`1VIVH304a<C080oooo1P1<C4`201TI6@<0/k>c1P0c<c<20?ooo`<06ATI1@1<C4`309VIV@<0
IVIV203Vi^H303<c<`80C4a<0`0c<c<30820P0<0i^KV0P2IVIT30;>c/`P0dLfY00060=7=ZDT0oooo
0`3<c<`300000080i^KV0`3<c<`30;>c/`<0IVIV0P3<c<`309VIV@D0<c<c0`20P80304a<C080IVIV
0`3oool303<c<`<0VIVI0P3<c<`30>KViP<0c<c<0P3Vi^H3000000<0<c<c0`00000204a<C0<0IVIV
0`20P8020?ooo`<0/k>c0`3Vi^H301TI6@80VIVI0`0c<c<30820P080C4a<0`0000030820P0<0/k>c
0P3Vi^H301TI6@<0P8200P2IVIT3000000H0i^KV0P2IVIT3000000<0i^KV1@2c/k<304a<C0<06ATI
0P00000306IVIP<0VIVI0P0c<c<30?ooo`<0c<c<0`20P802000000<0IVIV0`00000203<c<`<0P820
1P1<C4`501TI6@<0<c<c1@2IVIT300000080<c<c0`3<c<`306IVIP<0C4a<0P3oool604a<C0806ATI
0`2c/k<603<c<`80oooo0`0I6AT504a<C0<0VIVI0`1VIVH80>KViP<0<c<c0P1<C4`303<c<`<0P820
0`3Vi^H209VIV@<0/k>c203AcJT000H0dLfYC03oool30>KViP80IVIV0`1<C4`30<c<c0<000000P3<
c<`30;>c/`<0P8200P0000030;>c/`<0IVIV0P2IVIT304a<C0<0<c<c0`3Vi^H20;>c/`<0VIVI0`20
P8020?ooo`<0C4a<0`3Vi^H306IVIP80oooo0`2IVIT30>KViP806ATI0`0000030?ooo`<0C4a<0P3o
ool303<c<`<0C4a<0P2IVIT603<c<`<0P8200P1<C4`30<c<c0<0C4a<0P2IVIT304a<C0H0i^KV0P1<
C4`3000000<0VIVI0P20P8030>KViP<0/k>c0`3Vi^H506IVIP<0VIVI0P3oool3000000<0P8200`3o
ool201TI6@<0/k>c0`1<C4`20>KViP<0P8200`0c<c<306IVIPD000000`2IVIT20<c<c0<000001@1<
C4`306IVIP<0i^KV0`00000203<c<`<06ATI0`3<c<`20?ooo`<0P8200`3Vi^H30820P0806ATI0`00
000309VIV@80c<c<0`1VIVH30;>c/`<0oooo0P1VIVH304a<C0<0c<c<0P1VIVH3000000<06ATI0`1V
IVH204a<C0<0VIVI203AcJT000H0dLfYC03oool30>KViP80IVIV0`1<C4`30<c<c0<000000P3<c<`3
0;>c/`<0P8200P0000030;>c/`<0IVIV0P2IVIT304a<C0<0<c<c0`3Vi^H20;>c/`<0VIVI0`20P802
0?ooo`<0C4a<0`3Vi^H306IVIP80oooo0`2IVIT30>KViP806ATI0`0000030?ooo`<0C4a<0P3oool3
03<c<`<0C4a<0P2IVIT603<c<`<0P8200P1<C4`30<c<c0<0C4a<0P2IVIT304a<C0H0i^KV0P1<C4`3
000000<0VIVI0P20P8030>KViP<0/k>c0`3Vi^H506IVIP<0VIVI0P3oool3000000<0P8200`3oool2
01TI6@<0/k>c0`1<C4`20>KViP<0P8200`0c<c<306IVIPD000000`2IVIT20<c<c0<000001@1<C4`3
06IVIP<0i^KV0`00000203<c<`<06ATI0`3<c<`20?ooo`<0P8200`3Vi^H30820P0806ATI0`000003
09VIV@80c<c<0`1VIVH30;>c/`<0oooo0P1VIVH304a<C0<0c<c<0P1VIVH3000000<06ATI0`1VIVH2
04a<C0<0VIVI203AcJT000H0dLfYC03oool30>KViP80IVIV0`1<C4`30<c<c0<000000P3<c<`30;>c
/`<0P8200P0000030;>c/`<0IVIV0P2IVIT304a<C0<0<c<c0`3Vi^H20;>c/`<0VIVI0`20P8020?oo
o`<0C4a<0`3Vi^H306IVIP80oooo0`2IVIT30>KViP806ATI0`0000030?ooo`<0C4a<0P3oool303<c
<`<0C4a<0P2IVIT603<c<`<0P8200P1<C4`30<c<c0<0C4a<0P2IVIT304a<C0H0i^KV0P1<C4`30000
00<0VIVI0P20P8030>KViP<0/k>c0`3Vi^H506IVIP<0VIVI0P3oool3000000<0P8200`3oool201TI
6@<0/k>c0`1<C4`20>KViP<0P8200`0c<c<306IVIPD000000`2IVIT20<c<c0<000001@1<C4`306IV
IP<0i^KV0`00000203<c<`<06ATI0`3<c<`20?ooo`<0P8200`3Vi^H30820P0806ATI0`00000309VI
V@80c<c<0`1VIVH30;>c/`<0oooo0P1VIVH304a<C0<0c<c<0P1VIVH3000000<06ATI0`1VIVH204a<
C0<0VIVI203AcJT000H0dLfYD@3oool301TI6@<0C4a<0`0I6AT20;>c/`<0VIVI0`1VIVH20;>c/`<0
<c<c0`00000203<c<`<0P8200`2c/k<304a<C080<c<c0`2IVIT306IVIP806ATI0`2IVIT30<c<c0<0
/k>c0P3oool306IVIP<0c<c<0P0I6AT30;>c/`<0c<c<0`0c<c<206IVIP<0C4a<0`3oool209VIV@<0
oooo0`00000301TI6@80IVIV0`00000306IVIP80VIVI0`1VIVH3000000<0P8200P1VIVH309VIV@<0
00000P3Vi^H30;>c/`<000000`3oool206IVIP<000000`3<c<`509VIV@<000000`3Vi^H204a<C0<0
IVIV0`0c<c<206IVIP<0C4a<0`2IVIT301TI6@80i^KV0`1<C4`30>KViP80/k>c0`2IVIT300000080
/k>c0`3Vi^H309VIV@D0P8200`2IVIT30;>c/`D0VIVI0`1<C4`30<c<c080P8200`2IVIT300000080
i^KV0`3<c<`30820P0<0C4a<0P3Vi^H3000000<0<c<c0P0000030<c<c0<0<c<c0`3Vi^H2000000<0
6ATI203AcJT000H0dLfYD@3oool301TI6@<0C4a<0`0I6AT20;>c/`<0VIVI0`1VIVH20;>c/`<0<c<c
0`00000203<c<`<0P8200`2c/k<304a<C080<c<c0`2IVIT306IVIP806ATI0`2IVIT30<c<c0<0/k>c
0P3oool306IVIP<0c<c<0P0I6AT30;>c/`<0c<c<0`0c<c<206IVIP<0C4a<0`3oool209VIV@<0oooo
0`00000301TI6@80IVIV0`00000306IVIP80VIVI0`1VIVH3000000<0P8200P1VIVH309VIV@<00000
0P3Vi^H30;>c/`<000000`3oool206IVIP<000000`3<c<`509VIV@<000000`3Vi^H204a<C0<0IVIV
0`0c<c<206IVIP<0C4a<0`2IVIT301TI6@80i^KV0`1<C4`30>KViP80/k>c0`2IVIT300000080/k>c
0`3Vi^H309VIV@D0P8200`2IVIT30;>c/`D0VIVI0`1<C4`30<c<c080P8200`2IVIT300000080i^KV
0`3<c<`30820P0<0C4a<0P3Vi^H3000000<0<c<c0P0000030<c<c0<0<c<c0`3Vi^H2000000<06ATI
203AcJT000H0dLfYD@3oool301TI6@<0C4a<0`0I6AT20;>c/`<0VIVI0`1VIVH20;>c/`<0<c<c0`00
000203<c<`<0P8200`2c/k<304a<C080<c<c0`2IVIT306IVIP806ATI0`2IVIT30<c<c0<0/k>c0P3o
ool306IVIP<0c<c<0P0I6AT30;>c/`<0c<c<0`0c<c<206IVIP<0C4a<0`3oool209VIV@<0oooo0`00
000301TI6@80IVIV0`00000306IVIP80VIVI0`1VIVH3000000<0P8200P1VIVH309VIV@<000000P3V
i^H30;>c/`<000000`3oool206IVIP<000000`3<c<`509VIV@<000000`3Vi^H204a<C0<0IVIV0`0c
<c<206IVIP<0C4a<0`2IVIT301TI6@80i^KV0`1<C4`30>KViP80/k>c0`2IVIT300000080/k>c0`3V
i^H309VIV@D0P8200`2IVIT30;>c/`D0VIVI0`1<C4`30<c<c080P8200`2IVIT300000080i^KV0`3<
c<`30820P0<0C4a<0P3Vi^H3000000<0<c<c0P0000030<c<c0<0<c<c0`3Vi^H2000000<06ATI203A
cJT000H0dLfYE03oool30820P0<0/k>c0P0c<c<309VIV@<0IVIV0P0000030?ooo`D000000`0I6AT3
06IVIP<0<c<c0P1<C4`30?ooo`<0c<c<0P20P803000000<0C4a<0`3<c<`201TI6@<000000`3<c<`2
0;>c/`<0<c<c0`2IVIT30820P08000000`3<c<`306IVIP80oooo0`0c<c<60;>c/`80c<c<0`1VIVH3
0?ooo`80/k>c0`20P80301TI6@<0/k>c0P1VIVH309VIV@<0i^KV0P3oool306IVIPH0<c<c0P2c/k<3
0>KViP<0oooo0P1<C4`309VIV@<0i^KV0`3oool206IVIP<000000`0c<c<204a<C0<0P8200`2c/k<3
0820P08000000`20P80301TI6@80VIVI0`1VIVH30;>c/`80c<c<0`0I6AT3000000<0C4a<0P2IVIT3
04a<C0<0VIVI0P3oool30<c<c0<0VIVI0`0c<c<209VIV@<0i^KV0`2c/k<203<c<`<06ATI0`20P803
0<c<c080IVIV0`3Vi^H304a<C080oooo0`20P80304a<C0<0oooo1@3Vi^H80=7=Z@001P3AcJUD0?oo
o`<0P8200`2c/k<203<c<`<0VIVI0`1VIVH2000000<0oooo1@00000301TI6@<0IVIV0`0c<c<204a<
C0<0oooo0`3<c<`20820P0<000000`1<C4`30<c<c0806ATI0`0000030<c<c080/k>c0`0c<c<309VI
V@<0P8200P0000030<c<c0<0IVIV0P3oool303<c<`H0/k>c0P3<c<`306IVIP<0oooo0P2c/k<30820
P0<06ATI0`2c/k<206IVIP<0VIVI0`3Vi^H20?ooo`<0IVIV1P0c<c<20;>c/`<0i^KV0`3oool204a<
C0<0VIVI0`3Vi^H30?ooo`80IVIV0`00000303<c<`80C4a<0`20P8030;>c/`<0P8200P0000030820
P0<06ATI0P2IVIT306IVIP<0/k>c0P3<c<`301TI6@<000000`1<C4`209VIV@<0C4a<0`2IVIT20?oo
o`<0c<c<0`2IVIT303<c<`80VIVI0`3Vi^H30;>c/`80<c<c0`0I6AT30820P0<0c<c<0P1VIVH30>KV
iP<0C4a<0P3oool30820P0<0C4a<0`3oool50>KViPP0dLfY00060=7=ZEL0oooo0`3<c<`2000000<0
/k>c0`20P80201TI6@H0/k>c0P0I6AT30;>c/`<0<c<c0`1VIVH20820P0H0/k>c0P2IVIT604a<C0<0
P8200P1<C4`30>KViP<0oooo0P1<C4`30;>c/`<0C4a<0`0000020<c<c0<0i^KV0`0c<c<206IVIP<0
oooo0`00000306IVIP80<c<c0`2IVIT30>KViP80C4a<0`2c/k<306IVIP<0P8200P1<C4`30820P0<0
i^KV0P1<C4`303<c<`<0oooo0`2IVIT203<c<`<000001@20P80301TI6@<0IVIV1@3Vi^H309VIV@<0
00000P2c/k<304a<C0<0VIVI0`1VIVH20;>c/`<06ATI0`3Vi^H20?ooo`<0c<c<0`20P80204a<C0<0
/k>c0`3<c<`303<c<`80oooo0`0c<c<306IVIPD0<c<c0`0000030>KViP80P8200`1<C4`303<c<`80
VIVI0`0I6AT30;>c/`<0oooo0P3Vi^H309VIV@<0P8201@2c/k<306IVIPD0VIVI0`20P8080=7=Z@00
1P3AcJUG0?ooo`<0c<c<0P0000030;>c/`<0P8200P0I6AT60;>c/`806ATI0`2c/k<303<c<`<0IVIV
0P20P8060;>c/`80VIVI1P1<C4`30820P080C4a<0`3Vi^H30?ooo`80C4a<0`2c/k<304a<C0<00000
0P3<c<`30>KViP<0<c<c0P1VIVH30?ooo`<000000`1VIVH203<c<`<0VIVI0`3Vi^H204a<C0<0/k>c
0`1VIVH30820P080C4a<0`20P8030>KViP80C4a<0`0c<c<30?ooo`<0VIVI0P0c<c<3000000D0P820
0`0I6AT306IVIPD0i^KV0`2IVIT300000080/k>c0`1<C4`309VIV@<0IVIV0P2c/k<301TI6@<0i^KV
0P3oool30<c<c0<0P8200P1<C4`30;>c/`<0c<c<0`0c<c<20?ooo`<0<c<c0`1VIVH503<c<`<00000
0`3Vi^H20820P0<0C4a<0`0c<c<209VIV@<06ATI0`2c/k<30?ooo`80i^KV0`2IVIT30820P0D0/k>c
0`1VIVH509VIV@<0P820203AcJT000H0dLfYE`3oool30<c<c08000000`2c/k<30820P0806ATI1P2c
/k<201TI6@<0/k>c0`0c<c<306IVIP80P8201P2c/k<209VIV@H0C4a<0`20P80204a<C0<0i^KV0`3o
ool204a<C0<0/k>c0`1<C4`300000080c<c<0`3Vi^H303<c<`80IVIV0`3oool3000000<0IVIV0P0c
<c<309VIV@<0i^KV0P1<C4`30;>c/`<0IVIV0`20P80204a<C0<0P8200`3Vi^H204a<C0<0<c<c0`3o
ool309VIV@80<c<c0`0000050820P0<06ATI0`1VIVH50>KViP<0VIVI0`0000020;>c/`<0C4a<0`2I
VIT306IVIP80/k>c0`0I6AT30>KViP80oooo0`3<c<`30820P080C4a<0`2c/k<30<c<c0<0<c<c0P3o
ool303<c<`<0IVIV1@0c<c<3000000<0i^KV0P20P80304a<C0<0<c<c0P2IVIT301TI6@<0/k>c0`3o
ool20>KViP<0VIVI0`20P8050;>c/`<0IVIV1@2IVIT30820P0P0dLfY00060=7=ZEX0oooo0P3Vi^H3
06IVIP<0<c<c0P20P803000000<0IVIV0P0c<c<304a<C0<06ATI0`0c<c<206IVIP<0/k>c0`20P802
0>KViP<0/k>c0`1<C4`30820P080<c<c0`1VIVH304a<C080c<c<0`3oool30<c<c0<0oooo0P20P803
06IVIP<0C4a<0P1VIVH30;>c/`H06ATI0P1<C4`306IVIP<0c<c<0P0I6AT30>KViP<06ATI0`3Vi^H2
09VIV@<0c<c<0`20P8020?ooo`<0VIVI0`3<c<`303<c<`80P8201P2IVIT20>KViP<0VIVI0`2c/k<3
06IVIP80C4a<0`3<c<`309VIV@8000000`3oool3000000<0i^KV0P2IVIT306IVIP<0P8200P1VIVH3
0?ooo`<0C4a<0P2IVIT303<c<`<0VIVI0`20P80201TI6@<000000`2c/k<204a<C0<0oooo0`2IVIT3
01TI6@8000000`0c<c<30?ooo`8000000`1<C4`306IVIP<0<c<c0P3<c<`301TI6@<0oooo0P3<c<`3
000000<0oooo0`0I6AT206IVIP<0/k>c203AcJT000H0dLfYFP3oool20>KViP<0IVIV0`0c<c<20820
P0<000000`1VIVH203<c<`<0C4a<0`0I6AT303<c<`80IVIV0`2c/k<30820P080i^KV0`2c/k<304a<
C0<0P8200P0c<c<306IVIP<0C4a<0P3<c<`30?ooo`<0c<c<0`3oool20820P0<0IVIV0`1<C4`206IV
IP<0/k>c1P0I6AT204a<C0<0IVIV0`3<c<`201TI6@<0i^KV0`0I6AT30>KViP80VIVI0`3<c<`30820
P080oooo0`2IVIT30<c<c0<0<c<c0P20P80609VIV@80i^KV0`2IVIT30;>c/`<0IVIV0P1<C4`30<c<
c0<0VIVI0P0000030?ooo`<000000`3Vi^H209VIV@<0IVIV0`20P80206IVIP<0oooo0`1<C4`209VI
V@<0<c<c0`2IVIT30820P0806ATI0`0000030;>c/`80C4a<0`3oool309VIV@<06ATI0P00000303<c
<`<0oooo0P00000304a<C0<0IVIV0`0c<c<20<c<c0<06ATI0`3oool20<c<c0<000000`3oool301TI
6@80IVIV0`2c/k<80=7=Z@001P3AcJUJ0?ooo`80i^KV0`1VIVH303<c<`80P8200`00000306IVIP80
<c<c0`1<C4`301TI6@<0<c<c0P1VIVH30;>c/`<0P8200P3Vi^H30;>c/`<0C4a<0`20P80203<c<`<0
IVIV0`1<C4`20<c<c0<0oooo0`3<c<`30?ooo`80P8200`1VIVH304a<C080IVIV0`2c/k<601TI6@80
C4a<0`1VIVH30<c<c0806ATI0`3Vi^H301TI6@<0i^KV0P2IVIT30<c<c0<0P8200P3oool309VIV@<0
c<c<0`0c<c<20820P0H0VIVI0P3Vi^H309VIV@<0/k>c0`1VIVH204a<C0<0c<c<0`2IVIT2000000<0
oooo0`0000030>KViP80VIVI0`1VIVH30820P080IVIV0`3oool304a<C080VIVI0`0c<c<309VIV@<0
P8200P0I6AT3000000<0/k>c0P1<C4`30?ooo`<0VIVI0`0I6AT2000000<0<c<c0`3oool2000000<0
C4a<0`1VIVH303<c<`80c<c<0`0I6AT30?ooo`80c<c<0`0000030?ooo`<06ATI0P1VIVH30;>c/`P0
dLfY00060=7=ZEl0oooo0`0I6AT203<c<`<0IVIV0`3oool20;>c/`<0<c<c0`3Vi^H30?ooo`80VIVI
0`1<C4`301TI6@80IVIV0`1<C4`30;>c/`<0C4a<0P2IVIT301TI6@<0i^KV0P20P8030?ooo`<0IVIV
0`3Vi^H204a<C0<0VIVI0`0c<c<20?ooo`<06ATI0`20P805000000<0/k>c0`3oool204a<C0<0IVIV
0`1<C4`306IVIP80C4a<0`2c/k<3000000D0C4a<0`0000030?ooo`80VIVI0`1<C4`309VIV@80oooo
0`1VIVH303<c<`<000000P0c<c<306IVIP<0C4a<0P00000609VIV@<06ATI0P00000304a<C0<0P820
0P3<c<`60820P0806ATI0`1VIVH30820P0<0i^KV0P00000609VIV@80oooo0`2c/k<301TI6@D0IVIV
0`3oool509VIV@<000000`2c/k<30?ooo`8000000`1VIVH50820P0<0C4a<1P3Vi^H206IVIP<0VIVI
203AcJT000H0dLfYG`3oool301TI6@80<c<c0`1VIVH30?ooo`80/k>c0`0c<c<30>KViP<0oooo0P2I
VIT304a<C0<06ATI0P1VIVH304a<C0<0/k>c0`1<C4`209VIV@<06ATI0`3Vi^H20820P0<0oooo0`1V
IVH30>KViP80C4a<0`2IVIT303<c<`80oooo0`0I6AT30820P0D000000`2c/k<30?ooo`80C4a<0`1V
IVH304a<C0<0IVIV0P1<C4`30;>c/`<000001@1<C4`3000000<0oooo0P2IVIT304a<C0<0VIVI0P3o
ool306IVIP<0<c<c0`00000203<c<`<0IVIV0`1<C4`2000000H0VIVI0`0I6AT2000000<0C4a<0`20
P8020<c<c0H0P8200P0I6AT306IVIP<0P8200`3Vi^H2000000H0VIVI0P3oool30;>c/`<06ATI1@1V
IVH30?ooo`D0VIVI0`0000030;>c/`<0oooo0P00000306IVIPD0P8200`1<C4`60>KViP80IVIV0`2I
VIT80=7=Z@001P3AcJUO0?ooo`<06ATI0P0c<c<306IVIP<0oooo0P2c/k<303<c<`<0i^KV0`3oool2
09VIV@<0C4a<0`0I6AT206IVIP<0C4a<0`2c/k<304a<C080VIVI0`0I6AT30>KViP80P8200`3oool3
06IVIP<0i^KV0P1<C4`309VIV@<0<c<c0P3oool301TI6@<0P8201@0000030;>c/`<0oooo0P1<C4`3
06IVIP<0C4a<0`1VIVH204a<C0<0/k>c0`00000504a<C0<000000`3oool209VIV@<0C4a<0`2IVIT2
0?ooo`<0IVIV0`0c<c<300000080<c<c0`1VIVH304a<C08000001P2IVIT301TI6@8000000`1<C4`3
0820P080c<c<1P20P80201TI6@<0IVIV0`20P8030>KViP8000001P2IVIT20?ooo`<0/k>c0`0I6AT5
06IVIP<0oooo1@2IVIT3000000<0/k>c0`3oool2000000<0IVIV1@20P80304a<C0H0i^KV0P1VIVH3
09VIV@P0dLfY00060=7=ZF80oooo0P20P80309VIV@<0i^KV0P1<C4`30;>c/`<0C4a<0`0c<c<20<c<
c0<000000`0I6AT20;>c/`<0oooo0`0000030?ooo`8000000`3Vi^H306IVIP80i^KV0`2c/k<301TI
6@<0C4a<0P3<c<`306IVIP<0/k>c0P3Vi^H304a<C0<0IVIV200I6AT50820P0<06ATI0`1<C4`30820
P0806ATI0`3Vi^H301TI6@80/k>c0`1<C4`306IVIPD0oooo0`3<c<`306IVIP80c<c<0`0c<c<306IV
IPD0P8200`2IVIT30<c<c080oooo0`20P80304a<C0<000001@2IVIT30<c<c080P8200`3oool301TI
6@80i^KV0`3oool30;>c/`<0IVIV0P3Vi^H306IVIP<06ATI1@3oool30<c<c0<0i^KV0P2IVIT604a<
C08000000`3Vi^H306IVIP<0<c<c1@2c/k<30?ooo`806ATI0`3oool301TI6@<000000P20P80301TI
6@P0dLfY00060=7=ZF80oooo0P20P80309VIV@<0i^KV0P1<C4`30;>c/`<0C4a<0`0c<c<20<c<c0<0
00000`0I6AT20;>c/`<0oooo0`0000030?ooo`8000000`3Vi^H306IVIP80i^KV0`2c/k<301TI6@<0
C4a<0P3<c<`306IVIP<0/k>c0P3Vi^H304a<C0<0IVIV200I6AT50820P0<06ATI0`1<C4`30820P080
6ATI0`3Vi^H301TI6@80/k>c0`1<C4`306IVIPD0oooo0`3<c<`306IVIP80c<c<0`0c<c<306IVIPD0
P8200`2IVIT30<c<c080oooo0`20P80304a<C0<000001@2IVIT30<c<c080P8200`3oool301TI6@80
i^KV0`3oool30;>c/`<0IVIV0P3Vi^H306IVIP<06ATI1@3oool30<c<c0<0i^KV0P2IVIT604a<C080
00000`3Vi^H306IVIP<0<c<c1@2c/k<30?ooo`806ATI0`3oool301TI6@<000000P20P80301TI6@P0
dLfY00060=7=ZF@0oooo0`3<c<`300000080P8200`0I6AT30820P0<06ATI0P0c<c<609VIV@80/k>c
0`2IVIT6000000D0P8200`3oool20;>c/`<0VIVI0`3oool30820P080/k>c0`2IVIT304a<C0806ATI
0`2IVIT303<c<`<0IVIV0P20P80600000080i^KV0`00000309VIV@<0c<c<0P20P80309VIV@<0P820
0P2IVIT306IVIP<0VIVI201<C4`301TI6@80i^KV0`3<c<`306IVIP<000000P3Vi^H3000000<0i^KV
1@3<c<`30820P0<0/k>c0P0I6AT30?ooo`<0c<c<0P2c/k<306IVIP<0i^KV1@3oool306IVIP<0c<c<
0P20P80306IVIP<0VIVI202c/k<309VIV@80P8200`3<c<`30?ooo`80VIVI0`2c/k<3000000<0c<c<
0P1VIVH303<c<`D0VIVI0`0I6AT309VIV@<0/k>c0P0I6AT30>KViPP0dLfY00060=7=ZF@0oooo0`3<
c<`300000080P8200`0I6AT30820P0<06ATI0P0c<c<609VIV@80/k>c0`2IVIT6000000D0P8200`3o
ool20;>c/`<0VIVI0`3oool30820P080/k>c0`2IVIT304a<C0806ATI0`2IVIT303<c<`<0IVIV0P20
P80600000080i^KV0`00000309VIV@<0c<c<0P20P80309VIV@<0P8200P2IVIT306IVIP<0VIVI201<
C4`301TI6@80i^KV0`3<c<`306IVIP<000000P3Vi^H3000000<0i^KV1@3<c<`30820P0<0/k>c0P0I
6AT30?ooo`<0c<c<0P2c/k<306IVIP<0i^KV1@3oool306IVIP<0c<c<0P20P80306IVIP<0VIVI202c
/k<309VIV@80P8200`3<c<`30?ooo`80VIVI0`2c/k<3000000<0c<c<0P1VIVH303<c<`D0VIVI0`0I
6AT309VIV@<0/k>c0P0I6AT30>KViPP0dLfY00060=7=ZF@0oooo0`3<c<`300000080P8200`0I6AT3
0820P0<06ATI0P0c<c<609VIV@80/k>c0`2IVIT6000000D0P8200`3oool20;>c/`<0VIVI0`3oool3
0820P080/k>c0`2IVIT304a<C0806ATI0`2IVIT303<c<`<0IVIV0P20P80600000080i^KV0`000003
09VIV@<0c<c<0P20P80309VIV@<0P8200P2IVIT306IVIP<0VIVI201<C4`301TI6@80i^KV0`3<c<`3
06IVIP<000000P3Vi^H3000000<0i^KV1@3<c<`30820P0<0/k>c0P0I6AT30?ooo`<0c<c<0P2c/k<3
06IVIP<0i^KV1@3oool306IVIP<0c<c<0P20P80306IVIP<0VIVI202c/k<309VIV@80P8200`3<c<`3
0?ooo`80VIVI0`2c/k<3000000<0c<c<0P1VIVH303<c<`D0VIVI0`0I6AT309VIV@<0/k>c0P0I6AT3
0>KViPP0dLfY00060=7=ZFL0oooo0`3Vi^H206IVIPH06ATI0`3Vi^H20?ooo`<0VIVI0`1VIVH203<c
<`<00000201<C4`309VIV@<0C4a<0P3Vi^H301TI6@H0oooo0P3<c<`3000000<0i^KV0P20P80309VI
V@<0C4a<0`3oool20;>c/`P0IVIV0`3Vi^H306IVIP<0<c<c0P0000030>KViP<06ATI0P1VIVH301TI
6@<0i^KV0`2c/k<204a<C0<0P8200`0I6AT203<c<`<06ATI0`20P8030;>c/`80c<c<0`0I6AT50;>c
/`<000000`1VIVH30;>c/`80P8201P2IVIT20820P0<0C4a<0`20P8080?ooo`<0/k>c0P2IVIT304a<
C0<0P8200P3Vi^H303<c<`<000000`1VIVH201TI6@<0oooo0`1<C4`20>KViP<06ATI0`1VIVH30?oo
o`80i^KV0`2IVIT301TI6@80oooo0`3<c<`304a<C0<0VIVI0P3oool30820P0P0dLfY00060=7=ZFL0
oooo0`3Vi^H206IVIPH06ATI0`3Vi^H20?ooo`<0VIVI0`1VIVH203<c<`<00000201<C4`309VIV@<0
C4a<0P3Vi^H301TI6@H0oooo0P3<c<`3000000<0i^KV0P20P80309VIV@<0C4a<0`3oool20;>c/`P0
IVIV0`3Vi^H306IVIP<0<c<c0P0000030>KViP<06ATI0P1VIVH301TI6@<0i^KV0`2c/k<204a<C0<0
P8200`0I6AT203<c<`<06ATI0`20P8030;>c/`80c<c<0`0I6AT50;>c/`<000000`1VIVH30;>c/`80
P8201P2IVIT20820P0<0C4a<0`20P8080?ooo`<0/k>c0P2IVIT304a<C0<0P8200P3Vi^H303<c<`<0
00000`1VIVH201TI6@<0oooo0`1<C4`20>KViP<06ATI0`1VIVH30?ooo`80i^KV0`2IVIT301TI6@80
oooo0`3<c<`304a<C0<0VIVI0P3oool30820P0P0dLfY00060=7=ZFL0oooo0`3Vi^H206IVIPH06ATI
0`3Vi^H20?ooo`<0VIVI0`1VIVH203<c<`<00000201<C4`309VIV@<0C4a<0P3Vi^H301TI6@H0oooo
0P3<c<`3000000<0i^KV0P20P80309VIV@<0C4a<0`3oool20;>c/`P0IVIV0`3Vi^H306IVIP<0<c<c
0P0000030>KViP<06ATI0P1VIVH301TI6@<0i^KV0`2c/k<204a<C0<0P8200`0I6AT203<c<`<06ATI
0`20P8030;>c/`80c<c<0`0I6AT50;>c/`<000000`1VIVH30;>c/`80P8201P2IVIT20820P0<0C4a<
0`20P8080?ooo`<0/k>c0P2IVIT304a<C0<0P8200P3Vi^H303<c<`<000000`1VIVH201TI6@<0oooo
0`1<C4`20>KViP<06ATI0`1VIVH30?ooo`80i^KV0`2IVIT301TI6@80oooo0`3<c<`304a<C0<0VIVI
0P3oool30820P0P0dLfY00060=7=ZF`0oooo1P0I6AT30<c<c080<c<c0`0I6AT30?ooo`80/k>c0`0c
<c<30<c<c0<0IVIV0P2IVIT303<c<`<0P8200P2c/k<309VIV@P0/k>c0`2IVIT301TI6@8000000`1<
C4`3000000<0c<c<0P0c<c<309VIV@<0<c<c0P3oool30;>c/`<0VIVI0`3<c<`20>KViP<0oooo0`1<
C4`20?ooo`<06ATI0`0c<c<301TI6@80P8200`0I6AT304a<C080oooo1P0000030>KViP80<c<c0`00
000309VIV@80oooo0`3<c<`30>KViP<000000P1VIVH301TI6@<0IVIV0P2c/k<30?ooo`<0VIVI2`3V
i^H20<c<c0<000000`0I6AT20?ooo`<0C4a<0`3oool30820P0806ATI0`3<c<`303<c<`80IVIV0`1<
C4`306IVIPD06ATI0`00000304a<C0D0IVIV0`0c<c<30?ooo`80<c<c0`2c/k<80=7=Z@001P3AcJU/
0?ooo`H06ATI0`3<c<`203<c<`<06ATI0`3oool20;>c/`<0<c<c0`3<c<`306IVIP80VIVI0`0c<c<3
0820P080/k>c0`2IVIT80;>c/`<0VIVI0`0I6AT2000000<0C4a<0`0000030<c<c080<c<c0`2IVIT3
03<c<`80oooo0`2c/k<309VIV@<0c<c<0P3Vi^H30?ooo`<0C4a<0P3oool301TI6@<0<c<c0`0I6AT2
0820P0<06ATI0`1<C4`20?ooo`H000000`3Vi^H203<c<`<000000`2IVIT20?ooo`<0c<c<0`3Vi^H3
00000080IVIV0`0I6AT306IVIP80/k>c0`3oool309VIV@/0i^KV0P3<c<`3000000<06ATI0P3oool3
04a<C0<0oooo0`20P80201TI6@<0c<c<0`0c<c<206IVIP<0C4a<0`1VIVH501TI6@<000000`1<C4`5
06IVIP<0<c<c0`3oool203<c<`<0/k>c203AcJT000H0dLfYK`3oool30820P0<0VIVI0P20P8030000
00<0/k>c0P0I6AT30820P0<000000`3oool20;>c/`<0P8200`0000020>KViP<06ATI0`3oool30>KV
iP80<c<c0`00000504a<C0<0i^KV1P20P8020?ooo`<000000`1<C4`206IVIP<0oooo0`1<C4`30000
00D0oooo0`1VIVH509VIV@<06ATI0`0c<c<204a<C0H000000P3<c<`903<c<`80/k>c0`0c<c<30<c<
c0D0VIVI0`20P80506IVIP<0VIVI0`2c/k<206IVIP<0<c<c0`3<c<`2000000<0P8200`1VIVH50>KV
iPH0<c<c0P1<C4`303<c<`<0oooo0`1VIVH20;>c/`<0<c<c0`2IVIT20;>c/`<0oooo0`0000030<c<
c0D0C4a<0`3Vi^H20820P0<0/k>c0`3oool300000080P8200`2IVIT80=7=Z@001P3AcJU_0?ooo`<0
P8200`2IVIT20820P0<000000`2c/k<201TI6@<0P8200`0000030?ooo`80/k>c0`20P80300000080
i^KV0`0I6AT30?ooo`<0i^KV0P0c<c<3000000D0C4a<0`3Vi^H60820P080oooo0`00000304a<C080
IVIV0`3oool304a<C0<000001@3oool306IVIPD0VIVI0`0I6AT303<c<`80C4a<1P0000020<c<c0T0
<c<c0P2c/k<303<c<`<0c<c<1@2IVIT30820P0D0IVIV0`2IVIT30;>c/`80IVIV0`0c<c<30<c<c080
00000`20P80306IVIPD0i^KV1P0c<c<204a<C0<0<c<c0`3oool306IVIP80/k>c0`0c<c<309VIV@80
/k>c0`3oool3000000<0c<c<1@1<C4`30>KViP80P8200`2c/k<30?ooo`<000000P20P80309VIV@P0
dLfY00060=7=ZFl0oooo0`20P80309VIV@80P8200`0000030;>c/`806ATI0`20P803000000<0oooo
0P2c/k<30820P0<000000P3Vi^H301TI6@<0oooo0`3Vi^H203<c<`<000001@1<C4`30>KViPH0P820
0P3oool3000000<0C4a<0P1VIVH30?ooo`<0C4a<0`0000050?ooo`<0IVIV1@2IVIT301TI6@<0<c<c
0P1<C4`600000080c<c<2@0c<c<20;>c/`<0<c<c0`3<c<`509VIV@<0P8201@1VIVH309VIV@<0/k>c
0P1VIVH303<c<`<0c<c<0P0000030820P0<0IVIV1@3Vi^H603<c<`80C4a<0`0c<c<30?ooo`<0IVIV
0P2c/k<303<c<`<0VIVI0P2c/k<30?ooo`<000000`3<c<`504a<C0<0i^KV0P20P8030;>c/`<0oooo
0`0000020820P0<0VIVI203AcJT000H0dLfYLP3oool30<c<c08000000`0c<c<30<c<c080VIVI0`2c
/k<606IVIP80oooo0`1<C4`5000000<0P8200`0000030820P080oooo0`2IVIT300000080/k>c1P3V
i^H300000080i^KV1P1<C4`20820P0<0<c<c0`0I6AT30<c<c080i^KV0`1<C4`30>KViP8000000`1<
C4`309VIV@<0/k>c0P0c<c<60>KViP80oooo0`1<C4`306IVIP<0P8200P2IVIT30?ooo`<0VIVI0P20
P80304a<C0<000000`3Vi^H2000000<0<c<c0`20P8020>KViP<0VIVI0`0c<c<2000000<0VIVI0`1<
C4`30820P0D0oooo0`00000201TI6@<0<c<c1P3Vi^H209VIV@<0IVIV0`20P8020>KViP<0<c<c0`0I
6AT30;>c/`80VIVI0`0c<c<306IVIP80C4a<0`2IVIT306IVIP<0i^KV0P3oool301TI6@P0dLfY0006
0=7=ZG80oooo0`3<c<`2000000<0<c<c0`3<c<`209VIV@<0/k>c1P1VIVH20?ooo`<0C4a<1@000003
0820P0<000000`20P8020?ooo`<0VIVI0`0000020;>c/`H0i^KV0`0000020>KViPH0C4a<0P20P803
03<c<`<06ATI0`3<c<`20>KViP<0C4a<0`3Vi^H2000000<0C4a<0`2IVIT30;>c/`80<c<c1P3Vi^H2
0?ooo`<0C4a<0`1VIVH30820P080VIVI0`3oool309VIV@80P8200`1<C4`3000000<0i^KV0P000003
03<c<`<0P8200P3Vi^H309VIV@<0<c<c0P00000309VIV@<0C4a<0`20P8050?ooo`<000000P0I6AT3
03<c<`H0i^KV0P2IVIT306IVIP<0P8200P3Vi^H303<c<`<06ATI0`2c/k<209VIV@<0<c<c0`1VIVH2
04a<C0<0VIVI0`1VIVH30>KViP80oooo0`0I6AT80=7=Z@001P3AcJUb0?ooo`<0c<c<0P00000303<c
<`<0c<c<0P2IVIT30;>c/`H0IVIV0P3oool304a<C0D000000`20P803000000<0P8200P3oool309VI
V@<000000P2c/k<60>KViP<000000P3Vi^H604a<C080P8200`0c<c<301TI6@<0c<c<0P3Vi^H304a<
C0<0i^KV0P00000304a<C0<0VIVI0`2c/k<203<c<`H0i^KV0P3oool304a<C0<0IVIV0`20P80209VI
V@<0oooo0`2IVIT20820P0<0C4a<0`0000030>KViP8000000`0c<c<30820P080i^KV0`2IVIT303<c
<`8000000`2IVIT304a<C0<0P8201@3oool3000000806ATI0`0c<c<60>KViP80VIVI0`1VIVH30820
P080i^KV0`0c<c<301TI6@<0/k>c0P2IVIT303<c<`<0IVIV0P1<C4`309VIV@<0IVIV0`3Vi^H20?oo
o`<06ATI203AcJT000H0dLfYM@3oool20>KViP<0C4a<0`3oool20>KViP<0/k>c0`20P8030;>c/`80
oooo0`1VIVH309VIV@8000000`2IVIT604a<C0D0VIVI0`1<C4`20>KViP<0c<c<0`0c<c<501TI6@<0
VIVI0`0c<c<206IVIP<06ATI0`0c<c<304a<C080<c<c0`0I6AT304a<C0D0<c<c0`1VIVH303<c<`80
00000`0I6AT509VIV@<000000`0I6AT30>KViP80VIVI0`3oool306IVIP80/k>c0`3oool309VIV@<0
/k>c0P00000309VIV@<06ATI0P3oool306IVIP<06ATI0P3<c<`304a<C0<000000`2c/k<80?ooo`80
P8200`00000301TI6@<0VIVI0P20P8030>KViP<000000P1<C4`303<c<`<0C4a<0`1VIVH203<c<`<0
P8200`2IVIT20<c<c0<0oooo0`3<c<`30820P080IVIV0`3Vi^H80=7=Z@001P3AcJUe0?ooo`80i^KV
0`1<C4`30?ooo`80i^KV0`2c/k<30820P0<0/k>c0P3oool306IVIP<0VIVI0P00000309VIV@H0C4a<
1@2IVIT304a<C080i^KV0`3<c<`303<c<`D06ATI0`2IVIT303<c<`80IVIV0`0I6AT303<c<`<0C4a<
0P0c<c<301TI6@<0C4a<1@0c<c<306IVIP<0<c<c0P00000301TI6@D0VIVI0`00000301TI6@<0i^KV
0P2IVIT30?ooo`<0IVIV0P2c/k<30?ooo`<0VIVI0`2c/k<2000000<0VIVI0`0I6AT20?ooo`<0IVIV
0`0I6AT20<c<c0<0C4a<0`0000030;>c/`P0oooo0P20P803000000<06ATI0`2IVIT20820P0<0i^KV
0`00000204a<C0<0<c<c0`1<C4`306IVIP80<c<c0`20P80309VIV@80c<c<0`3oool30<c<c0<0P820
0P1VIVH30>KViPP0dLfY00060=7=ZGD0oooo0P3Vi^H304a<C0<0oooo0P3Vi^H30;>c/`<0P8200`2c
/k<20?ooo`<0IVIV0`2IVIT2000000<0VIVI1P1<C4`509VIV@<0C4a<0P3Vi^H30<c<c0<0<c<c1@0I
6AT309VIV@<0<c<c0P1VIVH301TI6@<0<c<c0`1<C4`203<c<`<06ATI0`1<C4`503<c<`<0IVIV0`0c
<c<2000000<06ATI1@2IVIT3000000<06ATI0`3Vi^H209VIV@<0oooo0`1VIVH20;>c/`<0oooo0`2I
VIT30;>c/`8000000`2IVIT301TI6@80oooo0`1VIVH301TI6@80c<c<0`1<C4`3000000<0/k>c203o
ool20820P0<000000`0I6AT309VIV@80P8200`3Vi^H300000080C4a<0`0c<c<304a<C0<0IVIV0P0c
<c<30820P0<0VIVI0P3<c<`30?ooo`<0c<c<0`20P80206IVIP<0i^KV203AcJT000H0dLfYNP3oool5
01TI6@<000000`1VIVH301TI6@D0P8200`0I6AT20?ooo`<0P8200`0c<c<30?ooo`8000000`3Vi^H3
0;>c/`80C4a<0`3<c<`30;>c/`<0<c<c0P3<c<`30>KViP<0/k>c0P0c<c<30?ooo`<0P8200`2IVIT2
0<c<c0<0C4a<0`3oool2000000<0/k>c0`0c<c<30?ooo`80VIVI0`00000309VIV@80oooo1P0c<c<3
04a<C080<c<c0`2IVIT300000080<c<c1P2IVIT306IVIPD0<c<c0`20P80509VIV@<0<c<c0P3Vi^H3
03<c<`<0C4a<0`3Vi^H20<c<c0<0<c<c0`3<c<`203<c<`<0IVIV0`3oool30820P080i^KV0`0I6AT5
000000<06ATI0`3<c<`306IVIP80VIVI0`2c/k<30?ooo`80c<c<1P2c/k<309VIV@80C4a<0`20P808
0=7=Z@001P3AcJUj0?ooo`D06ATI0`00000306IVIP<06ATI1@20P80301TI6@80oooo0`20P80303<c
<`<0oooo0P0000030>KViP<0/k>c0P1<C4`30<c<c0<0/k>c0`0c<c<20<c<c0<0i^KV0`2c/k<203<c
<`<0oooo0`20P80309VIV@80c<c<0`1<C4`30?ooo`8000000`2c/k<303<c<`<0oooo0P2IVIT30000
00<0VIVI0P3oool603<c<`<0C4a<0P0c<c<309VIV@<000000P0c<c<609VIV@<0IVIV1@0c<c<30820
P0D0VIVI0`0c<c<20>KViP<0<c<c0`1<C4`30>KViP80c<c<0`0c<c<30<c<c080<c<c0`1VIVH30?oo
o`<0P8200P3Vi^H301TI6@D000000`0I6AT30<c<c0<0IVIV0P2IVIT30;>c/`<0oooo0P3<c<`60;>c
/`<0VIVI0P1<C4`30820P0P0dLfY00060=7=ZGd0oooo0P20P80309VIV@<000000`3<c<`204a<C0<0
VIVI0`1<C4`506IVIP<06ATI0`0c<c<20;>c/`<0c<c<0`0c<c<2000000<0<c<c0`0000030?ooo`80
00000`1VIVH30>KViP80/k>c0`3Vi^H304a<C0<0VIVI0P1VIVH303<c<`<0oooo1@1VIVH30<c<c0D0
IVIV0`0I6AT30;>c/`D0P8200`0000030;>c/`80C4a<0`1VIVH50;>c/`<0i^KV0`0I6AT306IVIP80
VIVI0`2c/k<30>KViP8000000`3Vi^H30;>c/`80C4a<0`0c<c<304a<C0<0P8200P1VIVH30<c<c0<0
oooo0P1<C4`306IVIP<0/k>c0`0I6AT206IVIPH0C4a<0P3Vi^H304a<C0<0oooo0`1<C4`20820P0<0
i^KV1@0c<c<3000000<0oooo0`1<C4`2000000<0/k>c203AcJT000H0dLfYO@3oool20820P0<0VIVI
0`0000030<c<c080C4a<0`2IVIT304a<C0D0IVIV0`0I6AT303<c<`80/k>c0`3<c<`303<c<`800000
0`0c<c<3000000<0oooo0P00000306IVIP<0i^KV0P2c/k<30>KViP<0C4a<0`2IVIT206IVIP<0<c<c
0`3oool506IVIP<0c<c<1@1VIVH301TI6@<0/k>c1@20P803000000<0/k>c0P1<C4`306IVIPD0/k>c
0`3Vi^H301TI6@<0IVIV0P2IVIT30;>c/`<0i^KV0P0000030>KViP<0/k>c0P1<C4`303<c<`<0C4a<
0`20P80206IVIP<0c<c<0`3oool204a<C0<0IVIV0`2c/k<301TI6@80IVIV1P1<C4`20>KViP<0C4a<
0`3oool304a<C080P8200`3Vi^H503<c<`<000000`3oool304a<C08000000`2c/k<80=7=Z@001P3A
cJUm0?ooo`80P8200`2IVIT3000000<0c<c<0P1<C4`309VIV@<0C4a<1@1VIVH301TI6@<0<c<c0P2c
/k<30<c<c0<0<c<c0P00000303<c<`<000000`3oool2000000<0IVIV0`3Vi^H20;>c/`<0i^KV0`1<
C4`309VIV@80IVIV0`0c<c<30?ooo`D0IVIV0`3<c<`506IVIP<06ATI0`2c/k<50820P0<000000`2c
/k<204a<C0<0IVIV1@2c/k<30>KViP<06ATI0`1VIVH209VIV@<0/k>c0`3Vi^H2000000<0i^KV0`2c
/k<204a<C0<0<c<c0`1<C4`30820P080IVIV0`3<c<`30?ooo`80C4a<0`1VIVH30;>c/`<06ATI0P1V
IVH604a<C080i^KV0`1<C4`30?ooo`<0C4a<0P20P8030>KViPD0<c<c0`0000030?ooo`<0C4a<0P00
00030;>c/`P0dLfY00060=7=ZGl0oooo0`3<c<`600000080IVIV0`2IVIT306IVIP8000000`0c<c<3
06IVIP<0P8200P0000030?ooo`<0C4a<1@1VIVH30820P0<0VIVI1@00000303<c<`80/k>c0`20P803
0?ooo`<0VIVI0P3oool301TI6@<0<c<c0P2c/k<30?ooo`<06ATI0`20P8020;>c/`<0i^KV0`3oool2
0>KViP<000000`3<c<`30>KViP806ATI0`3Vi^H300000080IVIV0`0c<c<30;>c/`<0<c<c0P1VIVH3
0<c<c0<06ATI1@0000030820P080C4a<0`20P803000000<0/k>c0P3oool30;>c/`D0VIVI0`0c<c<3
06IVIP<0c<c<0P1<C4`30820P0<0/k>c0P1<C4`30<c<c0<0IVIV0`3oool2000000<0i^KV0`0c<c<2
0>KViP<0IVIV1P3oool509VIV@P0dLfY00060=7=ZGl0oooo0`3<c<`600000080IVIV0`2IVIT306IV
IP8000000`0c<c<306IVIP<0P8200P0000030?ooo`<0C4a<1@1VIVH30820P0<0VIVI1@00000303<c
<`80/k>c0`20P8030?ooo`<0VIVI0P3oool301TI6@<0<c<c0P2c/k<30?ooo`<06ATI0`20P8020;>c
/`<0i^KV0`3oool20>KViP<000000`3<c<`30>KViP806ATI0`3Vi^H300000080IVIV0`0c<c<30;>c
/`<0<c<c0P1VIVH30<c<c0<06ATI1@0000030820P080C4a<0`20P803000000<0/k>c0P3oool30;>c
/`D0VIVI0`0c<c<306IVIP<0c<c<0P1<C4`30820P0<0/k>c0P1<C4`30<c<c0<0IVIV0`3oool20000
00<0i^KV0`0c<c<20>KViP<0IVIV1P3oool509VIV@P0dLfY00060=7=ZGl0oooo0`3<c<`600000080
IVIV0`2IVIT306IVIP8000000`0c<c<306IVIP<0P8200P0000030?ooo`<0C4a<1@1VIVH30820P0<0
VIVI1@00000303<c<`80/k>c0`20P8030?ooo`<0VIVI0P3oool301TI6@<0<c<c0P2c/k<30?ooo`<0
6ATI0`20P8020;>c/`<0i^KV0`3oool20>KViP<000000`3<c<`30>KViP806ATI0`3Vi^H300000080
IVIV0`0c<c<30;>c/`<0<c<c0P1VIVH30<c<c0<06ATI1@0000030820P080C4a<0`20P803000000<0
/k>c0P3oool30;>c/`D0VIVI0`0c<c<306IVIP<0c<c<0P1<C4`30820P0<0/k>c0P1<C4`30<c<c0<0
IVIV0`3oool2000000<0i^KV0`0c<c<20>KViP<0IVIV1P3oool509VIV@P0dLfY00060=7=ZH80oooo
0`3Vi^H304a<C080i^KV0`2IVIT306IVIP8000000`2IVIT301TI6@<0i^KV0P2IVIT30;>c/`<06ATI
0P0c<c<30?ooo`<0/k>c0`1VIVH80;>c/`80i^KV0`0I6AT30?ooo`<0IVIV0P3<c<`603<c<`80i^KV
0`3<c<`303<c<`<0C4a<0P00000306IVIP<0C4a<0P3Vi^H303<c<`<0c<c<0`2c/k<209VIV@<0/k>c
1@2IVIT30<c<c0<0oooo0`0c<c<20>KViP<0VIVI0`20P80800000080<c<c0`3oool301TI6@<0/k>c
0P2IVIT3000000<0IVIV0P0I6AT30?ooo`<0VIVI0`1<C4`201TI6@<0i^KV0`0000020?ooo`<00000
0`3oool50;>c/`<0<c<c0`0I6AT203<c<`<0/k>c201VIVH301TI6@P0dLfY00060=7=ZH80oooo0`3V
i^H304a<C080i^KV0`2IVIT306IVIP8000000`2IVIT301TI6@<0i^KV0P2IVIT30;>c/`<06ATI0P0c
<c<30?ooo`<0/k>c0`1VIVH80;>c/`80i^KV0`0I6AT30?ooo`<0IVIV0P3<c<`603<c<`80i^KV0`3<
c<`303<c<`<0C4a<0P00000306IVIP<0C4a<0P3Vi^H303<c<`<0c<c<0`2c/k<209VIV@<0/k>c1@2I
VIT30<c<c0<0oooo0`0c<c<20>KViP<0VIVI0`20P80800000080<c<c0`3oool301TI6@<0/k>c0P2I
VIT3000000<0IVIV0P0I6AT30?ooo`<0VIVI0`1<C4`201TI6@<0i^KV0`0000020?ooo`<000000`3o
ool50;>c/`<0<c<c0`0I6AT203<c<`<0/k>c201VIVH301TI6@P0dLfY00060=7=ZHP0oooo0P0I6AT3
000000<0C4a<1@20P8030<c<c0D0i^KV0`0I6AT30820P08000000`0I6AT309VIV@<0oooo0P2c/k<3
0820P0<0i^KV0P3<c<`301TI6@<0c<c<0`0c<c<206IVIP<0c<c<0`3oool2000000<0P8200`1<C4`3
0?ooo`D0VIVI0`3<c<`50?ooo`<000000`1VIVH20<c<c0<0VIVI0`1VIVH20<c<c0<000000`1VIVH3
0?ooo`8000000`20P80304a<C0X000000`0I6AT309VIV@<0/k>c0P20P8030<c<c0<0i^KV0P000003
01TI6@<000000`3Vi^H20820P0<0VIVI0`20P80209VIV@H000000`20P8020>KViP<0/k>c0`3<c<`2
0>KViP<0P8200`1<C4`30820P080/k>c0`3Vi^H80=7=Z@001P3AcJV80?ooo`806ATI0`00000304a<
C0D0P8200`3<c<`50>KViP<06ATI0`20P802000000<06ATI0`2IVIT30?ooo`80/k>c0`20P8030>KV
iP80c<c<0`0I6AT30<c<c0<0<c<c0P1VIVH30<c<c0<0oooo0P0000030820P0<0C4a<0`3oool509VI
V@<0c<c<1@3oool3000000<0IVIV0P3<c<`309VIV@<0IVIV0P3<c<`3000000<0IVIV0`3oool20000
00<0P8200`1<C4`:000000<06ATI0`2IVIT30;>c/`80P8200`3<c<`30>KViP8000000`0I6AT30000
00<0i^KV0P20P80309VIV@<0P8200P2IVIT6000000<0P8200P3Vi^H30;>c/`<0c<c<0P3Vi^H30820
P0<0C4a<0`20P8020;>c/`<0i^KV203AcJT000H0dLfYR03oool201TI6@<000000`1<C4`50820P0<0
c<c<1@3Vi^H301TI6@<0P8200P00000301TI6@<0VIVI0`3oool20;>c/`<0P8200`3Vi^H20<c<c0<0
6ATI0`3<c<`303<c<`80IVIV0`3<c<`30?ooo`8000000`20P80304a<C0<0oooo1@2IVIT30<c<c0D0
oooo0`00000306IVIP80c<c<0`2IVIT306IVIP80c<c<0`00000306IVIP<0oooo0P0000030820P0<0
C4a<2P00000301TI6@<0VIVI0`2c/k<20820P0<0c<c<0`3Vi^H2000000<06ATI0`0000030>KViP80
P8200`2IVIT30820P080VIVI1P0000030820P080i^KV0`2c/k<30<c<c080i^KV0`20P80304a<C0<0
P8200P2c/k<30>KViPP0dLfY00060=7=ZHX0oooo1P20P8020;>c/`<0IVIV0`2c/k<309VIV@80P820
0`3oool30820P080c<c<0`0c<c<30>KViP<06ATI0P2IVIT30?ooo`<0c<c<0P0c<c<3000000<0/k>c
0`00000201TI6@<0C4a<0`3<c<`503<c<`<0P8200`0I6AT209VIV@<0oooo0`0c<c<20;>c/`<06ATI
1P2IVIT20>KViP<0<c<c0`20P8020<c<c0H06ATI0`1<C4`20<c<c0<0i^KV0`00000=0;>c/`<0c<c<
0`2IVIT206IVIP<0/k>c0`2IVIT50820P0<0VIVI0`0I6AT2000000<0C4a<0`0000020>KViPT06ATI
0P1VIVH304a<C0<0/k>c0P2IVIT30820P0<0c<c<0`1VIVH20;>c/`<0P820203AcJT000H0dLfYRP3o
ool60820P080/k>c0`1VIVH30;>c/`<0VIVI0P20P8030?ooo`<0P8200P3<c<`303<c<`<0i^KV0`0I
6AT209VIV@<0oooo0`3<c<`203<c<`<000000`2c/k<3000000806ATI0`1<C4`30<c<c0D0<c<c0`20
P80301TI6@80VIVI0`3oool303<c<`80/k>c0`0I6AT609VIV@80i^KV0`0c<c<30820P080c<c<1P0I
6AT304a<C080c<c<0`3Vi^H3000000d0/k>c0`3<c<`309VIV@80IVIV0`2c/k<309VIV@D0P8200`2I
VIT301TI6@8000000`1<C4`300000080i^KV2@0I6AT206IVIP<0C4a<0`2c/k<209VIV@<0P8200`3<
c<`306IVIP80/k>c0`20P8080=7=Z@001P3AcJV:0?ooo`H0P8200P2c/k<306IVIP<0/k>c0`2IVIT2
0820P0<0oooo0`20P8020<c<c0<0<c<c0`3Vi^H301TI6@80VIVI0`3oool30<c<c080<c<c0`000003
0;>c/`<000000P0I6AT304a<C0<0c<c<1@0c<c<30820P0<06ATI0P2IVIT30?ooo`<0<c<c0P2c/k<3
01TI6@H0VIVI0P3Vi^H303<c<`<0P8200P3<c<`601TI6@<0C4a<0P3<c<`30>KViP<000003@2c/k<3
0<c<c0<0VIVI0P1VIVH30;>c/`<0VIVI1@20P80309VIV@<06ATI0P00000304a<C0<000000P3Vi^H9
01TI6@80IVIV0`1<C4`30;>c/`80VIVI0`20P8030<c<c0<0IVIV0P2c/k<30820P0P0dLfY00060=7=
ZHd0oooo0`2c/k<20?ooo`<0i^KV0`00000306IVIP806ATI0`3oool306IVIP80/k>c0`2IVIT303<c
<`D06ATI1P3oool20>KViP<0IVIV0`3oool50<c<c0<0i^KV0`20P8020?ooo`<000000`0I6AT304a<
C080oooo0`0c<c<30;>c/`80i^KV0`0I6AT30<c<c0<000000P1<C4`30<c<c0<0IVIV0P0I6AT30820
P0<0VIVI0`0I6AT204a<C0<0<c<c1@0I6AT30820P0<0C4a<0P2c/k<30820P0<0i^KV0`3<c<`209VI
V@<0C4a<0`0I6AT206IVIP<0/k>c0`1VIVH30;>c/`80c<c<0`0c<c<30>KViP80oooo0`1<C4`30>KV
iP<0oooo0P20P8030;>c/`<0i^KV0P3<c<`3000000<0C4a<0`0I6AT20>KViP<0/k>c203AcJT000H0
dLfYS@3oool30;>c/`80oooo0`3Vi^H3000000<0IVIV0P0I6AT30?ooo`<0IVIV0P2c/k<309VIV@<0
<c<c1@0I6AT60?ooo`80i^KV0`1VIVH30?ooo`D0c<c<0`3Vi^H30820P080oooo0`00000301TI6@<0
C4a<0P3oool303<c<`<0/k>c0P3Vi^H301TI6@<0c<c<0`00000204a<C0<0c<c<0`1VIVH201TI6@<0
P8200`2IVIT301TI6@80C4a<0`0c<c<501TI6@<0P8200`1<C4`20;>c/`<0P8200`3Vi^H30<c<c080
VIVI0`1<C4`301TI6@80IVIV0`2c/k<306IVIP<0/k>c0P3<c<`303<c<`<0i^KV0P3oool304a<C0<0
i^KV0`3oool20820P0<0/k>c0`3Vi^H20<c<c0<000000`1<C4`301TI6@80i^KV0`2c/k<80=7=Z@00
1P3AcJV=0?ooo`<0/k>c0P3oool30>KViP<000000`1VIVH201TI6@<0oooo0`1VIVH20;>c/`<0VIVI
0`0c<c<501TI6@H0oooo0P3Vi^H306IVIP<0oooo1@3<c<`30>KViP<0P8200P3oool3000000<06ATI
0`1<C4`20?ooo`<0<c<c0`2c/k<20>KViP<06ATI0`3<c<`300000080C4a<0`3<c<`306IVIP806ATI
0`20P80309VIV@<06ATI0P1<C4`303<c<`D06ATI0`20P80304a<C080/k>c0`20P8030>KViP<0c<c<
0P2IVIT304a<C0<06ATI0P1VIVH30;>c/`<0IVIV0`2c/k<20<c<c0<0<c<c0`3Vi^H20?ooo`<0C4a<
0`3Vi^H30?ooo`80P8200`2c/k<30>KViP80c<c<0`00000304a<C0<06ATI0P3Vi^H30;>c/`P0dLfY
00060=7=ZI00oooo0P3Vi^H304a<C0<0c<c<0`0c<c<20?ooo`<0VIVI0`00000203<c<`<0VIVI0`1<
C4`30?ooo`80P820202IVIT30820P0<0c<c<0`0c<c<20;>c/`<000000`20P80203<c<`H0/k>c0`3<
c<`206IVIP<0oooo0`00000206IVIP<0C4a<0`1VIVH303<c<`80c<c<0`1VIVH30>KViPD000000`3V
i^H501TI6@<0c<c<0`3Vi^H20?ooo`<0P8200`3<c<`206IVIP<0c<c<0`20P8030?ooo`80i^KV0`2c
/k<304a<C080IVIV0`0000030?ooo`<06ATI0P20P80304a<C0D0oooo0`1VIVH609VIV@8000000`1<
C4`301TI6@80VIVI0`1VIVH30?ooo`<0VIVI0P2c/k<309VIV@P0dLfY00060=7=ZI00oooo0P3Vi^H3
04a<C0<0c<c<0`0c<c<20?ooo`<0VIVI0`00000203<c<`<0VIVI0`1<C4`30?ooo`80P820202IVIT3
0820P0<0c<c<0`0c<c<20;>c/`<000000`20P80203<c<`H0/k>c0`3<c<`206IVIP<0oooo0`000002
06IVIP<0C4a<0`1VIVH303<c<`80c<c<0`1VIVH30>KViPD000000`3Vi^H501TI6@<0c<c<0`3Vi^H2
0?ooo`<0P8200`3<c<`206IVIP<0c<c<0`20P8030?ooo`80i^KV0`2c/k<304a<C080IVIV0`000003
0?ooo`<06ATI0P20P80304a<C0D0oooo0`1VIVH609VIV@8000000`1<C4`301TI6@80VIVI0`1VIVH3
0?ooo`<0VIVI0P2c/k<309VIV@P0dLfY00060=7=ZID0oooo0`0000030?ooo`D0VIVI0`1<C4`20>KV
iP<0P8200`0c<c<30?ooo`80IVIV0`2c/k<30820P080C4a<0`0000030>KViP<0<c<c0P1<C4`30;>c
/`<06ATI0P3oool3000000<0IVIV0`0c<c<209VIV@<0i^KV1@1<C4`30820P0<0/k>c0`1<C4`20?oo
o`<0i^KV0`2IVIT80820P0<0oooo0P20P80309VIV@<0P8200P1VIVH30?ooo`<0<c<c0P0000030<c<
c0<0/k>c0`1VIVH20?ooo`<0IVIV0`0c<c<206IVIP<000001P2IVIT201TI6@<0IVIV0`00000209VI
V@<000000`0c<c<30820P0D0c<c<0`3oool20820P0<0i^KV0`0000030820P080i^KV0`0I6AT80=7=
Z@001P3AcJVE0?ooo`<000000`3oool509VIV@<0C4a<0P3Vi^H30820P0<0<c<c0`3oool206IVIP<0
/k>c0`20P80204a<C0<000000`3Vi^H303<c<`80C4a<0`2c/k<301TI6@80oooo0`00000306IVIP<0
<c<c0P2IVIT30>KViPD0C4a<0`20P8030;>c/`<0C4a<0P3oool30>KViP<0VIVI2020P8030?ooo`80
P8200`2IVIT30820P080IVIV0`3oool303<c<`8000000`3<c<`30;>c/`<0IVIV0P3oool306IVIP<0
<c<c0P1VIVH3000000H0VIVI0P0I6AT306IVIP<000000P2IVIT3000000<0<c<c0`20P8050<c<c0<0
oooo0P20P8030>KViP<000000`20P8020>KViP<06ATI203AcJT000H0dLfYU@3oool3000000<0oooo
1@2IVIT304a<C080i^KV0`20P80303<c<`<0oooo0P1VIVH30;>c/`<0P8200P1<C4`3000000<0i^KV
0`0c<c<204a<C0<0/k>c0`0I6AT20?ooo`<000000`1VIVH303<c<`80VIVI0`3Vi^H504a<C0<0P820
0`2c/k<304a<C080oooo0`3Vi^H309VIV@P0P8200`3oool20820P0<0VIVI0`20P80206IVIP<0oooo
0`0c<c<2000000<0c<c<0`2c/k<306IVIP80oooo0`1VIVH303<c<`80IVIV0`00000609VIV@806ATI
0`1VIVH300000080VIVI0`00000303<c<`<0P8201@3<c<`30?ooo`80P8200`3Vi^H3000000<0P820
0P3Vi^H301TI6@P0dLfY00060=7=ZIP0oooo1@20P80304a<C0<000000P3<c<`301TI6@<0oooo0`00
00020820P0<0c<c<0`0000020<c<c0<0oooo0`20P80306IVIP80P8200`2c/k<30820P0D0VIVI0`00
00030<c<c080IVIV0`0c<c<301TI6@80<c<c0`3oool303<c<`<000001@0c<c<301TI6@80IVIV0`2c
/k<306IVIPD0/k>c0`1VIVH30;>c/`80oooo1P2c/k<203<c<`<0c<c<0`2c/k<30820P080c<c<0`0c
<c<306IVIP80P8200`2c/k<30<c<c0<000000P1<C4`306IVIP<000000P2IVIT304a<C0<0i^KV0`20
P80203<c<`<0/k>c0`0000020820P0<0c<c<1P2c/k<20?ooo`<0i^KV203AcJT000H0dLfYV03oool5
0820P0<0C4a<0`0000020<c<c0<06ATI0`3oool300000080P8200`3<c<`300000080c<c<0`3oool3
0820P0<0IVIV0P20P8030;>c/`<0P8201@2IVIT3000000<0c<c<0P1VIVH303<c<`<06ATI0P0c<c<3
0?ooo`<0<c<c0`00000503<c<`<06ATI0P1VIVH30;>c/`<0IVIV1@2c/k<306IVIP<0/k>c0P3oool6
0;>c/`80<c<c0`3<c<`30;>c/`<0P8200P3<c<`303<c<`<0IVIV0P20P8030;>c/`<0c<c<0`000002
04a<C0<0IVIV0`00000209VIV@<0C4a<0`3Vi^H30820P080<c<c0`2c/k<300000080P8200`3<c<`6
0;>c/`80oooo0`3Vi^H80=7=Z@001P3AcJVH0?ooo`D0P8200`1<C4`300000080c<c<0`0I6AT30?oo
o`<000000P20P8030<c<c0<000000P3<c<`30?ooo`<0P8200`1VIVH20820P0<0/k>c0`20P80509VI
V@<000000`3<c<`206IVIP<0<c<c0`0I6AT203<c<`<0oooo0`0c<c<3000000D0<c<c0`0I6AT206IV
IP<0/k>c0`1VIVH50;>c/`<0IVIV0`2c/k<20?ooo`H0/k>c0P0c<c<30<c<c0<0/k>c0`20P8020<c<
c0<0<c<c0`1VIVH20820P0<0/k>c0`3<c<`300000080C4a<0`1VIVH300000080VIVI0`1<C4`30>KV
iP<0P8200P0c<c<30;>c/`<000000P20P8030<c<c0H0/k>c0P3oool30>KViPP0dLfY00060=7=ZI/0
oooo0P2c/k<30?ooo`<0VIVI0P2c/k<3000000<06ATI0`00000209VIV@<0C4a<0`2c/k<20<c<c0<0
6ATI0`2IVIT30>KViP80VIVI0`1<C4`30;>c/`80IVIV0`3<c<`600000080IVIV0`2IVIT30;>c/`80
c<c<0`1VIVH304a<C0<0oooo0P20P803000000<0/k>c0P0c<c<306IVIP<0c<c<0`20P80204a<C0<0
/k>c0`1VIVH203<c<`<0c<c<0`0000020?ooo`<000000`1VIVH30<c<c080P8200`3oool300000080
<c<c0`20P80304a<C0D0/k>c0`3Vi^H309VIV@8000000`3Vi^H30820P0<0oooo0P2c/k<30>KViP<0
6ATI0P2c/k<306IVIP<0i^KV0`0c<c<2000000<0P820203AcJT000H0dLfYV`3oool20;>c/`<0oooo
0`2IVIT20;>c/`<000000`0I6AT300000080VIVI0`1<C4`30;>c/`80c<c<0`0I6AT309VIV@<0i^KV
0P2IVIT304a<C0<0/k>c0P1VIVH30<c<c0H000000P1VIVH309VIV@<0/k>c0P3<c<`306IVIP<0C4a<
0`3oool20820P0<000000`2c/k<203<c<`<0IVIV0`3<c<`30820P080C4a<0`2c/k<306IVIP80<c<c
0`3<c<`300000080oooo0`00000306IVIP<0c<c<0P20P8030?ooo`<000000P0c<c<30820P0<0C4a<
1@2c/k<30>KViP<0VIVI0P0000030>KViP<0P8200`3oool20;>c/`<0i^KV0`0I6AT20;>c/`<0IVIV
0`3Vi^H303<c<`8000000`20P8080=7=Z@001P3AcJVM0?ooo`<0i^KV0`1<C4`209VIV@<0oooo0`20
P805000000<0C4a<0`20P80204a<C0<0/k>c0`3<c<`309VIV@80P8200`3<c<`30?ooo`80i^KV0`00
000806IVIP<0VIVI0`3oool204a<C0<06ATI0`3Vi^H309VIV@8000000`0c<c<30<c<c080VIVI0`2c
/k<30?ooo`<0C4a<0P2IVIT303<c<`<0VIVI0P0c<c<30>KViP<0c<c<0P1<C4`303<c<`<0c<c<0`20
P80206IVIP<06ATI1@2IVIT30;>c/`<0oooo0`2IVIT20?ooo`<0i^KV0`1<C4`2000000<0VIVI0`20
P8050<c<c0<0/k>c0`00000209VIV@<0oooo0`2c/k<309VIV@D0/k>c203AcJT000H0dLfYW@3oool3
0>KViP<0C4a<0P2IVIT30?ooo`<0P8201@00000304a<C0<0P8200P1<C4`30;>c/`<0c<c<0`2IVIT2
0820P0<0c<c<0`3oool20>KViP<00000201VIVH309VIV@<0oooo0P1<C4`301TI6@<0i^KV0`2IVIT2
000000<0<c<c0`3<c<`209VIV@<0/k>c0`3oool304a<C080VIVI0`0c<c<309VIV@80<c<c0`3Vi^H3
0<c<c080C4a<0`0c<c<30<c<c0<0P8200P1VIVH301TI6@D0VIVI0`2c/k<30?ooo`<0VIVI0P3oool3
0>KViP<0C4a<0P00000309VIV@<0P8201@3<c<`30;>c/`<000000P2IVIT30?ooo`<0/k>c0`2IVIT5
0;>c/`P0dLfY00060=7=ZId0oooo0`3Vi^H304a<C080VIVI0`3oool30820P0D000000`1<C4`30820
P080C4a<0`2c/k<30<c<c0<0VIVI0P20P8030<c<c0<0oooo0P3Vi^H3000000P0IVIV0`2IVIT30?oo
o`80C4a<0`0I6AT30>KViP<0VIVI0P00000303<c<`<0c<c<0P2IVIT30;>c/`<0oooo0`1<C4`209VI
V@<0<c<c0`2IVIT203<c<`<0i^KV0`3<c<`204a<C0<0<c<c0`3<c<`30820P080IVIV0`0I6AT509VI
V@<0/k>c0`3oool309VIV@80oooo0`3Vi^H304a<C08000000`2IVIT30820P0D0c<c<0`2c/k<30000
0080VIVI0`3oool30;>c/`<0VIVI1@2c/k<80=7=Z@001P3AcJVS0?ooo`8000001P3Vi^H809VIV@<0
c<c<0P20P8030;>c/`<0P8200`3oool203<c<`<0P8201@1VIVH604a<C0<0P8200P2c/k<30?ooo`<0
<c<c0P2c/k<30>KViP<0IVIV0`3Vi^H20;>c/`<06ATI0`3<c<`20;>c/`<0P8200`1<C4`30<c<c080
oooo0`3<c<`306IVIP806ATI1P3<c<`201TI6@<0<c<c0`3Vi^H30<c<c080P8200`2c/k<30<c<c080
VIVI0`1VIVH303<c<`<0c<c<0P0000030820P0<0oooo1@2IVIT30?ooo`<0<c<c0P0000030?ooo`<0
c<c<0P3Vi^H301TI6@<0VIVI0`3oool20<c<c0<0VIVI203AcJT000H0dLfYX`3oool2000000H0i^KV
202IVIT30<c<c080P8200`2c/k<30820P0<0oooo0P0c<c<30820P0D0IVIV1P1<C4`30820P080/k>c
0`3oool303<c<`80/k>c0`3Vi^H306IVIP<0i^KV0P2c/k<301TI6@<0c<c<0P2c/k<30820P0<0C4a<
0`3<c<`20?ooo`<0c<c<0`1VIVH201TI6@H0c<c<0P0I6AT303<c<`<0i^KV0`3<c<`20820P0<0/k>c
0`3<c<`209VIV@<0IVIV0`0c<c<30<c<c08000000`20P8030?ooo`D0VIVI0`3oool303<c<`800000
0`3oool30<c<c080i^KV0`0I6AT309VIV@<0oooo0P3<c<`309VIV@P0dLfY00060=7=ZJ<0oooo0P00
00060>KViPP0VIVI0`3<c<`20820P0<0/k>c0`20P8030?ooo`80<c<c0`20P80506IVIPH0C4a<0`20
P8020;>c/`<0oooo0`0c<c<20;>c/`<0i^KV0`1VIVH30>KViP80/k>c0`0I6AT30<c<c080/k>c0`20
P80304a<C0<0c<c<0P3oool30<c<c0<0IVIV0P0I6AT60<c<c0806ATI0`0c<c<30>KViP<0c<c<0P20
P8030;>c/`<0c<c<0P2IVIT306IVIP<0<c<c0`3<c<`2000000<0P8200`3oool509VIV@<0oooo0`0c
<c<2000000<0oooo0`3<c<`20>KViP<06ATI0`2IVIT30?ooo`80c<c<0`2IVIT80=7=Z@001P3AcJVU
0?ooo`<0P8200`1VIVH30>KViP80/k>c0`20P80304a<C0806ATI0`3oool304a<C0<000000P20P803
09VIV@<0i^KV0P2IVIT303<c<`<0oooo0`0000020>KViP<0<c<c0`0I6AT20<c<c0<0/k>c0`000005
0<c<c0<000000`2c/k<2000000<0IVIV0`0I6AT304a<C0D0<c<c0`0000020<c<c0<0C4a<0`3<c<`5
01TI6@H0c<c<0P0I6AT306IVIP<0<c<c0P2IVIT30?ooo`<06ATI0`0c<c<509VIV@D0i^KV0`2c/k<6
0820P08000001P2IVIT20820P0<0IVIV0`20P80504a<C0<06ATI203AcJT000H0dLfYY@3oool30820
P0<0IVIV0`3Vi^H20;>c/`<0P8200`1<C4`201TI6@<0oooo0`1<C4`300000080P8200`2IVIT30>KV
iP80VIVI0`0c<c<30?ooo`<000000P3Vi^H303<c<`<06ATI0P3<c<`30;>c/`<000001@3<c<`30000
00<0/k>c0P00000306IVIP<06ATI0`1<C4`503<c<`<000000P3<c<`304a<C0<0c<c<1@0I6AT60<c<
c0806ATI0`1VIVH303<c<`80VIVI0`3oool301TI6@<0<c<c1@2IVIT50>KViP<0/k>c1P20P8020000
00H0VIVI0P20P80306IVIP<0P8201@1<C4`301TI6@P0dLfY00060=7=ZJD0oooo0`20P80306IVIP<0
i^KV0P2c/k<30820P0<0C4a<0P0I6AT30?ooo`<0C4a<0`0000020820P0<0VIVI0`3Vi^H209VIV@<0
<c<c0`3oool300000080i^KV0`0c<c<301TI6@80c<c<0`2c/k<3000000D0c<c<0`0000030;>c/`80
00000`1VIVH301TI6@<0C4a<1@0c<c<300000080c<c<0`1<C4`30<c<c0D06ATI1P3<c<`201TI6@<0
IVIV0`0c<c<209VIV@<0oooo0`0I6AT303<c<`D0VIVI1@3Vi^H30;>c/`H0P8200P00000609VIV@80
P8200`1VIVH30820P0D0C4a<0`0I6AT80=7=Z@001P3AcJVX0?ooo`<0/k>c0`3oool206IVIP<0<c<c
0`20P80201TI6@<0<c<c0`0I6AT30<c<c080i^KV0`0000050>KViP<06ATI0`0c<c<30;>c/`80c<c<
0`0I6AT30<c<c080C4a<0`3<c<`3000000<0VIVI0P20P80304a<C0<0i^KV1@2c/k<30>KViP<0oooo
0P2IVIT30;>c/`<0c<c<0P3Vi^H303<c<`<0IVIV0P0c<c<30<c<c0<0i^KV0`3<c<`20;>c/`<0<c<c
0`1VIVH20820P0<0i^KV1P1<C4`20?ooo`<0c<c<0`2IVIT20820P0<0oooo0`3Vi^H300000080c<c<
0`3Vi^H301TI6@80IVIV0`2c/k<306IVIP<06ATI0P0c<c<30>KViPP0dLfY00060=7=ZJP0oooo0`2c
/k<30?ooo`80IVIV0`0c<c<30820P0806ATI0`0c<c<301TI6@<0c<c<0P3Vi^H3000000D0i^KV0`0I
6AT303<c<`<0/k>c0P3<c<`301TI6@<0c<c<0P1<C4`30<c<c0<000000`2IVIT20820P0<0C4a<0`3V
i^H50;>c/`<0i^KV0`3oool209VIV@<0/k>c0`3<c<`20>KViP<0<c<c0`1VIVH203<c<`<0c<c<0`3V
i^H30<c<c080/k>c0`0c<c<306IVIP80P8200`3Vi^H604a<C080oooo0`3<c<`309VIV@80P8200`3o
ool30>KViP<000000P3<c<`30>KViP<06ATI0P1VIVH30;>c/`<0IVIV0`0I6AT203<c<`<0i^KV203A
cJT000H0dLfYZ`3oool30>KViP80C4a<0`20P80309VIV@80i^KV0`1VIVH30820P0<0VIVI0P20P806
06IVIP80i^KV0`3<c<`30>KViP<0P8200P1<C4`30;>c/`<0c<c<0P2c/k<304a<C0<0/k>c0`3<c<`2
000000<0<c<c0`3oool206IVIP<0<c<c1P2IVIT2000000<0C4a<0`2c/k<209VIV@<0P8200`2IVIT2
0<c<c0<0oooo0`1<C4`30<c<c080/k>c0`20P80309VIV@80i^KV0`0I6AT3000000<06ATI0P3Vi^H3
04a<C0<0c<c<0P00000604a<C0D0<c<c0`2c/k<300000080VIVI0`3Vi^H301TI6@<0i^KV0P1VIVH3
0820P0P0dLfY00060=7=ZJ/0oooo0`3Vi^H204a<C0<0P8200`2IVIT20>KViP<0IVIV0`20P80309VI
V@80P8201P1VIVH20>KViP<0c<c<0`3Vi^H30820P080C4a<0`2c/k<30<c<c080/k>c0`1<C4`30;>c
/`<0c<c<0P00000303<c<`<0oooo0P1VIVH303<c<`H0VIVI0P00000304a<C0<0/k>c0P2IVIT30820
P0<0VIVI0P3<c<`30?ooo`<0C4a<0`3<c<`20;>c/`<0P8200`2IVIT20>KViP<06ATI0`00000301TI
6@80i^KV0`1<C4`30<c<c08000001P1<C4`503<c<`<0/k>c0`00000209VIV@<0i^KV0`0I6AT30>KV
iP80IVIV0`20P8080=7=Z@001P3AcJV[0?ooo`<0i^KV0P1<C4`30820P0<0VIVI0P3Vi^H306IVIP<0
P8200`2IVIT20820P0H0IVIV0P3Vi^H30<c<c0<0i^KV0`20P80204a<C0<0/k>c0`3<c<`20;>c/`<0
C4a<0`2c/k<30<c<c08000000`0c<c<30?ooo`80IVIV0`0c<c<609VIV@8000000`1<C4`30;>c/`80
VIVI0`20P80309VIV@80c<c<0`3oool304a<C0<0c<c<0P2c/k<30820P0<0VIVI0P3Vi^H301TI6@<0
00000`0I6AT20>KViP<0C4a<0`3<c<`2000000H0C4a<1@0c<c<30;>c/`<000000P2IVIT30>KViP<0
6ATI0`3Vi^H206IVIP<0P820203AcJT000H0dLfY/03oool3000000<0i^KV0P0I6AT309VIV@<0C4a<
0`00000204a<C0<0VIVI0`0c<c<50?ooo`<0C4a<0`3<c<`20820P0<0/k>c0`20P8020?ooo`<0<c<c
0`3oool304a<C0806ATI0`2c/k<304a<C080<c<c0`3oool309VIV@<0IVIV0P0I6AT30;>c/`<0C4a<
0P2c/k<30820P0<0<c<c0P20P8030?ooo`<0IVIV0`2IVIT20820P0<0C4a<0`2IVIT206IVIPH0C4a<
0`3Vi^H206IVIP<0i^KV0`20P8020>KViP<0oooo0`0000030;>c/`80c<c<0`3oool303<c<`80c<c<
0`2IVIT30820P0<0VIVI0P20P8030;>c/`P0dLfY00060=7=ZK00oooo0`0000030>KViP806ATI0`2I
VIT304a<C0<000000P1<C4`309VIV@<0<c<c1@3oool304a<C0<0c<c<0P20P8030;>c/`<0P8200P3o
ool303<c<`<0oooo0`1<C4`201TI6@<0/k>c0`1<C4`203<c<`<0oooo0`2IVIT306IVIP806ATI0`2c
/k<304a<C080/k>c0`20P80303<c<`80P8200`3oool306IVIP<0VIVI0P20P80304a<C0<0VIVI0P1V
IVH604a<C0<0i^KV0P1VIVH30>KViP<0P8200P3Vi^H30?ooo`<000000`2c/k<20<c<c0<0oooo0`0c
<c<20<c<c0<0VIVI0`20P80309VIV@80P8200`2c/k<80=7=Z@001P3AcJV`0?ooo`<000000`3Vi^H2
01TI6@<0VIVI0`1<C4`300000080C4a<0`2IVIT303<c<`D0oooo0`1<C4`30<c<c080P8200`2c/k<3
0820P080oooo0`0c<c<30?ooo`<0C4a<0P0I6AT30;>c/`<0C4a<0P0c<c<30?ooo`<0VIVI0`1VIVH2
01TI6@<0/k>c0`1<C4`20;>c/`<0P8200`0c<c<20820P0<0oooo0`1VIVH309VIV@80P8200`1<C4`3
09VIV@80IVIV1P1<C4`30>KViP80IVIV0`3Vi^H30820P080i^KV0`3oool3000000<0/k>c0P3<c<`3
0?ooo`<0<c<c0P3<c<`309VIV@<0P8200`2IVIT20820P0<0/k>c203AcJT000H0dLfY/`3oool30820
P080IVIV0`20P80303<c<`<0i^KV0P3oool3000000<0i^KV2020P80301TI6@80P8200`3<c<`309VI
V@D0i^KV1P20P80201TI6@<0<c<c0`00000201TI6@H0c<c<0`2IVIT203<c<`<0i^KV0`0I6AT20>KV
iP<06ATI0`3oool2000000<0C4a<0`0c<c<30?ooo`80c<c<0`20P8030;>c/`80P8200`0I6AT30<c<
c0D0oooo0`0I6AT309VIV@80C4a<1P3<c<`304a<C0806ATI0`2IVIT3000000806ATI0`20P8030>KV
iP<000000P3Vi^H309VIV@P0dLfY00060=7=ZK<0oooo0`20P80206IVIP<0P8200`0c<c<30>KViP80
oooo0`0000030>KViPP0P8200`0I6AT20820P0<0c<c<0`2IVIT50>KViPH0P8200P0I6AT303<c<`<0
00000P0I6AT60<c<c0<0VIVI0P0c<c<30>KViP<06ATI0P3Vi^H301TI6@<0oooo0P00000304a<C0<0
<c<c0`3oool20<c<c0<0P8200`2c/k<20820P0<06ATI0`3<c<`50?ooo`<06ATI0`2IVIT204a<C0H0
c<c<0`1<C4`201TI6@<0VIVI0`00000201TI6@<0P8200`3Vi^H300000080i^KV0`2IVIT80=7=Z@00
1P3AcJVf0?ooo`80/k>c0`3oool301TI6@D0c<c<1P0c<c<20;>c/`<0IVIV0`2c/k<306IVIP80P820
0`0c<c<309VIV@80oooo0`1VIVH304a<C0<0VIVI1@1<C4`30?ooo`80P8200`00000306IVIP<0i^KV
0P0I6AT303<c<`<0/k>c0P0c<c<30;>c/`<0<c<c1@2c/k<30>KViPD0P8200`1VIVH301TI6@80P820
0`0c<c<304a<C0D0<c<c0`0I6AT30<c<c08000000`0c<c<3000000<0oooo0P2IVIT30;>c/`<0IVIV
0P3oool30820P0<0c<c<0`2c/k<20<c<c0<06ATI203AcJT000H0dLfY]P3oool20;>c/`<0oooo0`0I
6AT50<c<c0H0<c<c0P2c/k<306IVIP<0/k>c0`1VIVH20820P0<0<c<c0`2IVIT20?ooo`<0IVIV0`1<
C4`309VIV@D0C4a<0`3oool20820P0<000000`1VIVH30>KViP806ATI0`0c<c<30;>c/`80<c<c0`2c
/k<303<c<`D0/k>c0`3Vi^H50820P0<0IVIV0`0I6AT20820P0<0<c<c0`1<C4`503<c<`<06ATI0`3<
c<`2000000<0<c<c0`0000030?ooo`80VIVI0`2c/k<306IVIP80oooo0`20P8030<c<c0<0/k>c0P3<
c<`301TI6@P0dLfY00060=7=ZKH0oooo0P2c/k<30?ooo`<06ATI1@3<c<`603<c<`80/k>c0`1VIVH3
0;>c/`<0IVIV0P20P80303<c<`<0VIVI0P3oool306IVIP<0C4a<0`2IVIT504a<C0<0oooo0P20P803
000000<0IVIV0`3Vi^H201TI6@<0<c<c0`2c/k<203<c<`<0/k>c0`0c<c<50;>c/`<0i^KV1@20P803
06IVIP<06ATI0P20P80303<c<`<0C4a<1@0c<c<301TI6@<0c<c<0P00000303<c<`<000000`3oool2
09VIV@<0/k>c0`1VIVH20?ooo`<0P8200`3<c<`30;>c/`80c<c<0`0I6AT80=7=Z@001P3AcJVh0?oo
o`<0i^KV0`1<C4`306IVIP80C4a<0`0I6AT30<c<c080IVIV0`0c<c<306IVIP<0c<c<0P20P80303<c
<`<0C4a<0P2c/k<301TI6@<0C4a<0`20P80203<c<`<0oooo0`0I6AT2000000<0c<c<0`3Vi^H30000
0080P8200`00000301TI6@80P8200`0000030?ooo`8000000`1VIVH303<c<`<0/k>c0P1VIVH30;>c
/`<0C4a<0P3oool301TI6@<0c<c<0`1VIVH20820P0<0VIVI0`2c/k<209VIV@<000000`2c/k<303<c
<`806ATI0`3oool30>KViP8000000`20P8030<c<c0<0/k>c0P20P8030>KViPP0dLfY00060=7=ZKP0
oooo0`3Vi^H304a<C0<0IVIV0P1<C4`301TI6@<0c<c<0P1VIVH303<c<`<0IVIV0`3<c<`20820P0<0
<c<c0`1<C4`20;>c/`<06ATI0`1<C4`30820P080<c<c0`3oool301TI6@8000000`3<c<`30>KViP<0
00000P20P803000000<06ATI0P20P803000000<0oooo0P00000306IVIP<0<c<c0`2c/k<206IVIP<0
/k>c0`1<C4`20?ooo`<06ATI0`3<c<`306IVIP80P8200`2IVIT30;>c/`80VIVI0`0000030;>c/`<0
<c<c0P0I6AT30?ooo`<0i^KV0P0000030820P0<0c<c<0`2c/k<20820P0<0i^KV203AcJT000H0dLfY
^03oool30>KViP<0C4a<0`1VIVH204a<C0<06ATI0`3<c<`206IVIP<0<c<c0`1VIVH30<c<c080P820
0`0c<c<304a<C080/k>c0`0I6AT304a<C0<0P8200P0c<c<30?ooo`<06ATI0P0000030<c<c0<0i^KV
0`0000020820P0<000000`0I6AT20820P0<000000`3oool2000000<0IVIV0`0c<c<30;>c/`80IVIV
0`2c/k<304a<C080oooo0`0I6AT30<c<c0<0IVIV0P20P80309VIV@<0/k>c0P2IVIT3000000<0/k>c
0`0c<c<201TI6@<0oooo0`3Vi^H2000000<0P8200`3<c<`30;>c/`80P8200`3Vi^H80=7=Z@001P3A
cJVn0?ooo`<000000P3<c<`306IVIP<0P8200P1VIVH3000000<0/k>c0`1VIVH204a<C0<000000`0I
6AT204a<C0H06ATI0`3Vi^H2000000H0/k>c1@0c<c<30;>c/`<000000P2IVIT604a<C080IVIV1P0I
6AT509VIV@<0c<c<0`3oool203<c<`<0oooo0`3<c<`50?ooo`<0P8200`3oool201TI6@<0IVIV0`0c
<c<2000000H0C4a<0`2c/k<203<c<`<0i^KV0`1<C4`20<c<c0<0C4a<0`00000306IVIP80c<c<0`20
P8080=7=Z@001P3AcJVn0?ooo`<000000P3<c<`306IVIP<0P8200P1VIVH3000000<0/k>c0`1VIVH2
04a<C0<000000`0I6AT204a<C0H06ATI0`3Vi^H2000000H0/k>c1@0c<c<30;>c/`<000000P2IVIT6
04a<C080IVIV1P0I6AT509VIV@<0c<c<0`3oool203<c<`<0oooo0`3<c<`50?ooo`<0P8200`3oool2
01TI6@<0IVIV0`0c<c<2000000H0C4a<0`2c/k<203<c<`<0i^KV0`1<C4`20<c<c0<0C4a<0`000003
06IVIP80c<c<0`20P8080=7=Z@001P3AcJW10?ooo`80P8200`1VIVH300000080i^KV1P00000306IV
IP8000001P2c/k<20<c<c0<0IVIV0`20P80300000080IVIV0`3oool30>KViP806ATI0`3<c<`306IV
IPD0<c<c0`20P8030;>c/`80C4a<0`20P80309VIV@806ATI0`1VIVH30<c<c0<06ATI0P2IVIT30<c<
c0<0<c<c0P2c/k<301TI6@<0VIVI1@3Vi^H306IVIP<0VIVI1@2c/k<30>KViP<0P8200P3Vi^H30820
P0<0IVIV0P2IVIT30820P0H06ATI0P1<C4`30;>c/`P0dLfY00060=7=ZL40oooo0P20P80306IVIP<0
00000P3Vi^H6000000<0IVIV0P0000060;>c/`80c<c<0`1VIVH30820P0<000000P1VIVH30?ooo`<0
i^KV0P0I6AT30<c<c0<0IVIV1@0c<c<30820P0<0/k>c0P1<C4`30820P0<0VIVI0P0I6AT306IVIP<0
c<c<0`0I6AT209VIV@<0c<c<0`0c<c<20;>c/`<06ATI0`2IVIT50>KViP<0IVIV0`2IVIT50;>c/`<0
i^KV0`20P8020>KViP<0P8200`1VIVH209VIV@<0P8201P0I6AT204a<C0<0/k>c203AcJT000H0dLfY
`@3oool20820P0<0IVIV0`0000020>KViPH000000`1VIVH2000000H0/k>c0P3<c<`306IVIP<0P820
0`00000206IVIP<0oooo0`3Vi^H201TI6@<0c<c<0`1VIVH503<c<`<0P8200`2c/k<204a<C0<0P820
0`2IVIT201TI6@<0IVIV0`3<c<`301TI6@80VIVI0`3<c<`303<c<`80/k>c0`0I6AT309VIV@D0i^KV
0`1VIVH309VIV@D0/k>c0`3Vi^H30820P080i^KV0`20P80306IVIP80VIVI0`20P80601TI6@80C4a<
0`2c/k<80=7=Z@001P3AcJW30?ooo`<0/k>c0`3Vi^H20?ooo`<0C4a<0`3Vi^H306IVIP8000000`2I
VIT306IVIP80c<c<0`2c/k<306IVIPD06ATI0`1<C4`30>KViP80<c<c0`3Vi^H303<c<`<0IVIV0P20
P80309VIV@<0i^KV0P2c/k<30>KViP<0VIVI0P3Vi^H30?ooo`<0/k>c0`2IVIT201TI6@<0IVIV0`3<
c<`20?ooo`<0<c<c0`3Vi^H301TI6@80VIVI0`20P8030<c<c08000000`1VIVH303<c<`<0/k>c0P1V
IVH30>KViP<0VIVI0P3Vi^H301TI6@<0C4a<0`3Vi^H20?ooo`<0VIVI203AcJT000H0dLfY``3oool3
0;>c/`<0i^KV0P3oool304a<C0<0i^KV0`1VIVH2000000<0VIVI0`1VIVH20<c<c0<0/k>c0`1VIVH5
01TI6@<0C4a<0`3Vi^H203<c<`<0i^KV0`0c<c<306IVIP80P8200`2IVIT30>KViP80/k>c0`3Vi^H3
09VIV@80i^KV0`3oool30;>c/`<0VIVI0P0I6AT306IVIP<0c<c<0P3oool303<c<`<0i^KV0`0I6AT2
09VIV@<0P8200`3<c<`2000000<0IVIV0`0c<c<30;>c/`80IVIV0`3Vi^H309VIV@80i^KV0`0I6AT3
04a<C0<0i^KV0P3oool309VIV@P0dLfY00060=7=ZL<0oooo0`2c/k<30>KViP80oooo0`1<C4`30>KV
iP<0IVIV0P00000309VIV@<0IVIV0P3<c<`30;>c/`<0IVIV1@0I6AT304a<C0<0i^KV0P0c<c<30>KV
iP<0<c<c0`1VIVH20820P0<0VIVI0`3Vi^H20;>c/`<0i^KV0`2IVIT20>KViP<0oooo0`2c/k<309VI
V@806ATI0`1VIVH30<c<c080oooo0`0c<c<30>KViP<06ATI0P2IVIT30820P0<0c<c<0P00000306IV
IP<0<c<c0`2c/k<206IVIP<0i^KV0`2IVIT20>KViP<06ATI0`1<C4`30>KViP80oooo0`2IVIT80=7=
Z@001P3AcJW60?ooo`<0i^KV0P1<C4`303<c<`<0oooo0`1VIVH2000000<0VIVI0`1VIVH2000000<0
oooo0`3Vi^H5000000<0VIVI0`3<c<`20;>c/`<0i^KV0`0c<c<30>KViP80VIVI0`1<C4`30;>c/`80
00000`3oool306IVIP80<c<c0`0I6AT309VIV@<0oooo0P3<c<`304a<C0<0P8200P3oool306IVIP<0
P8200`3oool20820P0<0i^KV0`0000020?ooo`<0P8200`0I6AT30<c<c080VIVI0`3Vi^H304a<C080
6ATI1P0000030<c<c080<c<c0`0I6AT80=7=Z@001P3AcJW60?ooo`<0i^KV0P1<C4`303<c<`<0oooo
0`1VIVH2000000<0VIVI0`1VIVH2000000<0oooo0`3Vi^H5000000<0VIVI0`3<c<`20;>c/`<0i^KV
0`0c<c<30>KViP80VIVI0`1<C4`30;>c/`8000000`3oool306IVIP80<c<c0`0I6AT309VIV@<0oooo
0P3<c<`304a<C0<0P8200P3oool306IVIP<0P8200`3oool20820P0<0i^KV0`0000020?ooo`<0P820
0`0I6AT30<c<c080VIVI0`3Vi^H304a<C0806ATI1P0000030<c<c080<c<c0`0I6AT80=7=Z@001P3A
cJW60?ooo`<0i^KV0P1<C4`303<c<`<0oooo0`1VIVH2000000<0VIVI0`1VIVH2000000<0oooo0`3V
i^H5000000<0VIVI0`3<c<`20;>c/`<0i^KV0`0c<c<30>KViP80VIVI0`1<C4`30;>c/`8000000`3o
ool306IVIP80<c<c0`0I6AT309VIV@<0oooo0P3<c<`304a<C0<0P8200P3oool306IVIP<0P8200`3o
ool20820P0<0i^KV0`0000020?ooo`<0P8200`0I6AT30<c<c080VIVI0`3Vi^H304a<C0806ATI1P00
00030<c<c080<c<c0`0I6AT80=7=Z@001P3AcJW;0?ooo`<000001P2c/k<204a<C0<0i^KV0`2c/k<2
04a<C0H0i^KV1@3<c<`30>KViP<06ATI0P20P8030>KViP<0c<c<0`3oool206IVIP<06ATI0`3Vi^H2
01TI6@H0/k>c0P1<C4`30?ooo`<0P8200`3Vi^H204a<C0<0/k>c0`3Vi^H20;>c/`<06ATI0`1<C4`5
09VIV@<0C4a<0`3<c<`504a<C0H000000P3oool30<c<c0<0/k>c0P3Vi^H906IVIP80c<c<0`3Vi^H8
0=7=Z@001P3AcJW;0?ooo`<000001P2c/k<204a<C0<0i^KV0`2c/k<204a<C0H0i^KV1@3<c<`30>KV
iP<06ATI0P20P8030>KViP<0c<c<0`3oool206IVIP<06ATI0`3Vi^H201TI6@H0/k>c0P1<C4`30?oo
o`<0P8200`3Vi^H204a<C0<0/k>c0`3Vi^H20;>c/`<06ATI0`1<C4`509VIV@<0C4a<0`3<c<`504a<
C0H000000P3oool30<c<c0<0/k>c0P3Vi^H906IVIP80c<c<0`3Vi^H80=7=Z@001P3AcJW>0?ooo`<0
P8200`1<C4`20;>c/`<0C4a<0`3<c<`209VIV@H0c<c<0`0c<c<2000000<0oooo0`3Vi^H20?ooo`<0
c<c<0`0c<c<301TI6@8000000`3<c<`304a<C080c<c<0`1<C4`30;>c/`80P8201P2c/k<306IVIP80
i^KV0`20P8050>KViP<06ATI0`2c/k<30>KViP80/k>c0`20P80301TI6@80P8200`2c/k<804a<C0<0
i^KV0`0c<c<209VIV@<0P8200`2c/k<30?ooo`806ATI0`20P8080=7=Z@001P3AcJW>0?ooo`<0P820
0`1<C4`20;>c/`<0C4a<0`3<c<`209VIV@H0c<c<0`0c<c<2000000<0oooo0`3Vi^H20?ooo`<0c<c<
0`0c<c<301TI6@8000000`3<c<`304a<C080c<c<0`1<C4`30;>c/`80P8201P2c/k<306IVIP80i^KV
0`20P8050>KViP<06ATI0`2c/k<30>KViP80/k>c0`20P80301TI6@80P8200`2c/k<804a<C0<0i^KV
0`0c<c<209VIV@<0P8200`2c/k<30?ooo`806ATI0`20P8080=7=Z@001P3AcJW>0?ooo`<0P8200`1<
C4`20;>c/`<0C4a<0`3<c<`209VIV@H0c<c<0`0c<c<2000000<0oooo0`3Vi^H20?ooo`<0c<c<0`0c
<c<301TI6@8000000`3<c<`304a<C080c<c<0`1<C4`30;>c/`80P8201P2c/k<306IVIP80i^KV0`20
P8050>KViP<06ATI0`2c/k<30>KViP80/k>c0`20P80301TI6@80P8200`2c/k<804a<C0<0i^KV0`0c
<c<209VIV@<0P8200`2c/k<30?ooo`806ATI0`20P8080=7=Z@001P3AcJWA0?ooo`<0/k>c0P3Vi^H3
0;>c/`<0i^KV0P3<c<`309VIV@<0P8200`1<C4`20?ooo`H0P8200P1VIVH30?ooo`<0C4a<1@1VIVH3
0?ooo`<0i^KV0P20P8030?ooo`<000000P3oool303<c<`<000000`1VIVH201TI6@<000000`1<C4`2
03<c<`<0/k>c0`0c<c<309VIV@80P8200`3Vi^H309VIV@80/k>c0`1VIVH30<c<c0<0IVIV0P2IVIT3
03<c<`<0/k>c0P1<C4`3000000<0i^KV0`0c<c<201TI6@<0/k>c203AcJT000H0dLfYd@3oool30;>c
/`80i^KV0`2c/k<30>KViP80c<c<0`2IVIT30820P0<0C4a<0P3oool60820P080IVIV0`3oool304a<
C0D0IVIV0`3oool30>KViP80P8200`3oool300000080oooo0`0c<c<3000000<0IVIV0P0I6AT30000
00<0C4a<0P0c<c<30;>c/`<0<c<c0`2IVIT20820P0<0i^KV0`2IVIT20;>c/`<0IVIV0`3<c<`306IV
IP80VIVI0`0c<c<30;>c/`80C4a<0`0000030>KViP<0<c<c0P0I6AT30;>c/`P0dLfY00060=7=ZM40
oooo0`2c/k<20>KViP<0/k>c0`3Vi^H20<c<c0<0VIVI0`20P80304a<C080oooo1P20P80206IVIP<0
oooo0`1<C4`506IVIP<0oooo0`3Vi^H20820P0<0oooo0`0000020?ooo`<0<c<c0`00000306IVIP80
6ATI0`00000304a<C080<c<c0`2c/k<303<c<`<0VIVI0P20P8030>KViP<0VIVI0P2c/k<306IVIP<0
c<c<0`1VIVH209VIV@<0<c<c0`2c/k<204a<C0<000000`3Vi^H303<c<`806ATI0`2c/k<80=7=Z@00
1P3AcJWD0?ooo`80i^KV0`1<C4`301TI6@80VIVI0`20P80304a<C0<000000P0c<c<301TI6@<0oooo
0P0I6AT60>KViP<0P8200P2c/k<30?ooo`<0IVIV0P3Vi^H30;>c/`D06ATI0`2IVIT60;>c/`80i^KV
0`3oool30820P0806ATI0`0c<c<309VIV@<06ATI0P3oool30<c<c0<06ATI0P3oool30>KViP<00000
0`1VIVH209VIV@<0oooo0`00000206IVIPH000000`20P802000000<0VIVI203AcJT000H0dLfYe03o
ool20>KViP<0C4a<0`0I6AT209VIV@<0P8200`1<C4`300000080<c<c0`0I6AT30?ooo`806ATI1P3V
i^H30820P080/k>c0`3oool306IVIP80i^KV0`2c/k<501TI6@<0VIVI1P2c/k<20>KViP<0oooo0`20
P80201TI6@<0<c<c0`2IVIT301TI6@80oooo0`3<c<`301TI6@80oooo0`3Vi^H3000000<0IVIV0P2I
VIT30?ooo`<000000P1VIVH6000000<0P8200P00000309VIV@P0dLfY00060=7=ZMT0oooo0`000002
09VIV@<0oooo0`0I6AT50<c<c0<0i^KV1@3oool30820P0H0oooo0P0c<c<3000000<0P8200P3<c<`3
03<c<`D000000`2IVIT30?ooo`<0C4a<0P0I6AT609VIV@D0C4a<0`3oool30<c<c080C4a<0`3Vi^H3
03<c<`D0C4a<1P0c<c<206IVIP<0c<c<1@0c<c<906IVIP80/k>c0`0I6AT80=7=Z@001P3AcJWI0?oo
o`<000000P2IVIT30?ooo`<06ATI1@3<c<`30>KViPD0oooo0`20P8060?ooo`80<c<c0`0000030820
P080c<c<0`0c<c<5000000<0VIVI0`3oool304a<C0806ATI1P2IVIT504a<C0<0oooo0`3<c<`204a<
C0<0i^KV0`0c<c<504a<C0H0<c<c0P1VIVH30<c<c0D0<c<c2@1VIVH20;>c/`<06ATI203AcJT000H0
dLfYf@3oool300000080VIVI0`3oool301TI6@D0c<c<0`3Vi^H50?ooo`<0P8201P3oool203<c<`<0
00000`20P8020<c<c0<0<c<c1@00000309VIV@<0oooo0`1<C4`201TI6@H0VIVI1@1<C4`30?ooo`<0
c<c<0P1<C4`30>KViP<0<c<c1@1<C4`603<c<`80IVIV0`3<c<`503<c<`T0IVIV0P2c/k<301TI6@P0
dLfY00060=7=ZM`0oooo0P20P80304a<C0<0<c<c0`3Vi^H203<c<`<0/k>c1@0I6AT3000000<0i^KV
0`1<C4`20<c<c0<0i^KV0`3oool203<c<`<000000`2c/k<201TI6@<0/k>c1P20P80501TI6@<0oooo
0P3<c<`306IVIPH0VIVI0P20P80301TI6@<0VIVI0P0I6AT30<c<c0<0oooo0`2IVIT201TI6@<0i^KV
0`3<c<`204a<C0<0oooo0`2c/k<306IVIP8000000`3Vi^H80=7=Z@001P3AcJWL0?ooo`80P8200`1<
C4`303<c<`<0i^KV0P0c<c<30;>c/`D06ATI0`0000030>KViP<0C4a<0P3<c<`30>KViP<0oooo0P0c
<c<3000000<0/k>c0P0I6AT30;>c/`H0P8201@0I6AT30?ooo`80c<c<0`1VIVH609VIV@80P8200`0I
6AT309VIV@806ATI0`3<c<`30?ooo`<0VIVI0P0I6AT30>KViP<0c<c<0P1<C4`30?ooo`<0/k>c0`1V
IVH2000000<0i^KV203AcJT000H0dLfYg03oool20820P0<0C4a<0`0c<c<30>KViP80<c<c0`2c/k<5
01TI6@<000000`3Vi^H304a<C080c<c<0`3Vi^H30?ooo`80<c<c0`0000030;>c/`806ATI0`2c/k<6
0820P0D06ATI0`3oool20<c<c0<0IVIV1P2IVIT20820P0<06ATI0`2IVIT201TI6@<0c<c<0`3oool3
09VIV@806ATI0`3Vi^H30<c<c080C4a<0`3oool30;>c/`<0IVIV0P0000030>KViPP0dLfY00060=7=
ZMh0oooo0`2c/k<30>KViP<0P8200P1VIVH30820P0<0i^KV1@1VIVH60?ooo`8000001P3oool206IV
IPH0P8200P3Vi^H306IVIP<0c<c<0`20P8020<c<c0<0C4a<1@1VIVH303<c<`<0oooo0`3<c<`209VI
V@<0C4a<0`1VIVH201TI6@<0c<c<0`0I6AT309VIV@80i^KV1P3oool204a<C0H0P8200`1<C4`50820
P0P0dLfY00060=7=ZMh0oooo0`2c/k<30>KViP<0P8200P1VIVH30820P0<0i^KV1@1VIVH60?ooo`80
00001P3oool206IVIPH0P8200P3Vi^H306IVIP<0c<c<0`20P8020<c<c0<0C4a<1@1VIVH303<c<`<0
oooo0`3<c<`209VIV@<0C4a<0`1VIVH201TI6@<0c<c<0`0I6AT309VIV@80i^KV1P3oool204a<C0H0
P8200`1<C4`50820P0P0dLfY00060=7=ZMh0oooo0`2c/k<30>KViP<0P8200P1VIVH30820P0<0i^KV
1@1VIVH60?ooo`8000001P3oool206IVIPH0P8200P3Vi^H306IVIP<0c<c<0`20P8020<c<c0<0C4a<
1@1VIVH303<c<`<0oooo0`3<c<`209VIV@<0C4a<0`1VIVH201TI6@<0c<c<0`0I6AT309VIV@80i^KV
1P3oool204a<C0H0P8200`1<C4`50820P0P0dLfY00060=7=ZN40oooo0`3Vi^H304a<C08000000`0c
<c<30820P080IVIV0`2IVIT30>KViP<0C4a<0P3<c<`30>KViP<0C4a<0P3Vi^H3000000<0C4a<0P00
00030820P0<0<c<c0`0000020>KViP<0<c<c0`1VIVH2000000<0c<c<1P1VIVH204a<C0<000000`2c
/k<20>KViP<0oooo0`3Vi^H306IVIP80c<c<1P0c<c<201TI6@<0i^KV0`0000030<c<c080oooo0`2c
/k<80=7=Z@001P3AcJWQ0?ooo`<0i^KV0`1<C4`2000000<0<c<c0`20P80206IVIP<0VIVI0`3Vi^H3
04a<C080c<c<0`3Vi^H304a<C080i^KV0`00000304a<C08000000`20P80303<c<`<000000P3Vi^H3
03<c<`<0IVIV0P0000030<c<c0H0IVIV0P1<C4`3000000<0/k>c0P3Vi^H30?ooo`<0i^KV0`1VIVH2
0<c<c0H0<c<c0P0I6AT30>KViP<000000`3<c<`20?ooo`<0/k>c203AcJT000H0dLfYi`3oool20000
00<0VIVI0`0I6AT20?ooo`<06ATI0`1VIVH30>KViP80P8200`3oool306IVIP8000000`1VIVH30?oo
o`D0VIVI0`3Vi^H306IVIPD0oooo0`00000503<c<`<0VIVI0`3Vi^H2000000<06ATI0`2c/k<20820
P0T0oooo0P0I6AT30820P0<0VIVI0P2c/k<30<c<c0<0/k>c0`3<c<`201TI6@<0VIVI203AcJT000H0
dLfYi`3oool2000000<0VIVI0`0I6AT20?ooo`<06ATI0`1VIVH30>KViP80P8200`3oool306IVIP80
00000`1VIVH30?ooo`D0VIVI0`3Vi^H306IVIPD0oooo0`00000503<c<`<0VIVI0`3Vi^H2000000<0
6ATI0`2c/k<20820P0T0oooo0P0I6AT30820P0<0VIVI0P2c/k<30<c<c0<0/k>c0`3<c<`201TI6@<0
VIVI203AcJT000H0dLfYi`3oool2000000<0VIVI0`0I6AT20?ooo`<06ATI0`1VIVH30>KViP80P820
0`3oool306IVIP8000000`1VIVH30?ooo`D0VIVI0`3Vi^H306IVIPD0oooo0`00000503<c<`<0VIVI
0`3Vi^H2000000<06ATI0`2c/k<20820P0T0oooo0P0I6AT30820P0<0VIVI0P2c/k<30<c<c0<0/k>c
0`3<c<`201TI6@<0VIVI203AcJT000H0dLfYj@3oool30820P0<0<c<c0P3Vi^H304a<C0<0IVIV0`0I
6AT2000000<0C4a<0`0c<c<20?ooo`<0P8200`0c<c<201TI6@<0oooo0`3<c<`30;>c/`80oooo0`1V
IVH30>KViP80oooo0`00000301TI6@<0IVIV0P3Vi^H304a<C0<0oooo0P1<C4`3000000<0VIVI0`00
00020820P0<0VIVI0`1<C4`209VIV@<0oooo0`3Vi^H30<c<c0D06ATI203AcJT000H0dLfYj@3oool3
0820P0<0<c<c0P3Vi^H304a<C0<0IVIV0`0I6AT2000000<0C4a<0`0c<c<20?ooo`<0P8200`0c<c<2
01TI6@<0oooo0`3<c<`30;>c/`80oooo0`1VIVH30>KViP80oooo0`00000301TI6@<0IVIV0P3Vi^H3
04a<C0<0oooo0P1<C4`3000000<0VIVI0`0000020820P0<0VIVI0`1<C4`209VIV@<0oooo0`3Vi^H3
0<c<c0D06ATI203AcJT000H0dLfYj@3oool30820P0<0<c<c0P3Vi^H304a<C0<0IVIV0`0I6AT20000
00<0C4a<0`0c<c<20?ooo`<0P8200`0c<c<201TI6@<0oooo0`3<c<`30;>c/`80oooo0`1VIVH30>KV
iP80oooo0`00000301TI6@<0IVIV0P3Vi^H304a<C0<0oooo0P1<C4`3000000<0VIVI0`0000020820
P0<0VIVI0`1<C4`209VIV@<0oooo0`3Vi^H30<c<c0D06ATI203AcJT000H0dLfYk03oool30;>c/`80
i^KV0`0c<c<30?ooo`D06ATI0`2c/k<304a<C080IVIV0`3oool301TI6@80c<c<0`1<C4`30>KViP<0
<c<c1@2IVIT304a<C080<c<c1P2c/k<30<c<c080P8200`1VIVH509VIV@H0<c<c1@20P8030<c<c0<0
VIVI0P0c<c<309VIV@<000000`20P80204a<C0<0i^KV203AcJT000H0dLfYk03oool30;>c/`80i^KV
0`0c<c<30?ooo`D06ATI0`2c/k<304a<C080IVIV0`3oool301TI6@80c<c<0`1<C4`30>KViP<0<c<c
1@2IVIT304a<C080<c<c1P2c/k<30<c<c080P8200`1VIVH509VIV@H0<c<c1@20P8030<c<c0<0VIVI
0P0c<c<309VIV@<000000`20P80204a<C0<0i^KV203AcJT000H0dLfYk`3oool20>KViP<0<c<c1P3V
i^H206IVIP<0P8200`1<C4`20820P0<0<c<c0`0I6AT20<c<c0<06ATI0`1<C4`303<c<`80C4a<0`2I
VIT30?ooo`8000000`2c/k<30820P0<0i^KV0P3<c<`30820P0<0c<c<0P00000304a<C0<0IVIV0`20
P8020<c<c0<0P8200`3oool203<c<`<0C4a<1P2IVIT20>KViP<0P820203AcJT000H0dLfYk`3oool2
0>KViP<0<c<c1P3Vi^H206IVIP<0P8200`1<C4`20820P0<0<c<c0`0I6AT20<c<c0<06ATI0`1<C4`3
03<c<`80C4a<0`2IVIT30?ooo`8000000`2c/k<30820P0<0i^KV0P3<c<`30820P0<0c<c<0P000003
04a<C0<0IVIV0`20P8020<c<c0<0P8200`3oool203<c<`<0C4a<1P2IVIT20>KViP<0P820203AcJT0
00H0dLfYk`3oool20>KViP<0<c<c1P3Vi^H206IVIP<0P8200`1<C4`20820P0<0<c<c0`0I6AT20<c<
c0<06ATI0`1<C4`303<c<`80C4a<0`2IVIT30?ooo`8000000`2c/k<30820P0<0i^KV0P3<c<`30820
P0<0c<c<0P00000304a<C0<0IVIV0`20P8020<c<c0<0P8200`3oool203<c<`<0C4a<1P2IVIT20>KV
iP<0P820203AcJT000H0dLfYm03oool3000000<0P8200P1VIVH309VIV@<0i^KV0P20P8030<c<c0<0
C4a<0P3oool304a<C0<0IVIV0`00000201TI6@<0C4a<0`0I6AT2000000<0VIVI0`1VIVH50;>c/`<0
00000`1<C4`201TI6@<0/k>c0`1<C4`30820P080c<c<0`2c/k<306IVIP80oooo0`00000301TI6@<0
oooo0P3<c<`30;>c/`P0dLfY00060=7=ZO@0oooo0`0000030820P080IVIV0`2IVIT30>KViP80P820
0`3<c<`304a<C080oooo0`1<C4`306IVIP<000000P0I6AT304a<C0<06ATI0P00000309VIV@<0IVIV
1@2c/k<3000000<0C4a<0P0I6AT30;>c/`<0C4a<0`20P8020<c<c0<0/k>c0`1VIVH20?ooo`<00000
0`0I6AT30?ooo`80c<c<0`2c/k<80=7=Z@001P3AcJWd0?ooo`<000000`20P80206IVIP<0VIVI0`3V
i^H20820P0<0c<c<0`1<C4`20?ooo`<0C4a<0`1VIVH3000000806ATI0`1<C4`301TI6@8000000`2I
VIT306IVIPD0/k>c0`00000304a<C0806ATI0`2c/k<304a<C0<0P8200P3<c<`30;>c/`<0IVIV0P3o
ool3000000<06ATI0`3oool20<c<c0<0/k>c203AcJT000H0dLfYm`3oool30820P080<c<c0`1VIVH3
0<c<c0806ATI0`3oool304a<C0D0P8200`0I6AT504a<C0<0IVIV1@00000309VIV@<0IVIV0`000002
0?ooo`<0<c<c0`3<c<`206IVIP<0P8200`1<C4`30820P080<c<c0`2IVIT30?ooo`D0/k>c0`0I6AT3
0<c<c080<c<c0`2IVIT80=7=Z@001P3AcJWg0?ooo`<0P8200P0c<c<306IVIP<0c<c<0P0I6AT30?oo
o`<0C4a<1@20P80301TI6@D0C4a<0`1VIVH5000000<0VIVI0`1VIVH300000080oooo0`0c<c<30<c<
c080IVIV0`20P80304a<C0<0P8200P0c<c<309VIV@<0oooo1@2c/k<301TI6@<0c<c<0P0c<c<309VI
V@P0dLfY00060=7=ZOL0oooo0`20P80203<c<`<0IVIV0`3<c<`201TI6@<0oooo0`1<C4`50820P0<0
6ATI1@1<C4`306IVIPD000000`2IVIT306IVIP<000000P3oool303<c<`<0c<c<0P1VIVH30820P0<0
C4a<0`20P80203<c<`<0VIVI0`3oool50;>c/`<06ATI0`3<c<`203<c<`<0VIVI203AcJT000H0dLfY
nP3oool20;>c/`<0i^KV0`00000206IVIPH0P8200P0I6AT306IVIPH06ATI0P3<c<`30?ooo`<0/k>c
0P0I6AT30;>c/`<0P8200`0I6AT50;>c/`<0C4a<0P0I6AT30>KViP<0VIVI0`3<c<`20820P0<0VIVI
0`3oool206IVIP<0c<c<0`2IVIT30;>c/`80VIVI0`0I6AT80=7=Z@001P3AcJWj0?ooo`80/k>c0`3V
i^H300000080IVIV1P20P80201TI6@<0IVIV1P0I6AT20<c<c0<0oooo0`2c/k<201TI6@<0/k>c0`20
P80301TI6@D0/k>c0`1<C4`201TI6@<0i^KV0`2IVIT30<c<c080P8200`2IVIT30?ooo`80IVIV0`3<
c<`309VIV@<0/k>c0P2IVIT301TI6@P0dLfY00060=7=ZO`0oooo0`3Vi^H303<c<`80c<c<0`20P803
03<c<`80P8200`00000603<c<`80i^KV0`0c<c<30<c<c08000000`2IVIT30?ooo`<0/k>c0P3<c<`3
09VIV@<0oooo0P2IVIT30;>c/`<0VIVI0`3oool204a<C0<0VIVI1@1VIVH3000000<0oooo0`3<c<`2
09VIV@<0i^KV203AcJT000H0dLfYo03oool30>KViP<0<c<c0P3<c<`30820P0<0<c<c0P20P8030000
00H0<c<c0P3Vi^H303<c<`<0c<c<0P00000309VIV@<0oooo0`2c/k<20<c<c0<0VIVI0`3oool209VI
V@<0/k>c0`2IVIT30?ooo`80C4a<0`2IVIT506IVIP<000000`3oool30<c<c080VIVI0`3Vi^H80=7=
Z@001P3AcJWl0?ooo`<0i^KV0`0c<c<20<c<c0<0P8200`0c<c<20820P0<000001P0c<c<20>KViP<0
<c<c0`3<c<`2000000<0VIVI0`3oool30;>c/`80c<c<0`2IVIT30?ooo`80VIVI0`2c/k<309VIV@<0
oooo0P1<C4`309VIV@D0IVIV0`0000030?ooo`<0c<c<0P2IVIT30>KViPP0dLfY00060=7=ZOl0oooo
0`3oool2000000<0IVIV0`2c/k<204a<C0H000000`0I6AT203<c<`<0/k>c0`1<C4`201TI6@<0/k>c
1P20P80204a<C0<0c<c<0`0000020820P0<0i^KV0`0I6AT50?ooo`<0VIVI0`3oool201TI6@H0C4a<
0`3Vi^H203<c<`<0P820203AcJT000H0dLfYo`3oool30?ooo`8000000`1VIVH30;>c/`80C4a<1P00
000301TI6@80<c<c0`2c/k<304a<C0806ATI0`2c/k<60820P080C4a<0`3<c<`300000080P8200`3V
i^H301TI6@D0oooo0`2IVIT30?ooo`806ATI1P1<C4`30>KViP80<c<c0`20P8080=7=Z@001P3AcJWo
0?ooo`<0oooo0P00000306IVIP<0/k>c0P1<C4`6000000<06ATI0P0c<c<30;>c/`<0C4a<0P0I6AT3
0;>c/`H0P8200P1<C4`30<c<c0<000000P20P8030>KViP<06ATI1@3oool309VIV@<0oooo0P0I6AT6
04a<C0<0i^KV0P0c<c<30820P0P0dLfY00060=7=ZOl0oooo1@3oool30820P0<0<c<c0P00000301TI
6@<0/k>c0`0I6AT20;>c/`<0i^KV0`0I6AT20<c<c0<0i^KV0`2c/k<30?ooo`80/k>c0`3Vi^H30<c<
c080C4a<0`0000030820P0<000000P2IVIT3000000<0C4a<0P3<c<`30>KViP<0P8200`2c/k<209VI
V@<0/k>c203AcJT000H0dLfYo`3oool50?ooo`<0P8200`0c<c<2000000<06ATI0`2c/k<301TI6@80
/k>c0`3Vi^H301TI6@80c<c<0`3Vi^H30;>c/`<0oooo0P2c/k<30>KViP<0c<c<0P1<C4`3000000<0
P8200`00000209VIV@<000000`1<C4`20<c<c0<0i^KV0`20P8030;>c/`80VIVI0`2c/k<80=7=Z@00
1P3AcJWo0?ooo`P0oooo0`2c/k<50<c<c0<0i^KV0`2c/k<20<c<c0<0/k>c0`0000020;>c/`<00000
0`20P80304a<C080i^KV0`0c<c<301TI6@80P8200`2c/k<301TI6@<0i^KV0P3oool603<c<`80IVIV
0`1<C4`303<c<`<0P8200P1<C4`309VIV@P0dLfY00060=7=ZOl0oooo203oool30;>c/`D0c<c<0`3V
i^H30;>c/`80c<c<0`2c/k<300000080/k>c0`0000030820P0<0C4a<0P3Vi^H303<c<`<06ATI0P20
P8030;>c/`<06ATI0`3Vi^H20?ooo`H0<c<c0P1VIVH304a<C0<0<c<c0`20P80204a<C0<0VIVI203A
cJT000H0dLfYo`3oool80?ooo`<0/k>c1@3<c<`30>KViP<0/k>c0P3<c<`30;>c/`<000000P2c/k<3
000000<0P8200`1<C4`20>KViP<0<c<c0`0I6AT20820P0<0/k>c0`0I6AT30>KViP80oooo1P0c<c<2
06IVIP<0C4a<0`0c<c<30820P080C4a<0`2IVIT80=7=Z@001P3AcJWo0?ooo`/0oooo0P3Vi^H303<c
<`<0/k>c0`0000020?ooo`<0C4a<0`2c/k<203<c<`H000000`0c<c<20?ooo`<0C4a<0`3oool20820
P0<0c<c<0`2IVIT50;>c/`<06ATI0`0c<c<204a<C0<0P8200`2c/k<304a<C08000000`0I6AT80=7=
Z@001P3AcJWo0?ooo`/0oooo0P3Vi^H303<c<`<0/k>c0`0000020?ooo`<0C4a<0`2c/k<203<c<`H0
00000`0c<c<20?ooo`<0C4a<0`3oool20820P0<0c<c<0`2IVIT50;>c/`<06ATI0`0c<c<204a<C0<0
P8200`2c/k<304a<C08000000`0I6AT80=7=Z@001P3AcJWo0?ooo`/0oooo0P3Vi^H303<c<`<0/k>c
0`0000020?ooo`<0C4a<0`2c/k<203<c<`H000000`0c<c<20?ooo`<0C4a<0`3oool20820P0<0c<c<
0`2IVIT50;>c/`<06ATI0`0c<c<204a<C0<0P8200`2c/k<304a<C08000000`0I6AT80=7=Z@001P3A
cJWo0?oooa00oooo0`00000304a<C0D0i^KV0`20P8020>KViP<0IVIV0`3oool30820P0806ATI0`00
00030<c<c080<c<c0`20P80306IVIP<0<c<c0P00000304a<C0<0oooo0P00000301TI6@<0oooo0`0c
<c<50>KViPP0dLfY00060=7=ZOl0oooo403oool3000000<0C4a<1@3Vi^H30820P080i^KV0`1VIVH3
0?ooo`<0P8200P0I6AT3000000<0c<c<0P0c<c<30820P0<0IVIV0`0c<c<2000000<0C4a<0`3oool2
000000<06ATI0`3oool303<c<`D0i^KV203AcJT000H0dLfYo`3oool@0?ooo`<000000`1<C4`50>KV
iP<0P8200P3Vi^H306IVIP<0oooo0`20P80201TI6@<000000`3<c<`203<c<`<0P8200`1VIVH303<c
<`8000000`1<C4`30?ooo`8000000`0I6AT30?ooo`<0<c<c1@3Vi^H80=7=Z@001P3AcJWo0?oooa<0
oooo0`20P80201TI6@<0VIVI0`20P8020<c<c0<0/k>c0`3oool306IVIP80/k>c1P0c<c<209VIV@<0
/k>c0`3oool30;>c/`80<c<c0`3<c<`306IVIPD0i^KV1P3oool209VIV@<0P820203AcJT000H0dLfY
o`3ooolC0?ooo`<0P8200P0I6AT309VIV@<0P8200P3<c<`30;>c/`<0oooo0`1VIVH20;>c/`H0<c<c
0P2IVIT30;>c/`<0oooo0`2c/k<203<c<`<0c<c<0`1VIVH50>KViPH0oooo0P2IVIT30820P0P0dLfY
00060=7=ZOl0oooo5P3oool20;>c/`<0c<c<0`2IVIT204a<C0<0c<c<0`0I6AT300000080c<c<0`2I
VIT30;>c/`80i^KV0`0I6AT60820P080C4a<0`1VIVH30>KViP8000000`20P80306IVIP<0oooo0P1V
IVH30;>c/`P0dLfY00060=7=ZOl0oooo5P3oool20;>c/`<0c<c<0`2IVIT204a<C0<0c<c<0`0I6AT3
00000080c<c<0`2IVIT30;>c/`80i^KV0`0I6AT60820P080C4a<0`1VIVH30>KViP8000000`20P803
06IVIP<0oooo0P1VIVH30;>c/`P0dLfY00060=7=ZOl0oooo5P3oool20;>c/`<0c<c<0`2IVIT204a<
C0<0c<c<0`0I6AT300000080c<c<0`2IVIT30;>c/`80i^KV0`0I6AT60820P080C4a<0`1VIVH30>KV
iP8000000`20P80306IVIP<0oooo0P1VIVH30;>c/`P0dLfY00060=7=ZOl0oooo603oool30>KViP<0
<c<c0P20P8030;>c/`<0VIVI1@0I6AT30820P0<0i^KV0P0c<c<601TI6@<0oooo0P0I6AT30>KViP<0
00000P1VIVH30?ooo`<0/k>c0`3oool206IVIP<0VIVI203AcJT000H0dLfYo`3ooolH0?ooo`<0i^KV
0`0c<c<20820P0<0/k>c0`2IVIT501TI6@<0P8200`3Vi^H203<c<`H06ATI0`3oool201TI6@<0i^KV
0`00000206IVIP<0oooo0`2c/k<30?ooo`80IVIV0`2IVIT80=7=Z@001P3AcJWo0?oooaP0oooo0`3V
i^H303<c<`80P8200`2c/k<309VIV@D06ATI0`20P8030>KViP80<c<c1P0I6AT30?ooo`806ATI0`3V
i^H300000080IVIV0`3oool30;>c/`<0oooo0P1VIVH309VIV@P0dLfY00060=7=ZOl0oooo7P3oool2
000000<0C4a<0`0I6AT306IVIP80P8200`00000304a<C080<c<c1P1<C4`30?ooo`80IVIV0`20P805
06IVIP<0/k>c0`0I6AT50820P0<06ATI203AcJT000H0dLfYo`3ooolN0?ooo`8000000`1<C4`301TI
6@<0IVIV0P20P803000000<0C4a<0P0c<c<604a<C0<0oooo0P1VIVH30820P0D0IVIV0`2c/k<301TI
6@D0P8200`0I6AT80=7=Z@001P3AcJWo0?ooob00oooo0`20P80601TI6@80i^KV1P2IVIT20<c<c0<0
IVIV0`00000303<c<`806ATI0`3Vi^H309VIV@80i^KV0`00000304a<C0<0oooo0P0I6AT30>KViPP0
dLfY00060=7=ZOl0oooo803oool30820P0H06ATI0P3Vi^H609VIV@80c<c<0`1VIVH3000000<0<c<c
0P0I6AT30>KViP<0VIVI0P3Vi^H3000000<0C4a<0`3oool201TI6@<0i^KV203AcJT000H0dLfYo`3o
oolP0?ooo`<0P8201P0I6AT20>KViPH0VIVI0P3<c<`306IVIP<000000`0c<c<201TI6@<0i^KV0`2I
VIT20>KViP<000000`1<C4`30?ooo`806ATI0`3Vi^H80=7=Z@001P3AcJWo0?ooob<0oooo0`2c/k<3
0<c<c080C4a<0`3<c<`309VIV@80IVIV0`0c<c<30?ooo`<0P8200P0000030;>c/`<000000P3Vi^H6
0<c<c0D0oooo0`20P8080=7=Z@001P3AcJWo0?ooob<0oooo0`2c/k<30<c<c080C4a<0`3<c<`309VI
V@80IVIV0`0c<c<30?ooo`<0P8200P0000030;>c/`<000000P3Vi^H60<c<c0D0oooo0`20P8080=7=
Z@001P3AcJWo0?ooob<0oooo0`2c/k<30<c<c080C4a<0`3<c<`309VIV@80IVIV0`0c<c<30?ooo`<0
P8200P0000030;>c/`<000000P3Vi^H60<c<c0D0oooo0`20P8080=7=Z@001P3AcJWo0?ooobH0oooo
0`3Vi^H203<c<`<0IVIV0`1<C4`2000000<0c<c<1P1VIVH501TI6@<0IVIV1@3oool304a<C0<0c<c<
0P0c<c<30;>c/`P0dLfY00060=7=ZOl0oooo9P3oool30>KViP80<c<c0`1VIVH304a<C08000000`3<
c<`606IVIPD06ATI0`1VIVH50?ooo`<0C4a<0`3<c<`203<c<`<0/k>c203AcJT000H0dLfYo`3oool[
0?ooo`<000000`0c<c<204a<C0<0i^KV0`3<c<`30820P0806ATI0`2c/k<30<c<c0P0P8200`0I6AT2
0820P0<0VIVI203AcJT000H0dLfYo`3oool[0?ooo`<000000`0c<c<204a<C0<0i^KV0`3<c<`30820
P0806ATI0`2c/k<30<c<c0P0P8200`0I6AT20820P0<0VIVI203AcJT000H0dLfYo`3oool[0?ooo`<0
00000`0c<c<204a<C0<0i^KV0`3<c<`30820P0806ATI0`2c/k<30<c<c0P0P8200`0I6AT20820P0<0
VIVI203AcJT000H0dLfYo`3oool^0?ooo`<0P8200P0000030<c<c0<0<c<c0`0000020<c<c0<0i^KV
0`3<c<`201TI6@<0IVIV0`0I6AT304a<C080oooo0`0I6AT80=7=Z@001P3AcJWo0?ooobh0oooo0`20
P802000000<0c<c<0`0c<c<300000080c<c<0`3Vi^H30<c<c0806ATI0`1VIVH301TI6@<0C4a<0P3o
ool301TI6@P0dLfY00060=7=ZOl0oooo;P3oool30820P08000000`3<c<`303<c<`<000000P3<c<`3
0>KViP<0c<c<0P0I6AT306IVIP<06ATI0`1<C4`20?ooo`<06ATI203AcJT000H0dLfYo`3ooola0?oo
o`80/k>c0`3<c<`301TI6@D0<c<c0`2c/k<300000080oooo0`20P8030;>c/`<0c<c<0P1VIVH30>KV
iPP0dLfY00060=7=ZOl0oooo<@3oool20;>c/`<0c<c<0`0I6AT503<c<`<0/k>c0`0000020?ooo`<0
P8200`2c/k<30<c<c080IVIV0`3Vi^H80=7=Z@001P3AcJWo0?oooc40oooo0P2c/k<30<c<c0<06ATI
1@0c<c<30;>c/`<000000P3oool30820P0<0/k>c0`3<c<`206IVIP<0i^KV203AcJT000H0dLfYo`3o
oolc0?ooo`<0i^KV1P0c<c<20>KViP<0P8201@1<C4`30>KViP<000000`3oool204a<C0<0P820203A
cJT000H0dLfYo`3ooolc0?ooo`<0i^KV1P0c<c<20>KViP<0P8201@1<C4`30>KViP<000000`3oool2
04a<C0<0P820203AcJT000H0dLfYo`3oooli0?ooo`<000000P0I6AT309VIV@<0C4a<0P20P80301TI
6@<0VIVI0`0I6AT2000000<0/k>c203AcJT000H0dLfYo`3oooli0?ooo`<000000P0I6AT309VIV@<0
C4a<0P20P80301TI6@<0VIVI0`0I6AT2000000<0/k>c203AcJT000H0dLfYo`3oooli0?ooo`<00000
0P0I6AT309VIV@<0C4a<0P20P80301TI6@<0VIVI0`0I6AT2000000<0/k>c203AcJT000H0dLfYo`3o
ooll0?ooo`80P8200`00000304a<C080P8200`0c<c<304a<C0<000001@2IVIT80=7=Z@001P3AcJWo
0?oooc`0oooo0P20P803000000<0C4a<0P20P80303<c<`<0C4a<0`00000509VIV@P0dLfY00060=7=
ZOl0oooo?03oool20820P0<000000`1<C4`20820P0<0<c<c0`1<C4`3000000D0VIVI203AcJT000H0
dLfYo`3oooln0?ooo`H0/k>c0P3Vi^H309VIV@<0/k>c0`3Vi^H206IVIP<06ATI203AcJT000H0dLfY
o`3oooln0?ooo`H0/k>c0P3Vi^H309VIV@<0/k>c0`3Vi^H206IVIP<06ATI203AcJT000H0dLfYo`3o
oom10?ooo`<0i^KV0P0c<c<301TI6@<0IVIV0`3<c<`20;>c/`<0i^KV203AcJT000H0dLfYo`3ooom1
0?ooo`<0i^KV0P0c<c<301TI6@<0IVIV0`3<c<`20;>c/`<0i^KV203AcJT000H0dLfYo`3ooom10?oo
o`<0i^KV0P0c<c<301TI6@<0IVIV0`3<c<`20;>c/`<0i^KV203AcJT000H0dLfYo`3ooom60?ooo`H0
00000`3<c<`20;>c/`<0P820203AcJT000H0dLfYo`3ooom60?ooo`H000000`3<c<`20;>c/`<0P820
203AcJT000H0dLfYo`3ooom60?ooo`H000000`3<c<`20;>c/`<0P820203AcJT000H0dLfYo`3ooom9
0?ooo`<0IVIV0`3oool20>KViP<0/k>c203AcJT000H0dLfYo`3ooom90?ooo`<0IVIV0`3oool20>KV
iP<0/k>c203AcJT000H0dLfYo`3ooom90?ooo`<0IVIV0`3oool20>KViP<0/k>c203AcJT000H0dLfY
o`3ooom<0?ooo`D0/k>c0`2IVIT80=7=Z@001P3AcJWo0?oood`0oooo1@2c/k<309VIV@P0dLfY0006
0=7=ZOl0ooooC`3oool20>KViP<06ATI203AcJT000H0dLfYo`3ooom?0?ooo`80i^KV0`0I6AT80=7=
Z@001P3AcJWo0?ooodl0oooo0P3Vi^H301TI6@P0dLfY003o0=7=ZF80dLfY003o0=7=ZF80dLfY003o
0=7=ZF80dLfY003o0=7=ZF80dLfY003o0=7=ZF80dLfY0000\
\>"],
  ImageRangeCache->{{{0, 352.813}, {282.063, 0}} -> {-2.54386, -2.00052, \
0.368716, 0.368716}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["REFERENCES", "Section"],

Cell[TextData[{
  "[1] http://www.stephenwolfram.com/\n\n[2] A Simple Universal Cellular \
Automaton and its One-Way and Totalistic Version\nA. Jurgen, K. Culik II\n\
Complex Systems 1, 1-16 (1987)\n      \n[3] A Fractal Guide to Tic-Tac-Toe\n\
I. Stewart\nScientific American 283, 86-88 (2000)\n    \n[4] Linear Cellular \
Automata and the Garden-of-Eden\nK. Sutner\nThe ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "l Intelligencer 11, 2 49-53 (1989)\n\n[5] Partitions and Sums of Integer \
Powers\nJ. Rangel-Mondragon\n\
http://www.mathsource.com/Content/WhatsNew/0211-307"
}], "Reference"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
AutoGeneratedPackage->None,
WindowToolbars->"EditBar",
WindowSize->{750, 869},
WindowMargins->{{206, Automatic}, {Automatic, 10}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell[TextData[{
    "Style Definitions for \n",
    StyleBox["The Mathematica Journal",
      FontSlant->"Italic"]
  }], "Subtitle",
    CellMargins->{{0, Inherited}, {Inherited, 0}},
    CellFrameMargins->{{20, 4}, {8, 20}},
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0]],
  
  Cell["v1.14", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[StyleData[All, "Working"],
    ScreenStyleEnvironment->"Working",
    PrintingStyleEnvironment->"Printout",
    CellBracketOptions->{"Color"->RGBColor[0.115343, 0.350561, 0.362966]},
    ShowCellLabel->True,
    CellFrameLabelMargins->6,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    ScreenStyleEnvironment->"Presentation",
    PrintingStyleEnvironment->"Printout",
    CellFrameMargins->{{30, 4}, {8, 8}},
    Magnification->1.25],
  
  Cell[StyleData[All, "HTML"],
    ScreenStyleEnvironment->"HTML",
    PrintingOptions->{"PrintingMargins"->{{0, 0}, {82, 56}},
    "PageSize"->{486, 711}},
    ShowCellBracket->True,
    CellFrameLabelMargins->6,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    ScreenStyleEnvironment->"Printout",
    PrintingStyleEnvironment->"Printout",
    PageWidth->PaperWidth,
    PrintingOptions->{"PrintingMargins"->{{24, 74}, {72, 72}},
    "PrintRegistrationMarks"->False,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    ShowCellBracket->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
          "Author(s)", "Header"]}, {
        Cell[ "Article Title", "Header"], Inherited, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"The Mathematica Journal  ", 
              StyleBox[ "volume", FontWeight -> "Bold"], ":issue (year)"}], 
            "Footer"], Inherited, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], 
              ValueBox[ "Date"]}], "Footer"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"], 
              ValueBox[ "Date"]}], "Footer"], Inherited, Cell[ 
            TextData[ {"The Mathematica Journal  ", 
              StyleBox[ "volume", FontWeight -> "Bold"], ":issue (year)"}], 
            "Footer"]}},
    CellLabelAutoDelete->True,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
Each notebook should contain at least one Title cell. One use of Title is \
preferred. Title resets all cell CounterBox values to zero (except Title).\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {Inherited, 0}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->{{55, 4}, {8, 20}},
    LineSpacing->{1.125, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Subtitle", 0}, {"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}, {"List", 0}, {"NumberedFigure", 0}, {
        "NumberedTable", 0}, {"NumberedProgram", 0}, {"Equation", 0}, {
        "Text", 0}, {"SmallText", 0}, {"Reference", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontSlant->"Italic",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Presentation"],
    LineSpacing->{0.95, 0},
    FontSize->40,
    FontSlant->"Italic",
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "HTML"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    CellFrameMargins->False,
    LineSpacing->{0.95, 0},
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell["\<\
Subtitle is an optional cell, used for example, in the Tech Support column \
where Subtitle states topics of a column for the current issue.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subtitle", "Presentation"]],
  
  Cell[StyleData["Subtitle", "HTML"],
    CellMargins->{{54, 0}, {10, 10}},
    FontSize->12],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{54, 0}, {10, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->18,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"]],
  
  Cell[StyleData["Subsubtitle", "HTML"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    FontSize->16],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    FontSize->16]
  }, Closed]],
  
  Cell["\<\
SectionFirst should be used for the first section level heading in a \
notebook. SectionFirst sets the following counter values to zero: Subsection \
and Subsubsection. Sets Section counter value to 1.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 2}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Presentation"],
    CellFrame->{{0, 0}, {0, 3}},
    CellFrameMargins->{{0, 0}, {0, 4}},
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    FontSize->18],
  
  Cell[StyleData["SectionFirst", "HTML"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{54, 24}, {15, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionFirst", "Printout"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{54, 24}, {15, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14]
  }, Closed]],
  
  Cell["\<\
Section should be used for subsequent section level headings. Section sets \
counter values Subsection and Subsubsection to zero.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}},
    FontSize->18],
  
  Cell[StyleData["Section", "HTML"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14]
  }, Closed]],
  
  Cell["\<\
Subsection is an optional style. Sets counter Subsubsection to zero.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"]],
  
  Cell[StyleData["Subsection", "HTML"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12]
  }, Closed]],
  
  Cell["\<\
SubsectionNoSpace is an optional style to be used if a subsection level \
heading directly follows a section level heading. SubsectionNoSpace sets \
counter Subsubsection to zero.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpace"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpace", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpace", "HTML"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpace", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"]],
  
  Cell[StyleData["Subsubsection", "HTML"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
NoDingbat versions of headings used, for example, in the frontmatter.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionNoDingbat"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionNoDingbat", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}}],
  
  Cell[StyleData["SectionNoDingbat", "HTML"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoDingbat"],
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoDingbat", "HTML"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat"],
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "HTML"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionNoDingbat"],
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsubsectionNoDingbat", "HTML"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
PreTitle to be used for such things that precede a title, for example, \
EDITOR'S PICK and other columns. Should be entered all caps with aspace \
between each letter, two spaces between words. FontTracking is set to Wide.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PreTitle"],
    ShowCellBracket->True,
    CellMargins->{{54, 25}, {Inherited, 0}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->{{55, 4}, {8, 20}},
    LineSpacing->{1.125, 0},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold",
    FontTracking->"Wide"],
  
  Cell[StyleData["PreTitle", "Presentation"]],
  
  Cell[StyleData["PreTitle", "HTML"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellFrameMargins->False,
    FontSize->12,
    FontTracking->"Wide"],
  
  Cell[StyleData["PreTitle", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellFrameMargins->False,
    FontSize->12,
    FontTracking->"Wide"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"Text",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Text", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Text", "HTML"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"SmallText",
    FontFamily->"Times",
    FontSize->10],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SmallText", "HTML"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->9]
  }, Closed]],
  
  Cell["\<\
Quote should be used when quoting portions from material previously published \
elsewhere (and appropriately cited).\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Quote"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    TextJustification->0,
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Quote", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Quote", "HTML"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Quote", "Printout"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[TextData[{
    "Input cell style to be used for ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " input statements that are followed by either Output or GraphicsOnly \
cell styles. Sets ",
    "DefaultFormatType->DefaultInputFormatType."
  }], "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->{{0.25, 0.25}, {0, 0.25}},
    CellMargins->{{54, 24}, {-1, 10}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold",
    Background->RGBColor[0.819455, 0.804242, 0.663142]],
  
  Cell[StyleData["Input", "Presentation"],
    FontSize->14,
    Background->RGBColor[0.819455, 0.804242, 0.663142]],
  
  Cell[StyleData["Input", "HTML"],
    CellFrame->False,
    CellMargins->{{0, 0}, {10, 10}},
    Background->None],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{54, 24}, {-1, 10}},
    FontSize->9,
    Background->GrayLevel[0.899001]]
  }, Closed]],
  
  Cell[TextData[{
    "InputOnly cell style to be used for ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " input statements that produce no output or graphic. See Program cell \
style for presenting segments of code that do not evaluate."
  }], "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InputOnly"],
    CellFrame->True,
    CellMargins->{{54, 24}, {15, 10}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Bold",
    Background->RGBColor[0.819455, 0.804242, 0.663142]],
  
  Cell[StyleData["InputOnly", "Presentation"],
    CellFrameMargins->8,
    FontSize->14,
    Background->RGBColor[0.819455, 0.804242, 0.663142]],
  
  Cell[StyleData["InputOnly", "HTML"],
    CellFrame->False,
    CellMargins->{{0, 0}, {10, 10}},
    CellFrameMargins->8,
    Background->None],
  
  Cell[StyleData["InputOnly", "Printout"],
    CellMargins->{{54, 24}, {10, 10}},
    FontSize->9,
    Background->GrayLevel[0.899001]]
  }, Closed]],
  
  Cell["\<\
InlineInput is for code segments embedded within another cell. Sets \
FormatType->DefaultInputFormatType.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineInput"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    AutoItalicWords->{},
    FormatType->DefaultInputFormatType,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineInput", "Presentation"]],
  
  Cell[StyleData["InlineInput", "HTML"]],
  
  Cell[StyleData["InlineInput", "Printout"]]
  }, Closed]],
  
  Cell["\<\
InlineInputTraditionalForm is for TraditionalForm segments embedded within \
another cell. Sets FormatType->TraditionalForm.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineInputTraditionalForm"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    AutoItalicWords->{},
    FormatType->TraditionalForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    SingleLetterItalics->True,
    ZeroWidthTimes->False,
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineInputTraditionalForm", "Presentation"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "HTML"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Printout"]]
  }, Closed]],
  
  Cell[TextData[{
    "Output cell style is usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel. To follow Input cell style. Sets \
DefaultFormatType->DefaultOutputFormatType."
  }], "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{0.25, 0.25}, {0.25, 0}},
    CellMargins->{{54, 24}, {10, 0}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelAutoDelete->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Output",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->RGBColor[0.819455, 0.804242, 0.663142]],
  
  Cell[StyleData["Output", "Presentation"],
    FontSize->14,
    Background->RGBColor[0.819455, 0.804242, 0.663142]],
  
  Cell[StyleData["Output", "HTML"],
    CellFrame->False,
    CellMargins->{{0, 0}, {10, 0}},
    Background->None],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{54, 24}, {10, -2}},
    FontSize->9,
    Background->GrayLevel[0.899001]]
  }, Closed]],
  
  Cell[TextData[{
    "Message cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically messages emitted during evaluation.To follow Input \
cell style, precede Output cell style."
  }], "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellFrame->{{0.25, 0.25}, {0, 0}},
    CellDingbat->"\[WarningSign]",
    CellMargins->{{54, 24}, {0, 0}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameLabelMargins->-9,
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0, 0, 1],
    Background->RGBColor[0.819455, 0.804242, 0.663142]],
  
  Cell[StyleData["Message", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["Message", "HTML"],
    CellFrame->False,
    CellMargins->{{0, 0}, {0, 0}},
    CellFrameLabelMargins->8,
    Background->None],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, 24}, {0, 0}},
    FontSize->8,
    FontColor->GrayLevel[0],
    Background->GrayLevel[0.899001]]
  }, Closed]],
  
  Cell[TextData[{
    "Print cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically from such commands as ?Plot."
  }], "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellFrame->True,
    CellMargins->{{54, 24}, {1, 6}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.718318, 0.694575, 0.474449],
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Print", "Presentation"],
    CellFrame->2,
    FontSize->12,
    Background->None],
  
  Cell[StyleData["Print", "HTML"],
    CellMargins->{{0, 0}, {2, 6}},
    CellFrameColor->GrayLevel[0]],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 24}, {2, 6}},
    CellFrameColor->GrayLevel[0],
    FontSize->8]
  }, Closed]],
  
  Cell["\<\
Graphics cell usually output by kernel. To follow Input cell, precede Output \
cell.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellFrame->{{0.25, 0.25}, {0, 0}},
    CellMargins->{{54, 24}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelAutoDelete->True,
    DefaultFormatType->DefaultOutputFormatType,
    CounterIncrements->"Graphics",
    ImageMargins->{{30, 0}, {0, 0}},
    StyleMenuListing->None,
    Background->RGBColor[0.819455, 0.804242, 0.663142]],
  
  Cell[StyleData["Graphics", "Presentation"]],
  
  Cell[StyleData["Graphics", "HTML"],
    CellFrame->False,
    Background->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, 24}, {-1, -2}},
    ImageSize->{266, 266},
    ImageMargins->{{40, Inherited}, {Inherited, Inherited}},
    Background->GrayLevel[0.899001]]
  }, Closed]],
  
  Cell["\<\
GraphicsOnly cell to follow Input cell, not followed by Output cell. Convert \
Graphics cell to GraphicsOnly cell manually.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GraphicsOnly"],
    CellFrame->{{0.25, 0.25}, {0.25, 0}},
    CellMargins->{{54, 24}, {10, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelAutoDelete->True,
    DefaultFormatType->DefaultOutputFormatType,
    CounterIncrements->"Graphics",
    ImageMargins->{{30, 0}, {0, 0}},
    Background->RGBColor[0.819455, 0.804242, 0.663142]],
  
  Cell[StyleData["GraphicsOnly", "Presentation"]],
  
  Cell[StyleData["GraphicsOnly", "HTML"],
    CellFrame->False,
    Background->None],
  
  Cell[StyleData["GraphicsOnly", "Printout"],
    CellMargins->{{54, 24}, {10, 0}},
    ImageSize->{266, 266},
    ImageMargins->{{40, Inherited}, {Inherited, Inherited}},
    Background->GrayLevel[0.899001]]
  }, Closed]],
  
  Cell["\<\
PictureGroup cell style used to group graphic cells that comprise an \
animation.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellFrame->{{0.25, 0.25}, {0.25, 0}},
    CellMargins->{{54, 17}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    ShowCellLabel->False,
    ImageMargins->{{30, 0}, {0, 0}},
    Background->RGBColor[0.819455, 0.804242, 0.663142]],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    CellMargins->{{54, 17}, {0, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "HTML"],
    CellFrame->False,
    CellMargins->{{54, 19}, {0, 0}},
    StyleMenuListing->None,
    Background->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{54, 24}, {0, 0}},
    Background->GrayLevel[0.899001]]
  }, Closed]],
  
  Cell[TextData[{
    "PlacedGraphics cell style to be used when pasting in a graphic from \
another application or when presenting a graphic not associated with ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " input. May be followed by NumberedFigureCaption."
  }], "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PlacedGraphics"],
    CellFrame->False,
    CellMargins->{{54, 24}, {10, 10}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelAutoDelete->True,
    DefaultFormatType->DefaultOutputFormatType,
    CounterIncrements->"Graphics",
    ImageMargins->{{90, 0}, {0, 0}}],
  
  Cell[StyleData["PlacedGraphics", "Presentation"],
    ImageMargins->{{30, 0}, {0, 0}}],
  
  Cell[StyleData["PlacedGraphics", "HTML"],
    ImageMargins->{{30, 0}, {0, 0}}],
  
  Cell[StyleData["PlacedGraphics", "Printout"],
    CellMargins->{{54, 24}, {10, 10}},
    ImageSize->{266, 266},
    ImageMargins->{{40, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell["\<\
CellLabel style controls how cell labels appear when a cell has \
ShowCellLabels->True.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{5, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontSlant->"Oblique",
    FontColor->RGBColor[0.115343, 0.350561, 0.362966]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->10,
    FontColor->RGBColor[0.115343, 0.350561, 0.362966]],
  
  Cell[StyleData["CellLabel", "HTML"],
    FontSize->8,
    FontColor->RGBColor[0.115343, 0.350561, 0.362966]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->6,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
NumberedEquation is for DisplayFormula cells that number sequentially \
throughout a notebook.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{54, 24}, {5, 10}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->TraditionalForm,
    TextAlignment->Center,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontFamily->"Times",
    FontSize->12,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    FontSize->14],
  
  Cell[StyleData["NumberedEquation", "HTML"],
    CellMargins->{{0, 0}, {5, 10}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    TextAlignment->Center,
    FontSize->12],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{Inherited, Inherited}, {10, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
NumberedFigure is for adding a CellFrameLabel with the word Figure and the \
value of the incremented NumberedFigure counter. Does not allow for a \
caption.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{54, 24}, {5, 10}},
    CellLabelAutoDelete->True,
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"], "."}], FontFamily -> "Helvetica",
             FontSize -> 10, FontWeight -> "Bold"], None}},
    CounterIncrements->"NumberedFigure",
    StyleMenuListing->None],
  
  Cell[StyleData["NumberedFigure", "Presentation"],
    CellMargins->{{54, 25}, {2, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"], "."}], FontFamily -> "Helvetica",
             FontSize -> 12, FontWeight -> "Bold"], None}}],
  
  Cell[StyleData["NumberedFigure", "HTML"],
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"], "."}], FontFamily -> "Helvetica",
             FontSize -> 8, FontWeight -> "Bold"], None}}],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"], "."}], FontFamily -> "Helvetica",
             FontSize -> 8, FontWeight -> "Bold"], None}}]
  }, Closed]],
  
  Cell["\<\
Table cell style to be used for cells containing displayed tabular material. \
May be followed by NumberedTableCaption cell.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Table"],
    CellMargins->{{54, 24}, {5, 10}},
    TextAlignment->Center,
    FontFamily->"Times",
    FontSize->12,
    Background->GrayLevel[0.899001]],
  
  Cell[StyleData["Table", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Table", "HTML"],
    Background->None],
  
  Cell[StyleData["Table", "Printout"],
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[TextData[{
    "DefinitionBox, 2 left-aligned columns, to emulate gray boxes in the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " book."
  }], "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{54, 24}, {5, 10}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    SingleLetterItalics->False,
    LineIndent->0,
    FontFamily->"Times",
    FontSize->12,
    Background->GrayLevel[0.899001],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["DefinitionBox", "HTML"],
    Background->None],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell["\<\
NumberedTable is for adding a CellFrameLabel with the word Table and the \
value of the incremented NumberedTable counter to a Table cell. Does not \
allow for a caption.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{54, 24}, {5, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"], "."}], FontFamily -> "Helvetica", 
            FontSize -> 10, FontWeight -> "Bold"], None}},
    CounterIncrements->"NumberedTable",
    StyleMenuListing->None],
  
  Cell[StyleData["NumberedTable", "Presentation"],
    CellMargins->{{54, 25}, {2, 10}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"], "."}], FontFamily -> "Helvetica", 
            FontSize -> 12, FontWeight -> "Bold"], None}}],
  
  Cell[StyleData["NumberedTable", "HTML"],
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"], "."}], FontFamily -> "Helvetica", 
            FontSize -> 8, FontWeight -> "Bold"], None}}],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"], "."}], FontFamily -> "Helvetica", 
            FontSize -> 8, FontWeight -> "Bold"], None}}]
  }, Closed]],
  
  Cell["\<\
NumberedFigureCaption to be used directly after a PlacedGraphic cell. Use the \
TMJstyles.nb palette to begin the cell and paste in the word Figure and the \
NumberedFigure counter value. Allows for a descriptive caption.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigureCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellLabelPositioning->Left,
    CellFrameLabels->{{None, None}, {None, None}},
    TextAlignment->Left,
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["NumberedFigureCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->14],
  
  Cell[StyleData["NumberedFigureCaption", "HTML"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedFigureCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8]
  }, Closed]],
  
  Cell["\<\
NumberedTableCaption to be used directly after a Table cell. Use the \
TMJstyles.nb palette to begin the cell and paste in the word Table and the \
NumberedTable counter value. Allows for a descriptive caption.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTableCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CounterIncrements->"NumberedTable",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedTableCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedTableCaption", "HTML"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedTableCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8]
  }, Closed]],
  
  Cell["\<\
NumberedProgramCaption to be used directly after a Program cell. Use the \
TMJstyles.nb palette to begin the cell and paste in the word Listing and the \
NumberedProgram counter value. Allows for a descriptive caption.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedProgramCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellFrameLabels->{{None, None}, {None, None}},
    CounterIncrements->"NumberedProgram",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedProgramCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedProgramCaption", "HTML"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedProgramCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8]
  }, Closed]],
  
  Cell["\<\
Use of Caption style should be discouraged. See cell styles for \
NumberedFigureCaption, NumberedTableCaption, NumberedProgramCaption.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {Inherited, 5}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["Caption", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Caption", "HTML"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {10, 10}},
    FontSize->8],
  
  Cell[StyleData["Caption", "Printout"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {10, 10}},
    FontSize->8]
  }, Closed]],
  
  Cell["\<\
BulletedList is an optional style. Adds a CellDingbat of FilledSmallCircle. \
Text indents left a little more.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BulletedList"],
    CellDingbat->"\[FilledSmallCircle]",
    CellMargins->{{86, 10}, {Inherited, Inherited}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BulletedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BulletedList", "HTML"],
    FontSize->10],
  
  Cell[StyleData["BulletedList", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
BeginNumberedList to be used as the first item in a numbered list sequence. \
Use the TMJstyles.nb palette to begin the cell and paste in the List counter \
value.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginNumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    CounterAssignments->{{"List", 0}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BeginNumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BeginNumberedList", "HTML"],
    FontSize->10],
  
  Cell[StyleData["BeginNumberedList", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
NumberedList to be used for subsequent items in a numbered list sequence with \
a single digit. Use the TMJstyles.nb palette to begin the cell and paste in \
the List counter value.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {None, None}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedList", "HTML"],
    FontSize->10],
  
  Cell[StyleData["NumberedList", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
NumberedListTwo to be used for subsequent items in a numbered list sequence \
with two digits. Use the TMJstyles.nb palette to begin the cell and paste in \
the List counter value.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedListTwo"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedListTwo", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedListTwo", "HTML"],
    FontSize->10],
  
  Cell[StyleData["NumberedListTwo", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NolabelList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {None, None}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NolabelList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NolabelList", "HTML"],
    FontSize->10],
  
  Cell[StyleData["NolabelList", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
Reference style to be used in the bibliography portion of a notebook. One \
cell for each bibliography entry. Use the TMJstyles.nb palette to begin cell \
and paste in the Reference counter value.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Reference", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["Reference", "HTML"],
    FontSize->8],
  
  Cell[StyleData["Reference", "Printout"],
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ReferenceTwo"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["ReferenceTwo", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["ReferenceTwo", "HTML"],
    FontSize->8],
  
  Cell[StyleData["ReferenceTwo", "Printout"],
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["OnlineHeader to be used at the beginning of a notebook.", 
    "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OnlineHeader"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {0, 0}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->{{54, 4}, {2, 8}},
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Wide",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0]],
  
  Cell[StyleData["OnlineHeader", "Presentation"],
    CellFrameMargins->{{54, 25}, {8, 8}},
    FontSize->14],
  
  Cell[StyleData["OnlineHeader", "HTML"],
    CellFrame->False,
    CellMargins->{{54, 24}, {10, 10}},
    FontFamily->"Times",
    FontSize->10,
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["OnlineHeader", "Printout"],
    CellFrame->False,
    CellMargins->{{54, 24}, {10, 10}},
    FontFamily->"Times",
    FontSize->10,
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell["\<\
Author to be used after the Title cell with author name(s). Author name(s) \
may be preceded by \"Edited by \" for certain columns. Text in author cell to \
be used as the left page header. Usually followed by an Address cell.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Author", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Author", "HTML"],
    CellMargins->{{54, 24}, {2, 15}},
    FontSize->12],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{54, 24}, {2, 15}},
    FontSize->12]
  }, Closed]],
  
  Cell["\<\
SecondAuthor to be used after a Section cell with author name(s) for a \
particular portion of a notebook. Used for columns Tech Support and Tricks of \
the Trade. Usually followed by an Address cell.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SecondAuthor"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SecondAuthor", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["SecondAuthor", "HTML"],
    CellMargins->{{54, 24}, {2, 15}},
    FontSize->12],
  
  Cell[StyleData["SecondAuthor", "Printout"],
    CellMargins->{{54, 24}, {2, 15}},
    FontSize->12]
  }, Closed]],
  
  Cell["\<\
Address to be used after Author or SecondAuthor. Contains contact information \
for article (section) author.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Address", "HTML"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->10],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
Abstract to be used after the Address cell. Contains a short summary of the \
article.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{54, 24}, {Inherited, 30}},
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Abstract", "HTML"],
    CellMargins->{{54, 24}, {20, 30}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{54, 24}, {20, 30}},
    FontSize->12,
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell["\<\
BeginQuestion is used in the In and Out column directly after a section cell. \
Followed by either Question or Input/Output etc. Last paragraph of the \
question should be in EndQuestion cell style.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginQuestion"],
    CellFrame->{{0, 0}, {0, 2}},
    CellDingbat->"Q:",
    CellMargins->{{72, 34}, {8, 8}},
    CellFrameMargins->{{0, 0}, {2, 4}},
    LineSpacing->{1, 2},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Presentation"],
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "HTML"],
    CellMargins->{{72, 34}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["BeginQuestion", "Printout"],
    CellMargins->{{72, 34}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["\<\
Question used for text cells within the Question portion of a QuestionAnswer.\
\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Question"],
    CellMargins->{{74, 34}, {8, 8}},
    LineSpacing->{1, 2},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["Question", "Presentation"],
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["Question", "HTML"],
    CellMargins->{{74, 34}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Question", "Printout"],
    CellMargins->{{74, 34}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["\<\
EndQuestion used in the In and Out column as the last paragraph of the \
question.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EndQuestion"],
    CellFrame->{{0, 0}, {2, 0}},
    CellMargins->{{70, 35}, {8, 8}},
    LineSpacing->{1, 2},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Presentation"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "HTML"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["EndQuestion", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["\<\
BeginEndQuestion is used in the In and Out column directly after a section \
cell. Used if the question is a single text paragraph.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginEndQuestion"],
    CellFrame->{{0, 0}, {2, 2}},
    CellDingbat->"Q:",
    CellMargins->{{70, 35}, {8, 8}},
    LineSpacing->{1, 2},
    StyleMenuListing->Automatic,
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Presentation"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "HTML"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["BeginEndQuestion", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["\<\
BeginAnswer is used in the In and Out column directly after an EndQuestion or \
BeginEndQuestion cell style to begin the answer portion.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginAnswer"],
    CellDingbat->"A:",
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"Text",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BeginAnswer", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BeginAnswer", "HTML"],
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["BeginAnswer", "Printout"],
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Answer"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"Text",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Answer", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Answer", "HTML"],
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Answer", "Printout"],
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EditorialComment"],
    CellFrame->False,
    CellDingbat->"\[FilledCircle]",
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontColor->RGBColor[1, 0, 0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["EditorialComment", "Presentation"],
    CellMargins->{{18, 4}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["EditorialComment", "HTML"],
    CellMargins->{{18, 4}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["EditorialComment", "Printout"],
    CellMargins->{{18, 4}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
SectionAboutAuthor to be used as the section head for the About the Author \
portion of a notebook.\
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionAboutAuthor"],
    CellDingbat->None,
    CellMargins->{{54, 24}, {0, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->4,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold",
    Background->RGBColor[0.819455, 0.804242, 0.663142]],
  
  Cell[StyleData["SectionAboutAuthor", "Presentation"]],
  
  Cell[StyleData["SectionAboutAuthor", "HTML"],
    Background->None],
  
  Cell[StyleData["SectionAboutAuthor", "Printout"],
    CellMargins->{{54, 24}, {0, 30}},
    FontSize->14,
    Background->GrayLevel[0.899001]]
  }, Closed]],
  
  Cell["\<\
TextAboutAuthor is to be used for the text in the About the Author portion of \
a notebook. \
\>", "EditorialComment"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextAboutAuthor"],
    CellMargins->{{54, 24}, {2, 0}},
    CellFrameMargins->4,
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontSize->12,
    Background->RGBColor[0.819455, 0.804242, 0.663142]],
  
  Cell[StyleData["TextAboutAuthor", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["TextAboutAuthor", "HTML"],
    CellMargins->{{54, 24}, {4, 10}},
    Background->None],
  
  Cell[StyleData["TextAboutAuthor", "Printout"],
    CellMargins->{{54, 24}, {2, 0}},
    FontSize->10,
    Background->GrayLevel[0.899001]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Display Formulas and Programs", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{54, 25}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->TraditionalForm,
    TextAlignment->Center,
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    FontFamily->"Times",
    FontSize->12,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["DisplayFormula", "HTML"],
    CellMargins->{{0, 0}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{54, 25}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->False,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{54, 25}, {Inherited, 6}},
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Program", "Presentation"],
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["Program", "HTML"],
    CellMargins->{{54, 30}, {Inherited, 4}},
    FontSize->9],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{54, 30}, {Inherited, 4}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[StyleData["Header"],
    CellMargins->{{54, 24}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontWeight->"Bold"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "HTML"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "HTML"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "HTML"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "HTML"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "HTML"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "HTML"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These cells define styles that are mixed in with most other cells.  If the \
FormatType of a cell style matches the name of one of the styles defined \
below, then that style is applied along with the local cell style \
definitions. This is particularly true of Input and Output.\
\>", "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["CellExpression"],
    CellMargins->{{54, 24}, {2, 4}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    Hyphenation->False,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["OutputForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    ZeroWidthTimes->False,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These styles are for modifying individual words or letters in a cell \
exclusive of the cell style.\
\>", "Text",
    PageWidth->342,
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell["\<\
RM used to change selection to FontWeight->Plain, FontSlant->Plain\
\>", "EditorialComment"],
  
  Cell[StyleData["RM"],
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
BF used to change selection to FontWeight->Bold, FontSlant->Plain\
\>", "EditorialComment"],
  
  Cell[StyleData["BF"],
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
IT used to change selection to FontWeight->Plain, FontSlant->Italic\
\>", "EditorialComment"],
  
  Cell[StyleData["IT"],
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
BFI used to change selection to FontWeight->Bold, FontSlant->Italic\
\>", "EditorialComment"],
  
  Cell[StyleData["BFI"],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
TR used to change selection to normal text font, FontWeight->Plain, \
FontSlant->Plain\
\>", "EditorialComment"],
  
  Cell[StyleData["TR"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
TI used to change selection to normal text font, FontWeight->Plain, \
FontSlant->Italic\
\>", "EditorialComment"],
  
  Cell[StyleData["TI"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
TB used to change selection to normal text font, FontWeight->Bold, \
FontSlant->Plain\
\>", "EditorialComment"],
  
  Cell[StyleData["TB"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
TBI used to change selection to normal text font, FontWeight->Bold, \
FontSlant->Italic\
\>", "EditorialComment"],
  
  Cell[StyleData["TBI"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
MR used to change selection to monospace font with FontWeight->Plain, \
FontSlant->Plain\
\>", "EditorialComment"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
MR used to change selection to monospace font with FontWeight->Plain, \
FontSlant->Oblique\
\>", "EditorialComment"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
MB used to change selection to monospace font with FontWeight->Bold, \
FontSlant->Plain\
\>", "EditorialComment"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
MBO used to change selection to monospace font with FontWeight->Bold, \
FontSlant->Oblique\
\>", "EditorialComment"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Oblique"],
  
  Cell["\<\
SR used to change selection to sans serif font with FontWeight->Plain, \
FontSlant->Plain\
\>", "EditorialComment"],
  
  Cell[StyleData["SR"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
SO used to change selection to sans serif font with FontWeight->Plain, \
FontSlant->Oblique\
\>", "EditorialComment"],
  
  Cell[StyleData["SO"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
SB used to change selection to sans serif font with FontWeight->Bold, \
FontSlant->Plain\
\>", "EditorialComment"],
  
  Cell[StyleData["SB"],
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
SBO used to change selection to sans serif font with FontWeight->Bold, \
FontSlant->Oblique\
\>", "EditorialComment"],
  
  Cell[StyleData["SBO"],
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold",
    FontSlant->"Oblique"],
  
  Cell["\<\
SCL used to change selection to sans serif font (FontTracking->\"Condensed\")\
\
\>", "EditorialComment"],
  
  Cell[StyleData["SCL"],
    FontFamily->"Helvetica",
    FontTracking->"Condensed"],
  
  Cell["\<\
SCLO used to change selection to sans serif font (FontSlant->\"Italic\", \
FontTracking->\"Condensed\")\
\>", "EditorialComment"],
  
  Cell[StyleData["SCLO"],
    FontFamily->"Helvetica",
    FontSlant->"Italic",
    FontTracking->"Condensed"],
  
  Cell["\<\
SCB used to change selection to sans serif font (FontWeight->\"Bold\", \
FontTracking->\"Condensed\")\
\>", "EditorialComment"],
  
  Cell[StyleData["SCB"],
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontTracking->"Condensed"],
  
  Cell["\<\
SCBO used to change selection to sans serif font (FontWeight->\"Bold\", \
FontSlant->\"Italic\", FontTracking->\"Condensed\")\
\>", "EditorialComment"],
  
  Cell[StyleData["SCBO"],
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontTracking->"Condensed"],
  
  Cell["\<\
SXR used to change selection to sans serif font (FontWeight->\"Bold\", \
FontTracking->\"Extended\")\
\>", "EditorialComment"],
  
  Cell[StyleData["SXR"],
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontTracking->"Extended"],
  
  Cell["\<\
SXO used to change selection to sans serif font (FontWeight->\"Bold\", \
FontSlant->\"Italic\", FontTracking->\"Extended\")\
\>", "EditorialComment"],
  
  Cell[StyleData["SXO"],
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontTracking->"Extended"]
  }, Closed]]
  }, Open  ]]
  }]
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 94, 2, 80, "Title"],
Cell[1836, 55, 304, 10, 90, "Author"],
Cell[2143, 67, 399, 9, 188, "Address"],
Cell[2545, 78, 347, 7, 93, "Reference"],
Cell[2895, 87, 441, 10, 103, "Text"],

Cell[CellGroupData[{
Cell[3361, 101, 24, 0, 67, "SectionFirst"],
Cell[3388, 103, 978, 17, 369, "Text"],
Cell[4369, 122, 1608, 27, 370, "Abstract"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6014, 154, 33, 0, 67, "SectionFirst"],
Cell[6050, 156, 48, 0, 27, "Text"],
Cell[6101, 158, 70, 1, 43, "Input"],
Cell[6174, 161, 207, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[6406, 170, 145, 3, 43, "Input"],
Cell[6554, 175, 184, 3, 43, "Output"]
}, Open  ]],
Cell[6753, 181, 1335, 25, 184, "Text"],
Cell[8091, 208, 1291, 24, 286, "Input",
  InitializationCell->True],
Cell[9385, 234, 313, 5, 65, "Text"],

Cell[CellGroupData[{
Cell[9723, 243, 226, 4, 83, "Input"],
Cell[9952, 249, 19760, 325, 156, 2770, 111, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29749, 579, 297, 5, 103, "Input"],
Cell[30049, 586, 20614, 347, 158, 5538, 156, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[50678, 936, 236, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[50939, 944, 383, 7, 103, "Input"],
Cell[51325, 953, 33149, 510, 158, 12173, 246, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[84511, 1468, 319, 5, 83, "Input"],
Cell[84833, 1475, 36794, 555, 158, 12173, 246, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[121642, 2033, 97, 2, 27, "Text"],

Cell[CellGroupData[{
Cell[121764, 2039, 152, 2, 63, "Input"],
Cell[121919, 2043, 551089, 7171, 657, 124646, 1902, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[673023, 9217, 92, 2, 27, "Text"],

Cell[CellGroupData[{
Cell[673140, 9223, 421, 9, 107, "Input"],
Cell[673564, 9234, 2336549, 55559, 938, 2112524, 52772, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[3010128, 64796, 355, 6, 84, "Text"],

Cell[CellGroupData[{
Cell[3010508, 64806, 120796, 6389, 304, 76513, 5838, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3131307, 71197, 1130932, 51723, 328, 923550, 49158, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[4262254, 122923, 814, 13, 141, "Text"],
Cell[4263071, 122938, 130, 3, 43, "Input"],
Cell[4263204, 122943, 144, 3, 27, "Text"],
Cell[4263351, 122948, 164, 3, 44, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[4263540, 122955, 40, 1, 43, "Input"],
Cell[4263583, 122958, 58, 1, 43, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4263678, 122964, 40, 1, 43, "Input"],
Cell[4263721, 122967, 140, 2, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4263898, 122974, 40, 1, 43, "Input"],
Cell[4263941, 122977, 302, 4, 81, "Output"]
}, Open  ]],
Cell[4264258, 122984, 108, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[4264391, 122990, 53, 1, 43, "Input"],
Cell[4264447, 122993, 58, 1, 43, "Output"]
}, Open  ]],
Cell[4264520, 122997, 111, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[4264656, 123004, 815, 17, 167, "Input"],
Cell[4265474, 123023, 804643, 17056, 1026, 561496, 14044, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5070154, 140084, 39, 0, 54, "Subsection"],
Cell[5070196, 140086, 596, 10, 122, "Text"],

Cell[CellGroupData[{
Cell[5070817, 140100, 235, 5, 83, "Input"],
Cell[5071055, 140107, 325, 4, 81, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5071417, 140116, 137, 2, 43, "Input"],
Cell[5071557, 140120, 49235, 865, 243, 4419, 307, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[5120807, 140988, 1031, 25, 103, "Text"],
Cell[5121841, 141015, 228, 5, 83, "Input"],

Cell[CellGroupData[{
Cell[5122094, 141024, 53, 1, 43, "Input"],
Cell[5122150, 141027, 135, 2, 43, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5122334, 141035, 36, 0, 54, "Subsection"],
Cell[5122373, 141037, 400, 8, 65, "Text"],

Cell[CellGroupData[{
Cell[5122798, 141049, 1639, 33, 431, "Input"],
Cell[5124440, 141084, 311340, 6294, 391, 190781, 4800, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[5435795, 147381, 336, 7, 84, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5436180, 147394, 35, 0, 65, "Section"],
Cell[5436218, 147396, 519, 9, 122, "Text"],
Cell[5436740, 147407, 107, 2, 43, "Input",
  InitializationCell->True],
Cell[5436850, 147411, 652, 13, 167, "Input",
  InitializationCell->True],
Cell[5437505, 147426, 58, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[5437588, 147430, 546, 13, 145, "Input"],
Cell[5438137, 147445, 40, 1, 43, "Output"]
}, Open  ]],
Cell[5438192, 147449, 64, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[5438281, 147453, 1167, 23, 367, "Input"],
Cell[5439451, 147478, 60156, 1043, 101, 36314, 744, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[5499622, 148524, 189, 5, 65, "Text"],

Cell[CellGroupData[{
Cell[5499836, 148533, 1341, 25, 407, "Input"],
Cell[5501180, 148560, 1643082, 29143, 995, 1180943, 23426, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[7144277, 177706, 187, 5, 65, "Text"],

Cell[CellGroupData[{
Cell[7144489, 177715, 55, 1, 43, "Input"],
Cell[7144547, 177718, 25345, 863, 194, 12074, 695, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[7169907, 178584, 85, 2, 27, "Text"],

Cell[CellGroupData[{
Cell[7170017, 178590, 251, 4, 83, "Input"],
Cell[7170271, 178596, 189732, 2606, 191, 92446, 1400, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7360052, 181208, 66, 0, 65, "Section"],
Cell[7360121, 181210, 371, 8, 67, "Text"],

Cell[CellGroupData[{
Cell[7360517, 181222, 462, 9, 123, "Input"],
Cell[7360982, 181233, 3568618, 55252, 1762, 2175767, 38036, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10929649, 236491, 38, 0, 65, "Section"],
Cell[10929690, 236493, 355, 6, 65, "Text"],
Cell[10930048, 236501, 1974, 37, 403, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[10932047, 236542, 658, 13, 203, "Input"],
Cell[10932708, 236557, 138008, 2373, 606, 64879, 1466, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[11070731, 238933, 170, 5, 65, "Text"],

Cell[CellGroupData[{
Cell[11070926, 238942, 763, 14, 223, "Input"],
Cell[11071692, 238958, 231, 4, 62, "Output"]
}, Open  ]],
Cell[11071938, 238965, 111, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[11072074, 238972, 764, 14, 223, "Input"],
Cell[11072841, 238988, 121, 3, 43, "Output"]
}, Open  ]],
Cell[11072977, 238994, 132, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[11073134, 239001, 491, 10, 143, "Input"],
Cell[11073628, 239013, 12923, 272, 117, 3586, 152, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[11086566, 239288, 67, 0, 27, "Text"],
Cell[11086636, 239290, 267, 4, 81, "Output"],
Cell[11086906, 239296, 65, 0, 27, "Text"],
Cell[11086974, 239298, 226610, 3089, 781, 37037, 744, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11313587, 242389, 65, 0, 27, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11313689, 242394, 46, 0, 65, "Section"],
Cell[11313738, 242396, 860, 14, 141, "Text"],

Cell[CellGroupData[{
Cell[11314623, 242414, 214, 5, 63, "Input"],
Cell[11314840, 242421, 225, 4, 62, "Output"]
}, Open  ]],
Cell[11315080, 242428, 625, 11, 122, "Text"],

Cell[CellGroupData[{
Cell[11315730, 242443, 1588, 28, 356, "Input"],
Cell[11317321, 242473, 545111, 9230, 943, 123840, 4021, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[11862447, 251706, 341, 6, 65, "Text"],

Cell[CellGroupData[{
Cell[11862813, 251716, 38, 0, 54, "Subsection"],
Cell[11862854, 251718, 219, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[11863098, 251726, 1838, 33, 517, "Input"],
Cell[11864939, 251761, 62, 2, 43, "Output"],
Cell[11865004, 251765, 167977, 4093, 548, 81905, 3025, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12032984, 255860, 155, 3, 43, "Output"]
}, Open  ]],
Cell[12033154, 255866, 575, 9, 103, "Text"],
Cell[12033732, 255877, 176215, 3424, 491, 60861, 1994, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12209984, 259306, 37, 0, 54, "Subsection"],
Cell[12210024, 259308, 178, 3, 46, "Text"],
Cell[12210205, 259313, 534477, 9098, 941, 123840, 4021, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12744685, 268413, 59, 0, 27, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12744781, 268418, 45, 0, 54, "Subsection"],
Cell[12744829, 268420, 564981, 9475, 1074, 123840, 4021, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13309813, 277897, 273, 6, 84, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13310135, 277909, 37, 0, 65, "Section"],
Cell[13310175, 277911, 390, 8, 66, "Text"],
Cell[13310568, 277921, 419, 8, 106, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[13311012, 277933, 51, 1, 43, "Input"],
Cell[13311066, 277936, 27147, 429, 132, 8930, 200, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13338250, 278370, 51, 1, 43, "Input"],
Cell[13338304, 278373, 31869, 448, 304, 4038, 100, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13370210, 278826, 52, 1, 43, "Input"],
Cell[13370265, 278829, 53212, 726, 256, 6888, 150, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13423514, 279560, 54, 1, 43, "Input"],
Cell[13423571, 279563, 139389, 1852, 300, 26179, 450, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13563009, 281421, 29, 0, 65, "Section"],
Cell[13563041, 281423, 605, 11, 297, "Reference"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

